(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     93727,       2187]*)
(*NotebookOutlinePosition[     94708,       2223]*)
(*  CellTagsIndexPosition[     94632,       2217]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 1  Complex Numbers",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Overview",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
\tGet ready for a treat. You're about to begin studying some of the most \
beautiful ideas in mathematics. They are ideas with surprises. They evolved \
over several centuries, yet they greatly simplify extremely difficult \
computations, making some as easy as sliding a hot knife through butter. They \
also have applications in a variety of areas, ranging from fluid flow, to \
electric circuits, to the mysterious quantum world. Generally, they are \
described as belonging to the area of mathematics known as complex \
analysis.\
\>", "Text"],

Cell[TextData[StyleBox["Section 1.1  The Origin of Complex Numbers",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tComplex analysis can roughly be thought of as the subject that applies \
the theory of calculus to imaginary numbers. But what exactly are imaginary \
numbers? Usually, students learn about them in high school with introductory \
remarks from their teachers along the following lines: \"We can't take the \
square root of a negative number. But let's pretend we can and begin by using \
the symbol ",
  Cell[BoxData[
      \(\[ImaginaryI] = \@\(-1\)\)]],
  ".\" Rules are then learned for doing arithmetic with these numbers. At \
some level the rules make sense. If ",
  Cell[BoxData[
      \(\[ImaginaryI] = \@\(-1\)\)]],
  ", it stands to reason that ",
  Cell[BoxData[
      \(\[ImaginaryI]\^2 = \(-1\)\)]],
  ". However, it is not uncommon for students to wonder whether they are \
really doing magic rather than mathematics."
}], "Text"],

Cell["\<\
\tIf you ever felt that way, congratulate yourself! You're in the company of \
some of the great mathematicians from the sixteenth through the nineteenth \
centuries. They, too, were perplexed by the notion of roots of negative \
numbers. Our purpose in this section is to highlight some of the episodes in \
the very colorful history of how thinking about imaginary numbers developed. \
We intend to show you that, contrary to popular belief, there is really \
nothing imaginary about \"imaginary numbers.\" They are just as real as \
\"real numbers.\"\
\>", "Text"],

Cell[TextData[{
  "\tOur story begins in 1545. In that year the Italian mathematician ",
  StyleBox[ButtonBox["Girolamo Cardano",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cardan.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Times New Roman",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " published Ars Magna (The Great Art), a 40-chapter masterpiece in which he \
gave for the first time an algebraic solution to the ",
  StyleBox["general cubic equation",
    FontColor->RGBColor[0, 0, 1]],
  "  \n\n\t\t\t",
  Cell[BoxData[
      \(z\^3 + a\_2\ z\^2 + a\_1\ z\  + \ a\_0\  = \ 0\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tCardano did not have at his disposal the power of today's algebraic \
notation, and he tended to think of cubes or squares as geometric objects \
rather than algebraic quantities.  Essentially, however, his solution began \
with the substiution ",
  Cell[BoxData[
      \(z\  = \ x - \(1\/3\) a\_2\)]],
  ".  This move transforms  ",
  Cell[BoxData[
      \(z\^3 + a\_2\ z\^2 + a\_1\ z\  + \ a\_0\  = \ 0\)]],
  "  into the cubic equation  ",
  Cell[BoxData[
      \(x\^3 + b\ x\  + \ c\  = \ 0\)]],
  "  without a squared term, which is called a depressed cubic and can be \
written as \n\n\t\t\t",
  Cell[BoxData[
      \(x\^3 + b\ x\  + \ c\  = \ 0\)]],
  ". \n\nYou need not worry about the computational details, but the \
coefficients are  ",
  Cell[BoxData[
      \(b\  = \ a\_1 - \(1\/3\) a\_2\%2\)]],
  "  and  ",
  Cell[BoxData[
      \(c\  = \ a\_0 - \(1\/3\) a\_1\ a\_2 + \(1\/27\) 2\ a\_2\%3\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[BoxData[{
    \(\(eqn0\  = 
        z\^3 + a\_2\ z\^2 + a\_1\ z\  + \ a\_0;\)\), "\[IndentingNewLine]", 
    \(\(eqn1\  = ReplaceAll[eqn0, \ z \[Rule] \ x - a\_2/3];\)\), "\n", 
    \(\(eqn2\  = ExpandAll[eqn1];\)\), "\n", 
    \(\(eqn3\  = \ Collect[eqn2, x];\)\), "\[IndentingNewLine]", 
    \(\(Print[eqn0 \[Equal] 0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute  \>", 
        z \[Rule] \ x - a\_2/3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[eqn1 \[Equal] 0];\)\), "\[IndentingNewLine]", 
    \(\(Print[eqn2 \[Equal] 0];\)\), "\[IndentingNewLine]", 
    \(\(Print[eqn3 \[Equal] 0];\)\), "\[IndentingNewLine]", 
    \(\(A = CoefficientList[eqn3, x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[x\^3, "\< + (\>", 
        A\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\), \
"\<)\>", x, "\< + (\>", 
        A\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<) = \
0\>"];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tTo illustrate, begin with  ",
  Cell[BoxData[
      \(z\^3 + 9  z\^2 + 24  z + 20\  = \ 0\)]],
  "  and substitute  ",
  Cell[BoxData[
      \(z\  = \ \(x - \(1\/3\) a\_2\  = \ \ \(x - 9\/3\  = \ \ x - 3\)\)\)]],
  ".  The equation then becomes  ",
  Cell[BoxData[
      \(\((x - 3)\)\^3 + 9\ \((x - 3)\)\^2 + 24\ \((x - 3)\) + 20\  = \ 
        0\)]],
  ", which simplifies to  ",
  Cell[BoxData[
      \(x\^3 - 3\ x + 2\  = \ 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[BoxData[{
    \(\(eqn0\  = z\^3 + 9  z\^2 + 24  z + 20;\)\), "\[IndentingNewLine]", 
    \(\(eqn1\  = ReplaceAll[eqn0, \ z \[Rule] \ x - 9/3];\)\), "\n", 
    \(\(eqn2\  = ExpandAll[eqn1];\)\), "\n", 
    \(\(Print[eqn0 \[Equal] 0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute  \>", 
        z \[Rule] \ x - 9/3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[eqn1 \[Equal] 0];\)\), "\[IndentingNewLine]", 
    \(\(Print[eqn2 \[Equal] 0];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tIf Cardano could get any value of x that solved a depressed cubic, he \
could easily get a corresponding solution to ",
  Cell[BoxData[
      \(z\^3 + a\_2\ z\^2 + a\_1\ z\  + \ a\_0\  = \ 0\)]],
  " from the identity ",
  Cell[BoxData[
      \(z\  = \ x - \(1\/3\) a\_2\)]],
  ". Happily, Cardano knew how to solve a depressed cubic. The technique had \
been communicated to him by Niccolo Fontana who, unfortunately, came to be \
known as ",
  StyleBox[ButtonBox["Tartaglia",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Tartaglia.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " (the stammerer) due to a speaking disorder. The procedure was also \
independently discovered some 30 years earlier by Scipione del Ferro of \
Bologna. Ferro and Tartaglia showed that one of the solutions to the \
depressed cubic equation is\n\n\t\t",
  Cell[BoxData[
      \(x\  = \ \@\(\(-c\)\/2\  + \ \@\(c\^2\/4 + b\^3\/27\)\)\%3\  + \ \
\@\(\(-\(c\/2\)\)\  - \ \@\(c\^2\/4 + b\^3\/27\)\)\%3\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tAlthough Cardano would not have reasoned in the following way, today we \
can take this value for x and use it to factor the depressed cubic into a \
linear and quadratic term. The remaining roots can then be found with the \
quadratic formula. \n\n\tFor example, to solve  ",
  Cell[BoxData[
      \(z\^3 + 9  z\^2 + 24  z + 20\  = \ 0\)]],
  ",  use the substitution  ",
  Cell[BoxData[
      \(z = x - 3\)]],
  "  to get  ",
  Cell[BoxData[
      \(x\^3 - 3\ x + 2\  = \ 0\)]],
  ",  which is a depressed cubic equation.  Next, apply the \"Ferro-Tartaglia\
\" formula with ",
  Cell[BoxData[
      \(b = \(-3\)\)]],
  " and ",
  Cell[BoxData[
      \(c = 2\)]],
  " to get  ",
  Cell[BoxData[
      \(\@\(\(-2\)\/2\  + \ \@\(2\^2\/4 + \((\(-3\))\)\^3\/27\)\)\%3\  + \ \@\
\(\(-\(2\/2\)\)\  - \ \@\(2\^2\/4 + \((\(-3\))\)\^3\/27\)\)\%3\  = \ \
\(\((\(-1\))\)\^\(1/3\) + \((\(-1\))\)\^\(1/3\)\  = \ \(-2\)\)\)]],
  ".  Since  ",
  Cell[BoxData[
      \(x = \(-2\)\)]],
  "  is a root,   ",
  Cell[BoxData[
      \(x + 2\)]],
  "  must be a factor of  ",
  Cell[BoxData[
      \(x\^3 - 3\ x + 2\)]],
  ".  Dividing   ",
  Cell[BoxData[
      \(x + 2\)]],
  "  into  ",
  Cell[BoxData[
      \(x\^3 - 3\ x + 2\)]],
  "  gives  ",
  Cell[BoxData[
      \(x\^2 - 2\ x + 1\)]],
  ",  which yields the remaining (duplicate) roots of   ",
  Cell[BoxData[
      \(x = 1\)]],
  ".  The solutions to  ",
  Cell[BoxData[
      \(z\^3 + 9  z\^2 + 24  z + 20\  = \ 0\)]],
  "  are obtained by recalling  ",
  Cell[BoxData[
      \(z = x - 3\)]],
  ", which yields the three roots  ",
  Cell[BoxData[
      \(z\_1 = \(\(-2\) - 3 = \(-5\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(z\_2\  = \ \(z\_3 = \(1 - 3 = \(-2\)\)\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[BoxData[{
    \(\(eqn0\  = z\^3 + 9  z\^2 + 24  z + 20;\)\), "\[IndentingNewLine]", 
    \(\(eqn1\  = ReplaceAll[eqn0, \ z \[Rule] \ x - 9/3];\)\), "\n", 
    \(\(eqn2\  = ExpandAll[eqn1];\)\), "\n", 
    \(\(Print[eqn0 \[Equal] 0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute  \>", 
        z \[Rule] \ x - 9/3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[eqn1 \[Equal] 0];\)\), "\[IndentingNewLine]", 
    \(\(Print[eqn2 \[Equal] 0];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<Start with the Ferro-Tartaglia formula\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<x = \!\(\@\(\(-c\)\/2\\\  + \\\ \@\(c\^2\/4 + b\^3\/27\)\
\)\%3\) + \!\(\@\(\(-\(c\/2\)\)\\\  - \\\ \@\(c\^2\/4 + \
b\^3\/27\)\)\%3\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute  b\[Rule]-3  and  c\[Rule]2  and  get\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<x = \>", 
        ReplaceAll[\ \@\(\(-c\)\/2\  + \ \@\(c\^2\/4 + b\^3\/27\)\)\%3\  + \ \
\@\(\(-\(c\/2\)\)\  - \ \@\(c\^2\/4 + b\^3\/27\)\)\%3, {b \[Rule] "\<-3\>", 
            c \[Rule] "\<2\>"}]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Which simplifies\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x = \>", 
        ReplaceAll[\ \@\(\(-c\)\/2\  + \ \@\(c\^2\/4 + b\^3\/27\)\)\%3\  + \ \
\@\(\(-\(c\/2\)\)\  - \ \@\(c\^2\/4 + b\^3\/27\)\)\%3, {b \[Rule] \(-3\), 
            c \[Rule] 2}]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<And an answer is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x = -2\>"];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<Now divide \!\(x\^3\)-3 x+2 by x+2\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Q[x_] = 
        PolynomialQuotient[x\^3 - 3\ x + 2, x + 2, 
          x];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Q[x] = \!\(\(x\^3 - 3\\\ x + 2\)\/\(x + 2\)\) = \>\"", 
        Q[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[Q[x] \[Equal] 0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(Print[\ Solve[Q[x] \[Equal] 0, x\ ]]\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<The solutions to\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[eqn0 \[Equal] 0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Are\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    \!\(z\_1\) = x-3 = -2 - 3 = -5\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \!\(z\_3\)= x-3 = 1 - 3 = -2\>\""];\)\)}], \
"Input"]
}, Closed]],

Cell[TextData[{
  "\tSo, by using Tartaglia's work and a clever transformation technique, \
Cardano was able to crack what had seemed to be the impossible task of \
solving the general cubic equation.  Surprisingly, this development played a \
significant role in helping to establish the legitimacy of imaginary numbers. \
 Roots of negative numbers, of course, had come up earlier in the simplest of \
quadratic equations, such as  ",
  Cell[BoxData[
      \(x\^2 + 1 = 0\)]],
  ".  The solutions we know today as  ",
  Cell[BoxData[
      \(x = \(\[PlusMinus]\@\(-1\)\)\)]],
  ", however, were easy for mathematicians to ignore.  In Cardano's time, \
negative numbers were still being treated with some suspicion, as it was \
difficult to conceive of any physical reality corresponding to them. Taking \
square roots of such quantities was surely all the more ludicrous. \
Nevertheless, Cardano made some genuine attempts to deal with ",
  Cell[BoxData[
      \(\@\(-1\)\)]],
  ". Unfortunately, his geometric thinking made it hard to make much headway. \
At one point he commented that the process of arithmetic that deals with \
quantities such as ",
  Cell[BoxData[
      \(\@\(-1\)\)]],
  " \"involves mental tortures and is truly sophisticated.\" At another point \
he concluded that the process is \"as refined as it is useless.\" Many \
mathematicians held this view, but finally there was a breakthrough."
}], "Text"],

Cell[TextData[{
  "\tIn his 1572 treatise L'Algebra, ",
  StyleBox[ButtonBox["Rafael Bombelli",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Bombelli.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " showed that roots of negative numbers have great utility indeed. Consider \
the depressed cubic ",
  Cell[BoxData[
      \(x\^3 - 15  x - 4 = 0\)]],
  ".  Using ",
  Cell[BoxData[
      \(b = \(-15\)\)]],
  " and ",
  Cell[BoxData[
      \(c = \(-4\)\)]],
  " in the \"Ferro-Tartaglia\" formula for the depressed cubic, we compute ",
  Cell[BoxData[
      \(x = \@\(2 + \@\(-121\)\)\%3 + \@\(2 - \@\(-121\)\)\%3\)]],
  ", or in a somewhat different form, ",
  Cell[BoxData[
      \(x = \@\(2 + 11 \@\(-1\)\)\%3 + \@\(2 - 11 \@\(-1\)\)\%3\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tSimplifying this expression would have been very difficult if Bombelli \
had not come up with what he called a \"wild thought.\"  He suspected that if \
the original depressed cubic had real solutions, then the two parts of x in \
the preceding equation could be written as  ",
  Cell[BoxData[
      \(u + v \@\(-1\)\)],
    AspectRatioFixed->True],
  "  and  ",
  Cell[BoxData[
      \(u - v \@\(-1\)\)],
    AspectRatioFixed->True],
  "  for some real numbers u and v.  That is, Bombeli believed  ",
  Cell[BoxData[
      \(u + v \@\(-1\) = \@\(2 + 11 \@\(-1\)\)\%3\)]],
  " and  ",
  Cell[BoxData[
      \(u - v \@\(-1\) = \@\(2 - 11 \@\(-1\)\)\%3\)]],
  ",  which would mean  ",
  Cell[BoxData[
      \(\((u + v \@\(-1\))\)\^3 = 2 + 11 \@\(-1\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\((u - v \@\(-1\))\)\^3 = 2 - 11 \@\(-1\)\)]],
  ".  Then, using the well-known algebraic identity ",
  Cell[BoxData[
      \(\((a + b)\)\^3 = a\^3 + 3\ a\^2\ b + 3\ a\ b\^2 + b\^3\)]],
  ", and (letting ",
  Cell[BoxData[
      \(a = u\)]],
  " and ",
  Cell[BoxData[
      \(b = v\ \@\(-1\)\)]],
  "),  and assuming that roots of negative numbers obey the rules of algebra, \
he obtained  \n\t\n\t",
  Cell[BoxData[
      \(\(\(\((u + v \@\(-1\))\)\^3\)\(=\)\)\)]],
  " ",
  Cell[BoxData[
      \(u\^3 + 3 \( u\^2\) \((v \@\(-1\))\) + 
        3 \((u)\)\ \((v \@\(-1\))\)\^2 + \((v \@\(-1\))\)\^3\)]],
  "  \n\t",
  Cell[BoxData[
      \(\ \ \ \ \ \ \ \ \ \ \ \)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(u\^3 + 3 \((u)\)\ \((v \@\(-1\))\)\^2 + 
          3 \( u\^2\) \((v \@\(-1\))\) + \((v \@\(-1\))\)\^3\)\)\)\)]],
  "   \n\t                          ",
  Cell[BoxData[
      \(\(\(=\)\(\((u\^3 - 
              3  u\ v\^2)\) + \((3 \( u\^2\) v - v\^3)\) \@\(-1\)\)\)\)]],
  "  \n\t                          ",
  Cell[BoxData[
      \(\(\(=\)\(u \((u\^2 - 3\ v\^2)\) + 
          v \((3  u\^2 - v\^2)\) \@\(-1\)\)\)\)]],
  "  \n\t                          ",
  Cell[BoxData[
      \(\(\(=\)\("2 + 11\!\(\@\(-1\)\)"\)\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tBy equating like parts, Bombelli reasoned that  ",
  Cell[BoxData[
      \(u \((u\^2 - 3\ v\^2)\) = 2\)]],
  "  and  ",
  Cell[BoxData[
      \(v \((3  u\^2 - v\^2)\) = 11\)]],
  ".  Perhaps thinking even more wildly, Bombelli then supposed that u and v \
were integers.  The only integer factors of 2 are 2 and 1, so the equation  \
",
  Cell[BoxData[
      \(u \((u\^2 - 3\ v\^2)\) = 2\)]],
  "   led Bombelli to conclude that  ",
  Cell[BoxData[
      \(u = 2\)]],
  "  and  ",
  Cell[BoxData[
      \(u\^2 - 3\ v\^2 = 1\)]],
  ".  From this conclusion it follows that  ",
  Cell[BoxData[
      \(v\^2 = 1\)]],
  ", or  ",
  Cell[BoxData[
      \(v = \(\[PlusMinus]1\)\)]],
  ". Amazingly, ",
  Cell[BoxData[
      \(u = 2\)]],
  " and ",
  Cell[BoxData[
      \(v = 1\)]],
  "  solve the second equation ",
  Cell[BoxData[
      \(v \((3  u\^2 - v\^2)\) = 11\)]],
  ", so Bombelli declared the values for u and v to be u=2 and v=1, \
respectively."
}], "Text"],

Cell[TextData[{
  "\tSince ",
  Cell[BoxData[
      \(\((2 + \@\(-1\))\)\^3 = 2 + 11 \@\(-1\)\)]],
  ", we clearly have ",
  Cell[BoxData[
      \(2 + \@\(-1\) = \@\(2 + 11 \@\(-1\)\)\%3\)]],
  ".  Similarly, Bombelli showed that ",
  Cell[BoxData[
      \(2 - \@\(-1\) = \@\(2 - 11 \@\(-1\)\)\%3\)]],
  ". But this means that\n\n\t",
  Cell[BoxData[
      \(\@\(2 + 11 \@\(-1\)\)\%3 + \@\(2 - 11 \@\(-1\)\)\%3 = \(\((2 + \@\(-1\
\))\) + \((2 - \@\(-1\))\) = 4\)\)]],
  ", "
}], "Text"],

Cell[TextData[{
  "which was a proverbial bombshell.  Prior to Bombelli, mathematicians could \
easily scoff at imaginary numbers when they arose as solutions to quadratic \
equations.  With cubic equations, they no longer had this luxury. That ",
  Cell[BoxData[
      \(x = 4\)]],
  " was a correct solution to the equation  ",
  Cell[BoxData[
      \(x\^3 - 15  x - 4 = 0\)]],
  "  was indisputable, as it could be checked easily.  However, to arrive at \
this very real solution, mathematicians had to take a detour through the \
uncharted territory of \"imaginary numbers.\"  Thus, whatever else might have \
been said about these numbers (which, today, we call complex numbers), their \
utility could no longer be ignored."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the cubic equation.", "Text"],

Cell[BoxData[{
    \(\(Clear[b, c, r, x, z];\)\ \), "\n", 
    \(\(eqn\  = \ x\^3\  - \ 15\ x\  - \ 4\  \[Equal] \ 0;\)\ \), "\n", 
    \(\(solset\  = \ Solve[eqn, \ x\ ];\)\ \), "\[IndentingNewLine]", 
    \(eqn\), "\[IndentingNewLine]", 
    \(MapAll[Factor, eqn]\), "\n", 
    \(solset\)}], "Input"],

Cell["Enter the solution for the cubic equation.", "Text"],

Cell[BoxData[
    \(z\  = \ \@\(\(-c\)\/2\  + \ \@\(c\^2\/4 + b\^3\/27\)\)\%3\  + \ \@\(\(-\
\(c\/2\)\)\  - \ \@\(c\^2\/4 + b\^3\/27\)\)\%3\)], "Input"],

Cell[TextData[{
  "\nUse the Ferro-Tartaglia formula  ",
  Cell[BoxData[
      \(z = \@\(\(-c\)\/2 + \@\(c\^2\/4 + b\^3\/27\)\)\%3 - \@\(c\/2 + \
\@\(c\^2\/4 + b\^3\/27\)\)\%3\)],
    AspectRatioFixed->True],
  "  and verify that  z  it is a solution."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[z];\)\ \ \), "\n", 
    \(\(b\  = \ \(-\ 15\);\)\ \ \), "\n", 
    \(\(c\  = \ \(-\ 4\);\)\ \ \), "\n", 
    \(\(Print["\<Solve  \>", 0, "\< = \>", 
        z\^3\  + \ b\ z\  + \ c];\)\ \ \), "\n", 
    \(\(Print["\<Use the `Ferro-Tartaglia formula.`\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(z\^3\) + b z + c\>\""];\)\ \ \), "\n", 
    \(\(z\  = \ \@\(\(-c\)\/2\  + \ \@\(c\^2\/4 + b\^3\/27\)\)\%3\  + \ \
\@\(\(-\(c\/2\)\)\  - \ \@\(c\^2\/4 + b\^3\/27\)\)\%3;\)\ \ \), "\n", 
    \(\(Print[\*"\"\<z = \!\(\@\(\(-c\)\/2 + \\\ \@\(c\^2\/4 + \
b\^3\/27\)\)\%3\) + \!\(\@\(\(-\(c\/2\)\) - \\\ \@\(c\^2\/4 + b\^3\/27\)\)\%3\
\)\>\""];\)\ \ \), "\n", 
    \(\(Print["\<Substitute  b = \>", b, "\<  and  c = \>", 
        c, \ "\<  and get\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    \!\(\@\(\(-c\)\/2 + \\\ \@\(c\^2\/4 + \
b\^3\/27\)\)\%3\) = \>\"", \ \@\(\(-c\)\/2\  + \ \@\(c\^2\/4 + \
b\^3\/27\)\)\%3];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<    \!\(\@\(\(-\(c\/2\)\) - \\\ \@\(c\^2\/4 + b\^3\/27\)\
\)\%3\) = \>\"", \ \ \@\(\(-\(c\/2\)\)\  - \ \@\(c\^2\/4 + \
b\^3\/27\)\)\%3];\)\ \ \), "\n", 
    \(\(Print["\<The details are\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<z = \!\(\@\(2 + \@\(-121\)\)\%3\)+ \!\(\@\(2 + \
\@\(-121\)\)\%3\)\>\""];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<z = \!\(\@\(2 + 11 \@\(-1\)\)\%3\)+ \!\(\@\(2 + 11 \
\@\(-1\)\)\%3\)\>\""];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<    \!\(\@\(2 + 11 \@\(-1\)\)\%3\) = \>\"", \@\(2 + 11 \
\@\(-1\)\)\%3];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<    \!\(\@\(2 - 11 \@\(-1\)\)\%3\) = \>\"", \@\(2 - 11 \
\@\(-1\)\)\%3];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Add these quantities and obtain\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<z = \>", \ \@\(2 + 11 \@\(-1\)\)\%3, "\< + \>", \@\(2 - 11 \
\@\(-1\)\)\%3];\)\ \ \), "\n", 
    \(\(Print["\<z = \>", \@\(2 + 11 \@\(-1\)\)\%3 + \@\(2 - 11 \
\@\(-1\)\)\%3];\)\ \ \), "\n", 
    \(\(Print["\<z = \>"\ , \ 
        z, \ "\<, using the `Ferro-Tartaglia formula.`\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tAdmittedly, Bombelli's technique applies only to a few specialized \
cases, and lots of work remained to be done even if Bombelli's results could \
be extended.  After all, today we represent real numbers geometrically on the \
number line.  What possible representation could complex numbers have?  In \
1673 ",
  StyleBox[ButtonBox["John Wallis",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Wallis.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " made a stab at a geometric picture of complex numbers that comes close to \
what we use today.  He was interested in representing solutions to general \
quadratic equations, which we can write as ",
  Cell[BoxData[
      \(x\^2 + 2  b\ x\  + c\^2\  = 0\)]],
  " to make the following discussion easier to follow.  When we use the \
quadratic formula with this equation, we get\n\n\t\t",
  Cell[BoxData[
      \(x = \(-b\) - \@\(b\^2 - c\^2\)\)]],
  " and ",
  Cell[BoxData[
      \(x = \(-b\) + \@\(b\^2 - c\^2\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWallis imagined these solutions as displacements to the left and right \
from the point ",
  Cell[BoxData[
      \(\(-b\)\)]],
  ". He saw each displacement, whose value is ",
  Cell[BoxData[
      \(\@\(b\^2 - c\^2\)\)]],
  ", as the length of the sides of the right triangles shown in Figure 1.1. \
The points P\:2081 and P\:2082 represent the solutions to our equation, which \
is clearly correct if  ",
  Cell[BoxData[
      \(b\^2 - c\^2 \[GreaterEqual] 0\)]],
  ".  But how should we picture P\:2081 and P\:2082 when negative roots arise \
(i.e., when ",
  Cell[BoxData[
      \(b\^2 - c\^2 < 0\)]],
  ")?  Wallis reasoned that, with negative roots, b would be less than c, so \
the lines of length b in Figure 1.1 would no longer be able to reach all the \
way to the x axis.  Instead, they would stop somewhere above it, as Figure \
1.2 shows.  Wallis argued that P\:2081 and P\:2082 should represent the \
geometric locations of the solutions  ",
  Cell[BoxData[
      \(x = \(-b\) - \@\(b\^2 - c\^2\)\)]],
  "  and   ",
  Cell[BoxData[
      \(x = \(-b\) + \@\(b\^2 - c\^2\)\)]],
  "  when  ",
  Cell[BoxData[
      \(b\^2 - c\^2 < 0\)]],
  ".  He evidently thought that, because b is shorter than c, it could no \
longer be the hypotenuse of the right triangle as it had been earlier. The \
side of length c would now have to take that role."
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .65385 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.961538 0.384615 0.0769231 0.384615 [
[ 0 0 0 0 ]
[ 1 .65385 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .07692 m
1 .07692 L
s
.96154 0 m
.96154 .65385 L
s
0 0 m
1 0 L
1 .65385 L
0 .65385 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.41761 .07692 m
.41761 .46154 L
s
1 0 0 r
.03299 .07692 m
.41761 .46154 L
.80223 .07692 L
s
0 0 1 r
.02 w
.96154 .07692 Mdot
.41761 .07692 Mdot
1 0 0 r
.03299 .07692 Mdot
.80223 .07692 Mdot
0 g
gsave
.03299 .03846 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.80223 .03846 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05223 .02308 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.82146 .02308 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41761 .03846 -84.5625 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
91.750 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.938 12.813 moveto
(L) show
106.125 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.20607 .30769 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.62915 .30769 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.44838 .25 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 188.25},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000_2000`400?l00000o`00003oo`3ooolD
0?ooo`030000003oool0oooo00X0oooo003o0?oooa@0oooo00<000000?ooo`3oool02P3oool00?l0
oooo503oool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00X0oooo
003o0?oooa@0oooo00<000000?ooo`3oool02P3oool000d0oooo1@00003G0?ooo`@000009P3oool0
0`000000oooo0?ooo`0:0?ooo`003`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool02P3oool000l0oooo00<000000?ooo`3oool0f03oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo00X0oooo000?0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0:0?ooo`003`3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0100oooo0P00000=0?ooo`030000003oool0oooo05h0oooo00@0
00000?ooo`3oool000009P3oool00`000000oooo0?ooo`0:0?ooo`001`3oool3000000@0oooo0P00
001E0?ooo`030000003oool0oooo00P0oooo1@0000050?ooo`030000003oool0oooo00@0oooo0`00
00050?ooo`030000003oool0oooo05L0oooo0`0000040?ooo`8000009`3oool00`000000oooo0?oo
o`0:0?ooo`00203oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00T0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`800000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo
00080?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool00P3oool500000080oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool000P0oooo
0`00001J0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1H0?ooo`<00000;03oool00`00
0000oooo0?ooo`0:0?ooo`00203oool010000000oooo0?ooo`00001I0?ooo`030000003oool0oooo
00T0oooo0P0000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo05P0oooo00@000000?ooo`3oool00000:`3oool00`000000oooo0?oo
o`0:0?ooo`00203oool010000000oooo0?ooo`00001I0?ooo`030000003oool0oooo00T0oooo00@0
00000?ooo`00000000002`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0F03oool010000000oooo0?ooo`00000[0?ooo`030000003oool0oooo00X0oooo00080?ooo`04
0000003oool0oooo000005X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`1I0?ooo`040000003oool0
oooo000002/0oooo00<000000?ooo`3oool02P3oool000L0oooo1000001L0?ooo`030000003oool0
oooo00H0oooo0P00000?0?ooo`<000000`3oool00`000000oooo0?ooo`1I0?ooo`@00000;03oool0
0`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00X0oooo003o0?oooa@0
oooo00<000000?ooo`3oool02P3oool00?l0oooo503oool00`000000oooo0?ooo`0:0?ooo`00203o
ool30?l006/0oooo0`000?m[0?ooo`<0o`00:`3oool30000o`/0oooo0007000000D0o`00J@000005
0000ofT000001@3o000Y000000D0003o2@0000010?ooo`001`3oool50?l006T0oooo1@000?mY0?oo
o`D0o`00:@3oool50000o`X0oooo00070?ooo`D0o`00J@3oool50000ofT0oooo1@3o000Y0?ooo`D0
003o2P3oool000P0oooo0`3o00000`3oool0o`000?ooo`1X0?ooo`<0003oJP3oool40?l002/0oooo
0`000?l;0?ooo`003@3oool00`3o0000oooo0?ooo`1W0?ooo`030000o`3oool0oooo06P0oooo00<0
o`000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`003P3oool00`3o0000oooo0?ooo`1V
0?ooo`030000o`3oool0oooo06L0oooo00<0o`000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:
0?ooo`003`3oool00`3o0000oooo0?ooo`1U0?ooo`030000o`3oool0oooo06H0oooo00<0o`000?oo
o`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`00403oool00`3o0000oooo0?ooo`1T0?ooo`03
0000o`3oool0oooo06D0oooo00<0o`000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`00
4@3oool00`3o0000oooo0?ooo`1S0?ooo`030000o`3oool0oooo06@0oooo00<0o`000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0:0?ooo`004P3oool00`3o0000oooo0?ooo`1R0?ooo`030000o`3o
ool0oooo06<0oooo00<0o`000?ooo`3oool0<`3oool00`000000oooo0?ooo`0:0?ooo`004`3oool0
0`3o0000oooo0?ooo`1Q0?ooo`030000o`3oool0oooo0680oooo00<0o`000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0:0?ooo`00503oool00`3o0000oooo0?ooo`1P0?ooo`030000o`3oool0oooo
0640oooo00<0o`000?ooo`3oool0=@3oool00`000000oooo0?ooo`0:0?ooo`005@3oool00`3o0000
oooo0?ooo`1O0?ooo`030000o`3oool0oooo0600oooo00<0o`000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0:0?ooo`005P3oool00`3o0000oooo0?ooo`1N0?ooo`030000o`3oool0oooo05l0oooo
00<0o`000?ooo`3oool0=`3oool00`000000oooo0?ooo`0:0?ooo`005`3oool00`3o0000oooo0?oo
o`1M0?ooo`030000o`3oool0oooo05h0oooo00<0o`000?ooo`3oool0>03oool00`000000oooo0?oo
o`0:0?ooo`00603oool00`3o0000oooo0?ooo`1L0?ooo`030000o`3oool0oooo05d0oooo00<0o`00
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`3o0000oooo0?ooo`1K0?oo
o`030000o`3oool0oooo05`0oooo00<0o`000?ooo`3oool0>P3oool00`000000oooo0?ooo`0:0?oo
o`006P3oool00`3o0000oooo0?ooo`1J0?ooo`030000o`3oool0oooo05/0oooo00<0o`000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`3o0000oooo0?ooo`1I0?ooo`030000
o`3oool0oooo05X0oooo00<0o`000?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`00703o
ool00`3o0000oooo0?ooo`1H0?ooo`030000o`3oool0oooo05T0oooo00<0o`000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0:0?ooo`007@3oool00`3o0000oooo0?ooo`1G0?ooo`030000o`3oool0
oooo05P0oooo00<0o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`0:0?ooo`007P3oool00`3o
0000oooo0?ooo`1F0?ooo`030000o`3oool0oooo05L0oooo00<0o`000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0:0?ooo`007`3oool00`3o0000oooo0?ooo`1E0?ooo`030000o`3oool0oooo05H0
oooo00<0o`000?ooo`3oool0@03oool00`000000oooo0?ooo`0:0?ooo`00803oool00`3o0000oooo
0?ooo`1D0?ooo`030000o`3oool0oooo05D0oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0:0?ooo`008@3oool00`3o0000oooo0?ooo`1C0?ooo`030000o`3oool0oooo05@0oooo00<0
o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`3o0000oooo0?ooo`1B
0?ooo`030000o`3oool0oooo05<0oooo00<0o`000?ooo`3oool0@`3oool00`000000oooo0?ooo`0:
0?ooo`008`3oool00`3o0000oooo0?ooo`1A0?ooo`030000o`3oool0oooo0580oooo00<0o`000?oo
o`3oool0A03oool00`000000oooo0?ooo`0:0?ooo`00903oool00`3o0000oooo0?ooo`1@0?ooo`03
0000o`3oool0oooo0540oooo00<0o`000?ooo`3oool0A@3oool00`000000oooo0?ooo`0:0?ooo`00
9@3oool00`3o0000oooo0?ooo`1?0?ooo`030000o`3oool0oooo0500oooo00<0o`000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0:0?ooo`009P3oool00`3o0000oooo0?ooo`1>0?ooo`030000o`3o
ool0oooo04l0oooo00<0o`000?ooo`3oool0A`3oool00`000000oooo0?ooo`0:0?ooo`009`3oool0
0`3o0000oooo0?ooo`1=0?ooo`030000o`3oool0oooo04h0oooo00<0o`000?ooo`3oool0B03oool0
0`000000oooo0?ooo`0:0?ooo`00:03oool00`3o0000oooo0?ooo`1<0?ooo`030000o`3oool0oooo
04d0oooo00<0o`000?ooo`3oool0B@3oool00`000000oooo0?ooo`0:0?ooo`00:@3oool00`3o0000
oooo0?ooo`1;0?ooo`030000o`3oool0oooo04`0oooo00<0o`000?ooo`3oool0BP3oool00`000000
oooo0?ooo`0:0?ooo`00:P3oool00`3o0000oooo0?ooo`1:0?ooo`030000o`3oool0oooo04/0oooo
00<0o`000?ooo`3oool0B`3oool00`000000oooo0?ooo`0:0?ooo`00:`3oool00`3o0000oooo0?oo
o`190?ooo`030000o`3oool0oooo04X0oooo00<0o`000?ooo`3oool0C03oool00`000000oooo0?oo
o`0:0?ooo`00;03oool00`3o0000oooo0?ooo`180?ooo`030000o`3oool0oooo04T0oooo00<0o`00
0?ooo`3oool0C@3oool00`000000oooo0?ooo`0:0?ooo`00;@3oool00`3o0000oooo0?ooo`170?oo
o`030000o`3oool0oooo04P0oooo00<0o`000?ooo`3oool0CP3oool00`000000oooo0?ooo`0:0?oo
o`00;P3oool00`3o0000oooo0?ooo`160?ooo`030000o`3oool0oooo04L0oooo00<0o`000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0:0?ooo`00;`3oool00`3o0000oooo0?ooo`150?ooo`030000
o`3oool0oooo04H0oooo00<0o`000?ooo`3oool0D03oool00`000000oooo0?ooo`0:0?ooo`00<03o
ool00`3o0000oooo0?ooo`140?ooo`030000o`3oool0oooo04D0oooo00<0o`000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`0:0?ooo`00<@3oool00`3o0000oooo0?ooo`130?ooo`030000o`3oool0
oooo04@0oooo00<0o`000?ooo`3oool0DP3oool00`000000oooo0?ooo`0:0?ooo`00<P3oool00`3o
0000oooo0?ooo`120?ooo`030000o`3oool0oooo04<0oooo00<0o`000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0:0?ooo`00<`3oool00`3o0000oooo0?ooo`110?ooo`030000o`3oool0oooo0480
oooo00<0o`000?ooo`3oool0E03oool00`000000oooo0?ooo`0:0?ooo`00=03oool00`3o0000oooo
0?ooo`100?ooo`030000o`3oool0oooo0440oooo00<0o`000?ooo`3oool0E@3oool00`000000oooo
0?ooo`0:0?ooo`00=@3oool00`3o0000oooo0?ooo`0o0?ooo`030000o`3oool0oooo0400oooo00<0
o`000?ooo`3oool0EP3oool00`000000oooo0?ooo`0:0?ooo`00=P3oool00`3o0000oooo0?ooo`0n
0?ooo`030000o`3oool0oooo03l0oooo00<0o`000?ooo`3oool0E`3oool00`000000oooo0?ooo`0:
0?ooo`00=`3oool00`3o0000oooo0?ooo`0m0?ooo`030000o`3oool0oooo03h0oooo00<0o`000?oo
o`3oool0F03oool00`000000oooo0?ooo`0:0?ooo`00>03oool00`3o0000oooo0?ooo`0l0?ooo`03
0000o`3oool0oooo03d0oooo00<0o`000?ooo`3oool0F@3oool00`000000oooo0?ooo`0:0?ooo`00
>@3oool00`3o0000oooo0?ooo`0k0?ooo`030000o`3oool0oooo00D0oooo0`00000d0?ooo`030?l0
003oool0oooo05X0oooo00<000000?ooo`3oool02P3oool003X0oooo00<0o`000?ooo`3oool0>P3o
ool00`000?l0oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000<P3oool00`3o0000oooo
0?ooo`1K0?ooo`030000003oool0oooo00X0oooo000k0?ooo`030?l0003oool0oooo03T0oooo00<0
003o0?ooo`3oool0103oool00`000000oooo0?ooo`0c0?ooo`030?l0003oool0oooo05`0oooo00<0
00000?ooo`3oool02P3oool003`0oooo00<0o`000?ooo`3oool0>03oool00`000?l0oooo0?ooo`04
0?ooo`030000003oool0oooo0380oooo00<0o`000?ooo`3oool0G@3oool00`000000oooo0?ooo`0:
0?ooo`00?@3oool00`3o0000oooo0?ooo`0g0?ooo`030000o`3oool0oooo00@0oooo00D000000?oo
o`3oool0oooo0000000_0?ooo`030?l0003oool0oooo05h0oooo00<000000?ooo`3oool02P3oool0
03h0oooo00<0o`000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`050?ooo`@00000;P3oool00`3o
0000oooo0?ooo`1O0?ooo`030000003oool0oooo00X0oooo000o0?ooo`030?l0003oool0oooo03D0
oooo00<0003o0?ooo`3oool0=P3oool00`3o0000oooo0?ooo`1P0?ooo`030000003oool0oooo00X0
oooo00100?ooo`030?l0003oool0oooo03@0oooo00<0003o0?ooo`3oool0=03oool20?l006<0oooo
00<000000?ooo`3oool02P3oool00440oooo00<0o`000?ooo`3oool0<`3oool00`000?l0oooo0?oo
o`0c0?ooo`030?l0003oool0oooo06<0oooo00<000000?ooo`3oool02P3oool00480oooo00<0o`00
0?ooo`3oool0<P3oool00`000?l0oooo0?ooo`0b0?ooo`030?l0003oool0oooo06@0oooo00<00000
0?ooo`3oool02P3oool004<0oooo00<0o`000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0a0?oo
o`030?l0003oool0oooo06D0oooo00<000000?ooo`3oool02P3oool004@0oooo00<0o`000?ooo`3o
ool0<03oool00`000?l0oooo0?ooo`0`0?ooo`030?l0003oool0oooo06H0oooo00<000000?ooo`3o
ool02P3oool004D0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0_0?ooo`030?l0
003oool0oooo06L0oooo00<000000?ooo`3oool02P3oool004H0oooo00<0o`000?ooo`3oool0;P3o
ool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo06P0oooo00<000000?ooo`3oool02P3o
ool004L0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0
oooo06T0oooo00<000000?ooo`3oool02P3oool004P0oooo00<0o`000?ooo`3oool0;03oool00`00
0?l0oooo0?ooo`0/0?ooo`030?l0003oool0oooo06X0oooo00<000000?ooo`3oool02P3oool004T0
oooo00<0o`000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`0[0?ooo`030?l0003oool0oooo06/0
oooo00<000000?ooo`3oool02P3oool003L0oooo1@00000>0?ooo`030?l0003oool0oooo02X0oooo
00<0003o0?ooo`3oool0:P3oool00`3o0000oooo0?ooo`090?ooo`D00000GP3oool00`000000oooo
0?ooo`0:0?ooo`00>03oool01@000000oooo0?ooo`3oool0000000h0oooo00<0o`000?ooo`3oool0
:@3oool00`000?l0oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00/0oooo00D000000?ooo`3oool0
oooo0000001M0?ooo`030000003oool0oooo00X0oooo000h0?ooo`050000003oool0oooo0?ooo`00
00003`3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3o
ool0303oool01@000000oooo0?ooo`3oool0000005d0oooo00<000000?ooo`3oool02P3oool003P0
oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030?l0003oool0oooo02L0oooo00<0003o0?oo
o`3oool09`3oool00`3o0000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000G@3oool0
0`000000oooo0?ooo`0:0?ooo`00>03oool200000080oooo00<000000?ooo`3oool03`3oool00`3o
0000oooo0?ooo`0V0?ooo`030000o`3oool0oooo02H0oooo00<0o`000?ooo`3oool03P3oool20000
0080oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0:0?ooo`00>03oool010000000
oooo00000000000C0?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool09@3oool00`3o
0000oooo0?ooo`0?0?ooo`040000003oool00000000005h0oooo00<000000?ooo`3oool02P3oool0
03P0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo
02@0oooo00<0o`000?ooo`3oool0403oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo
00X0oooo000g0?ooo`800000603oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo02<0
oooo00<0o`000?ooo`3oool0403oool200000640oooo00<000000?ooo`3oool02P3oool00580oooo
00<0o`000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo07@0oooo
00<000000?ooo`3oool02P3oool005<0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?oo
o`0Q0?ooo`030?l0003oool0oooo07D0oooo00<000000?ooo`3oool02P3oool005@0oooo00<0o`00
0?ooo`3oool0803oool00`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo07H0oooo00<00000
0?ooo`3oool02P3oool005D0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0O0?oo
o`030?l0003oool0oooo07L0oooo00<000000?ooo`3oool02P3oool005H0oooo00<0o`000?ooo`3o
ool07P3oool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo07P0oooo00<000000?ooo`3o
ool02P3oool005L0oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0M0?ooo`030?l0
003oool0oooo07T0oooo00<000000?ooo`3oool02P3oool005P0oooo00<0o`000?ooo`3oool0703o
ool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo07X0oooo00<000000?ooo`3oool02P3o
ool005T0oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0
oooo07/0oooo00<000000?ooo`3oool02P3oool005X0oooo00<0o`000?ooo`3oool06P3oool00`00
0?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo07`0oooo00<000000?ooo`3oool02P3oool005/0
oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo07d0
oooo00<000000?ooo`3oool02P3oool005`0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo
0?ooo`0H0?ooo`030?l0003oool0oooo07h0oooo00<000000?ooo`3oool02P3oool005d0oooo00<0
o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo07l0oooo00<0
00000?ooo`3oool02P3oool005h0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0F
0?ooo`030?l0003oool0oooo0800oooo00<000000?ooo`3oool02P3oool005l0oooo00<0o`000?oo
o`3oool05@3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo0840oooo00<000000?oo
o`3oool02P3oool00600oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0D0?ooo`03
0?l0003oool0oooo0880oooo00<000000?ooo`3oool02P3oool00640oooo00<0o`000?ooo`3oool0
4`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo08<0oooo00<000000?ooo`3oool0
2P3oool00680oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003o
ool0oooo08@0oooo00<000000?ooo`3oool02P3oool006<0oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo08D0oooo00<000000?ooo`3oool02P3oool0
06@0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo
08H0oooo00<000000?ooo`3oool02P3oool006D0oooo00<0o`000?ooo`3oool03`3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo08L0oooo00<000000?ooo`3oool02P3oool006H0oooo
00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo08P0oooo
00<000000?ooo`3oool02P3oool006L0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo08T0oooo00<000000?ooo`3oool02P3oool006P0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo08X0oooo00<00000
0?ooo`3oool02P3oool006T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo08/0oooo00<000000?ooo`3oool02P3oool006X0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo08`0oooo00<000000?ooo`3o
ool02P3oool006/0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo08d0oooo00<000000?ooo`3oool02P3oool006`0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo08h0oooo00<000000?ooo`3oool02P3o
ool006d0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo08l0oooo00<000000?ooo`3oool02P3oool006h0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0900oooo00<000000?ooo`3oool02P3oool006l0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0940
oooo00<000000?ooo`3oool02P3oool00700oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo0980oooo00<000000?ooo`3oool02P3oool00740oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo09<0oooo00<0
00000?ooo`3oool02P3oool00780oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo09@0oooo00<000000?ooo`3oool02P3oool007<0oooo00D0o`000?oo
o`3oool0oooo0000o`030?ooo`030?l0003oool0oooo09D0oooo00<000000?ooo`3oool02P3oool0
07@0oooo00@0o`000?ooo`3oool0003o0P3oool00`3o0000oooo0?ooo`2F0?ooo`030000003oool0
oooo00X0oooo001e0?ooo`050?l0003oool0003o0?ooo`3o0000V@3oool00`000000oooo0?ooo`0:
0?ooo`00MP3oool00`3o0000003o0?l0002J0?ooo`030000003oool0oooo00X0oooo001g0?ooo`03
0?l0003oool0oooo09T0oooo00<000000?ooo`3oool02P3oool00?l0oooo503oool00`000000oooo
0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00X0oooo003o0?oooa@0oooo00<00000
0?ooo`3oool02P3oool00?l0oooo503oool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`03
0000003oool0oooo00X0oooo003o0?oooa@0oooo00<000000?ooo`3oool02P3oool00?l0oooo503o
ool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00X0oooo003o0?oo
oa@0oooo00<000000?ooo`3oool02P3oool00?l0oooo503oool00`000000oooo0?ooo`0:0?ooo`00
o`3ooolD0?ooo`030000003oool0oooo00X0oooo003o0?oooa@0oooo00<000000?ooo`3oool02P3o
ool00?l0oooo503oool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0oooo
00X0oooo003o0?oooa@0oooo00<000000?ooo`3oool02P3oool00?l0oooo503oool00`000000oooo
0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00X0oooo003o0?oooa@0oooo00<00000
0?ooo`3oool02P3oool00?l0oooo503oool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`03
0000003oool0oooo00X0oooo003o0?oooa@0oooo00<000000?ooo`3oool02P3oool00?l0oooo503o
ool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00X0oooo003o0?oo
oa@0oooo00<000000?ooo`3oool02P3oool00?l0oooo503oool00`000000oooo0?ooo`0:0?ooo`00
o`3ooolD0?ooo`030000003oool0oooo00X0oooo003o0?oooa@0oooo00<000000?ooo`3oool02P3o
ool00?l0oooo503oool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0oooo
00X0oooo003o0?oooa@0oooo00<000000?ooo`3oool02P3oool00?l0oooo503oool00`000000oooo
0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00X0oooo003o0?oooa@0oooo00<00000
0?ooo`3oool02P3oool00?l0oooo503oool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`03
0000003oool0oooo00X0oooo003o0?oooa@0oooo00<000000?ooo`3oool02P3oool00?l0oooo503o
ool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00X0oooo003o0?oo
oa@0oooo00<000000?ooo`3oool02P3oool00?l0oooo503oool00`000000oooo0?ooo`0:0?ooo`00
o`3ooolD0?ooo`030000003oool0oooo00X0oooo003o0?oooa@0oooo00<000000?ooo`3oool02P3o
ool00?l0oooo503oool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0oooo
00X0oooo003o0?oooa@0oooo00<000000?ooo`3oool02P3oool00?l0oooo503oool00`000000oooo
0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00X0oooo003o0?oooa@0oooo00<00000
0?ooo`3oool02P3oool00?l0oooo503oool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`03
0000003oool0oooo00X0oooo003o0?oooa@0oooo00<000000?ooo`3oool02P3oool00?l0oooo503o
ool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00X0oooo003o0?oo
oa@0oooo00<000000?ooo`3oool02P3oool00?l0oooo503oool00`000000oooo0?ooo`0:0?ooo`00
\
\>"],
    ImageRangeCache->{{{0, 287}, {187.25, 0}} -> {-2, 0, 0, 0}}],
  "   \n\t\t",
  StyleBox["Figure 1.1",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Wallis's representation of real roots of quadratics.  "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .65385 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.961538 0.384615 0.0769231 0.384615 [
[ 0 0 0 0 ]
[ 1 .65385 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .07692 m
1 .07692 L
s
.96154 0 m
.96154 .65385 L
s
0 0 m
1 0 L
1 .65385 L
0 .65385 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.57692 .07692 m
.57692 .62085 L
s
1 0 0 r
.30496 .34889 m
.57692 .62085 L
.84889 .34889 L
s
0 1 0 r
.30496 .34889 m
.57692 .07692 L
.84889 .34889 L
s
0 0 1 r
.02 w
.96154 .07692 Mdot
.57692 .07692 Mdot
1 0 0 r
.30496 .34889 Mdot
.84889 .34889 Mdot
0 g
gsave
.28573 .31043 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.86812 .31043 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.30496 .29504 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.88735 .29504 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57692 .03846 -84.5625 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(H) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
91.750 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.938 12.813 moveto
(L) show
106.125 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.40248 .49283 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75137 .49283 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.60769 .32169 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 188.25},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000_2000`400?l00000o`00003oo`3ooolD
0?ooo`030000003oool0oooo00X0oooo003o0?oooa@0oooo00<000000?ooo`3oool02P3oool00?l0
oooo503oool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00X0oooo
003o0?oooa@0oooo00<000000?ooo`3oool02P3oool00?l0oooo503oool00`000000oooo0?ooo`0:
0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00X0oooo003o0?oooa@0oooo00<000000?ooo`3o
ool02P3oool009@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo05`0oooo00<000000?ooo`3oool02P3oool009<0oooo00<000000?ooo`3oool04@3o
ool2000000`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0:0?ooo`00TP3oool0
0`000000oooo0?ooo`090?ooo`D000001@3oool00`000000oooo0?ooo`030?ooo`<000001@3oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00X0oooo002B0?ooo`030000003oool0oooo
00X0oooo00D000000?ooo`3oool0oooo000000040?ooo`8000000`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0:0?ooo`00TP3oool0
0`000000oooo0?ooo`030?ooo`D000000P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
2P3oool00980oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000T0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool02P3oool00980oooo00<000000?ooo`3oool02P3oool200000080oooo00<000000?ooo`3oool0
1`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`0:0?ooo`00TP3oool00`000000oooo0?ooo`0:0?ooo`040000003oool00000000000X0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool02P3oool009<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
00X0oooo002D0?ooo`030000003oool0oooo00L0oooo0P00000>0?ooo`<000000`3oool00`000000
oooo0?ooo`1L0?ooo`030000003oool0oooo00X0oooo003o0?oooa@0oooo00<000000?ooo`3oool0
2P3oool00?l0oooo503oool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0
oooo00X0oooo002T0?ooo`<0003oJ`3oool30000o`/0oooo002S000000D0003oJ@0000050000o`T0
00000@3oool00:<0oooo1@000?mY0?ooo`D0003o2P3oool00:<0oooo1@000?mY0?ooo`D0003o2P3o
ool00:80oooo00<00?l00?ooo`000?l00P000?l00`3oool00?l00?ooo`1X0?ooo`<0003o2`3oool0
0:40oooo00D00?l00?ooo`3oool0oooo0000o`030?ooo`03003o003oool0oooo06L0oooo00<00000
0?ooo`3oool02P3oool00:00oooo00<00?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`03003o003oool0oooo06H0oooo00<000000?ooo`3oool02P3oool009l0oooo00<00?l00?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`030?ooo`03003o003oool0oooo06D0oooo00<000000?ooo`3o
ool02P3oool009h0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03003o
003oool0oooo06@0oooo00<000000?ooo`3oool02P3oool009d0oooo00<00?l00?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo06<0oooo00<000000?ooo`3oool02P3o
ool009`0oooo00<00?l00?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0
oooo0680oooo00<000000?ooo`3oool02P3oool009/0oooo00<00?l00?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`070?ooo`03003o003oool0oooo0640oooo00<000000?ooo`3oool02P3oool009X0
oooo00<00?l00?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`03003o003oool0oooo0600
oooo00<000000?ooo`3oool02P3oool009T0oooo00<00?l00?ooo`3oool02@3oool00`000?l0oooo
0?ooo`090?ooo`03003o003oool0oooo05l0oooo00<000000?ooo`3oool02P3oool009P0oooo00<0
0?l00?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`03003o003oool0oooo05h0oooo00<0
00000?ooo`3oool02P3oool009L0oooo00<00?l00?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;
0?ooo`03003o003oool0oooo05d0oooo00<000000?ooo`3oool02P3oool009H0oooo00<00?l00?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`03003o003oool0oooo05`0oooo00<000000?oo
o`3oool02P3oool009D0oooo00<00?l00?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`03
003o003oool0oooo05/0oooo00<000000?ooo`3oool02P3oool009@0oooo00<00?l00?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`0>0?ooo`03003o003oool0oooo05X0oooo00<000000?ooo`3oool0
2P3oool009<0oooo00<00?l00?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`03003o003o
ool0oooo05T0oooo00<000000?ooo`3oool02P3oool00980oooo00<00?l00?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0@0?ooo`03003o003oool0oooo05P0oooo00<000000?ooo`3oool02P3oool0
0940oooo00<00?l00?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03003o003oool0oooo
05L0oooo00<000000?ooo`3oool02P3oool00900oooo00<00?l00?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0B0?ooo`03003o003oool0oooo05H0oooo00<000000?ooo`3oool02P3oool008l0oooo
00<00?l00?ooo`3oool04`3oool00`000?l0oooo0?ooo`0C0?ooo`03003o003oool0oooo05D0oooo
00<000000?ooo`3oool02P3oool008h0oooo00<00?l00?ooo`3oool0503oool00`000?l0oooo0?oo
o`0D0?ooo`03003o003oool0oooo05@0oooo00<000000?ooo`3oool02P3oool008d0oooo00<00?l0
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0E0?ooo`03003o003oool0oooo05<0oooo00<00000
0?ooo`3oool02P3oool008`0oooo00<00?l00?ooo`3oool05P3oool00`000?l0oooo0?ooo`0F0?oo
o`03003o003oool0oooo0580oooo00<000000?ooo`3oool02P3oool008/0oooo00<00?l00?ooo`3o
ool05`3oool00`000?l0oooo0?ooo`0G0?ooo`03003o003oool0oooo0540oooo00<000000?ooo`3o
ool02P3oool008X0oooo00<00?l00?ooo`3oool0603oool00`000?l0oooo0?ooo`0H0?ooo`03003o
003oool0oooo0500oooo00<000000?ooo`3oool02P3oool008T0oooo00<00?l00?ooo`3oool06@3o
ool00`000?l0oooo0?ooo`0I0?ooo`03003o003oool0oooo04l0oooo00<000000?ooo`3oool02P3o
ool008P0oooo00<00?l00?ooo`3oool06P3oool00`000?l0oooo0?ooo`0J0?ooo`03003o003oool0
oooo04h0oooo00<000000?ooo`3oool02P3oool008L0oooo00<00?l00?ooo`3oool06`3oool00`00
0?l0oooo0?ooo`0K0?ooo`03003o003oool0oooo04d0oooo00<000000?ooo`3oool02P3oool008H0
oooo00<00?l00?ooo`3oool0703oool00`000?l0oooo0?ooo`0L0?ooo`03003o003oool0oooo04`0
oooo00<000000?ooo`3oool02P3oool008D0oooo00<00?l00?ooo`3oool07@3oool00`000?l0oooo
0?ooo`0M0?ooo`03003o003oool0oooo04/0oooo00<000000?ooo`3oool02P3oool008@0oooo00<0
0?l00?ooo`3oool07P3oool00`000?l0oooo0?ooo`0N0?ooo`03003o003oool0oooo04X0oooo00<0
00000?ooo`3oool02P3oool008<0oooo00<00?l00?ooo`3oool07`3oool00`000?l0oooo0?ooo`0O
0?ooo`03003o003oool0oooo04T0oooo00<000000?ooo`3oool02P3oool00880oooo00<00?l00?oo
o`3oool0803oool00`000?l0oooo0?ooo`0P0?ooo`03003o003oool0oooo04P0oooo00<000000?oo
o`3oool02P3oool00840oooo00<00?l00?ooo`3oool08@3oool00`000?l0oooo0?ooo`0Q0?ooo`03
003o003oool0oooo04L0oooo00<000000?ooo`3oool02P3oool00800oooo00<00?l00?ooo`3oool0
8P3oool00`000?l0oooo0?ooo`0R0?ooo`03003o003oool0oooo04H0oooo00<000000?ooo`3oool0
2P3oool007l0oooo00<00?l00?ooo`3oool08`3oool00`000?l0oooo0?ooo`0S0?ooo`03003o003o
ool0oooo04D0oooo00<000000?ooo`3oool02P3oool007h0oooo00<00?l00?ooo`3oool0903oool0
0`000?l0oooo0?ooo`0T0?ooo`03003o003oool0oooo04@0oooo00<000000?ooo`3oool02P3oool0
07d0oooo00<00?l00?ooo`3oool09@3oool00`000?l0oooo0?ooo`0U0?ooo`03003o003oool0oooo
04<0oooo00<000000?ooo`3oool02P3oool007`0oooo00<00?l00?ooo`3oool09P3oool00`000?l0
oooo0?ooo`0V0?ooo`03003o003oool0oooo0480oooo00<000000?ooo`3oool02P3oool007/0oooo
00<00?l00?ooo`3oool09`3oool00`000?l0oooo0?ooo`0W0?ooo`03003o003oool0oooo0440oooo
00<000000?ooo`3oool02P3oool007X0oooo00<00?l00?ooo`3oool0:03oool00`000?l0oooo0?oo
o`0X0?ooo`03003o003oool0oooo0400oooo00<000000?ooo`3oool02P3oool007T0oooo00<00?l0
0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0Y0?ooo`03003o003oool0oooo03l0oooo00<00000
0?ooo`3oool02P3oool007P0oooo00<00?l00?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0Z0?oo
o`03003o003oool0oooo03h0oooo00<000000?ooo`3oool02P3oool007L0oooo00<00?l00?ooo`3o
ool0:`3oool00`000?l0oooo0?ooo`0[0?ooo`03003o003oool0oooo03d0oooo00<000000?ooo`3o
ool02P3oool007H0oooo00<00?l00?ooo`3oool0;03oool00`000?l0oooo0?ooo`0/0?ooo`03003o
003oool0oooo03`0oooo00<000000?ooo`3oool02P3oool007D0oooo00<00?l00?ooo`3oool0;@3o
ool00`000?l0oooo0?ooo`0]0?ooo`03003o003oool0oooo03/0oooo00<000000?ooo`3oool02P3o
ool007@0oooo00<00?l00?ooo`3oool0;P3oool00`000?l0oooo0?ooo`0^0?ooo`03003o003oool0
oooo03X0oooo00<000000?ooo`3oool02P3oool007<0oooo00<00?l00?ooo`3oool0;`3oool00`00
0?l0oooo0?ooo`0_0?ooo`03003o003oool0oooo03T0oooo00<000000?ooo`3oool02P3oool00780
oooo00<00?l00?ooo`3oool0<03oool00`000?l0oooo0?ooo`0`0?ooo`03003o003oool0oooo03P0
oooo00<000000?ooo`3oool02P3oool00740oooo00<00?l00?ooo`3oool0<@3oool00`000?l0oooo
0?ooo`0a0?ooo`03003o003oool0oooo03L0oooo00<000000?ooo`3oool02P3oool00700oooo00<0
0?l00?ooo`3oool0<P3oool00`000?l0oooo0?ooo`0b0?ooo`03003o003oool0oooo03H0oooo00<0
00000?ooo`3oool02P3oool006l0oooo00<00?l00?ooo`3oool0<`3oool00`000?l0oooo0?ooo`0c
0?ooo`03003o003oool0oooo03D0oooo00<000000?ooo`3oool02P3oool006h0oooo00<00?l00?oo
o`3oool0=03oool00`000?l0oooo0?ooo`0d0?ooo`03003o003oool0oooo03@0oooo00<000000?oo
o`3oool02P3oool006d0oooo00<00?l00?ooo`3oool0=@3oool00`000?l0oooo0?ooo`0e0?ooo`03
003o003oool0oooo03<0oooo00<000000?ooo`3oool02P3oool006`0oooo00<00?l00?ooo`3oool0
=P3oool00`000?l0oooo0?ooo`0f0?ooo`03003o003oool0oooo0380oooo00<000000?ooo`3oool0
2P3oool006/0oooo00<00?l00?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0g0?ooo`03003o003o
ool0oooo0340oooo00<000000?ooo`3oool02P3oool006X0oooo00<00?l00?ooo`3oool0>03oool0
0`000?l0oooo0?ooo`0h0?ooo`03003o003oool0oooo0300oooo00<000000?ooo`3oool02P3oool0
06T0oooo00<00?l00?ooo`3oool0>@3oool00`000?l0oooo0?ooo`0i0?ooo`03003o003oool0oooo
02l0oooo00<000000?ooo`3oool02P3oool005D0oooo1@00000>0?ooo`03003o003oool0oooo03X0
oooo00<0003o0?ooo`3oool0>P3oool00`00o`00oooo0?ooo`0G0?ooo`@000004`3oool00`000000
oooo0?ooo`0:0?ooo`00E`3oool00`000000oooo0?ooo`0=0?ooo`03003o003oool0oooo03/0oooo
00<0003o0?ooo`3oool0>`3oool00`00o`00oooo0?ooo`0F0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool02P3oool005L0oooo00<000000?ooo`3oool0303oool00`00o`00oooo0?oo
o`0l0?ooo`030000o`3oool0oooo03`0oooo00<00?l00?ooo`3oool05P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00X0oooo001G0?ooo`030000003oool0oooo00/0oooo00<00?l0
0?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0m0?ooo`03003o003oool0oooo01H0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`00E`3oool00`000000oooo0?ooo`0:0?oo
o`03003o003oool0oooo03h0oooo00<0003o0?ooo`3oool0?P3oool00`00o`00oooo0?ooo`0C0?oo
o`040000003oool0oooo000001<0oooo00<000000?ooo`3oool02P3oool004l0oooo0`0000040?oo
o`8000002`3oool00`00o`00oooo0?ooo`0o0?ooo`030000o`3oool0oooo03l0oooo00<00?l00?oo
o`3oool0303oool3000000@0oooo0P00000D0?ooo`030000003oool0oooo00X0oooo001@0?ooo`03
0000003oool0oooo00l0oooo00<00?l00?ooo`3oool0@03oool00`000?l0oooo0?ooo`100?ooo`03
003o003oool0oooo00`0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`00
D03oool00`000000oooo0?ooo`0>0?ooo`03003o003oool0oooo0440oooo00<0003o0?ooo`3oool0
@@3oool00`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
2P3oool00500oooo0`00000=0?ooo`03003o003oool0oooo0480oooo00<0003o0?ooo`3oool0103o
ool3000003/0oooo00<00?l00?ooo`3oool02P3oool3000001T0oooo00<000000?ooo`3oool02P3o
ool00500oooo00@000000?ooo`3oool000002`3oool00`00o`00oooo0?ooo`130?ooo`030000o`3o
ool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000k0?ooo`03003o003oool0oooo00T0oooo
00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`0:0?ooo`00D03oool010000000oooo
0?ooo`00000:0?ooo`03003o003oool0oooo04@0oooo00<0003o0?ooo`3oool00`3oool00`000000
oooo0?ooo`0n0?ooo`03003o003oool0oooo00P0oooo00@000000?ooo`3oool00000603oool00`00
0000oooo0?ooo`0:0?ooo`00D03oool010000000oooo0?ooo`0000090?ooo`03003o003oool0oooo
04D0oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`0o0?ooo`03003o003oool0oooo
00L0oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`0:0?ooo`00C`3oool40000
00T0oooo00<00?l00?ooo`3oool0AP3oool00`000?l0oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`000000?P3oool00`00o`00oooo0?ooo`050?ooo`@000006@3oool00`000000oooo0?ooo`0:
0?ooo`00F`3oool00`00o`00oooo0?ooo`170?ooo`030000o`3oool0oooo00@0oooo1000000o0?oo
o`03003o003oool0oooo0240oooo00<000000?ooo`3oool02P3oool005X0oooo00<00?l00?ooo`3o
ool0B03oool00`000?l0oooo0?ooo`180?ooo`03003o003oool0oooo0200oooo00<000000?ooo`3o
ool02P3oool005H0oooo0`3o00000`00o`00oooo0?ooo`190?ooo`030000o`3oool0oooo04T0oooo
00@00?l00?l0003o0000o`007P3oool00`000000oooo0?ooo`0:0?ooo`00E@3oool50?l004/0oooo
00<0003o0?ooo`3oool0B@3oool50?l001d0oooo00<000000?ooo`3oool02P3oool005D0oooo1@3o
001;0?ooo`030000o`3oool0oooo04T0oooo1@3o000M0?ooo`030000003oool0oooo00X0oooo001E
0?ooo`D0o`00B`3oool00`000?l0oooo0?ooo`190?ooo`D0o`007@3oool00`000000oooo0?ooo`0:
0?ooo`00EP3oool40?l004/0oooo00<0003o0?ooo`3oool0B@3oool40?l001h0oooo00<000000?oo
o`3oool02P3oool005X0oooo00<0o`000?ooo`3oool0B03oool00`000?l0oooo0?ooo`180?ooo`03
0?l0003oool0oooo0200oooo00<000000?ooo`3oool02P3oool005/0oooo00<0o`000?ooo`3oool0
A`3oool00`000?l0oooo0?ooo`170?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool0
2P3oool005`0oooo00<0o`000?ooo`3oool0AP3oool00`000?l0oooo0?ooo`160?ooo`030?l0003o
ool0oooo0280oooo00<000000?ooo`3oool02P3oool005d0oooo00<0o`000?ooo`3oool0A@3oool0
0`000?l0oooo0?ooo`150?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool02P3oool0
05h0oooo00<0o`000?ooo`3oool0A03oool00`000?l0oooo0?ooo`140?ooo`030?l0003oool0oooo
02@0oooo00<000000?ooo`3oool02P3oool005l0oooo00<0o`000?ooo`3oool0@`3oool00`000?l0
oooo0?ooo`130?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3oool02P3oool00600oooo
00<0o`000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`120?ooo`030?l0003oool0oooo02H0oooo
00<000000?ooo`3oool02P3oool00640oooo00<0o`000?ooo`3oool0@@3oool00`000?l0oooo0?oo
o`110?ooo`030?l0003oool0oooo02L0oooo00<000000?ooo`3oool02P3oool00680oooo00<0o`00
0?ooo`3oool0@03oool00`000?l0oooo0?ooo`100?ooo`030?l0003oool0oooo02P0oooo00<00000
0?ooo`3oool02P3oool006<0oooo00<0o`000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0o0?oo
o`030?l0003oool0oooo02T0oooo00<000000?ooo`3oool02P3oool006@0oooo00<0o`000?ooo`3o
ool0?P3oool00`000?l0oooo0?ooo`0n0?ooo`030?l0003oool0oooo02X0oooo00<000000?ooo`3o
ool02P3oool006D0oooo00<0o`000?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0m0?ooo`030?l0
003oool0oooo02/0oooo00<000000?ooo`3oool02P3oool006H0oooo00<0o`000?ooo`3oool0?03o
ool00`000?l0oooo0?ooo`0l0?ooo`030?l0003oool0oooo02`0oooo00<000000?ooo`3oool02P3o
ool006L0oooo00<0o`000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`0k0?ooo`030?l0003oool0
oooo02d0oooo00<000000?ooo`3oool02P3oool006P0oooo00<0o`000?ooo`3oool0>P3oool00`00
0?l0oooo0?ooo`0j0?ooo`030?l0003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool006T0
oooo00<0o`000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`0i0?ooo`030?l0003oool0oooo02l0
oooo00<000000?ooo`3oool02P3oool006X0oooo00<0o`000?ooo`3oool0>03oool00`000?l0oooo
0?ooo`0h0?ooo`030?l0003oool0oooo0300oooo00<000000?ooo`3oool02P3oool006/0oooo00<0
o`000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0g0?ooo`030?l0003oool0oooo0340oooo00<0
00000?ooo`3oool02P3oool006`0oooo00<0o`000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`0f
0?ooo`030?l0003oool0oooo0380oooo00<000000?ooo`3oool02P3oool006d0oooo00<0o`000?oo
o`3oool0=@3oool00`000?l0oooo0?ooo`0e0?ooo`030?l0003oool0oooo03<0oooo00<000000?oo
o`3oool02P3oool006h0oooo00<0o`000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0d0?ooo`03
0?l0003oool0oooo03@0oooo00<000000?ooo`3oool02P3oool006l0oooo00<0o`000?ooo`3oool0
<`3oool00`000?l0oooo0?ooo`0c0?ooo`030?l0003oool0oooo03D0oooo00<000000?ooo`3oool0
2P3oool00700oooo00<0o`000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`0b0?ooo`030?l0003o
ool0oooo03H0oooo00<000000?ooo`3oool02P3oool00740oooo00<0o`000?ooo`3oool0<@3oool0
0`000?l0oooo0?ooo`0a0?ooo`030?l0003oool0oooo03L0oooo00<000000?ooo`3oool02P3oool0
0780oooo00<0o`000?ooo`3oool0<03oool00`000?l0oooo0?ooo`0`0?ooo`030?l0003oool0oooo
03P0oooo00<000000?ooo`3oool02P3oool007<0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0
oooo0?ooo`0_0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool02P3oool007@0oooo
00<0o`000?ooo`3oool0;P3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo03X0oooo
00<000000?ooo`3oool02P3oool007D0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?oo
o`0]0?ooo`030?l0003oool0oooo03/0oooo00<000000?ooo`3oool02P3oool007H0oooo00<0o`00
0?ooo`3oool0;03oool00`000?l0oooo0?ooo`0/0?ooo`030?l0003oool0oooo03`0oooo00<00000
0?ooo`3oool02P3oool007L0oooo00<0o`000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`0[0?oo
o`030?l0003oool0oooo03d0oooo00<000000?ooo`3oool02P3oool007P0oooo00<0o`000?ooo`3o
ool0:P3oool00`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0oooo03h0oooo00<000000?ooo`3o
ool02P3oool007T0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0Y0?ooo`030?l0
003oool0oooo03l0oooo00<000000?ooo`3oool02P3oool007X0oooo00<0o`000?ooo`3oool0:03o
ool00`000?l0oooo0?ooo`0X0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool02P3o
ool007/0oooo00<0o`000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0W0?ooo`030?l0003oool0
oooo0440oooo00<000000?ooo`3oool02P3oool007`0oooo00<0o`000?ooo`3oool09P3oool00`00
0?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo0480oooo00<000000?ooo`3oool02P3oool007d0
oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`0U0?ooo`030?l0003oool0oooo04<0
oooo00<000000?ooo`3oool02P3oool007h0oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo
0?ooo`0T0?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3oool02P3oool006l0oooo1@00
000;0?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool08`3oool00`3o0000oooo0?oo
o`050?ooo`D00000>`3oool00`000000oooo0?ooo`0:0?ooo`00L03oool01@000000oooo0?ooo`3o
ool0000000/0oooo00<0o`000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003o
ool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000j0?ooo`030000003oool0oooo00X0oooo
001`0?ooo`050000003oool0oooo0?ooo`000000303oool00`3o0000oooo0?ooo`0Q0?ooo`030000
o`3oool0oooo0240oooo00<0o`000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000003X0
oooo00<000000?ooo`3oool02P3oool00700oooo00D000000?ooo`3oool0oooo0000000=0?ooo`03
0?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0803oool00`3o0000oooo0?ooo`090?ooo`05
0000003oool0oooo0?ooo`000000>P3oool00`000000oooo0?ooo`0:0?ooo`00L03oool200000080
oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo01l0
oooo00<0o`000?ooo`3oool02P3oool200000080oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0:0?ooo`00L03oool010000000oooo00000000000@0?ooo`030?l0003oool0oooo01h0
oooo00<0003o0?ooo`3oool07P3oool00`3o0000oooo0?ooo`0;0?ooo`040000003oool000000000
03/0oooo00<000000?ooo`3oool02P3oool00700oooo00<000000?ooo`3oool04P3oool00`3o0000
oooo0?ooo`0M0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool0303oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo00X0oooo001_0?ooo`8000005@3oool00`3o0000oooo
0?ooo`0L0?ooo`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool0303oool2000003h0oooo
00<000000?ooo`3oool02P3oool008L0oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?oo
o`0K0?ooo`030?l0003oool0oooo04d0oooo00<000000?ooo`3oool02P3oool008P0oooo00<0o`00
0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo04h0oooo00<00000
0?ooo`3oool02P3oool008T0oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0I0?oo
o`030?l0003oool0oooo04l0oooo00<000000?ooo`3oool02P3oool008X0oooo00<0o`000?ooo`3o
ool0603oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo0500oooo00<000000?ooo`3o
ool02P3oool008/0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0
003oool0oooo0540oooo00<000000?ooo`3oool02P3oool008`0oooo00<0o`000?ooo`3oool05P3o
ool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo0580oooo00<000000?ooo`3oool02P3o
ool008d0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0
oooo05<0oooo00<000000?ooo`3oool02P3oool008h0oooo00<0o`000?ooo`3oool0503oool00`00
0?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo05@0oooo00<000000?ooo`3oool02P3oool008l0
oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo05D0
oooo00<000000?ooo`3oool02P3oool00900oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo
0?ooo`0B0?ooo`030?l0003oool0oooo05H0oooo00<000000?ooo`3oool02P3oool00940oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo05L0oooo00<0
00000?ooo`3oool02P3oool00980oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0@
0?ooo`030?l0003oool0oooo05P0oooo00<000000?ooo`3oool02P3oool009<0oooo00<0o`000?oo
o`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo05T0oooo00<000000?oo
o`3oool02P3oool009@0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo05X0oooo00<000000?ooo`3oool02P3oool009D0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo05/0oooo00<000000?ooo`3oool0
2P3oool009H0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo05`0oooo00<000000?ooo`3oool02P3oool009L0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo05d0oooo00<000000?ooo`3oool02P3oool0
09P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
05h0oooo00<000000?ooo`3oool02P3oool009T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo05l0oooo00<000000?ooo`3oool02P3oool009X0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0600oooo
00<000000?ooo`3oool02P3oool009/0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo0640oooo00<000000?ooo`3oool02P3oool009`0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0680oooo00<00000
0?ooo`3oool02P3oool009d0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo06<0oooo00<000000?ooo`3oool02P3oool009h0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo06@0oooo00<000000?ooo`3o
ool02P3oool009l0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo06D0oooo00<000000?ooo`3oool02P3oool00:00oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo06H0oooo00<000000?ooo`3oool02P3o
ool00:40oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo06L0oooo00<0
00000?ooo`3oool02P3oool00:80oooo00@0o`000?ooo`3oool0003o0P3oool00`3o0000oooo0?oo
o`1X0?ooo`030000003oool0oooo00X0oooo002S0?ooo`050?l0003oool0003o0?ooo`3o0000J`3o
ool00`000000oooo0?ooo`0:0?ooo`00Y03oool00`3o0000003o0?l0001/0?ooo`030000003oool0
oooo00X0oooo002U0?ooo`030?l0003oool0oooo06/0oooo00<000000?ooo`3oool02P3oool00?l0
oooo503oool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00X0oooo
003o0?oooa@0oooo00<000000?ooo`3oool02P3oool00?l0oooo503oool00`000000oooo0?ooo`0:
0?ooo`00o`3ooolD0?ooo`030000003oool0oooo00X0oooo003o0?oooa@0oooo00<000000?ooo`3o
ool02P3oool00?l0oooo503oool00`000000oooo0?ooo`0:0?ooo`00o`3ooolD0?ooo`030000003o
ool0oooo00X0oooo003o0?oooa@0oooo00<000000?ooo`3oool02P3oool00001\
\>"],
    ImageRangeCache->{{{0, 287}, {187.25, 0}} -> {-2, 0, 0, 0}}],
  "   \n\t\t",
  StyleBox["Figure 1.2",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Wallis's representation of nonreal roots of quadratics.  "
}], "Text"],

Cell[TextData[{
  "\tWallis's method has the undesirable consequence that  ",
  Cell[BoxData[
      \(\(-\@\(-1\)\)\)]],
  "  is represented by the same point as is  ",
  Cell[BoxData[
      \(\@\(-1\)\)]],
  ". Nevertheless, this interpretation helped set the stage for thinking of \
complex numbers as \"points on the plane.\" By 1732, the great Swiss \
mathematician  ",
  StyleBox[ButtonBox["Leonhard Euler",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Euler.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  "  (pronounced \"oiler\") adopted this view concerning the n solutions to \
the equation  ",
  Cell[BoxData[
      \(x\^n - 1 = 0\)]],
  ".  You will learn shortly that these solutions can be expressed as  ",
  Cell[BoxData[
      \(cos \((\[Theta])\) + \(\@\(-1\)\) sin \((\[Theta])\)\)]],
  "  for various values of  ",
  Cell[BoxData[
      \(\[Theta]\)]],
  ";  Euler thought of them as being located at the vertices of a regular \
polygon in the plane. Euler was also the first to use the symbol ",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  " for ",
  Cell[BoxData[
      \(\@\(-1\)\)]],
  ". Today, this notation is still the most popular, although some electrical \
engineers prefer the symbol ",
  Cell[BoxData[
      \(j\)]],
  " instead so that they can use ",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  " to represent current."
}], "Text"],

Cell[TextData[{
  "\tIs it possible to modify slightly Wallis's picture of complex numbers so \
that it is consistent with the representation used today?  To help you answer \
this question, refer to the article by Alec Norton and Benjamin Lotto, \"",
  StyleBox[ButtonBox["Complex Roots Made Visible",
    ButtonData:>{
      URL[ 
      "http://links.jstor.org/sici?sici=0746-8342%28198406%2915%3A3%3C248%\
3ACRMV%3E2.0.CO%3B2-8"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  ",\" The College Mathematics Journal, 15(3), June 1984, pp. 248--249, \
Jstor. "
}], "Text"],

Cell[TextData[{
  "\tTwo additional mathematicians deserve mention. The Frenchman ",
  StyleBox[ButtonBox["Augustin-Louis Cauchy",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " (1789--1857) formulated many of the classic theorems that are now part of \
the corpus of complex analysis.  The German ",
  StyleBox[ButtonBox["Carl Friedrich Gauss",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Gauss.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " (1777--1855) reinforced the utility of complex numbers by using them in \
his several proofs of the fundamental theorem of algebra (see Chapter 6).  In \
an 1831 paper, he produced a clear geometric representation of x+iy by \
identifying it with the point (x, y) in the coordinate plane. He also \
described how to perform arithmetic operations with these new numbers."
}], "Text"],

Cell[TextData[{
  "\tIt would be a mistake, however, to conclude that in 1831 complex numbers \
were transformed into legitimacy. In that same year the prolific logician ",
  StyleBox[ButtonBox["Augustus De Morgan",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/De_Morgan.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " commented in his book, On the Study and Difficulties of Mathematics, \"We \
have shown the symbol ",
  Cell[BoxData[
      \(\@\(-a\)\)]],
  " to be void of meaning, or rather self-contradictory and absurd. \
Nevertheless, by means of such symbols, a part of algebra is established \
which is of great utility.\""
}], "Text"],

Cell[TextData[{
  "\tThere are, indeed, genuine logical problems associated with complex \
numbers. For example, with real numbers  ",
  Cell[BoxData[
      \(\@ab = \(\@a\) \@b\)]],
  "  so long as both sides of the equation are defined. Applying this \
identity to complex numbers leads to 1=\[Sqrt]1=\[Sqrt]((-1)(-1))=\[Sqrt](-1)\
\[Sqrt](-1)=-1.  Plausible answers to these problems can be given, however, \
and you will learn how to resolve this apparent contradiction in Section 2.4. \
De Morgan's remark illustrates that many factors are needed to persuade \
mathematicians to adopt new theories. In this case, as always, a firm logical \
foundation was crucial, but so, too, was a willingness to modify some ideas \
concerning certain well-established properties of numbers."
}], "Text"],

Cell["\<\
\tAs time passed, mathematicians gradually refined their thinking, and by the \
end of the nineteenth century complex numbers were firmly entrenched. Thus, \
as it is with many new mathematical or scientific innovations, the theory of \
complex numbers evolved by way of a very intricate process. But what is the \
theory that Tartaglia, Ferro, Cardano, Bombelli, Wallis, Euler, Cauchy, \
Gauss, and so many others helped produce? That is, how do we now think of \
complex numbers? We explore this question in the remainder of this chapter.\
\>", "Text"],

Cell[TextData[{
  StyleBox["The solution of the cubic equations.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can construct the solutions to the general cubic equation. However they \
are quite formidable."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the depressed cubic equation.", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[a, b, c, z];\)\ \), "\n", 
    \(\(eqn\  = \ z\^3 + b\ z\  + \ c\  \[Equal] \ 0;\)\ \), "\n", 
    \(\(solset\  = \ Solve[eqn, \ z\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1 = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(z\_2 = 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(z\_3 = 
        solset\_\(\(\[LeftDoubleBracket]\)\(3, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The depressed cubic equation \>", 
        eqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Mathematica can find the roots\>", "\<\n\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", 
        z\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", 
        z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", 
        z\_3];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Enter the general cubic equation.", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[a, b, c, z];\)\ \), "\n", 
    \(\(eqn\  = \ z\^3 + a\ z\^2 + b\ z\  + \ c\  \[Equal] \ 0;\)\ \), "\n", 
    \(\(solset\  = \ Solve[eqn, \ z\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1 = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(z\_2 = 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(z\_3 = 
        solset\_\(\(\[LeftDoubleBracket]\)\(3, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The general cubic equation \>", 
        eqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Mathematica can find the roots\>", "\<\n\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", 
        z\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", 
        z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", 
        z\_3];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nThe formulas for the roots ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", \(z\_3\)}]}]]],
  " are complicated.  Hopefully this text will promote their understanding."
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["History of Complex Numbers",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/HistoryComplexBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Numbers",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexNumbersBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1019, 643},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
CellLabelAutoDelete->True,
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[2102, 62, 189, 5, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 94416, 2206}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 189, 5, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2294, 69, 98, 2, 33, "Text"],
Cell[2395, 73, 557, 9, 71, "Text"],
Cell[2955, 84, 132, 2, 33, "Text"],
Cell[3090, 88, 864, 18, 90, "Text"],
Cell[3957, 108, 577, 9, 71, "Text"],
Cell[4537, 119, 760, 21, 90, "Text",
  Evaluatable->False],
Cell[5300, 142, 949, 25, 153, "Text"],

Cell[CellGroupData[{
Cell[6274, 171, 141, 3, 33, "Text"],
Cell[6418, 176, 1045, 19, 271, "Input"]
}, Closed]],
Cell[7478, 198, 473, 15, 52, "Text"],

Cell[CellGroupData[{
Cell[7976, 217, 141, 3, 33, "Text"],
Cell[8120, 222, 526, 9, 170, "Input"]
}, Closed]],
Cell[8661, 234, 1181, 28, 158, "Text"],
Cell[9845, 264, 1753, 59, 176, "Text"],

Cell[CellGroupData[{
Cell[11623, 327, 141, 3, 33, "Text"],
Cell[11767, 332, 526, 9, 170, "Input"],
Cell[12296, 343, 1064, 18, 290, "Input"],
Cell[13363, 363, 571, 11, 169, "Input"],
Cell[13937, 376, 380, 7, 110, "Input"]
}, Closed]],
Cell[14332, 386, 1428, 27, 144, "Text"],
Cell[15763, 415, 890, 27, 57, "Text"],
Cell[16656, 444, 2138, 62, 214, "Text",
  Evaluatable->False],
Cell[18797, 508, 985, 35, 71, "Text"],
Cell[19785, 545, 486, 15, 81, "Text"],
Cell[20274, 562, 741, 14, 90, "Text"],

Cell[CellGroupData[{
Cell[21040, 580, 190, 5, 33, "Text",
  Evaluatable->False],
Cell[21233, 587, 41, 0, 33, "Text"],
Cell[21277, 589, 302, 6, 130, "Input"],
Cell[21582, 597, 58, 0, 33, "Text"],
Cell[21643, 599, 152, 2, 63, "Input"],
Cell[21798, 603, 312, 9, 82, "Text",
  Evaluatable->False],
Cell[22113, 614, 2185, 41, 646, "Input"]
}, Closed]],
Cell[24313, 658, 1137, 27, 125, "Text"],
Cell[25453, 687, 1386, 33, 109, "Text"],
Cell[26842, 722, 26348, 564, 227, "Text"],
Cell[53193, 1288, 29635, 608, 227, "Text"],
Cell[82831, 1898, 1496, 43, 109, "Text"],
Cell[84330, 1943, 642, 14, 52, "Text"],
Cell[84975, 1959, 1142, 25, 90, "Text"],
Cell[86120, 1986, 775, 18, 71, "Text"],
Cell[86898, 2006, 795, 13, 90, "Text"],
Cell[87696, 2021, 564, 8, 71, "Text"],
Cell[88263, 2031, 346, 11, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[88634, 2046, 190, 5, 33, "Text",
  Evaluatable->False],
Cell[88827, 2053, 51, 0, 33, "Text"],
Cell[88881, 2055, 1124, 25, 310, "Input"],
Cell[90008, 2082, 49, 0, 33, "Text"],
Cell[90060, 2084, 1186, 26, 330, "Input"],
Cell[91249, 2112, 1053, 30, 52, "Text"]
}, Closed]],
Cell[92317, 2145, 290, 7, 30, "Text"],
Cell[92610, 2154, 298, 7, 33, "Text"],
Cell[92911, 2163, 287, 7, 33, "Text"],
Cell[93201, 2172, 257, 5, 33, "Text"],
Cell[93461, 2179, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

