(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     63970,       1874]*)
(*NotebookOutlinePosition[     64838,       1906]*)
(*  CellTagsIndexPosition[     64762,       1900]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["1.2  The Algebra of Complex Numbers",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tWe have seen that complex numbers came to be viewed as ordered pairs of \
real numbers. That is, a complex number ",
  Cell[BoxData[
      \(z\)]],
  " is defined to be \n\n\t\t\t",
  Cell[BoxData[
      \(z = \((x, y)\)\)]],
  ", \n\t\t\nwhere x and y are both real numbers."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe reason we say ordered pair is because we are thinking of a point in \
the plane.  The point (2, 3), for example, is not the same as (3, 2). The \
order in which we write ",
  Cell[BoxData[
      \(x\)]],
  " and ",
  Cell[BoxData[
      \(y\)]],
  " in the equation makes a difference.  Clearly, then, two complex numbers \
are equal if and only if their x coordinates are and their y coordinates are \
equal. In other words,\n\n\t\t\t",
  Cell[BoxData[
      \(\((x, y)\) = \((u, v)\)\)]],
  "   iff   ",
  Cell[BoxData[
      RowBox[{"x", "=", 
        RowBox[{
          RowBox[{"u", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "y"}], "=", "v"}]}]]],
  ".\n\t\t\n(Throughout this text, iff means if and only if.)"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tA meaningful number system requires a method for combining ordered \
pairs.  The definition of algebraic operations must be consistent so that the \
sum, difference, product, and quotient of any two ordered pairs will again be \
an ordered pair.  The key to defining how these numbers should be manipulated \
is to follow ",
  StyleBox[ButtonBox["Gauss's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Gauss.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " lead and equate ",
  Cell[BoxData[
      \(\((x, y)\)\)]],
  " with ",
  Cell[BoxData[
      \(x + \[ImaginaryI]y\)]],
  ".  Then, if ",
  Cell[BoxData[
      \(z\_1 = \((x\_1, y\_1)\)\)]],
  " and ",
  Cell[BoxData[
      \(z\_2 = \((x\_2, y\_2)\)\)]],
  " are arbitrary complex numbers, we have"
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[BoxData[{
      \(\(\(z\_1 + 
          z\_2 = \((x\_1, y\_1)\) + \((x\_2, y\_2)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\((x\_1 + \[ImaginaryI]\ y\_1)\) + \
\((x\_2 + \[ImaginaryI]\ y\_2)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\((x\_1 + 
              x\_2)\) + \[ImaginaryI] \((y\_1 + 
                y\_2)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\((x\_1 + x\_2, y\_1 + y\_2)\)\)\)}]],
  "  \n\n\tThus, the following definitions should make sense."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Definition 1.1, (Addition)\n",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\nFormula (1-8)",
    FontColor->RGBColor[0, 0, 1]],
  "    ",
  Cell[BoxData[
      \(z\_1\  + 
          z\_2\  = \(\((x\_1 + \[ImaginaryI]\ y\_1)\) + \((x\_2 + \
\[ImaginaryI]\ y\_2)\) = \((x\_1 + x\_2, y\_1 + y\_2)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation of  Formula (1-8).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[x, y, z];\)\ \), "\n", 
    \(\(z\_1 = \ x\_1\  + \ \[ImaginaryI]\ y\_1;\)\ \), "\n", 
    \(\(z\_2 = \ x\_2\  + \ \[ImaginaryI]\ y\_2;\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\""\ , \ z\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(z\_2\) = \>\""\ , \ 
        z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\) + \!\(z\_2\) = \>\""\ , \ 
        z\_1 + z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\) + \!\(z\_2\) = \>\""\ , \ 
        ComplexExpand[z\_1 + z\_2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Definition 1.2, (Subtraction)\n",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\nFormula (1-9)",
    FontColor->RGBColor[0, 0, 1]],
  "    ",
  Cell[BoxData[
      \(z\_1\  - 
          z\_2\  = \(\((x\_1 + \[ImaginaryI]\ y\_1)\) - \((x\_2 + \
\[ImaginaryI]\ y\_2)\) = \((x\_1 - x\_2, y\_1 - y\_2)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation of  Formula (1-9).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[x, y, z];\)\ \), "\n", 
    \(\(z\_1 = \ x\_1\  + \ \[ImaginaryI]\ y\_1;\)\ \), "\n", 
    \(\(z\_2 = \ x\_2\  + \ \[ImaginaryI]\ y\_2;\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\""\ , \ z\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(z\_2\) = \>\""\ , \ 
        z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\) - \!\(z\_2\) = \>\""\ , \ 
        z\_1 - z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\) - \!\(z\_2\) = \>\""\ , \ 
        ComplexExpand[z\_1 - z\_2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 1.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given  ",
  Cell[BoxData[
      \(z\_1 = \(3 + 7  \[ImaginaryI]\ \ \ and\ \ \ z\_2 = 
          5 - 6  \[ImaginaryI]\)\)]],
  ".  ",
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Find  ",
  Cell[BoxData[
      \(z\_1 + z\_2\)]],
  "  and  ",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(z\_1 - z\_2\)]],
  ".  \n\n\t\t\t",
  Cell[BoxData[
      \(z\_1\  + 
          z\_2\  = \(\((3, 7)\) + \((5, \(-6\))\) = \(\((3 + 5, 
              7 - 6)\) = \((8, 1)\)\)\)\)]],
  "  and  \n\t\t\n\t\t\t",
  Cell[BoxData[
      \(z\_1\  + 
          z\_2\  = \(\((3, 7)\) - \((5, \(-6\))\) = \(\((3 - 5, 
              7 + 6)\) = \((\(-2\), 13)\)\)\)\)]],
  ".\n\n We can also use the notation ",
  Cell[BoxData[
      \(z\_1 = 3 + 7  \[ImaginaryI]\)]],
  " and ",
  Cell[BoxData[
      \(z\_2 = 5 - 6  \[ImaginaryI]\)]],
  ":\n\n\t\t\t",
  Cell[BoxData[
      \(z\_1\  + z\_2\  = \(3 + 7  \[ImaginaryI] + 5 - 6  \[ImaginaryI] = 
          8 + \[ImaginaryI]\)\)]],
  "  and  \n\n\t\t\t",
  Cell[BoxData[
      \(z\_1\  - 
          z\_2\  = \(3 + 
            7  \[ImaginaryI]\  - \((5 - 6  \[ImaginaryI])\) = \(-2\) + 
            13  \[ImaginaryI]\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.1. (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Compute  ",
  Cell[BoxData[
      \(z\_1 + z\_2\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[V, w, z];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1 = 3 + 7  \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_2 = 5 - 6  \[ImaginaryI];\)\ \), "\n", 
    \(\(w\_1 = z\_1 + z\_2;\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        Graphics[{Red, Arrow[{0, \ 0}, {Re[z\_1], Im[z\_1]}]}];\)\ \), "\n", 
    \(\(V\_2\  = \ 
        Graphics[{Green, 
            Arrow[{Re[z\_1], Im[z\_1]}, {Re[w\_1], 
                Im[w\_1]}]}];\)\ \), "\n", 
    \(\(V\_3\  = \ 
        Graphics[{Blue, 
            Arrow[{0, \ 0}, {Re[w\_1], Im[w\_1]}]}];\)\ \), "\n", 
    \(\(Show[V\_1, V\_2, V\_3, 
        PlotRange \[Rule] {{0, 8}, {0, 
              7}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 8, 1], 
            Range[0, 7, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 7\/8, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<Red      \>", \*"\"\<     \!\(z\_1\) = \>\""\ , \ 
        z\_1];\)\ \), "\n", 
    \(\(Print["\<Green    \>", \*"\"\<     \!\(z\_2\) = \>\""\ , \ 
        z\_2];\)\ \), "\n", 
    \(\(Print["\<Blue     \>", \*"\"\<\!\(z\_1\) + \!\(z\_2\) = \>\""\ , \ 
        z\_1\  + \ z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.1. (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  " ",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" ",
    FontWeight->"Bold"],
  "Compute ",
  Cell[BoxData[
      \(z\_1 - z\_2\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[w, z];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1 = 3 + 7  \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_2 = 5 - 6  \[ImaginaryI];\)\ \), "\n", 
    \(\(w\_2 = z\_1 - z\_2;\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(v1\  = \ 
        Graphics[{Red, Arrow[{0, \ 0}, {Re[z\_1], Im[z\_1]}]}];\)\ \), "\n", 
    \(\(v2\  = \ 
        Graphics[{Green, 
            Arrow[{Re[w\_2], Im[w\_2]}, {Re[z\_1], 
                Im[z\_1]}]}];\)\ \), "\n", 
    \(\(v3\  = \ 
        Graphics[{Blue, 
            Arrow[{0, \ 0}, {Re[w\_2], Im[w\_2]}]}];\)\ \), "\n", 
    \(\(Show[v1, v2, v3, PlotRange \[Rule] {{\(-2\), 3}, {0, 13}}, 
        Ticks \[Rule] {Range[\(-2\), 3, 1], 
            Range[0, 13, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 13\/5, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<Red      \>", \*"\"\<     \!\(z\_1\) = \>\""\ , \ 
        z\_1];\)\ \), "\n", 
    \(\(Print["\<Green    \>", \*"\"\<     \!\(z\_2\) = \>\""\ , \ 
        z\_2];\)\ \), "\n", 
    \(\(Print["\<Blue    \>", \*"\"\<\!\(z\_1\) - \!\(z\_2\) = \>\""\ , \ 
        z\_1\  - \ z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tGiven the rationale we devised for addition and subtraction, it is \
tempting to define the product  ",
  Cell[BoxData[
      \(z\_1\ z\_2\)]],
  "  as  ",
  Cell[BoxData[
      \(z\_1\ z\_2\  = \((x\_1\ x\_2, y\_1\ y\_2)\)\)]],
  ".  It turns out, however, that this is not a good definition, and we ask \
you in the exercises for this section to explain why.  How, then, should \
products be defined?  Again, if we equate  ",
  Cell[BoxData[
      \(\((x, y)\)\)]],
  "  with  ",
  Cell[BoxData[
      \(x + \[ImaginaryI]\ y\)]],
  "  and assume, for the moment, that  ",
  Cell[BoxData[
      \(\[ImaginaryI] = \@\(-1\)\)]],
  "  makes sense (so that  ",
  Cell[BoxData[
      \(\[ImaginaryI]\^2 = \(-1\)\)]],
  "), we have"
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[BoxData[{
      \(\(\(z\_1\ z\_2\  = \((x\_1, \ y\_1)\) \((x\_2, 
            y\_2)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\((x\_1 + \[ImaginaryI]\ y\_1)\) \
\((x\_2 + \[ImaginaryI]y\_2)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(=\)\(x\_1\ x\_2 + \[ImaginaryI]\ x\_1\ y\_2 + \
\[ImaginaryI]\ x\_2\ y\_1 + \[ImaginaryI]\^2\ y\_1\ y\_\(\(2\)\(\
\[IndentingNewLine]\)
              \)\)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(x\_1\ x\_2 - 
          y\_1\ y\_2 + \[ImaginaryI]\ \((x\_1\ y\_2 + 
                x\_2\ y\_1)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(=\)\((x\_1\ x\_2 - y\_1\ y\_2, 
          x\_1\ y\_2 + x\_2\ y\_1)\)\)\)}]],
  "  \n\n\tThus, it appears we are forced into the following definition."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 1.3, (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Complex Multiplication",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ComplexMultiplication.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[")",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\nFormula (1-10)",
    FontColor->RGBColor[0, 0, 1]],
  "    ",
  Cell[BoxData[
      \(z\_1\ z\_2\  = \(\(\((x\_1, \ y\_1)\) \((x\_2, y\_2)\)\)\(=\)\)\)]],
  Cell[BoxData[
      \(\((x\_1\ x\_2 - y\_1\ y\_2, x\_1\ y\_2 + x\_2\ y\_1)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation of  Formula (1-10).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[x, y, z];\)\ \), "\n", 
    \(\(z\_1 = \ x\_1\  + \ \[ImaginaryI]\ y\_1;\)\ \), "\n", 
    \(\(z\_2 = \ x\_2\  + \ \[ImaginaryI]\ y\_2;\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\""\ , \ z\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(z\_2\) = \>\""\ , \ 
        z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\) \!\(z\_2\) = \>\""\ , \ 
        z\_1\ z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\) \!\(z\_2\) = \>\""\ , \ 
        ComplexExpand[z\_1\ z\_2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["\nExample 1.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given  ",
  Cell[BoxData[
      \(z\_1 = \(3 + 7  \[ImaginaryI]\ \ \ and\ \ \ z\_2 = 
          5 - 6  \[ImaginaryI]\)\)]],
  ".  Find  ",
  Cell[BoxData[
      \(\(z\_1\) z\_2\)]],
  ".  \n\t\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\(z\_1\) 
          z\_2\  = \((3, 7)\) \((5, \(-6\))\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\((3*5 - 7 \((\(-6\))\), 
          3 \((\(-6\))\) + 5*7)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\((15 + 42, \(-18\) + 
            35)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\((57, 17)\)\)\)}]],
  " \n\n We get the same answer by using the notation ",
  Cell[BoxData[
      \(z\_1 = 3 + 7  \[ImaginaryI]\)]],
  " and ",
  Cell[BoxData[
      \(z\_2 = 5 - 6  \[ImaginaryI]\)]],
  ":\n\n\t\t\t",
  Cell[BoxData[{
      \(\(z\_1\) 
          z\_2\  = \(\((3, 
              7)\) \((5, \(-6\))\) = \((3 + 7  \[ImaginaryI])\) \((5 - 
                6  \[ImaginaryI])\)\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(=\)\(15 - 18  \[ImaginaryI] + 
          35  \[ImaginaryI] - 42\ \[ImaginaryI]\^2\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(=\)\(15 - 
          42 \((\(-1\))\) + \((\(-18\) + 
                35)\) \[ImaginaryI]\)\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(57 + 
          17  \[ImaginaryI]\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\((57, 17)\)\)\)}]],
  " \n\nOf course, it makes sense that the answer came out as we expected \
because we used the notation x+iy as motivation for our definition in the \
first place."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Compute ",
  Cell[BoxData[
      \(\(z\_1\) z\_2\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[V, w, z];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1 = 3 + 7  \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_2 = 5 - 6  \[ImaginaryI];\)\ \), "\n", 
    \(\(w\_3 = \(z\_1\) z\_2;\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        Graphics[{Red, Arrow[{0, \ 0}, {Re[z\_1], Im[z\_1]}]}];\)\ \), "\n", 
    \(\(V\_2\  = \ 
        Graphics[{Green, Arrow[{0, 0}, {Re[z\_2], Im[z\_2]}]}];\)\ \), "\n", 
    \(\(V\_3 = \ 
        Graphics[{Blue, 
            Arrow[{0, \ 0}, {Re[w\_3], Im[w\_3]}]}];\)\ \), "\n", 
    \(\(Show[V\_1, V\_2, V\_3, PlotRange \[Rule] {{0, 57}, {\(-6\), 17}}, 
        Ticks \[Rule] {Range[0, 57, 5], 
            Range[\(-6\), 17, 2]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<Red      \>", \*"\"\<   \!\(z\_1\) = \>\""\ , \ 
        z\_1];\)\ \), "\n", 
    \(\(Print["\<Green    \>", \*"\"\<   \!\(z\_2\) = \>\""\ , \ 
        z\_2];\)\ \), "\n", 
    \(\(Print["\<Blue     \>", \*"\"\<\!\(z\_1\) \!\(z\_2\) = \>\""\ , \ \
\(z\_1\) z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tTo motivate our definition for division, we will proceed along the same \
lines as we did for multiplication, assuming ",
  Cell[BoxData[
      \(z\_2 \[NotEqual] 0\)]],
  ":  \n\n\t\t\t",
  Cell[BoxData[
      \(z\_1\/z\_2 = \(\((x\_1, \ y\_1)\)\/\((x\_2, y\_2)\) = \(x\_1 + \
\[ImaginaryI]\ y\_1\)\/\(x\_2 + \[ImaginaryI]y\_2\)\)\)]],
  "  "
}], "Text"],

Cell[TextData[{
  "\t\nWe need to figure out a way to write the preceding quantity in the \
form  ",
  Cell[BoxData[
      \(x + \[ImaginaryI]\ y\)]],
  ".  To do this, we use a standard trick and multiply the numerator and \
denominator by  ",
  Cell[BoxData[
      \(x\_2 + \[ImaginaryI]y\_2\)]],
  ",  which gives \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(z\_1\/z\_2 = \(\((x\_1 + \[ImaginaryI]\ y\_1)\) \((x\_2 - \
\[ImaginaryI]\ y\_2)\)\)\/\(\((x\_2 + \[ImaginaryI]\ y\_2)\) \((x\_2 - \
\[ImaginaryI]\ y\_2)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(\(=\)\(\(x\_1\ x\_2 + 
              y\_1\ y\_2 + \[ImaginaryI]\ \((\(-x\_1\)\ y\_2 + 
                    x\_2\ y\_1)\)\)\/\(x\_2\%2 + 
              y\_2\%2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(\(=\)\(\(x\_1\ x\_2 + y\_1\ y\_2\)\/\(x\_2\%2 + \
y\_2\%2\) + \[ImaginaryI] \(\(\ \)\(\(-x\_1\)\ y\_2 + x\_2\ \
y\_1\)\)\/\(x\_2\%2 + y\_2\%2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(=\)\((\(x\_1\ x\_2 + y\_1\ y\_2\)\/\(x\_2\%2 + \
y\_2\%2\), \(\(\ \)\(\(-x\_1\)\ y\_2 + x\_2\ y\_1\)\)\/\(x\_2\%2 + y\_2\%2\))\
\)\)\)}]],
  "   \n\nThus, we finally arrive at a rather odd definition."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 1.4, (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Complex Division",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ComplexDivision.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[")\n",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\nFormula (1-11)",
    FontColor->RGBColor[0, 0, 1]],
  "    ",
  Cell[BoxData[
      \(z\_1\/z\_2 = \(\((x\_1, \ y\_1)\)\/\((x\_2, y\_2)\) = \((\(x\_1\ x\_2 \
+ y\_1\ y\_2\)\/\(x\_2\%2 + y\_2\%2\), \(\(\ \)\(\(-x\_1\)\ y\_2 + x\_2\ y\_1\
\)\)\/\(x\_2\%2 + y\_2\%2\))\)\)\)]],
  ",   for   ",
  Cell[BoxData[
      \(z\_2 \[NotEqual] 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation of  Formula (1-11).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[x, y, z];\)\ \), "\n", 
    \(\(z\_1 = \ x\_1\  + \ \[ImaginaryI]\ y\_1;\)\ \), "\n", 
    \(\(z\_2 = \ 
        x\_2\  + \ \[ImaginaryI]\ y\_2;\)\ \), "\[IndentingNewLine]", 
    \(\(n = 
        Expand[\(z\_1\) \((x\_2 - \[ImaginaryI]\ y\_2)\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(d = Expand[\(z\_2\) \((x\_2 - \[ImaginaryI]\ y\_2)\)];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(z\_1\) = \>\""\ , \ z\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(z\_2\) = \>\""\ , \ 
        z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\/z\_2\) = \>\""\ , \ z\_1\/z\_2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\/z\_2\) = \>\""\ , 
        n\/d];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\/z\_2\) = \>\""\ , \(ComplexExpand[Re[n]] + \
\[ImaginaryI]\ ComplexExpand[Im[n]]\)\/d];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 1.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given  ",
  Cell[BoxData[
      \(z\_1 = \(3 + 7  \[ImaginaryI]\ \ \ and\ \ \ z\_2 = 
          5 - 6  \[ImaginaryI]\)\)]],
  ".  Find  ",
  Cell[BoxData[
      \(z\_1\/z\_2\)]],
  ".  \n\n\t\t\t",
  Cell[BoxData[
      \(z\_1\/z\_2 = \(\((3, \ 7)\)\/\((5, \(-6\))\) = \(\((\(15 - 42\)\/\(25 \
+ 36\), \(\(\ \)\(18 + 35\)\)\/\(25 + 36\))\) = \ \((\(-\(27\/61\)\), 
              53\/61)\)\)\)\)]],
  "\n\t\nAs with the example for multiplication, we also get this answer if \
we use the notation  ",
  Cell[BoxData[
      \(x + \[ImaginaryI]\ y\)]],
  ":\n\n\t\t\t",
  Cell[BoxData[{
      \(z\_1\/z\_2 = \(\((3, \ 7)\)\/\((5, \(-6\))\) = \((3 + 7  \
\[ImaginaryI])\)\/\((5 - 6  \[ImaginaryI])\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(=\)\(\(\((3 + 7  \[ImaginaryI])\)\/\((5 - 
                    6  \[ImaginaryI])\)\) \((5 + 6  \[ImaginaryI])\)\/\((5 + \
6  \[ImaginaryI])\) = \(15 + 18  \[ImaginaryI] + 35  \[ImaginaryI] + 42  \
\[ImaginaryI]\^2\)\/\(25 + 30  \[ImaginaryI] - 30  \[ImaginaryI] - 36  \
\[ImaginaryI]\^2\)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(=\)\(\(15 - 42 + \((18 + 35)\) \[ImaginaryI]\)\/\((25 \
+ 3)\)\  = \(-\(27\/61\)\) + \(53\/61\) \
\[ImaginaryI]\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(=\)\((\(-\(27\/61\)\), 53\/61)\)\)\)}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Compute ",
  Cell[BoxData[
      \(z\_1\/z\_2\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[V, w, z];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1 = 3 + 7  \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_2 = 5 - 6  \[ImaginaryI];\)\ \), "\n", 
    \(\(w\_4 = z\_1\/z\_2;\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1 = \ 
        Graphics[{Red, Arrow[{0, \ 0}, {Re[z\_1], Im[z\_1]}]}];\)\ \), "\n", 
    \(\(V\_2\  = \ 
        Graphics[{Green, Arrow[{0, 0}, {Re[z\_2], Im[z\_2]}]}];\)\ \), "\n", 
    \(\(V\_3\  = \ 
        Graphics[{Blue, 
            Arrow[{0, \ 0}, {Re[w\_4], Im[w\_4]}]}];\)\ \), "\n", 
    \(\(Show[V\_1, V\_2, V\_3, PlotRange \[Rule] {{\(-1\), 5}, {\(-6\), 7}}, 
        Ticks \[Rule] {Range[\(-1\), 5, 1], 
            Range[\(-6\), 7, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 
          13\/6, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<Red      \>", \*"\"\< \!\(z\_1\) = \>\""\ , \ 
        z\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Green    \>", \*"\"\< \!\(z\_2\) = \>\""\ , \ 
        z\_2];\)\ \), "\n", 
    \(\(Print["\<Blue     \>", \*"\"\<\!\(z\_1\/z\_2\) = \>\""\ , \ 
        z\_1\/z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tTo perform operations on complex numbers, most mathematicians would use \
the notation  ",
  Cell[BoxData[
      \(x + \[ImaginaryI]\ y\)]],
  "  and engage in algebraic manipulations, as we did here, rather than apply \
the complicated-looking definitions we gave for those operations on ordered \
pairs.  This procedure is valid because we used the  ",
  Cell[BoxData[
      \(x + \[ImaginaryI]\ y\)]],
  "  notation as a guide for defining the operations in the first place.  \
Remember, though, that the  ",
  Cell[BoxData[
      \(x + \[ImaginaryI]\ y\)]],
  "  notation is nothing more than a convenient bookkeeping device for \
keeping track of how to manipulate ordered pairs.  It is the ordered pair \
algebraic definitions that form the real foundation on which the complex \
number system is based.  In fact, if you were to program a computer to do \
arithmetic on complex numbers, your program would perform calculations on \
ordered pairs, using exactly the definitions that we gave."
}], "Text"],

Cell[TextData[{
  "\tIt turns out that our algebraic definitions give complex numbers all the \
properties we normally ascribe to the real number system.  Taken together, \
they describe what algebraists call a ",
  StyleBox[ButtonBox["field",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Field.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ".  In formal terms, a field is a set (in this case, the complex numbers) \
together with two binary operations (in this case, addition and \
multiplication) having the following properties."
}], "Text"],

Cell[TextData[{
  StyleBox["(P1) Commutative Law for Addition.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  \n",
  StyleBox["\n\t\t\t",
    FontColor->RGBColor[1, 0, 1]],
  Cell[BoxData[
      \(z\_1 + z\_2\  = \ z\_2 + z\_1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation of  Property (P1).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[x, y, z];\)\ \), "\n", 
    \(\(z\_1\  = \ x\_1\  + \ \[ImaginaryI]\ y\_1;\)\ \), "\n", 
    \(\(z\_2\  = \ x\_2\  + \ \[ImaginaryI]\ y\_2;\)\ \), "\n", 
    \(\(Print[\*"\"\<     \!\(z\_1\) = \>\""\ , z\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<     \!\(z\_2\) = \>\""\ , \ 
        z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\) + \!\(z\_2\) = \>\""\ , \ 
        z\_1 + z\_2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) + \!\(z\_1\) = \>\""\ , \ 
        z\_2 + z\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(z\_1\) + \!\(z\_2\) = \!\(z\_2\) + \!\(z\_1\) ? \
\>\"", z\_1 + z\_2\  \[Equal] \ z\_2 + z\_1];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["(P2) Associative Law for Addition.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  \n\n\t\t\t",
  Cell[BoxData[
      \(z\_1 + \((z\_2 + z\_3)\) = \((z\_1 + z\_2)\) + \ z\_3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["(P3) Additive Identity.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  There is a complex number ",
  Cell[BoxData[
      \(\[Omega]\)]],
  " such that \n\n\t\t\t",
  Cell[BoxData[
      \(z + \[Omega] = z\)]],
  " for all complex numbers z. \n\t\t\nThe number ",
  Cell[BoxData[
      \(\[Omega]\)]],
  " is obviously the ordered pair ",
  Cell[BoxData[
      \(\((0, 0)\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["(P4) Additive Inverses.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Given any complex number ",
  Cell[BoxData[
      \(z\)]],
  ", there is a complex number ",
  Cell[BoxData[
      \(\[Eta]\)]],
  " (depending on ",
  Cell[BoxData[
      \(z\)]],
  ") with the property that \n\n\t\t\t",
  Cell[BoxData[
      \(z + \[Eta] = \((0, 0)\)\)]],
  ". \n\nObviously, if ",
  Cell[BoxData[
      \(z = \(\((x, y)\) = x + \[ImaginaryI]\ y\)\)]],
  ", the number ",
  Cell[BoxData[
      \(\[Eta]\)]],
  " will be ",
  Cell[BoxData[
      \(\[Eta] = \(\((\(-x\), \(-y\))\) = \(\(-x\) - \[ImaginaryI]\ y = \
\(-z\)\)\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["(P5) Commutative Law for Multiplication.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   \n\n\t\t\t",
  Cell[BoxData[
      \(\(z\_1\) z\_2\  = \ \(z\_2\) z\_1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["(P6) Associative Law for Addition.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  \n\n\t\t\t",
  Cell[BoxData[
      \(z\_1 + \((\(z\_2\) z\_3)\) = \((\(z\_1\) z\_2)\) + \ z\_3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["(P7) Multiplicative Identity.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  There is a complex number ",
  Cell[BoxData[
      \(\[Zeta]\)]],
  " such that \n\n\t\t\t",
  Cell[BoxData[
      \(\[Zeta]z = z\)]],
  " for all complex numbers ",
  Cell[BoxData[
      \(z\)]],
  ". \n\nAs one might expect, it turns out that ",
  Cell[BoxData[
      \(\((1, 0)\)\)]],
  " is the unique complex number ",
  Cell[BoxData[
      \(\[Zeta]\)]],
  " with this property. We ask you to verify this identity in the exercises \
for this section."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["(P8) Multiplicative Inverses.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Given any number ",
  Cell[BoxData[
      \(z\)]],
  " other than the number (0, 0), there is a complex number (depending on z) \
which we shall denote by ",
  Cell[BoxData[
      \(z\^\(-1\)\)]],
  " with the property that \n\n\t\t\t",
  Cell[BoxData[
      \(z\ z\^\(-1\) = \(\((1, 0)\) = 1\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Based on our definition for division, it seems reasonable that the number \
",
  Cell[BoxData[
      \(z\^\(-1\)\)]],
  " would be  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(z\^\(-1\)\  = \ \(\((1, 0)\)\/\(\(z\)\(\ \)\) = \ 
          1\/\(x + \[ImaginaryI]\ y\)\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \(\(=\)\(\ \)\(\(x - \[ImaginaryI]\ y\)\/\(\((x + \
\[ImaginaryI]\ y)\) \((x - \[ImaginaryI]\ y)\)\)\  = \ \(x - \[ImaginaryI]\ y\
\)\/\(x\^2 + y\^2\)\)\)\ \[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(x\/\(x\^2 + y\^2\)\  + \[ImaginaryI] \
\(-y\)\/\(x\^2 + y\^2\)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \(\(=\)\((\ 
          x\/\(x\^2 + y\^2\)\ , \(-y\)\/\(x\^2 + y\^2\))\)\)\)}]],
  ".  \n\nWe ask you to confirm this result in the exercises for this \
section."
}], "Text"],

Cell[TextData[{
  StyleBox["(P9) The Distributive Law.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  \n\n\t\t\t",
  Cell[BoxData[
      \(\(z\_1\) \((z\_2 + z\_3)\) = \(z\_1\) \((z\_2 + z\_3)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation of  Property (P 9).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[x, y, z];\)\ \), "\n", 
    \(\(z\_1 = x\_1 + \[ImaginaryI]\ y\_1;\)\ \), "\n", 
    \(\(z\_2 = x\_2 + \[ImaginaryI]\ y\_2;\)\ \), "\n", 
    \(\(z\_3 = x\_3 + \[ImaginaryI]\ y\_3;\)\ \), "\n", 
    \(\(Print[\*"\"\<          \!\(z\_1\) = \>\""\ , \ z\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<          \!\(z\_2\) = \>\""\ , \ z\_2];\)\ \), "\n", 
    \(\(Print[\*"\"\<          \!\(z\_3\) = \>\""\ , \ z\_3];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<  \!\(z\_1\)(\!\(z\_2\) + \!\(z\_3\)) = \>\""\ , \
\(z\_1\) \((z\_2 + z\_3)\)];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\) \!\(z\_2\) + \!\(z\_1\) \!\(z\_3\) = \>\""\ , \
\(z\_1\) z\_2 + z\_1\ z\_3];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<  \!\(z\_1\)(\!\(z\_2\) + \!\(z\_3\)) = \>\""\ , \ 
        Expand[\(z\_1\) \((z\_2 + z\_3)\)]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\) \!\(z\_2\) + \!\(z\_1\) \!\(z\_3\) = \>\""\ , \
\ Expand[z\_1\ z\_2 + z\_1\ z\_3]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(z\_1\)(\!\(z\_2\) + \!\(z\_3\)) =  \!\(z\_1\) \
\!\(z\_2\) + \!\(z\_1\) \!\(z\_3\) ?  \>\"", 
        Expand[\(z\_1\) \((z\_2 + z\_3)\)]\ \  \[Equal] \ \ Expand[
            z\_1\ z\_2 + z\_1\ z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tNone of these properties is difficult to prove.  Most of the proofs make \
use of corresponding facts in the real number system. To illustrate, we give \
a proof of property (P1).\
\>", "Text"],

Cell[TextData[{
  "Proof of the commutative law for addition:  Let ",
  Cell[BoxData[
      \(z\_1 = \((x\_1, y\_1)\)\)]],
  " and ",
  Cell[BoxData[
      \(z\_2 = \((x\_2, y\_2)\)\)]],
  " be arbitrary complex numbers. Then,\n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(z\_1 + z\_2\  = \ \((x\_1, y\_1)\) + \((x\_2, y\_2)\)\), 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"              ", 
        RowBox[{"=", 
          RowBox[{\((x\_1 + x\_2, y\_1 + y\_2)\), "        ", 
            RowBox[{"(", 
              
              StyleBox[\(by\ definition\ of\ addition\ of\ complex\ numbers\),
                
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], ")"}]}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"              ", 
        RowBox[{"=", 
          RowBox[{\((x\_2 + x\_1, y\_2 + y\_1)\), "        ", 
            RowBox[{"(", 
              StyleBox[\(by\ the\ commutative\ law\ for\ real\ numbers\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], ")"}]}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"              ", 
        RowBox[{"=", " ", 
          RowBox[{\((x\_2, y\_2)\), "+", 
            RowBox[{\((x\_1, y\_1)\), "   ", 
              RowBox[{"(", 
                
                StyleBox[\(by\ definition\ of\ addition\ of\ complex\ numbers\
\),
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], ")"}]}]}]}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"              ", \(\(=\)\(\ \)\(z\_2 + z\_1\)\)}]}]]
}], "Text"],

Cell[TextData[{
  "\tActually, you can think of the real number system as a subset of the \
complex number system.  To see why, let's agree that, as any complex number \
of the form ",
  Cell[BoxData[
      \(\((t, 0)\)\)]],
  " is on the ",
  Cell[BoxData[
      \(x\)]],
  " axis, we can identify it with the real number ",
  Cell[BoxData[
      \(t\)]],
  ".  With this correspondence, we can easily verify that our definitions for \
addition, subtraction, multiplication, and division of complex numbers are \
consistent with the corresponding operations on real numbers.  For example, \
if ",
  Cell[BoxData[
      \(x\_1\)]],
  " and ",
  Cell[BoxData[
      \(x\_2\)]],
  " are real numbers, then\n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(\(x\_1\) x\_2\), " ", "=", " ", 
          RowBox[{\((x\_1, 0)\), \((x\_2, 0)\), "     ", 
            RowBox[{"(", 
              StyleBox[\(by\ our\ agreed\ correspondence\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], ")"}]}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"           ", 
        RowBox[{"=", 
          RowBox[{\((\(x\_1\) x\_2 - 0, 0 + 0)\), "   ", 
            RowBox[{"(", 
              
              StyleBox[\(by\ definition\ of\ multiplication\ of\ complex\ \
numbers\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], ")"}]}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"           ", 
        RowBox[{"=", 
          RowBox[{\((\(x\_1\) x\_2, 0)\), "                ", 
            RowBox[{"(", 
              
              StyleBox[\(confirming\ the\ consistence\ of\ our\ \
correspondence\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], ")"}]}]}]}]}]]
}], "Text"],

Cell[TextData[{
  "\tIt is now time to show specifically how the symbol ",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  " relates to the quantity  ",
  Cell[BoxData[
      \(\@\(-1\)\)]],
  ".  Note that \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(\((0, 1)\)\^2 = \((0, 1)\) \((0, 1)\)\), 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"               ", 
        RowBox[{"=", 
          RowBox[{\((0 - 1, 0 + 0)\), "    ", 
            RowBox[{"(", 
              
              StyleBox[\(by\ definition\ of\ multiplication\ of\ complex\ \
numbers\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], ")"}]}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"               ", \(\(=\)\((\(-1\), 0)\)\), 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"               ", 
        RowBox[{"=", 
          RowBox[{\(-1\), "                          ", 
            RowBox[{"(", 
              StyleBox[\(by\ our\ agreed\ correspondence\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], ")"}]}]}]}]}]]
}], "Text"],

Cell[TextData[{
  "\tIf we use the symbol ",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  " for the point ",
  Cell[BoxData[
      \(\((0, 1)\)\)]],
  " , the preceding identity gives \n\n\t\t\t",
  Cell[BoxData[
      \(\[ImaginaryI]\^2\  = \ \(\((0, 1)\)\^2\  = \ \(-1\)\)\)]],
  ", \n\nwhich means  ",
  Cell[BoxData[
      \(\[ImaginaryI] = \(\((0, 1)\) = \@\(-1\)\)\)]],
  ".  So, the next time you are having a discussion with your friends and \
they scoff when you claim that ",
  Cell[BoxData[
      \(\@\(-1\)\)]],
  " is not imaginary, calmly put your pencil on the point ",
  Cell[BoxData[
      \(\((0, 1)\)\)]],
  " of the coordinate plane and ask them if there is anything imaginary about \
it.  When they agree there isn't, you can tell them that this point, in fact, \
represents the mysterious ",
  Cell[BoxData[
      \(\@\(-1\)\)]],
  " in the same way that ",
  Cell[BoxData[
      \(\((1, 0)\)\)]],
  " represents ",
  Cell[BoxData[
      \(1\)]],
  " ."
}], "Text"],

Cell[TextData[{
  "\tWe can also see more clearly now how the notation  ",
  Cell[BoxData[
      \(x + \[ImaginaryI]\ y\)]],
  "  quates to ",
  Cell[BoxData[
      \(\((x, y)\)\)]],
  ".  Using the preceding conventions (i.e.,  ",
  Cell[BoxData[
      \(x = \((x, 0)\)\)]],
  ", etc.), we have  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(x + \[ImaginaryI]\ y\), " ", "=", " ", 
          RowBox[{\((x, 0)\), "+", 
            RowBox[{\((0, 1)\), \((y, 0)\), "    ", 
              RowBox[{"(", 
                StyleBox[\(by\ our\ previously\ discussed\ conventions\),
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], ")"}]}]}]}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"              ", 
        RowBox[{"=", 
          RowBox[{\((x, 0)\), "+", 
            RowBox[{\((0, y)\), "                   ", 
              RowBox[{"(", 
                
                StyleBox[\(by\ definition\ of\ multiplication\ of\ complex\ \
numbers\),
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], ")"}]}]}]}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"              ", 
        RowBox[{"=", " ", 
          RowBox[{\((x, y)\), "                                   ", 
            RowBox[{"(", 
              
              StyleBox[\(by\ definition\ of\ addition\ of\ complex\ numbers\),
                
                FontFamily->"Times New Roman"], ")"}]}]}]}]}]],
  "  "
}], "Text"],

Cell[TextData[{
  "\tThus we may move freely between the notations  ",
  Cell[BoxData[
      \(x + \[ImaginaryI]\ y\)]],
  "  and ",
  Cell[BoxData[
      \(\((x, y)\)\)]],
  ", depending on which is more convenient for the context in which we are \
working.  Students sometimes wonder whether it matters where the \"",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  "\" is located in writing a complex number.  It does not.  Generally, most \
texts place terms containing an \"",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  "\" at the end of an expression, and place the \"",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  "\" before a variable, but after a constant.  Thus, we write  ",
  Cell[BoxData[
      \(x + \[ImaginaryI]\ y\)]],
  ",  ",
  Cell[BoxData[
      \(u + \[ImaginaryI]\ v\)]],
  ", etc.,  but  ",
  Cell[BoxData[
      \(3 + \(\(7\)  \(\[ImaginaryI]\)\(\ \)\)\)]],
  ",  ",
  Cell[BoxData[
      \(5 - 6  \[ImaginaryI]\)]],
  "  and so forth.  Because letters lower in the alphabet generally denote \
constants, you will usually (but not always) see the expression  ",
  Cell[BoxData[
      \(a + b\ \[ImaginaryI]\)]],
  ",  instead of  ",
  Cell[BoxData[
      \(a + \[ImaginaryI]\ b\)]],
  ".  Many authors write quantities like ",
  Cell[BoxData[
      \(1 + \[ImaginaryI]\ \@3\)]],
  "  instead of  ",
  Cell[BoxData[
      \(1 + \@3\)]],
  "  to make sure the \"",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  "\" is not mistakenly thought to be inside the square root symbol.  \
Additionally, if there is concern that the \"",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  "\" might be missed, it is sometimes placed before a lengthy expression, as \
in  ",
  Cell[BoxData[
      \(2  cos \((\(-\(5\/6\)\) \[Pi] + 2  n\ \[Pi])\) + \[ImaginaryI]\ 2  
          sin \((\(-\(5\/6\)\) \[Pi] + 2  n\ \[Pi])\)\)]],
  "."
}], "Text"],

Cell["\<\
\tWe close this section with three important definitions and a theorem \
involving them.  We ask you for a proof of the theorem in the excercises.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Definition 1.5, (Real Part of z).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]],
  "The real part of  ",
  Cell[BoxData[
      \(z = x + \[ImaginaryI]\ y\)]],
  ",  denoted by  ",
  Cell[BoxData[
      \(Re \((z)\)\)]],
  ",  is the real number  ",
  Cell[BoxData[
      \(x\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Definition 1.6, (Imaginary Part of z).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]],
  "The imaginary part of  ",
  Cell[BoxData[
      \(z = x + \[ImaginaryI]\ y\)]],
  ",  denoted by  ",
  Cell[BoxData[
      \(Im \((z)\)\)]],
  ",  is the real number  ",
  Cell[BoxData[
      \(y\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Definition 1.7, (Conjugate of z).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]],
  "The conjugate of  ",
  Cell[BoxData[
      \(z = x + \[ImaginaryI]\ y\)]],
  ",  denoted by  ",
  Cell[BoxData[
      \(\(\(z\)\(\ \)\)\&_\)]],
  ",  is the complex number  ",
  Cell[BoxData[
      \(\((x, \(-y\))\) = x - \[ImaginaryI]\ y\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 1.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given  ",
  Cell[BoxData[
      \(z\_1 = \(\(-3\) + 7  \[ImaginaryI]\ \ \ and\ \ \ z\_2 = 
          9 + 4  \[ImaginaryI]\)\)]],
  ".   \n\n",
  StyleBox["1.4",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  We have   ",
  Cell[BoxData[
      \(Re[z\_1] = \(Re[\(-3\) + 7  \[ImaginaryI]] = \(\(-3\)\(\ \)\)\)\)]],
  "    and    ",
  Cell[BoxData[
      \(Re[z\_2] = \ \(Re[9 + 4  \[ImaginaryI]] = 9\)\)]],
  ".  \n\n",
  StyleBox["1.4",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  We have   ",
  Cell[BoxData[
      \(Im[z\_1] = \(Im[\(-3\) + 7  \[ImaginaryI]] = 7\)\)]],
  "    and    ",
  Cell[BoxData[
      \(Im[z\_2] = \(Im[9 + 4  \[ImaginaryI]] = 4\)\)]],
  ".  \n\n",
  StyleBox["1.4",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox["(c)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  We have   ",
  Cell[BoxData[
      \(\(z\_1\)\&_\  = \(\(\(-3\) + 7  \[ImaginaryI]\)\&_\  = \(-3\) - 
            7  \[ImaginaryI]\)\)]],
  "    and      ",
  Cell[BoxData[
      \(\(z\_2\)\&_ = \(\(9 + 4  \[ImaginaryI]\)\&_\  = 
          9 - 4  \[ImaginaryI]\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.4 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Compute ",
  Cell[BoxData[
      \(Re[z\_1]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[V, z];\)\ \), "\n", 
    \(\(z\_1\  = \ \(-3\)\  + \ 7  \[ImaginaryI];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1 = \ 
        Graphics[{Red, Arrow[{0, \ 0}, {Re[z\_1], Im[z\_1]}]}];\)\ \), "\n", 
    \(\(V\_2\  = \ 
        Graphics[{Blue, Arrow[{0, \ 0}, {Re[z\_1], 0}]}];\)\ \), "\n", 
    \(\(Show[V\_1, V\_2, 
        PlotRange \[Rule] {{\(-3\), 0}, {0, 
              7}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-3\), 0, 1], 
            Range[0, 7, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 7\/3, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<Red      \>", \*"\"\<    \!\(z\_1\) = \>\""\ , \ 
        z\_1];\)\ \), "\n", 
    \(\(Print["\<Blue     \>", \*"\"\<Re[\!\(z\_1\)] = \>\""\ , \ 
        Re[z\_1]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Compute ",
  Cell[BoxData[
      \(Re[z\_2]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[V, z];\)\ \), "\n", 
    \(\(z\_2\  = \ 9\  + \ 4  \[ImaginaryI];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        Graphics[{Red, Arrow[{0, \ 0}, {Re[z\_2], Im[z\_2]}]}];\)\ \), "\n", 
    \(\(V\_2\  = \ 
        Graphics[{Blue, Arrow[{0, \ 0}, {Re[z\_2], 0}]}];\)\ \), "\n", 
    \(\(Show[V\_1, V\_2, 
        PlotRange \[Rule] {{0, 9}, {0, 
              4}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 9, 1], 
            Range[0, 4, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 4\/9, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<Red      \>", \*"\"\<    \!\(z\_2\) = \>\""\ , \ 
        z\_2];\)\ \), "\n", 
    \(\(Print["\<Blue     \>", \*"\"\<Re[\!\(z\_2\)] = \>\""\ , \ 
        Re[z\_2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.4 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Compute ",
  Cell[BoxData[
      \(Im[z\_1]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[V, z];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1\  = \ \(-3\)\  + \ 7  \[ImaginaryI];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        Graphics[{Red, Arrow[{0, \ 0}, {Re[z\_1], Im[z\_1]}]}];\)\ \), "\n", 
    \(\(V\_2\  = \ 
        Graphics[{Green, Arrow[{0, \ 0}, {0, Im[z\_1]}]}];\)\ \), "\n", 
    \(\(Show[V\_1, V\_2, 
        PlotRange \[Rule] {{\(-3\), 0.1}, {0, 
              7}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-3\), 0, 1], 
            Range[0, 7, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 7\/3, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<Red      \>", \*"\"\<    \!\(z\_1\) = \>\""\ , \ 
        z\_1];\)\ \), "\n", 
    \(\(Print["\<Green    \>", \*"\"\<Im[\!\(z\_1\)] = \>\""\ , \ 
        Im[z\_1]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Compute ",
  Cell[BoxData[
      \(Im[z\_2]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[V, z];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_2\  = \ 9\  + \ 4  \[ImaginaryI];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        Graphics[{Red, Arrow[{0, \ 0}, {Re[z\_2], Im[z\_2]}]}];\)\ \), "\n", 
    \(\(V\_2\  = \ 
        Graphics[{Green, Arrow[{0, \ 0}, {0, Im[z\_2]}]}];\)\ \), "\n", 
    \(\(Show[V\_1, V\_2, 
        PlotRange \[Rule] {{0, 9}, {0, 
              4}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 9, 1], 
            Range[0, 4, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 4\/9, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<Red      \>", \*"\"\<    \!\(z\_2\) = \>\""\ , \ 
        z\_2];\)\ \), "\n", 
    \(\(Print["\<Green    \>", \*"\"\<Im[\!\(z\_2\)] = \>\""\ , \ 
        Im[z\_2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.4 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Compute  ",
  Cell[BoxData[
      \(\(\(\(z\_1\)\&_\)\(\ \)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[V, z];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1\  = \ \(-3\)\  + \ 7  \[ImaginaryI];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        Graphics[{Red, Arrow[{0, \ 0}, {Re[z\_1], Im[z\_1]}]}];\)\ \), "\n", 
    \(\(V\_2\  = \ 
        Graphics[{Blue, 
            Arrow[{0, \ 0}, {Re[z\_1], \(-Im[z\_1]\)}]}];\)\ \), "\n", 
    \(\(Show[V\_1, V\_2, 
        PlotRange \[Rule] {{\(-3\), 0}, {\(-7\), 
              7}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-3\), 0, 1], 
            Range[\(-7\), 7, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 
          7\/3, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<Red      \>", \*"\"\<\!\(z\_1\) = \>\""\ , \ 
        z\_1];\)\ \), "\n", 
    \(\(Print["\<Blue     \>", \*"\"\<\!\(\(z\_1\)\&_\) = \>\""\ , 
        Conjugate[z\_1]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Compute  ",
  Cell[BoxData[
      \(\(z\_2\)\&_\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[V, z];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_2\  = \ 9\  + \ 4  \[ImaginaryI];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        Graphics[{Red, Arrow[{0, \ 0}, {Re[z\_2], Im[z\_2]}]}];\)\ \), "\n", 
    \(\(V\_2\  = \ 
        Graphics[{Blue, 
            Arrow[{0, \ 0}, {Re[z\_2], \(-Im[z\_2]\)}]}];\)\ \), "\n", 
    \(\(Show[V\_1, V\_2, 
        PlotRange \[Rule] {{0, 9}, {\(-4\), 
              4}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 8, 1], 
            Range[\(-4\), 4, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 
          8\/9, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<Red      \>", \*"\"\<\!\(z\_2\) = \>\""\ , \ 
        z\_2];\)\ \), "\n", 
    \(\(Print["\<Blue     \>", \*"\"\<\!\(\(z\_2\)\&_\) = \>\""\ , \ 
        Conjugate[z\_2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tThe following theorem gives some important facts relating to these \
operations. You will be asked for a proof in the exercises\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 1.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose ",
  Cell[BoxData[
      RowBox[{\(z\_1\), ",", 
        RowBox[{\(z\_2\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", \(z\_3\)}]}]]],
  " are arbitrary complex numbers. Then if ",
  Cell[BoxData[
      \(z\_2 \[NotEqual] 0\)]],
  " \n\n",
  Cell[BoxData[GridBox[{
          {
            RowBox[{
              StyleBox[\((1 - 12)\),
                FontColor->RGBColor[0, 0, 1]], 
              "    "}], \(\(\ \)\(\[IndentingNewLine]\)\(\ \)\), \
\(\(\(\(\(\(z\)\(\ \)\)\&_\)\(\ \)\)\&_\)\(=\)\(z\)\(\ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \)\)},
          {
            RowBox[{
              StyleBox[\((1 - 13)\),
                FontColor->RGBColor[0, 0, 1]], 
              "     "}], \(\(\ \)\(\[IndentingNewLine]\)\(\ \)\), \(\(z\_1 + \
z\_2\)\&_\  = \(\(\(z\_1\)\&_\)\(+\)\(\(z\_2\)\&_\)\(\ \ \ \ \)\)\)},
          {
            RowBox[{
              StyleBox[\((1 - 14)\),
                FontColor->RGBColor[0, 0, 1]], 
              "     "}], \(\(\ \)\(\[IndentingNewLine]\)\(\ \)\), \
\(\(\(z\_1\) z\_2\)\&_\  = \(\(\(z\_1\)\&_\)\(\ \ \)\(\(z\_2\)\&_\)\(\ \ \ \ \
\ \ \ \ \ \ \)\)\)},
          {
            RowBox[{
              StyleBox[\((1 - 15)\),
                FontColor->RGBColor[0, 0, 1]], 
              "     "}], \(\(\ \)\(\[IndentingNewLine]\)\(\ \)\), 
            RowBox[{\(\(z\_1\/z\_2\)\&_\), " ", "=", 
              RowBox[{
                
                RowBox[{\(\(z\_1\)\&_\/\(\(\ \)\(\(\(z\_2\)\(\ \)\)\&_\)\(\ \
\)\)\), 
                  StyleBox["if",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], " ", \(z\_2\)}], "\[NotEqual]", 
                "0"}]}]},
          {
            RowBox[{
              StyleBox[\((1 - 16)\),
                FontColor->RGBColor[0, 0, 1]], 
              "     "}], \(\(\ \)\(\[IndentingNewLine]\)\(\ \)\), \(\(Re[
                z]\)\(=\)\(\(\(\ \)\(z\  + \ \ \(\(z\)\(\ \)\)\&_\)\)\/2\)\(\ \
\ \ \ \ \ \ \)\)},
          {
            RowBox[{
              StyleBox[\((1 - 17)\),
                FontColor->RGBColor[0, 0, 1]], 
              "     "}], \(\(\ \)\(\[IndentingNewLine]\)\(\ \)\), \(\(Im[
                z]\)\(=\)\(\(\(\ \)\(z\  - \ \ \(\(z\)\(\ \)\)\&_\)\)\/\(2  \
\[ImaginaryI]\)\)\(\ \ \ \ \ \ \ \ \)\)},
          {
            RowBox[{
              StyleBox[\((1 - 18)\),
                FontColor->RGBColor[0, 0, 1]], 
              "     "}], \(\(\ \)\(\[IndentingNewLine]\)\(\ \)\), \(Re[\
\[ImaginaryI]\ z] = \(-\ Im[z]\)\)},
          {
            RowBox[{
              StyleBox[\((1 - 19)\),
                FontColor->RGBColor[0, 0, 1]], "    "}], 
            " ", \(\(Im[\[ImaginaryI]\ z]\)\(=\)\(Re[z]\)\(\ \ \ \ \)\)}
          }]]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tBecause of what it erroneously connotes, it is a shame that the term \
imaginary is used in Definition (1.6).  It was coined by the brilliant \
mathematician and philosopher ",
  StyleBox[ButtonBox["Ren\[EAcute] Descartes",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Descartes.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " (1596--1650) during an era when quantities such as ",
  Cell[BoxData[
      \(\@\(-1\)\)]],
  " were thought to be just that.  Gauss, who was successful in getting \
mathematicians to adopt the phrase complex number rather than imaginary \
number, also suggested that they use lateral part of z in place of imaginary \
part of z.  Unfortunately, that suggestion never caught on, and it appears we \
are stuck with what history has handed down to us."
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Numbers",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexNumbersBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["History of Complex Numbers",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/HistoryComplexBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{991, 624},
WindowMargins->{{Automatic, 12}, {Automatic, 1}},
CellLabelAutoDelete->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 64641, 1892}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 125, 2, 33, "Text"],
Cell[2230, 66, 357, 11, 109, "Text",
  Evaluatable->False],
Cell[2590, 79, 1070, 30, 128, "Text",
  Evaluatable->False],
Cell[3663, 111, 883, 26, 71, "Text"],
Cell[4549, 139, 745, 17, 183, "Text",
  Evaluatable->False],
Cell[5297, 158, 425, 14, 71, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5747, 176, 168, 4, 33, "Text",
  Evaluatable->False],
Cell[5918, 182, 721, 14, 230, "Input"]
}, Closed]],
Cell[6654, 199, 428, 14, 68, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[7107, 217, 168, 4, 33, "Text",
  Evaluatable->False],
Cell[7278, 223, 702, 14, 210, "Input"]
}, Closed]],
Cell[7995, 240, 1492, 54, 220, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[9512, 298, 165, 4, 33, "Text",
  Evaluatable->False],
Cell[9680, 304, 208, 10, 33, "Text"],
Cell[9891, 316, 1397, 29, 345, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11325, 350, 165, 4, 30, "Text",
  Evaluatable->False],
Cell[11493, 356, 213, 11, 33, "Text"],
Cell[11709, 369, 1360, 28, 325, "Input"]
}, Closed]],
Cell[13084, 400, 760, 23, 68, "Text"],
Cell[13847, 425, 961, 20, 225, "Text"],
Cell[14811, 447, 744, 23, 71, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[15580, 474, 169, 4, 33, "Text",
  Evaluatable->False],
Cell[15752, 480, 696, 14, 210, "Input"]
}, Closed]],
Cell[16463, 497, 1967, 49, 463, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[18455, 550, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[18618, 556, 92, 5, 33, "Text"],
Cell[18713, 563, 1315, 26, 310, "Input"]
}, Closed]],
Cell[20043, 592, 376, 10, 74, "Text"],
Cell[20422, 604, 1294, 28, 305, "Text"],
Cell[21719, 634, 832, 26, 80, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[22576, 664, 169, 4, 33, "Text",
  Evaluatable->False],
Cell[22748, 670, 982, 19, 315, "Input"]
}, Closed]],
Cell[23745, 692, 1536, 37, 300, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[25306, 733, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[25469, 739, 89, 5, 39, "Text"],
Cell[25561, 746, 1336, 26, 353, "Input"]
}, Closed]],
Cell[26912, 775, 1030, 20, 106, "Text"],
Cell[27945, 797, 602, 12, 71, "Text"],
Cell[28550, 811, 318, 12, 71, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[28893, 827, 168, 4, 33, "Text",
  Evaluatable->False],
Cell[29064, 833, 831, 16, 230, "Input"]
}, Closed]],
Cell[29910, 852, 292, 10, 68, "Text",
  Evaluatable->False],
Cell[30205, 864, 492, 19, 109, "Text",
  Evaluatable->False],
Cell[30700, 885, 731, 29, 109, "Text",
  Evaluatable->False],
Cell[31434, 916, 279, 10, 71, "Text",
  Evaluatable->False],
Cell[31716, 928, 296, 10, 71, "Text",
  Evaluatable->False],
Cell[32015, 940, 641, 23, 109, "Text",
  Evaluatable->False],
Cell[32659, 965, 490, 17, 71, "Text",
  Evaluatable->False],
Cell[33152, 984, 923, 19, 254, "Text"],
Cell[34078, 1005, 286, 10, 71, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[34389, 1019, 169, 4, 33, "Text",
  Evaluatable->False],
Cell[34561, 1025, 1369, 24, 330, "Input"]
}, Closed]],
Cell[35945, 1052, 205, 4, 30, "Text"],
Cell[36153, 1058, 2288, 56, 221, "Text"],
Cell[38444, 1116, 2435, 65, 183, "Text"],
Cell[40882, 1183, 1559, 40, 183, "Text"],
Cell[42444, 1225, 987, 32, 147, "Text"],
Cell[43434, 1259, 1963, 51, 145, "Text"],
Cell[45400, 1312, 1849, 56, 131, "Text"],
Cell[47252, 1370, 170, 3, 33, "Text"],
Cell[47425, 1375, 439, 18, 33, "Text",
  Evaluatable->False],
Cell[47867, 1395, 449, 18, 33, "Text",
  Evaluatable->False],
Cell[48319, 1415, 487, 18, 33, "Text",
  Evaluatable->False],
Cell[48809, 1435, 1488, 55, 147, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[50322, 1494, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[50489, 1500, 165, 8, 33, "Text"],
Cell[50657, 1510, 1006, 20, 265, "Input"],
Cell[51666, 1532, 165, 8, 33, "Text"],
Cell[51834, 1542, 993, 20, 265, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52864, 1567, 164, 4, 30, "Text",
  Evaluatable->False],
Cell[53031, 1573, 165, 8, 33, "Text"],
Cell[53199, 1583, 1028, 20, 265, "Input"],
Cell[54230, 1605, 173, 9, 52, "Text"],
Cell[54406, 1616, 1011, 20, 265, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[55454, 1641, 164, 4, 30, "Text",
  Evaluatable->False],
Cell[55621, 1647, 183, 8, 33, "Text"],
Cell[55807, 1657, 1068, 21, 265, "Input"],
Cell[56878, 1680, 177, 9, 52, "Text"],
Cell[57058, 1691, 1053, 21, 265, "Input"]
}, Closed]],
Cell[58126, 1715, 153, 3, 30, "Text"],
Cell[58282, 1720, 3365, 89, 345, "Text",
  Evaluatable->False],
Cell[61650, 1811, 907, 19, 90, "Text"],
Cell[62560, 1832, 290, 7, 33, "Text"],
Cell[62853, 1841, 287, 7, 33, "Text"],
Cell[63143, 1850, 298, 7, 33, "Text"],
Cell[63444, 1859, 257, 5, 33, "Text"],
Cell[63704, 1866, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

