(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    225720,       4136]*)
(*NotebookOutlinePosition[    226561,       4167]*)
(*  CellTagsIndexPosition[    226484,       4161]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[{
  StyleBox["1.3",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" The Geometry of Complex Numbers",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell["\<\
\tComplex numbers are ordered pairs of real numbers, so they can be \
represented by points in the plane. In this section we show the effect that \
algebraic operations on complex numbers have on their geometric \
representations.\
\>", "Text"],

Cell[TextData[{
  "\tWe can represent the number  ",
  Cell[BoxData[
      \(z = \(x + \[ImaginaryI]\ y = \((x, y)\)\)\)]],
  "  by a position vector in the xy plane whose tail is at the origin and \
whose head is at the point  ",
  Cell[BoxData[
      \(\((x, y)\)\)]],
  ".  When the xy plane is used for displaying complex numbers, it is called \
the ",
  StyleBox[ButtonBox["complex plane",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ComplexPlane.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ", or more simply, the ",
  Cell[BoxData[
      \(z\)]],
  " plane.  Recall that  ",
  Cell[BoxData[
      RowBox[{\(Re \((z)\)\), "=", 
        RowBox[{
          RowBox[{"x", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "Im", \((z)\)}], "=", 
          "y"}]}]]],
  ".  Geometrically,  ",
  Cell[BoxData[
      \(Re \((z)\)\)]],
  "  is the projection of  ",
  Cell[BoxData[
      \(z = \((x, y)\)\)]],
  "  onto the ",
  Cell[BoxData[
      \(x\)]],
  " axis, and  ",
  Cell[BoxData[
      \(Im \((z)\)\)]],
  "  is the projection of ",
  Cell[BoxData[
      \(z\)]],
  " onto the ",
  Cell[BoxData[
      \(y\)]],
  " axis. It makes sense, then, to call the ",
  Cell[BoxData[
      \(x\)]],
  " axis the real axis and the ",
  Cell[BoxData[
      \(y\)]],
  " axis the imaginary axis, as Figure 1.3 illustrates."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006F0000Z2000`400?l0
0000o`00003oo`3ooonG0?ooo`00o`3ooonG0?ooo`00N03oool40000oeD0
oooo0`00000D0?ooo`<00000Z`3oool007L0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0ZP3oool007L0oooo1P000?mE0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0ZP3oool006`0oooo10000?l3
0?ooo`T0003o0`3oool90000o`80oooo0`000?l60?ooo`@0003o00<0oooo
0000o`000?l00P3oool30000o`X0oooo0`0000030?ooo`<0000000@0oooo
000000000000oooo0P0000060?ooo`8000000`3oool300000080oooo0`00
0000103oool000000000003oool2000000030?ooo`000000oooo00800000
0P3oool3000000030?ooo`00000000000080oooo0P0000000`3oool00000
000000040?ooo`040000003oool0000000000080oooo0`0000000`3oool0
000000000005000000040?ooo`00000000000?ooo`8000000`3oool00`00
0000oooo0?ooo`2@0?ooo`00K@3oool20000o`D0oooo0P000?l00`3oool0
003o0?ooo`050?ooo`80003o00<0oooo0000o`000?l00P3oool20000o`80
oooo0P000?l20?ooo`030000o`3oool0oooo00@0oooo0P000?l20?ooo`80
003o00D0oooo0000o`3oool0oooo0000o`0;0?ooo`030000003oool0oooo
00<0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool2
00000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`060000
003oool0oooo0000003oool000001@3oool200000080oooo00H000000?oo
o`3oool000000?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`2C0?ooo`00K@3o
ool20000o`D0oooo0P000?l20?ooo`<0003o0`3oool20000o`030?ooo`00
0?l0003o0080oooo0P000?l20?ooo`80003o2@3oool20000o`P0oooo0P00
0?l:0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool00000
0?ooo`0000070?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000`3oool01P000000oooo0?ooo`000000oooo000000H0
oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000009P0oooo001]0?ooo`80003o00<0oooo0000
o`3oool00P3oool20000o`040?ooo`000?l0003o0?ooo`80003o0P3oool2
0000o`030?ooo`000?l0003o0080oooo0P000?l20?ooo`D0003o1P3oool2
0000o`P0oooo0P000?l:0?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool000000?ooo`04000000@0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo
0000003oool0100000030?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<000000P3o
ool01@000000oooo0?ooo`000000oooo00@00000U@3oool006d0oooo1000
0?l30?ooo`80003o00@0oooo0000o`000?l0oooo0P000?l20?ooo`80003o
00<0oooo0000o`000?l00P3oool20000o`050?ooo`000?l0003o0000o`3o
ool00P000?l60?ooo`80003o1`3oool30000o`X0oooo00<000000?ooo`3o
ool00`3oool2000000040?ooo`000000oooo00000080oooo00<000000?oo
o`3oool00P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`3oool00P0000001@3oool000000000003oool000000080oooo
0P0000020?ooo`060000003oool0oooo0000003oool000000P3oool01P00
0000oooo0?ooo`000000oooo000000D0oooo0P0000020?ooo`060000003o
ool0oooo0000003oool000000P3oool00`000000oooo0?ooo`0200000004
0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0T`3oool006d0
oooo0P000?l0103oool0003o0?ooo`3oool30000o`80oooo20000?l0103o
ool0003o0000o`3oool50000o`040?ooo`000?l0003o0000o`L0oooo0P00
0?l70?ooo`80003o2`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000<0oooo0P0000060?ooo`<000000P3oool300000080oooo0P00
00001@3oool000000?ooo`3oool000000080oooo0P0000000`3oool00000
000000030?ooo`030000003oool0oooo008000000P3oool2000000030?oo
o`000000000000<0oooo0P0000000`3oool00000000000030?ooo`030000
003oool0oooo008000000P3oool2000000030?ooo`000000oooo0080oooo
0P00002F0?ooo`00K@3oool20000obD0oooo0P000?l80?ooo`80003o2P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`2S0?ooo`00K@3oool2
0000o`<0oooo00@0003o0?ooo`000?l0003o7P3oool20000o`D0oooo00<0
003o0?ooo`3oool00P000?l70?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0:<0oooo001/0?ooo`L0003o00<0oooo0000o`000?l0
7@3oool30000o`H0oooo0`000?l80?ooo`L0000000<0oooo000000000000
9`3oool2000001D0oooo0P00002U0?ooo`00o`3ooonG0?ooo`00o`3ooonG
0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3o
oonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00
o`3ooonG0?ooo`00o`3ooonG0?ooo`00O@3oool3000001L0oooo0P00000G
0?ooo`@000005`3oool5000002`0oooo1@00000F0?ooo`@000005`3oool2
000001X0oooo0`0000150?ooo`00OP3oool00`000000oooo0?ooo`0E0?oo
o`040000003oool0oooo000001H0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05`3oool010000000oooo0?ooo`00000J0?ooo`030000003o
ool0oooo04@0oooo001k0?ooo`D00000603oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool05P3oool5000004D0oooo001e0?ooo`@000000P3oool01000
0000oooo0?ooo`00000A0?ooo`@000001@3oool00`000000oooo0?ooo`0>
0?ooo`@00000103oool00`000000oooo0?ooo`0@0?ooo`@00000103oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0E0?ooo`040000003oool0
oooo000004H0oooo001l0?ooo`030000003oool0000001L0oooo00@00000
0?ooo`3oool000005P3oool010000000oooo0?ooo`00000I0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool05P3oool010000000oooo
0?ooo`00000F0?ooo`040000003oool0oooo000001P0oooo00<000000?oo
o`000000AP3oool007d0oooo0P00000H0?ooo`800000603oool2000001T0
oooo0P00000F0?ooo`030000003oool0oooo01H0oooo0P00000I0?ooo`80
0000603oool2000001X0oooo0P0000160?ooo`00i03oool00`000000oooo
0?ooo`2_0?ooo`00i03oool00`000000oooo0?ooo`2_0?ooo`00R03oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0:l0oooo00280?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0[`3oool008P0
oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1l0?ooo`80
000000<0oooo000000000000203oool7000000030?ooo`000000000000<0
oooo0`0000020?ooo`<000004@3oool006d0oooo6P0000000`3o00000000
0?l0001I0?l00003003o0000ool00?oo07H00000203oool00`000000oooo
000000030?ooo`@000000P3oool400000080oooo00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo
001j0?ooo`030000003oool0oooo00X0oooo00<0o`000000003o0000F@3o
00000`000?l00?l00?ooo`02003ooaH0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`050000003o
ool0oooo0?ooo`0000001P3oool010000000oooo0?ooo`3oool300000140
oooo001j0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool05@3oool00`000?l00?l0003o00030?ooo`<00?oo
4`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`800000
00<0oooo0000000000002@3oool3000000040?ooo`00000000000?ooo`80
00000`3oool2000000<0oooo1000000@0?ooo`00R03oool00`000000oooo
0?ooo`1F0?ooo`040000o`3oool00?l0003o00H0oooo0P00oonY0?ooo`00
R03oool00`000000oooo0?ooo`1D0?ooo`80003o0P3oool2003o00P0oooo
0`00oon>0?ooo`030000003oool0oooo01D0oooo00280?ooo`030000003o
ool0oooo05<0oooo00<0003o0?ooo`3oool00P3oool2003o00/0oooo0P00
oonT0?ooo`00g@3oool00`000?l0oooo0?ooo`030?ooo`800?l03@3oool3
003ooj40oooo003L0?ooo`030000o`3oool0oooo00@0oooo0P00o`0@0?oo
o`800?ooW`3oool00=/0oooo00<0003o0?ooo`3oool01@3oool2003o0180
oooo0`00oonL0?ooo`00fP3oool00`000?l0oooo0?ooo`060?ooo`800?l0
5@3oool2003ooiX0oooo003I0?ooo`030000o`3oool0oooo00L0oooo0P00
o`0G0?ooo`<00?ooU`3oool00=L0oooo0P000?l:0?ooo`800?l06P3oool2
003ooiD0oooo003F0?ooo`030000o`3oool0oooo00X0oooo0P00o`0L0?oo
o`<00?ooTP3oool00=D0oooo00<0003o0?ooo`3oool02`3oool2003o01l0
oooo0P00oon@0?ooo`00e03oool00`000?l0oooo0?ooo`0<0?ooo`800?l0
8@3oool3003oohd0oooo00240?ooo`8000000P3oool2000004T0oooo00<0
003o0?ooo`3oool03@3oool2003o02@0oooo0P00oon;0?ooo`00Q@3oool0
10000000oooo0?ooo`0000190?ooo`030000o`3oool0oooo00h0oooo0P00
o`0V0?ooo`800?ooR@3oool008H0oooo0P0000190?ooo`030000o`3oool0
oooo00l0oooo0P00o`0X0?ooo`<00?ooQP3oool008H0oooo0P0000170?oo
o`80003o4P3oool2003o02/0oooo0P00oon40?ooo`00Q@3oool010000000
oooo0?ooo`0000150?ooo`030000o`3oool0oooo0180oooo0P00o`0]0?oo
o`<00?ooP@3oool008@0oooo0P0000020?ooo`800000@`3oool00`000?l0
oooo0?ooo`0C0?ooo`800?l0<03oool2003oogl0oooo003<0?ooo`030000
o`3oool0oooo01@0oooo0P00o`0b0?ooo`<00?ooO03oool00</0oooo00<0
003o0?ooo`3oool05@3oool2003o03D0oooo0P00oomj0?ooo`00bP3oool0
0`000?l0oooo0?ooo`0F0?ooo`800?l0=`3oool3003oogL0oooo00390?oo
o`030000o`3oool0oooo01L0oooo0P00o`0j0?ooo`800?oo1P3oool00`00
ool0oooo0?ooo`1/0?ooo`00b03oool00`000?l0oooo0?ooo`0H0?ooo`80
0?l0?03oool3003oo`80oooo1000oom/0?ooo`00aP3oool20000oa/0oooo
0P00o`0o0?ooo`L00?ooJ`3oool00<D0oooo00<0003o0?ooo`3oool06`3o
ool2003o0400oooo1`00oomZ0?ooo`00a03oool00`000?l0oooo0?ooo`0L
0?ooo`800?l0@03oool9003oofP0oooo00330?ooo`030000o`3oool0oooo
01d0oooo0P00o`0o0?ooo`/00?ooI`3oool00<80oooo00<0003o0?ooo`3o
ool07P3oool2003o04<0oooo2@00oomU0?ooo`00`@3oool00`000?l0oooo
0?ooo`0H0?ooo`D000000P3oool2003o04T0oooo1000ool30000o`T0oooo
0`0000060?ooo`030000003oool0oooo0080oooo1`0000130?ooo`00`03o
ool00`000?l0oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo0P00
o`1<0?ooo`D0003o1`3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool0103oool00`000000oooo000000150?ooo`00_P3o
ool20000oah0oooo00<000000?ooo`3oool00P3oool2003o00800000BP3o
ool50000o`/0oooo00@000000?ooo`3oool0oooo1@0000040?ooo`030000
003oool0000004D0oooo002m0?ooo`030000o`3oool0oooo01h0oooo00<0
00000?ooo`3oool00P3oool2003o04`0oooo1@000?l;0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0000
00150?ooo`00_03oool00`000?l0oooo0?ooo`0O0?ooo`030000003oool0
oooo0080oooo0P00o`1=0?ooo`<0003o2P3oool2000000H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo000000150?ooo`00^`3oool00`00
0?l0oooo0?ooo`0O0?ooo`800000103oool2003o05`0oooo00<000000?oo
o`3oool0203oool5000004D0oooo002j0?ooo`030000o`3oool0oooo02H0
oooo0P00o`1H0?ooo`050000003oool0oooo0?ooo`000000E03oool00;T0
oooo00<0003o0?ooo`3oool09`3oool2003o05T0oooo0`00000>0?ooo`03
0000003oool0oooo04@0oooo002h0?ooo`030000o`3oool0oooo02P0oooo
0P00o`2a0?ooo`00]`3oool00`000?l0oooo0?ooo`0Y0?ooo`800?l0/@3o
ool00;D0oooo0P000?l/0?ooo`800?l0/@3oool00;@0oooo00<0003o0?oo
o`3oool0;03oool2003o0;40oooo002c0?ooo`030000o`3oool0oooo02d0
oooo0P00o`2a0?ooo`00/P3oool00`000?l0oooo0?ooo`0^0?ooo`800?l0
/@3oool00;40oooo00<0003o0?ooo`3oool0;`3oool2003o0;40oooo002`
0?ooo`030000o`3oool0oooo0300oooo0P00o`2a0?ooo`00[`3oool00`00
0?l0oooo0?ooo`0a0?ooo`800?l0/@3oool00:d0oooo0P000?ld0?ooo`80
0?l0/@3oool00:`0oooo00<0003o0?ooo`3oool0=03oool2003o0;40oooo
002[0?ooo`030000o`3oool0oooo03D0oooo0P00o`2a0?ooo`00ZP3oool0
0`000?l0oooo0?ooo`0f0?ooo`800?l0/@3oool00:T0oooo00<0003o0?oo
o`3oool0=`3oool2003o0;40oooo002X0?ooo`030000o`3oool0oooo03P0
oooo0P00o`2a0?ooo`00Y`3oool00`000?l0oooo0?ooo`0i0?ooo`800?l0
/@3oool00:D0oooo0P000?ll0?ooo`800?l0/@3oool00:@0oooo00<0003o
0?ooo`3oool0?03oool2003o0;40oooo002S0?ooo`030000o`3oool0oooo
03d0oooo0P00o`2a0?ooo`00XP3oool00`000?l0oooo0?ooo`0n0?ooo`80
0?l0/@3oool00:40oooo00<0003o0?ooo`3oool0?`3oool2003o0;40oooo
002P0?ooo`030000o`3oool0oooo0400oooo0P00o`2a0?ooo`00W`3oool0
0`000?l0oooo0?ooo`110?ooo`800?l0/@3oool009h0oooo00<0003o0?oo
o`3oool0@P3oool2003o0;40oooo002L0?ooo`80003o?P3oool4000000<0
oooo0P00o`2a0?ooo`00V`3oool00`000?l0oooo0?ooo`0n0?ooo`030000
003oool0oooo00@0oooo0P00o`2a0?ooo`00VP3oool00`000?l0oooo0?oo
o`100?ooo`030000003oool0oooo00<0oooo0P00o`0200000:l0oooo002I
0?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool00P3oool2
003o0;40oooo002H0?ooo`030000o`3oool0oooo0440oooo00@000000?oo
o`3oool000000`3oool2003o0;40oooo002G0?ooo`030000o`3oool0oooo
04<0oooo0P0000040?ooo`800?l0/@3oool009H0oooo00<0003o0?ooo`3o
ool0BP3oool2003o0;40oooo002D0?ooo`80003oC@3oool2003o0;40oooo
002?0?ooo`050000o`3oool0oooo0?ooo`000?l0C`3oool2003o0;40oooo
002>0?ooo`<0003o00<0oooo0000o`3oool0C`3oool2003o0;40oooo002>
0?ooo`@0003oD@3oool2003o0;40oooo002=0?ooo`D0003oD@3oool2003o
0;40oooo002<0?ooo`L0003oD03oool2003o0;40oooo002;0?ooo`L0003o
D@3oool2003o0;40oooo002;0?ooo`D0003oD`3oool2003o00X0oooo1000
002S0?ooo`00RP3oool40000oeD0oooo0P00o`0<0?ooo`030000003oool0
oooo0:80oooo00290?ooo`@0003oEP3oool2003o00`0oooo00<000000?oo
o`3oool0XP3oool008T0oooo0P000?mH0?ooo`800?l0303oool200000:<0
oooo00280?ooo`030000o`3oool0oooo05H0oooo200000070?ooo`030000
003oool000000:<0oooo003S0?ooo`800?l02`3oool010000000oooo0?oo
o`00002R0?ooo`00i03oool00`000000oooo0?ooo`080?ooo`050000003o
ool0oooo0?ooo`000000XP3oool00>@0oooo00<000000?ooo`3oool01`3o
ool3000000040?ooo`000000000000000:40oooo003T0?ooo`030000003o
ool0oooo0:l0oooo003T0?ooo`030000003oool0oooo0:l0oooo003T0?oo
o`030000003oool0oooo0:l0oooo003T0?ooo`030000003oool0oooo0:l0
oooo003T0?ooo`030000003oool0oooo0:l0oooo003T0?ooo`030000003o
ool0oooo0:l0oooo003T0?ooo`030000003oool0oooo0:l0oooo003T0?oo
o`030000003oool0oooo0:l0oooo002[0?ooo`@00000=@3oool00`000000
oooo0?ooo`2_0?ooo`00[@3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0:l0oooo001i0?ooo`D000005`3oool200000080oooo0P00
00040?ooo`030000003oool0oooo0080oooo1`0000020?ooo`030000003o
ool0oooo02d0oooo0P0000050?ooo`030000003oool0oooo0:l0oooo001i
0?ooo`050000003oool0oooo0?ooo`0000002@3oool5000000X0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0000000@0oooo0P00000]0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0[`3oool007X0oooo00<000000?ooo`3oool0
6P3oool2000000@0oooo1@0000040?ooo`030000003oool0000000<0oooo
00<000000?ooo`000000;`3oool00`000000oooo0?ooo`030?ooo`<00000
[`3oool007/0oooo00<000000?ooo`3oool02@3oool5000000/0oooo0P00
00060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3o
ool010000000oooo0?ooo`00000_0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0[`3oool007T0oooo00@000000?ooo`3oool00000
6@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
02`0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2_
0?ooo`00N@3oool5000001L0oooo0P0000020?ooo`8000002@3oool50000
00050?ooo`00000000000000003oool00`00000/0?ooo`8000001@3oool0
0`000000oooo0?ooo`2_0?ooo`00i03oool00`000000oooo0?ooo`2_0?oo
o`00Y`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0:l0
oooo003T0?ooo`030000003oool0oooo0:l0oooo003T0?ooo`030000003o
ool0oooo0:l0oooo003T0?ooo`030000003oool0oooo0:l0oooo003T0?oo
o`030000003oool0oooo0:l0oooo003T0?ooo`030000003oool0oooo0:l0
oooo003T0?ooo`030000003oool0oooo0:l0oooo003T0?ooo`030000003o
ool0oooo0:l0oooo003T0?ooo`030000003oool0oooo0:l0oooo003T0?oo
o`030000003oool0oooo0:l0oooo003T0?ooo`030000003oool0oooo0:l0
oooo003T0?ooo`030000003oool0oooo0:l0oooo003o0?oooiL0oooo003o
0?oooiL0oooo003o0?oooiL0oooo003o0?oooiL0oooo003o0?oooiL0oooo
003o0?oooiL0oooo003o0?oooiL0oooo003o0?oooiL0oooo003C0?ooo`80
0000`@3oool00=@0oooo00<000000?ooo`3oool0_`3oool00=D0oooo00<0
00000?ooo`3oool01`3oool7000000030?ooo`000000000000<0oooo0`00
00020?ooo`<00000XP3oool00=@0oooo00<000000?ooo`0000000P3oool4
00000080oooo100000020?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`2O0?ooo`00d`3oool01000
0000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool010000000oooo0?ooo`3oool300000:80oooo003B0?ooo`<0000000<0
oooo000000000000203oool3000000040?ooo`00000000000?ooo`800000
0`3oool2000000<0oooo1000002Q0?ooo`00o`3ooonG0?ooo`00k@3oool0
0`000000oooo0?ooo`2V0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00
\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{406, 168},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\tAddition of complex numbers is analogous to addition of vectors in the \
plane.  As we saw in Section 1.2, the sum of ",
  Cell[BoxData[
      \(z\_1 = \(x\_1 + \[ImaginaryI]\ y\_1 = \((x\_1, y\_1)\)\)\)]],
  " and ",
  Cell[BoxData[
      \(z\_2 = \(x\_2 + \[ImaginaryI]\ y\_2 = \((x\_2, y\_2)\)\)\)]],
  "is ",
  Cell[BoxData[
      \(\((x\_1 + x\_2, y\_1 + y\_2)\)\)]],
  ".  Hence, ",
  Cell[BoxData[
      \(z\_1\  + z\_2\)]],
  " can be obtained vectorially by using the \"parallelogram law,\" where the \
vector sum is the vector represented by the diagonal of the parallelogram \
formed by the two original vectors. Figure 1.4 illustrates this notion."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000aB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
N03oool40000ool0oooo603oool007L0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`1L0?ooo`D000005@3oool3000009/0oooo001g
0?ooo`H0003oH03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo09/0oooo001/0?ooo`@0003o0`3oool90000o`<0oooo2@000?l20?oo
o`<0003o1P3oool40000o`030?ooo`000?l0003o00@0oooo0P000?l90?oo
o`<000000`3oool3000000040?ooo`00000000000?ooo`8000001@3oool3
000000@0oooo1`000000103oool000000000003oool2000000@0oooo1@00
00030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool5000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`2D0?ooo`00K@3oool20000o`D0oooo0P000?l00`3oool0003o0?ooo`05
0?ooo`80003o00<0oooo0000o`000?l00P3oool20000o`80oooo0P000?l2
0?ooo`030000o`3oool0oooo00@0oooo0P000?l20?ooo`80003o103oool2
0000o`X0oooo00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`00
0000oooo00000080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo09X0oooo001]0?ooo`80003o1@3oool20000o`80oooo0`00
0?l30?ooo`80003o00<0oooo0000o`000?l00P3oool20000o`80oooo0P00
0?l90?ooo`80003o1@3oool60000o`T0oooo00<000000?ooo`3oool00`3o
ool01P000000oooo0?ooo`000000oooo000000T0oooo0P0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool5000000H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0000002K0?ooo`00K@3oool20000o`030?ooo`000?l0oooo
0080oooo0P000?l0103oool0003o0000o`3oool20000o`80oooo0P000?l0
0`3oool0003o0000o`020?ooo`80003o0P3oool50000o`H0oooo0P000?l5
0?ooo`030000o`3oool0oooo0080003o2P3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0000003oool0100000040?ooo`800000103o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`80
0000203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0VP3oool006d0oooo10000?l30?ooo`80003o
00@0oooo0000o`000?l0oooo0P000?l20?ooo`80003o00<0oooo0000o`00
0?l00P3oool20000o`050?ooo`000?l0003o0000o`3oool00P000?l60?oo
o`80003o1P3oool010000?l0oooo0000o`000?l:0?ooo`030000003oool0
oooo00<0oooo0P000000103oool000000?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`80000000D0oooo000000000000oooo000000050?oo
o`040000003oool0oooo000000d0oooo00<000000?ooo`3oool01@3oool0
10000000oooo0?ooo`00002Q0?ooo`00K@3oool20000o`040?ooo`000?l0
oooo0?ooo`<0003o0P3oool80000o`040?ooo`000?l0003o0?ooo`D0003o
00@0oooo0000o`000?l0003o1`3oool20000o`H0oooo00@0003o0?ooo`00
0?l0003o2P3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
00<0oooo0P0000060?ooo`<0000000@0oooo000000000000oooo0P000000
1@3oool000000000003oool000000080oooo00<000000?ooo`3oool0103o
ool5000001@0oooo1@00002P0?ooo`00K@3oool20000obD0oooo0P000?l7
0?ooo`<0003o2P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0>00oooo001]0?ooo`80003o0`3oool010000?l0oooo0000o`000?lN
0?ooo`80003o203oool20000o`L0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00003R0?ooo`00K03oool70000o`030?ooo`00
0?l0003o01d0oooo0`000?l80?ooo`80003o1`3oool7000000030?ooo`00
000000000>80oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0
oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oo
oi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o
0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo
003o0?ooogT0oooo0P0000000`3oool000000000000F0?ooo`00o`3ooomj
0?ooo`030000003oool0000001L0oooo001k0?ooo`030000o`3o0000o`00
00<0o`00l00000090?ooo`030000003oool0oooo01H0oooo001k0?ooo`03
003o00000?l0003o00<0oooo2`3o003/0?ooo`80000000<0oooo00000000
00005P3oool007/0oooo00@00?l00?ooo`3oool0003o3@3oool:0?l00?d0
oooo001k0?ooo`0400000000o`00oooo0?ooo`80003o5@3oool;0?l00?80
oooo001k0?ooo`0300000000o`00oooo00<0oooo00<0003o0?ooo`3oool0
7@3oool;0?l00>L0oooo001k0?ooo`0300000000o`00oooo00@0oooo0P00
0?lX0?ooo`X0o`00g@3oool007/0oooo00<00000003o003oool01P3oool0
0`000?l0oooo0?ooo`0_0?ooo`/0o`00dP3oool007/0oooo00<000000?oo
o`00o`001`3oool20000ocX0oooo2`3o00370?ooo`00N`3oool00`000000
oooo003o00090?ooo`030000o`3oool0oooo0480oooo2P3o002m0?ooo`00
N`3oool00`000000oooo003o000:0?ooo`80003oC03oool;0?l00;80oooo
001k0?ooo`030000003oool00?l000`0oooo00<0003o0?ooo`3oool0E03o
ool;0?l004L0oooo1@00001K0?ooo`00N`3oool00`000000oooo003o000=
0?ooo`80003oG`3oool:0?l003l0oooo00<000000?ooo`3oool0F`3oool0
07/0oooo00@000000?ooo`3oool00?l03P3oool00`000?l0oooo0?ooo`1V
0?ooo`/0o`006@3oool20?l00140oooo1@0000030?ooo`030000003oool0
oooo05/0oooo001k0?ooo`040000003oool0oooo003o00l0oooo0P000?ma
0?ooo`/0o`003P3oool50?l000l0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`1K0?ooo`00N`3oool010000000oooo0?ooo`00
o`0A0?ooo`030000o`3oool0oooo07T0oooo2P3o00040?ooo`P0o`003@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05/0oooo001k
0?ooo`040000003oool0oooo003o0180oooo0P000?n30?ooo`l0o`002`3o
ool010000000oooo0?ooo`3oool2000005d0oooo001k0?ooo`050000003o
ool0oooo0?ooo`00o`004`3oool00`000?l0oooo0?ooo`240?ooo``0o`00
00<00?l00?ooo`3oool01@3oool010000000oooo0?ooo`00001Q0?ooo`00
N`3oool01@000000oooo0?ooo`3oool00?l001@0oooo0P000?n40?ooo`X0
o`000P3oool00`00o`00oooo0?ooo`050?ooo`D00000H03oool007/0oooo
00D000000?ooo`3oool0oooo003o000F0?ooo`030000o`3oool0oooo0840
oooo103o00080?ooo`03003o003oool0oooo06X0oooo001k0?ooo`050000
003oool0oooo0?ooo`00o`005`3oool20000ohh0oooo00<00?l00?ooo`3o
ool0J@3oool007/0oooo00D000000?ooo`3oool0oooo003o000I0?ooo`03
0000o`3oool0oooo08/0oooo00<00?l00?ooo`3oool0J@3oool007/0oooo
00<000000?ooo`3oool00P3oool00`00o`00oooo0?ooo`0G0?ooo`80003o
R`3oool00`00o`00oooo0?ooo`1Y0?ooo`00N`3oool00`000000oooo0?oo
o`020?ooo`03003o003oool0oooo01T0oooo00<0003o0?ooo`3oool0R03o
ool00`00o`00oooo0?ooo`1Y0?ooo`00N`3oool00`000000oooo0?ooo`02
0?ooo`03003o003oool0oooo01X0oooo0P000?n90?ooo`03003o003oool0
oooo06P0oooo001k0?ooo`030000003oool0oooo0080oooo00<00?l00?oo
o`3oool0703oool00`000?l0oooo0?ooo`260?ooo`03003o003oool0oooo
06P0oooo001k0?ooo`030000003oool0oooo0080oooo00<00?l00?ooo`3o
ool07@3oool20000ohH0oooo00<00?l00?ooo`3oool0J03oool007/0oooo
00<000000?ooo`3oool00`3oool00`00o`00oooo0?ooo`0N0?ooo`030000
o`3oool0oooo08<0oooo00<00?l00?ooo`3oool0J03oool007/0oooo00<0
00000?ooo`3oool00`3oool00`00o`00oooo0?ooo`0O0?ooo`80003oQ03o
ool00`00o`00oooo0?ooo`1W0?ooo`00N`3oool00`000000oooo0?ooo`03
0?ooo`03003o003oool0oooo0240oooo00<0003o0?ooo`3oool0P@3oool0
0`00o`00oooo0?ooo`1W0?ooo`00N`3oool00`000000oooo0?ooo`030?oo
o`03003o003oool0oooo0280oooo0P000?o[0?ooo`00N`3oool00`000000
oooo0?ooo`040?ooo`03003o003oool0oooo02<0oooo00<0003o0?ooo`3o
ool0j03oool007/0oooo00<000000?ooo`3oool0103oool00`00o`00oooo
0?ooo`0T0?ooo`80003oj03oool007/0oooo00<000000?ooo`3oool0103o
ool00`00o`00oooo0?ooo`0V0?ooo`030000o`3oool0oooo0>D0oooo001k
0?ooo`030000003oool0oooo00@0oooo00<00?l00?ooo`3oool09`3oool2
0000onD0oooo001k0?ooo`030000003oool0oooo00@0oooo00<00?l00?oo
o`3oool0:@3oool00`000?l0oooo0?ooo`3R0?ooo`00N`3oool00`000000
oooo0?ooo`050?ooo`03003o003oool0oooo02T0oooo0P000?oR0?ooo`00
N`3oool00`000000oooo0?ooo`050?ooo`03003o003oool0oooo02/0oooo
00<0003o0?ooo`3oool0g`3oool007/0oooo00<000000?ooo`3oool01@3o
ool00`00o`00oooo0?ooo`0/0?ooo`80003og`3oool007/0oooo00<00000
0?ooo`3oool01@3oool00`00o`00oooo0?ooo`0^0?ooo`030000o`3oool0
oooo0=`0oooo001k0?ooo`030000003oool0oooo00H0oooo00<00?l00?oo
o`3oool0;P3oool20000om`0oooo001k0?ooo`030000003oool0oooo00H0
oooo00<00?l00?ooo`3oool0<03oool00`000?l0oooo0?ooo`1a0?ooo`03
003o003oool0oooo06D0oooo001k0?ooo`030000003oool0oooo00H0oooo
00<00?l00?ooo`3oool0<@3oool20000og40oooo00<00?l00?ooo`3oool0
I@3oool007/0oooo00<000000?ooo`3oool01P3oool00`00o`00oooo0?oo
o`0c0?ooo`030000o`3oool0oooo06h0oooo00<00?l00?ooo`3oool0I@3o
ool007/0oooo00<000000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0d
0?ooo`80003oK`3oool00`00o`00oooo0?ooo`1T0?ooo`00N`3oool00`00
0000oooo0?ooo`070?ooo`03003o003oool0oooo03D0oooo00<0003o0?oo
o`3oool0K03oool00`00o`00oooo0?ooo`1T0?ooo`00N`3oool00`000000
oooo0?ooo`070?ooo`03003o003oool0oooo03H0oooo0P000?m/0?ooo`03
003o003oool0oooo06@0oooo001k0?ooo`030000003oool0oooo00L0oooo
00<00?l00?ooo`3oool0>03oool00`000?l0oooo0?ooo`1Y0?ooo`03003o
003oool0oooo06@0oooo001k0?ooo`030000003oool0oooo00L0oooo00<0
0?l00?ooo`3oool0>@3oool20000ofX0oooo00<00?l00?ooo`3oool0H`3o
ool007/0oooo00<000000?ooo`3oool0203oool00`00o`00oooo0?ooo`0j
0?ooo`030000o`3oool0oooo06L0oooo00<00?l00?ooo`3oool0H`3oool0
07/0oooo00<000000?ooo`3oool0203oool00`00o`00oooo0?ooo`0k0?oo
o`80003oI`3oool00`00o`00oooo0?ooo`1S0?ooo`00N`3oool00`000000
oooo0?ooo`080?ooo`03003o003oool0oooo03d0oooo00<0003o0?ooo`3o
ool0I03oool00`00o`00oooo0?ooo`1S0?ooo`00N`3oool00`000000oooo
0?ooo`080?ooo`03003o003oool0oooo03h0oooo0P000?mU0?ooo`03003o
003oool0oooo0680oooo001k0?ooo`030000003oool0oooo00P0oooo00<0
0?l00?ooo`3oool0@03oool00`000?l0oooo0?ooo`1R0?ooo`03003o003o
ool0oooo0680oooo001k0?ooo`030000003oool0oooo00T0oooo00<00?l0
0?ooo`3oool0@03oool20000olL0oooo001k0?ooo`030000003oool0oooo
00T0oooo00<00?l00?ooo`3oool0@P3oool00`000?l0oooo0?ooo`340?oo
o`00N`3oool00`000000oooo0?ooo`090?ooo`03003o003oool0oooo04<0
oooo0P000?o40?ooo`00N`3oool00`000000oooo0?ooo`090?ooo`03003o
003oool0oooo04D0oooo00<0003o0?ooo`3oool0`@3oool007/0oooo00<0
00000?ooo`3oool02@3oool00`00o`00oooo0?ooo`160?ooo`80003o`@3o
ool007/0oooo00<000000?ooo`3oool02P3oool00`00o`00oooo0?ooo`17
0?ooo`030000o`3oool0oooo0;h0oooo001k0?ooo`030000003oool0oooo
00X0oooo00<00?l00?ooo`3oool0B03oool20000okh0oooo001k0?ooo`03
0000003oool0oooo00X0oooo00<00?l00?ooo`3oool0BP3oool00`000?l0
oooo0?ooo`2k0?ooo`00N`3oool00`000000oooo0?ooo`0:0?ooo`03003o
003oool0oooo04/0oooo0P000?nk0?ooo`00N`3oool00`000000oooo0?oo
o`0;0?ooo`03003o003oool0oooo04`0oooo00<0003o0?ooo`3oool0K03o
ool3000000D0oooo1000000C0?ooo`<00000:P3oool007/0oooo00<00000
0?ooo`3oool02`3oool00`00o`00oooo0?ooo`1=0?ooo`80003oK@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0:P3oool007/0oooo00<000000?ooo`3oool02`3oool00`00
o`00oooo0?ooo`1?0?ooo`030000o`3oool0oooo05<0oooo00<00?l00?oo
o`3oool01`3oool3000000@0oooo0`0000030?ooo`@000001@3oool00`00
0000oooo0?ooo`0:0?ooo`D00000103oool00`000000oooo0?ooo`0Y0?oo
o`00N`3oool00`000000oooo0?ooo`0;0?ooo`03003o003oool0oooo0500
oooo00<0003o0?ooo`3oool0DP3oool00`00o`00oooo0?ooo`060?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo000000040?ooo`800000303o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02T0oooo
001k0?ooo`030000003oool0oooo00/0oooo00<00?l00?ooo`3oool0D@3o
ool20000oe80oooo00<00?l00?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`0000003@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0000002X0oooo001k0?ooo`030000
003oool0oooo00`0oooo00<00?l00?ooo`3oool0DP3oool00`000?l0oooo
0?ooo`1?0?ooo`03003o003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`040000003oool0oooo000000d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0Y0?ooo`00N`3oool00`00
0000oooo0?ooo`0<0?ooo`03003o003oool0oooo05<0oooo0P000?m@0?oo
o`03003o003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01@00
0000oooo0?ooo`3oool000000080oooo0P0000020?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool02@3oool010000000oooo0?oo
o`00000`0?ooo`00N`3oool00`000000oooo0?ooo`0<0?ooo`03003o003o
ool0oooo05D0oooo00<0003o0?ooo`3oool0C@3oool00`00o`00oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo0`0000020?ooo`80000000<0
oooo0000000000000P3oool3000000040?ooo`0000000000000000X0oooo
1@00000_0?ooo`00N`3oool00`000000oooo0?ooo`0<0?ooo`03003o003o
ool0oooo05H0oooo0P000?m=0?ooo`03003o003oool0oooo00D0oooo00D0
00000?ooo`3oool0oooo0000001D0?ooo`00N`3oool00`000000oooo0?oo
o`0=0?ooo`03003o003oool0oooo05L0oooo00<0003o0?ooo`3oool0BP3o
ool00`00o`00oooo0?ooo`060?ooo`@00000E03oool007/0oooo00<00000
0?ooo`3oool03@3oool00`00o`00oooo0?ooo`1H0?ooo`80003oBP3oool0
0`00o`00oooo0?ooo`1N0?ooo`00N`3oool00`000000oooo0?ooo`0=0?oo
o`03003o003oool0oooo05X0oooo00<0003o0?ooo`3oool0A`3oool00`00
o`00oooo0?ooo`1N0?ooo`00N`3oool00`000000oooo0?ooo`0=0?ooo`03
003o003oool0oooo05/0oooo0P000?m80?ooo`03003o003oool0oooo05d0
oooo001k0?ooo`030000003oool0oooo00d0oooo00<00?l00?ooo`3oool0
G@3oool00`000?l0oooo0?ooo`150?ooo`03003o003oool0oooo05d0oooo
001k0?ooo`030000003oool0oooo00h0oooo00<00?l00?ooo`3oool0G@3o
ool20000odD0oooo00<00?l00?ooo`3oool0G@3oool007/0oooo00<00000
0?ooo`3oool03P3oool00`00o`00oooo0?ooo`1O0?ooo`030000o`3oool0
oooo0:80oooo001k0?ooo`030000003oool0oooo00h0oooo00<00?l00?oo
o`3oool0H03oool20000oj80oooo001k0?ooo`030000003oool0oooo00h0
oooo00<00?l00?ooo`3oool0HP3oool00`000?l0oooo0?ooo`2O0?ooo`00
N`3oool00`000000oooo0?ooo`0?0?ooo`03003o003oool0oooo0680oooo
0P000?nO0?ooo`00N`3oool00`000000oooo0?ooo`0?0?ooo`03003o003o
ool0oooo06@0oooo00<0003o0?ooo`3oool0W03oool007/0oooo00<00000
0?ooo`3oool03`3oool00`00o`00oooo0?ooo`1U0?ooo`80003oW03oool0
07/0oooo00<000000?ooo`3oool03`3oool00`00o`00oooo0?ooo`1W0?oo
o`030000o`3oool0oooo09T0oooo001k0?ooo`030000003oool0oooo00l0
oooo00<00?l00?ooo`3oool0J03oool20000oiT0oooo001k0?ooo`030000
003oool0oooo0100oooo00<00?l00?ooo`3oool0J@3oool00`000?l0oooo
0?ooo`2F0?ooo`00N`3oool00`000000oooo0?ooo`0@0?ooo`03003o003o
ool0oooo06X0oooo0P000?nF0?ooo`00N`3oool00`000000oooo0?ooo`0@
0?ooo`03003o003oool0oooo06`0oooo00<0003o0?ooo`3oool0T`3oool0
07/0oooo00<000000?ooo`3oool0403oool00`00o`00oooo0?ooo`1]0?oo
o`80003o=P3oool00`00o`00oooo0?ooo`1J0?ooo`00N`3oool00`000000
oooo0?ooo`0A0?ooo`03003o003oool0oooo06h0oooo00<0003o0?ooo`3o
ool0<`3oool00`00o`00oooo0?ooo`1J0?ooo`00N`3oool00`000000oooo
0?ooo`0A0?ooo`03003o003oool0oooo06l0oooo0P000?lc0?ooo`03003o
003oool0oooo05X0oooo001k0?ooo`030000003oool0oooo0140oooo00<0
0?l00?ooo`3oool0L@3oool00`000?l0oooo0?ooo`0`0?ooo`03003o003o
ool0oooo05X0oooo001k0?ooo`030000003oool0oooo0140oooo00<00?l0
0?ooo`3oool0LP3oool20000oc40oooo00<00?l00?ooo`3oool0F@3oool0
07/0oooo00<000000?ooo`3oool04@3oool00`00o`00oooo0?ooo`1d0?oo
o`030000o`3oool0oooo02h0oooo00<00?l00?ooo`3oool0F@3oool007/0
oooo00<000000?ooo`3oool04P3oool00`00o`00oooo0?ooo`1d0?ooo`80
003o;P3oool00`00o`00oooo0?ooo`1I0?ooo`00N`3oool00`000000oooo
0?ooo`0B0?ooo`03003o003oool0oooo07H0oooo00<0003o0?ooo`3oool0
:`3oool00`00o`00oooo0?ooo`1I0?ooo`00N`3oool00`000000oooo0?oo
o`0B0?ooo`03003o003oool0oooo07L0oooo0P000?l[0?ooo`03003o003o
ool0oooo05T0oooo001k0?ooo`030000003oool0oooo0180oooo00<00?l0
0?ooo`3oool0N@3oool00`000?l0oooo0?ooo`0X0?ooo`03003o003oool0
oooo05T0oooo001k0?ooo`030000003oool0oooo0180oooo00<00?l00?oo
o`3oool0NP3oool20000obT0oooo00<00?l00?ooo`3oool0F03oool007/0
oooo00<000000?ooo`3oool04`3oool00`00o`00oooo0?ooo`1k0?ooo`03
0000o`3oool0oooo02H0oooo00<00?l00?ooo`3oool0F03oool007/0oooo
00<000000?ooo`3oool04`3oool00`00o`00oooo0?ooo`1l0?ooo`80003o
9P3oool00`00o`00oooo0?ooo`1H0?ooo`00N`3oool00`000000oooo0?oo
o`0C0?ooo`03003o003oool0oooo07h0oooo00<0003o0?ooo`3oool0OP3o
ool007/0oooo00<000000?ooo`3oool04`3oool4003o07h0oooo0P000?mn
0?ooo`00N`3oool00`000000oooo0?ooo`0@0?ooo`L00?l0P03oool00`00
0?l0oooo0?ooo`1k0?ooo`00N`3oool00`000000oooo0?ooo`0A0?ooo`H0
0?l0P@3oool20000og/0oooo001k0?ooo`030000003oool0oooo0140oooo
1P00o`230?ooo`030000o`3oool0oooo07P0oooo001k0?ooo`030000003o
ool0oooo0180oooo1@00o`240?ooo`80003oN03oool007/0oooo00<00000
0?ooo`3oool04P3oool5003o08H0oooo00<0003o0?ooo`3oool0M@3oool0
07/0oooo00<000000?ooo`3oool04`3oool4003o08L0oooo0P000?me0?oo
o`00N`3oool00`000000oooo0?ooo`0C0?ooo`@00?l0R@3oool00`000?l0
oooo0?ooo`1b0?ooo`00N`3oool00`000000oooo0?ooo`0D0?ooo`<00?l0
RP3oool20000og80oooo001k0?ooo`030000003oool0oooo01@0oooo0`00
o`2<0?ooo`030000o`3oool0oooo06l0oooo001k0?ooo`030000003oool0
oooo01D0oooo0P00o`2=0?ooo`80003o5`3oool00`00o`00oooo0?ooo`1E
0?ooo`00N`3oool00`000000oooo0?ooo`0E0?ooo`800?l0S`3oool00`00
0?l0oooo0?ooo`0D0?ooo`03003o003oool0oooo05D0oooo001k0?ooo`03
0000003oool0oooo01H0oooo1P3o002;0?ooo`80003o503oool00`00o`00
oooo0?ooo`1E0?ooo`00N`3oool00`000000oooo0?ooo`0L0?ooo`L0o`00
QP3oool00`000?l0oooo0?ooo`0A0?ooo`03003o003oool0oooo05D0oooo
001k0?ooo`030000003oool0oooo0:X0oooo0P000?lB0?ooo`03003o003o
ool0oooo05@0oooo001k0?ooo`030000003oool0oooo01L0oooo0`00000D
0?ooo`H0o`00N03oool00`000?l0oooo0?ooo`0?0?ooo`03003o003oool0
oooo05@0oooo001k0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool06P3oool70?l00780oooo0P000?l?0?ooo`@00?l0D`3oool007/0
oooo00<000000?ooo`3oool0403oool5000000<0oooo00<000000?ooo`3o
ool0:`3oool60?l006<0oooo00<0003o0?ooo`3oool02@3oool7003o05<0
oooo001k0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`0a0?ooo`L0o`00G@3oool20000o`X0
oooo1@00o`1D0?ooo`00N`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`000000A@3oool60?l004d0oooo
00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3oool5003o05@0
oooo001k0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1:0?ooo`L0o`00A`3oool20000o`80oooo
0`000?l30?ooo`@00?l0E03oool007/0oooo00<000000?ooo`3oool04@3o
ool010000000oooo0?ooo`00002P0?ooo`030000o`3oool0003o00<0003o
0P3oool4003o05@0oooo001k0?ooo`030000003oool0oooo0140oooo1@00
001Q0?ooo`H0o`00>@3oool60000o`80oooo0`00o`1D0?ooo`00N`3oool0
0`000000oooo0?ooo`1m0?ooo`L0o`00<P3oool70000o`040?ooo`00o`00
0?l0003o05@0oooo001k0?ooo`030000003oool0oooo08l0oooo1`3o000O
0?ooo`030?l000000?l0003o00D0003o0P3oool2003o05@0oooo001k0?oo
o`030000003oool0oooo09H0oooo1`3o000H0?ooo`<0o`001P000?l00`3o
ool00?l0003o000E0?ooo`D00000403oool3000002L0oooo001k0?ooo`03
0000003oool0oooo0:P0oooo1P3o00070?ooo`D0o`001@000?l00`3oool0
0?l00?ooo`0F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool09`3oool007/0oooo00<000000?ooo`3oool0[P3oool?0?l000<0003o
00<00?l00?ooo`3oool03@3oool5000000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`D000000`3oool00`000000oooo
0?ooo`0V0?ooo`00N`3oool00`000000oooo0?ooo`2d0?ooo`/0o`0000<0
003o0?l00000o`003`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo02H0oooo001k0?ooo`030000
003oool0oooo0;@0oooo3P3o000@0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool5000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0000000W0?ooo`00N`3oool00`000000oooo0?oo
o`2d0?ooo`L0o`00603oool010000000oooo0?ooo`3oool2000000H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo02H0oooo001k0?ooo`030000003oool0oooo0=40oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000002`0oooo001k0?ooo`030000003oool0oooo0=40oooo
1@00000?0?ooo`D00000:`3oool007/0oooo00<000000?ooo`3oool0E@3o
ool3000000D0oooo1000000A0?ooo`D00000WP3oool007/0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0WP3oool007/0oooo00<000000?oo
o`3oool0B@3oool3000000@0oooo0`0000030?ooo`@000001@3oool00`00
0000oooo0?ooo`0:0?ooo`D000000`3oool00`000000oooo0?ooo`2N0?oo
o`00N`3oool00`000000oooo0?ooo`180?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`800000303oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo09h0oooo001k0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0000000d0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`2N0?ooo`00N`3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00000=
0?ooo`040000003oool0oooo0?ooo`800000X03oool007/0oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`0000000P3oool200000080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000:@0
oooo001k0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
1@3oool300000080oooo0P0000000`3oool00000000000020?ooo`<00000
00@0oooo00000000000000002P3oool500000:<0oooo001k0?ooo`030000
003oool0oooo04P0oooo00D000000?ooo`3oool0oooo000000380?ooo`00
N`3oool00`000000oooo0?ooo`190?ooo`@00000b03oool007/0oooo00<0
00000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o
0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool00?l0
ooooU03oool00?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03oool0
0?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03o
ool007T0oooo0P00003o0?oooaT0oooo001j0?ooo`030000003oool0oooo
0?l0oooo5`3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00
NP3oool00`000000oooo0000003o0?oooaL0oooo001i0?ooo`040000003o
ool0oooo00000?l0oooo5`3oool007P0oooo0`0000000`3oool000000000
003o0?oooaH0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0
oooo003o0?oooi@0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 197},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\tThe difference  ",
  Cell[BoxData[
      \(z\_1\  - z\_2\)]],
  "  can be represented by the displacement vector from the point  ",
  Cell[BoxData[
      \(z\_2 = \((x\_2, y\_2)\)\)]],
  "  to the point  ",
  Cell[BoxData[
      \(z\_1 = \((x\_1, y\_1)\)\)]],
  ",  as Figure 1.5 shows."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006F0000ob000`400?l0
0000o`00003oo`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00
N03oool40000ool0oooo6`3oool007L0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`1g0?ooo`D000005@3oool3000008<0oooo001g
0?ooo`H0003oN`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo08<0oooo001/0?ooo`@0003o0`3oool90000o`<0oooo2@000?l20?oo
o`<0003o1P3oool40000o`040?ooo`000?l0003o0?ooo`<0003o2`3oool3
000000<0oooo0`000000103oool000000000003oool2000000H0oooo2`00
0000103oool000000000000000020?ooo`8000000P3oool300000080oooo
0P0000020?ooo`<0000000@0oooo000000000000oooo0P0000030?ooo`80
00001P3oool5000000<0oooo00<000000?ooo`3oool03P3oool5000000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1l0?ooo`00
K@3oool20000o`D0oooo0P000?l00`3oool0003o0?ooo`050?ooo`80003o
00<0oooo0000o`000?l00P3oool20000o`80oooo0P000?l20?ooo`030000
o`3oool0oooo00@0oooo0P000?l20?ooo`80003o00D0oooo0000o`000?l0
oooo0000o`0;0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3o
ool000000?ooo`0000020?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool03P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool0PP3oool006d0oooo0P000?l50?ooo`80003o0P3oool30000o`<0
oooo0P000?l00`3oool0003o0000o`020?ooo`80003o0P3oool20000o`T0
oooo0P000?l90?ooo`030000o`3oool0oooo00P0oooo00<000000?ooo`3o
ool00`3oool01P000000oooo0?ooo`000000oooo000000L0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo
00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000050?oo
o`060000003oool0oooo0000003oool00000103oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool5000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00230?ooo`00K@3oool20000o`030?ooo`000?l0oooo0080oooo0P000?l0
103oool0003o0000o`3oool20000o`80oooo0P000?l00`3oool0003o0000
o`020?ooo`80003o0P3oool50000o`H0oooo0P000?l80?ooo`80003o2P3o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0000003oool0
100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00@000000P3oool00`00
0000oooo0?ooo`0400000080oooo00H000000?ooo`3oool000000?ooo`00
00040?ooo`@000001`3oool00`000000oooo0?ooo`020?ooo`8000004P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0880oooo001]
0?ooo`@0003o0`3oool20000o`040?ooo`000?l0003o0?ooo`80003o0P3o
ool20000o`030?ooo`000?l0003o0080oooo0P000?l01@3oool0003o0000
o`000?l0oooo0080003o1P3oool20000o`D0oooo1@000?l:0?ooo`030000
003oool0oooo00<0oooo0P000000103oool000000?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P0000020?ooo`04
0000003oool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`02000000050?ooo`000000oooo0?ooo`0000000P3o
ool2000000040?ooo`000000oooo00000080oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000001D0
oooo00@000000?ooo`3oool00000R@3oool006d0oooo0P000?l0103oool0
003o0?ooo`3oool30000o`80oooo20000?l0103oool0003o0000o`3oool5
0000o`040?ooo`000?l0003o0000o`L0oooo0P000?l50?ooo`@0003o2`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo0P00
00060?ooo`80000000<0oooo0000003oool00P0000001@3oool000000000
00000000oooo00<000000P3oool200000080oooo0P0000000`3oool00000
0?ooo`0200000080oooo0P0000000`3oool000000?ooo`020?ooo`<00000
0P3oool2000000H0oooo1@00000D0?ooo`D00000R03oool006d0oooo0P00
0?lU0?ooo`80003o1@3oool00`000?l0oooo0?ooo`0<0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`030?ooo`050000003oool0oooo0?ooo`000000bP3oool006d0oooo0P00
0?l30?ooo`040000o`3oool0003o0000oah0oooo0P000?l60?ooo`<0003o
203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020000
0080oooo00<000000?ooo`3oool0a@3oool006`0oooo1`000?l00`3oool0
003o0000o`0M0?ooo`<0003o1P3oool40000o`L0oooo1`0000000`3oool0
00000000000?0?ooo`8000000P3oool010000000oooo0?ooo`3oool30000
00040?ooo`000000000000000<L0oooo003o0?oooiL0oooo003o0?oooiL0
oooo003o0?oooiL0oooo003o0?oooiL0oooo003o0?oooiL0oooo003o0?oo
oiL0oooo003o0?oooiL0oooo003o0?oooiL0oooo003o0?oooiL0oooo003o
0?oooiL0oooo001b0?ooo`030000003oool0oooo0?l0oooo8P3oool00780
oooo00<000000?ooo`3oool0o`3ooolR0?ooo`00LP3oool00`000000oooo
0?ooo`3o0?ooob80oooo001b0?ooo`030000003oool0oooo0?l0oooo8P3o
ool00780oooo00<000000?ooo`3oool0o`3ooolR0?ooo`00LP3oool00`00
0000oooo0?ooo`3o0?ooob80oooo001b0?ooo`030000003oool0oooo0?l0
oooo8P3oool00780oooo00<000000?ooo`3oool0o`3ooolR0?ooo`00LP3o
ool00`000000oooo0?ooo`3o0?ooob80oooo001b0?ooo`030000003oool0
oooo0?l0oooo8P3oool00780oooo00<000000?ooo`3oool0o`3ooolR0?oo
o`00LP3oool00`000000oooo0?ooo`330?ooo`D00000403oool3000004H0
oooo001b0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`160?ooo`00LP3oool00`000000oooo0?oo
o`2m0?ooo`D000000`3oool00`000000oooo0?ooo`090?ooo`D000000`3o
ool00`000000oooo0?ooo`150?ooo`00LP3oool00`000000oooo0?ooo`2n
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo04D0oooo
001b0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`D00000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0000004H0oooo001b0?ooo`030000003oool0
oooo0<00oooo00@000000?ooo`3oool0oooo0P00000>0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0A@3oool00780oooo00<00000
0?ooo`3oool0_P3oool010000000oooo0?ooo`00000@0?ooo`040000003o
ool0oooo000004/0oooo001b0?ooo`030000003oool0oooo0;h0oooo1@00
000?0?ooo`D00000BP3oool00780oooo00<000000?ooo`3oool0Y`3oool4
0000ogH0oooo001b0?ooo`030000003oool0oooo0:L0oooo2`000?m_0?oo
o`00LP3oool00`000000oooo0?ooo`2W0?ooo`l0003oJ`3oool00780oooo
00<000000?ooo`3oool0Y`3oool=0000o`030?ooo`00o`00oooo06X0oooo
001b0?ooo`030000003oool0oooo0:00oooo4P000?l30?ooo`03003o003o
ool0oooo06T0oooo001b0?ooo`030000003oool0oooo09L0oooo2@000?l8
0?ooo`L0003o1P3oool2003o06X0oooo001b0?ooo`030000003oool0oooo
08h0oooo2@000?lA0?ooo`@0003o2@3oool2003o06X0oooo001b0?ooo`03
0000003oool0oooo08D0oooo2@000?lJ0?ooo`80003o2`3oool3003o06T0
oooo001b0?ooo`030000003oool0oooo07d0oooo20000?l`0?ooo`<00?l0
J@3oool00780oooo00<000000?ooo`3oool0M03oool90000ocP0oooo0`00
o`1Y0?ooo`00LP3oool00`000000oooo0?ooo`1[0?ooo`T0003o@@3oool4
003o06P0oooo001b0?ooo`030000003oool0oooo0680oooo2@000?m:0?oo
o`@00?l0J03oool00780oooo00<000000?ooo`3oool0FP3oool80000oe<0
oooo1@00o`1W0?ooo`00LP3oool00`000000oooo0?ooo`1A0?ooo`T0003o
F`3oool5003o06L0oooo001b0?ooo`030000003oool0oooo04P0oooo2@00
0?mT0?ooo`H00?l0IP3oool00780oooo00<000000?ooo`3oool0?`3oool9
0000of`0oooo1`00o`1V0?ooo`00LP3oool00`000000oooo0?ooo`0f0?oo
o`T0003oM@3oool4003o06T0oooo001b0?ooo`030000003oool0oooo02h0
oooo20000?n20?ooo`03003o003oool0oooo06H0oooo001b0?ooo`030000
003oool0oooo02D0oooo2@000?n:0?ooo`03003o003oool0oooo06H0oooo
001b0?ooo`030000003oool0oooo01`0oooo2@000?nC0?ooo`03003o003o
ool0oooo06H0oooo001b0?ooo`030000003oool0oooo01<0oooo2@000?nL
0?ooo`03003o003oool0oooo06H0oooo001b0?ooo`030000003oool0oooo
00/0oooo20000?oo0?ooo`l0oooo001b0?ooo`030000003oool0oooo0080
oooo2@000?oo0?ooo`80oooo0P0000000`3oool000000000000@0?ooo`00
LP3oool50000ool00000100000080?ooo`030000003oool000000140oooo
001b0?ooo`03003o003o0000o`000?l0oooo3`3oool00`000000oooo0?oo
o`0@0?ooo`00LP3oool00`00o`00oooo0?ooo`020?l00?l0oooo2`3oool2
000000030?ooo`00000000000100oooo001b0?ooo`0300000000o`00oooo
0080oooo00<0o`000?ooo`3oool0o`3ooolM0?ooo`00LP3oool00`000000
0?l00?ooo`030?ooo`80o`00o`3ooolM0?ooo`00LP3oool00`0000000?l0
0?ooo`050?ooo`80o`00o`3ooolK0?ooo`00LP3oool00`0000000?l00?oo
o`070?ooo`030?l0003oool0oooo0?l0oooo603oool00780oooo00<00000
003o003oool0203oool20?l00?l0oooo603oool00780oooo00<00000003o
003oool02P3oool20?l00?l0oooo5P3oool00780oooo00<000000?ooo`00
o`00303oool00`3o0000oooo0?ooo`3o0?oooa<0oooo001b0?ooo`030000
003oool00?l000d0oooo0P3o002[0?ooo`03003o003oool0oooo06@0oooo
001b0?ooo`030000003oool00?l000l0oooo0P3o002Y0?ooo`03003o003o
ool0oooo06@0oooo001b0?ooo`030000003oool00?l00140oooo00<0o`00
0?ooo`3oool0YP3oool00`00o`00oooo0?ooo`1T0?ooo`00LP3oool00`00
0000oooo003o000B0?ooo`80o`00Y`3oool00`00o`00oooo0?ooo`1S0?oo
o`00LP3oool00`000000oooo003o000D0?ooo`80o`00Y@3oool00`00o`00
oooo0?ooo`1S0?ooo`00LP3oool010000000oooo0?ooo`00o`0E0?ooo`03
0?l0003oool0oooo0:80oooo00<00?l00?ooo`3oool0H`3oool00780oooo
00@000000?ooo`3oool00?l05P3oool20?l00:80oooo00<00?l00?ooo`3o
ool0H`3oool00780oooo00@000000?ooo`3oool00?l0603oool20?l00:40
oooo00<00?l00?ooo`3oool0HP3oool00780oooo00@000000?ooo`3oool0
0?l06P3oool00`3o0000oooo0?ooo`2N0?ooo`03003o003oool0oooo0680
oooo001b0?ooo`040000003oool0oooo003o01/0oooo0P3o002N0?ooo`03
003o003oool0oooo0680oooo001b0?ooo`050000003oool0oooo0?ooo`00
o`00703oool20?l009`0oooo00<00?l00?ooo`3oool0HP3oool00780oooo
00D000000?ooo`3oool0oooo003o000N0?ooo`030?l0003oool0oooo09X0
oooo00<00?l00?ooo`3oool0H@3oool00780oooo00D000000?ooo`3oool0
oooo003o000O0?ooo`80o`00VP3oool00`00o`00oooo0?ooo`1Q0?ooo`00
LP3oool01@000000oooo0?ooo`3oool00?l00240oooo0P3o002H0?ooo`03
003o003oool0oooo0640oooo001b0?ooo`050000003oool0oooo0?ooo`00
o`008`3oool00`3o0000oooo0?ooo`3i0?ooo`00LP3oool01@000000oooo
0?ooo`3oool00?l002@0oooo0P3o003i0?ooo`00LP3oool00`000000oooo
0?ooo`020?ooo`03003o003oool0oooo02<0oooo0P3o003g0?ooo`00LP3o
ool00`000000oooo0?ooo`020?ooo`03003o003oool0oooo02D0oooo00<0
o`000?ooo`3oool0m03oool00780oooo00<000000?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`0V0?ooo`80o`00m03oool00780oooo00<000000?oo
o`3oool00P3oool00`00o`00oooo0?ooo`0X0?ooo`80o`00lP3oool00780
oooo00<000000?ooo`3oool00P3oool00`00o`00oooo0?ooo`0Z0?ooo`03
0?l0003oool0oooo0>l0oooo001b0?ooo`030000003oool0oooo0080oooo
00<00?l00?ooo`3oool0:`3oool20?l00>l0oooo001b0?ooo`030000003o
ool0oooo00<0oooo00<00?l00?ooo`3oool0;03oool20?l00>d0oooo001b
0?ooo`030000003oool0oooo00<0oooo00<00?l00?ooo`3oool0;P3oool0
0`3o0000oooo0?ooo`3Z0?ooo`00LP3oool00`000000oooo0?ooo`030?oo
o`03003o003oool0oooo02l0oooo0P3o003Z0?ooo`00LP3oool00`000000
oooo0?ooo`030?ooo`03003o003oool0oooo0340oooo0P3o003X0?ooo`00
LP3oool00`000000oooo0?ooo`030?ooo`03003o003oool0oooo03<0oooo
00<0o`000?ooo`3oool0P`3oool00`00o`00oooo0?ooo`1O0?ooo`00LP3o
ool00`000000oooo0?ooo`040?ooo`03003o003oool0oooo03<0oooo0P3o
00230?ooo`03003o003oool0oooo05l0oooo001b0?ooo`030000003oool0
oooo00@0oooo00<00?l00?ooo`3oool0=@3oool20?l00840oooo00<00?l0
0?ooo`3oool0G`3oool00780oooo00<000000?ooo`3oool0103oool00`00
o`00oooo0?ooo`0g0?ooo`030?l0003oool0oooo07h0oooo00<00?l00?oo
o`3oool0G`3oool00780oooo00<000000?ooo`3oool0103oool00`00o`00
oooo0?ooo`0h0?ooo`80o`00O`3oool00`00o`00oooo0?ooo`1N0?ooo`00
LP3oool00`000000oooo0?ooo`040?ooo`03003o003oool0oooo03X0oooo
0P3o001m0?ooo`03003o003oool0oooo05h0oooo001b0?ooo`030000003o
ool0oooo00@0oooo00<00?l00?ooo`3oool0?03oool00`3o0000oooo0?oo
o`1j0?ooo`03003o003oool0oooo05h0oooo001b0?ooo`030000003oool0
oooo00D0oooo00<00?l00?ooo`3oool0?03oool20?l007X0oooo00<00?l0
0?ooo`3oool04P3oool3000000D0oooo1000000I0?ooo`<00000903oool0
0780oooo00<000000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0n0?oo
o`80o`00N03oool00`00o`00oooo0?ooo`0C0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0T0?oo
o`00LP3oool00`000000oooo0?ooo`050?ooo`03003o003oool0oooo0400
oooo00<0o`000?ooo`3oool0M@3oool00`00o`00oooo0?ooo`060?ooo`<0
0000103oool3000000<0oooo100000050?ooo`030000003oool0oooo0140
oooo1@0000030?ooo`030000003oool0oooo02<0oooo001b0?ooo`030000
003oool0oooo00D0oooo00<00?l00?ooo`3oool0@@3oool20?l007H0oooo
00<00?l00?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`000000103oool2000001<0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0S0?ooo`00LP3oool00`000000oooo0?ooo`05
0?ooo`03003o003oool0oooo04<0oooo0P3o001d0?ooo`03003o003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0000000X0oooo1@0000050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`000000903oool00780oooo00<000000?ooo`3oool01@3o
ool00`00o`00oooo0?ooo`150?ooo`030?l0003oool0oooo0740oooo00<0
0?l00?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02<0oooo001b0?ooo`030000003oool0oooo00H0
oooo00<00?l00?ooo`3oool0A@3oool20?l00740oooo00<00?l00?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000000P3oool200000080oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000002T0oooo001b
0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool0A`3oool2
0?l007H0oooo00<000000?ooo`3oool01@3oool300000080oooo0P000000
0`3oool00000000000020?ooo`<0000000@0oooo00000000000000004@3o
ool5000002P0oooo001b0?ooo`030000003oool0oooo00H0oooo00<00?l0
0?ooo`3oool0B@3oool00`3o0000oooo0?ooo`1c0?ooo`050000003oool0
oooo0?ooo`000000E03oool00780oooo00<000000?ooo`3oool01P3oool0
0`00o`00oooo0?ooo`1:0?ooo`80o`00M03oool4000005@0oooo001b0?oo
o`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool0C03oool20?l0
0<X0oooo001b0?ooo`030000003oool0oooo00L0oooo00<00?l00?ooo`3o
ool0C@3oool00`3o0000oooo0?ooo`370?ooo`00LP3oool00`000000oooo
0?ooo`070?ooo`03003o003oool0oooo04h0oooo0P3o00370?ooo`00LP3o
ool00`000000oooo0?ooo`070?ooo`03003o003oool0oooo0500oooo0P3o
00350?ooo`00LP3oool00`000000oooo0?ooo`070?ooo`03003o003oool0
oooo0580oooo00<0o`000?ooo`3oool0`P3oool00780oooo00<000000?oo
o`3oool01`3oool00`00o`00oooo0?ooo`1C0?ooo`80o`00`P3oool00780
oooo00<000000?ooo`3oool01`3oool00`00o`00oooo0?ooo`1E0?ooo`80
o`00`03oool00780oooo00<000000?ooo`3oool0203oool00`00o`00oooo
0?ooo`1F0?ooo`030?l0003oool0oooo0;d0oooo001b0?ooo`030000003o
ool0oooo00P0oooo00<00?l00?ooo`3oool0E`3oool20?l00;d0oooo001b
0?ooo`030000003oool0oooo00P0oooo00<00?l00?ooo`3oool0F@3oool2
0?l005d0oooo00<00?l00?ooo`3oool0F`3oool00780oooo00<000000?oo
o`3oool0203oool00`00o`00oooo0?ooo`1K0?ooo`030?l0003oool0oooo
05X0oooo00<00?l00?ooo`3oool0F`3oool00780oooo00<000000?ooo`3o
ool0203oool00`00o`00oooo0?ooo`1L0?ooo`80o`00FP3oool00`00o`00
oooo0?ooo`1K0?ooo`00LP3oool00`000000oooo0?ooo`080?ooo`03003o
003oool0oooo05h0oooo0P3o001I0?ooo`03003o003oool0oooo05X0oooo
001b0?ooo`030000003oool0oooo00T0oooo00<00?l00?ooo`3oool0G`3o
ool00`3o0000oooo0?ooo`1F0?ooo`03003o003oool0oooo05X0oooo001b
0?ooo`030000003oool0oooo00T0oooo00<00?l00?ooo`3oool0H03oool2
0?l005H0oooo00<00?l00?ooo`3oool0FP3oool00780oooo00<000000?oo
o`3oool02@3oool00`00o`00oooo0?ooo`1R0?ooo`80o`00E03oool00`00
o`00oooo0?ooo`1J0?ooo`00LP3oool00`000000oooo0?ooo`090?ooo`03
003o003oool0oooo06@0oooo00<0o`000?ooo`3oool0DP3oool00`00o`00
oooo0?ooo`1I0?ooo`00LP3oool00`000000oooo0?ooo`090?ooo`03003o
003oool0oooo06D0oooo0P3o001B0?ooo`03003o003oool0oooo05T0oooo
001b0?ooo`030000003oool0oooo00X0oooo00<00?l00?ooo`3oool0IP3o
ool20?l00500oooo00<00?l00?ooo`3oool0F@3oool00780oooo00<00000
0?ooo`3oool02P3oool00`00o`00oooo0?ooo`1X0?ooo`030?l0003oool0
oooo04d0oooo00<00?l00?ooo`3oool0F@3oool00780oooo00<000000?oo
o`3oool02P3oool00`00o`00oooo0?ooo`1Y0?ooo`80o`00CP3oool00`00
o`00oooo0?ooo`1H0?ooo`00LP3oool00`000000oooo0?ooo`0:0?ooo`03
003o003oool0oooo06/0oooo0P3o001<0?ooo`03003o003oool0oooo05P0
oooo001b0?ooo`030000003oool0oooo00X0oooo00<00?l00?ooo`3oool0
K@3oool00`3o0000oooo0?ooo`190?ooo`03003o003oool0oooo05P0oooo
001b0?ooo`030000003oool0oooo00X0oooo00<00?l00?ooo`3oool0KP3o
ool20?l00:@0oooo001b0?ooo`030000003oool0oooo00/0oooo00<00?l0
0?ooo`3oool0K`3oool20?l00:80oooo001b0?ooo`030000003oool0oooo
00/0oooo00<00?l00?ooo`3oool0L@3oool00`3o0000oooo0?ooo`2O0?oo
o`00LP3oool00`000000oooo0?ooo`0;0?ooo`03003o003oool0oooo0780
oooo0P3o002O0?ooo`00LP3oool00`000000oooo0?ooo`0;0?ooo`03003o
003oool0oooo07@0oooo0P3o002M0?ooo`00LP3oool00`000000oooo0?oo
o`0;0?ooo`03003o003oool0oooo07H0oooo00<0o`000?ooo`3oool0VP3o
ool00780oooo00<000000?ooo`3oool0303oool00`00o`00oooo0?ooo`1f
0?ooo`80o`00VP3oool00780oooo00<000000?ooo`3oool0303oool00`00
o`00oooo0?ooo`1h0?ooo`80o`00V03oool00780oooo00<000000?ooo`3o
ool0303oool00`00o`00oooo0?ooo`1j0?ooo`030?l0003oool0oooo09D0
oooo001b0?ooo`030000003oool0oooo00`0oooo00<00?l00?ooo`3oool0
N`3oool20?l009D0oooo001b0?ooo`030000003oool0oooo00`0oooo00<0
0?l00?ooo`3oool0O@3oool20?l009<0oooo001b0?ooo`030000003oool0
oooo00`0oooo00<00?l00?ooo`3oool0O`3oool00`3o0000oooo0?ooo`2@
0?ooo`00LP3oool00`000000oooo0?ooo`0=0?ooo`03003o003oool0oooo
07l0oooo0P3o000g0?ooo`03003o003oool0oooo05H0oooo001b0?ooo`03
0000003oool0oooo00d0oooo00<00?l00?ooo`3oool0P@3oool20?l003D0
oooo00<00?l00?ooo`3oool0EP3oool00780oooo00<000000?ooo`3oool0
3@3oool00`00o`00oooo0?ooo`230?ooo`030?l0003oool0oooo0380oooo
00<00?l00?ooo`3oool0EP3oool00780oooo00<000000?ooo`3oool03@3o
ool00`00o`00oooo0?ooo`240?ooo`80o`00<P3oool00`00o`00oooo0?oo
o`1F0?ooo`00LP3oool00`000000oooo0?ooo`0=0?ooo`03003o003oool0
oooo08H0oooo0P3o000a0?ooo`03003o003oool0oooo05D0oooo001b0?oo
o`030000003oool0oooo00d0oooo00<00?l00?ooo`3oool0R03oool00`3o
0000oooo0?ooo`0^0?ooo`03003o003oool0oooo05D0oooo001b0?ooo`03
0000003oool0oooo00h0oooo00<00?l00?ooo`3oool0R03oool20?l002h0
oooo00<00?l00?ooo`3oool0E@3oool00780oooo00<000000?ooo`3oool0
3P3oool00`00o`00oooo0?ooo`2:0?ooo`80o`00;03oool00`00o`00oooo
0?ooo`1E0?ooo`00LP3oool00`000000oooo0?ooo`0>0?ooo`03003o003o
ool0oooo08`0oooo00<0o`000?ooo`3oool0:@3oool00`00o`00oooo0?oo
o`1E0?ooo`00LP3oool00`000000oooo0?ooo`0>0?ooo`03003o003oool0
oooo08d0oooo0P3o000Y0?ooo`03003o003oool0oooo05D0oooo001b0?oo
o`030000003oool0oooo00h0oooo00<00?l00?ooo`3oool0S`3oool20?l0
02P0oooo00<00?l00?ooo`3oool0E03oool00780oooo00<000000?ooo`3o
ool03`3oool00`00o`00oooo0?ooo`2@0?ooo`030?l0003oool0oooo02D0
oooo00<00?l00?ooo`3oool0E03oool00780oooo00<000000?ooo`3oool0
3`3oool00`00o`00oooo0?ooo`2A0?ooo`80o`009@3oool00`00o`00oooo
0?ooo`1D0?ooo`00LP3oool00`000000oooo0?ooo`0?0?ooo`03003o003o
ool0oooo09<0oooo0P3o000S0?ooo`03003o003oool0oooo05@0oooo001b
0?ooo`030000003oool0oooo00l0oooo00<00?l00?ooo`3oool0U@3oool0
0`3o0000oooo0?ooo`1g0?ooo`00LP3oool00`000000oooo0?ooo`0?0?oo
o`03003o003oool0oooo09H0oooo0P3o001g0?ooo`00LP3oool00`000000
oooo0?ooo`0?0?ooo`03003o003oool0oooo09P0oooo0P3o001e0?ooo`00
LP3oool00`000000oooo0?ooo`0@0?ooo`03003o003oool0oooo09T0oooo
00<0o`000?ooo`3oool0LP3oool00780oooo00<000000?ooo`3oool0403o
ool00`00o`00oooo0?ooo`2J0?ooo`80o`00LP3oool00780oooo00<00000
0?ooo`3oool0403oool00`00o`00oooo0?ooo`2L0?ooo`80o`00L03oool0
0780oooo00<000000?ooo`3oool0403oool00`00o`00oooo0?ooo`2N0?oo
o`030?l0003oool0oooo06d0oooo001b0?ooo`030000003oool0oooo0100
oooo00<00?l00?ooo`3oool0W`3oool20?l006d0oooo001b0?ooo`030000
003oool0oooo0100oooo00<00?l00?ooo`3oool0X@3oool20?l006/0oooo
001b0?ooo`030000003oool0oooo0140oooo00<00?l00?ooo`3oool0XP3o
ool00`3o0000oooo0?ooo`1X0?ooo`00LP3oool00`000000oooo0?ooo`0A
0?ooo`03003o003oool0oooo0:<0oooo0P3o001X0?ooo`00LP3oool00`00
0000oooo0?ooo`0A0?ooo`03003o003oool0oooo0:D0oooo0P3o000B0?oo
o`03003o003oool0oooo0540oooo001b0?ooo`030000003oool0oooo0140
oooo00<00?l00?ooo`3oool0Y`3oool00`3o0000oooo0?ooo`0?0?ooo`03
003o003oool0oooo0540oooo001b0?ooo`030000003oool0oooo0140oooo
00<00?l00?ooo`3oool0Z03oool20?l000l0oooo00<00?l00?ooo`3oool0
D@3oool00780oooo00<000000?ooo`3oool04P3oool00`00o`00oooo0?oo
o`2Y0?ooo`80o`003@3oool00`00o`00oooo0?ooo`1A0?ooo`00LP3oool0
0`000000oooo0?ooo`0B0?ooo`03003o003oool0oooo0:/0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`03003o003oool0
oooo0500oooo001b0?ooo`030000003oool0oooo0180oooo00<00?l00?oo
o`3oool0[03oool20?l000040?ooo`3o0000o`000?l000L0oooo00<00?l0
0?ooo`3oool0D03oool00780oooo00<000000?ooo`3oool04P3oool00`00
o`00oooo0?ooo`2^0?ooo`D0o`001P3oool00`00o`00oooo0?ooo`0<0?oo
o`D00000?`3oool00780oooo00<000000?ooo`3oool04P3oool00`00o`00
oooo0?ooo`2^0?ooo`H0o`001@3oool00`00o`00oooo0?ooo`0>0?ooo`03
0000003oool0oooo03l0oooo001b0?ooo`030000003oool0oooo0180oooo
00<00?l00?ooo`3oool0[P3oool70?l000@0oooo00<00?l00?ooo`3oool0
1P3oool5000000<0oooo00<000000?ooo`3oool0?`3oool00780oooo00<0
00000?ooo`3oool04`3oool00`00o`00oooo0?ooo`2/0?ooo`X0o`000P3o
ool00`00o`00oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0?`3oool00780oooo00<000000?ooo`3oool04`3o
ool00`00o`00oooo0?ooo`2^0?ooo`T0o`000P3oool00`00o`00oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0?`3o
ool00780oooo00<000000?ooo`3oool04`3oool00`00o`00oooo0?ooo`2a
0?ooo`L0o`0000<0oooo003o003oool02@3oool010000000oooo0?ooo`3o
ool200000440oooo001b0?ooo`030000003oool0oooo01<0oooo00<00?l0
0?ooo`3oool0[03oool00`000?l0oooo0?ooo`060?ooo`@0o`0000<00?l0
0?ooo`3oool01P3oool010000000oooo0?ooo`0000150?ooo`00LP3oool0
0`000000oooo0?ooo`0C0?ooo`03003o003oool0oooo0:`0oooo3P000?l8
0?ooo`D00000A03oool00780oooo00<000000?ooo`3oool04`3oool00`00
o`00oooo0?ooo`2/0?ooo`/0003o00<0oooo0000o`000?l0D@3oool00780
oooo00<000000?ooo`3oool0503oool00`00o`00oooo0?ooo`2T0?ooo`l0
003o00@0oooo0000o`000?l0003oD`3oool00780oooo00<000000?ooo`3o
ool0503oool00`00o`00oooo0?ooo`2M0?ooo`L0003o1`3oool90000oeH0
oooo001b0?ooo`030000003oool0oooo01@0oooo00<00?l00?ooo`3oool0
Z`3oool50000oeX0oooo001b0?ooo`030000003oool0oooo01@0oooo00<0
0?l00?ooo`3oool0RP3oool70000oaX0oooo0P000?mM0?ooo`00LP3oool0
0`000000oooo0?ooo`0D0?ooo`03003o003oool0oooo08<0oooo1`000?n0
0?ooo`00LP3oool00`000000oooo0?ooo`0E0?ooo`03003o003oool0oooo
0?l0oooo2P3oool00780oooo00<000000?ooo`3oool05@3oool4003o06h0
oooo1`000?nC0?ooo`00LP3oool00`000000oooo0?ooo`0B0?ooo`L00?l0
I`3oool70000oiX0oooo001b0?ooo`030000003oool0oooo0180oooo1`00
o`3o0?ooo`T0oooo001b0?ooo`030000003oool0oooo01<0oooo1P00o`1C
0?ooo`L0003o[P3oool00780oooo00<000000?ooo`3oool04`3oool6003o
04`0oooo1`000?ne0?ooo`00LP3oool00`000000oooo0?ooo`0D0?ooo`D0
0?l0o`3oool90?ooo`00LP3oool00`000000oooo0?ooo`0D0?ooo`D00?l0
>@3oool70000olP0oooo001b0?ooo`030000003oool0oooo01@0oooo1000
o`0c0?ooo`L0003oc`3oool00780oooo00<000000?ooo`3oool05@3oool3
003o0?l0oooo2P3oool00780oooo00<000000?ooo`3oool05@3oool3003o
0200oooo1`000?oR0?ooo`00LP3oool00`000000oooo0?ooo`0F0?ooo`80
0?l06@3oool70000obL0oooo0`0000050?ooo`@000004@3oool500000100
oooo0`00002=0?ooo`00LP3oool00`000000oooo0?ooo`0F0?ooo`800?l0
B03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`2=0?ooo`00LP3o
ool00`000000oooo0?ooo`0G0?ooo`03003o003oool0oooo00@0oooo1`00
0?l^0?ooo`<00000103oool3000000<0oooo100000050?ooo`030000003o
ool0oooo00X0oooo1@0000030?ooo`030000003oool0oooo00T0oooo1@00
00030?ooo`030000003oool0oooo08`0oooo001b0?ooo`030000003oool0
oooo01L0oooo1`000?ld0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000040?ooo`800000303oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00X0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`2<0?ooo`00LP3oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000
000=0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo
1@0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
S@3oool00780oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000003@3oool01000
0000oooo0?ooo`3oool2000000h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2<0?ooo`00LP3oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`8000000P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00T0oooo00@000000?ooo`3oool00000403oool010000000oooo
0?ooo`00002B0?ooo`00LP3oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo00D0oooo0`0000020?ooo`80000000<0oooo000000000000
0P3oool3000000040?ooo`0000000000000000X0oooo1@00000?0?ooo`D0
0000T@3oool00780oooo00<000000?ooo`3oool06@3oool3000003H0oooo
00D000000?ooo`3oool0oooo0000003:0?ooo`00LP3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo03L0oooo1000003:0?ooo`00LP3o
ool00`000000oooo0?ooo`0B0?ooo`D000000`3oool00`000000oooo0?oo
o`3o0?ooo`D0oooo001b0?ooo`030000003oool0oooo01<0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001b
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0000003o0?ooo`H0oooo001b0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oo
o`D0oooo001b0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3o
ool00000o`3oool;0?ooo`00LP3oool00`000000oooo0?ooo`0C0?ooo`D0
0000o`3oool:0?ooo`00LP3oool00`000000oooo0?ooo`3o0?ooob80oooo
001b0?ooo`030000003oool0oooo0?l0oooo8P3oool00780oooo00<00000
0?ooo`3oool0o`3ooolR0?ooo`00LP3oool00`000000oooo0?ooo`3o0?oo
ob80oooo001b0?ooo`030000003oool0oooo0?l0oooo8P3oool00780oooo
00<000000?ooo`3oool0o`3ooolR0?ooo`00LP3oool00`000000oooo0?oo
o`3o0?ooob80oooo001b0?ooo`030000003oool0oooo0?l0oooo8P3oool0
0780oooo00<000000?ooo`3oool0o`3ooolR0?ooo`00o`3ooonG0?ooo`00
o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?oo
o`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG
0?ooo`00L03oool200000?l0oooo9@3oool00740oooo00<000000?ooo`3o
ool0o`3ooolS0?ooo`00LP3oool00`000000oooo0?ooo`3o0?ooob80oooo
001a0?ooo`030000003oool000000?l0oooo8`3oool00700oooo00@00000
0?ooo`3oool00000o`3ooolS0?ooo`00K`3oool3000000030?ooo`000000
00000?l0oooo8P3oool00?l0ooooU`3oool00?l0ooooU`3oool00?l0oooo
U`3oool00?l0ooooU`3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{406, 255},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Definition 1.8, (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Modulus",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ModulusComplexNumber.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[" or Absolute Value).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]],
  "The modulus, or absolute value, of the complex number  ",
  Cell[BoxData[
      \(z = x + \[ImaginaryI]\ y\)]],
  "  is a nonnegative real number denoted by  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\)\)]],
  "  and is given by the equation  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = \@\(x\^2 + y\^2\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe number  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\)\)]],
  "  is the distance between the origin and the point  ",
  Cell[BoxData[
      \(z = \((x, y)\)\)]],
  ".  The only complex number with modulus zero is the number ",
  Cell[BoxData[
      \(0\)]],
  ".  The number  ",
  Cell[BoxData[
      \(z = 3 + 4  \[ImaginaryI]\)]],
  "  has modulus  ",
  Cell[BoxData[
      \(\(\(|\)\(4 + 
            3  \[ImaginaryI]\)\(|\)\) = \(\@\(4\^2 + 3\^2\) = \(\@25 = 
            5\)\)\)]],
  ",  and is depicted in Figure 1.6.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006J0000n2000`400?l0
0000o`00003oo`3ooonK0?ooo`00o`3ooonK0?ooo`00N03oool40000og/0
oooo0`00000C0?ooo`800000203oool300000480oooo0`00000k0?ooo`00
M`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo07L0oooo
00D000000?ooo`3oool0oooo0000000D0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0j0?ooo`00
M`3oool60000ogT0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0j0?ooo`00K03oool40000o`<0oooo2@000?l30?ooo`T0003o
0P3oool30000o`H0oooo10000?l00`3oool0003o0000o`020?ooo`<0003o
2P3oool3000000<0oooo0`000000103oool000000000003oool2000000D0
oooo0`0000020?ooo`8000000`3oool7000000@0oooo1`000000103oool0
00000000003oool5000000<0oooo1P000000103oool000000000003oool2
000000030?ooo`00000000000080000000D0oooo00000000000000000?oo
o`06000000040?ooo`00000000000?ooo`L00000103oool00`000000oooo
0?ooo`050?ooo`040000003oool00000000000<0oooo1`0000020?ooo`80
000000@0oooo00000000000000001P3oool300000080oooo0`0000050?oo
o`@00000103oool2000000<0oooo0`0000020?ooo`<0000000@0oooo0000
00000000oooo0P0000000`3oool000000?ooo`0200000080oooo0`000000
0`3oool00000000000020?ooo`80000000<0oooo0000000000000`3oool3
000000030?ooo`00000000000080oooo1`000000103oool000000000003o
ool2000000040?ooo`0000000000000000<0oooo0P0000020?ooo`<00000
0P3oool100000040oooo001]0?ooo`80003o1@3oool20000o`030?ooo`00
0?l0oooo00D0oooo0P000?l00`3oool0003o0000o`020?ooo`80003o0P3o
ool20000o`80oooo00<0003o0?ooo`3oool0103oool20000o`80oooo0P00
0?l0103oool0003o0000o`3oool20000o`X0oooo00<000000?ooo`3oool0
0`3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
00000080oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000020?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00H00000
0?ooo`3oool000000?ooo`0000020?ooo`030000003oool0000000D0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo000000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`0000001P3oool20000
0080oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000040?ooo`060000003oool0oooo0000
003oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo0P0000020?ooo`060000003oool0oooo0000003o
ool000000P3oool01P000000oooo0?ooo`000000oooo000000D0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000020?ooo`040000003oool0oooo000000D0oooo001]0?oo
o`80003o1@3oool20000o`80oooo0`000?l30?ooo`80003o00<0oooo0000
o`000?l00P3oool20000o`80oooo0P000?l90?ooo`80003o1@3oool20000
o`030?ooo`000?l0003o00X0oooo00<000000?ooo`3oool00`3oool01P00
0000oooo0?ooo`000000oooo000000P0oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000020?ooo`060000003oool0oooo0000003oool000000P3oool00`00
0000oooo0?ooo`02000000<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo000000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
0080oooo0P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oo
o`060000003oool0oooo0000003oool000001P3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?oo
o`00K@3oool20000o`030?ooo`000?l0oooo0080oooo0P000?l0103oool0
003o0000o`3oool20000o`80oooo0P000?l00`3oool0003o0000o`020?oo
o`80003o0P3oool50000o`H0oooo0P000?l50?ooo`80003o00<0oooo0000
o`000?l02P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0000003oool0100000050?ooo`030000003oool0oooo00@000000P3oool3
00000080oooo00<000000?ooo`3oool00`3oool300000080oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`<0000000D0oooo0000003oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00`0000020?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`0000000P3oool300000080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`8000001P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0103oool3000000@0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`05
0000003oool0oooo0000003oool0100000030?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`000000
0`3oool00`000000oooo0000000300000080oooo00<000000?ooo`3oool0
0`3oool006d0oooo10000?l30?ooo`80003o00@0oooo0000o`000?l0oooo
0P000?l20?ooo`80003o00<0oooo0000o`000?l00P3oool20000o`050?oo
o`000?l0003o0000o`3oool00P000?l60?ooo`80003o1@3oool20000o`03
0?ooo`000?l0003o00X0oooo00<000000?ooo`3oool00`3oool200000004
0?ooo`000000oooo00000080oooo00<000000?ooo`3oool00`3oool20000
00070?ooo`000000oooo0?ooo`000000oooo000000020?ooo`040000003o
ool0oooo000000@0oooo00@000000?ooo`3oool000000P3oool200000004
0?ooo`000000oooo00000080oooo0P0000050?ooo`030000003oool0oooo
0080000000L0oooo000000000000oooo0000003oool000000080oooo00<0
00000?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`800000
00@0oooo0000003oool000000P3oool00`000000oooo0?ooo`0200000080
oooo00D000000?ooo`3oool0oooo000000050?ooo`8000000P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo008000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000103oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool00P0000001@3oool000000000003oool0
00000080oooo0P0000020?ooo`060000003oool0oooo0000003oool00000
0P3oool01P000000oooo0?ooo`000000oooo000000D0oooo0P0000001@3o
ool000000?ooo`3oool000000080oooo00<000000?ooo`3oool00P000000
1P3oool000000000003oool000000?ooo`8000000P3oool00`000000oooo
000000020?ooo`030000003oool0oooo00800000103oool006d0oooo0P00
0?l0103oool0003o0?ooo`3oool30000o`80oooo20000?l0103oool0003o
0000o`3oool50000o`040?ooo`000?l0003o0000o`L0oooo0P000?l50?oo
o`@0003o2`3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
00<0oooo0P0000050?ooo`80000000<0oooo0000003oool00P0000030?oo
o`8000000`3oool00`000000oooo0?ooo`030?ooo`8000000P3oool20000
00030?ooo`000000oooo0080oooo0P0000000`3oool000000?ooo`030?oo
o`80000000D0oooo000000000000oooo000000020?ooo`040000003oool0
oooo0?ooo`8000000`3oool6000000050?ooo`00000000000?ooo`000000
0`3oool200000080oooo0P0000000`3oool0000000000002000000040?oo
o`0000000000000000<0oooo0P0000000`3oool00000000000030?ooo`80
00000P3oool2000000030?ooo`0000000000008000000P3oool3000000D0
oooo0`0000020?ooo`<000001@3oool2000000H0oooo0`0000020?ooo`<0
00000P3oool2000000050?ooo`000000oooo0?ooo`0000000P3oool20000
00030?ooo`000000000000<0oooo00<000000?ooo`3oool00P0000020?oo
o`80000000<0oooo0000000000000`3oool2000000040?ooo`000000oooo
0?ooo`80000000@0oooo000000000000oooo0P0000001@3oool000000?oo
o`3oool000000080oooo00@000000?ooo`00000000000`3oool200000080
oooo0P0000000`3oool000000?ooo`020?ooo`00K@3oool20000obD0oooo
0P000?l60?ooo`030000o`3oool0oooo00/0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0?0?ooo`00K@3oool20000o`<0oooo00@0003o0?ooo`000?l0003o
7P3oool20000o`H0oooo0`000?l80?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000006`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool01000
0000oooo0?ooo`00000V0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool03`3oool006`0oooo1`000?l00`3oool0003o0000o`0M0?oo
o`<0003o203oool20000o`L0oooo1`0000000`3oool000000000000J0?oo
o`8000004P3oool2000000D0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0l0?ooo`<000009@3oool200000280oooo0P00000A0?oo
o`00o`3ooonK0?ooo`00o`3ooonK0?ooo`00o`3ooonK0?ooo`00o`3ooonK
0?ooo`00o`3ooonK0?ooo`00o`3ooonK0?ooo`00o`3ooonK0?ooo`00o`3o
oonK0?ooo`00o`3ooonK0?ooo`00o`3ooonK0?ooo`00o`3ooonK0?ooo`00
O03oool00`000000oooo0?ooo`0e0?ooo`D00000=@3oool4000003L0oooo
0P00000i0?ooo`<00000<`3oool007`0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03L0oooo00@0
00000?ooo`3oool00000>@3oool00`000000oooo0?ooo`0b0?ooo`00O03o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0e0?ooo`D00000<`3o
ool007`0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0=03oool0
10000000oooo0?ooo`00000d0?ooo`00O03oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo03D0oooo00@000000?ooo`3oool00000=P3o
ool010000000oooo0?ooo`00000g0?ooo`030000003oool0000003@0oooo
001l0?ooo`030000003oool0oooo03H0oooo0P00000h0?ooo`800000>03o
ool2000003T0oooo0P00000d0?ooo`00O03oool00`000000oooo0?ooo`3o
0?oooa`0oooo001l0?ooo`030000003oool0oooo0?l0oooo703oool007`0
oooo00<000000?ooo`3oool0o`3ooolL0?ooo`00O03oool00`000000oooo
0?ooo`3o0?oooa`0oooo001l0?ooo`030000003oool0oooo0?l0oooo0P00
00000`3oool000000000000G0?ooo`00O03oool00`00ool0oooo0?ooo`3o
0?ooo`40oooo00<000000?ooo`000000603oool00700oooo2`000003003o
onD0o`000P00o`0A000000X0oooo00<000000?ooo`3oool05`3oool007/0
oooo00<00?l0003oo`00ool00P00oooS0?l000800?l06@3oool200000003
0?ooo`000000000001L0oooo001k0?ooo`800?l01000oooR0?ooo`800?l0
=@3oool007/0oooo0P00o`020?ooo`<00?ooh@3oool2003o03D0oooo001k
0?ooo`800?l00`3oool4003ooml0oooo0P00o`0e0?ooo`00N`3oool2003o
00@0oooo1000oooN0?ooo`800?l0=@3oool007/0oooo0P00o`060?ooo`<0
0?oog@3oool2003o03D0oooo001k0?ooo`800?l01`3oool4003oom/0oooo
0P00o`0e0?ooo`00N`3oool2003o00P0oooo1000oomX0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0I03oool2003o03D0oooo001k
0?ooo`800?l02P3oool3003oofH0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`1S0?ooo`800?l0=@3oool007/0oooo0P00o`0;0?oo
o`@00?oo@`3oool200000080oooo0P0000090?ooo`<000000`3oool00`00
0000oooo0?ooo`04000000@0oooo00<000000?ooo`3oool00P3oool50000
00D0oooo00<000000?ooo`3oool0303oool3000005<0oooo0P00o`0e0?oo
o`00N`3oool2003o00`0oooo1000oom30?ooo`040000003oool0oooo0000
00@0oooo1@0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo1@00
00060?ooo`030000003oool0oooo0580oooo0P00o`0e0?ooo`00N`3oool2
003o00h0oooo0`00oom30?ooo`800000303oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo1P00
001C0?ooo`800?l0=@3oool007/0oooo0P00o`0?0?ooo`@00?oo@@3oool2
000000D0oooo1@0000020?ooo`@000000`3oool5000000@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo1@0000020?ooo`050000003oool0oooo0?ooo`000000E03o
ool2003o03D0oooo001k0?ooo`800?l0403oool4003oocl0oooo00@00000
0?ooo`3oool000002`3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`0:0?oo
o`040000003oool0oooo000005@0oooo0P00o`0e0?ooo`00N`3oool2003o
0180oooo0`00oolm0?ooo`8000000P3oool2000000X0oooo00D000000?oo
o`3oool0oooo000000030?ooo`<000001@3oool00`000000oooo0?ooo`02
0?ooo`D000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
000005@0oooo0P00o`0e0?ooo`00N`3oool2003o01<0oooo1000oom;0?oo
o`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000E03oool2
003o03D0oooo001k0?ooo`800?l0503oool4003oodT0oooo1@00000>0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool20000
05@0oooo0P00o`0e0?ooo`00N`3oool2003o01H0oooo0`00ooo=0?ooo`80
0?l0=@3oool007/0oooo0P00o`0G0?ooo`@00?oob`3oool2003o03D0oooo
001k0?ooo`800?l0603oool4003oolX0oooo0P00o`0e0?ooo`00N`3oool2
003o01X0oooo0`00ooo90?ooo`800?l0=@3oool007/0oooo0P00o`0K0?oo
o`@00?ooa`3oool2003o03D0oooo001k0?ooo`800?l0703oool4003oolH0
oooo0P00o`0e0?ooo`00N`3oool2003o01h0oooo0`00ooo50?ooo`800?l0
=@3oool007/0oooo0P00o`0O0?ooo`@00?oo``3oool2003o03D0oooo001k
0?ooo`800?l0803oool4003ool80oooo0P00o`0e0?ooo`00N`3oool2003o
0280oooo0`00ooo10?ooo`800?l0=@3oool007/0oooo0P00o`0S0?ooo`@0
0?oo_`3oool2003o03D0oooo001k0?ooo`800?l0903oool4003ookh0oooo
0P00o`0e0?ooo`00N`3oool2003o02H0oooo0`00oonm0?ooo`800?l0=@3o
ool007/0oooo0P00o`0W0?ooo`@00?oo^`3oool2003o03D0oooo001k0?oo
o`800?l0:03oool4003ookX0oooo0P00o`0e0?ooo`00N`3oool2003o02X0
oooo0`00ooni0?ooo`800?l0=@3oool007/0oooo0P00o`0[0?ooo`@00?oo
]`3oool2003o03D0oooo001k0?ooo`800?l0;03oool4003ookH0oooo0P00
o`0e0?ooo`00N`3oool2003o02h0oooo0`00oone0?ooo`800?l0=@3oool0
07/0oooo0P00o`0_0?ooo`@00?oo/`3oool2003o03D0oooo001k0?ooo`80
0?l0<03oool4003ook80oooo0P00o`0e0?ooo`00N`3oool2003o0380oooo
1000oon`0?ooo`800?l0=@3oool007/0oooo0P00o`0c0?ooo`@00?oo[`3o
ool2003o03D0oooo001k0?ooo`800?l0=@3oool3003oojh0oooo0P00o`0e
0?ooo`00N`3oool2003o03H0oooo1000oon/0?ooo`800?l0=@3oool007/0
oooo0P00o`0g0?ooo`@00?ooZ`3oool2003o03D0oooo001k0?ooo`800?l0
>@3oool3003oojX0oooo0P00o`0e0?ooo`00N`3oool2003o03X0oooo1000
oonX0?ooo`800?l0=@3oool007/0oooo0P00o`0k0?ooo`@00?ooY`3oool2
003o03D0oooo001k0?ooo`800?l0?@3oool3003oojH0oooo0P00o`0e0?oo
o`00N`3oool2003o03h0oooo1000oonT0?ooo`800?l0=@3oool007/0oooo
0P00o`0o0?ooo`@00?ooX`3oool2003o03D0oooo001k0?ooo`800?l0@@3o
ool3003ooj80oooo0P00o`0e0?ooo`00N`3oool2003o0480oooo1000oonP
0?ooo`800?l0=@3oool007/0oooo0P00o`130?ooo`@00?ooW`3oool2003o
03D0oooo001k0?ooo`800?l0A@3oool3003ooih0oooo0P00o`0e0?ooo`00
N`3oool2003o04H0oooo1000oonL0?ooo`800?l0=@3oool007/0oooo0P00
o`170?ooo`@00?ooV`3oool2003o03D0oooo001c0?ooo`D000000`3oool2
003o04T0oooo0`00oonJ0?ooo`800?l0=@3oool007D0oooo00<000000?oo
o`3oool00`3oool2003o04X0oooo1000oonH0?ooo`800?l0=@3oool007D0
oooo00<000000?ooo`3oool00`3oool2003o00030000003oool0oooo04P0
oooo1000oonG0?ooo`800?l0=@3oool007D0oooo00<000000?ooo`3oool0
0`3oool2003o04d0oooo0`00oonF0?ooo`800?l0=@3oool007D0oooo00<0
00000?ooo`3oool00`3oool2003o04h0oooo1000oonD0?ooo`800?l0=@3o
ool007@0oooo0P0000050?ooo`800?l0C`3oool4003ooi<0oooo0P00o`0e
0?ooo`00N`3oool2003o0540oooo0`00oonB0?ooo`800?l0=@3oool007/0
oooo0P00o`1B0?ooo`@00?ooT03oool2003o03D0oooo001k0?ooo`800?l0
D`3oool4003oohl0oooo0P00o`0e0?ooo`00N`3oool2003o05D0oooo0`00
oon>0?ooo`800?l0=@3oool007/0oooo0P00o`1F0?ooo`@00?ooS03oool2
003o03D0oooo001k0?ooo`800?l0E`3oool4003ooh/0oooo0P00o`0e0?oo
o`00N`3oool2003o05T0oooo0`00oon:0?ooo`800?l0=@3oool007/0oooo
0P00o`1J0?ooo`@00?ooR03oool2003o03D0oooo001k0?ooo`800?l0F`3o
ool4003oohL0oooo0P00o`0e0?ooo`00N`3oool2003o05d0oooo0`00oon6
0?ooo`800?l0=@3oool007/0oooo0P00o`1N0?ooo`@00?ooQ03oool2003o
03D0oooo001k0?ooo`800?l0G`3oool4003ooh<0oooo0P00o`0e0?ooo`00
N`3oool2003o0640oooo0`00oon20?ooo`800?l0=@3oool007/0oooo0P00
o`1R0?ooo`@00?ooP03oool2003o03D0oooo001k0?ooo`800?l0H`3oool4
003oogl0oooo0P00o`0e0?ooo`00N`3oool2003o06D0oooo0`00oomn0?oo
o`800?l0=@3oool007/0oooo0P00o`1V0?ooo`@00?ooO03oool2003o03D0
oooo001k0?ooo`800?l0I`3oool4003oog/0oooo0P00o`0e0?ooo`00N`3o
ool2003o06T0oooo0`00oomj0?ooo`800?l0=@3oool007/0oooo0P00o`1Z
0?ooo`@00?ooN03oool2003o03D0oooo001k0?ooo`800?l0J`3oool4003o
ogL0oooo0P00o`0e0?ooo`00N`3oool2003o06d0oooo0`00ool_0?ooo`@0
00007@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0
oooo0P00o`0e0?ooo`00N`3oool2003o06h0oooo1000ool_0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0G0?ooo`800?l0=@3oool007/0oooo0P00o`1_0?ooo`@00?oo;P3o
ool00`000000oooo0?ooo`0:0?ooo`D0000000<0oooo0000000000001@00
00030?ooo`030000003oool0oooo0080oooo1@0000050?ooo`030000003o
ool0oooo00X0oooo0`0000090?ooo`800?l0=@3oool007/0oooo0P00o`1a
0?ooo`<00?oo;@3oool2000000@0oooo1@0000040?ooo`030000003oool0
oooo0080oooo00D000000?ooo`000000oooo000000040?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo0080oooo1@0000020?ooo`050000003oool0oooo0?ooo`00
0000203oool2003o03D0oooo001k0?ooo`800?l0LP3oool4003oobX0oooo
00<000000?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`050000
003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`060?ooo`800?l0=@3oool007/0oooo0P00o`1c0?ooo`@00?oo
:@3oool010000000oooo0?ooo`0000030?ooo`D00000103oool00`000000
oooo0?ooo`020?ooo`050000003oool000000?ooo`000000103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool5000000H0oooo00<000000?ooo`3oool01P3oool2003o
03D0oooo001k0?ooo`800?l0@03oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo02@0oooo0`00oolW0?ooo`050000003oool0oooo0?oo
o`000000303oool00`000000oooo0?ooo`020?ooo`050000003oool00000
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool02`3oool2000000T0oooo0P00
o`0e0?ooo`00N`3oool2003o0400oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0U0?ooo`@00?oo903oool3000000040?ooo`000000
0000000000/0oooo00@000000?ooo`3oool0oooo0`0000000`3oool00000
0?ooo`040?ooo`030000003oool0oooo0080oooo1@0000050?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool2003o03D0oooo
001k0?ooo`800?l0@03oool00`000000oooo0?ooo`020?ooo`D00000103o
ool00`000000oooo0?ooo`0I0?ooo`<000002P3oool4003oocD0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo00D000000?ooo`3oool0oooo000000080?ooo`800?l0
=@3oool007/0oooo0P00o`100?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00T0oooo
1@00000:0?ooo`050000003oool0oooo0?ooo`0000002`3oool3003ooc80
oooo1@00000=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0303oool3000000T0oooo0P00o`0e0?ooo`00N`3oool2003o0400oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool02P3oool4003oofP0oooo
0P00o`0e0?ooo`00N`3oool2003o0400oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo1@00
000>0?ooo`030000003oool0oooo00/0oooo1000oomW0?ooo`800?l0=@3o
ool007/0oooo0P00o`100?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`0I0?ooo`<00000403o
ool3003oofH0oooo0P00o`0e0?ooo`00N`3oool2003o0400oooo00<00000
0?ooo`3oool00P3oool5000000@0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0A0?ooo`@00?ooI03oool2003o03D0oooo001k0?oo
o`800?l0@03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool04P3oool4003oof<0oooo0P00o`0e0?oo
o`00N`3oool2003o0400oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0I0?ooo`@000004`3oool3003oof80oooo0P00o`0e0?ooo`00
N`3oool2003o0880oooo1000oomP0?ooo`800?l0=@3oool007/0oooo0P00
o`230?ooo`@00?ooG`3oool2003o03D0oooo001k0?ooo`800?l0Q@3oool3
003ooeh0oooo0P00o`0e0?ooo`00N`3oool2003o08H0oooo1000oomL0?oo
o`800?l0=@3oool007/0oooo0P00o`270?ooo`@00?ooF`3oool2003o03D0
oooo001k0?ooo`800?l0R@3oool3003ooeX0oooo0P00o`0e0?ooo`00N`3o
ool2003o08X0oooo1000oomH0?ooo`800?l0=@3oool007/0oooo0P00o`2;
0?ooo`@00?ooE`3oool2003o03D0oooo001k0?ooo`800?l0S@3oool3003o
oeH0oooo0P00o`0e0?ooo`00N`3oool2003o08h0oooo1000oomD0?ooo`80
0?l0=@3oool007/0oooo0P00o`2?0?ooo`@00?ooD`3oool2003o03D0oooo
001k0?ooo`800?l0T@3oool3003ooe80oooo0P00o`0e0?ooo`00N`3oool2
003o0980oooo1000oom@0?ooo`800?l0=@3oool007/0oooo0P00o`2C0?oo
o`@00?ooC`3oool2003o03D0oooo001k0?ooo`800?l0U@3oool3003oodh0
oooo0P00o`0e0?ooo`00L`3oool4000000@0oooo0P00o`2F0?ooo`@00?oo
C03oool2003o03D0oooo001c0?ooo`030000003oool0oooo00D0oooo0P00
o`2G0?ooo`@00?ooB`3oool2003o03D0oooo001d0?ooo`030000003oool0
oooo00@0oooo0P00o`000`000000oooo0?ooo`2F0?ooo`<00?ooBP3oool2
003o03D0oooo001e0?ooo`030000003oool0oooo00<0oooo0P00o`2J0?oo
o`@00?ooB03oool2003o03D0oooo001c0?ooo`040000003oool0oooo0000
00@0oooo0P00o`2K0?ooo`@00?ooA`3oool2003o03D0oooo001d0?ooo`80
00001@3oool2003o09d0oooo0`00oom60?ooo`800?l0=@3oool007/0oooo
0P00o`2N0?ooo`@00?ooA03oool2003o03D0oooo001k0?ooo`800?l0W`3o
ool4003ood<0oooo0P00o`0e0?ooo`00N`3oool2003o0:40oooo0`00oom2
0?ooo`800?l0=@3oool007/0oooo0P00o`2R0?ooo`@00?oo@03oool2003o
03D0oooo001k0?ooo`800?l0X`3oool4003oocl0oooo0P00o`0e0?ooo`00
N`3oool2003o0:D0oooo0`00ooln0?ooo`800?l0=@3oool007/0oooo0P00
o`2V0?ooo`@00?oo?03oool2003o03D0oooo001k0?ooo`800?l0Y`3oool4
003ooc/0oooo0P00o`0e0?ooo`00N`3oool2003o0:T0oooo0`00oolj0?oo
o`800?l0=@3oool007/0oooo0P00o`2Z0?ooo`@00?oo>03oool2003o03D0
oooo001k0?ooo`800?l0Z`3oool4003oocL0oooo0P00o`0e0?ooo`00N`3o
ool2003o0:d0oooo0`00oolf0?ooo`800?l0=@3oool007/0oooo0P00o`2^
0?ooo`@00?oo=03oool2003o03D0oooo001k0?ooo`800?l0[`3oool4003o
oc<0oooo0P00o`0e0?ooo`00N`3oool2003o0;40oooo1000oola0?ooo`80
0?l0=@3oool007/0oooo0P00o`2b0?ooo`@00?oo<03oool2003o03D0oooo
001k0?ooo`800?l0]03oool3003oobl0oooo0P00o`0e0?ooo`00N`3oool2
003o0;D0oooo1000ool]0?ooo`800?l0=@3oool007/0oooo0P00o`2f0?oo
o`@00?oo;03oool2003o03D0oooo001k0?ooo`800?l0^03oool3003oob/0
oooo0P00o`0e0?ooo`00N`3oool2003o0;T0oooo1000oolY0?ooo`800?l0
=@3oool007/0oooo0P00o`2j0?ooo`@00?oo:03oool2003o03D0oooo001k
0?ooo`800?l0_03oool3003oobL0oooo0P00o`0e0?ooo`00N`3oool2003o
0;d0oooo1000oolU0?ooo`800?l0=@3oool007/0oooo0P00o`2n0?ooo`@0
0?oo903oool2003o03D0oooo001k0?ooo`800?l0`03oool3003oob<0oooo
0P00o`0e0?ooo`00N`3oool2003o0<40oooo1000oolQ0?ooo`800?l0=@3o
ool007/0oooo0P00o`320?ooo`@00?oo803oool2003o03D0oooo001k0?oo
o`800?l0a03oool3003ooal0oooo0P00o`0e0?ooo`00N`3oool2003o0<D0
oooo1000oolM0?ooo`800?l0=@3oool007/0oooo0P00o`360?ooo`@00?oo
703oool2003o03D0oooo001k0?ooo`800?l0b03oool3003ooa/0oooo0P00
o`0e0?ooo`00N`3oool2003o0<T0oooo1000oolI0?ooo`800?l0=@3oool0
07/0oooo0P00o`3:0?ooo`@00?oo603oool2003o03D0oooo001k0?ooo`80
0?l0c03oool3003ooaL0oooo0P00o`0e0?ooo`00N`3oool2003o0<d0oooo
1000oolE0?ooo`800?l0=@3oool007/0oooo0P00o`3>0?ooo`@00?oo503o
ool2003o03D0oooo001k0?ooo`800?l0d03oool3003ooa<0oooo0P00o`0e
0?ooo`00N`3oool2003o0=40oooo1000oolA0?ooo`800?l0=@3oool007/0
oooo0P00o`3B0?ooo`@00?oo403oool2003o03D0oooo001k0?ooo`800?l0
e03oool3003oo`l0oooo0P00o`0e0?ooo`00N`3oool2003o0=D0oooo1000
ool30?ooo`03003oo`3oool0oooo00L0oooo0P00o`0e0?ooo`00N`3oool2
003o0=H0oooo1000ool0103oool00?oo003oo`00ool80?ooo`800?l0=@3o
ool007/0oooo0P00o`3H0?ooo`L00?oo1`3oool2003o03D0oooo001k0?oo
o`800?l0f@3oool7003oo`H0oooo0P00o`0e0?ooo`00N`3oool2003o0=T0
oooo2000ool50?ooo`800?l0=@3oool007/0oooo0P00o`3H0?ooo`T00?oo
1@3oool2003o03D0oooo001k0?ooo`800?l0e`3oool;003oo`@0oooo0P00
o`0e0?ooo`00N`3oool2003o0=P0oooo2`00ool30?ooo`800?l0=@3oool0
07/0oooo0P00o`3K0?ooo`T00?oo0P3oool2003o03D0oooo001k0?ooo`80
0?l0g@3oool8003oo`030?ooo`00o`000?l003D0oooo001k0?ooo`800?l0
h03oool6003oo`800?l0=@3oool007@0oooo0P0000050?ooo`800?l0W@3o
ool5000001/0oooo0`0000030?ooo`030000003oool0oooo00<0oooo0`00
00030?ooo`L00000303oool4003oo`80003o=@3oool007<0oooo00@00000
0?ooo`3oool00000103oool2003o09d0oooo00D000000?ooo`3oool0oooo
000000090?ooo`D000003P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool000000140oooo10000?ld0?ooo`00M@3oool00`000000oooo
0?ooo`030?ooo`800?l000<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`0I0?ooo`H0000000<0oooo0000000000000`0000060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`000000403oool60000oc<0oooo
001f0?ooo`030000003oool0oooo0080oooo0P00o`2O0?ooo`030000003o
ool0oooo00T0oooo1@00000:0?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`000000403oool60000oc<0oooo001c0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0V`3oool010000000oooo
0?ooo`00000J0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0103oool2000000D0oooo00<000000?ooo`0000004@3oool40000
oc@0oooo001d0?ooo`8000001P3oool00`000000oooo0?ooo`2K0?ooo`D0
00006P3oool00`000000oooo0000000=0?ooo`030000003oool0oooo00D0
00004P3oool20000ocD0oooo001l0?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`0000002@3oool01@000000oooo0?ooo`3oool000000500
oooo001l0?ooo`030000003oool0oooo0;/0oooo0P00000:0?ooo`<00000
1P3oool00`000000oooo0?ooo`180?ooo`00O03oool00`000000oooo0?oo
o`3o0?oooa`0oooo001l0?ooo`030000003oool0oooo0?l0oooo703oool0
07`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`00O03oool00`000000
oooo0?ooo`3o0?oooa`0oooo001l0?ooo`030000003oool0oooo0?l0oooo
703oool007`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`00O03oool0
0`000000oooo0?ooo`3o0?oooa`0oooo001l0?ooo`030000003oool0oooo
0?l0oooo703oool007`0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`00
O03oool00`000000oooo0?ooo`3o0?oooa`0oooo001l0?ooo`030000003o
ool0oooo0?l0oooo703oool007`0oooo00<000000?ooo`3oool0o`3ooolL
0?ooo`00o`3ooonK0?ooo`00o`3ooonK0?ooo`00o`3ooonK0?ooo`00o`3o
oonK0?ooo`00o`3ooonK0?ooo`00o`3ooonK0?ooo`00o`3ooonK0?ooo`00
o`3ooonK0?ooo`00o`3ooonK0?ooo`00NP3oool200000?l0oooo7`3oool0
07/0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`00O03oool00`000000
oooo0?ooo`3o0?oooa`0oooo001k0?ooo`030000003oool000000?l0oooo
7@3oool007X0oooo00@000000?ooo`3oool00000o`3ooolM0?ooo`00N@3o
ool3000000030?ooo`00000000000?l0oooo703oool00?l0ooooV`3oool0
0?l0ooooV`3oool00?l0ooooV`3oool00?l0ooooV`3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{410, 248},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\tThe numbers  ",
  Cell[BoxData[
      RowBox[{\(Re \((z)\)\), ",", 
        RowBox[{
          RowBox[{"Im", \((z)\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}], "  ", "|", "z", "|"}]}]]],
  "  are the lengths of the sides of the right triangle OPQ shown in Figure \
1.7.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006F0000n2000`400?l0
0000o`00003oo`3ooonG0?ooo`00o`3ooonG0?ooo`00N03oool40000ok80
oooo0`00001U0?ooo`00M`3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo0;00oooo00<000000?ooo`3oool0I03oool007L0oooo1P00
0?nb0?ooo`030000003oool0oooo06@0oooo001/0?ooo`@0003o0`3oool9
0000o`<0oooo2@000?l20?ooo`<0003o1P3oool40000o`030?ooo`000?l0
003o00<0oooo00<0003o0?ooo`3oool02@3oool3000000<0oooo0`000000
103oool000000000003oool2000000D0oooo0`000000103oool000000000
003oool2000000040?ooo`0000000000000000<0oooo1@0000020?ooo`X0
0000103oool300000080oooo0`0000040?ooo`D000001@3oool700000004
0?ooo`00000000000?ooo`D000000`3oool3000000040?ooo`0000000000
0?ooo`<000001P3oool2000000<0oooo0`0000020?ooo`<0000000@0oooo
000000000000oooo0P0000000`3oool000000?ooo`02000000<0oooo0`00
00020?ooo`<0000000@0oooo000000000000oooo0P0000020?ooo`<00000
00@0oooo000000000000oooo0P000000103oool000000000000000030?oo
o`030000003oool0oooo03d0oooo001]0?ooo`80003o1@3oool20000o`03
0?ooo`000?l0oooo00D0oooo0P000?l00`3oool0003o0000o`020?ooo`80
003o0P3oool20000o`80oooo00<0003o0?ooo`3oool0103oool20000o`80
oooo0P000?l30?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`3o
ool00`3oool01P000000oooo0?ooo`000000oooo00000080oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`060000003oool0oooo0000003oool00000
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo0P0000020?ooo`030000003oool0000000<0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo000000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000120?ooo`00K@3oool20000o`D0oooo0P000?l20?ooo`<0003o
0`3oool20000o`030?ooo`000?l0003o0080oooo0P000?l20?ooo`80003o
2@3oool20000o`L0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo
0?ooo`030?ooo`060000003oool0oooo0000003oool00000203oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000103oool2000000@0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0000
00050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool200000480oooo001]0?ooo`80003o00<0oooo0000o`3oool00P3o
ool20000o`040?ooo`000?l0003o0?ooo`80003o0P3oool20000o`030?oo
o`000?l0003o0080oooo0P000?l20?ooo`D0003o1P3oool20000o`P0oooo
00<0003o0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0000003oool0100000050?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
0`0000020?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0P000006
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo000000030?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`0000000`0000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00P0000140?ooo`00K@3oool40000
o`<0oooo0P000?l0103oool0003o0000o`3oool20000o`80oooo0P000?l0
0`3oool0003o0000o`020?ooo`80003o00D0oooo0000o`000?l0003o0?oo
o`020000o`H0oooo0P000?l80?ooo`030000o`3oool0oooo00T0oooo00<0
00000?ooo`3oool00`3oool2000000040?ooo`000000oooo00000080oooo
00<000000?ooo`3oool00`3oool2000000070?ooo`00000000000?ooo`00
0000oooo000000030?ooo`030000003oool000000080oooo0P0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0000
0080oooo0P000000103oool000000?ooo`0000020?ooo`8000001@3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo
0080000000D0oooo000000000000oooo000000020?ooo`8000000P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo0080000000@0oooo
0000003oool000000P3oool00`000000oooo0?ooo`02000000050?ooo`00
0000oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000120?ooo`00
K@3oool20000o`040?ooo`000?l0oooo0?ooo`<0003o0P3oool80000o`04
0?ooo`000?l0003o0?ooo`D0003o00@0oooo0000o`000?l0003o1`3oool2
0000o`P0oooo00<0003o0?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000<0oooo0P0000050?ooo`80000000D0oooo
0000003oool0oooo000000030?ooo`<000000`3oool2000000030?ooo`00
0000oooo0080000000<0oooo0000000000000P3oool010000000oooo0000
000000050?ooo`<000000P3oool3000000@0oooo1@0000050?ooo`800000
0P3oool2000000030?ooo`000000oooo0080oooo0P0000000`3oool00000
0?ooo`030?ooo`80000000@0oooo00000000000000000P3oool3000000D0
oooo0`0000020?ooo`<000000P3oool2000000050?ooo`000000oooo0?oo
o`0000000P3oool2000000030?ooo`000000000000<0oooo0`0000020?oo
o`80000000<0oooo0000003oool00P3oool200000080oooo0P000000103o
ool000000?ooo`3oool300000080oooo0`0000120?ooo`00K@3oool20000
obD0oooo0P000?l80?ooo`030000o`3oool0oooo00T0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`160?ooo`00K@3oool20000o`<0oooo00@0003o0?ooo`00
0?l0003o7P3oool20000o`D0oooo1@000?l70?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000
6P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0AP3oool006`0oooo1`000?l00`3oool0003o0000
o`0M0?ooo`<0003o1@3oool50000o`L0oooo1`0000000`3oool000000000
000N0?ooo`8000001`3oool200000080oooo00<000000?ooo`3oool02P3o
ool3000001T0oooo0P0000050?ooo`030000003oool0oooo08L0oooo003o
0?oooiL0oooo003o0?oooiL0oooo003o0?oooiL0oooo003o0?oooiL0oooo
003o0?oooiL0oooo003o0?oooiL0oooo003o0?oooiL0oooo003o0?oooiL0
oooo003o0?oooiL0oooo003o0?oooiL0oooo00210?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01/0oooo00210?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool20000
00d0oooo00<000000?ooo`3oool0V@3oool3000000`0oooo00<000000?oo
o`3oool02@3oool2000000d0oooo00<000000?ooo`3oool06P3oool00840
oooo00<000000?ooo`3oool0103oool3000000`0oooo00<000000?ooo`3o
ool00`3oool3000000D0oooo00<000000?ooo`3oool0103oool3000000D0
oooo00<000000?ooo`3oool0U`3oool3000000`0oooo00@000000?ooo`3o
ool0oooo0P0000020?ooo`800000103oool00`000000oooo0?ooo`030?oo
o`<000001P3oool00`000000oooo0?ooo`0I0?ooo`00P@3oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool50000
00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000@0oooo0P0000040?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`2F0?ooo`050000003oool0oooo0?ooo`000000
0P3oool5000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000050?ooo`8000000`3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool06@3oool00840oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000X0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo09H0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo00<0oooo
0P00000;0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`0I0?ooo`00P@3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`0000000P3oool5000000@0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000X0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo09H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`D00000103oool00`000000oooo0?oo
o`030?ooo`8000002`3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool06@3oool00840oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000X0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo09H0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool06@3oool00840oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000X0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo09H0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`040000003oool0oooo0?ooo`8000000P3o
ool2000000T0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo01T0oooo00210?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`3oool0oooo0000000<0?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`2G0?ooo`050000003oool0oooo
0?ooo`000000303oool00`000000oooo0?ooo`0?0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`0J0?ooo`00P@3oool0
0`000000oooo0?ooo`040?ooo`<000003P3oool010000000oooo0?ooo`3o
ool3000000`0oooo0`0000030?ooo`030000003oool0oooo09T0oooo0`00
000>0?ooo`030000003oool0oooo00l0oooo0`0000040?ooo`030000003o
ool0oooo01/0oooo00210?ooo`030000003oool0oooo0?l0oooo4`3oool0
0840oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00P@3oool00`000000
oooo0?ooo`3Q0?ooo`030000003oool0oooo02h0oooo00210?ooo`030000
003oool0oooo0>40oooo00<000000?ooo`3oool0;P3oool00840oooo00<0
00000?ooo`3oool0h@3oool00`000000oooo0?ooo`0^0?ooo`00P@3oool0
0`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo02h0oooo00210?oo
o`03003oo`3oool0oooo0>40oooo00<000000?ooo`3oool05P3oool20000
00030?ooo`000000000001<0oooo001`0?oooa0000000`00oooQ0?l00003
003o00000000000001000000203oool00`000000oooo0000000D0?ooo`00
P03oool00`3o00000?oo003oo`02003ooml0o`000P00o`0J0?ooo`030000
003oool0oooo01<0oooo00210?ooo`0300000000ool00?oo00800?oogP3o
ool2003o01P0oooo0P0000000`3oool000000000000C0?ooo`00P@3oool0
0`000000oooo0?ooo`03003oomd0oooo0P00o`0`0?ooo`00P@3oool01000
0000oooo0?ooo`3oool4003oom/0oooo0P00o`0`0?ooo`00P@3oool00`00
0000oooo0?ooo`020?ooo`@00?oofP3oool2003o0300oooo00210?ooo`03
0000003oool0oooo00@0oooo0`00oooI0?ooo`800?l0<03oool00840oooo
00<000000?ooo`3oool01@3oool4003oomL0oooo0P00o`0`0?ooo`00P@3o
ool00`000000oooo0?ooo`060?ooo`@00?ooC`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1I0?ooo`800?l0<03oool00840oooo00<00000
0?ooo`3oool0203oool3003oodh0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0F@3oool2003o0300oooo00210?ooo`030000003oool0oooo
00T0oooo1000oom<0?ooo`040000003oool0oooo0?ooo`<000000`3oool0
0`000000oooo0?ooo`04000000@0oooo00<000000?ooo`3oool00P3oool5
000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1I
0?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool02P3oool4003o
od/0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo05T0oooo0P00o`0`0?ooo`00P@3oool0
0`000000oooo0?ooo`0<0?ooo`<00?ooBP3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1I0?ooo`800?l0<03o
ool00840oooo00<000000?ooo`3oool03@3oool4003oodP0oooo00<00000
0?ooo`3oool00P3oool4000000<0oooo1@0000040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo05T0oooo0P00o`0`0?ooo`00P@3oool00`00
0000oooo0?ooo`0>0?ooo`@00?ooA`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
F@3oool2003o0300oooo00210?ooo`030000003oool0oooo0100oooo0`00
oom60?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000030?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`D00000
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05T0oooo
0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`0A0?ooo`@00?ooA03o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0F@3oool2003o0300oooo00210?ooo`030000003o
ool0oooo0180oooo1000oom30?ooo`040000003oool0oooo0?ooo`D00000
3P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0F@3oool2003o0300oooo00210?ooo`030000003o
ool0oooo01@0oooo0`00ooo90?ooo`800?l0<03oool00840oooo00<00000
0?ooo`3oool05@3oool4003oolL0oooo0P00o`0`0?ooo`00P@3oool00`00
0000oooo0?ooo`0F0?ooo`@00?ooaP3oool2003o0300oooo00210?ooo`03
0000003oool0oooo01P0oooo0`00ooo50?ooo`800?l0<03oool00840oooo
00<000000?ooo`3oool06@3oool4003ool<0oooo0P00o`0`0?ooo`00P@3o
ool00`000000oooo0?ooo`0J0?ooo`@00?oo`P3oool2003o0300oooo0021
0?ooo`030000003oool0oooo01`0oooo0`00ooo10?ooo`800?l0<03oool0
0840oooo00<000000?ooo`3oool07@3oool4003ookl0oooo0P00o`0`0?oo
o`00P@3oool00`000000oooo0?ooo`0N0?ooo`@00?oo_P3oool2003o0300
oooo00210?ooo`030000003oool0oooo0200oooo0`00oonm0?ooo`800?l0
<03oool00840oooo00<000000?ooo`3oool08@3oool4003ook/0oooo0P00
o`0`0?ooo`00P@3oool00`000000oooo0?ooo`0R0?ooo`@00?oo^P3oool2
003o0300oooo00210?ooo`030000003oool0oooo02@0oooo0`00ooni0?oo
o`800?l0<03oool00840oooo00<000000?ooo`3oool09@3oool4003ookL0
oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`0V0?ooo`@00?oo
]P3oool2003o0300oooo00210?ooo`030000003oool0oooo02P0oooo0`00
oone0?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0:@3oool4
003ook<0oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?oo
o`@00?oo/P3oool2003o0300oooo00210?ooo`030000003oool0oooo02`0
oooo0`00oona0?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0
;@3oool4003oojl0oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?oo
o`0^0?ooo`@00?oo[P3oool2003o0300oooo00210?ooo`030000003oool0
oooo0300oooo0`00oon]0?ooo`800?l0<03oool00840oooo00<000000?oo
o`3oool0<@3oool4003ooj/0oooo0P00o`0`0?ooo`00P@3oool00`000000
oooo0?ooo`0b0?ooo`@00?ooZP3oool2003o0300oooo00210?ooo`030000
003oool0oooo03@0oooo0`00oonY0?ooo`800?l0<03oool00840oooo00<0
00000?ooo`3oool0=@3oool4003oojL0oooo0P00o`0`0?ooo`00P@3oool0
0`000000oooo0?ooo`0f0?ooo`@00?ooYP3oool2003o0300oooo00210?oo
o`030000003oool0oooo03P0oooo0`00oonU0?ooo`800?l0<03oool00840
oooo00<000000?ooo`3oool0>@3oool4003ooj<0oooo0P00o`0`0?ooo`00
P@3oool00`000000oooo0?ooo`0j0?ooo`@00?ooXP3oool2003o0300oooo
00210?ooo`030000003oool0oooo03`0oooo0`00oonQ0?ooo`800?l0<03o
ool00840oooo00<000000?ooo`3oool0?@3oool4003ooil0oooo0P00o`0`
0?ooo`00P@3oool00`000000oooo0?ooo`0n0?ooo`@00?ooWP3oool2003o
0300oooo00210?ooo`030000003oool0oooo0400oooo0`00oonM0?ooo`80
0?l0<03oool00840oooo00<000000?ooo`3oool0@@3oool4003ooi/0oooo
0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`120?ooo`@00?ooVP3o
ool2003o0300oooo00210?ooo`030000003oool0oooo04@0oooo0`00oonI
0?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0A@3oool4003o
oiL0oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`160?ooo`@0
0?ooUP3oool2003o0300oooo00210?ooo`030000003oool0oooo04P0oooo
0`00oonE0?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0B@3o
ool4003ooi<0oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`1:
0?ooo`@00?ooTP3oool2003o0300oooo00210?ooo`030000003oool0oooo
04`0oooo0`00oonA0?ooo`800?l0<03oool00840oooo00<000000?ooo`3o
ool0C@3oool4003oohl0oooo0P00o`0`0?ooo`00P@3oool00`000000oooo
0?ooo`1>0?ooo`@00?ooSP3oool2003o0300oooo00210?ooo`030000003o
ool0oooo0500oooo0`00oon=0?ooo`800?l0<03oool00840oooo00<00000
0?ooo`3oool0D@3oool4003ooh/0oooo0P00o`0`0?ooo`00P@3oool00`00
0000oooo0?ooo`1B0?ooo`@00?ooRP3oool2003o0300oooo00210?ooo`03
0000003oool0oooo05@0oooo0`00oon90?ooo`800?l0<03oool00840oooo
00<000000?ooo`3oool0E@3oool4003oohL0oooo0P00o`0`0?ooo`00P@3o
ool00`000000oooo0?ooo`1F0?ooo`@00?ooQP3oool2003o0300oooo0021
0?ooo`030000003oool0oooo05P0oooo0`00oon50?ooo`800?l0<03oool0
0840oooo00<000000?ooo`3oool0F@3oool4003ooh<0oooo0P00o`0`0?oo
o`00P@3oool00`000000oooo0?ooo`1J0?ooo`@00?ooPP3oool2003o0300
oooo00210?ooo`030000003oool0oooo05`0oooo0`00oon10?ooo`800?l0
<03oool00840oooo00<000000?ooo`3oool0G@3oool4003oogl0oooo0P00
o`0`0?ooo`00P@3oool00`000000oooo0?ooo`1N0?ooo`@00?ooOP3oool2
003o0300oooo00210?ooo`030000003oool0oooo0600oooo0`00oomm0?oo
o`800?l0<03oool00840oooo00<000000?ooo`3oool0H@3oool4003oog/0
oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`1R0?ooo`@00?oo
NP3oool2003o0300oooo00210?ooo`030000003oool0oooo06@0oooo0`00
oomi0?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0I@3oool4
003oogL0oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`1V0?oo
o`@00?ooMP3oool2003o0300oooo00210?ooo`030000003oool0oooo06P0
oooo0`00oome0?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0
J@3oool4003oocd0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
203oool2003o0300oooo00210?ooo`030000003oool0oooo06X0oooo1000
ooll0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0P00
o`0`0?ooo`00P@3oool00`000000oooo0?ooo`1/0?ooo`<00?oo>`3oool0
0`000000oooo0?ooo`020?ooo`D0000000<0oooo0000000000001@000003
0?ooo`030000003oool0oooo0080oooo1@0000050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0203oool2003o0300oooo00210?oo
o`030000003oool0oooo06d0oooo0`00oolj0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0
000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`080?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0KP3oool4
003oocP0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`080?ooo`800?l0<03oool00840oooo00<00000
0?ooo`3oool0K`3oool4003oocL0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`800?l0<03o
ool00840oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00X0oooo0`00oolf0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003o
ool0000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
203oool2003o0300oooo00210?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`@00?oo=03o
ool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<00000
00<0oooo0000003oool0103oool00`000000oooo0?ooo`020?ooo`D00000
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo
0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo0080oooo1@0000040?ooo`030000003oool0oooo00`0oooo1000
oolc0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0203oool2003o0300oooo00210?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool03P3oool3003ooc80oooo00<0
00000?ooo`3oool00P3oool5000000d0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo0P00
o`0`0?ooo`00P@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?
0?ooo`@00?ooIP3oool2003o0300oooo00210?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0100oooo1000oomU0?ooo`800?l0<03oool00840
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool04P3oool3003o
of@0oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0080oooo1@0000040?ooo`030000003oool0oooo01<0
oooo1000oomR0?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo
1000oomQ0?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo0`00
oomP0?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0OP3oool4
003ooeh0oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`1o0?oo
o`@00?ooG@3oool2003o0300oooo00210?ooo`030000003oool0oooo0840
oooo0`00oomL0?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0
PP3oool4003ooeX0oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?oo
o`230?ooo`@00?ooF@3oool2003o0300oooo00210?ooo`030000003oool0
oooo08D0oooo0`00oomH0?ooo`800?l0<03oool00840oooo00<000000?oo
o`3oool0QP3oool4003ooeH0oooo0P00o`0`0?ooo`00P@3oool00`000000
oooo0?ooo`270?ooo`@00?ooE@3oool2003o0300oooo00210?ooo`030000
003oool0oooo08T0oooo0`00oomD0?ooo`800?l0<03oool00840oooo00<0
00000?ooo`3oool0RP3oool4003ooe80oooo0P00o`0`0?ooo`00P@3oool0
0`000000oooo0?ooo`2;0?ooo`@00?ooD@3oool2003o0300oooo00210?oo
o`030000003oool0oooo08d0oooo0`00oom@0?ooo`800?l0<03oool00840
oooo00<000000?ooo`3oool0SP3oool4003oodh0oooo0P00o`0`0?ooo`00
P@3oool00`000000oooo0?ooo`2?0?ooo`@00?ooC@3oool2003o0300oooo
00210?ooo`030000003oool0oooo0940oooo0`00oom<0?ooo`800?l0<03o
ool00840oooo00<000000?ooo`3oool0TP3oool4003oodX0oooo0P00o`0`
0?ooo`00P@3oool00`000000oooo0?ooo`2C0?ooo`@00?ooB@3oool2003o
0300oooo00210?ooo`030000003oool0oooo09D0oooo0`00oom80?ooo`80
0?l0<03oool00840oooo00<000000?ooo`3oool0UP3oool4003oodH0oooo
0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`2G0?ooo`@00?ooA@3o
ool2003o0300oooo00210?ooo`030000003oool0oooo09T0oooo0`00oom4
0?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0VP3oool4003o
od80oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`2K0?ooo`@0
0?oo@@3oool2003o0300oooo00210?ooo`030000003oool0oooo09d0oooo
0`00oom00?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0WP3o
ool4003ooch0oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`2O
0?ooo`@00?oo?@3oool2003o0300oooo00210?ooo`030000003oool0oooo
0:40oooo0`00ooll0?ooo`800?l0<03oool00840oooo00<000000?ooo`3o
ool0XP3oool4003oocX0oooo0P00o`0`0?ooo`00P@3oool00`000000oooo
0?ooo`2S0?ooo`@00?oo>@3oool2003o0300oooo00210?ooo`030000003o
ool0oooo0:D0oooo0`00oolh0?ooo`800?l0<03oool00840oooo00<00000
0?ooo`3oool0YP3oool4003oocH0oooo0P00o`0`0?ooo`00P@3oool00`00
0000oooo0?ooo`2W0?ooo`@00?oo=@3oool2003o0300oooo00210?ooo`03
0000003oool0oooo0:T0oooo0`00oold0?ooo`800?l0<03oool00840oooo
00<000000?ooo`3oool0ZP3oool4003ooc80oooo0P00o`0`0?ooo`00P@3o
ool00`000000oooo0?ooo`2[0?ooo`@00?oo<@3oool2003o0300oooo0021
0?ooo`030000003oool0oooo0:d0oooo0`00ool`0?ooo`800?l0<03oool0
0840oooo00<000000?ooo`3oool0[P3oool4003oobh0oooo0P00o`0`0?oo
o`00P@3oool00`000000oooo0?ooo`2_0?ooo`@00?oo;@3oool2003o0300
oooo00210?ooo`030000003oool0oooo0;40oooo0`00ool/0?ooo`800?l0
<03oool00840oooo00<000000?ooo`3oool0/P3oool4003oobX0oooo0P00
o`0`0?ooo`00P@3oool00`000000oooo0?ooo`2c0?ooo`@00?oo:@3oool2
003o0300oooo00210?ooo`030000003oool0oooo0;D0oooo0`00oolX0?oo
o`800?l0<03oool00840oooo00<000000?ooo`3oool0]P3oool4003oobH0
oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`2g0?ooo`@00?oo
9@3oool2003o0300oooo00210?ooo`030000003oool0oooo0;T0oooo0`00
oolT0?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0^P3oool4
003oob80oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`2k0?oo
o`@00?oo8@3oool2003o0300oooo00210?ooo`030000003oool0oooo0;d0
oooo0`00oolP0?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0
_P3oool4003ooah0oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?oo
o`2o0?ooo`@00?oo7@3oool2003o0300oooo00210?ooo`030000003oool0
oooo0<40oooo0`00oolL0?ooo`800?l0<03oool00840oooo00<000000?oo
o`3oool0`P3oool4003ooaX0oooo0P00o`0`0?ooo`00P@3oool00`000000
oooo0?ooo`330?ooo`@00?oo6@3oool2003o0300oooo00210?ooo`030000
003oool0oooo0<D0oooo0`00oolH0?ooo`800?l0<03oool00840oooo00<0
00000?ooo`3oool0aP3oool4003ooaH0oooo0P00o`0`0?ooo`00P@3oool0
0`000000oooo0?ooo`370?ooo`@00?oo5@3oool2003o0300oooo00210?oo
o`030000003oool0oooo0<T0oooo0`00oolD0?ooo`800?l0<03oool00840
oooo00<000000?ooo`3oool0bP3oool4003ooa80oooo0P00o`0`0?ooo`00
P@3oool00`000000oooo0?ooo`3;0?ooo`@00?oo4@3oool2003o0300oooo
00210?ooo`030000003oool0oooo0<d0oooo0`00ool60?ooo`03003oo`3o
ool0oooo00L0oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`3>
0?ooo`@00?oo103oool00`00ool0oooo0?ooo`070?ooo`800?l0<03oool0
0840oooo00<000000?ooo`3oool0c`3oool4003oo`80oooo0`00ool80?oo
o`800?l0<03oool00840oooo00<000000?ooo`3oool0d@3oool8003oo`L0
oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`3B0?ooo`P00?oo
1P3oool2003o0300oooo00210?ooo`030000003oool0oooo0=<0oooo1`00
ool60?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0dP3oool9
003oo`D0oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?ooo`3A0?oo
o`/00?oo103oool2003o0300oooo00210?ooo`030000003oool0oooo0=80
oooo2P00ool40?ooo`800?l0<03oool00840oooo00<000000?ooo`3oool0
e03oool9003oo`<0oooo0P00o`0`0?ooo`00P@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool4000000<0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00<0oooo100000030?ooo`030000003o
ool0oooo01D0oooo1`00ool20?ooo`800?l0<03oool00840oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`8000001P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo07l0oooo00<00000
0?ooo`3oool02P3oool2000000H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0F0?ooo`H00?oo00<0oooo0000o`000?l0<03oool0
0840oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?oo
o`<000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0K@3oool3000000d0oooo00@000000?oo
o`3oool0oooo0P0000020?ooo`8000001@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool5
000000X0oooo0`00ool40000obl0oooo001k0?ooo``000001@3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool2
000000D0oooo0P0000050?ooo`030000003oool0oooo06h0oooo00<00000
0?ooo`3oool00`3oool5000000@0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000060?ooo`8000001@3oool2000000D0oooo00<0
00000?ooo`3oool00P3oool500000080oooo00D000000?ooo`3oool0oooo
0000000<0?ooo`H0003o;P3oool00840oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
2P3oool00`000000oooo000000050?ooo`030000003oool0oooo06h0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`800000
3@3oool00`000000oooo000000050?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool03@3oool60000obh0oooo00210?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000X0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`1^0?ooo`<000000`3oool5000000@0oooo00<000000?ooo`3o
ool00`3oool2000000d0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`020?ooo`D00000103oool00`000000oooo0?ooo`0=0?oo
o`@0003o;`3oool00840oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0KP3oool0
10000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000002`3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000?0?oo
o`80003o<03oool00840oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000203oool30000
00040?ooo`0000000000000000<0oooo00<000000?ooo`3oool0KP3oool0
10000000oooo0?ooo`00000;0?ooo`040000003oool0oooo0?ooo`800000
0P3oool2000000T0oooo0`000000103oool000000000000000030?ooo`03
0000003oool0oooo00T0oooo1@0000100?ooo`00P@3oool00`000000oooo
0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo06l0oooo00@000000?ooo`3o
ool00000303oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
04l0oooo00210?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3o
ool0oooo0`00000A0?ooo`030000003oool0oooo06l0oooo1000000>0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0D03oool00840
oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00P@3oool00`000000oooo
0?ooo`3o0?oooa<0oooo00210?ooo`030000003oool0oooo0?l0oooo4`3o
ool00840oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00P@3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo00210?ooo`030000003oool0oooo0?l0
oooo4`3oool00840oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00P@3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo00210?ooo`030000003oool0
oooo0?l0oooo4`3oool00840oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`00P@3oool00`000000oooo0?ooo`3o0?oooa<0oooo003o0?oooiL0oooo
003o0?oooiL0oooo003o0?oooiL0oooo003o0?oooiL0oooo003o0?oooiL0
oooo003o0?oooiL0oooo003o0?oooiL0oooo003o0?oooiL0oooo003o0?oo
oiL0oooo001o0?ooo`800000o`3ooolF0?ooo`00P03oool00`000000oooo
0?ooo`3o0?oooa@0oooo00210?ooo`030000003oool0oooo0?l0oooo4`3o
ool00800oooo00<000000?ooo`000000o`3ooolD0?ooo`00O`3oool01000
0000oooo0?ooo`00003o0?oooa@0oooo001n0?ooo`<0000000<0oooo0000
00000000o`3ooolC0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3o
oonG0?ooo`00o`3ooonG0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{406, 248},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\tThe inequality ",
  Cell[BoxData[
      \(\(\(|\)\(z\_1\)\(|\)\(\(<\)\(\(|\)\(z\_2\)\(|\)\)\)\)\)]],
  " means that the point ",
  Cell[BoxData[
      \(z\_1\)]],
  " is closer to the origin than the point ",
  Cell[BoxData[
      \(z\_2\)]],
  ".  Although obvious from Figure 1.7, it is still profitable to work out \
algebraically the standard results that\t\n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(x\)\(|\)\) = \(\(|\)\(Re \
\((z)\)\)\(|\)\(\(\[LessEqual]\)\(\(|\)\(z\)\(|\)\)\)\)\)]],
  " and  ",
  Cell[BoxData[
      \(\(\(|\)\(y\)\(|\)\) = \(\(|\)\(Im \
\((z)\)\)\(|\)\(\(\[LessEqual]\)\(\(|\)\(z\)\(|\)\)\)\)\)]],
  ".\n\t\t\t\nwhich we leave as an exercise for the reader. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe difference ",
  Cell[BoxData[
      \(z\_1\  - z\_2\)]],
  " represents the displacement vector from ",
  Cell[BoxData[
      \(z\_2\)]],
  " to ",
  Cell[BoxData[
      \(z\_1\)]],
  ", so the distance between ",
  Cell[BoxData[
      \(z\_1\)]],
  " and ",
  Cell[BoxData[
      \(z\_2\)]],
  " is given by",
  Cell[BoxData[
      \(\(\(|\)\(z\_1\  - z\_2\)\(|\)\)\)]],
  ".  We can obtain this distance by using Definitions (1.2) and (1-3) to \
obtain the familiar formula \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["dist",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \((z\_1, z\_2)\)}], 
        "=", \(\(|\)\(z\_2 - z\_1\)\(|\)\)}]]],
  Cell[BoxData[
      \(\(\(=\)\(\@\(\((x\_1 - x\_2)\)\^2 + \((y\_1 - y\_2)\)\^2\)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tIf  ",
  Cell[BoxData[
      \(z = \(\((x, y)\) = x + \[ImaginaryI]\ y\)\)]],
  ",  then  ",
  Cell[BoxData[
      \(\(-z\) = \(\((\(-x\), \(-y\))\) = \(-x\) - \[ImaginaryI]\ y\)\)]],
  "  is the reflection of ",
  Cell[BoxData[
      \(z\)]],
  ", through the origin, and  ",
  Cell[BoxData[
      \(\(\(z\)\(\ \)\)\&_ = \(\((x, \(-y\))\) = x - \[ImaginaryI]\ y\)\)]],
  "  is the reflection of ",
  Cell[BoxData[
      \(z\)]],
  " through the ",
  Cell[BoxData[
      \(x\)]],
  " axis, as illustrated in Figure 1.8."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000aB000`400?l0
0000o`00003oo`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
N03oool40000ocl0oooo0`00000R0?ooo`8000008@3oool300000400oooo
0P0000090?ooo`<00000G03oool007L0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0k0?ooo`050000003oool0oooo0?ooo`000000
8`3oool00`000000oooo0?ooo`0M0?ooo`050000003oool0oooo0?ooo`00
0000@@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?oo
o`000000F`3oool007L0oooo1P000?lm0?ooo`050000003oool0oooo0?oo
o`000000903oool00`000000oooo0?ooo`0L0?ooo`050000003oool0oooo
0?ooo`000000@@3oool00`000000oooo0?ooo`050?ooo`050000003oool0
oooo0?ooo`000000F`3oool006`0oooo10000?l30?ooo`T0003o0`3oool9
0000o`80oooo0`000?l60?ooo`@0003o00<0oooo0000o`000?l00P3oool3
0000o`L0oooo0`0000030?ooo`<0000000@0oooo000000000000oooo0P00
00060?ooo`<000000P3oool2000000<0oooo0`0000020?ooo`<0000000@0
oooo000000000000oooo0P0000000`3oool00000000000030?ooo`800000
00@0oooo0000000000000000103oool00`000000oooo0?ooo`050?ooo`<0
00000P3oool3000000@0oooo0`000000103oool000000000003oool20000
00<0oooo0`0000020?ooo`@0000000@0oooo000000000000oooo0`000000
103oool000000000000000020?ooo`<0000000<0oooo000000000000103o
ool7000000040?ooo`00000000000?ooo`D00000103oool2000000<0oooo
0`0000020?ooo`<0000000D0oooo000000000000oooo000000030?ooo`@0
000000@0oooo00000000000000000P3oool4000000040?ooo`0000000000
0?ooo`<0000000@0oooo00000000000000000P3oool3000000050?ooo`00
000000000?ooo`000000@@3oool006d0oooo0P000?l50?ooo`80003o00<0
oooo0000o`3oool01@3oool20000o`030?ooo`000?l0003o0080oooo0P00
0?l20?ooo`80003o0P3oool00`000?l0oooo0?ooo`040?ooo`80003o0P3o
ool20000o`040?ooo`000?l0003o0?ooo`80003o1`3oool00`000000oooo
0?ooo`030?ooo`060000003oool0oooo0000003oool000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`040000003oool0oooo00000080oooo
00H000000?ooo`3oool000000?ooo`0000020?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000005
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`040?ooo`060000003oool0oooo0000003oool000000P3oool00`000000
oooo000000040?ooo`040000003oool0oooo00000080oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
oooo0080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000000@0oooo00@000000?ooo`3oool00000
0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0480oooo001]0?oo
o`80003o1@3oool20000o`80oooo0`000?l30?ooo`80003o00<0oooo0000
o`000?l00P3oool20000o`80oooo0P000?l90?ooo`80003o1@3oool20000
o`030?ooo`000?l0003o00L0oooo00<000000?ooo`3oool00`3oool01P00
0000oooo0?ooo`000000oooo000000P0oooo0P0000020?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`0000001@3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000001@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool0
1P000000oooo0?ooo`000000oooo000000D0oooo0P0000020?ooo`040000
003oool0oooo00000080oooo00L000000?ooo`3oool0oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo008000000P3oool010000000oooo0?ooo`0000020?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0@P3oool006d0oooo0P000?l0
0`3oool0003o0?ooo`020?ooo`80003o00@0oooo0000o`000?l0oooo0P00
0?l20?ooo`80003o00<0oooo0000o`000?l00P3oool20000o`80oooo1@00
0?l60?ooo`80003o1@3oool20000o`030?ooo`000?l0003o00L0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`000000oooo00@00000
103oool01@000000oooo0?ooo`000000oooo00@0000000<0oooo0000003o
ool00P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0000003oool0100000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0000
003oool0100000001@3oool000000?ooo`3oool000000080oooo0`000002
0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool300000080
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool00`0000020?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0@P3o
ool006d0oooo10000?l30?ooo`80003o00@0oooo0000o`000?l0oooo0P00
0?l20?ooo`80003o00<0oooo0000o`000?l00P3oool20000o`050?ooo`00
0?l0003o0000o`3oool00P000?l60?ooo`80003o1P3oool30000o`P0oooo
00<000000?ooo`3oool00`3oool2000000040?ooo`000000oooo00000080
oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`02
000000070?ooo`00000000000?ooo`000000oooo000000020?ooo`040000
003oool0oooo000000<0oooo0P0000020?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0103oool2000000040?ooo`000000oooo00000080oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000020?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`02000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool0
00000P3oool2000000040?ooo`000000oooo00000080oooo0P0000040?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?oo
o`02000000050?ooo`000000oooo0?ooo`0000000P3oool01P000000oooo
0?ooo`000000oooo00000080oooo00<000000?ooo`0000000P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool00P0000000`3oool000000?ooo`130?ooo`00K@3oool20000
o`040?ooo`000?l0oooo0?ooo`<0003o0P3oool80000o`040?ooo`000?l0
003o0?ooo`D0003o00@0oooo0000o`000?l0003o1`3oool20000o`D0oooo
0P000?l00`3oool0003o0000o`070?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`0000000`3oool2000000H0oooo100000000`3oool00000
000000030?ooo`<000000P3oool2000000050?ooo`000000oooo0?ooo`00
00000`3oool200000080oooo0`000000103oool000000000003oool40000
00040?ooo`0000000000000000@0oooo0`0000020?ooo`<00000103oool2
000000030?ooo`000000oooo0080oooo0P0000030?ooo`@0000000<0oooo
0000000000000P3oool3000000030?ooo`00000000000080oooo0`000002
0?ooo`80000000<0oooo0000003oool01@3oool200000080oooo0P000000
0`3oool000000?ooo`020?ooo`80000000<0oooo0000003oool0103oool3
00000080oooo0`0000020?ooo`80000000@0oooo0000003oool0oooo0P00
0000103oool000000000003oool200000080oooo100000000`3oool00000
000000020?ooo`<0000000<0oooo0000000000000P3oool300000080oooo
0P0000000`3oool000000?ooo`140?ooo`00K@3oool20000obD0oooo0P00
0?l50?ooo`80003o00<0oooo0000o`000?l01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`1B0?ooo`00K@3oool2
0000o`<0oooo00@0003o0?ooo`000?l0003o7P3oool20000o`D0oooo0P00
0?l00`3oool0003o0000o`040?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000:`3oool00`000000oooo0?ooo`0E0?ooo`04
0000003oool0oooo000001P0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0580oooo001/0?ooo`L0
003o00<0oooo0000o`000?l07@3oool30000o`H0oooo0`000?l50?ooo`L0
000000<0oooo000000000000A03oool3000001`0oooo00<000000?ooo`3o
ool0703oool2000001H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`1>0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
m@3oool00`000000oooo0?ooo`1_0?ooo`@00000A@3oool00:00oooo1000
001A0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0A03o
ool00:80oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1;
0?ooo`D00000203oool200000080oooo0P00000:0?ooo`L000000P3oool0
0`000000oooo0?ooo`140?ooo`00M@3oool500000100oooo0P0000020?oo
o`8000002@3oool700000080oooo00<000000?ooo`3oool0D03oool00`00
0000oooo0?ooo`1<0?ooo`040000003oool0oooo00000080oooo1@000002
0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`000000103o
ool2000004D0oooo001e0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool5000000X0oooo00@000000?ooo`3oool00000303oool00`000000oooo
000000040?ooo`800000D@3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo00X0oooo0P0000050?ooo`D00000103oool00`000000oooo
000000030?ooo`030000003oool0000004D0oooo001^0?ooo`D000000`3o
ool00`000000oooo0?ooo`0;0?ooo`D000000`3oool2000000@0oooo1@00
00040?ooo`030000003oool0000000<0oooo00<000000?ooo`000000D@3o
ool00`000000oooo0?ooo`1>0?ooo`040000003oool0oooo0?ooo`D00000
0`3oool2000000h0oooo00<000000?ooo`0000000`3oool010000000oooo
0?ooo`0000140?ooo`00M`3oool00`000000oooo0?ooo`020?ooo`D00000
2`3oool2000000d0oooo00<000000?ooo`0000000`3oool010000000oooo
0?ooo`00001@0?ooo`030000003oool0oooo04`0oooo00@000000?ooo`3o
ool000002@3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0
00000080oooo00D000000?ooo`3oool0oooo000000140?ooo`00M@3oool0
10000000oooo0?ooo`00000B0?ooo`040000003oool0oooo000000`0oooo
00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000500
oooo00<000000?ooo`3oool0C03oool5000000L0oooo0P0000020?ooo`80
00002P3oool5000000050?ooo`00000000000000003oool00`0000130?oo
o`00M@3oool500000100oooo0P0000020?ooo`8000002@3oool500000005
0?ooo`00000000000000003oool00`00001?0?ooo`030000003oool0oooo
0;P0oooo003e0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3o
ool0BP3oool009`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`2h0?ooo`00m@3oool00`000000oooo0?ooo`1;0?ooo`D00000J03o
ool00?D0oooo00<000000?ooo`3oool0^03oool00?D0oooo00<000000?oo
o`3oool0G@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo100000030?ooo`030000003oool0oooo03P0oooo003e0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`3oool02P3oool2000000d0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0g0?ooo`00
R03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo
100000040?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
B`3oool5000000/0oooo00<000000?ooo`3oool00P3oool200000080oooo
0P0000040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0f0?ooo`00Q`3oool00`000000oooo0?oo
o`0@0?ooo`8000003@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0C03oool010000000oooo0?oo
o`0000020?ooo`D00000103oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000D0oooo0P00000<0?ooo`8000001@3oool00`000000
oooo0?ooo`0f0?ooo`00M@3oool5000000`0oooo00<000000?ooo`3oool0
203oool200000080oooo0P0000040?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`040?ooo`8000002`3oool5000000<0oooo00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`0f0?ooo`00M@3oool01@000000oooo0?oo
o`3oool000000080oooo1@0000050?ooo`030000003oool0oooo00T0oooo
00@000000?ooo`3oool000001@3oool2000000`0oooo0P0000060?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0CP3oool010000000
oooo0?ooo`3oool5000000@0oooo00<000000?ooo`3oool0103oool20000
01<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0f
0?ooo`00KP3oool5000000<0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`020?ooo`D000000`3oool2000000/0oooo1@0000030?oo
o`030000003oool0000000H0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`1<0?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`00000A0?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0f0?ooo`00M`3o
ool00`000000oooo0?ooo`020?ooo`D000001@3oool00`000000oooo0?oo
o`0:0?ooo`8000004`3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0C03oool5000000X0oooo
00<000000?ooo`3oool00P3oool200000080oooo0P00000?0?ooo`<00000
00@0oooo00000000000000000`3oool00`000000oooo0?ooo`0f0?ooo`00
M@3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00T0
oooo00@000000?ooo`3oool000004@3oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1L
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=`3oool0
07D0oooo1@00000<0?ooo`030000003oool0oooo00P0oooo0P0000020?oo
o`8000003`3oool3000000040?ooo`0000000000000000@0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0>03oool008L0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0180oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0^03oool008P0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0B`3oool5000006P0oooo003=0?ooo`030000
003oool0oooo00<0oooo0P0000040?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0;P0oooo003=0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`3oool4000000<0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0;P0oooo00260?ooo`@00?l0@`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`L00000I`3oool40000
od`0oooo00270?ooo`T00?l0?@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000d0oooo0`0000000`3oool00000000000030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0HP3oool90000
odd0oooo00280?ooo``00?l0>P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo05h0oooo30000?m>0?ooo`00RP3oool9003o03`0
oooo00@000000?ooo`3oool0oooo0P00000E0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0GP3oool:0000oe00oooo002;0?ooo`P0
0?l0HP3oool00`000000oooo0?ooo`1O0?ooo`P0003oD@3oool008`0oooo
1`00o`1R0?ooo`030000003oool0oooo05l0oooo1`000?mB0?ooo`00S@3o
ool5003o00030?ooo`00o`000?l00600oooo00<000000?ooo`3oool0G@3o
ool20000o`030?ooo`000?l0003o00<0003oD`3oool008l0oooo0P00o`04
0?ooo`800?l0GP3oool00`000000oooo0?ooo`1K0?ooo`80003o0`3oool3
0000oeD0oooo002@0?ooo`03003o003oool0oooo00@0oooo0P00o`1L0?oo
o`030000003oool0oooo05T0oooo0P000?l60?ooo`030000o`3oool0oooo
05@0oooo002I0?ooo`<00?l0F@3oool00`000000oooo0?ooo`1G0?ooo`80
003oG`3oool009`0oooo0P00o`1G0?ooo`030000003oool0oooo05@0oooo
0`000?mQ0?ooo`00WP3oool2003o05D0oooo00<000000?ooo`3oool0DP3o
ool20000of@0oooo002P0?ooo`800?l0D`3oool00`000000oooo0?ooo`1@
0?ooo`80003oIP3oool00:80oooo0P00o`1A0?ooo`030000003oool0oooo
04h0oooo0P000?mX0?ooo`00Y03oool3003o04h0oooo00<000000?ooo`3o
ool0C03oool20000ofX0oooo002W0?ooo`800?l0C03oool00`000000oooo
0?ooo`190?ooo`<0003oK03oool00:T0oooo0P00o`1:0?ooo`030000003o
ool0oooo04L0oooo0P000?m_0?ooo`00Z`3oool2003o04P0oooo00<00000
0?ooo`3oool0A@3oool20000og40oooo002]0?ooo`<00?l0A@3oool00`00
0000oooo0?ooo`130?ooo`80003oL`3oool00;00oooo0P00o`130?ooo`03
0000003oool0oooo0440oooo0P000?me0?ooo`00/P3oool2003o0440oooo
00<000000?ooo`3oool0?P3oool30000ogL0oooo002d0?ooo`800?l0?`3o
ool00`000000oooo0?ooo`0l0?ooo`80003oNP3oool00;H0oooo0P00o`0m
0?ooo`030000003oool0oooo03X0oooo0P000?ml0?ooo`00^03oool3003o
03X0oooo00<000000?ooo`3oool0>03oool20000ogh0oooo002k0?ooo`80
0?l0>03oool00`000000oooo0?ooo`0f0?ooo`80003oP03oool00;d0oooo
0P00o`0f0?ooo`030000003oool0oooo03<0oooo0`000?n20?ooo`00_`3o
ool2003o03@0oooo00<000000?ooo`3oool0<@3oool20000ohD0oooo0031
0?ooo`<00?l0<@3oool00`000000oooo0?ooo`0_0?ooo`80003oQ`3oool0
0<@0oooo0P00o`0_0?ooo`030000003oool0oooo02d0oooo0P000?n90?oo
o`00aP3oool2003o02d0oooo00<000000?ooo`3oool0:`3oool20000oh/0
oooo00380?ooo`800?l0:`3oool00`000000oooo0?ooo`0X0?ooo`<0003o
S@3oool00<X0oooo0P00o`0Y0?ooo`030000003oool0oooo02H0oooo0P00
0?n@0?ooo`00c03oool3003o02H0oooo00<000000?ooo`3oool0903oool2
0000oi80oooo003?0?ooo`800?l0903oool00`000000oooo0?ooo`0R0?oo
o`80003oU03oool00=40oooo0P00o`0R0?ooo`030000003oool0oooo0200
oooo0P000?nF0?ooo`00d`3oool2003o0200oooo00<000000?ooo`3oool0
7@3oool30000oiP0oooo003E0?ooo`<00?l07@3oool00`000000oooo0?oo
o`0K0?ooo`80003oV`3oool007P0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`120?ooo`800?l06`3oool00`000000oooo0?ooo`0I
0?ooo`80003oA@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0400oooo001g0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`130?ooo`800?l06@3oool00`00
0000oooo0?ooo`0G0?ooo`80003oAP3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?`3oool007H0
oooo00<000000?ooo`3oool01`3oool2000000030?ooo`000000000000<0
oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3o
ool0A03oool2003o01L0oooo00<000000?ooo`3oool05@3oool20000odL0
oooo00@000000?ooo`3oool0oooo0P0000000`3oool00000000000030?oo
o`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo
03h0oooo001f0?ooo`030000003oool0oooo0080oooo100000020?ooo`03
0000003oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0AP3oool2003o
01D0oooo00<000000?ooo`3oool04P3oool30000odT0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000050?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo03h0oooo001f0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo04P0oooo0`00o`0B0?ooo`030000003oool0oooo0100oooo0P000?m<
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo03h0oooo001f
0?ooo`030000003oool0oooo00L0oooo0P0000000`3oool0000000000008
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0B`3o
ool2003o0100oooo00<000000?ooo`3oool03P3oool20000odh0oooo00@0
00000?ooo`3oool0oooo0P0000000`3oool00000000000080?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0?P3oool007L0oooo
00<000000?ooo`3oool04`3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo04h0oooo0P00o`0>0?ooo`030000003oool0oooo00`0
oooo0P000?mA0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0o0?ooo`00N03oool00`000000
oooo0?ooo`0C0?ooo`8000000`3oool00`000000oooo0?ooo`1A0?ooo`80
0?l0303oool00`000000oooo0?ooo`0:0?ooo`80003oE03oool00`000000
oooo0?ooo`0=0?ooo`8000000`3oool00`000000oooo0?ooo`100?ooo`00
j@3oool3003o00T0oooo00<000000?ooo`3oool01`3oool30000ojh0oooo
003/0?ooo`800?l01`3oool00`000000oooo0?ooo`050?ooo`80003o/@3o
ool00>h0oooo0P00o`050?ooo`030000003oool0oooo00<0oooo0P000?nc
0?ooo`00QP3oool00`000000oooo0?ooo`1W0?ooo`800?l00`3oool01000
0000oooo0?ooo`3oool20000ofP0oooo00<000000?ooo`3oool05P3oool2
000000030?ooo`000000000002l0oooo00260?ooo`030000003oool0oooo
06T0oooo0P00o`000`3oool000000?ooo`020000ofX0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0000000`0?ooo`00M@3ooomo00000003
003o00000?l0003o07h000002@3oool00`000000oooo0?ooo`0_0?ooo`00
QP3oool00`000000oooo0?ooo`1/0?ooo`040000003oool0o`000?l006X0
oooo00<000000?ooo`3oool05P3oool2000000030?ooo`000000000002l0
oooo00260?ooo`030000003oool0oooo06`0oooo00@000000?ooo`3oool0
oooo0P3o001X0?ooo`030000003oool0oooo04X0oooo00260?ooo`030000
003oool0oooo06`0oooo00<000000?ooo`3oool00`3oool20?l006H0oooo
00<000000?ooo`3oool0BP3oool00?D0oooo00<000000?ooo`3oool01@3o
ool20?l00;40oooo003e0?ooo`030000003oool0oooo00L0oooo0`3o002^
0?ooo`00m@3oool00`000000oooo0?ooo`0:0?ooo`80o`00[03oool00?D0
oooo00<000000?ooo`3oool0303oool20?l00:X0oooo003e0?ooo`030000
003oool0oooo00h0oooo0P3o002X0?ooo`00m@3oool00`000000oooo0?oo
o`0@0?ooo`80o`00YP3oool00?D0oooo00<000000?ooo`3oool04P3oool3
0?l00:<0oooo003e0?ooo`030000003oool0oooo01D0oooo0P3o002Q0?oo
o`00m@3oool00`000000oooo0?ooo`0G0?ooo`80o`00W`3oool00?D0oooo
00<000000?ooo`3oool06@3oool20?l009d0oooo003e0?ooo`030000003o
ool0oooo01/0oooo0P3o002K0?ooo`00m@3oool00`000000oooo0?ooo`0M
0?ooo`<0o`00V03oool00?D0oooo00<000000?ooo`3oool0803oool20?l0
09H0oooo003e0?ooo`030000003oool0oooo0280oooo0P3o002D0?ooo`00
m@3oool00`000000oooo0?ooo`0T0?ooo`80o`00TP3oool00?D0oooo00<0
00000?ooo`3oool09P3oool20?l00900oooo003e0?ooo`030000003oool0
oooo02P0oooo0`3o002=0?ooo`00m@3oool00`000000oooo0?ooo`0[0?oo
o`80o`00R`3oool00?D0oooo00<000000?ooo`3oool0;@3oool20?l008T0
oooo003e0?ooo`030000003oool0oooo02l0oooo0P3o00270?ooo`00m@3o
ool00`000000oooo0?ooo`0a0?ooo`80o`00Q@3oool00?D0oooo00<00000
0?ooo`3oool0<`3oool30?l00880oooo003e0?ooo`030000003oool0oooo
03H0oooo0P3o00200?ooo`00m@3oool00`000000oooo0?ooo`0h0?ooo`80
o`00OP3oool00?D0oooo00<000000?ooo`3oool0>P3oool20?l007`0oooo
003e0?ooo`030000003oool0oooo03`0oooo0P3o001j0?ooo`00m@3oool0
0`000000oooo0?ooo`0n0?ooo`<0o`00M`3oool00?D0oooo00<000000?oo
o`3oool0@@3oool20?l007D0oooo003e0?ooo`030000003oool0oooo04<0
oooo0P3o001c0?ooo`00m@3oool00`000000oooo0?ooo`150?ooo`80o`00
L@3oool00?D0oooo00<000000?ooo`3oool0A`3oool20?l006l0oooo003e
0?ooo`030000003oool0oooo04T0oooo0`3o001/0?ooo`00m@3oool00`00
0000oooo0?ooo`1<0?ooo`80o`00JP3oool00?D0oooo00<000000?ooo`3o
ool0CP3oool20?l006P0oooo003e0?ooo`030000003oool0oooo0500oooo
0P3o001V0?ooo`00m@3oool00`000000oooo0?ooo`1B0?ooo`80o`00I03o
ool00?D0oooo00<000000?ooo`3oool0E03oool30?l00640oooo003e0?oo
o`030000003oool0oooo05L0oooo0P3o001O0?ooo`00m@3oool00`000000
oooo0?ooo`1I0?ooo`80o`001P3oool00`3o0000oooo0?ooo`1D0?ooo`00
m@3oool00`000000oooo0?ooo`1K0?ooo`80o`000`3oool30?l005D0oooo
003e0?ooo`030000003oool0oooo05d0oooo0P3o00000`3oool0o`000?l0
00030?l005<0oooo003e0?ooo`030000003oool0oooo05l0oooo1`3o001B
0?ooo`00m@3oool00`000000oooo0?ooo`1O0?ooo`P0o`00D@3oool00=D0
oooo00<000000?ooo`3oool0303oool2000000@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1N0?ooo`X0o`00D03oool00=@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`1N0?ooo``0o`00CP3oool00=<0oooo00<000000?ooo`3oool00`3o
ool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0HP3o
ool90?l004d0oooo003C0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool00`3oool7000006L0oooo103o
001<0?ooo`00d`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0;P0oooo003C0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000001`3oool3000000030?oo
o`000000000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`2h0?ooo`00e03oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0;P0oooo003E0?ooo`040000003oool0oooo0?ooo`800000
3`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0;P0oooo
003e0?ooo`030000003oool0oooo07L0oooo1000000m0?ooo`00m@3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03`0oooo003e0?oo
o`030000003oool0oooo05<0oooo1@0000080?ooo`8000000P3oool20000
00D0oooo00<000000?ooo`3oool00P3oool700000080oooo00<000000?oo
o`3oool0?03oool00?D0oooo00<000000?ooo`3oool0D`3oool01@000000
oooo0?ooo`3oool000000080oooo1@0000020?ooo`040000003oool0oooo
000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo00000004
0?ooo`800000?@3oool00?D0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0;0?ooo`8000001@3oool5000000@0oooo00<000000?oo
o`0000000`3oool00`000000oooo0000000m0?ooo`00m@3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo1@0000030?ooo`80
00001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0
oooo00@000000?ooo`3oool00000?03oool00?D0oooo00<000000?ooo`3o
ool0D`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo
000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`000000?03oool00?D0oooo00<00000
0?ooo`3oool0D`3oool5000000P0oooo0P0000020?ooo`8000002P3oool5
000000050?ooo`00000000000000003oool00`00000k0?ooo`00m@3oool0
0`000000oooo0?ooo`2h0?ooo`00m@3oool00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo0480oooo003e0?ooo`030000003oool0oooo0;P0
oooo003e0?ooo`030000003oool0oooo0;P0oooo003e0?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`@000000`3oool00`000000oooo0?ooo`0g0?ooo`00m@3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00X0oooo0P000006
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=P3oool0
0?D0oooo00<000000?ooo`3oool0D`3oool5000000/0oooo00<000000?oo
o`3oool00P3oool200000080oooo0P0000040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0e0?oo
o`00m@3oool00`000000oooo0?ooo`1C0?ooo`050000003oool0oooo0?oo
o`0000000P3oool5000000@0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000050?ooo`8000001@3oool2000000D0oooo00<00000
0?ooo`3oool0=@3oool00?D0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo0P00000<0?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool0=@3oool00?D0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`020?ooo`D0
0000103oool00`000000oooo0?ooo`040?ooo`800000303oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo03D0oooo003e0?ooo`03
0000003oool0oooo05<0oooo00@000000?ooo`3oool00000303oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo000000X0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo03D0oooo003e
0?ooo`030000003oool0oooo05<0oooo1@00000;0?ooo`030000003oool0
oooo0080oooo0P0000020?ooo`800000203oool3000000040?ooo`000000
0000000000<0oooo00<000000?ooo`3oool0=@3oool00?D0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo03H0oooo003e0?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0g0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00l`3oool2
00000;/0oooo003d0?ooo`030000003oool0oooo0;T0oooo003e0?ooo`03
0000003oool0oooo0;P0oooo003d0?ooo`030000003oool000000;T0oooo
003c0?ooo`040000003oool0oooo00000;T0oooo003b0?ooo`<0000000<0
oooo000000000000^03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{432, 197},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\tWe can use an important algebraic relationship to establish properties \
of the absolute value that have geometric applications.  Its proof is rather \
straightforward, and we ask you to give it in the exercises for this section. \
\n\t\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(z\)\( | \^2\)\) = z\ \(\(z\)\(\ \)\)\&_\)]],
  ".  "
}], "Text"],

Cell["\<\
\tA beautiful and important application of the above identity is its use in \
establishing the triangle inequality, which states that the sum of the \
lengths of two sides of a triangle is greater than or equal to the length of \
the third side. Figure 1.9 illustrates this inequality.\
\>", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000aB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
N03oool40000oeP0oooo0`00000M0?ooo`<000005@3oool2000008D0oooo
001g0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0E03o
ool01@000000oooo0?ooo`3oool0000001d0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`220?ooo`00M`3oool60000oeH0oooo00D0
00000?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0P@3oool006`0oooo10000?l30?ooo`T0003o0`3o
ool90000o`80oooo0`000?l60?ooo`@0003o00@0oooo0000o`000?l0oooo
0P000?l<0?ooo`<000000`3oool3000000040?ooo`00000000000?ooo`80
00001P3oool2000000050?ooo`00000000000000003oool00`0000000`3o
ool0000000000005000000040?ooo`00000000000?ooo`<0000000D0oooo
00000000000000000?ooo`02000000D0oooo1P000000103oool000000000
003oool2000000<0oooo0P0000000`3oool000000?ooo`020?ooo`@00000
00<0oooo000000000000200000000`3oool00000000000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0O03oool006d0oooo0P00
0?l50?ooo`80003o00<0oooo0000o`3oool01@3oool20000o`030?ooo`00
0?l0003o0080oooo0P000?l20?ooo`80003o0P3oool00`000?l0oooo0?oo
o`040?ooo`80003o0P3oool20000o`80oooo0`000?l;0?ooo`030000003o
ool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo000000050?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000P3oool200000080oooo00H0
00000?ooo`3oool000000?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo00000022
0?ooo`00K@3oool20000o`D0oooo0P000?l20?ooo`<0003o0`3oool20000
o`030?ooo`000?l0003o0080oooo0P000?l20?ooo`80003o2@3oool20000
o`P0oooo00<0003o0?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`060000003oool0oooo0000003oool00000203oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo008000000`3oool00`000000
oooo000000080?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`000000103oool01@000000oooo0?ooo`3oool000000080oooo00H00000
0?ooo`3oool000000?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo000000220?oo
o`00K@3oool20000o`030?ooo`000?l0oooo0080oooo0P000?l0103oool0
003o0000o`3oool20000o`80oooo0P000?l00`3oool0003o0000o`020?oo
o`80003o0P3oool50000o`H0oooo0P000?l60?ooo`@0003o2P3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0000003oool010000005
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`0300000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`05
0000003oool0oooo0000003oool0100000050?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`0000000`0000000`3oool000000?ooo`02
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`00
00020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0800oooo001]0?ooo`@0003o
0`3oool20000o`040?ooo`000?l0003o0?ooo`80003o0P3oool20000o`03
0?ooo`000?l0003o0080oooo0P000?l01@3oool0003o0000o`000?l0oooo
0080003o1P3oool20000o`D0oooo0P000?l00`3oool0003o0000o`0:0?oo
o`030000003oool0oooo00<0oooo0P000000103oool000000?ooo`000002
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00
00020?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P00
0000103oool000000?ooo`0000020?ooo`060000003oool0oooo0000003o
ool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080000000@0oooo0000003oool000000P3oool00`000000oooo00000002
0?ooo`8000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oo
o`050000003oool0oooo0?ooo`000000P@3oool006d0oooo0P000?l0103o
ool0003o0?ooo`3oool30000o`80oooo20000?l0103oool0003o0000o`3o
ool50000o`040?ooo`000?l0003o0000o`L0oooo0P000?l50?ooo`80003o
00<0oooo0000o`000?l02P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000<0oooo0P0000050?ooo`<0000000@0oooo000000000000
oooo0`0000020?ooo`8000000P3oool2000000030?ooo`000000oooo0080
oooo10000000103oool000000?ooo`3oool2000000D0oooo0P0000001@3o
ool000000000003oool0000000<0oooo0P0000030?ooo`80000000<0oooo
0000003oool00P0000000`3oool00000000000020?ooo`8000000`3oool0
1@000000oooo000000000000oooo00<0000000D0oooo0000000000000000
0?ooo`0300000800oooo001]0?ooo`80003o9@3oool20000o`D0oooo0P00
0?l00`3oool0003o0000o`0:0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`270?ooo`00K@3oool20000o`<0oooo00@0003o0?ooo`000?l0003o7P3o
ool20000o`D0oooo0P000?l00`3oool0003o0000o`070?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000003@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`270?ooo`00K03oool70000o`030?oo
o`000?l0003o01d0oooo0`000?l60?ooo`<0003o203oool7000000030?oo
o`000000000001D0oooo00<000000?ooo`3oool03`3oool2000000X0oooo
00<000000?ooo`3oool06`3oool200000080oooo00<000000?ooo`3oool0
RP3oool00?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03oool00?l0
ooooU03oool00?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03oool0
0?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03o
ool00?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03oool00?l0oooo
N@3oool2000000030?ooo`000000000001H0oooo003o0?ooogX0oooo00<0
00000?ooo`0000005`3oool007/0oooo00@0003o0?l0003o0000o`00lP00
00090?ooo`030000003oool0oooo01H0oooo001k0?ooo`04000000000?l0
003o0?ooo`L0o`00lP3oool2000000030?ooo`000000000001H0oooo001k
0?ooo`0300000000o`00oooo0080003o1P3oool70?l00?l0oooo1`3oool0
07/0oooo00<000000?ooo`00o`000P3oool00`000?l0oooo0?ooo`0:0?oo
o`L0o`00o`3oool007/0oooo00<000000?ooo`00o`000`3oool20000oa40
oooo203o003g0?ooo`00N`3oool010000000oooo0?ooo`00o`040?ooo`80
003o5`3oool70?l00?00oooo001k0?ooo`050000003oool0oooo0?ooo`00
o`001@3oool00`000?l0oooo0?ooo`0K0?ooo`L0o`00j@3oool007/0oooo
00D000000?ooo`3oool0oooo003o00060?ooo`80003o8P3oool70?l00>80
oooo001k0?ooo`030000003oool0oooo0080oooo00<00?l00?ooo`3oool0
1@3oool20000obL0oooo1`3o003K0?ooo`00N`3oool00`000000oooo0?oo
o`020?ooo`03003o003oool0oooo00L0oooo00<0003o0?ooo`3oool0:`3o
ool70?l00=@0oooo001k0?ooo`030000003oool0oooo00<0oooo00<00?l0
0?ooo`3oool01`3oool20000oc80oooo1`3o003=0?ooo`00N`3oool00`00
0000oooo0?ooo`040?ooo`03003o003oool0oooo00P0oooo0P000?lg0?oo
o`L0o`00aP3oool007/0oooo00<000000?ooo`3oool0103oool00`00o`00
oooo0?ooo`0:0?ooo`030000o`3oool0oooo03/0oooo203o002n0?ooo`00
N`3oool00`000000oooo0?ooo`050?ooo`03003o003oool0oooo00X0oooo
0P000?m30?ooo`L0o`00]`3oool007/0oooo00<000000?ooo`3oool01@3o
ool00`00o`00oooo0?ooo`0<0?ooo`80003oB03oool70?l00;00oooo001k
0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`1<0?ooo`L0o`00Z@3oool007/0oooo00<000000?oo
o`3oool01`3oool00`00o`00oooo0?ooo`0=0?ooo`80003oD`3oool70?l0
0480oooo1@00001K0?ooo`00N`3oool00`000000oooo0?ooo`070?ooo`03
003o003oool0oooo00l0oooo0P000?mH0?ooo`L0o`00?@3oool00`000000
oooo0?ooo`1K0?ooo`00N`3oool00`000000oooo0?ooo`080?ooo`03003o
003oool0oooo0100oooo00<0003o0?ooo`3oool0G03oool70?l002h0oooo
1@0000030?ooo`030000003oool0oooo05/0oooo001k0?ooo`030000003o
ool0oooo00T0oooo00<00?l00?ooo`3oool0403oool20000of<0oooo1`3o
000X0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
F`3oool007/0oooo00<000000?ooo`3oool02@3oool00`00o`00oooo0?oo
o`0B0?ooo`80003oJ03oool80?l000d0oooo0P3o000B0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0F`3oool007/0oooo00<00000
0?ooo`3oool02P3oool00`00o`00oooo0?ooo`0C0?ooo`030000o`3oool0
oooo0340oooo00<000000?ooo`3oool02@3oool5000000<0oooo00<00000
0?ooo`3oool09@3oool70?l000H0oooo1@3o000@0?ooo`040000003oool0
oooo0?ooo`800000G@3oool007/0oooo00<000000?ooo`3oool02P3oool0
0`00o`00oooo0?ooo`0D0?ooo`80003o<@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;03oool=
0?l000`0oooo00@000000?ooo`3oool00000H@3oool007/0oooo00<00000
0?ooo`3oool02`3oool00`00o`00oooo0?ooo`0E0?ooo`80003o;`3oool0
0`000000oooo0?ooo`030?ooo`D000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0340oooo2`3o00090?ooo`D00000H03oool0
07/0oooo00<000000?ooo`3oool0303oool00`00o`00oooo0?ooo`0F0?oo
o`030000o`3oool0oooo02`0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0<@3oool<0?l00003003o003oool0oooo06X0oooo001k0?oo
o`030000003oool0oooo00`0oooo00<00?l00?ooo`3oool05`3oool20000
ob`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<@3oool:0?l0
00<0oooo00<00?l00?ooo`3oool0J@3oool007/0oooo00<000000?ooo`3o
ool03@3oool00`00o`00oooo0?ooo`0H0?ooo`80003o:P3oool00`000000
oooo0?ooo`060?ooo`040000003oool0oooo0?ooo`8000001@3oool00`00
0000oooo0?ooo`0a0?ooo`@0o`002@3oool00`00o`00oooo0?ooo`1Y0?oo
o`00N`3oool00`000000oooo0?ooo`0=0?ooo`03003o003oool0oooo01X0
oooo00<0003o0?ooo`3oool09`3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0?`3oool00`00
o`00oooo0?ooo`1X0?ooo`00N`3oool00`000000oooo0?ooo`0>0?ooo`03
003o003oool0oooo01X0oooo0P000?lW0?ooo`030000003oool0oooo00@0
oooo1@0000080?ooo`030000003oool0oooo03l0oooo00<00?l00?ooo`3o
ool0J03oool007/0oooo00<000000?ooo`3oool03`3oool00`00o`00oooo
0?ooo`0K0?ooo`80003o9@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0400oooo00<00?l00?ooo`3oool0I`3oool007/0oooo00<0
00000?ooo`3oool03`3oool00`00o`00oooo0?ooo`0M0?ooo`030000o`3o
ool0oooo0280oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`110?ooo`03003o003oool0oooo06H0oooo001k0?ooo`030000003oool0
oooo0100oooo00<00?l00?ooo`3oool07@3oool20000ogX0oooo00<00?l0
0?ooo`3oool0IP3oool007/0oooo00<000000?ooo`3oool0403oool00`00
o`00oooo0?ooo`0O0?ooo`80003oN@3oool00`00o`00oooo0?ooo`1U0?oo
o`00N`3oool00`000000oooo0?ooo`0A0?ooo`03003o003oool0oooo0200
oooo00<0003o0?ooo`3oool0MP3oool00`00o`00oooo0?ooo`1U0?ooo`00
N`3oool00`000000oooo0?ooo`0B0?ooo`03003o003oool0oooo0200oooo
0P000?mg0?ooo`03003o003oool0oooo06@0oooo001k0?ooo`030000003o
ool0oooo0180oooo00<00?l00?ooo`3oool08P3oool20000ogH0oooo00<0
0?l00?ooo`3oool0H`3oool007/0oooo00<000000?ooo`3oool04`3oool0
0`00o`00oooo0?ooo`0S0?ooo`030000o`3oool0oooo07<0oooo00<00?l0
0?ooo`3oool0H`3oool007/0oooo00<000000?ooo`3oool04`3oool00`00
o`00oooo0?ooo`0T0?ooo`80003oM03oool00`00o`00oooo0?ooo`1R0?oo
o`00N`3oool00`000000oooo0?ooo`0D0?ooo`03003o003oool0oooo02D0
oooo0P000?mb0?ooo`03003o003oool0oooo0680oooo001k0?ooo`030000
003oool0oooo01D0oooo00<00?l00?ooo`3oool09P3oool00`000?l0oooo
0?ooo`1`0?ooo`03003o003oool0oooo0640oooo001k0?ooo`030000003o
ool0oooo01D0oooo00<00?l00?ooo`3oool09`3oool20000og40oooo00<0
0?l00?ooo`3oool0H03oool007/0oooo00<000000?ooo`3oool05P3oool0
0`00o`00oooo0?ooo`0X0?ooo`80003oK`3oool00`00o`00oooo0?ooo`1P
0?ooo`00N`3oool00`000000oooo0?ooo`0F0?ooo`03003o003oool0oooo
02X0oooo00<0003o0?ooo`3oool0K@3oool00`00o`00oooo0?ooo`1O0?oo
o`00N`3oool00`000000oooo0?ooo`0G0?ooo`03003o003oool0oooo02X0
oooo0P000?m]0?ooo`03003o003oool0oooo05l0oooo001k0?ooo`030000
003oool0oooo01P0oooo00<00?l00?ooo`3oool0:`3oool20000of`0oooo
00<00?l00?ooo`3oool0GP3oool007/0oooo00<000000?ooo`3oool0603o
ool00`00o`00oooo0?ooo`0]0?ooo`030000o`3oool0oooo06X0oooo00<0
0?l00?ooo`3oool0G@3oool007/0oooo00<000000?ooo`3oool06@3oool0
0`00o`00oooo0?ooo`0]0?ooo`80003oJP3oool00`00o`00oooo0?ooo`1M
0?ooo`00N`3oool00`000000oooo0?ooo`0J0?ooo`03003o003oool0oooo
02h0oooo0P000?mY0?ooo`03003o003oool0oooo05`0oooo001k0?ooo`03
0000003oool0oooo01X0oooo00<00?l00?ooo`3oool0<03oool00`000?l0
oooo0?ooo`1V0?ooo`03003o003oool0oooo05`0oooo001k0?ooo`030000
003oool0oooo01/0oooo00<00?l00?ooo`3oool0<03oool20000ofL0oooo
00<00?l00?ooo`3oool0F`3oool007/0oooo00<000000?ooo`3oool06`3o
ool00`00o`00oooo0?ooo`0b0?ooo`80003oIP3oool00`00o`00oooo0?oo
o`1J0?ooo`00N`3oool00`000000oooo0?ooo`0L0?ooo`03003o003oool0
oooo03<0oooo00<0003o0?ooo`3oool0H`3oool00`00o`00oooo0?ooo`1J
0?ooo`00N`3oool00`000000oooo0?ooo`0M0?ooo`03003o003oool0oooo
03<0oooo0P000?mT0?ooo`03003o003oool0oooo05T0oooo001k0?ooo`03
0000003oool0oooo01d0oooo00<00?l00?ooo`3oool0=@3oool20000of80
oooo00<00?l00?ooo`3oool0F@3oool007/0oooo00<000000?ooo`3oool0
7P3oool00`00o`00oooo0?ooo`0f0?ooo`030000o`3oool0oooo0600oooo
00<00?l00?ooo`3oool0F03oool007/0oooo00<000000?ooo`3oool07P3o
ool00`00o`00oooo0?ooo`0g0?ooo`80003oH@3oool00`00o`00oooo0?oo
o`1G0?ooo`00N`3oool00`000000oooo0?ooo`0O0?ooo`03003o003oool0
oooo03P0oooo0P000?mO0?ooo`03003o003oool0oooo05L0oooo001k0?oo
o`030000003oool0oooo0200oooo00<00?l00?ooo`3oool0>@3oool00`00
0?l0oooo0?ooo`1M0?ooo`03003o003oool0oooo05H0oooo001k0?ooo`03
0000003oool0oooo0200oooo00<00?l00?ooo`3oool0>P3oool20000oed0
oooo00<00?l00?ooo`3oool0EP3oool007/0oooo00<000000?ooo`3oool0
8@3oool00`00o`00oooo0?ooo`0k0?ooo`80003oG03oool00`00o`00oooo
0?ooo`1E0?ooo`00N`3oool00`000000oooo0?ooo`0Q0?ooo`03003o003o
ool0oooo03d0oooo00<0003o0?ooo`3oool0FP3oool00`00o`00oooo0?oo
o`1D0?ooo`00N`3oool00`000000oooo0?ooo`0R0?ooo`03003o003oool0
oooo03d0oooo0P000?mJ0?ooo`03003o003oool0oooo05@0oooo001k0?oo
o`030000003oool0oooo02<0oooo00<00?l00?ooo`3oool0?P3oool20000
oeT0oooo00<00?l00?ooo`3oool0D`3oool007/0oooo00<000000?ooo`3o
ool08`3oool00`00o`00oooo0?ooo`100?ooo`030000o`3oool0oooo05H0
oooo00<00?l00?ooo`3oool0D`3oool007/0oooo00<000000?ooo`3oool0
903oool00`00o`00oooo0?ooo`100?ooo`80003oE`3oool00`00o`00oooo
0?ooo`1B0?ooo`00N`3oool00`000000oooo0?ooo`0T0?ooo`03003o003o
ool0oooo0480oooo0P000?mF0?ooo`03003o003oool0oooo0540oooo001k
0?ooo`030000003oool0oooo02D0oooo00<00?l00?ooo`3oool0@`3oool0
0`000?l0oooo0?ooo`1C0?ooo`03003o003oool0oooo0540oooo001k0?oo
o`030000003oool0oooo02H0oooo00<00?l00?ooo`3oool0@`3oool20000
oe@0oooo00<00?l00?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo02l0oooo001k0?ooo`030000003oool0oooo02H0
oooo00<00?l00?ooo`3oool0A@3oool20000oe80oooo00<00?l00?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`<000001@3oool00`000000
oooo0?ooo`0_0?ooo`00N`3oool00`000000oooo0?ooo`0W0?ooo`03003o
003oool0oooo04H0oooo00<0003o0?ooo`3oool0D03oool00`00o`00oooo
0?ooo`090?ooo`030000003oool0oooo0080oooo1@0000020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0;`3oool007/0oooo00<0
00000?ooo`3oool09`3oool00`00o`00oooo0?ooo`170?ooo`80003oD@3o
ool00`00o`00oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo02l0oooo001k0?ooo`030000003oool0oooo02P0oooo00<0
0?l00?ooo`3oool0B03oool20000odl0oooo00<00?l00?ooo`3oool0203o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0_0?ooo`00N`3oool0
0`000000oooo0?ooo`0Y0?ooo`03003o003oool0oooo04T0oooo00<0003o
0?ooo`3oool0C@3oool00`00o`00oooo0?ooo`070?ooo`030000003oool0
oooo00D0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo
00<000000?ooo`3oool0;`3oool007/0oooo00<000000?ooo`3oool0:@3o
ool00`00o`00oooo0?ooo`1:0?ooo`80003oC@3oool00`00o`00oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02l0oooo
001k0?ooo`030000003oool0oooo02X0oooo00<00?l00?ooo`3oool0B`3o
ool20000od`0oooo00<00?l00?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`D000002@3oool00`000000oooo0?ooo`0_0?ooo`00N`3oool0
0`000000oooo0?ooo`0Z0?ooo`03003o003oool0oooo04d0oooo00<0003o
0?ooo`3oool0BP3oool00`00o`00oooo0?ooo`050?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0;`3oool007/0oooo00<000000?oo
o`3oool0:`3oool00`00o`00oooo0?ooo`1=0?ooo`80003oBP3oool00`00
o`00oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0;`3oool007/0oooo00<000000?ooo`3oool0;03oool00`00o`00
oooo0?ooo`1>0?ooo`80003oB@3oool00`00o`00oooo0?ooo`1:0?ooo`00
N`3oool00`000000oooo0?ooo`0/0?ooo`03003o003oool0oooo0500oooo
00<0003o0?ooo`3oool0AP3oool00`00o`00oooo0?ooo`1:0?ooo`00N`3o
ool00`000000oooo0?ooo`0]0?ooo`03003o003oool0oooo0500oooo0P00
0?m70?ooo`03003o003oool0oooo04T0oooo001k0?ooo`030000003oool0
oooo02h0oooo00<00?l00?ooo`3oool0D@3oool20000odH0oooo00<00?l0
0?ooo`3oool0B03oool007/0oooo00<000000?ooo`3oool0;P3oool00`00
o`00oooo0?ooo`1C0?ooo`030000o`3oool0oooo04<0oooo00<00?l00?oo
o`3oool0B03oool007/0oooo00<000000?ooo`3oool0;`3oool00`00o`00
oooo0?ooo`1C0?ooo`80003oA03oool00`00o`00oooo0?ooo`170?ooo`00
N`3oool00`000000oooo0?ooo`0_0?ooo`03003o003oool0oooo05D0oooo
0P000?m20?ooo`03003o003oool0oooo04L0oooo001k0?ooo`030000003o
ool0oooo0300oooo00<00?l00?ooo`3oool0EP3oool00`000?l0oooo0?oo
o`100?ooo`03003o003oool0oooo04H0oooo001k0?ooo`030000003oool0
oooo0340oooo00<00?l00?ooo`3oool0EP3oool20000od40oooo00<00?l0
0?ooo`3oool0A@3oool007/0oooo00<000000?ooo`3oool0<@3oool00`00
o`00oooo0?ooo`1H0?ooo`80003o?`3oool00`00o`00oooo0?ooo`150?oo
o`00N`3oool00`000000oooo0?ooo`0b0?ooo`03003o003oool0oooo05T0
oooo00<0003o0?ooo`3oool0?@3oool00`00o`00oooo0?ooo`140?ooo`00
N`3oool00`000000oooo0?ooo`0b0?ooo`03003o003oool0oooo05X0oooo
0P000?ln0?ooo`03003o003oool0oooo04<0oooo001k0?ooo`030000003o
ool0oooo03<0oooo00<00?l00?ooo`3oool0:@3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00L0oooo0P000?ll0?ooo`03003o003o
ool0oooo04<0oooo001k0?ooo`030000003oool0oooo03@0oooo00<00?l0
0?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`D00000403oool3
000000@0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0j
0?ooo`03003o003oool0oooo0480oooo001k0?ooo`030000003oool0oooo
03@0oooo00<00?l00?ooo`3oool0:03oool00`000000oooo0?ooo`020?oo
o`D00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo1@0000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02P3oool20000ocX0oooo00<00?l00?ooo`3oool0@P3oool007/0
oooo00<000000?ooo`3oool0=@3oool00`00o`00oooo0?ooo`0W0?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00`0oooo0P000?li0?ooo`03003o003oool0oooo0440oooo001k0?oo
o`030000003oool0oooo03D0oooo00<00?l00?ooo`3oool09`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool0oooo1@0000040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo03L0oooo00<00?l00?ooo`3oool0@03oool007/0oooo00<000000?oo
o`3oool0=P3oool00`00o`00oooo0?ooo`0V0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000040?ooo`030000003oool0oooo00l0oooo0P000?lg0?oo
o`03003o003oool0oooo0400oooo001k0?ooo`030000003oool0oooo03L0
oooo00<00?l00?ooo`3oool09@3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000<0oooo0P0000050?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0140oooo0P000?lf0?ooo`03003o003oool0
oooo03l0oooo001k0?ooo`030000003oool0oooo03L0oooo00<00?l00?oo
o`3oool09@3oool00`000000oooo0?ooo`030?ooo`D000003`3oool50000
00T0oooo00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0c0?oo
o`03003o003oool0oooo03l0oooo001k0?ooo`030000003oool0oooo03P0
oooo00<00?l00?ooo`3oool0903oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo01@0oooo0P000?ld0?ooo`03003o003oool0oooo03h0
oooo001k0?ooo`030000003oool0oooo03P0oooo00<00?l00?ooo`3oool0
903oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01H0oooo
0P000?lc0?ooo`03003o003oool0oooo03d0oooo001k0?ooo`030000003o
ool0oooo03T0oooo00<00?l00?ooo`3oool0IP3oool00`000?l0oooo0?oo
o`0`0?ooo`03003o003oool0oooo03d0oooo001k0?ooo`030000003oool0
oooo03X0oooo00<00?l00?ooo`3oool0IP3oool20000oc40oooo00<00?l0
0?ooo`3oool0?03oool007/0oooo00<000000?ooo`3oool0>P3oool00`00
o`00oooo0?ooo`1X0?ooo`80003o;`3oool00`00o`00oooo0?ooo`0l0?oo
o`00N`3oool00`000000oooo0?ooo`0k0?ooo`03003o003oool0oooo06T0
oooo00<0003o0?ooo`3oool0;@3oool00`00o`00oooo0?ooo`0k0?ooo`00
N`3oool00`000000oooo0?ooo`0k0?ooo`03003o003oool0oooo06X0oooo
0P000?l^0?ooo`03003o003oool0oooo03X0oooo001k0?ooo`030000003o
ool0oooo03`0oooo00<00?l00?ooo`3oool0J`3oool20000ob`0oooo00<0
0?l00?ooo`3oool0>P3oool007/0oooo00<000000?ooo`3oool0?@3oool0
0`00o`00oooo0?ooo`1/0?ooo`030000o`3oool0oooo02X0oooo00<00?l0
0?ooo`3oool0>@3oool007/0oooo00<000000?ooo`3oool0?@3oool00`00
o`00oooo0?ooo`1]0?ooo`80003o:P3oool00`00o`00oooo0?ooo`0i0?oo
o`00N`3oool00`000000oooo0?ooo`0n0?ooo`03003o003oool0oooo06h0
oooo0P000?lY0?ooo`03003o003oool0oooo03P0oooo001k0?ooo`030000
003oool0oooo03l0oooo00<00?l00?ooo`3oool0K`3oool00`000?l0oooo
0?ooo`0W0?ooo`03003o003oool0oooo03L0oooo001k0?ooo`030000003o
ool0oooo03l0oooo00<00?l00?ooo`3oool0L03oool20000obL0oooo00<0
0?l00?ooo`3oool0=`3oool007/0oooo00<000000?ooo`3oool0@03oool0
1000o`00oooo0?ooo`00o`1`0?ooo`80003o9P3oool00`00o`00oooo0?oo
o`0f0?ooo`00N`3oool00`000000oooo0?ooo`100?ooo`@00?l0LP3oool0
0`000?l0oooo0?ooo`0S0?ooo`03003o003oool0oooo03H0oooo001k0?oo
o`030000003oool0oooo03l0oooo1P00o`1b0?ooo`80003o903oool00`00
o`00oooo0?ooo`0e0?ooo`00N`3oool00`000000oooo0?ooo`0n0?ooo`L0
0?l0M03oool20000ob<0oooo00<00?l00?ooo`3oool0=03oool007/0oooo
00<000000?ooo`3oool0?`3oool6003o07H0oooo00<0003o0?ooo`3oool0
803oool00`00o`00oooo0?ooo`0d0?ooo`00N`3oool00`000000oooo0?oo
o`100?ooo`H00?l0MP3oool20000ob40oooo00<00?l00?ooo`3oool0<`3o
ool007/0oooo00<000000?ooo`3oool0@@3oool5003o07P0oooo0P000?lO
0?ooo`03003o003oool0oooo03<0oooo001k0?ooo`030000003oool0oooo
0480oooo1000o`1j0?ooo`030000o`3oool0oooo01d0oooo00<00?l00?oo
o`3oool0<P3oool007/0oooo00<000000?ooo`3oool0@`3oool4003o07X0
oooo0P000?lN0?ooo`03003o003oool0oooo0340oooo001k0?ooo`030000
003oool0oooo04@0oooo0`00o`1l0?ooo`80003o703oool00`00o`00oooo
0?ooo`0a0?ooo`00N`3oool00`000000oooo0?ooo`150?ooo`800?l0OP3o
ool00`000?l0oooo0?ooo`0J0?ooo`03003o003oool0oooo0300oooo001k
0?ooo`030000003oool0oooo04H0oooo0P00o`1n0?ooo`80003o6P3oool0
0`00o`00oooo0?ooo`0`0?ooo`00N`3oool00`000000oooo0?ooo`170?oo
o`03003o003oool0oooo07h0oooo0P000?lI0?ooo`03003o003oool0oooo
02l0oooo001k0?ooo`030000003oool0oooo0<X0oooo00<0003o0?ooo`3o
ool05`3oool00`00o`00oooo0?ooo`0^0?ooo`00N`3oool00`000000oooo
0?ooo`3;0?ooo`80003o5`3oool00`00o`00oooo0?ooo`0^0?ooo`00N`3o
ool00`000000oooo0?ooo`3=0?ooo`80003o5P3oool00`00o`00oooo0?oo
o`0]0?ooo`00N`3oool00`000000oooo0?ooo`3?0?ooo`030000o`3oool0
oooo01<0oooo00<00?l00?ooo`3oool0;@3oool007/0oooo00<000000?oo
o`3oool0d03oool20000oa@0oooo00<00?l00?ooo`3oool0;03oool007/0
oooo00<000000?ooo`3oool0dP3oool20000oa<0oooo00<00?l00?ooo`3o
ool0:`3oool007/0oooo00<000000?ooo`3oool0B03oool3000008T0oooo
00<0003o0?ooo`3oool0403oool00`00o`00oooo0?ooo`0[0?ooo`00N`3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo08X0oooo0P00
0?lA0?ooo`03003o003oool0oooo02X0oooo001k0?ooo`030000003oool0
oooo0440oooo1@0000030?ooo`030000003oool0oooo08/0oooo0P000?l?
0?ooo`03003o003oool0oooo02X0oooo001k0?ooo`030000003oool0oooo
0480oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`2=
0?ooo`030000o`3oool0oooo00d0oooo00<00?l00?ooo`3oool0:@3oool0
07/0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000008l0oooo0P000?l>0?ooo`03003o003oool0oooo
02P0oooo001k0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`2@0?ooo`80003o303oool00`00o`00
oooo0?ooo`0X0?ooo`00N`3oool00`000000oooo0?ooo`120?ooo`040000
003oool0oooo000009P0oooo00<0003o0?ooo`3oool02P3oool01000o`00
oooo0?ooo`00o`0V0?ooo`00N`3oool00`000000oooo0?ooo`120?ooo`D0
0000V03oool20000o`X0oooo1000o`0V0?ooo`00N`3oool00`000000oooo
0?ooo`3Q0?ooo`80003o1`3oool6003o02D0oooo001k0?ooo`030000003o
ool0oooo0><0oooo00<0003o0?ooo`3oool00`3oool00`000?l00?l0003o
0004003o02D0oooo001k0?ooo`030000003oool0oooo0>@0oooo0P000?l2
0?ooo`<0003o1@00o`0U0?ooo`00N`3oool00`000000oooo0?ooo`3V0?oo
o`H0003o1@00o`0T0?ooo`00N`3oool00`000000oooo0?ooo`3W0?ooo`H0
003o1000o`0T0?ooo`00N`3oool00`000000oooo0?ooo`3W0?ooo`L0003o
0`00o`0T0?ooo`00N`3oool00`000000oooo0?ooo`3:0?ooo`D00000403o
ool3000000@0oooo2@000?l3003o02<0oooo001k0?ooo`030000003oool0
oooo0<`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`06
0?ooo`P0003o0P00o`0S0?ooo`00N`3oool00`000000oooo0?ooo`340?oo
o`D000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo1@0000030?ooo`030000003oool0oooo00P0oooo1P000?l00`00
o`00oooo0?ooo`0Q0?ooo`00N`3oool00`000000oooo0?ooo`350?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool02`3oool40000o`03003o003oool0oooo0200oooo001k0?oo
o`030000003oool0oooo0<H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`D00000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000l0oooo0P000?lR0?ooo`00o`3ooom60?ooo`04
0000003oool0oooo0?ooo`8000001P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0<P3oool00?l0
ooooA03oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000>03oool00?l0ooooA03oool50000
00l0oooo1@00000g0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3o
oonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00N@3oool200000?l0
oooo6@3oool007X0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`00N`3o
ool00`000000oooo0?ooo`3o0?oooaH0oooo001j0?ooo`030000003oool0
00000?l0oooo5`3oool007T0oooo00@000000?ooo`3oool00000o`3ooolG
0?ooo`00N03oool3000000030?ooo`00000000000?l0oooo5P3oool00?l0
ooooU03oool00?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03oool0
0001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 197},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Theorem 1.2, (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Triangle Inequality",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/TriangleInequality.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox["). ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(z\_2\)}]]],
  " are arbitrary complex numbers, then  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(z\_1 + 
          z\_2\)\(|\)\(\(\[LessEqual]\)\(\(|\)\(z\_1\)\(|\)\(+\(\(|\)\(z\_2\)\
\(|\)\)\)\)\)\)\)]],
  ".  \n\t\t\t"
}], "Text"],

Cell[TextData[{
  StyleBox["Proof.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  We appeal to basic results:  \n\n\t\t\t",
  Cell[BoxData[GridBox[{
          {\(\(|\)\(z\_1 + z\_2\)\( | \^2\)\), 
            "=", \(\(\((z\_1 + 
                  z\_2)\) \((z\_1 + z\_2)\)\&_\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \)\(\[IndentingNewLine]\)
            \), 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["by",
                    FontFamily->"Times New Roman",
                    FontWeight->"Plain"], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontWeight->"Plain"], 
                  StyleBox["Identity",
                    FontFamily->"Times New Roman",
                    FontWeight->"Plain"], 
                  StyleBox[
                    StyleBox[
                      RowBox[{
                        StyleBox[" ",
                          FontFamily->"Times New Roman"], 
                        StyleBox[" ",
                          FontFamily->"Times New Roman",
                          FontColor->RGBColor[0, 0, 1]]}]],
                    FontWeight->"Plain"], 
                  StyleBox[\((1 - 22)\),
                    FontFamily->"Times New Roman",
                    FontWeight->"Plain",
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], 
              "                                           "}]},
          {" ", 
            "=", \(\(\((z\_1 + 
                  z\_2)\) \((\(z\_1\)\&_ + \(z\_2\)\&_)\)\)\(\ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \)\(\[IndentingNewLine]\)
            \), 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["by",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["Identity",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["  ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[\((1 - 13)\),
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}], ")"}], 
              "                                            "}]},
          {" ", 
            "=", \(\(\(z\_1\) \(z\_1\)\&_ + \(z\_1\) \(z\_2\)\&_ + \(z\_2\) \
\(z\_1\)\&_ + \(z\_2\) \(z\_2\)\&_\)\(\ \ \ \ \ \ \ \)\(\[IndentingNewLine]\)
            \), 
            RowBox[{
              RowBox[{"(", 
                StyleBox[\(by\ the\ distributive\ law\),
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], ")"}], 
              "                                         "}]},
          {" ", 
            "=", \(\(|\)\(z\_1\)\( | \^2\)\(\(+z\_1\) \(z\_2\)\&_ + \
\(\(z\_1\)\&_\) z\_2 + \)\(|\)\(z\_2\)\( | \^2\)\(\[IndentingNewLine]\)\), 
            RowBox[{
              RowBox[{"(", 
                StyleBox[\(by\ the\ commutative\ law\),
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], ")"}], 
              "                                       "}]},
          {" ", 
            "=", \(\(|\)\(z\_1\)\( | \^2\)\(\(+z\_1\) \(z\_2\)\&_ + \
\(\(z\_1\) \(z\_2\)\&_\)\&_ + \)\(|\)\(z\_2\)\( | \
\^2\)\(\[IndentingNewLine]\)\), 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["by",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["  ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[\((1 - 12)\),
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}], ")"}], 
              "                                                          \
"}]},
          {" ", 
            "=", \(\(|\)\(z\_1\)\( | \^2\)\(\(\(+2\) 
                  Re \((\(z\_1\) \(z\_2\)\&_)\)\)\(+\)\)\(|\)\(z\_2\)\( | \^2\
\)\(\[IndentingNewLine]\)\), 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["by",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["Identity",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["  ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[\((1 - 16)\),
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}], ")"}], 
              "                                            "}]},
          {" ", 
            "\[LessEqual]", \(\(|\)\(z\_1\)\( | \^2\)\(+2\)\(|\)\(\(z\_1\) \
\(z\_2\)\&_\)\(|\)\(+\(\(|\)\(z\_2\)\( | \^2\)\(\ \ \ \)\(\[IndentingNewLine]\
\)\)\)\), 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["by",
                    FontFamily->"Times New Roman",
                    FontWeight->"Plain"], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontWeight->"Plain"], 
                  StyleBox["Identity",
                    FontFamily->"Times New Roman",
                    FontWeight->"Plain"], 
                  StyleBox[
                    StyleBox[
                      RowBox[{
                        StyleBox[" ",
                          FontFamily->"Times New Roman"], 
                        StyleBox[" ",
                          FontFamily->"Times New Roman",
                          FontColor->RGBColor[0, 0, 1]]}]],
                    FontWeight->"Plain"], 
                  StyleBox[\((1 - 22)\),
                    FontFamily->"Times New Roman",
                    FontWeight->"Plain",
                    FontColor->RGBColor[0, 0, 1]]}], ")"}], 
              "                                           "}]},
          {" ", 
            "=", \(\(\((\(|\)\(z\_1\)\(|\)\(+\(\(|\)\(z\_2\)\(|\)\)\))\)\^2\)\
\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\), " "}
          }]]],
  "   \n\nTaking square roots yields the desired inequality.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example  1.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  To produce an example of which Figure 1.9 is a reasonable illustration, \
we let  ",
  Cell[BoxData[
      \(z\_1 = \(7 + \[ImaginaryI]\ \ and\ \ z\_2 = 
          3 + 5  \[ImaginaryI]\)\)]],
  ".  Then  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_1\)\(|\)\) = \(\@\(49 + 1\) = \@50\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_2\)\(|\)\) = \(\@\(9 + 25\) = \@34\)\)]],
  ".  Clearly,  ",
  Cell[BoxData[
      \(z\_1 + z\_2 = 10 + 6  \[ImaginaryI]\)]],
  ";  hence  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_1 + z\_2\)\(|\)\) = \(\@\(100 + 36\) = \@136\)\)]],
  ".  In this case, we can verify the triangle inequality without recourse to \
computation of square roots because  \n\n\t\t",
  Cell[BoxData[
      \(\(\(|\)\(z\_1 + 
            z\_2\)\(|\)\) = \(\@\(100 + 36\) = \(\@136 = \(2\ \@34 = \(\@34 + \
\ \@34 < \@50 + \ \@34 = \
\(\(|\)\(z\_1\)\(|\)\(+\(\(|\)\(z\_2\)\(|\)\)\)\)\)\)\)\)\)]],
  ",  \nthus \n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(z\_1 + 
          z\_2\)\(|\)\(\(\[LessEqual]\)\(\(|\)\(z\_1\)\(|\)\(+\(\(|\)\(z\_2\)\
\(|\)\)\)\)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Compute ",
  Cell[BoxData[
      \(\(\(|\)\(z\_1 + 
          z\_2\)\(|\)\(\ \ \)\(and\)\(\ \ \
\)\(|\)\(z\_1\)\(|\)\(+\(\(|\)\(z\_2\)\(|\)\)\)\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[z];\)\ \), "\n", 
    \(\(z\_1 = 7 + \[ImaginaryI];\)\ \), "\n", 
    \(\(z\_2 = 3 + 5  \[ImaginaryI];\)\ \), "\n", 
    \(\(w\_1 = z\_1 + z\_2;\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        Graphics[{Red, Arrow[{0, \ 0}, {Re[z\_1], Im[z\_1]}]}];\)\ \), "\n", 
    \(\(V\_2\  = \ 
        Graphics[{Green, 
            Arrow[{0, \ 0}, {Re[z\_2], 
                Im[z\_2]}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_3\  = \ 
        Graphics[{Pink, 
            Arrow[{Re[z\_1], Im[z\_1]}, {Re[w\_1], 
                Im[w\_1]}]}];\)\ \), "\n", 
    \(\(V\_4\  = \ 
        Graphics[{Blue, 
            Arrow[{0, \ 0}, {Re[w\_1], Im[w\_1]}]}];\)\ \), "\n", 
    \(\(Show[V\_1, V\_2, V\_3, V\_4, PlotRange \[Rule] {{0, 10}, {0, 6}}, 
        Ticks \[Rule] {Range[0, 10, 1], Range[0, 6, 1]}, 
        AspectRatio \[Rule] 6\/10, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print[\*"\"\<          \!\(z\_1\) = \>\""\ , z\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<          \!\(z\_2\) = \>\""\ , z\_2];\)\ \), "\n", 
    \(\(Print[\*"\"\<     \!\(z\_1\) + \!\(z\_2\) = \>\""\ , 
        z\_1 + z\_2];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<        |\!\(z\_1\)| = \>\"", 
        Abs[z\_1]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<        |\!\(z\_2\)| = \>\"", 
        Abs[z\_2]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   |\!\(z\_1\) + \!\(z\_2\)| = \>\"", 
        Abs[z\_1 + z\_2]];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is |\!\(z\_1\) + \!\(z\_2\)| \[LessEqual]  |\!\(z\_1\)| \
+ |\!\(z\_2\)| ?  \>\"", 
        Abs[z\_1 + z\_2] \[LessEqual] Abs[z\_1] + Abs[z\_2]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<   |\!\(z\_1\) + \!\(z\_2\)| = \>\"", 
        N[Abs[z\_1 + z\_2]]];\)\ \), "\n", 
    \(\(Print[\*"\"\< |\!\(z\_1\)| + |\!\(z\_2\)| = \>\"", 
        N[Abs[z\_1] + Abs[z\_2]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is |\!\(z\_1\) + \!\(z\_2\)| \[LessEqual]  |\!\(z\_1\)| \
+ |\!\(z\_2\)| ?  \>\"", 
        Abs[z\_1 + z\_2] \[LessEqual] 
          Abs[z\_1] + Abs[z\_2]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Is    \>", Abs[z\_1 + z\_2], "\< \[LessEqual] \>", 
        Abs[z\_1] + Abs[z\_2], "\< ?  \>", 
        Abs[z\_1 + z\_2] \[LessEqual] 
          Abs[z\_1] + Abs[z\_2]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Is  \>", N[Abs[z\_1 + z\_2]], "\< \[LessEqual] \>", 
        N[Abs[z\_1] + Abs[z\_2]], "\< ?  \>", 
        Abs[z\_1 + z\_2] \[LessEqual] 
          Abs[z\_1] + Abs[z\_2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\t",
  "We can also establish other important identities by means of the triangle \
inequality. Note that",
  "  \n\t\n\t\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(z\_1\)\(|\)\) = \(\(|\)\(\((z\_1 + 
                z\_2)\) + \((\(-z\_2\))\)\)\(|\)\)\)]],
  "  \n\t\t\t\t",
  Cell[BoxData[
      \(\(\(\ \ \ \ \ \ \ \ \ \ \ \ \)\(\(\[LessEqual]\)\(\(|\)\(z\_1 + 
            z\_2\)\(|\)\(+\(\(|\)\(-z\_2\)\(|\)\)\)\)\)\)\)]],
  "  \n\t\t\t\t",
  Cell[BoxData[
      \(\(\(\ \ \ \ \ \ \ \ \ \ \ \ \)\(\(\[LessEqual]\)\(\(|\)\(z\_1 + 
            z\_2\)\(|\)\(+\(\(|\)\(z\_2\)\(|\)\)\)\)\)\)\)]],
  ".  \n\nSubtracting ",
  Cell[BoxData[
      \(\(\(|\)\(z\_2\)\(|\)\)\)]],
  " from the left and right sides of this string of inequalities gives an \
important relationship that will be used in determining lower bounds of sums \
of complex numbers: \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(z\_1 + 
          z\_2\)\(|\)\(\(\[GreaterEqual]\)\(\(|\)\(z\_1\)\(|\)\(-\(\(|\)\(z\_\
2\)\(|\)\)\)\)\)\)\)]],
  ".  \n"
}], "Text"],

Cell[TextData[{
  "Using the identity  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\( | \^2\)\) = z\ \(\(z\)\(\ \)\)\&_\)]],
  "  and the commutative and associative laws it follows that  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(\(z\_1\) 
            z\_2\)\( | \^2\)\) = \((\(z\_1\) 
              z\_2)\)\ \(\((\(z\_1\) z\_2)\)\(\ \)\)\&_\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(\(=\)\(\((z\_1\ \
\(\(z\_1\)\(\ \)\)\&_)\) \((z\_2\ \(\(z\_2\)\(\ \)\)\&_)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(\(=\)\(\(|\)\(z\_1\)\( \
| \^2\)\(|\)\(z\_2\)\( | \^2\)\)\)\)\)]],
  "  \n\nTaking square roots of the terms on the left and right establishes \
another important identity  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(\(z\_1\) z\_2\)\(|\)\) = \(\(|\)\(z\_1 || z\_2\)\(|\)\)\)]],
  ".  \n\nAs an exercise, we ask you to show\n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(z\_1\/z\_2\)\(|\)\) = \
\(\(|\)\(z\_1\)\(|\)\)\/\(\(|\)\(z\_2\)\(|\)\)\)]],
  ", provided   ",
  Cell[BoxData[
      \(z\_2 \[NotEqual] 0\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example  1.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the values  ",
  Cell[BoxData[
      \(z\_1 = \(1 + 2  \[ImaginaryI]\ \ and\ \ z\_2 = 
          3 + 2  \[ImaginaryI]\)\)]],
  ",  then  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_1\)\(|\)\) = \(\@\(1 + 4\) = \@5\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_2\)\(|\)\) = \(\@\(9 + 4\) = \@13\)\)]],
  ".  Also  ",
  Cell[BoxData[
      \(\(z\_1\) 
          z\_2 = \(\((1 + 2  \[ImaginaryI])\) \((3 + 
                2  \[ImaginaryI])\) = \(-1\) + 8\ \[ImaginaryI]\)\)]],
  ";  hence  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(\(z\_1\) 
            z\_2\)\(|\)\) = \(\@\(1 + 64\) = \(\@65 = \(\(\@5\) \@13 = \
\(\(|\)\(z\_1 || z\_2\)\(|\)\)\)\)\)\)]],
  ",  \nthus \n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(\(z\_1\) z\_2\)\(|\)\) = \(\(|\)\(z\_1 || z\_2\)\(|\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Compute ",
  Cell[BoxData[
      \(\(\(|\)\(\(z\_1\) z\_2\)\(|\)\(\ \ \)\(and\)\(\ \ \)\(|\)\(z\_1 || 
          z\_2\)\(|\)\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[z];\)\ \), "\n", 
    \(\(z\_1\  = \ 1\  + \ 2  \[ImaginaryI];\)\ \), "\n", 
    \(\(z\_2\  = \ 3\  + \ 2  \[ImaginaryI];\)\ \), "\n", 
    \(\(z\_3\  = \ z\_1\ z\_2;\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        Graphics[{Red, 
            Arrow[{0, \ 0}, {Re[z\_1], Im[z\_1]}, 
              HeadScaling \[Rule] Absolute]}];\)\ \), "\n", 
    \(\(V\_2\  = \ 
        Graphics[{Green, 
            Arrow[{0, 0}, {Re[z\_2], Im[z\_2]}, 
              HeadScaling \[Rule] Absolute]}];\)\ \), "\n", 
    \(\(V\_3\  = \ 
        Graphics[{Blue, 
            Arrow[{0, \ 0}, {Re[z\_3], Im[z\_3]}, 
              HeadScaling \[Rule] Absolute]}];\)\ \), "\n", 
    \(\(Show[V\_1, V\_2, V\_3, PlotRange \[Rule] {{\(-1\), 3}, {0, 8}}, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[0, 8, 1]}, 
        AspectRatio \[Rule] 2, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\""\ , \ z\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\""\ , \ z\_2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\) \!\(z\_2\) = \>\""\ , \ z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<|\!\(z\_1\)| = \>\""\ , \ Abs[z\_1]];\)\ \), "\n", 
    \(\(Print[\*"\"\<|\!\(z\_2\)| = \>\""\ , \ 
        Abs[z\_2]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\< |\!\(z\_1\) \!\(z\_2\)| = \>\""\ , \ 
        Abs[z\_1\ z\_2]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|\!\(z\_1\)||\!\(z\_2\)| = \>\"", \ Abs[z\_1], 
        Abs[z\_2]];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is |\!\(z\_1\) \!\(z\_2\)| = |\!\(z\_1\)||\!\(z\_2\)| ?  \
\>\"", \n\ \ Abs[z\_1\ z\_2]\  \[Equal] \ 
          Abs[z\_1]\ Abs[z\_2]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\< |\!\(z\_1\) \!\(z\_2\)| = \>\"", \ 
        N[Abs[z\_1\ z\_2]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<|\!\(z\_1\)||\!\(z\_2\)| = \>\"", \ 
        N[Abs[z\_1] Abs[z\_2]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is |\!\(z\_1\) \!\(z\_2\)| = |\!\(z\_1\)||\!\(z\_2\)| ?  \
\>\"", \n\ \ Abs[z\_1\ z\_2]\  \[Equal] \ 
          Abs[z\_1]\ Abs[z\_2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tFigure 1.10 illustrates the multiplication shown in Example1.6.  The \
length of the ",
  Cell[BoxData[
      \(\(z\_1\) z\_2\)]],
  " vector apparently equals the product of the lengths of ",
  Cell[BoxData[
      RowBox[{\(z\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(z\_2\)}]]],
  ", confirming that  ",
  Cell[BoxData[
      \(\(\(|\)\(\(z\_1\) z\_2\)\(|\)\) = \(\(|\)\(z\_1 || z\_2\)\(|\)\)\)]],
  ",  but why is it located in the second quadrant when both ",
  Cell[BoxData[
      RowBox[{\(z\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(z\_2\)}]]],
  "are in the first quadrant?  The answer to this question will become \
apparent to you in Section 1.4.."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000560001>2000`400?l0
0000o`00003oo`3ooom70?ooo`00o`3ooom70?ooo`00N03oool40000odP0
oooo0`00000R0?ooo`800000;P3oool3000002X0oooo001g0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0A03oool01@000000oooo
0?ooo`3oool0000002<0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0Y0?ooo`00M`3oool60000odH0oooo00D000000?ooo`3oool0
oooo0000000T0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0:@3oool006`0oooo10000?l30?ooo`T0003o0`3oool90000o`80oooo
0`000?l60?ooo`@0003o00<0oooo0000o`000?l00P3oool40000o`80oooo
0`000?l:0?ooo`<000000`3oool3000000040?ooo`00000000000?ooo`80
00001P3oool300000080oooo0P0000030?ooo`<000000P3oool300000004
0?ooo`00000000000?ooo`80000000<0oooo0000000000000`3oool20000
00040?ooo`0000000000000000@0oooo00<000000?ooo`3oool01@3oool3
00000080oooo0`0000040?ooo`<0000000@0oooo000000000000oooo0P00
00020?ooo`L0000000@0oooo000000000000oooo0`0000000`3oool00000
0?ooo`0200000080oooo1P0000000`3oool00000000000030?ooo`@00000
00@0oooo000000000000oooo0`000000103oool000000000000000020?oo
o`<0000000D0oooo000000000000oooo000000010?ooo`00K@3oool20000
o`D0oooo0P000?l00`3oool0003o0?ooo`050?ooo`80003o00<0oooo0000
o`000?l00P3oool20000o`80oooo0P000?l20?ooo`030000o`3oool0oooo
00@0oooo0P000?l20?ooo`80003o0`3oool20000o`80oooo0P000?l00`3o
ool0003o0000o`0:0?ooo`030000003oool0oooo00<0oooo00H000000?oo
o`3oool000000?ooo`0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000
oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`800000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool000000080
oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0000000<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`00K@3oool20000o`D0oooo0P000?l20?oo
o`<0003o0`3oool20000o`030?ooo`000?l0003o0080oooo0P000?l20?oo
o`80003o2@3oool20000o`L0oooo0P000?l20?ooo`80003o00<0oooo0000
o`000?l02P3oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo
0000003oool00000203oool200000080oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo000000050?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo000000050?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?oo
o`0000040?ooo`040000003oool0oooo00000080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`00K@3oool20000o`030?ooo`000?l0
oooo0080oooo0P000?l0103oool0003o0000o`3oool20000o`80oooo0P00
0?l00`3oool0003o0000o`020?ooo`80003o0P3oool50000o`H0oooo0P00
0?l70?ooo`80003o0P3oool20000o`030?ooo`000?l0003o00X0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`000000oooo00@00000
103oool01@000000oooo0?ooo`000000oooo00@0000000<0oooo0000003o
ool00P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0000003oool0100000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?ooo`000005
0?ooo`<000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080
oooo001]0?ooo`@0003o0`3oool20000o`040?ooo`000?l0003o0?ooo`80
003o0P3oool20000o`030?ooo`000?l0003o0080oooo0P000?l01@3oool0
003o0000o`000?l0oooo0080003o1P3oool20000o`L0oooo0P000?l20?oo
o`80003o00<0oooo0000o`000?l02P3oool00`000000oooo0?ooo`030?oo
o`80000000@0oooo0000003oool000000P3oool00`000000oooo0?ooo`02
0?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo
000000030?ooo`030000003oool0oooo0080000000L0oooo000000000000
oooo0000003oool000000080oooo00@000000?ooo`3oool000000`3oool2
00000080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`800000
00D0oooo000000000000oooo000000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`02
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0000
00020?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo000000030?ooo`030000003oool0oooo00800000
00<0oooo0000003oool00`3oool006d0oooo0P000?l0103oool0003o0?oo
o`3oool30000o`80oooo20000?l0103oool0003o0000o`3oool50000o`04
0?ooo`000?l0003o0000o`L0oooo0P000?l70?ooo`80003o0P3oool20000
o`030?ooo`000?l0003o00X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000030?ooo`8000001P3oool4000000030?ooo`0000000000
00<0oooo0`0000020?ooo`80000000D0oooo0000003oool0oooo00000003
0?ooo`8000000P3oool3000000040?ooo`00000000000?ooo`@0000000@0
oooo0000000000000000103oool300000080oooo0`0000040?ooo`800000
00D0oooo0000003oool0oooo000000020?ooo`80000000<0oooo00000000
00000P3oool00`000000oooo00000002000000040?ooo`00000000000?oo
o`80000000<0oooo0000000000000`3oool010000000oooo000000000002
0?ooo`<000000P3oool200000080oooo0`0000000`3oool0000000000002
0?ooo`<000000P3oool2000000030?ooo`000000oooo00@0oooo001]0?oo
o`80003o9@3oool20000o`L0oooo0P000?l20?ooo`80003o00<0oooo0000
o`000?l02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?oo
o`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0B0?ooo`00K@3oool20000o`<0oooo00@0003o0?oo
o`000?l0003o7P3oool20000o`L0oooo0P000?l20?ooo`80003o00<0oooo
0000o`000?l01`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002/0oooo00<000000?ooo`3oool05@3oool010000000oooo
0?ooo`00000B0?ooo`040000003oool0oooo000000d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`00K03oool70000o`03
0?ooo`000?l0003o01d0oooo0`000?l60?ooo`<0003o0`3oool30000o`P0
oooo1`0000000`3oool00000000000140?ooo`<000004@3oool2000000H0
oooo00<000000?ooo`3oool01P3oool200000080oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`00o`3ooom70?ooo`00o`3o
oom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00
o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?oo
o`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3o
oom70?ooo`00o`3ooom70?ooo`00L`3oool5000003D0oooo1@00000J0?oo
o`@00000703oool2000005P0oooo001e0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0L0?ooo`04
0000003oool0oooo000005L0oooo001e0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo05H0oooo001]0?ooo`@00000103oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`1E0?ooo`00M@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo01X0oooo00@000000?ooo`3oool00000
6`3oool010000000oooo0?ooo`00001G0?ooo`00M03oool2000003P0oooo
0P00000M0?ooo`8000007@3oool2000005P0oooo003o0?ooodL0oooo003o
0?ooodL0oooo003c0?ooo`80000000<0oooo000000000000CP3oool00?@0
oooo00<000000?ooo`000000C`3oool00780oooo7P0000000`000?l00000
0000001K000000L0oooo00<000000?ooo`3oool0CP3oool00900oooo00<0
003o003o0000o`00H03oool2000000030?ooo`000000000004h0oooo002@
0?ooo`040000o`3o0000oooo003o0;80oooo002@0?ooo`040000o`3oool0
o`000?ooo`800?l0/03oool00900oooo00<0003o0?ooo`3o00000`3oool0
0`00o`00oooo0?ooo`2]0?ooo`00S`3oool01@000?l000000?ooo`3oool0
o`0000<0oooo0P00o`2]0?ooo`00S`3oool01@000?l000000?ooo`3oool0
o`0000D0oooo00<00?l00?ooo`3oool0ZP3oool008l0oooo00<0003o0000
003oool00P3oool00`3o0000oooo0?ooo`030?ooo`800?l0ZP3oool008l0
oooo00<0003o0000003oool00P3oool00`3o0000oooo0?ooo`050?ooo`03
003o003oool0oooo0:L0oooo002?0?ooo`030000o`000000oooo00<0oooo
00<0o`000?ooo`3oool01@3oool2003o0:L0oooo002?0?ooo`030000o`00
0000oooo00<0oooo00<0o`000?ooo`3oool01`3oool2003o0:D0oooo002?
0?ooo`030000o`000000oooo00@0oooo00<0o`000?ooo`3oool0203oool0
0`00o`00oooo0?ooo`2R0?ooo`00S`3oool00`000?l000000?ooo`040?oo
o`030?l0003oool0oooo00T0oooo0P00o`2R0?ooo`00SP3oool00`000?l0
oooo000000060?ooo`030?l0003oool0oooo00X0oooo00<00?l00?ooo`3o
ool0W`3oool008h0oooo00<0003o0?ooo`0000001P3oool00`3o0000oooo
0?ooo`0;0?ooo`800?l0W`3oool008h0oooo00<0003o0?ooo`0000001`3o
ool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo09`0oooo002>
0?ooo`030000o`3oool0000000L0oooo00<0o`000?ooo`3oool03@3oool2
003o09`0oooo002>0?ooo`030000o`3oool0000000P0oooo00<0o`000?oo
o`3oool03P3oool00`00o`00oooo0?ooo`2I0?ooo`00SP3oool00`000?l0
oooo000000080?ooo`030?l0003oool0oooo00l0oooo0P00o`2I0?ooo`00
SP3oool00`000?l0oooo000000090?ooo`030?l0003oool0oooo0100oooo
00<00?l00?ooo`3oool0UP3oool008h0oooo00<0003o0?ooo`0000002@3o
ool00`3o0000oooo0?ooo`0A0?ooo`800?l0UP3oool008d0oooo00@0003o
0?ooo`3oool000002P3oool00`3o0000oooo0?ooo`0B0?ooo`03003o003o
ool0oooo09<0oooo002=0?ooo`040000o`3oool0oooo000000X0oooo00<0
o`000?ooo`3oool04`3oool2003o09<0oooo002=0?ooo`040000o`3oool0
oooo000000/0oooo00<0o`000?ooo`3oool0503oool00`00o`00oooo0?oo
o`2@0?ooo`00S@3oool010000?l0oooo0?ooo`00000;0?ooo`030?l0003o
ool0oooo01D0oooo0P00o`2@0?ooo`00S@3oool010000?l0oooo0?ooo`00
000<0?ooo`030?l0003oool0oooo01H0oooo00<00?l00?ooo`3oool0S@3o
ool008d0oooo00@0003o0?ooo`3oool00000303oool00`3o0000oooo0?oo
o`0G0?ooo`800?l0S@3oool008d0oooo00@0003o0?ooo`3oool000003@3o
ool00`3o0000oooo0?ooo`0H0?ooo`03003o003oool0oooo08X0oooo002=
0?ooo`040000o`3oool0oooo000000d0oooo00<0o`000?ooo`3oool06@3o
ool2003o08X0oooo002:0?ooo`80000000D0003o000000000000oooo0000
000>0?ooo`030?l0003oool0oooo01X0oooo00<00?l00?ooo`3oool0Q`3o
ool008`0oooo00D0003o0?ooo`3oool0oooo0000000>0?ooo`030?l0003o
ool0oooo01/0oooo0P00o`270?ooo`00S03oool010000?l0oooo0?ooo`3o
ool2000000h0oooo00<0o`000?ooo`3oool0703oool2003o08D0oooo002<
0?ooo`050000o`3oool0oooo0?ooo`0000003`3oool00`3o0000oooo0?oo
o`0N0?ooo`03003o003oool0oooo0880oooo002<0?ooo`050000o`3oool0
oooo0?ooo`000000403oool00`3o0000oooo0?ooo`0N0?ooo`800?l0PP3o
ool008/0oooo00<000000000o`3oool00P3oool00`000000oooo0?ooo`0>
0?ooo`030?l0003oool0oooo0200oooo00<00?l00?ooo`3oool0O`3oool0
08`0oooo00D0003o0?ooo`3oool0oooo0000000A0?ooo`030?l0003oool0
oooo0200oooo0P00o`1o0?ooo`00S03oool01@000?l0oooo0?ooo`3oool0
00000140oooo00<0o`000?ooo`3oool08P3oool00`00o`00oooo0?ooo`1l
0?ooo`00S03oool01@000?l0oooo0?ooo`3oool000000180oooo00<0o`00
0?ooo`3oool08P3oool2003o07`0oooo002;0?ooo`030000o`3oool0oooo
0080oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`0T0?oo
o`03003o003oool0oooo07T0oooo002;0?ooo`030000o`3oool0oooo0080
oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0T0?ooo`80
0?l0N@3oool008/0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo
0?ooo`0A0?ooo`030?l0003oool0oooo02H0oooo00<00?l00?ooo`3oool0
MP3oool008/0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?oo
o`0B0?ooo`030?l0003oool0oooo02H0oooo0P00o`1f0?ooo`00R`3oool0
0`000?l0oooo0?ooo`020?ooo`030000003oool0oooo0180oooo00<0o`00
0?ooo`3oool0:03oool00`00o`00oooo0?ooo`1c0?ooo`00R`3oool00`00
0?l0oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo00<0o`000?oo
o`3oool0:03oool2003o07<0oooo002;0?ooo`030000o`3oool0oooo0080
oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0Z0?ooo`03
003o003oool0oooo0700oooo002;0?ooo`030000o`3oool0oooo0080oooo
00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`0Z0?ooo`800?l0
L03oool008X0oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?oo
o`0D0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool09`3o
ool00`00o`00oooo0?ooo`1]0?ooo`00RP3oool00`000?l0oooo0?ooo`03
0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3o00000P3o000Z
0?ooo`800?l0K@3oool008X0oooo00<0003o0?ooo`3oool00`3oool00`00
0000oooo0?ooo`0E0?ooo`D0o`00;03oool00`00o`00oooo0?ooo`1Z0?oo
o`00RP3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo01<0
oooo203o000/0?ooo`800?l0JP3oool008X0oooo00<0003o0?ooo`3oool0
0`3oool00`000000oooo0?ooo`0B0?ooo`T0o`00;P3oool00`00o`00oooo
0?ooo`040?ooo`03003o003oool0oooo0600oooo002:0?ooo`030000o`3o
ool0oooo00<0oooo00<000000?ooo`3oool04`3oool80?l002l0oooo0P00
o`030?ooo`<00?l0H@3oool008X0oooo00<0003o0?ooo`3oool00`3oool0
0`000000oooo0?ooo`0D0?ooo`L0o`00<@3oool2003o00030?ooo`00o`00
0?l000800?l0H03oool008X0oooo00<0003o0?ooo`3oool00`3oool00`00
0000oooo0?ooo`0E0?ooo`H0o`00<`3oool6003o05l0oooo00290?ooo`03
0000o`3oool0oooo00@0oooo00<000000?ooo`3oool05P3oool60?l00340
oooo2000o`1N0?ooo`00R@3oool00`000?l0oooo0?ooo`040?ooo`030000
003oool0oooo01L0oooo1@3o000a0?ooo`T00?l0G@3oool008T0oooo00<0
003o0?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`D0o`00<03o
ool:003o05d0oooo00290?ooo`030000o`3oool0oooo00@0oooo00<00000
0?ooo`3oool0603oool40?l00380oooo2@00o`1L0?ooo`00R@3oool00`00
0?l0oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo0`3o000e0?oo
o`L00?l0F`3oool008T0oooo00<0003o0000000000000P0000020?ooo`03
0000003oool0oooo01X0oooo0`3o000f0?ooo`H00?l0FP3oool008T0oooo
00<0003o0000003oool0103oool00`000000oooo0?ooo`0K0?ooo`80o`00
>@3oool4003o05T0oooo00290?ooo`030000o`3oool0000000@0oooo0P00
000M0?ooo`030?l0003oool0oooo03X0oooo0P00o`1H0?ooo`00R03oool0
1@000?l0oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0/`3o
ool008P0oooo00<0003o0?ooo`0000000P3oool010000000oooo0?ooo`00
002e0?ooo`00R03oool00`000?l0oooo0?ooo`02000000<0oooo00<00000
0?ooo`3oool0/`3oool008P0oooo00<0003o0?ooo`3oool01@3oool00`00
0000oooo0?ooo`2c0?ooo`00R03oool00`000?l0oooo0?ooo`050?ooo`03
0000003oool0oooo0;<0oooo00280?ooo`030000o`3oool0oooo00D0oooo
00<000000?ooo`3oool0/`3oool008P0oooo00<0003o0?ooo`3oool01@3o
ool00`000000oooo0?ooo`2c0?ooo`00R03oool00`000?l0oooo0?ooo`05
0?ooo`030000003oool0oooo0;<0oooo00270?ooo`030000o`3oool0oooo
00H0oooo00<000000?ooo`3oool0/`3oool008L0oooo00<0003o0?ooo`3o
ool01P3oool00`000000oooo0?ooo`2c0?ooo`00Q`3oool00`000?l0oooo
0?ooo`060?ooo`030000003oool0oooo0;<0oooo00270?ooo`030000o`3o
ool0oooo00H0oooo00<000000?ooo`3oool0/`3oool008L0oooo00<0003o
0?ooo`3oool01P3oool00`000000oooo0?ooo`2c0?ooo`00Q`3oool00`00
0?l0oooo0?ooo`060?ooo`030000003oool0oooo0;<0oooo00270?ooo`03
0000o`3oool0oooo00H0oooo00<000000?ooo`3oool0/`3oool008L0oooo
00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`2c0?ooo`00Q`3o
ool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo0;<0oooo0026
0?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3oool0/`3oool0
08H0oooo00<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`2c0?oo
o`00QP3oool00`000?l0oooo0?ooo`070?ooo`030000003oool0oooo0;<0
oooo00260?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3oool0
/`3oool008H0oooo00<0003o0?ooo`3oool01`3oool00`000000oooo0?oo
o`2c0?ooo`00QP3oool00`000?l0oooo0?ooo`070?ooo`030000003oool0
oooo0;<0oooo00260?ooo`030000o`3oool0oooo00L0oooo00<000000?oo
o`3oool0/`3oool008H0oooo00<0003o0?ooo`3oool01`3oool00`000000
oooo0?ooo`2c0?ooo`00Q@3oool00`000?l0oooo0?ooo`080?ooo`030000
003oool0oooo0;<0oooo00250?ooo`030000o`3oool0oooo00P0oooo00<0
00000?ooo`3oool0/`3oool008D0oooo00<0003o0?ooo`3oool0203oool0
0`000000oooo0?ooo`2c0?ooo`00Q@3oool00`000?l0oooo0?ooo`030?oo
o`8000000`3oool00`000000oooo0?ooo`2c0?ooo`00Q@3oool00`000?l0
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0/`3oool008D0oooo00<0003o0?ooo`3oool0103oool010000000
oooo0?ooo`3oool200000;@0oooo00250?ooo`030000o`3oool0oooo00D0
oooo00@000000?ooo`3oool00000]@3oool008D0oooo00<0003o0?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0;<0oooo00240?ooo`030000o`3oool0oooo00@0oooo0P0000030?ooo`03
0000003oool0oooo0;<0oooo00240?ooo`030000o`3oool0oooo00T0oooo
00<000000?ooo`3oool0/`3oool008@0oooo00<0003o0?ooo`3oool02@3o
ool00`000000oooo0?ooo`2c0?ooo`00Q03oool00`000?l0oooo0?ooo`09
0?ooo`030000003oool0oooo0;<0oooo00240?ooo`030000o`3oool0oooo
00T0oooo00<000000?ooo`3oool0/`3oool008@0oooo00<0003o0?ooo`3o
ool02@3oool00`000000oooo0?ooo`2c0?ooo`00Q03oool00`000?l0oooo
0?ooo`090?ooo`030000003oool0oooo0;<0oooo00240?ooo`030000o`3o
ool0oooo00T0oooo00<000000?ooo`3oool0/`3oool008<0oooo00<0003o
0?ooo`3oool02P3oool00`000000oooo0?ooo`2c0?ooo`00P`3oool00`00
0?l0oooo0?ooo`0:0?ooo`030000003oool0oooo0;<0oooo00230?ooo`03
0000o`3oool0oooo00X0oooo00<000000?ooo`3oool0/`3oool008<0oooo
00<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`2c0?ooo`00P`3o
ool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo0;<0oooo0023
0?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`3oool0/`3oool0
08<0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`2c0?oo
o`00P`3oool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo0;<0
oooo00230?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`3oool0
/`3oool00880oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?oo
o`2c0?ooo`00PP3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0
oooo0;<0oooo00220?ooo`030000o`3oool0oooo00/0oooo00<000000?oo
o`3oool0/`3oool00880oooo00<0003o0?ooo`3oool02`3oool00`000000
oooo0?ooo`2c0?ooo`00PP3oool00`000?l0oooo0?ooo`0;0?ooo`030000
003oool0oooo0;<0oooo00220?ooo`030000o`3oool0oooo00/0oooo00<0
00000?ooo`3oool0/`3oool00880oooo00<0003o0?ooo`3oool02`3oool0
0`000000oooo0?ooo`2c0?ooo`00PP3oool00`000?l0oooo0?ooo`0;0?oo
o`030000003oool0oooo0;<0oooo00210?ooo`030000o`3oool0oooo00`0
oooo00<000000?ooo`3oool0/`3oool00840oooo00<0003o0?ooo`3oool0
203oool3000000030?ooo`000000oooo0;@0oooo00210?ooo`030000o`3o
ool0oooo00T0oooo00@000000?ooo`3oool00000]@3oool00840oooo00<0
003o0?ooo`3oool01P3oool5000000030?ooo`00000000000;@0oooo0021
0?ooo`030000o`3oool0oooo00H0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`2c0?ooo`00P@3oool00`000?l0oooo0?ooo`07
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0/`3oool0
0840oooo00<0003o0?ooo`3oool0203oool200000080oooo00<000000?oo
o`3oool0/`3oool00840oooo00<0003o0?ooo`3oool0303oool00`000000
oooo0?ooo`2c0?ooo`00P03oool00`000?l0oooo0?ooo`0=0?ooo`030000
003oool0oooo0;<0oooo00200?ooo`030000o`3oool0oooo00d0oooo00<0
00000?ooo`3oool0/`3oool00800oooo00<0003o0?ooo`3oool03@3oool0
0`000000oooo0?ooo`2c0?ooo`00P03oool00`000?l0oooo0?ooo`0=0?oo
o`030000003oool0oooo0;<0oooo00200?ooo`030000o`3oool0oooo00d0
oooo00<000000?ooo`3oool0/`3oool00800oooo00<0003o0?ooo`3oool0
3@3oool00`000000oooo0?ooo`2c0?ooo`00P03oool00`000?l0oooo0?oo
o`0=0?ooo`030000003oool0oooo0;<0oooo00200?ooo`030000o`3oool0
oooo00d0oooo00<000000?ooo`3oool0/`3oool007l0oooo00<0003o0?oo
o`3oool03P3oool00`000000oooo0?ooo`2c0?ooo`00O`3oool00`000?l0
oooo0?ooo`0>0?ooo`030000003oool0oooo0;<0oooo001o0?ooo`030000
o`3oool0oooo00h0oooo00<000000?ooo`3oool0/`3oool007l0oooo00<0
003o0?ooo`3oool03P3oool00`000000oooo0?ooo`2c0?ooo`00O`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo0;<0oooo001o0?oo
o`030000o`3oool0oooo00h0oooo00<000000?ooo`3oool0/`3oool007l0
oooo00<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`2c0?ooo`00
O`3oool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo0;<0oooo
001o0?ooo`030000o`3oool0oooo00h0oooo00<000000?ooo`3oool0/`3o
ool007h0oooo00<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`2c
0?ooo`00OP3oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo
0;<0oooo001n0?ooo`030000o`3oool0oooo00l0oooo00<000000?ooo`3o
ool0/`3oool007h0oooo00<0003o0?ooo`3oool03`3oool00`000000oooo
0?ooo`2c0?ooo`00OP3oool00`000?l0oooo0?ooo`0?0?ooo`030000003o
ool0oooo0;<0oooo001n0?ooo`030000o`3oool0oooo00l0oooo00<00000
0?ooo`3oool0/`3oool007h0oooo00<0003o0?ooo`3oool03`3oool00`00
0000oooo0?ooo`2c0?ooo`00OP3oool00`000?l0oooo0?ooo`0:0?ooo`80
00000`3oool00`000000oooo0?ooo`2c0?ooo`00O@3oool00`000?l0oooo
0?ooo`0:0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0/`3oool007d0oooo00<0003o0?ooo`3oool03@3oool00`000000oooo
0?ooo`0200000;@0oooo001m0?ooo`030000o`3oool0oooo00/0oooo0P00
00030?ooo`030000003oool0oooo0;<0oooo001m0?ooo`030000o`3oool0
oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2c
0?ooo`00O@3oool00`000?l0oooo0?ooo`0;0?ooo`<000000P3oool00`00
0000oooo0?ooo`2c0?ooo`00O@3oool00`000?l0oooo0?ooo`0@0?ooo`03
0000003oool0oooo0;<0oooo001m0?ooo`030000o`3oool0oooo0100oooo
00<000000?ooo`3oool0/`3oool007d0oooo00<0003o0?ooo`3oool0403o
ool00`000000oooo0?ooo`2c0?ooo`00O03oool00`000?l0oooo0?ooo`0A
0?ooo`030000003oool0oooo0;<0oooo001l0?ooo`030000o`3oool0oooo
0140oooo00<000000?ooo`3oool0/`3oool007`0oooo00<0003o0?ooo`3o
ool04@3oool00`000000oooo0?ooo`2c0?ooo`00O03oool00`000?l0oooo
0?ooo`0A0?ooo`030000003oool0oooo0;<0oooo001l0?ooo`030000o`3o
ool0oooo0140oooo00<000000?ooo`3oool0/`3oool007`0oooo00<0003o
0?ooo`3oool04@3oool00`000000oooo0?ooo`2c0?ooo`00O03oool00`00
0?l0oooo0?ooo`0A0?ooo`030000003oool0oooo0;<0oooo001l0?ooo`03
0000o`3oool0oooo0140oooo00<000000?ooo`3oool0/`3oool007/0oooo
00<0003o0?ooo`3oool04P3oool00`000000oooo0?ooo`2c0?ooo`00N`3o
ool00`000?l0oooo0?ooo`0B0?ooo`030000003oool0oooo0;<0oooo001k
0?ooo`030000o`3oool0oooo0180oooo00<000000?ooo`3oool0/`3oool0
07/0oooo00<0003o0?ooo`3oool04P3oool00`000000oooo0?ooo`2c0?oo
o`00N`3oool00`000?l0oooo0?ooo`0B0?ooo`030000003oool0oooo0;<0
oooo001k0?ooo`030000o`3oool0oooo0180oooo00<000000?ooo`3oool0
/`3oool007/0oooo00<0003o0?ooo`3oool04P3oool00`000000oooo0?oo
o`2c0?ooo`00N`3oool00`000?l0oooo0?ooo`0B0?ooo`030000003oool0
oooo0;<0oooo001k0?ooo`030000o`3oool0oooo0180oooo00<000000?oo
o`3oool0/`3oool007X0oooo00<0003o0?ooo`3oool04`3oool00`000000
oooo0?ooo`2c0?ooo`00NP3oool00`000?l0oooo0?ooo`0C0?ooo`030000
003oool0oooo0;<0oooo001j0?ooo`030000o`3oool0oooo01<0oooo00<0
00000?ooo`3oool0/`3oool007X0oooo00<0003o0?ooo`3oool04`3oool0
0`000000oooo0?ooo`2c0?ooo`00NP3oool00`000?l0oooo0?ooo`0C0?oo
o`030000003oool0oooo0;<0oooo001j0?ooo`030000o`3oool0oooo00d0
oooo0`0000030?ooo`030000003oool0oooo0;<0oooo001j0?ooo`030000
o`3oool0oooo00d0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`2c0?ooo`00NP3oool00`000?l0oooo0?ooo`0=0?ooo`040000
003oool0oooo00000080oooo0P00002d0?ooo`00N@3oool00`000?l0oooo
0?ooo`0>0?ooo`<000000`3oool00`000000oooo0?ooo`2c0?ooo`00N@3o
ool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0/`3oool007T0oooo00<0003o0?ooo`3oool03`3oool3
00000080oooo00<000000?ooo`3oool0/`3oool007T0oooo00<0003o0?oo
o`3oool0503oool00`000000oooo0?ooo`2c0?ooo`00N@3oool00`000?l0
oooo0?ooo`0D0?ooo`030000003oool0oooo0;<0oooo001i0?ooo`030000
o`3oool0oooo01@0oooo00<000000?ooo`3oool0/`3oool007T0oooo00<0
003o0?ooo`3oool0503oool00`000000oooo0?ooo`2c0?ooo`00N@3oool0
0`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo0;<0oooo001h0?oo
o`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool0/`3oool007P0
oooo00<0003o0?ooo`3oool05@3oool00`000000oooo0?ooo`2c0?ooo`00
N03oool00`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo0;<0oooo
001h0?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool0/`3o
ool007P0oooo00<0003o0?ooo`3oool05@3oool00`000000oooo0?ooo`2c
0?ooo`00N03oool00`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo
0;<0oooo001h0?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3o
ool0/`3oool007P0oooo00<0003o0?ooo`3oool05@3oool00`000000oooo
0?ooo`2c0?ooo`00M`3oool00`000?l0oooo0?ooo`0F0?ooo`030000003o
ool0oooo0;<0oooo001g0?ooo`030000o`3oool0oooo01H0oooo00<00000
0?ooo`3oool0/`3oool007L0oooo00<0003o0?ooo`3oool05P3oool00`00
0000oooo0?ooo`2c0?ooo`00M`3oool00`000?l0oooo0?ooo`0F0?ooo`03
0000003oool0oooo0;<0oooo001g0?ooo`030000o`3oool0oooo01H0oooo
00<000000?ooo`3oool0/`3oool007L0oooo00<0003o0?ooo`3oool05P3o
ool00`000000oooo0?ooo`2c0?ooo`00M`3oool00`000?l0oooo0?ooo`0F
0?ooo`030000003oool0oooo0;<0oooo001g0?ooo`030000o`3oool0oooo
01H0oooo00<000000?ooo`3oool0/`3oool007H0oooo00<0003o0?ooo`3o
ool05`3oool00`000000oooo0?ooo`2c0?ooo`00MP3oool00`000?l0oooo
0?ooo`0G0?ooo`030000003oool0oooo0;<0oooo001f0?ooo`030000o`3o
ool0oooo01L0oooo00<000000?ooo`3oool0/`3oool007H0oooo00<0003o
0?ooo`3oool05`3oool00`000000oooo0?ooo`2c0?ooo`00MP3oool00`00
0?l0oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`000000]@3oool0
07H0oooo00<0003o0?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0
00000;D0oooo001f0?ooo`030000o`3oool0oooo01<0oooo00@000000?oo
o`3oool0oooo0P00002d0?ooo`00MP3oool00`000?l0oooo0?ooo`0D0?oo
o`040000003oool0oooo00000;D0oooo001f0?ooo`030000o`3oool0oooo
0140oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`2c
0?ooo`00M@3oool00`000?l0oooo0?ooo`0B0?ooo`@000000P3oool00`00
0000oooo0?ooo`2c0?ooo`00M@3oool00`000?l0oooo0?ooo`0H0?ooo`03
0000003oool0oooo0;<0oooo001e0?ooo`030000o`3oool0oooo01P0oooo
00<000000?ooo`3oool0/`3oool007D0oooo00<0003o0?ooo`3oool0603o
ool00`000000oooo0?ooo`2c0?ooo`00M@3oool00`000?l0oooo0?ooo`0H
0?ooo`030000003oool0oooo0;<0oooo001e0?ooo`030000o`3oool0oooo
01P0oooo00<000000?ooo`3oool0/`3oool007D0oooo00<0003o0?ooo`3o
ool0603oool00`000000oooo0?ooo`2c0?ooo`00M@3oool00`000?l0oooo
0?ooo`0H0?ooo`030000003oool0oooo0;<0oooo001d0?ooo`030000o`3o
ool0oooo01T0oooo00<000000?ooo`3oool0/`3oool007@0oooo00<0003o
0?ooo`3oool06@3oool00`000000oooo0?ooo`2c0?ooo`00M03oool00`00
0?l0oooo0?ooo`0I0?ooo`030000003oool0oooo0;<0oooo001d0?ooo`03
0000o`3oool0oooo01T0oooo00<000000?ooo`3oool0/`3oool007@0oooo
00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`2c0?ooo`00L03o
ool50000oa/0oooo00<000000?ooo`3oool0/`3oool00700oooo20000?lH
0?ooo`030000003oool0oooo0;<0oooo001`0?ooo`P0003o603oool00`00
0000oooo0?ooo`2c0?ooo`00L03oool70000oaT0oooo00<000000?ooo`3o
ool0/`3oool00740oooo1P000?lI0?ooo`030000003oool0oooo0;<0oooo
001a0?ooo`H0003o6@3oool00`000000oooo0?ooo`2c0?ooo`00L@3oool5
0000oaX0oooo00<000000?ooo`3oool0/`3oool00740oooo1@000?lJ0?oo
o`030000003oool0oooo0;<0oooo001a0?ooo`@0003o6`3oool00`000000
oooo0?ooo`2c0?ooo`00L@3oool40000oa/0oooo00<000000?ooo`3oool0
/`3oool00740oooo10000?lK0?ooo`030000003oool0oooo0;<0oooo001a
0?ooo`<0003o703oool00`000000oooo0?ooo`2c0?ooo`00LP3oool20000
oa`0oooo00<000000?ooo`3oool0/`3oool00780oooo0P000?lG0?ooo`80
00000`3oool00`000000oooo0?ooo`2c0?ooo`00LP3oool00`000?l0oooo
0?ooo`0E0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0/`3oool00780oooo00<0003o0?ooo`3oool05@3oool010000000oooo
0?ooo`0000020?ooo`800000]03oool008/0oooo0P00002i0?ooo`00RP3o
ool010000000oooo0?ooo`00002h0?ooo`00R`3oool200000;T0oooo003o
0?ooodL0oooo003o0?ooodL0oooo002?0?ooo`800000]@3oool00900oooo
00<000000?ooo`3oool0/`3oool00940oooo00<000000?ooo`3oool0/P3o
ool00900oooo00<000000?ooo`000000/`3oool008l0oooo00@000000?oo
o`3oool00000/`3oool008h0oooo0`0000000`3oool000000000002b0?oo
o`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3o
oom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00
\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{326, 312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Numbers",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexNumbersBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["History of Complex Numbers",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/HistoryComplexBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{988, 617},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 226363, 4153}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 209, 7, 33, "Text"],
Cell[2314, 71, 254, 5, 52, "Text"],
Cell[2571, 78, 1654, 57, 90, "Text"],
Cell[4228, 137, 15351, 255, 182, 15237, 251, "GraphicsData", "Bitmap", "Text",
  
  Evaluatable->False],
Cell[19582, 394, 693, 17, 71, "Text"],
Cell[20278, 413, 20682, 342, 211, 20568, 338, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[40963, 757, 368, 13, 33, "Text",
  Evaluatable->False],
Cell[41334, 772, 25078, 414, 269, 24964, 410, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[66415, 1188, 874, 27, 90, "Text",
  Evaluatable->False],
Cell[67292, 1217, 611, 21, 52, "Text",
  Evaluatable->False],
Cell[67906, 1240, 25102, 414, 262, 24988, 410, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[93011, 1656, 620, 18, 33, "Text",
  Evaluatable->False],
Cell[93634, 1676, 28860, 476, 262, 28746, 472, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[122497, 2154, 770, 22, 128, "Text",
  Evaluatable->False],
Cell[123270, 2178, 1027, 36, 90, "Text"],
Cell[124300, 2216, 553, 20, 52, "Text"],
Cell[124856, 2238, 25692, 424, 211, 25578, 420, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[150551, 2664, 365, 8, 90, "Text"],
Cell[150919, 2674, 309, 5, 52, "Text"],
Cell[151231, 2681, 24688, 408, 211, 24574, 404, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[175922, 3091, 982, 30, 90, "Text"],
Cell[176907, 3123, 9955, 233, 385, "Text",
  Evaluatable->False],
Cell[186865, 3358, 1243, 36, 147, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[188133, 3398, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[188296, 3404, 187, 7, 33, "Text"],
Cell[188486, 3413, 2786, 56, 565, "Input"]
}, Closed]],
Cell[191287, 3472, 1043, 27, 201, "Text"],
Cell[192333, 3501, 1138, 29, 267, "Text"],
Cell[193474, 3532, 961, 30, 109, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[194460, 3566, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[194623, 3572, 168, 6, 33, "Text"],
Cell[194794, 3580, 2345, 46, 550, "Input"]
}, Closed]],
Cell[197154, 3629, 1185, 32, 49, "Text"],
Cell[198342, 3663, 25965, 429, 326, 25851, 425, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[224310, 4094, 290, 7, 33, "Text"],
Cell[224603, 4103, 287, 7, 33, "Text"],
Cell[224893, 4112, 298, 7, 33, "Text"],
Cell[225194, 4121, 257, 5, 33, "Text"],
Cell[225454, 4128, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

