(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    284024,       5518]*)
(*NotebookOutlinePosition[    284867,       5549]*)
(*  CellTagsIndexPosition[    284790,       5543]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["1.4 The Geometry of Complex Numbers, Continued",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tIn Secion 1.3 we saw that a complex number  ",
  Cell[BoxData[
      \(z = x + \[ImaginaryI]\ y\)]],
  "  could be viewed as a vector in the xy-plane whose tail is at the origin \
and whose head is at the point ",
  StyleBox["(x,y)",
    FontFamily->"Courier New"],
  ".  A vector can be uniquely specified by giving its magnitude (i.e., its \
length) and direction (i.e., the angle it makes with the positive x-axis). In \
this section, we focus on these two geometric aspects of complex numbers."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\tLet ",
  StyleBox["r",
    FontFamily->"Courier New"],
  " be the modulus of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " (i.e., ",
  StyleBox["r = |z|",
    FontFamily->"Courier New"],
  "), and let  ",
  Cell[BoxData[
      \(\[Theta]\)]],
  "  be the angle that the line from the origin to the complex number ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " makes with the positive ",
  StyleBox["x",
    FontFamily->"Courier New"],
  "-axis. (Note: The number  ",
  Cell[BoxData[
      \(\[Theta]\)]],
  "  is undefined if ",
  StyleBox["z=0",
    FontFamily->"Courier New"],
  ").  We make the following definition."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Definition 1.9, (Polar Representation).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  " The identity \n\n\t\t\t",
  Cell[BoxData[
      \(z\  = \(\((r\ cos\ \[Theta], r\ sin\ \[Theta])\) = \ 
          r \((cos\ \[Theta]\  + \ i\ sin\ \[Theta])\)\)\)]],
  "  \n\nis known as a polar representation of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ", and the values ",
  StyleBox["r",
    FontFamily->"Courier New"],
  " and  ",
  Cell[BoxData[
      \(\[Theta]\)]],
  "  are called polar coordinates of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ", and is illustrated in Figure 1.11 (a)."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009U00017b000`400?l0
0000o`00003oo`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0
ooooo`3ooomW0?ooo`00[03oool40000oeH0oooo0`00001P0?ooo`<00000
n@3oool00:/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`1D0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0n03o
ool00:/0oooo1P000?mF0?ooo`030000003oool0oooo0600oooo00<00000
0?ooo`3oool0n03oool00:00oooo10000?l30?ooo`T0003o0`3oool90000
o`80oooo0`000?l60?ooo`@0003o00<0oooo0000o`000?l00P3oool40000
o`80oooo10000?l70?ooo`<000001@3oool300000080oooo0`0000000`3o
ool0000000000005000000@0oooo0`0000020?ooo`8000000`3oool01000
0000oooo0000000000020?ooo`<000000P3oool200000080oooo0`000003
0?ooo`8000000P3oool3000000040?ooo`00000000000?ooo`8000000P3o
ool4000000040?ooo`00000000000?ooo`<0000000@0oooo000000000000
00000P3oool3000000030?ooo`000000000000@0oooo0`0000020?ooo`<0
0000203oool2000000<0oooo0`0000020?ooo`<0000000@0oooo00000000
0000oooo0P0000000`3oool000000?ooo`0200000080oooo0`0000000`3o
ool00000000000020?ooo`80000000<0oooo0000000000000`3oool30000
00030?ooo`00000000000080oooo1`000000103oool000000000003oool2
000000040?ooo`0000000000000000<0oooo0P0000020?ooo`<0000000@0
oooo00000000000000000`3oool00`000000oooo0?ooo`2h0?ooo`00X@3o
ool20000o`D0oooo0P000?l00`3oool0003o0?ooo`050?ooo`80003o00<0
oooo0000o`000?l00P3oool20000o`80oooo0P000?l20?ooo`030000o`3o
ool0oooo00@0oooo0P000?l20?ooo`80003o0`3oool20000o`@0oooo0P00
0?l90?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool000000080oooo00@000000?ooo`3oool0
00001P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
008000000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0
oooo0000003oool000000P3oool00`000000oooo000000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`070000003oool0oooo0?ooo`000000oooo
000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`80
00000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00H00000
0?ooo`3oool000000?ooo`0000050?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000;d0oooo
002Q0?ooo`80003o1@3oool20000o`80oooo0`000?l30?ooo`80003o00<0
oooo0000o`000?l00P3oool20000o`80oooo0P000?l90?ooo`80003o1`3o
ool20000o`@0oooo0P000?l90?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool000000080oooo
00@000000?ooo`3oool000001P3oool010000000oooo0?ooo`0000050?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00060?ooo`80000000<0oooo0000003oool0103oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo000000030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00H000000?oo
o`3oool000000?ooo`0000060?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000050?ooo`030000003oool0oooo0080oooo0P00002m0?oo
o`00X@3oool20000o`030?ooo`000?l0oooo0080oooo0P000?l0103oool0
003o0000o`3oool20000o`80oooo0P000?l00`3oool0003o0000o`020?oo
o`80003o0P3oool50000o`H0oooo0P000?l70?ooo`80003o103oool20000
o`T0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00`0000020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0100000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`04000000030?ooo`00
0000000000<0oooo100000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool0oooo0`0000020?ooo`070000003oool0oooo0?oo
o`000000oooo000000030?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000<0oooo00D000000?ooo`3oool000000?oo
o`04000000<0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo000000030?ooo`030000003oool00000
00<000000P3oool00`000000oooo0?ooo`0200000;l0oooo002Q0?ooo`@0
003o0`3oool20000o`040?ooo`000?l0003o0?ooo`80003o0P3oool20000
o`030?ooo`000?l0003o0080oooo0P000?l01@3oool0003o0000o`000?l0
oooo0080003o1P3oool20000o`L0oooo0P000?l40?ooo`80003o2@3oool4
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool00P0000050?ooo`80000000D0
oooo0000003oool0oooo000000020?ooo`8000000P3oool00`000000oooo
0?ooo`02000000070?ooo`000000oooo0?ooo`000000oooo000000020?oo
o`030000003oool000000080oooo00<000000?ooo`3oool00P0000001@3o
ool000000?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`02000000030?ooo`000000oooo00<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00H0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`030000003oool0oooo0080000000D0
oooo000000000000oooo000000020?ooo`8000000P3oool01P000000oooo
0?ooo`000000oooo00000080oooo00H000000?ooo`3oool000000?ooo`00
00050?ooo`80000000D0oooo0000003oool0oooo000000020?ooo`030000
003oool0oooo0080000000H0oooo000000000000oooo0000003oool20000
0080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020000
00050?ooo`000000oooo0?ooo`000000_@3oool00:40oooo0P000?l0103o
ool0003o0?ooo`3oool30000o`80oooo20000?l0103oool0003o0000o`3o
ool50000o`040?ooo`000?l0003o0000o`L0oooo0P000?l70?ooo`80003o
103oool20000o`T0oooo00D000000?ooo`3oool0oooo000000020?ooo`<0
00000`3oool00`000000oooo0?ooo`0200000080oooo0P0000000`3oool0
00000?ooo`020?ooo`80000000<0oooo0000003oool00P0000020?ooo`80
000000<0oooo0000000000000P3oool2000000030?ooo`000000oooo0080
00000`3oool300000080oooo0P0000020?ooo`80000000@0oooo0000003o
ool0oooo0`0000020?ooo`8000000P3oool3000000030?ooo`0000000000
0080oooo0`0000020?ooo`80000000<0oooo0000003oool01@3oool30000
0080oooo0`0000080?ooo`<000000P3oool300000080oooo0P0000001@3o
ool000000?ooo`3oool000000080oooo0P0000000`3oool0000000000003
0?ooo`030000003oool0oooo008000000P3oool2000000030?ooo`000000
000000<0oooo0P000000103oool000000?ooo`3oool2000000040?ooo`00
000000000?ooo`80000000D0oooo0000003oool0oooo000000020?ooo`04
0000003oool00000000000<0oooo0P0000020?ooo`80000000<0oooo0000
003oool00`00002m0?ooo`00X@3oool20000obD0oooo0P000?l70?ooo`80
003o103oool20000o`T0oooo00D000000?ooo`3oool0oooo000000080?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`3=0?ooo`00X@3oool20000o`<0
oooo00@0003o0?ooo`000?l0003o7P3oool20000o`L0oooo0P000?l40?oo
o`80003o2@3oool01@000000oooo0?ooo`3oool0000000P0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01T0oooo00@000000?ooo`3oool000008@3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0<d0oooo002P0?ooo`L0003o00<0oooo
0000o`000?l07@3oool30000o`H0oooo0`000?l30?ooo`<0003o203oool5
000000P0oooo0P0000140?ooo`030000003oool0oooo01H0oooo0`00000P
0?ooo`8000008P3oool200000<l0oooo003o0?ooool0ooooI`3oool00?l0
ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3o
ool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0
ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o
0?ooool0ooooI`3oool004<0oooo00<000000?ooo`3oool0o`3ooom20?oo
o`030000003oool0oooo0=/0oooo00130?ooo`030000003oool0oooo0?l0
oooo@P3oool00`000000oooo0?ooo`3K0?ooo`00@`3oool00`000000oooo
0?ooo`3o0?oood80oooo00<000000?ooo`3oool0f`3oool004<0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0=l0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo07T0oooo00130?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3M
0?oooa00003oB03oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo07P0oooo00130?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool00`3oool5000000<0oooo00<000000?ooo`3oool0f03oool40000
o`030?ooo`000000oooo00d0oooo1P000?m10?ooo`040000003oool0oooo
0?ooo`D000001@3oool00`000000oooo0?ooo`1g0?ooo`00@`3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0=80oooo1P000?l5
0?ooo`030000003oool0oooo0180oooo10000?lm0?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo07L0oooo00130?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0cP3oool40000o`/0oooo00<000000?ooo`3oool05P3o
ool50000ocP0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool0M`3oool004<0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`030?ooo`@00000103o
ool00`000000oooo0?ooo`3<0?ooo`80003o3`3oool00`000000oooo0?oo
o`0K0?ooo`@0003o=03oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1g0?ooo`00@`3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0<X0oooo
0P000?lA0?ooo`030000003oool0oooo01l0oooo0P000?lb0?ooo`030000
003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0M`3oool004<0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`030?ooo`<000001@3oool00`000000oooo0?oo
o`380?ooo`80003o4`3oool00`000000oooo0?ooo`0Q0?ooo`80003o<03o
ool00`000000oooo0?ooo`020?ooo`040000003oool00000000000D0oooo
00<000000?ooo`3oool0M`3oool004<0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0<L0oooo0P00
0?lE0?ooo`030000003oool0oooo02<0oooo0P000?l_0?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`1h0?ooo`00@`3o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0aP3oool20000oaL0oooo00<000000?ooo`3oool09@3o
ool20000obh0oooo00@000000?ooo`00000000001P3oool00`000000oooo
0?ooo`1i0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooobL0oooo0P00
0?lI0?ooo`030000003oool0oooo02L0oooo0P000?nb0?ooo`00@`3oool0
0`000000oooo0?ooo`3o0?ooobD0oooo0P000?lK0?ooo`030000003oool0
oooo02T0oooo00<0003o0?ooo`3oool0[`3oool004<0oooo00<000000?oo
o`3oool0o`3ooolS0?ooo`80003o7@3oool00`000000oooo0?ooo`0Z0?oo
o`80003o[`3oool004<0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`03
0000o`3oool0oooo01d0oooo00<000000?ooo`3oool0;03oool00`000?l0
oooo0?ooo`2/0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooob00oooo
0P000?lP0?ooo`030000003oool0oooo02d0oooo0P000?n/0?ooo`00@`3o
ool00`000000oooo0?ooo`3o0?oooal0oooo00<0003o0?ooo`3oool0803o
ool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0oooo0:T0oooo0013
0?ooo`030000003oool0oooo0?l0oooo7P3oool00`000?l0oooo0?ooo`0Q
0?ooo`030000003oool0oooo0300oooo00<0003o0?ooo`3oool0Z03oool0
04<0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`80003o903oool00`00
0000oooo0?ooo`0a0?ooo`030000o`3oool0oooo0:L0oooo00130?ooo`03
0000003oool0oooo0?l0oooo6`3oool00`000?l0oooo0?ooo`0T0?ooo`03
0000003oool0oooo0380oooo00<0003o0?ooo`3oool0YP3oool004<0oooo
00<000000?ooo`3oool0o`3ooolJ0?ooo`030000o`3oool0oooo02D0oooo
00<000000?ooo`3oool0<`3oool20000ojH0oooo00130?ooo`030000003o
ool0oooo0?l0oooo6@3oool00`000?l0oooo0?ooo`0V0?ooo`030000003o
ool0oooo03D0oooo00<0003o0?ooo`3oool0X`3oool004<0oooo00<00000
0?ooo`3oool0o`3ooolH0?ooo`030000o`3oool0oooo02L0oooo00<00000
0?ooo`3oool0=P3oool00`000?l0oooo0?ooo`2R0?ooo`00@`3oool00`00
0000oooo0?ooo`3o0?oooaP0oooo00<0003o0?ooo`3oool09`3oool00`00
0000oooo0?ooo`0g0?ooo`030000o`3oool0oooo0:40oooo00130?ooo`03
0000003oool0oooo0?l0oooo5`3oool00`000?l0oooo0?ooo`0X0?ooo`03
0000003oool0oooo03P0oooo00<0003o0?ooo`3oool0X03oool004<0oooo
00<000000?ooo`3oool0o`3ooolF0?ooo`030000o`3oool0oooo02T0oooo
00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`2O0?ooo`00@`3o
ool00`000000oooo0?ooo`3o0?oooaD0oooo00<0003o0?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0j0?ooo`030000o`3oool0oooo09h0oooo0013
0?ooo`030000003oool0oooo0?l0oooo503oool00`000?l0oooo0?ooo`0[
0?ooo`030000003oool0oooo03X0oooo00<0003o0?ooo`3oool0WP3oool0
04<0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`030000o`3oool0oooo
02`0oooo00<000000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`2M0?oo
o`00@`3oool00`000000oooo0?ooo`3o0?oooa<0oooo00<0003o0?ooo`3o
ool0;03oool00`000000oooo0?ooo`0l0?ooo`030000o`3oool0oooo09`0
oooo00130?ooo`030000003oool0oooo0?l0oooo4P3oool00`000?l0oooo
0?ooo`0]0?ooo`030000003oool0oooo03d0oooo00<0003o0?ooo`3oool0
V`3oool004<0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`030000o`3o
ool0oooo02h0oooo00<000000?ooo`3oool0?P3oool00`000?l0oooo0?oo
o`2J0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0003o
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0
oooo09X0oooo00130?ooo`030000003oool0oooo0?l0oooo403oool00`00
0?l0oooo0?ooo`0_0?ooo`030000003oool0oooo03l0oooo00<0003o0?oo
o`3oool0V@3oool004<0oooo00<000000?ooo`3oool0o`3oool?0?ooo`03
0000o`3oool0oooo0300oooo00<000000?ooo`3oool0@03oool00`000?l0
oooo0?ooo`2H0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo
00<0003o0?ooo`3oool0;`3oool>0000ocP0oooo00<0003o0?ooo`3oool0
U`3oool004<0oooo00<000000?ooo`3oool0o`3oool>0?ooo`030000o`3o
ool0oooo02/0oooo10000?l20?ooo`030000003oool0oooo00T0oooo0P00
0?lf0?ooo`030000o`3oool0oooo09L0oooo00130?ooo`030000003oool0
oooo0?l0oooo3@3oool00`000?l0oooo0?ooo`0Z0?ooo`80003o1P3oool0
0`000000oooo0?ooo`0;0?ooo`@0003o<`3oool00`000?l0oooo0?ooo`2F
0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo00<0003o0?oo
o`3oool0:03oool20000o`P0oooo00<000000?ooo`3oool03`3oool30000
oc40oooo00<0003o0?ooo`3oool0U@3oool004<0oooo00<000000?ooo`3o
ool0o`3oool<0?ooo`030000o`3oool0oooo02L0oooo0P000?l:0?ooo`03
0000003oool0oooo0180oooo0P000?l`0?ooo`030000o`3oool0oooo09@0
oooo00130?ooo`030000003oool0oooo0?l0oooo303oool00`000?l0oooo
0?ooo`0T0?ooo`<0003o303oool00`000000oooo0?ooo`0D0?ooo`80003o
;P3oool00`000?l0oooo0?ooo`2D0?ooo`00@`3oool00`000000oooo0?oo
o`3o0?ooo`/0oooo00<0003o0?ooo`3oool08`3oool20000o`l0oooo00<0
00000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0/0?ooo`030000o`3o
ool0oooo09<0oooo00130?ooo`030000003oool0oooo0?l0oooo2`3oool0
0`000?l0oooo0?ooo`0Q0?ooo`80003o4@3oool00`000000oooo0?ooo`0G
0?ooo`030000o`3oool0oooo02/0oooo00<0003o0?ooo`3oool0T`3oool0
04<0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000o`3oool0oooo
0240oooo00<0003o0?ooo`3oool04@3oool00`000000oooo0?ooo`0H0?oo
o`80003o;03oool00`000?l0oooo0?ooo`2B0?ooo`00@`3oool00`000000
oooo0?ooo`3o0?ooo`X0oooo00<0003o0?ooo`3oool0803oool00`000?l0
oooo0?ooo`0B0?ooo`030000003oool0oooo01X0oooo00<0003o0?ooo`3o
ool0:@3oool00`000?l0oooo0?ooo`2B0?ooo`00@`3oool00`000000oooo
0?ooo`3o0?ooo`X0oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo
0?ooo`0C0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool0
:@3oool00`000?l0oooo0?ooo`2A0?ooo`00@`3oool00`000000oooo0?oo
o`3o0?ooo`X0oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo0?oo
o`0D0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0:03o
ool00`000?l0oooo0?ooo`2A0?ooo`00@`3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo0?ooo`0E
0?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool0:03oool0
0`000?l0oooo0?ooo`2@0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oo
o`T0oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`0F0?oo
o`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool09`3oool00`00
0?l0oooo0?ooo`2@0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooo`T0
oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`0F0?ooo`03
0000003oool0oooo01l0oooo00<0003o0?ooo`3oool09`3oool00`000?l0
oooo0?ooo`2?0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooo`T0oooo
00<0003o0?ooo`3oool0703oool00`000?l0oooo0?ooo`0G0?ooo`030000
003oool0oooo0200oooo00<0003o0?ooo`3oool09P3oool00`000?l0oooo
0?ooo`2?0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<0
003o0?ooo`3oool0703oool00`000?l0oooo0?ooo`0H0?ooo`030000003o
ool0oooo0200oooo00<0003o0?ooo`3oool09`3oool00`000?l0oooo0?oo
o`2>0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<0003o
0?ooo`3oool0703oool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0
oooo0240oooo00<0003o0?ooo`3oool09P3oool00`000?l0oooo0?ooo`2>
0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<0003o0?oo
o`3oool06`3oool00`000?l0oooo0?ooo`0I0?ooo`030000003oool0oooo
0280oooo00<0003o0?ooo`3oool09P3oool00`000?l0oooo0?ooo`2=0?oo
o`00@`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<0003o0?ooo`3o
ool06`3oool00`000?l0oooo0?ooo`0I0?ooo`030000003oool0oooo02<0
oooo00<0003o0?ooo`3oool09@3oool00`000?l0oooo0?ooo`2=0?ooo`00
@`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<0003o0?ooo`3oool0
6`3oool00`000?l0oooo0?ooo`0J0?ooo`030000003oool0oooo02<0oooo
00<0003o0?ooo`3oool09@3oool00`000?l0oooo0?ooo`2=0?ooo`00@`3o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo00<0003o0?ooo`3oool06`3o
ool00`000?l0oooo0?ooo`0J0?ooo`030000003oool0oooo02@0oooo00<0
003o0?ooo`3oool09@3oool00`000?l0oooo0?ooo`2<0?ooo`00@`3oool0
0`000000oooo0?ooo`2[0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0
oooo01/0oooo00<0003o0?ooo`3oool06`3oool00`000000oooo0?ooo`0T
0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool0G03oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool05@3oool004<0oooo00<000000?ooo`3oool0ZP3oool00`00
0000oooo0?ooo`090?ooo`800000303oool00`000000oooo0?ooo`0n0?oo
o`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool06`3oool00`00
0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo02@0oooo00<0003o0?oo
o`3oool0F`3oool00`000000oooo0?ooo`090?ooo`800000303oool00`00
0000oooo0?ooo`0D0?ooo`00@`3oool00`000000oooo0?ooo`2Y0?ooo`04
0000003oool0oooo0?ooo`8000000P3oool2000000@0oooo00<000000?oo
o`3oool00`3oool3000000D0oooo00<000000?ooo`3oool0?@3oool00`00
0?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo01`0oooo00<000000?oo
o`3oool09@3oool00`000?l0oooo0?ooo`0T0?ooo`030000o`3oool0oooo
05X0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`800000103oool0
0`000000oooo0?ooo`030?ooo`<000001@3oool00`000000oooo0?ooo`0C
0?ooo`00@`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000001@3oool2000000<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo03d0oooo00<0
003o0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0L0?ooo`030000003o
ool0oooo02D0oooo00<0003o0?ooo`3oool09@3oool00`000?l0oooo0?oo
o`1I0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
1@3oool2000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0:T0oooo
00<000000?ooo`3oool00`3oool2000000/0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo03d0oooo00<0003o0?ooo`3o
ool06P3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo02H0
oooo00<0003o0?ooo`3oool0903oool00`000?l0oooo0?ooo`1I0?ooo`03
0000003oool0oooo00<0oooo0P00000;0?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000
oooo0?ooo`2Y0?ooo`030000003oool0oooo00<0oooo0P00000;0?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0m0?oo
o`030000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool0703oool00`00
0000oooo0?ooo`0V0?ooo`030000o`3oool0oooo02@0oooo00<0003o0?oo
o`3oool0F@3oool00`000000oooo0?ooo`030?ooo`8000002`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool04`3oool0
04<0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000X0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo03d0oooo00<0003o0?ooo`3oool06P3o
ool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo02H0oooo00<0
003o0?ooo`3oool09@3oool00`000?l0oooo0?ooo`1H0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000002P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool04`3oool004<0oooo
00<000000?ooo`3oool0Z@3oool010000000oooo0?ooo`3oool200000080
oooo0P0000090?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`0m0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?oo
o`3oool07@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo
02@0oooo00<0003o0?ooo`3oool0F03oool010000000oooo0?ooo`3oool2
00000080oooo0P0000090?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`2Z
0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo03h0oooo00<0003o0?ooo`3oool06@3o
ool00`000?l0oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo00<0
003o0?ooo`3oool0903oool00`000?l0oooo0?ooo`1I0?ooo`030000003o
ool0oooo00l0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo01@0oooo00130?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool03`3oool3000000<0oooo00<000000?ooo`3oool0?`3o
ool00`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo01d0oooo00<0
00000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0S0?ooo`030000o`3o
ool0oooo05X0oooo00<000000?ooo`3oool03`3oool3000000<0oooo00<0
00000?ooo`3oool05@3oool004<0oooo00<000000?ooo`3oool0o`3oool6
0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool07@3oool0
0`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo02<0oooo00<0003o
0?ooo`3oool0RP3oool004<0oooo00<000000?ooo`3oool0o`3oool60?oo
o`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?oo
o`3oool0RP3oool004<0oooo00<000000?ooo`3oool0o`3oool60?ooo`03
0000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool07@3oool00`000000
oooo0?ooo`0X0?ooo`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3o
ool0R@3oool004<0oooo00<000000?ooo`3oool0]`3oool20?l004`0oooo
00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`0M0?ooo`030000
003oool0oooo02P0oooo00<0003o0?ooo`3oool0903oool00`000?l0oooo
0?ooo`1U0?ooo`80o`008P3oool004<0oooo00<000000?ooo`3oool0]P3o
ool40?l001@0oooo0P0000000`3oool000000000000b0?ooo`030000o`3o
ool0oooo01T0oooo00<0003o0?ooo`3oool07@3oool00`000000oooo0?oo
o`0Y0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0I03o
ool40?l001@0oooo0P0000000`3oool00000000000080?ooo`000P3ooom1
000000030000o`000000000004`0000000<0003o000000000000IP000006
0?l000`00000203oool00`000000oooo0000000^0?ooo`D0000000<0003o
0000000000006@0000000`000?l000000000000M000000030000o`000000
000001@0000000<0003o0000000000004P0000000`000?l000000000000S
000000030000o`000000000006<000001P3o000<000000P0oooo00<00000
0?ooo`0000002@3oool004<0oooo00<000000000o`000?l0C03oool00`00
0?l0oooo0?ooo`1V0?ooo`H0o`005@3oool00`000000oooo0?ooo`0b0?oo
o`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool07@3oool00`00
0000003o0000o`0D0?ooo`030000o`3oool0oooo0180oooo00<0003o0?oo
o`3oool08`3oool00`000?l0oooo0?ooo`1S0?ooo`H0o`005@3oool00`00
0000oooo0?ooo`080?ooo`00@`3oool010000000oooo0?ooo`000?m;0?oo
o`030000o`3oool0oooo06L0oooo103o000D0?ooo`80000000<0oooo0000
00000000<P3oool00`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo
01d0oooo00@000000?ooo`3oool0003o4`3oool00`000?l0oooo0?ooo`0B
0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0I03oool4
0?l001@0oooo0P0000000`3oool00000000000080?ooo`00@`3oool01@00
0000oooo0?ooo`3oool0003o04X0oooo00<0003o0?ooo`3oool0J03oool2
0?l004`0oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`0M
0?ooo`050000003oool0oooo0?ooo`000?l04P3oool00`000?l0oooo0?oo
o`0B0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0I@3o
ool20?l00280oooo00130?ooo`030000003oool0oooo0080oooo0P000?m8
0?ooo`030000o`3oool0oooo06T0oooo00<0o`000?ooo`3oool0B`3oool0
0`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo01`0oooo00<00000
0?ooo`3oool00P3oool20000oa00oooo00<0003o0?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`0S0?ooo`030000o`3oool0oooo06H0oooo00<0o`00
0?ooo`3oool0803oool004<0oooo00<000000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`150?ooo`030000o`3oool0oooo06T0oooo00<0o`000?oo
o`3oool0B`3oool00`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo
01`0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0=0?oo
o`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool08`3oool00`00
0?l0oooo0?ooo`1V0?ooo`030?l0003oool0oooo0200oooo00130?ooo`03
0000003oool0oooo00D0oooo00<0003o0?ooo`3oool0A03oool00`000?l0
oooo0?ooo`1Y0?ooo`030?l0003oool0oooo04/0oooo00<0003o0?ooo`3o
ool06@3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo00D0
oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0B0?ooo`03
0000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0IP3oool00`3o0000
oooo0?ooo`0P0?ooo`00@`3oool00`000000oooo0?ooo`060?ooo`80003o
A03oool00`000?l0oooo0?ooo`2g0?ooo`030000o`3oool0oooo01T0oooo
00<0003o0?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`80003o
303oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo02<0oooo
00<0003o0?ooo`3oool0R@3oool004<0oooo00<000000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`110?ooo`030000o`3oool0oooo0;L0oooo00<0
003o0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0K0?ooo`030000003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0B0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0R@3o
ool004<0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo0?ooo`10
0?ooo`030000o`3oool0oooo0;L0oooo00<0003o0?ooo`3oool06P3oool0
0`000?l0oooo0?ooo`0K0?ooo`030000003oool0oooo00T0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0
oooo02<0oooo00<0003o0?ooo`3oool0R@3oool004<0oooo00<000000?oo
o`3oool02P3oool20000od00oooo00<0003o0?ooo`3oool0^03oool00`00
0?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo01X0oooo00<000000?oo
o`3oool02P3oool20000o`L0oooo00<0003o0?ooo`3oool04`3oool00`00
0?l0oooo0?ooo`0S0?ooo`030000o`3oool0oooo08T0oooo00130?ooo`03
0000003oool0oooo00`0oooo00<0003o0?ooo`3oool0?@3oool00`000?l0
oooo0?ooo`1Y0?ooo`030?l0003oool0oooo04`0oooo00<0003o0?ooo`3o
ool06P3oool00`000?l0oooo0?ooo`0J0?ooo`030000003oool0oooo00`0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0B0?ooo`03
0000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool0IP3oool00`3o0000
oooo0?ooo`0P0?ooo`00@`3oool00`000000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo03/0oooo00<0003o0?ooo`3oool0JP3oool00`3o0000oooo
0?ooo`1=0?ooo`030000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool0
6@3oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0T0?ooo`030000
o`3oool0oooo06H0oooo00<0o`000?ooo`3oool0803oool004<0oooo00<0
00000?ooo`3oool03P3oool20000oc/0oooo00<0003o0?ooo`3oool0JP3o
ool00`3o0000oooo0?ooo`1=0?ooo`030000o`3oool0oooo01X0oooo00<0
003o0?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`80003o0P3o
ool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo02@0oooo00<0
003o0?ooo`3oool0IP3oool00`3o0000oooo0?ooo`0P0?ooo`00@`3oool0
0`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo03P0oooo00<0003o
0?ooo`3oool0JP3oool00`3o0000oooo0?ooo`1>0?ooo`030000o`3oool0
oooo01X0oooo00<0003o0?ooo`3oool0603oool00`000000oooo0?ooo`0@
0?ooo`80003o5P3oool00`000?l0oooo0?ooo`0T0?ooo`030000o`3oool0
oooo06H0oooo00<0o`000?ooo`3oool0803oool004<0oooo00<000000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0g0?ooo`030000o`3oool0oooo
06X0oooo00<0o`000?ooo`3oool0CP3oool00`000?l0oooo0?ooo`0J0?oo
o`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo02@0oooo00<0003o0?oo
o`3oool0IP3oool00`3o0000oooo0?ooo`0P0?ooo`00@`3oool00`000000
oooo0?ooo`0B0?ooo`80003o=P3oool00`000?l0oooo0?ooo`1[0?ooo`03
0?l0003oool0oooo04h0oooo00<0003o0?ooo`3oool06`3oool00`000?l0
oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00@0003o0?ooo`00
0?l0003o4`3oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo
06H0oooo00<0o`000?ooo`3oool0803oool004<0oooo00<000000?ooo`3o
ool0503oool00`000?l0oooo0?ooo`0c0?ooo`030000o`3oool0oooo0;`0
oooo00<0003o0?ooo`3oool0703oool00`000?l0oooo0?ooo`0F0?ooo`03
0000003oool0oooo00l0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0@0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3o
ool0R@3oool004<0oooo00<000000?ooo`3oool05@3oool00`000?l0oooo
0?ooo`0b0?ooo`030000o`3oool0oooo0;d0oooo00<0003o0?ooo`3oool0
703oool00`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0?0?ooo`030000
o`3oool0oooo02D0oooo00<0003o0?ooo`3oool0R@3oool004<0oooo00<0
00000?ooo`3oool05P3oool20000oc80oooo00<0003o0?ooo`3oool0_@3o
ool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo01@0oooo00<0
00000?ooo`3oool03P3oool00`000?l0oooo0?ooo`050?ooo`80003o3P3o
ool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo08T0oooo0013
0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool0;`3oool0
0`000?l0oooo0?ooo`2m0?ooo`030000o`3oool0oooo01h0oooo00<0003o
0?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00P0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0V
0?ooo`030000o`3oool0oooo08T0oooo00130?ooo`030000003oool0oooo
01T0oooo00<0003o0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`2o0?oo
o`030000o`3oool0oooo01h0oooo00<0003o0?ooo`3oool04P3oool00`00
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo
08X0oooo00130?ooo`030000003oool0oooo01X0oooo0P000?l]0?ooo`03
0000o`3oool0oooo00d0oooo1000001K0?ooo`030?l0003oool0oooo0500
oooo00<0003o0?ooo`3oool07`3oool20000oa80oooo00<000000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`80003o2@3oool00`000?l0
oooo0?ooo`0V0?ooo`030000o`3oool0oooo00P0oooo1000001K0?ooo`03
0?l0003oool0oooo0200oooo00130?ooo`030000003oool0oooo01`0oooo
00<0003o0?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0<0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0F03oool00`3o0000oooo
0?ooo`1A0?ooo`030000o`3oool0oooo0200oooo00<0003o0?ooo`3oool0
3`3oool00`000000oooo0?ooo`090?ooo`80003o4@3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05P0oooo
00<0o`000?ooo`3oool0803oool004<0oooo00<000000?ooo`3oool07@3o
ool00`000?l0oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1H0?ooo`030?l0003o
ool0oooo0580oooo00<0003o0?ooo`3oool0803oool20000o`l0oooo00<0
00000?ooo`3oool0203oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool09P3oool00`000?l0oooo0?oo
o`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0F03o
ool00`3o0000oooo0?ooo`0P0?ooo`00@`3oool00`000000oooo0?ooo`0N
0?ooo`80003o:03oool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0E`3oool00`3o0000oooo0?ooo`1B
0?ooo`030000o`3oool0oooo0280oooo00<0003o0?ooo`3oool0303oool0
0`000000oooo0?ooo`060?ooo`80003o5P3oool20000o`@0oooo00<0003o
0?ooo`3oool09P3oool00`000?l0oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0E`3oool00`3o0000oooo0?ooo`0P
0?ooo`00@`3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo
02D0oooo00<0003o0?ooo`3oool03@3oool7000005T0oooo00<0o`000?oo
o`3oool0D`3oool00`000?l0oooo0?ooo`0R0?ooo`80003o303oool00`00
0000oooo0?ooo`030?ooo`<0003o6P3oool01@000?l0oooo0?ooo`3oool0
003o02P0oooo00<0003o0?ooo`3oool0203oool7000005T0oooo00<0o`00
0?ooo`3oool0803oool004<0oooo00<000000?ooo`3oool08@3oool00`00
0?l0oooo0?ooo`0T0?ooo`030000o`3oool0oooo00d0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`1G0?ooo`030?l0003oool0oooo
05@0oooo00<0003o0?ooo`3oool08`3oool60000o`H0oooo00<000000?oo
o`000?l00`000?lN0?ooo`030000o`3oool0003o02T0oooo00<0003o0?oo
o`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
05L0oooo00<0o`000?ooo`3oool0803oool004<0oooo00<000000?ooo`3o
ool08P3oool20000ob@0oooo00<0003o0?ooo`3oool03P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0:h0oooo00<0003o0?ooo`3o
ool0:@3oool80000ob<0oooo0P000?lY0?ooo`030000o`3oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1j0?ooo`00
@`3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0200oooo
00<0003o0?ooo`3oool0403oool400000;80oooo00<0003o0?ooo`3oool0
;P3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0003o02P0oooo
00<0003o0?ooo`3oool02P3oool4000007d0oooo00130?ooo`030000003o
ool0oooo02D0oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?oo
o`370?ooo`030000o`3oool0oooo02d0oooo00<000000?ooo`3oool08P3o
ool010000?l0oooo0?ooo`000?lV0?ooo`030000o`3oool0oooo08`0oooo
00130?ooo`030000003oool0oooo02H0oooo0P000?lN0?ooo`030000o`3o
ool0oooo0<T0oooo00<0003o0?ooo`3oool0;03oool00`000000oooo0?oo
o`0Q0?ooo`030000o`3oool0oooo0080oooo0P000?lT0?ooo`030000o`3o
ool0oooo08`0oooo00130?ooo`030000003oool0oooo02P0oooo00<0003o
0?ooo`3oool06`3oool00`000?l0oooo0?ooo`1_0?ooo`030?l0003oool0
oooo05P0oooo00<0003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`0P
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool08@3oool0
0`000?l0oooo0?ooo`1Y0?ooo`030?l0003oool0oooo0200oooo00130?oo
o`030000003oool0oooo02T0oooo00<0003o0?ooo`3oool06@3oool00`00
0?l0oooo0?ooo`1`0?ooo`030?l0003oool0oooo05P0oooo00<0003o0?oo
o`3oool0:`3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`1Y0?oo
o`030?l0003oool0oooo0200oooo00130?ooo`030000003oool0oooo02X0
oooo0P000?lI0?ooo`030000o`3oool0oooo0700oooo00<0o`000?ooo`3o
ool0F@3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo01l0
oooo00<0003o0?ooo`3oool0203oool20000ob00oooo00<0003o0?ooo`3o
ool0J@3oool00`3o0000oooo0?ooo`0P0?ooo`00@`3oool00`000000oooo
0?ooo`0/0?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool0
L@3oool00`3o0000oooo0?ooo`1J0?ooo`030000o`3oool0oooo02T0oooo
00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0;0?ooo`030000
o`3oool0oooo01`0oooo00<0003o0?ooo`3oool0JP3oool00`3o0000oooo
0?ooo`0P0?ooo`00@`3oool00`000000oooo0?ooo`0]0?ooo`030000o`3o
ool0oooo01@0oooo00<0003o0?ooo`3oool0L@3oool00`3o0000oooo0?oo
o`1K0?ooo`030000o`3oool0oooo02P0oooo00<000000?ooo`3oool07@3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo01/0oooo00<0
003o0?ooo`3oool0JP3oool00`3o0000oooo0?ooo`0P0?ooo`00@`3oool0
0`000000oooo0?ooo`0^0?ooo`80003o4`3oool00`000?l0oooo0?ooo`1b
0?ooo`030?l0003oool0oooo05`0oooo00<0003o0?ooo`3oool09`3oool0
0`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00l0oooo0P000?lJ
0?ooo`030000o`3oool0oooo06/0oooo00<0o`000?ooo`3oool0803oool0
04<0oooo00<000000?ooo`3oool0<03oool00`000?l0oooo0?ooo`0?0?oo
o`030000o`3oool0oooo07<0oooo00<0o`000?ooo`3oool0G@3oool00`00
0?l0oooo0?ooo`0V0?ooo`030000003oool0oooo01/0oooo00<0003o0?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo
06/0oooo00<0o`000?ooo`3oool0803oool004<0oooo00<000000?ooo`3o
ool0<@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo0=@0
oooo0P000?lV0?ooo`030000003oool0oooo01X0oooo00<0003o0?ooo`3o
ool0503oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo08h0
oooo00130?ooo`030000003oool0oooo0380oooo0P000?l=0?ooo`030000
o`3oool0oooo0=L0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo
0?ooo`0I0?ooo`030000o`3oool0oooo01H0oooo0P000?lE0?ooo`030000
o`3oool0oooo08l0oooo00130?ooo`030000003oool0oooo03@0oooo00<0
003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`3H0?ooo`030000o`3o
ool0oooo0280oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?oo
o`0I0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0S`3o
ool004<0oooo00<000000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0oooo0=X0oooo0P000?lR0?ooo`030000003oool0
oooo01H0oooo0P000?lM0?ooo`030000o`3oool0oooo0140oooo00<0003o
0?ooo`3oool0S`3oool004<0oooo00<000000?ooo`3oool0=P3oool20000
o`P0oooo00<0003o0?ooo`3oool0M@3oool00`3o0000oooo0?ooo`1T0?oo
o`030000o`3oool0oooo01l0oooo00<000000?ooo`3oool05@3oool00`00
0?l0oooo0?ooo`0N0?ooo`80003o403oool00`000?l0oooo0?ooo`1]0?oo
o`030?l0003oool0oooo0200oooo00130?ooo`030000003oool0oooo03P0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1f0?ooo`03
0?l0003oool0oooo06D0oooo0P000?lO0?ooo`030000003oool0oooo01<0
oooo0P000?lS0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o
ool0K@3oool00`3o0000oooo0?ooo`0P0?ooo`00@`3oool00`000000oooo
0?ooo`0i0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
MP3oool00`3o0000oooo0?ooo`1W0?ooo`030000o`3oool0oooo01`0oooo
00<000000?ooo`3oool04@3oool20000obH0oooo00<0003o0?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`1^0?ooo`030?l0003oool0oooo0200oooo
00130?ooo`030000003oool0oooo03X0oooo0P000?l20?ooo`030000o`3o
ool0oooo07L0oooo00<0o`000?ooo`3oool0J03oool20000oa`0oooo00<0
00000?ooo`3oool03`3oool20000obT0oooo0P000?l;0?ooo`030000o`3o
ool0oooo06h0oooo00<0o`000?ooo`3oool0803oool004<0oooo00<00000
0?ooo`3oool0?03oool20000ogX0oooo00<0o`000?ooo`3oool0JP3oool2
0000oaX0oooo00<000000?ooo`3oool03@3oool20000obd0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`1_0?ooo`030?l0003oool0
oooo0200oooo00130?ooo`030000003oool0oooo03`0oooo0P000?mj0?oo
o`030?l0003oool0oooo06`0oooo0`000?lG0?ooo`030000003oool0oooo
00X0oooo0`000?l`0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool0K`3oool00`3o0000oooo0?ooo`0P0?ooo`00@`3oool00`000000
oooo0?ooo`0n0?ooo`80003ojP3oool40000oa<0oooo00<000000?ooo`3o
ool01`3oool30000oc@0oooo0P000?l50?ooo`030000o`3oool0oooo09<0
oooo00130?ooo`030000003oool0oooo0400oooo00<0003o0?ooo`3oool0
j`3oool40000o`l0oooo00<000000?ooo`3oool0103oool30000ocT0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`2C0?ooo`00@`3o
ool00`000000oooo0?ooo`110?ooo`030000o`3oool0oooo0>h0oooo1@00
0?l:0?ooo`03000000000?l0003o00@0003o?@3oool010000?l0oooo0?oo
o`000?nF0?ooo`00@`3oool00`000000oooo0?ooo`120?ooo`80003ol`3o
ool;0000od@0oooo0`000?nF0?ooo`00@`3oool00`000000oooo0?ooo`14
0?ooo`030000o`3oool0oooo0?X0oooo00<000000?ooo`3oool0@`3oool2
0000oiH0oooo00130?ooo`030000003oool0oooo04D0oooo00<0003o0?oo
o`3oool0L03oool00`3o0000oooo0?ooo`260?ooo`030000003oool0oooo
04D0oooo00<0003o0?ooo`3oool0L03oool00`3o0000oooo0?ooo`0P0?oo
o`00@`3oool00`000000oooo0?ooo`160?ooo`80003oL03oool00`3o0000
oooo0?ooo`260?ooo`030000003oool0oooo04H0oooo0P000?m`0?ooo`03
0?l0003oool0oooo0200oooo00130?ooo`030000003oool0oooo04P0oooo
00<0003o0?ooo`3oool0K@3oool00`3o0000oooo0?ooo`260?ooo`030000
003oool0oooo04P0oooo00<0003o0?ooo`3oool0K@3oool00`3o0000oooo
0?ooo`0P0?ooo`00@`3oool00`000000oooo0?ooo`190?ooo`030000o`3o
ool0oooo06`0oooo00<0o`000?ooo`3oool0QP3oool00`000000oooo0?oo
o`190?ooo`030000o`3oool0oooo06`0oooo00<0o`000?ooo`3oool0803o
ool004<0oooo00<000000?ooo`3oool0BP3oool20000of`0oooo00<0o`00
0?ooo`3oool0QP3oool00`000000oooo0?ooo`1:0?ooo`80003oK03oool0
0`3o0000oooo0?ooo`0P0?ooo`00@`3oool00`000000oooo0?ooo`1<0?oo
o`030000o`3oool0oooo06T0oooo00<0o`000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`1<0?ooo`030000o`3oool0oooo06T0oooo00<0o`000?oo
o`3oool0803oool004<0oooo00<000000?ooo`3oool0C@3oool00`000?l0
oooo0?ooo`3a0?ooo`030000003oool0oooo04d0oooo00<0003o0?ooo`3o
ool0R`3oool004<0oooo00<000000?ooo`3oool0CP3oool20000oo40oooo
00<000000?ooo`3oool0CP3oool20000oh/0oooo00130?ooo`030000003o
ool0oooo0500oooo00<0003o0?ooo`3oool0kP3oool00`000000oooo0?oo
o`1@0?ooo`030000o`3oool0oooo08P0oooo00130?ooo`030000003oool0
oooo0540oooo00<0003o0?ooo`3oool0k@3oool00`000000oooo0?ooo`1A
0?ooo`030000o`3oool0oooo08L0oooo00130?ooo`030000003oool0oooo
0580oooo0P000?mT0?ooo`030?l0003oool0oooo08H0oooo00<000000?oo
o`3oool0DP3oool20000of@0oooo00<0o`000?ooo`3oool0803oool004<0
oooo00<000000?ooo`3oool0E03oool00`000?l0oooo0?ooo`1Q0?ooo`03
0?l0003oool0oooo08H0oooo00<000000?ooo`3oool0E03oool00`000?l0
oooo0?ooo`1Q0?ooo`030?l0003oool0oooo0200oooo00130?ooo`030000
003oool0oooo05D0oooo00<0003o0?ooo`3oool0H03oool00`3o0000oooo
0?ooo`260?ooo`030000003oool0oooo05D0oooo00<0003o0?ooo`3oool0
H03oool00`3o0000oooo0?ooo`0P0?ooo`00@`3oool00`000000oooo0?oo
o`1F0?ooo`80003oH03oool00`3o0000oooo0?ooo`260?ooo`030000003o
ool0oooo05H0oooo0P000?mP0?ooo`030?l0003oool0oooo0200oooo0013
0?ooo`030000003oool0oooo05P0oooo00<0003o0?ooo`3oool0G@3oool0
0`3o0000oooo0?ooo`260?ooo`030000003oool0oooo05P0oooo00<0003o
0?ooo`3oool0G@3oool00`3o0000oooo0?ooo`0P0?ooo`00@`3oool00`00
0000oooo0?ooo`1I0?ooo`030000o`3oool0oooo00`0oooo1@00001;0?oo
o`030?l0003oool0oooo08H0oooo00<000000?ooo`3oool0F@3oool00`00
0?l0oooo0?ooo`0<0?ooo`D00000B`3oool00`3o0000oooo0?ooo`0P0?oo
o`00@`3oool00`000000oooo0?ooo`1J0?ooo`80003o3@3oool00`000000
oooo0?ooo`1<0?ooo`030?l0003oool0oooo08H0oooo00<000000?ooo`3o
ool0FP3oool20000o`d0oooo00<000000?ooo`3oool0C03oool00`3o0000
oooo0?ooo`0P0?ooo`00@`3oool00`000000oooo0?ooo`1L0?ooo`030000
o`3oool0oooo00X0oooo00<000000?ooo`3oool0e@3oool00`000000oooo
0?ooo`1L0?ooo`030000o`3oool0oooo00X0oooo00<000000?ooo`3oool0
K`3oool004<0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?oo
o`090?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0G@3o
ool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo06l0oooo0013
0?ooo`030000003oool0oooo05h0oooo0P000?l90?ooo`800000eP3oool0
0`000000oooo0?ooo`1N0?ooo`80003o2@3oool200000700oooo00130?oo
o`030000003oool0oooo0600oooo00<0003o0?ooo`3oool01@3oool20000
00030?ooo`00000000000=@0oooo00<000000?ooo`3oool0H03oool00`00
0?l0oooo0?ooo`050?ooo`80000000<0oooo000000000000KP3oool004<0
oooo00<000000?ooo`3oool0H@3oool00`000?l0oooo0?ooo`1D0?ooo`03
0?l0003oool0oooo08H0oooo00<000000?ooo`3oool0H@3oool00`000?l0
oooo0?ooo`1D0?ooo`030?l0003oool0oooo0200oooo00130?ooo`030000
003oool0oooo0680oooo0P000?mD0?ooo`030?l0003oool0oooo08H0oooo
00<000000?ooo`3oool0HP3oool20000oe@0oooo00<0o`000?ooo`3oool0
803oool004<0oooo00<000000?ooo`3oool0I03oool00`000?l0oooo0?oo
o`1A0?ooo`030?l0003oool0oooo08H0oooo00<000000?ooo`3oool0I03o
ool00`000?l0oooo0?ooo`1A0?ooo`030?l0003oool0oooo0200oooo0013
0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool0D03oool0
0`3o0000oooo0?ooo`260?ooo`030000003oool0oooo06D0oooo00<0003o
0?ooo`3oool0D03oool00`3o0000oooo0?ooo`0P0?ooo`00@`3oool00`00
0000oooo0?ooo`1V0?ooo`80003oD03oool00`3o0000oooo0?ooo`260?oo
o`030000003oool0oooo06H0oooo0P000?m@0?ooo`030?l0003oool0oooo
0200oooo00130?ooo`030000003oool0oooo06P0oooo00<0003o0?ooo`3o
ool0C@3oool00`3o0000oooo0?ooo`260?ooo`030000003oool0oooo06P0
oooo00<0003o0?ooo`3oool0C@3oool00`3o0000oooo0?ooo`0P0?ooo`00
@`3oool00`000000oooo0?ooo`1Y0?ooo`030000o`3oool0oooo0=D0oooo
00<000000?ooo`3oool0J@3oool00`000?l0oooo0?ooo`1_0?ooo`00@`3o
ool00`000000oooo0?ooo`1Z0?ooo`80003oe@3oool00`000000oooo0?oo
o`1Z0?ooo`80003oK`3oool004<0oooo00<000000?ooo`3oool0K03oool0
0`000?l0oooo0?ooo`3B0?ooo`030000003oool0oooo06`0oooo00<0003o
0?ooo`3oool0K03oool004<0oooo00<000000?ooo`3oool0K@3oool00`00
0?l0oooo0?ooo`3A0?ooo`030000003oool0oooo06d0oooo00<0003o0?oo
o`3oool0J`3oool004<0oooo00<000000?ooo`3oool0KP3oool20000odP0
oooo00<0o`000?ooo`3oool0QP3oool00`000000oooo0?ooo`1^0?ooo`80
003oB03oool00`3o0000oooo0?ooo`0P0?ooo`00@`3oool00`000000oooo
0?ooo`1`0?ooo`030000o`3oool0oooo04D0oooo00<0o`000?ooo`3oool0
QP3oool00`000000oooo0?ooo`1`0?ooo`030000o`3oool0oooo04D0oooo
00<0o`000?ooo`3oool0803oool004<0oooo00<000000?ooo`3oool0L@3o
ool00`000?l0oooo0?ooo`140?ooo`030?l0003oool0oooo08H0oooo00<0
00000?ooo`3oool0L@3oool00`000?l0oooo0?ooo`140?ooo`030?l0003o
ool0oooo0200oooo00130?ooo`030000003oool0oooo0780oooo0P000?m4
0?ooo`030?l0003oool0oooo08H0oooo00<000000?ooo`3oool0LP3oool2
0000od@0oooo00<0o`000?ooo`3oool0803oool004<0oooo00<000000?oo
o`3oool0M03oool00`000?l0oooo0?ooo`110?ooo`030?l0003oool0oooo
08H0oooo00<000000?ooo`3oool0M03oool00`000?l0oooo0?ooo`110?oo
o`030?l0003oool0oooo0200oooo00130?ooo`030000003oool0oooo07D0
oooo00<0003o0?ooo`3oool0@03oool00`3o0000oooo0?ooo`260?ooo`03
0000003oool0oooo07D0oooo00<0003o0?ooo`3oool0@03oool00`3o0000
oooo0?ooo`0P0?ooo`00@`3oool00`000000oooo0?ooo`1f0?ooo`80003o
@03oool00`3o0000oooo0?ooo`260?ooo`030000003oool0oooo07H0oooo
0P000?m00?ooo`030?l0003oool0oooo0200oooo00130?ooo`030000003o
ool0oooo07P0oooo00<0003o0?ooo`3oool0aP3oool00`000000oooo0?oo
o`1h0?ooo`030000o`3oool0oooo0600oooo00130?ooo`030000003oool0
oooo07T0oooo00<0003o0?ooo`3oool0a@3oool00`000000oooo0?ooo`1i
0?ooo`030000o`3oool0oooo05l0oooo00130?ooo`030000003oool0oooo
07X0oooo0P000?o50?ooo`030000003oool0oooo07X0oooo0P000?mO0?oo
o`00@`3oool00`000000oooo0?ooo`1l0?ooo`030000o`3oool0oooo0<80
oooo00<000000?ooo`3oool0O03oool00`000?l0oooo0?ooo`1L0?ooo`00
@`3oool00`000000oooo0?ooo`1m0?ooo`030000o`3oool0oooo03P0oooo
00<0o`000?ooo`3oool0QP3oool00`000000oooo0?ooo`1m0?ooo`030000
o`3oool0oooo03P0oooo00<0o`000?ooo`3oool0803oool004<0oooo00<0
00000?ooo`3oool0OP3oool20000ocP0oooo00<0o`000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`1n0?ooo`80003o>03oool00`3o0000oooo0?oo
o`0P0?ooo`00@`3oool00`000000oooo0?ooo`200?ooo`030000o`3oool0
oooo03D0oooo00<0o`000?ooo`3oool0QP3oool00`000000oooo0?ooo`20
0?ooo`030000o`3oool0oooo03D0oooo00<0o`000?ooo`3oool0803oool0
04<0oooo00<000000?ooo`3oool0P@3oool00`000?l0oooo0?ooo`0d0?oo
o`030?l0003oool0oooo08H0oooo00<000000?ooo`3oool0P@3oool00`00
0?l0oooo0?ooo`0d0?ooo`030?l0003oool0oooo0200oooo00130?ooo`03
0000003oool0oooo0880oooo0P000?ld0?ooo`030?l0003oool0oooo08H0
oooo00<000000?ooo`3oool0PP3oool20000oc@0oooo00<0o`000?ooo`3o
ool0803oool004<0oooo00<000000?ooo`3oool0Q03oool00`000?l0oooo
0?ooo`0a0?ooo`030?l0003oool0oooo08H0oooo00<000000?ooo`3oool0
Q03oool00`000?l0oooo0?ooo`0a0?ooo`030?l0003oool0oooo0200oooo
00130?ooo`030000003oool0oooo08D0oooo00<0003o0?ooo`3oool0^@3o
ool00`000000oooo0?ooo`250?ooo`030000o`3oool0oooo05<0oooo0013
0?ooo`030000003oool0oooo08H0oooo0P000?ni0?ooo`030000003oool0
oooo08H0oooo0P000?mC0?ooo`00@`3oool00`000000oooo0?ooo`280?oo
o`030000o`3oool0oooo0;H0oooo00<000000?ooo`3oool0R03oool00`00
0?l0oooo0?ooo`1@0?ooo`00@`3oool00`000000oooo0?ooo`290?ooo`03
0000o`3oool0oooo0;D0oooo00<000000?ooo`3oool0R@3oool00`000?l0
oooo0?ooo`1?0?ooo`00@`3oool00`000000oooo0?ooo`2:0?ooo`80003o
]@3oool00`000000oooo0?ooo`2:0?ooo`80003oC`3oool004<0oooo00<0
00000?ooo`3oool0S03oool00`000?l0oooo0?ooo`0Y0?ooo`030?l0003o
ool0oooo08H0oooo00<000000?ooo`3oool0S03oool00`000?l0oooo0?oo
o`0Y0?ooo`030?l0003oool0oooo0200oooo00130?ooo`030000003oool0
oooo08d0oooo00<0003o0?ooo`3oool0:03oool00`3o0000oooo0?ooo`26
0?ooo`030000003oool0oooo08d0oooo00<0003o0?ooo`3oool0:03oool0
0`3o0000oooo0?ooo`0P0?ooo`00@`3oool00`000000oooo0?ooo`2>0?oo
o`80003o:03oool00`3o0000oooo0?ooo`260?ooo`030000003oool0oooo
08h0oooo0P000?lX0?ooo`030?l0003oool0oooo0200oooo00130?ooo`03
0000003oool0oooo0900oooo00<0003o0?ooo`3oool09@3oool00`3o0000
oooo0?ooo`260?ooo`030000003oool0oooo0900oooo00<0003o0?ooo`3o
ool09@3oool00`3o0000oooo0?ooo`0P0?ooo`00@`3oool00`000000oooo
0?ooo`2A0?ooo`030000o`3oool0oooo02@0oooo00<0o`000?ooo`3oool0
QP3oool00`000000oooo0?ooo`2A0?ooo`030000o`3oool0oooo02@0oooo
00<0o`000?ooo`3oool0803oool004<0oooo00<000000?ooo`3oool0TP3o
ool20000ob@0oooo00<0o`000?ooo`3oool0QP3oool00`000000oooo0?oo
o`2B0?ooo`80003o903oool00`3o0000oooo0?ooo`0P0?ooo`00@`3oool0
0`000000oooo0?ooo`2D0?ooo`030000o`3oool0oooo0:X0oooo00<00000
0?ooo`3oool0U03oool00`000?l0oooo0?ooo`140?ooo`00@`3oool00`00
0000oooo0?ooo`2E0?ooo`030000o`3oool0oooo0:T0oooo00<000000?oo
o`3oool0U@3oool00`000?l0oooo0?ooo`130?ooo`00@`3oool00`000000
oooo0?ooo`2F0?ooo`80003oZ@3oool00`000000oooo0?ooo`2F0?ooo`80
003o@`3oool004<0oooo00<000000?ooo`3oool0V03oool00`000?l0oooo
0?ooo`2V0?ooo`030000003oool0oooo09P0oooo00<0003o0?ooo`3oool0
@03oool004<0oooo00<000000?ooo`3oool0V@3oool00`000?l0oooo0?oo
o`0L0?ooo`030?l0003oool0oooo08H0oooo00<000000?ooo`3oool0V@3o
ool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo0200oooo0013
0?ooo`030000003oool0oooo09X0oooo0P000?lL0?ooo`030?l0003oool0
oooo08H0oooo00<000000?ooo`3oool0VP3oool20000oa`0oooo00<0o`00
0?ooo`3oool0803oool004<0oooo00<000000?ooo`3oool0W03oool00`00
0?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo08H0oooo00<000000?oo
o`3oool0W03oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo
0200oooo00130?ooo`030000003oool0oooo09d0oooo00<0003o0?ooo`3o
ool0603oool00`3o0000oooo0?ooo`260?ooo`030000003oool0oooo09d0
oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0P0?ooo`00
@`3oool00`000000oooo0?ooo`2N0?ooo`80003o603oool00`3o0000oooo
0?ooo`260?ooo`030000003oool0oooo09h0oooo0P000?lH0?ooo`030?l0
003oool0oooo0200oooo00130?ooo`030000003oool0oooo0:00oooo00<0
003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`260?ooo`030000003o
ool0oooo0:00oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?oo
o`0P0?ooo`00@`3oool00`000000oooo0?ooo`2Q0?ooo`030000o`3oool0
oooo01@0oooo00<0o`000?ooo`3oool0QP3oool00`000000oooo0?ooo`2Q
0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0803oool0
04<0oooo00<000000?ooo`3oool0XP3oool20000oid0oooo00<000000?oo
o`3oool0XP3oool20000ocL0oooo00130?ooo`030000003oool0oooo0:@0
oooo00<0003o0?ooo`3oool0VP3oool00`000000oooo0?ooo`2T0?ooo`03
0000o`3oool0oooo03@0oooo00130?ooo`030000003oool0oooo0:D0oooo
00<0003o0?ooo`3oool0V@3oool00`000000oooo0?ooo`2U0?ooo`030000
o`3oool0oooo03<0oooo00130?ooo`030000003oool0oooo0:H0oooo0P00
0?nI0?ooo`030000003oool0oooo0:H0oooo0P000?lc0?ooo`00@`3oool0
0`000000oooo0?ooo`2X0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool0QP3oool00`000000oooo0?ooo`2X0?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool0803oool004<0oooo00<000000?oo
o`3oool0Z@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
08H0oooo00<000000?ooo`3oool0Z@3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo0200oooo00130?ooo`030000003oool0oooo0:X0
oooo0P000?l30?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`2Z0?ooo`80003o0`3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo0200oooo00130?ooo`030000
003oool0oooo0:`0oooo00<0003o0?ooo`000?l00P000?l70?ooo`030?l0
003oool0oooo08H0oooo00<000000?ooo`3oool0[03oool00`000?l0oooo
0000o`020000o`L0oooo00<0o`000?ooo`3oool0803oool004<0oooo00<0
00000?ooo`3oool0[@3oool50000o`H0oooo00<0o`000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`2]0?ooo`D0003o1P3oool00`3o0000oooo0?oo
o`0P0?ooo`00@`3oool00`000000oooo0?ooo`2]0?ooo`H0003o1@3oool0
0`3o0000oooo0?ooo`260?ooo`030000003oool0oooo0:d0oooo1P000?l5
0?ooo`030?l0003oool0oooo0200oooo00130?ooo`030000003oool0oooo
0:`0oooo20000?n=0?ooo`030000003oool0oooo0:`0oooo20000?lW0?oo
o`00@`3oool00`000000oooo0?ooo`2[0?ooo`T0003oS@3oool00`000000
oooo0?ooo`2[0?ooo`T0003o9`3oool004<0oooo00<000000?ooo`3oool0
[@3oool80000oh`0oooo00<000000?ooo`3oool0[@3oool80000obH0oooo
000O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool4000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`2_0?ooo`L0003oI`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo100000040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0[`3oool70000obD0oooo000N0?ooo`030000003oool0
oooo00T0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01P3oool2003o0;@0oooo1`000?mS0?ooo`030000003oool0
oooo00T0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01P3oool2003o0;@0oooo1`000?lR0?ooo`007@3oool00`00
0000oooo0?ooo`030?ooo`<000001@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool4003o
0;H0oooo1@000?mQ0?ooo`030000003oool0oooo00<0oooo0`0000050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`@00?l0]P3oool50000ob40oooo000M0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?oo
o`8000001@3oool2000000H0oooo00<000000?ooo`3oool00`3oool9003o
00D0oooo1P00o`040?ooo`L00?l0103oool6003o00D0oooo1P00o`040?oo
o`L00?l0103oool6003o00@0oooo1`00o`040?ooo`H00?l01@3oool6003o
00@0oooo1`00o`040?ooo`H00?l01@3oool6003o00@0oooo1`00o`040?oo
o`H00?l01@3oool6003o00@0oooo1P00o`050?ooo`<00?l01P000?mP0?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`8000001@3oool2000000H0oooo00<000000?ooo`3oool00`3oool9
003o00D0oooo1P00o`040?ooo`L00?l0103oool6003o00D0oooo1P00o`04
0?ooo`L00?l0103oool6003o00@0oooo1`00o`040?ooo`H00?l01@3oool6
003o00@0oooo1`00o`040?ooo`H00?l01@3oool6003o00@0oooo1`00o`04
0?ooo`H00?l01@3oool6003o00@0oooo1P00o`050?ooo`<00?l01P000?lP
0?ooo`007@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000002P3oool00`000000oooo000000060?ooo`030000003oool0
oooo00<0oooo1P00o`2e0?ooo`H0003oH03oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0000
00060?ooo`030000003oool0oooo00<0oooo1P00o`2e0?ooo`H0003o803o
ool001d0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`040?ooo`@00?l0]`3oool40000of40oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`040?ooo`@00?l0]`3oool40000
ob40oooo000M0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000090?ooo`050000003oool0oooo0?ooo`0000001@3oool0
0`000000oooo0?ooo`050?ooo`800?l0^@3oool20000of80oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00D0oooo
0P00o`2i0?ooo`80003o8P3oool001d0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000P0oooo0`000000103oool00000
0000000000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0o`3ooolL0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000080?ooo`<0000000@0oooo0000000000000000103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0=/0oooo000N0?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolM
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0f`3o
ool001l0oooo00@000000?ooo`3oool0oooo0`00000B0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`040000003o
ool0oooo0?ooo`<000004P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0=/0oooo00130?ooo`030000003oool0oooo0?l0oooo@P3o
ool00`000000oooo0?ooo`3K0?ooo`00@`3oool00`000000oooo0?ooo`3o
0?oood80oooo00<000000?ooo`3oool0f`3oool004<0oooo00<000000?oo
o`3oool0o`3ooom20?ooo`030000003oool0oooo0=/0oooo00130?ooo`03
0000003oool0oooo0?l0oooo@P3oool00`000000oooo0?ooo`3K0?ooo`00
@`3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo07/0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00/0oooo00130?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool09P3oool2000002T0oooo00<0
00000?ooo`3oool0L03oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo02H0oooo0P00000Y0?ooo`030000003oool0oooo00X0oooo0013
0?ooo`030000003oool0oooo05<0oooo1@00000G0?ooo`D000001@3oool0
0`000000oooo0?ooo`030?ooo`<00000103oool3000000<0oooo1000000:
0?ooo`@000001P3oool00`000000oooo0?ooo`020?ooo`@000000`3oool5
000000050?ooo`00000000000000003oool00`0000090?ooo`@000001@3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo05<0oooo1@00
000G0?ooo`D000001@3oool00`000000oooo0?ooo`030?ooo`<00000103o
ool3000000<0oooo1000000:0?ooo`@000001P3oool00`000000oooo0?oo
o`020?ooo`@000000`3oool5000000050?ooo`00000000000000003oool0
0`0000090?ooo`@000001@3oool00`000000oooo0?ooo`090?ooo`00@`3o
ool00`000000oooo0?ooo`1C0?ooo`050000003oool0oooo0?ooo`000000
2@3oool5000000X0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000008
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2
000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo05<0oooo00D000000?ooo`3oool0
oooo000000090?ooo`D000002P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00T0oooo00130?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo000000060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00130?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool02@3oool5000000X0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`<000002@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo0`00
00050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo0000001a0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3o
ool02@3oool5000000X0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`<000002@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00P0oooo0`0000050?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`00@`3oool0
0`000000oooo0?ooo`1C0?ooo`040000003oool0oooo000001T0oooo0P00
00070?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000P0oooo1`0000090?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`8000000P3oool0
0`000000oooo0?ooo`070?ooo`L000000`3oool00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo05<0oooo00@000000?ooo`3oool000006@3o
ool2000000L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`000000203oool7000000T0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo0P000002
0?ooo`030000003oool0oooo00L0oooo1`0000030?ooo`030000003oool0
oooo00T0oooo00130?ooo`030000003oool0oooo05<0oooo1@00000G0?oo
o`80000000<0oooo0000000000001@3oool00`000000oooo0?ooo`030?oo
o`@000000`3oool3000000@0oooo100000080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool400000080oooo0`0000030?oo
o`80000000<0oooo0000000000002P3oool00`000000oooo0?ooo`030?oo
o`050000003oool0oooo0?ooo`000000L@3oool00`000000oooo0?ooo`1C
0?ooo`D000005`3oool2000000030?ooo`000000000000D0oooo00<00000
0?ooo`3oool00`3oool4000000<0oooo0`0000040?ooo`@00000203oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo10000002
0?ooo`<000000`3oool2000000030?ooo`000000000000X0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000/0oooo0013
0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00001b0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`00000<0?ooo`00@`3oool00`000000oooo0?oo
o`1k0?ooo`030000003oool0oooo01d0oooo1000000C0?ooo`030000003o
ool0oooo0180oooo100000020?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0N`3oool00`000000oooo0?ooo`0M0?ooo`@000004`3o
ool00`000000oooo0?ooo`0B0?ooo`@000000P3oool00`000000oooo0?oo
o`0;0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oood80oooo00<00000
0?ooo`3oool0f`3oool004<0oooo00<000000?ooo`3oool0o`3ooom20?oo
o`030000003oool0oooo0=/0oooo00130?ooo`030000003oool0oooo0?l0
oooo@P3oool00`000000oooo0?ooo`3K0?ooo`00@`3oool00`000000oooo
0?ooo`3o0?oood80oooo00<000000?ooo`3oool0f`3oool004<0oooo00<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00<0oooo100000030?ooo`030000003oool0oooo02l0oooo1000
001o0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`@000000`3oool00`000000oooo0?oo
o`0_0?ooo`@000006@3oool004<0oooo00<000000?ooo`3oool0LP3oool0
0`000000oooo0?ooo`0:0?ooo`8000001P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0OP3oool0
0`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00X0oooo0P000006
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0H0?ooo`00@`3oool00`000000oooo0?ooo`1C0?oo
o`D000006@3oool00`000000oooo0?ooo`020?ooo`8000000P3oool20000
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01L0oooo0P0000020?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`L000000P3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo05<0oooo1@00000I0?ooo`030000003oool0oooo
0080oooo0P0000020?ooo`800000103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool20000
0080oooo0P0000040?ooo`030000003oool0oooo0080oooo1`0000020?oo
o`030000003oool0oooo01P0oooo00130?ooo`030000003oool0oooo05<0
oooo00D000000?ooo`3oool0oooo000000090?ooo`D000002`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo000000D0oooo0P000005
0?ooo`8000001@3oool00`000000oooo0?ooo`090?ooo`D000002P3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`000000103oool2000007l0oooo00<000000?ooo`3oool0D`3o
ool01@000000oooo0?ooo`3oool0000000T0oooo1@00000;0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000001@3oool2000000D0
oooo0P0000050?ooo`030000003oool0oooo00T0oooo1@00000:0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo000000040?ooo`8000006@3oool009X0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`040?ooo`800000303oool00`000000
oooo000000050?ooo`030000003oool0oooo01T0oooo0P0000040?ooo`D0
0000103oool00`000000oooo000000030?ooo`030000003oool000000=H0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`80
0000303oool00`000000oooo000000050?ooo`030000003oool0oooo01T0
oooo0P0000040?ooo`D00000103oool00`000000oooo000000030?ooo`03
0000003oool0000001T0oooo002K0?ooo`030000003oool0oooo00T0oooo
1@00000;0?ooo`030000003oool0oooo00@0oooo0P00000<0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool02@3oool5000000/0
oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`00
00000`3oool010000000oooo0?ooo`00003F0?ooo`030000003oool0oooo
00T0oooo1@00000;0?ooo`030000003oool0oooo00@0oooo0P00000<0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02@3oool5
000000/0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`0000000`3oool010000000oooo0?ooo`00000H0?ooo`00V@3oool0
10000000oooo0?ooo`00000J0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0603oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool000000=@0oooo00@000000?ooo`3oool000006P3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000X0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo01P0
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`040?oo
o`030000003oool000000080oooo00D000000?ooo`3oool0oooo0000000H
0?ooo`00V@3oool5000001T0oooo00<000000?ooo`3oool00P3oool20000
0080oooo0P0000080?ooo`<0000000@0oooo00000000000000000`3oool0
0`000000oooo0?ooo`0G0?ooo`8000000P3oool2000000T0oooo1@000000
1@3oool00000000000000000oooo00<00000d`3oool5000001T0oooo00<0
00000?ooo`3oool00P3oool200000080oooo0P0000080?ooo`<0000000@0
oooo00000000000000000`3oool00`000000oooo0?ooo`0G0?ooo`800000
0P3oool2000000T0oooo1@0000001@3oool00000000000000000oooo00<0
00005`3oool00;P0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`1;0?ooo`00^@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool07P3o
ool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0
ooooI`3oool00440oooo0P00003o0?oood<0oooo0P00003N0?ooo`00@P3o
ool00`000000oooo0?ooo`3o0?oood80oooo00<000000?ooo`3oool0g03o
ool004<0oooo00<000000?ooo`3oool0o`3ooom20?ooo`030000003oool0
oooo0=/0oooo00120?ooo`030000003oool000000?l0oooo@P3oool00`00
0000oooo0000003L0?ooo`00@@3oool010000000oooo0?ooo`00003o0?oo
od40oooo00@000000?ooo`3oool00000g03oool00400oooo0`0000000`3o
ool000000000003o0?ooocl0oooo0`0000000`3oool000000000003K0?oo
o`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3o
oomW0?ooo`00o`3ooooo0?ooofL0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{613, 287},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\tAs Figure 1.11(b) shows, the angle ",
  Cell[BoxData[
      \(\[Theta]\)]],
  "  can",
  " be any val",
  "ue for which the identities  ",
  Cell[BoxData[
      \(cos\ \[Theta] = \(x\/r\ and\ cos\ \[Theta] = y\/r\)\)]],
  "  hold true.  Given ",
  Cell[BoxData[
      \(\(\(\ \)\(z \[NotEqual] 0\)\)\)]],
  ",  the collection of all values of  ",
  Cell[BoxData[
      \(\[Theta]\)]],
  " for which  ",
  Cell[BoxData[
      \(z\  = r \((cos\ \[Theta]\  + \ i\ sin\ \[Theta])\)\)]],
  "  is denoted by  ",
  Cell[BoxData[
      \(arg\ z\)]],
  ".  Formally, ",
  "we have the following definitions."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  If  ",
  Cell[BoxData[
      \(z = 1 + \[ImaginaryI]\)]],
  ",  then  ",
  Cell[BoxData[
      \(r = \(\@\(1 + 1\) = \@2\)\)]],
  "  and  ",
  Cell[BoxData[
      \(z = \(\((\(\@2\) cos  \[Pi]\/4, \ \(\@2\) 
              sin  \[Pi]\/4)\) = \ \(\@2\) \((cos  \[Pi]\/4 + \[ImaginaryI]\ \
sin  \[Pi]\/4)\)\)\)]],
  "  is a polar representation of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ".  The polar coordinates in this case are ",
  Cell[BoxData[
      \(r = \@2\)]],
  ", and ",
  Cell[BoxData[
      \(\[Theta] = \[Pi]\/4\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[z];\)\ \), "\n", 
    \(\(z = \ 1 + \ \[ImaginaryI];\)\ \), "\n", 
    \(\(r = Abs[z];\)\ \), "\n", 
    \(\(\[Theta] = Arg[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        Graphics[{Magenta, Arrow[{0, \ 0}, {Re[z], Im[z]}]}];\)\ \), "\n", 
    \(\(Show[V\_1, 
        PlotRange \[Rule] {{0, 1.1}, {0, 
              1.1}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2, 1\/2], 
            Range[0, 1, 1\/2]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<         z = \>", z];\)\ \), "\n", 
    \(\(Print["\<r = Abs[z] = \>", r];\)\ \), "\n", 
    \(\(Print["\<\[Theta] = Arg[z] = \>", \[Theta]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Verify it\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<z = \!\(\@2\)Cos[\!\(\[Pi]\/4\)] + \[ImaginaryI] \!\(\@2\
\)Sin[\!\(\[Pi]\/4\)]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<z = \!\(\@2\)(Cos[\!\(\[Pi]\/4\)] + \[ImaginaryI] Sin[\!\
\(\[Pi]\/4\)])\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<z = \>", \@2, "\<(\>", \((Cos[\[Pi]\/4] + \[ImaginaryI]\ \
Sin[\[Pi]\/4])\), "\<)\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<z = \>", 
        ComplexExpand[\(\@2\) \((Cos[\[Pi]\/4] + \[ImaginaryI]\ \
Sin[\[Pi]\/4])\)]\ \ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Definition 1.10, (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Argument",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ArgumentComplexNumber.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[", arg z).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  " If  ",
  Cell[BoxData[
      \(\(\(\ \)\(z \[NotEqual] 0\)\)\)]],
  ",  we denote  ",
  Cell[BoxData[
      \(arg\ z\)]],
  "  by  \n\n\t\t\t",
  Cell[BoxData[
      \(arg\ z\  = {\[Theta] : \ z = 
            r \((cos\ \[Theta]\  + \[ImaginaryI]\ sin\ \[Theta])\)}\)]],
  ".  \n\nIf  ",
  Cell[BoxData[
      \(\[Theta]\  \[Element] arg\ z\)]],
  ",  we say that ",
  Cell[BoxData[
      \(\[Theta]\)]],
  " is an argument of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tNotice that we write  ",
  Cell[BoxData[
      \(\[Theta]\  \[Element] arg\ z\)]],
  "  as opposed to  ",
  Cell[BoxData[
      \(\[Theta]\  = arg\ z\)]],
  ".  This is because  ",
  Cell[BoxData[
      \(arg\ z\)]],
  "  is a set, and the designation ",
  Cell[BoxData[
      \(\[Theta]\  \[Element] arg\ z\)]],
  " indicates that ",
  Cell[BoxData[
      \(\[Theta]\)]],
  " belongs to that set.  Notice also that, if  ",
  Cell[BoxData[
      RowBox[{\(\[Theta]\_1\), "\[Element]", 
        RowBox[{"arg", " ", "z", "  ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", \(\[Theta]\_2\)}], 
        "\[Element]", \(arg\ z\)}]]],
  ",  then there exists some integer ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " such that  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Theta]\_2\  = \ \[Theta]\_1\  + \ 2  n\ \[Pi]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Since ",
  Cell[BoxData[
      \(1 + \[ImaginaryI] = \(\@2\) \((Cos[\[Pi]\/4] + \[ImaginaryI]\ Sin[\
\[Pi]\/4])\)\)]],
  ", we have \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(arg \((1 + \[ImaginaryI])\)\), "=", 
        RowBox[{"{", 
          RowBox[{\(\[Pi]\/4\), "+", 
            RowBox[{"2", "n", " ", 
              RowBox[{"\[Pi]", ":", " ", 
                RowBox[{"n", " ", 
                  StyleBox["an",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["integer",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]}]}]}], "}"}]}], 
    "\[IndentingNewLine]", 
      RowBox[{
        "                      ", \(\(=\)\({\(...\)\(,\)\(\(\(-15\) \
\[Pi]\)\/4\)\(,\)\(\(\(-7\) \[Pi]\)\/4\)\(,\)\(\[Pi]\/4\)\(,\)\(\(9  \
\[Pi]\)\/4\)\(,\)\(\(17  \[Pi]\)\/4\)\(,\)\(\(25  \[Pi]\)\/4\)\(,\)\(...\)}\)\
\)}]}]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter several values  ",
  Cell[BoxData[
      RowBox[{\(arg \((1 + \[ImaginaryI])\)\), "=", 
        RowBox[{"{", 
          RowBox[{\(\[Pi]\/4\), "+", 
            RowBox[{"2", "n", " ", 
              RowBox[{"\[Pi]", ":", " ", 
                RowBox[{"n", " ", 
                  StyleBox["an",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["integer",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]}]}]}], "}"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[z];\)\ \), "\n", 
    \(\(z\_1 = \ 1 + \ \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_2\  = \ \@2\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\);\)\ \), "\
\n", 
    \(\(z\_3\  = \ \@2\ \[ExponentialE]\^\(\[ImaginaryI]\ 9\ \[Pi]/4\);\)\ \
\), "\n", 
    \(\(z\_4\  = \ \@2\ \[ExponentialE]\^\(\(-\ \[ImaginaryI]\)\ 7\ \
\[Pi]/4\);\)\ \), "\[IndentingNewLine]", 
    \(\(z\_5\  = \ \@2\ \[ExponentialE]\^\(\[ImaginaryI]\ 17  \[Pi]/4\);\)\ \
\), "\n", 
    \(\(r = Abs[z\_1];\)\ \), "\n", 
    \(\(\[Theta] = Arg[z\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        Graphics[{Magenta, 
            Arrow[{0, \ 0}, {Re[z\_1], Im[z\_1]}]}];\)\ \), "\n", 
    \(\(Show[V\_1, 
        PlotRange \[Rule] {{0, 1.1}, {0, 
              1.1}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2, 1\/2], 
            Range[0, 1, 1\/2]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", z\_1];\)\ \), "\n", 
    \(\(Print["\<r = \>", r];\)\ \), "\n", 
    \(\(Print["\<\[Theta] = \>", \[Theta]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \!\(\@2\) \!\(\[ExponentialE]\^\(\"\<\
\[ImaginaryI]\>\" \[Pi]/4\)\)    = \>\"", z\_2, "\< = \>", 
        ComplexExpand[z\_2]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \!\(\@2\) \!\(\[ExponentialE]\^\(\"\<\
\[ImaginaryI]\>\" 13  \[Pi]/4\)\)  = \>\"", z\_3, "\< = \>", 
        ComplexExpand[z\_3]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \!\(\@2\) \!\(\[ExponentialE]\^\(\"\<-\
\[ImaginaryI]\>\" 11  \[Pi]/4\)\) = \>\"", z\_4, "\< = \>", 
        ComplexExpand[z\_4]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_5\) = \!\(\@2\) \!\(\[ExponentialE]\^\(\"\<\
\[ImaginaryI]\>\" 25  \[Pi]/4\)\)  = \>\"", z\_5, "\< = \>", 
        ComplexExpand[z\_5]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Here is another way to look at it.", "Text"],

Cell[BoxData[{
    \(\(Clear[n, w];\)\ \), "\[IndentingNewLine]", 
    \(\(w\  = \ \@2\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4 + \ \
\[ImaginaryI]\ 2  \[Pi]\ n\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = \>", w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<w = \!\(\@2\)\!\(\[ExponentialE]\^\(\[ImaginaryI]\\\ \
\[Pi]/4\)\) \!\(\[ExponentialE]\^\(\[ImaginaryI]\\\ 2  \[Pi]\\\ \
n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(w\  = \ Simplify[w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = \>", w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = (\>", 
        ComplexExpand[\@2\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)], \
"\<)(\>", 
        Simplify[\[ExponentialE]\^\(\(\ \)\(\[ImaginaryI]\ 2  \[Pi]\ n\)\), 
          Element[n, Integers]], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(w\  = \ 
        Simplify[w, Element[n, Integers]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = \>", w];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tMathematicians have agreed to single out a special choice of  ",
  Cell[BoxData[
      \(\[Theta]\  \[Element] arg\ z\)]],
  ".  It is that value of ",
  Cell[BoxData[
      \(\[Theta]\)]],
  " for which ",
  Cell[BoxData[
      \(\(-\[Pi]\) < \[Theta] \[LessEqual] \[Pi]\)]],
  " as the following definition indicates."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 1.11, (The principal value of argument, Arg z).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  " Let  ",
  Cell[BoxData[
      \(\(\(\ \)\(z \[NotEqual] 0\)\)\)]],
  ",  be a complex number.  Then \n\n\t\t",
  Cell[BoxData[
      \(Arg\ z\  = \[Theta]\)]],
  ",    provided ",
  Cell[BoxData[
      \(z\  = r \((cos\ \[Theta]\  + \ i\ sin\ \[Theta])\)\)]],
  " and ",
  Cell[BoxData[
      \(\(-\[Pi]\) < \[Theta] \[LessEqual] \[Pi]\)]],
  ".  \n\nIf  ",
  Cell[BoxData[
      \(\[Theta]\  = Arg\ z\)]],
  ",  we call ",
  Cell[BoxData[
      \(\[Theta]\)]],
  " the argument of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  Cell[BoxData[
      \(Arg \((1 + \[ImaginaryI])\) = \[Pi]\/4\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(z = 1 + \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Theta] = Arg[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<z = \>", z];\)\ \), "\n", 
    \(\(Print["\<\[Theta] = Arg[1+\[ImaginaryI]]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\[Theta] = ArcTan[\!\(1\/1\)] = \>\"", 
        ArcTan[1\/1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Theta] = ArcTan[1,1] = \>", 
        ArcTan[1, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Theta] = \>", \[Theta]];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Clearly if ",
  Cell[BoxData[
      \(z\  = \(x + \[ImaginaryI]\ y = 
          r \((cos\ \[Theta]\  + \ i\ sin\ \[Theta])\)\)\)]],
  ", where ",
  Cell[BoxData[
      \(x \[NotEqual] 0\)]],
  ", then  \n\n\t\t\t",
  Cell[BoxData[
      \(arg\ z\ \  \[Subset] \ arctan\ y\/x\)]],
  ".  \n\nwhere  ",
  Cell[BoxData[
      \(arctan\ y\/x\  = \ {\[Theta] : \ \ tan\ \[Theta]\  = \ y\/x}\)]],
  ".  Note that, as with ",
  StyleBox["arg",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["arctan",
    FontFamily->"Courier New"],
  " is a set (as opposed to ",
  StyleBox["Arctan",
    FontFamily->"Courier New"],
  ", which is a number).  We specifically identify ",
  Cell[BoxData[
      \(arg\ z\)]],
  " as a proper subset of ",
  Cell[BoxData[
      \(arctan\ y\/x\)]],
  " because ",
  Cell[BoxData[
      \(\(\(\ \)\(\(tan\)\(\ \)\(\[Theta]\)\(\ \)\)\)\)]],
  " has period ",
  Cell[BoxData[
      \(\[Pi]\)]],
  ", whereas ",
  StyleBox["cos",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["sin",
    FontFamily->"Courier New"],
  " have period  ",
  Cell[BoxData[
      \(2  \[Pi]\)]],
  ".  In selecting the proper values for  ",
  Cell[BoxData[
      \(arg\ z\)]],
  " , we must be careful in specifying the choices of ",
  Cell[BoxData[
      \(arctan\ y\/x\)]],
  " so that the poin ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " associated with ",
  StyleBox["r",
    FontFamily->"Courier New"],
  " and ",
  Cell[BoxData[
      \(\[Theta]\)]],
  " lies in the appropriate quadrant."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  If  ",
  Cell[BoxData[
      \(z = \(\(-\@3\) - \[ImaginaryI] = 
          r \((cos\ \[Theta]\  + \ i\ sin\ \[Theta])\)\)\)]],
  ",  then  \n\n\t\t\t",
  Cell[BoxData[
      \(r = \(\(\(|\)\(z\)\(|\)\) = \(\(\(|\)\(\(-\@3\) - \
\[ImaginaryI]\)\(|\)\) = \(\@\(3 + 1\) = 2\)\)\)\)]],
  "   and  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(\[Theta]\  \[Element] \ arctan\ y\/x\), " ", "=", " ", 
        RowBox[{\(arctan\ \(-1\)\/\(-\@3\)\), " ", "=", 
          RowBox[{"{", 
            RowBox[{\(\[Pi]\/6\), "+", 
              RowBox[{"n", " ", 
                RowBox[{"\[Pi]", ":", "  ", 
                  RowBox[{"n", "   ", 
                    StyleBox["is",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox[" ",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox["an",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox[" ",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox["integer",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}]}]}]}]}], "}"}]}]}]]],
  ".  \n\nIt would be a mistake to use ",
  Cell[BoxData[
      \(\[Pi]\/6\)]],
  " as an acceptable value for ",
  Cell[BoxData[
      \(\(\(\[Theta]\)\(\ \)\)\)]],
  ", as the point z associated with ",
  Cell[BoxData[
      \(r = 2\)]],
  " and ",
  Cell[BoxData[
      \(\[Theta] = \[Pi]\/6\)]],
  " is in the first quadrant, whereas ",
  Cell[BoxData[
      \(z = \(-\@3\) - \[ImaginaryI]\)]],
  " is in the third quadrant.  A correct choice for ",
  Cell[BoxData[
      \(\(\(\[Theta]\)\(\ \)\)\)]],
  " is ",
  Cell[BoxData[
      \(\[Theta] = \(\[Pi]\/6 - \[Pi] = \(-\(\(5  \[Pi]\)\/6\)\)\)\)]],
  ".  Thus\n\n\t\t\t",
  Cell[BoxData[
      \(\@3 - \[ImaginaryI]\  = \ 
        2  Cos[\(-\(\(5  \[Pi]\)\/6\)\)] + \[ImaginaryI]\ 2 
             Sin[\(-\(\(5  \[Pi]\)\/6\)\)]\)]],
  ",  and \n\n\t\t\t",
  Cell[BoxData[
      \(\(-\@3\) - \[ImaginaryI]\  = \ 
        2  Cos[\(-\(\(5  \[Pi]\)\/6\)\) + 2  n\ \[Pi]] + \[ImaginaryI]\ 2 
             Sin[\(-\(\(5  \[Pi]\)\/6\)\) + 2  n\ \[Pi]]\)]],
  ", \n\t\t\t\nwhere ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is any integer.  In this case,\n\n\t\t\t",
  Cell[BoxData[
      \(Arg \((\(-\@3\) - \[ImaginaryI])\) = \(-\(\(5  \[Pi]\)\/6\)\)\)]],
  ",  and \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(arg \((\(-\@3\) - \[ImaginaryI])\)\), "=", 
        RowBox[{"{", 
          RowBox[{\(-\(\(5  \[Pi]\)\/6\)\), "+", 
            RowBox[{"2", "n", " ", 
              RowBox[{"\[Pi]", ":", "  ", 
                RowBox[{"n", "  ", 
                  StyleBox["is",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["an",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["integer",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]}]}]}], "}"}]}]]],
  ". \n\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Note that  ",
  Cell[BoxData[
      RowBox[{\(arg \((\(-\@3\) - \[ImaginaryI])\)\), "=", 
        RowBox[{"{", 
          RowBox[{\(-\(\(5  \[Pi]\)\/6\)\), "+", 
            RowBox[{"2", "n", " ", 
              RowBox[{"\[Pi]", ":", "  ", 
                RowBox[{"n", "  ", 
                  StyleBox["is",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["an",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["integer",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]}]}]}], "}"}]}]]],
  "  is indeed a proper subset of  ",
  Cell[BoxData[
      RowBox[{\(arctan\ \(-1\)\/\(-\@3\)\), " ", "=", 
        RowBox[{"{", 
          RowBox[{\(\[Pi]\/6\), "+", 
            RowBox[{"n", " ", 
              RowBox[{"\[Pi]", ":", "  ", 
                RowBox[{"n", "  ", 
                  StyleBox["is",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["an",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["integer",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]}]}]}], "}"}]}]]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter  ",
  Cell[BoxData[
      \(z\_1 = \ \(-\@3\) - \[ImaginaryI]\)],
    AspectRatioFixed->True],
  "  and  ",
  Cell[BoxData[
      \(z\_2, z\_3, z\_4, z\_5\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[z];\)\ \), "\n", 
    \(\(z\_1 = \ \(-\@3\)\  - \ \[ImaginaryI];\)\ \), "\n", 
    \(\(z\_2\  = \ 
        2\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 5  \[Pi]/6\);\)\ \), "\n", 
    \(\(z\_3\  = \ 
        2\ \[ExponentialE]\^\(\[ImaginaryI]\ 7  \[Pi]/6\);\)\ \), "\n", 
    \(\(z\_4\  = \ 
        2\ \[ExponentialE]\^\(\(-\ \[ImaginaryI]\)\ 17\ \[Pi]/6\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(z\_5\  = \ 
        2\ \[ExponentialE]\^\(\[ImaginaryI]\ 19  \[Pi]/6\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        Graphics[{Magenta, 
            Arrow[{0, \ 0}, {Re[z\_1], Im[z\_1]}]}];\)\ \), "\n", 
    \(\(Show[V\_1, 
        PlotRange \[Rule] {{\(-2\), 0}, {\(-1\), 
              1}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-2\), 2, 1\/2], 
            Range[\(-1\)\/2, 1, 
              1\/2]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", z\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = 2 \!\(\[ExponentialE]\^\(\"\<-\[ImaginaryI]\
\>\" 5  \[Pi]/6\)\) = \>\"", z\_2, "\< = \>", 
        ComplexExpand[z\_2]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_3\) = 2 \
\!\(\[ExponentialE]\^\(\"\<\[ImaginaryI]\>\" 7  \[Pi]/6\)\)  = \>\"", 
        z\_3, "\< = \>", ComplexExpand[z\_3]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_4\) = 2 \!\(\[ExponentialE]\^\(\"\<-\[ImaginaryI]\
\>\" 17  \[Pi]/6\)\) = \>\"", z\_4, "\< = \>", 
        ComplexExpand[z\_4]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_5\) = 2 \
\!\(\[ExponentialE]\^\(\"\<\[ImaginaryI]\>\" 19  \[Pi]/6\)\)  = \>\"", 
        z\_5, "\< = \>", ComplexExpand[z\_5]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Here is another way to look at it.", "Text"],

Cell[BoxData[{
    \(\(Clear[n, w];\)\ \), "\[IndentingNewLine]", 
    \(\(w\  = \ 
        2\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 5  \[Pi]/6 + \ \
\[ImaginaryI]\ 2  \[Pi]\ n\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = \>", w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<w = 2 \!\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\\\ 5  \
\[Pi]/6\)\) \!\(\[ExponentialE]\^\(\[ImaginaryI]\\\ 2  \[Pi]\\\ \
n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(w\  = \ 
        Simplify[w, Element[n, Integers]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = \>", w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = (\>", 
        ComplexExpand[
          2\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 5  \[Pi]/6\)], "\<)(\>", \
\ Simplify[\[ExponentialE]\^\(\(\ \)\(\[ImaginaryI]\ 2  \[Pi]\ n\)\), 
          Element[n, Integers]], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(w\  = \ ComplexExpand[w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = \>", w];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tIf  ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  "  is on the ",
  StyleBox["y",
    FontFamily->"Courier New"],
  "-axis, it would be a mistake to attempt to find  ",
  Cell[BoxData[
      \(Arg\ z\)]],
  "  by looking at  ",
  Cell[BoxData[
      \(arctan\ y\/x\)]],
  ",  as ",
  Cell[BoxData[
      \(x = 0\)]],
  ",  so ",
  Cell[BoxData[
      \(y\/x\)]],
  " is undefined.  We emphasize these special cases:\n\n\t\t\tIf  ",
  Cell[BoxData[
      RowBox[{GridBox[{
            {"y", ">"}
            }], "0"}]]],
  ",  then  ",
  Cell[BoxData[
      \(Arg \((0 + \[ImaginaryI]\ y)\)\  = \ \[Pi]\/2\)]],
  ",  and \n\n\t\t\tIf  ",
  Cell[BoxData[
      RowBox[{GridBox[{
            {"y", "<"}
            }], "0"}]]],
  ",  then  ",
  Cell[BoxData[
      \(Arg\ \((0 + \[ImaginaryI]\ y)\)\  = \ \(-\(\[Pi]\/2\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  If  ",
  Cell[BoxData[
      \(z = \(x + \[ImaginaryI]\ y = 0 + 4  \[ImaginaryI]\)\)]],
  ", it would be a mistake to attempt to find  ",
  Cell[BoxData[
      \(arg\ z\)]],
  "  by looking at  ",
  Cell[BoxData[
      \(arctan\ y\/x\)]],
  ",  as ",
  Cell[BoxData[
      \(x = 0\)]],
  ",  so ",
  Cell[BoxData[
      \(y\/x = 4\/0\)]],
  " is undefined.  In this case  \n\n\t\t\t",
  Cell[BoxData[
      \(Arg \((4\ \[ImaginaryI])\) = \(Arg \((0 + 
                4\ \[ImaginaryI])\) = \[Pi]\/2\)\)]],
  ",   and   ",
  Cell[BoxData[
      RowBox[{\(arg \((4  \[ImaginaryI])\)\), "=", 
        RowBox[{"{", 
          RowBox[{\(\[Pi]\/2\), "+", 
            RowBox[{"2", "n", " ", 
              RowBox[{"\[Pi]", ":", " ", 
                RowBox[{"n", " ", 
                  StyleBox["is",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["an",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["integer",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]}]}]}], "}"}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tAs we shall see in Chapter 2, ",
  Cell[BoxData[
      \(\(\(Arg\)\(\ \)\(z\)\(\ \)\)\)]],
  " is a discontinuous function of z because it \"jumps'' by an amount of ",
  Cell[BoxData[
      \(2  \[Pi]\)]],
  " as ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " crosses the negative real axis."
}], "Text"],

Cell[TextData[{
  "\tIn Chapter 5 we define ",
  Cell[BoxData[
      \(\[ExponentialE]\^z\)]],
  " for any complex number ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ".  You will see that this complex exponential has all the properties of \
real exponentials that you studied in earlier mathematics courses.  That is,  \
",
  Cell[BoxData[
      \(\(\[ExponentialE]\^z\_1\) \[ExponentialE]\^z\_2 = \
\[ExponentialE]\^\(z\_1 + z\_2\)\)]],
  ",  and so forth. You will also see, amazingly, that if ",
  Cell[BoxData[
      \(z\  = x + \[ImaginaryI]\ y\)]],
  ", then  \n\n\t\t\t",
  Cell[BoxData[
      \(\[ExponentialE]\^z\  = \ \(\[ExponentialE]\^\(x + \[ImaginaryI]\ y\)\ \
 = \ \(\[ExponentialE]\^x\) \((cos\ y\  + \ \[ImaginaryI]\ sin\ y)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tWe will establish this result rigorously in Chapter 5, but there is a \
plausible explanation we can give now.  \n\nIf  ",
  Cell[BoxData[
      \(\(\(\[ExponentialE]\^z\)\(\ \)\)\)]],
  "  has the normal properties of an exponential, it must be that  ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(x + \[ImaginaryI]\ y\) = \ \(\[ExponentialE]\^x = \
\ \[ExponentialE]\^\(\[ImaginaryI]\ y\)\)\)]],
  ".  Now, recall from Calculus the values of three infinite series: \n\n\t",
  Cell[BoxData[
      \(\[ExponentialE]\^x = \ \[Sum]\+\(k = 0\)\%\[Infinity]\( 1\/\(k!\)\) 
            x\^k\)]],
  ",    ",
  Cell[BoxData[
      \(cos\ x\  = \[Sum]\+\(k = 0\)\%\[Infinity]\(\((\(-1\))\)\^k\/\(\((2  
                      k)\)!\)\) x\^\(2  k\)\)]],
  ",   and   ",
  Cell[BoxData[
      \(Sin[
          x]\  = \ \[Sum]\+\(k = 0\)\%\[Infinity]\(\((\(-1\))\)\^k\/\(\((2  
                        k + 1)\)!\)\) x\^\(2  k + 1\)\)]],
  ".  \n"
}], "Text"],

Cell[TextData[{
  "Substituting ",
  Cell[BoxData[
      \(\[ImaginaryI]\ y\)]],
  " for ",
  Cell[BoxData[
      \(x\)]],
  " in the infinite series for  ",
  Cell[BoxData[
      \(\[ExponentialE]\^x\)]],
  "  gives  ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\[ImaginaryI]\ y\)\  = \ \ \[Sum]\+\(k = 0\)\%\
\[Infinity]\( 
                  1\/\(k!\)\) \((\[ImaginaryI]\ y)\)\^k\  + \ \[Sum]\+\(k = 0\
\)\%\[Infinity]\( 1\/\(k!\)\) \(\[ImaginaryI]\^k\) y\^k\)]],
  ".  At this point, our argument loses rigor because we have not talked \
about infinite series of complex numbers, let alone whether such series \
converge.  Nevertheless, if we merely take the last series as a formal \
expression and split it into two series according to whether the index ",
  StyleBox["k",
    FontFamily->"Courier New"],
  " is even (",
  StyleBox["k=2n",
    FontFamily->"Courier New"],
  ") or odd (",
  StyleBox["k=2n+1",
    FontFamily->"Courier New"],
  "), we get  \n\n\t\t\t",
  Cell[BoxData[{
      \(\ \[ExponentialE]\^\(\[ImaginaryI]\ y\)\  = \ \ \[Sum]\+\(k\ is\ even\
\)\%\[Infinity]\( 1\/\(k!\)\) \(\[ImaginaryI]\^k\) 
              y\^k\  + \ \[Sum]\+\(k\ is\ odd\)\%\[Infinity]\( 
                  1\/\(k!\)\) \(\[ImaginaryI]\^k\) 
              y\^k\ \[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(\[Sum]\+\(n = 0\)\%\[Infinity]\( 
                  1\/\(\((2  n)\)!\)\) \(\[ImaginaryI]\^\(2  n\)\) 
              y\^\(2  n\)\  + \ \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                  1\/\(\((2  n + 1)\)!\)\) \(\[ImaginaryI]\^\(2  n + 1\)\) 
              y\^\(2  n + 1\)\)\)\ \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(\[Sum]\+\(n = 0\)\%\[Infinity]\( 
                  1\/\(\((2  n)\)!\)\) \(\((\[ImaginaryI]\^2)\)\^n\) 
              y\^\(2  n\)\  + \ \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                  1\/\(\((2  n + 
                        1)\)!\)\) \(\((\[ImaginaryI]\^2)\)\^n\) \[ImaginaryI]\
\ y\^\(2  n + 1\)\)\)\ \[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(\[Sum]\+\(n = 0\)\%\[Infinity]\( 
                  1\/\(\((2  n)\)!\)\) \(\((\(-1\))\)\^n\) 
              y\^\(2  n\)\  + \ \[ImaginaryI] \(\[Sum]\+\(n = \
0\)\%\[Infinity]\( 
                    1\/\(\((2  n + 
                          1)\)!\)\) \((\(-1\))\)\^n\ y\^\(2  n + 1\)\)\)\)\
\[IndentingNewLine]\ \), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(cos\ y\ \  + \ \[ImaginaryI]\ sin\ y\)\
\)\)}]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\[ExponentialE]\^x\ \  \[Equal] \ \ \[Sum]\+\(k = 0\)\%\[Infinity]\( 
              1\/\(k!\)\) x\^k\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ y\)\  \[Equal] \ \[Sum]\+\(n = \
0\)\%\[Infinity]\( 1\/\(\((2  n)\)!\)\) \(\[ImaginaryI]\^\(2  n\)\) 
                y\^\(2  n\)\  + \ \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                    1\/\(\((2  n + 1)\)!\)\) \(\[ImaginaryI]\^\(2  n + 1\)\) 
                y\^\(2  n + 1\)\ \ \ \  // ComplexExpand\) // 
      PowerExpand\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ y\)\  \[Equal] \ \[Sum]\+\(n = \
0\)\%\[Infinity]\( 1\/\(\((2  n)\)!\)\) \(\[ImaginaryI]\^\(2  n\)\) 
                y\^\(2  n\)\  + \ \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                    1\/\(\((2  n + 1)\)!\)\) \(\[ImaginaryI]\^\(2  n + 1\)\) 
                y\^\(2  n + 1\)\ \ \ \ \  // ComplexExpand\) // 
      PowerExpand\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ y\)\  \[Equal] \[Sum]\+\(n = 0\)\%\
\[Infinity]\( 1\/\(\((2  n)\)!\)\) \(\((\(-1\))\)\^n\) 
                y\^\(2  n\)\  + \[ImaginaryI] \(\[Sum]\+\(n = \
0\)\%\[Infinity]\( 1\/\(\((2  n + 
                            1)\)!\)\) \((\(-1\))\)\^n\ y\^\(2  n + 1\)\)\ \ \ \
\ \  // ComplexExpand\) // PowerExpand\)], "Input"]
}, Closed]],

Cell[TextData[{
  "\tThus, it seems the only possible value for ",
  Cell[BoxData[
      \(\[ExponentialE]\^z\)]],
  " is  ",
  Cell[BoxData[
      \(\[ExponentialE]\^z\  = \ \(\[ExponentialE]\^x\) \((cos\ y\  + \ \
\[ImaginaryI]\ sin\ y)\)\)]],
  ".  We will use this result freely from now on, and, as stated, supply a \
rigorous proof in Chapter 5."
}], "Text"],

Cell[TextData[{
  "If we set ",
  StyleBox["x=0",
    FontFamily->"Courier New"],
  " and let ",
  Cell[BoxData[
      \(\[Theta]\)]],
  " take the role of ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " in the above equation, we get a famous result known as ",
  StyleBox[ButtonBox["Euler Formula",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/EulerFormula.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ": \n\n\t\t\t",
  Cell[BoxData[
      \(e\^\[ImaginaryI]\[Theta]\  = \ \ \(cos\ \[Theta]\  + \ 
            i\ sin\ \[Theta]\  = \ \((cos\ \[Theta]\ , 
            sin\ \[Theta])\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tIf ",
  Cell[BoxData[
      \(\[Theta]\)]],
  " is a real number, ",
  Cell[BoxData[
      \(e\^\[ImaginaryI]\[Theta]\)]],
  " will be located somewhere on the circle with radius ",
  StyleBox["1",
    FontFamily->"Courier New"],
  " centered at the origin.  This assertion is easy to verify because   \n\n\t\
\t\t",
  Cell[BoxData[
      \(\(\(|\)\(e\^\[ImaginaryI]\[Theta]\)\(|\)\)\  = \ \(\@\(cos\^2\ \
\[Theta]\  + \ sin\^2\ \[Theta]\)\  = \ 1\)\)]],
  ".  \n\nFigure 1.12 illustrates the location of the points ",
  Cell[BoxData[
      \(e\^\[ImaginaryI]\[Theta]\)]],
  " for various values of ",
  Cell[BoxData[
      \(\[Theta]\)]],
  "."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006;0001>2000`400?l0
0000o`00003oo`3ooon<0?ooo`00o`3ooon<0?ooo`00o`3ooon<0?ooo`00
Q03oool40000ool0oooo103oool008<0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`3o0?ooo`40oooo00230?ooo`H0003oo`3oool3
0?ooo`00N03oool40000o`<0oooo2@000?l30?ooo`T0003o0P3oool30000
o`H0oooo10000?l00`3oool0003o0000o`020?ooo`@0003o00<0oooo0000
o`000?l00`000?l90?ooo`<000000`3oool3000000040?ooo`0000000000
0?ooo`8000001@3oool3000000040?ooo`0000000000000000<0oooo0P00
00030?ooo`@0000000@0oooo000000000000oooo0`000000103oool00000
0000000000020?ooo`<0000000<0oooo000000000000103oool300000080
oooo0`0000060?ooo`@00000403oool300000080oooo0`0000020?ooo`<0
00001P3oool00`000000oooo0?ooo`020?ooo`L0000000D0oooo00000000
000000000?ooo`03000000@0oooo1`0000070?ooo`030000003oool0oooo
0080oooo1`0000020?ooo`@0000000<0oooo0000000000000P3oool30000
00H0oooo0`0000020?ooo`<000001@3oool4000000@0oooo0@0000010?oo
o`00N@3oool20000o`D0oooo0P000?l00`3oool0003o0?ooo`050?ooo`80
003o00<0oooo0000o`000?l00P3oool20000o`80oooo0P000?l20?ooo`03
0000o`3oool0oooo00@0oooo0P000?l20?ooo`80003o0`3oool20000o`<0
oooo10000?l:0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3o
ool000000?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0
00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000
00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo0000
00<0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo
000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0
oooo0000003oool000000P3oool00`000000oooo000000020?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`00N@3oool20000o`D0oooo0P000?l20?ooo`<0003o
0`3oool20000o`030?ooo`000?l0003o0080oooo0P000?l20?ooo`80003o
2@3oool20000o`L0oooo0P000?l30?ooo`030000o`3oool0oooo00/0oooo
00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo0000
00P0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?oo
o`040000003oool0oooo00000080oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`0000060?ooo`030000003o
ool000000080oooo00@000000?ooo`3oool000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo000000060?ooo`800000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo001i0?ooo`80
003o00<0oooo0000o`3oool00P3oool20000o`040?ooo`000?l0003o0?oo
o`80003o0P3oool20000o`030?ooo`000?l0003o0080oooo0P000?l20?oo
o`D0003o1P3oool20000o`L0oooo0P000?l40?ooo`030000o`3oool0oooo
00X0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`000000
oooo00@000001@3oool00`000000oooo000000030?ooo`030000003oool0
000000D0oooo0`0000020?ooo`070000003oool0oooo0?ooo`000000oooo
000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0103oool500000140oooo00@000000?ooo`3oool000000`3oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0000000<0oooo0`00
00020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`00000000001`3oool0
0`000000oooo000000030?ooo`<000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0000000<0000000<0oooo0000000000001P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
001i0?ooo`@0003o0`3oool20000o`040?ooo`000?l0003o0?ooo`80003o
0P3oool20000o`030?ooo`000?l0003o0080oooo0P000?l01@3oool0003o
0000o`000?l0oooo0080003o1P3oool20000o`L0oooo0P000?l50?ooo`03
0000o`3oool0oooo00T0oooo00<000000?ooo`3oool00`3oool200000004
0?ooo`000000oooo00000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`03
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`0000000P3oool300000080oooo
0P0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool00P0000040?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`030000003oool0oooo008000000P3oool00`000000oooo00000003
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`040000003oool0oooo00000080oooo00H000000?oo
o`3oool000000?ooo`0000020?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00`3oool7000000@0oooo001i0?ooo`80003o00@0
oooo0000o`3oool0oooo0`000?l20?ooo`P0003o00@0oooo0000o`000?l0
oooo1@000?l0103oool0003o0000o`000?l70?ooo`80003o1`3oool20000
o`D0oooo0P000?l:0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000000`3oool2000000H0oooo00<000000?ooo`3oool00`0000030?oo
o`<000000P3oool200000080oooo0`0000000`3oool00000000000020?oo
o`<000000P3oool2000000030?ooo`000000oooo00D0oooo0`0000020?oo
o`<000001P3oool3000000@0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`040?ooo`<000000P3oool300000080oooo0P000000
103oool000000?ooo`3oool300000080oooo0P0000000`3oool000000000
00020?ooo`80000000@0oooo00000000000000000P3oool300000080oooo
0P0000000`3oool00000000000020?ooo`<000000`3oool300000080oooo
0P0000000`3oool00000000000030?ooo`050000003oool000000000003o
ool00P0000020?ooo`8000000`3oool3000000D0oooo0`0000020?ooo`<0
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo001i0?ooo`80003o9@3oool20000o`L0oooo0P000?l20?ooo`030000
o`3oool0oooo0080003o2P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool007T0oooo
0P000?l30?ooo`040000o`3oool0003o0000oah0oooo0P000?l70?ooo`80
003o0`3oool40000o`L0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00000=0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool06@3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo00D000001P3oool010000000oooo0?ooo`00000n0?ooo`030000
003oool0oooo01T0oooo00@000000?ooo`3oool00000103oool4000000D0
oooo001h0?ooo`L0003o00<0oooo0000o`000?l07@3oool30000o`H0oooo
0`000?l30?ooo`<0003o203oool7000000030?ooo`000000000000`0oooo
0P00000F0?ooo`030000003oool0oooo01H0oooo0`00000:0?ooo`800000
0`3oool010000000oooo0?ooo`0000070?ooo`<00000703oool00`000000
oooo0?ooo`0N0?ooo`800000703oool3000000d0oooo003o0?oooa@0oooo
0P00001f0?ooo`00o`3oool?0?ooo`030000003oool0oooo07X0oooo003o
0?oooh`0oooo003o0?oooh`0oooo003o0?oooh`0oooo003o0?oooh`0oooo
003o0?oooh`0oooo003o0?oooh`0oooo003o0?oooh`0oooo003o0?oooh`0
oooo003Z0?ooo`030000003oool0oooo09h0oooo003Z0?ooo`030000003o
ool0oooo09h0oooo003Z0?ooo`030000003oool0oooo09h0oooo003Z0?oo
o`030000003oool0oooo09h0oooo003Z0?ooo`030000003oool0oooo0480
oooo1@00000R0?ooo`D00000<03oool00>X0oooo00<000000?ooo`3oool0
@P3oool01@000000oooo0?ooo`3oool000000280oooo00D000000?ooo`3o
ool0oooo0000000`0?ooo`00jP3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0<@3oool00>X0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo0300oooo003Z0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0_0?ooo`00jP3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0;P3oool00>X0oooo00<000000?ooo`3oool0@P3oool01@00
0000oooo0?ooo`3oool000000280oooo00D000000?ooo`3oool0oooo0000
000`0?ooo`00jP3oool00`000000oooo0?ooo`130?ooo`<00000903oool3
00000340oooo003Z0?ooo`030000003oool0oooo09h0oooo003Z0?ooo`03
0000003oool0oooo0340oooo1@00001X0?ooo`00jP3oool00`000000oooo
0?ooo`0i0?oooaL000000`3oool5000000@0oooo8@00000Q0?ooo`00jP3o
ool00`000000oooo0?ooo`0a0?ooo`D00000J03oool00>X0oooo00<00000
0?ooo`3oool0WP3oool00>X0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo003Z0?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0_0?ooo`00jP3oool00`000000oooo0?ooo`0o0?ooo`800000
1@3oool5000001<0oooo1`0000060?ooo`8000001P3oool5000002H0oooo
003Z0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000001D0oooo00<000000?ooo`000000
203oool00`000000oooo000000050?ooo`050000003oool0oooo0?ooo`00
00009P3oool00>X0oooo00<000000?ooo`3oool0?P3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo01H0oooo00<000000?ooo`00
00001`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo
02L0oooo003Z0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool09P3oool00>X0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0503oool00`000000oooo
000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0U0?ooo`00jP3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3o
ool5000000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0T0?ooo`00jP3oool00`000000oooo0?ooo`120?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo0000000V0?ooo`00jP3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0080oooo0`00
000G0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3o
ool3000002L0oooo003Z0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0/0?ooo`00Q03oool50000
01L0oooo1@00000k0?oooa@0ool0?03oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo02`0oooo00240?ooo`050000003oool0oooo0?oo
o`0000005`3oool01@000000oooo0?ooo`3oool0000003<0oooo203oo`0:
0?ooo`030000003oool0oooo00L0oooo203oo`0d0?ooo``00000803oool<
000002<0oooo00250?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0;P3oool60?oo0180oooo00<000000?ooo`3oool03`3oool60?oo
08T0oooo00260?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0:`3oool20?oo01P0oooo00<000000?ooo`3oool05@3oool30?oo08H0
oooo00270?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
903oool60?oo01X0oooo00<000000?ooo`3oool0603oool50?oo0840oooo
00280?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0803o
ool30?oo0200oooo00<000000?ooo`3oool07@3oool30?oo07h0oooo0024
0?ooo`050000003oool0oooo0?ooo`0000005`3oool01@000000oooo0?oo
o`3oool000000200oooo0P3oo`0S0?ooo`030000003oool0oooo0200oooo
0`3oo`1k0?ooo`00Q@3oool3000001T0oooo0`00000N0?ooo`<0ool09@3o
ool00`000000oooo0?ooo`0S0?ooo`80ool0N@3oool006`0oooo1@00001>
0?ooo`<0ool0:03oool00`000000oooo0?ooo`0@0?ooo`D00000403oool3
0?oo0140oooo1@00001P0?ooo`00L`3oool5000000<0oooo5`0000030?oo
o`D000000`3oool;000001D0oooo0P3oo`0[0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`0000005P3oool30?oo00L0oooo1@000000103o
ool000000?ooo`00001S0?ooo`00K03oool5000004T0oooo0`3oo`0]0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`0000006@3oool20?oo
00/0oooo00<000000?ooo`000000H`3oool00;P0oooo0P3oo`0`0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`0000000`00000H0?ooo`80
ool00`3oool5000000030?ooo`000000oooo00@00000H03oool00880oooo
00<000000?ooo`3oool0<P3oool00`3oo`00oooo0?ooo`0`0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00D0oooo0P3oo`070?ooo`030000
003oool000000080oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`1<0?ooo`00PP3oool00`000000oooo0?ooo`0`0?ooo`80ool0<`3o
ool00`000000oooo0?ooo`0@0?ooo`@000000`3oool3000000<0oooo00<0
00000?ooo`000000103oool010000000oooo0?ooo`0000050?ooo`<00000
00<0oooo0?oo003oool01P3oool4000000P0oooo100000040?ooo`030000
003oool0000000D0oooo0`0000160?ooo`00P@3oool2000000H0oooo0`00
000D0?ooo`L00000303oool20?oo03D0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo0?ooo`<0ool02`3oool400000080oooo00@000000?ooo`3o
ool000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`3oool0A@3oool00840oooo00<000000?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000001D0oooo00<000000?ooo`000000303oool2
0?oo03L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`02
0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`040000
003oool0oooo0?ooo`@000001@3oool20?oo00l0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00@000000?ooo`3oool0oooo1000
00160?ooo`00P03oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`0000002P3oool20?oo03T0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`030?ooo`060000003o
ool0oooo0000003oool00000103oool01`000000oooo0?ooo`3oool00000
0?ooo`000000203oool00`3oo`00oooo0?ooo`0<0?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`00
0000oooo000000170?ooo`00OP3oool00`000000oooo000000020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000
oooo000000090?ooo`030?oo003oool0oooo03T0oooo00<000000?ooo`3o
ool05`3oool2000000<0oooo00@000000?ooo`000000oooo1@0000040?oo
o`040000003oool0oooo0?ooo`8000002@3oool20?oo00/0oooo0P000002
0?ooo`D000000`3oool010000000oooo0?ooo`3oool2000004L0oooo001o
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2
000001H0oooo00<000000?ooo`0000001`3oool20?oo03`0oooo00<00000
0?ooo`3oool0703oool3000000X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`80ool05@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo04D0oooo00240?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool04@3oool5000000D0oooo0P3oo`0n0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool08@3oool00`3o
o`00oooo0?ooo`070?ooo`030000003oool0oooo05D0oooo00240?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0J0?oo
o`030?oo003oool0oooo03h0oooo00<000000?ooo`3oool0?@3oool00`3o
o`00oooo0?ooo`1N0?ooo`00Q03oool00`000000oooo0?ooo`020?ooo`<0
00005`3oool00`000000oooo0?ooo`020?ooo`030?oo003oool0oooo03l0
oooo00<000000?ooo`3oool0?P3oool00`3oo`00oooo0?ooo`1M0?ooo`00
Q@3oool00`000000oooo0?ooo`0O0?ooo`030?oo003oool0oooo0400oooo
00<000000?ooo`3oool0?`3oool20?oo05d0oooo00250?ooo`030000003o
ool0oooo01d0oooo0P3oo`130?ooo`030000003oool0oooo0440oooo0P3o
o`1K0?ooo`00Q@3oool<000001<0oooo00<0ool00?ooo`3oool0@`3oool0
0`000000oooo0?ooo`130?ooo`030?oo003oool0oooo05P0oooo002S0?oo
o`030?oo003oool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`3o
o`00oooo0?ooo`1G0?ooo`00X@3oool20?oo04L0oooo00<000000?ooo`3o
ool0A@3oool00`3oo`00oooo0?ooo`1F0?ooo`00X03oool00`3oo`00oooo
0?ooo`170?ooo`030000003oool0oooo04H0oooo00<0ool00?ooo`3oool0
E@3oool009l0oooo00<0ool00?ooo`3oool0B03oool00`000000oooo0?oo
o`170?ooo`030?oo003oool0oooo05@0oooo002N0?ooo`030?oo003oool0
oooo04T0oooo00<000000?ooo`3oool0B03oool00`3oo`00oooo0?ooo`1C
0?ooo`00W@3oool00`3oo`00oooo0?ooo`1:0?ooo`030000003oool0oooo
04T0oooo00<0ool00?ooo`3oool0DP3oool009`0oooo00<0ool00?ooo`3o
ool0B`3oool00`000000oooo0?ooo`1:0?ooo`030?oo003oool0oooo0080
ogl0C`3oool006d0oooo1@00000X0?ooo`80ool0CP3oool00`000000oooo
0?ooo`1;0?ooo`030?oo003oO`00ogl00080ogl0CP3oool006`0oooo00<0
00000?ooo`000000:P3oool00`3oo`00oooo0?ooo`1>0?ooo`030000003o
ool0oooo04/0oooo1P3oO`1=0?ooo`00K03oool00`000000oooo0000000Y
0?ooo`030?oo003oool0oooo04l0oooo00<000000?ooo`3oool0B`3oool6
0?mo04d0oooo001/0?ooo`030000003oool0000000<000004P3oool00`00
0000oooo0?ooo`0@0?ooo`030?oo003oool0oooo0500oooo00<000000?oo
o`3oool0BP3oool60?mo04h0oooo001/0?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00`0000030?ooo`030000003oool0000000@0
oooo00@000000?ooo`3oool00000103oool2000000`0oooo00<0ool00?oo
o`3oool0D03oool00`000000oooo0?ooo`180?ooo`@0ogl000@0oooo0?mo
003oO`00ool0CP3oool006d0oooo100000040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`030?oo
003oool0oooo0540oooo00<000000?ooo`3oool0AP3oool60?mo00@0oooo
00<0ool00?ooo`3oool0B`3oool007D0oooo00<000000?ooo`3oool00P3o
ool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01`000000
oooo0?ooo`3oool000000?ooo`0000002@3oool00`3oo`00oooo0?ooo`1B
0?ooo`030000003oool0oooo04D0oooo1P3oO`060?ooo`030?oo003oool0
oooo04X0oooo001e0?ooo`030000003oool0oooo00<0oooo00H000000?oo
o`3oool000000?ooo`0000040?ooo`040000003oool0oooo0?ooo`800000
2@3oool00`3oo`00oooo0?ooo`1C0?ooo`030000003oool0oooo04<0oooo
203oO`070?ooo`030?oo003oool0oooo04T0oooo001d0?ooo`8000000`3o
ool010000000oooo0000003oool5000000@0oooo00@000000?ooo`3oool0
00002@3oool00`3oo`00oooo0?ooo`1D0?ooo`030000003oool0oooo0480
oooo203oO`090?ooo`030?oo003oool0oooo04P0oooo001i0?ooo`<00000
2P3oool010000000oooo0?ooo`3oool2000000H0oooo00<0ool00?ooo`3o
ool0E@3oool00`000000oooo0?ooo`130?ooo`L0ogl02P3oool00`3oo`00
oooo0?ooo`170?ooo`00M@3oool00`000000oooo0?ooo`0I0?ooo`030?oo
003oool0oooo05H0oooo00<000000?ooo`3oool0A03oool50?mo00`0oooo
00<0ool00?ooo`3oool0AP3oool00900oooo00<0ool00?ooo`3oool0E`3o
ool00`000000oooo0?ooo`130?ooo`030?mo003oool0ogl000<0ogl03@3o
ool00`3oo`00oooo0?ooo`150?ooo`00S`3oool00`3oo`00oooo0?ooo`1H
0?ooo`030000003oool0oooo0480oooo00@0ogl00?ooo`3oool0oooo0P3o
O`0?0?ooo`030?oo003oool0oooo04@0oooo002?0?ooo`030?oo003oool0
oooo05P0oooo00<000000?ooo`3oool0@@3oool00`3oO`00oooo0?ooo`03
0?ooo`030?mo003oool0oooo00h0oooo00<0ool00?ooo`3oool0@`3oool0
08h0oooo00<0ool00?ooo`3oool0F@3oool00`000000oooo0?ooo`100?oo
o`030?mo003oool0oooo01D0oooo00<0ool00?ooo`3oool0@`3oool008h0
oooo00<0ool00?ooo`3oool0F@3oool00`000000oooo0?ooo`0o0?ooo`03
0?mo003oool0oooo01L0oooo00<0ool00?ooo`3oool0@P3oool008d0oooo
00<0ool00?ooo`3oool0FP3oool00`000000oooo0?ooo`0n0?ooo`030?mo
003oool0oooo01P0oooo00<0ool00?ooo`3oool0@P3oool008`0oooo00<0
ool00?ooo`3oool0F`3oool00`000000oooo0?ooo`0m0?ooo`030?mo003o
ool0oooo01X0oooo00<0ool00?ooo`3oool0@@3oool008/0oooo00<0ool0
0?ooo`3oool0G03oool00`000000oooo0?ooo`0l0?ooo`030?mo003oool0
oooo01`0oooo00<0ool00?ooo`3oool0@03oool008X0oooo00<0ool00?oo
o`3oool0G@3oool00`000000oooo0?ooo`0k0?ooo`030?mo003oool0oooo
01d0oooo00<0ool00?ooo`3oool0@03oool008X0oooo00<0ool00?ooo`3o
ool0G@3oool00`000000oooo0?ooo`0j0?ooo`030?mo003oool0oooo01l0
oooo00<0ool00?ooo`3oool0?`3oool008T0oooo00<0ool00?ooo`3oool0
GP3oool00`000000oooo0?ooo`0i0?ooo`030?mo003oool0oooo0240oooo
00<0ool00?ooo`3oool0?P3oool008T0oooo00<0ool00?ooo`3oool0GP3o
ool00`000000oooo0?ooo`0h0?ooo`030?mo003oool0oooo0280oooo00<0
ool00?ooo`3oool0?P3oool008H0oooo0P00ool00`3oo`00oooo0?ooo`1O
0?ooo`030000003oool0oooo03L0oooo00<0ogl00?ooo`3oool0903oool0
0`3oo`00oooo0?ooo`0m0?ooo`00Q@3oool4003oof40oooo00<000000?oo
o`3oool0=P3oool00`3oO`00oooo0?ooo`0U0?ooo`030?oo003oool0oooo
03d0oooo00240?ooo`H00?ooH03oool00`000000oooo0?ooo`0e0?ooo`03
0?mo003oool0oooo02L0oooo00<0ool00?ooo`3oool0?03oool008@0oooo
2000oomN0?ooo`030000003oool0oooo03@0oooo00<0ogl00?ooo`3oool0
:@3oool00`3oo`00oooo0?ooo`0k0?ooo`00Q@3oool:003ooe/0oooo00<0
00000?ooo`3oool0<`3oool00`3oO`00oooo0?ooo`0Z0?ooo`030?oo003o
ool0oooo03/0oooo00250?ooo`030?oo0000ool00?oo0080oooo2000oomH
0?ooo`030000003oool0oooo0380oooo00<0ogl00?ooo`3oool0;03oool0
0`3oo`00oooo0?ooo`0j0?ooo`00Q03oool00`3oo`00oooo0?ooo`040?oo
o`T00?ooEP3oool00`000000oooo0?ooo`0a0?ooo`030?mo003oool0oooo
02d0oooo00<0ool00?ooo`3oool0>P3oool008@0oooo00<0ool00?ooo`3o
ool01@3oool7003ooeL0oooo00<000000?ooo`3oool0<03oool00`3oO`00
oooo0?ooo`0_0?ooo`030?oo003oool0oooo03T0oooo00240?ooo`030?oo
003oool0oooo00H0oooo1P00oomG0?ooo`030000003oool0oooo02l0oooo
00<0ogl00?ooo`3oool0<03oool00`3oo`00oooo0?ooo`0i0?ooo`00P`3o
ool00`3oo`00oooo0?ooo`080?ooo`@00?oo00<0oooo003oo`00ool0E@3o
ool00`000000oooo0?ooo`0^0?ooo`030?mo003oool0oooo0380oooo00<0
ool00?ooo`3oool0>03oool008<0oooo00<0ool00?ooo`3oool02@3oool3
003oo`<0oooo00<00?oo0?ooo`3oool0DP3oool00`000000oooo0?ooo`0]
0?ooo`030?mo003oool0oooo03<0oooo00<0ool00?ooo`3oool0>03oool0
0880oooo00<0ool00?ooo`3oool02`3oool00`00ool0oooo0?ooo`030?oo
o`800?ooDP3oool00`000000oooo0?ooo`0/0?ooo`030?mo003oool0oooo
03D0oooo00<0ool00?ooo`3oool0=`3oool00880oooo00<0ool00?ooo`3o
ool04`3oool2003ooe00oooo00<000000?ooo`3oool0:`3oool00`3oO`00
oooo0?ooo`0g0?ooo`030?oo003oool0oooo03H0oooo00220?ooo`030?oo
003oool0oooo01D0oooo00<00?oo0?ooo`3oool0C@3oool00`000000oooo
0?ooo`0Z0?ooo`030?mo003oool0oooo03P0oooo00<0ool00?ooo`3oool0
=P3oool00840oooo00<0ool00?ooo`3oool05`3oool2003oodd0oooo00<0
00000?ooo`3oool0:@3oool00`3oO`00oooo0?ooo`0j0?ooo`030?oo003o
ool0oooo03D0oooo00210?ooo`030?oo003oool0oooo01T0oooo0P00oom;
0?ooo`030000003oool0oooo02P0oooo00<0ogl00?ooo`3oool0>`3oool0
0`3oo`00oooo0?ooo`0e0?ooo`00P03oool00`3oo`00oooo0?ooo`0L0?oo
o`800?ooB@3oool00`000000oooo0?ooo`0W0?ooo`030?mo003oool0oooo
03`0oooo00<0ool00?ooo`3oool0=@3oool007l0oooo00<0ool00?ooo`3o
ool07`3oool00`00ool0oooo0?ooo`160?ooo`030000003oool0oooo02H0
oooo00<0ogl00?ooo`3oool0?P3oool00`3oo`00oooo0?ooo`0d0?ooo`00
O`3oool00`3oo`00oooo0?ooo`0P0?ooo`800?ooAP3oool00`000000oooo
0?ooo`0U0?ooo`030?mo003oool0oooo03l0oooo00<0ool00?ooo`3oool0
=03oool007h0oooo00<0ool00?ooo`3oool08`3oool2003ood@0oooo00<0
00000?ooo`3oool09@3oool00`3oO`00oooo0?ooo`0o0?ooo`030?oo003o
ool0oooo03@0oooo001n0?ooo`030?oo003oool0oooo02D0oooo0P00oom2
0?ooo`030000003oool0oooo02@0oooo00<0ogl00?ooo`3oool0@@3oool0
0`3oo`00oooo0?ooo`0c0?ooo`00OP3oool00`3oo`00oooo0?ooo`0W0?oo
o`03003oo`3oool0oooo03l0oooo00<000000?ooo`3oool08`3oool00`3o
O`00oooo0?ooo`120?ooo`030?oo003oool0oooo03<0oooo001n0?ooo`03
0?oo003oool0oooo02P0oooo0P00oolo0?ooo`030000003oool0oooo0280
oooo00<0ogl00?ooo`3oool0A03oool00`3oo`00oooo0?ooo`0b0?ooo`00
OP3oool00`3oo`00oooo0?ooo`0Z0?ooo`800?oo?@3oool00`000000oooo
0?ooo`0Q0?ooo`030?mo003oool0oooo04D0oooo00<0ool00?ooo`3oool0
<P3oool007h0oooo00<0ool00?ooo`3oool0;03oool2003ooc/0oooo00<0
00000?ooo`3oool0803oool00`3oO`00oooo0?ooo`160?ooo`030?oo003o
ool0oooo0380oooo001m0?ooo`030?oo003oool0oooo02l0oooo00<00?oo
0?ooo`3oool0>03oool00`000000oooo0?ooo`0O0?ooo`030?mo003oool0
oooo04P0oooo00<0ool00?ooo`3oool0<@3oool007d0oooo00<0ool00?oo
o`3oool0<03oool2003oocP0oooo00<000000?ooo`3oool07P3oool00`3o
O`00oooo0?ooo`190?ooo`030?oo003oool0oooo0340oooo001l0?ooo`03
0?oo003oool0oooo03<0oooo0P00oolf0?ooo`030000003oool0oooo01d0
oooo00<0ogl00?ooo`3oool0BP3oool00`3oo`00oooo0?ooo`0a0?ooo`00
O03oool00`3oo`00oooo0?ooo`0e0?ooo`800?oo=03oool00`000000oooo
0?ooo`0L0?ooo`030?mo003oool0oooo04/0oooo00<0ool00?ooo`3oool0
<@3oool007`0oooo00<0ool00?ooo`3oool0=`3oool00`00ool0oooo0?oo
o`0a0?ooo`030000003oool0oooo01/0oooo00<0ogl00?ooo`3oool0C03o
ool00`3oo`00oooo0?ooo`0a0?ooo`00N`3oool00`3oo`00oooo0?ooo`0i
0?ooo`800?oo<@3oool00`000000oooo0?ooo`0J0?ooo`030?mo003oool0
oooo04h0oooo00<0ool00?ooo`3oool0<03oool007/0oooo00<0ool00?oo
o`3oool0>`3oool2003oobl0oooo00<000000?ooo`3oool06@3oool00`3o
O`00oooo0?ooo`1?0?ooo`030?oo003oool0oooo0300oooo001k0?ooo`03
0?oo003oool0oooo03d0oooo00<00?oo0?ooo`3oool0;03oool00`000000
oooo0?ooo`0H0?ooo`030?mo003oool0oooo0500oooo00<0ool00?ooo`3o
ool0<03oool007X0oooo00<0ool00?ooo`3oool0?`3oool2003oob`0oooo
00<000000?ooo`3oool05`3oool00`3oO`00oooo0?ooo`1B0?ooo`030?oo
003oool0oooo02l0oooo001j0?ooo`030?oo003oool0oooo0440oooo0P00
oolZ0?ooo`030000003oool0oooo01H0oooo00<0ogl00?ooo`3oool0D`3o
ool00`3oo`00oooo0?ooo`0_0?ooo`00NP3oool00`3oo`00oooo0?ooo`13
0?ooo`800?oo:03oool00`000000oooo0?ooo`0E0?ooo`030?mo003oool0
oooo05@0oooo00<0ool00?ooo`3oool0;`3oool007X0oooo00<0ool00?oo
o`3oool0A@3oool00`00ool0oooo0?ooo`0U0?ooo`030000003oool0oooo
01@0oooo00<0ogl00?ooo`3oool0E@3oool00`3oo`00oooo0?ooo`0_0?oo
o`00NP3oool00`3oo`00oooo0?ooo`160?ooo`800?oo9@3oool00`000000
oooo0?ooo`0C0?ooo`030?mo003oool0oooo05H0oooo00<0ool00?ooo`3o
ool0;`3oool007T0oooo00<0ool00?ooo`3oool0B@3oool2003oob<0oooo
00<000000?ooo`3oool04P3oool00`3oO`00oooo0?ooo`1G0?ooo`030?oo
003oool0oooo02l0oooo001i0?ooo`030?oo003oool0oooo04/0oooo0P00
oolQ0?ooo`030000003oool0oooo0140oooo00<0ogl00?ooo`3oool0F@3o
ool00`3oo`00oooo0?ooo`0^0?ooo`00N@3oool00`3oo`00oooo0?ooo`1=
0?ooo`03003oo`3oool0oooo01h0oooo00<000000?ooo`3oool0403oool0
0`3oO`00oooo0?ooo`1J0?ooo`030?oo003oool0oooo02h0oooo001i0?oo
o`030?oo003oool0oooo04h0oooo0P00oolN0?ooo`030000003oool0oooo
00l0oooo00<0ogl00?ooo`3oool0F`3oool00`3oo`00oooo0?ooo`0^0?oo
o`00N@3oool00`3oo`00oooo0?ooo`1@0?ooo`800?oo703oool00`000000
oooo0?ooo`0>0?ooo`030?mo003oool0oooo05`0oooo00<0ool00?ooo`3o
ool0;P3oool007T0oooo00<0ool00?ooo`3oool0DP3oool2003ooaX0oooo
00<000000?ooo`3oool03@3oool00`3oO`00oooo0?ooo`1M0?ooo`030?oo
003oool0oooo02h0oooo001h0?ooo`030?oo003oool0oooo05D0oooo00<0
0?oo0?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`030?mo003o
ool0oooo05l0oooo00<0ool00?ooo`3oool0;@3oool007P0oooo00<0ool0
0?ooo`3oool0EP3oool2003ooaL0oooo00<000000?ooo`3oool02`3oool0
0`3oO`00oooo0?ooo`1P0?ooo`030?oo003oool0oooo02d0oooo001h0?oo
o`030?oo003oool0oooo05P0oooo0P00oolE0?ooo`030000003oool0oooo
00X0oooo00<0ogl00?ooo`3oool0H@3oool00`3oo`00oooo0?ooo`0]0?oo
o`00N03oool00`3oo`00oooo0?ooo`1J0?ooo`800?oo4`3oool00`000000
oooo0?ooo`090?ooo`030?mo003oool0oooo0680oooo00<0ool00?ooo`3o
ool0;@3oool007P0oooo00<0ool00?ooo`3oool0G03oool00`00ool0oooo
0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<0ogl00?ooo`3oool0
H`3oool00`3oo`00oooo0?ooo`0]0?ooo`00N03oool00`3oo`00oooo0?oo
o`1M0?ooo`800?oo403oool00`000000oooo0?ooo`070?ooo`030?mo003o
ool0oooo06@0oooo00<0ool00?ooo`3oool0;@3oool007P0oooo00<0ool0
0?ooo`3oool0G`3oool2003oo`h0oooo00<000000?ooo`3oool01P3oool0
0`3oO`00oooo0?ooo`1U0?ooo`030?oo003oool0oooo02d0oooo001h0?oo
o`030?oo003oool0oooo0640oooo00<00?oo0?ooo`3oool02`3oool00`00
0000oooo0?ooo`050?ooo`030?mo003oool0oooo06H0oooo00<0ool00?oo
o`3oool0;@3oool007P0oooo00<0ool00?ooo`3oool0HP3oool2003oo`/0
oooo00<000000?ooo`3oool0103oool00`3oO`00oooo0?ooo`1W0?ooo`03
0?oo003oool0oooo02d0oooo001h0?ooo`030?oo003oool0oooo06@0oooo
0P00ool90?ooo`030000003oool0oooo00<0oooo00<0ogl00?ooo`3oool0
J@3oool00`3oo`00oooo0?ooo`0/0?ooo`00N03oool00`3oo`00oooo0?oo
o`1V0?ooo`800?oo1`3oool00`000000oooo0?ooo`020?ooo`030?mo003o
ool0oooo06X0oooo00<0ool00?ooo`3oool0;03oool007P0oooo00<0ool0
0?ooo`3oool0J03oool00`00ool0oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`3oO`00K@3oool00`3oo`00oooo0?ooo`0/0?ooo`00N03oool0
0`3oo`00oooo0?ooo`080?ooo`80o`3oG`3oool2003oo`@0oooo00@00000
0?ooo`3oool0ogl0H@3oool30?l000X0oooo00<0ool00?ooo`3oool0;03o
ool007L0oooo0P3o0?l60?ooo`H0o`3oH@3oool2003oo`80oooo00<00000
0?ooo`3oO`00HP3oool70?l000D0oooo0P3o000^0?ooo`00MP3oool40?l0
o`030?ooo`3o0?l0o`3o00P0o`3oH`3oool2003oo`030000003oO`00oooo
0680oooo3`3o000A0?ooo`80000000<0oooo0000000000005`3oool006`0
oooo2@00001e0?l0o`030?mo003o0000o`000780o`002@0000080?ooo`03
0000003oool0000001P0oooo001e0?oooa00o`3oI@3oool00`000?l00?l0
0?ooo`1R0?oooa00o`004P3oool00`000000oooo0?ooo`0G0?ooo`00MP3o
ool40?l0o`@0oooo1`3o0?mU0?ooo`030000o`00o`00oooo0680oooo1`3o
00040?ooo`@0o`004@3oool2000000030?ooo`000000000001L0oooo001g
0?ooo`80o`3o2@3oool30?l0ofD0oooo00<0003o0?ooo`00o`00HP3oool3
0?l000T0oooo0P3o000^0?ooo`00N03oool00`3oo`00oooo0?ooo`1_0?oo
o`030000o`3oool00?l006l0oooo00<0ool00?ooo`3oool0;03oool007P0
oooo00<0ool00?ooo`3oool0K`3oool010000?l0oooo0?ooo`00o`1^0?oo
o`030?oo003oool0oooo02`0oooo001h0?ooo`030?oo003oool0oooo06l0
oooo00@0003o0?ooo`3oool00?l0KP3oool00`3oo`00oooo0?ooo`0/0?oo
o`00N03oool00`3oo`00oooo0?ooo`1_0?ooo`050000o`3oool0oooo0?oo
o`00o`00K@3oool00`3oo`00oooo0?ooo`0/0?ooo`00N03oool00`3oo`00
oooo0?ooo`1_0?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3o
ool0J@3oool00`3oo`00oooo0?ooo`0]0?ooo`00N03oool00`3oo`00oooo
0?ooo`080?ooo`D000002@3oool5000005@0oooo00<0003o0?ooo`3oool0
0P3oool00`00o`00oooo0?ooo`0W0?ooo`D000006@3oool5000001T0oooo
1@0000000`3oool0ool00?ooo`0^0?ooo`00N03oool00`3oo`00oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo1@000000103oool000000?oo
o`00001G0?ooo`030000o`3oool0oooo00<0oooo00<00?l00?ooo`3oool0
9@3oool00`000000oooo0000000E0?ooo`D0000000@0oooo0000003oool0
00005@3oool5000000@0oooo00D000000?ooo`3oool0oooo0?oo000_0?oo
o`00N03oool0103oo`00oooo0?ooo`3oool5000000@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0000001G0?ooo`030000o`3oool0oooo
00<0oooo00<00?l00?ooo`3oool09@3oool00`000000oooo0000000K0?oo
o`030000003oool0000001h0oooo00D000000?ooo`3oool0oooo0?oo000_
0?ooo`00N03oool00`3oo`00oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo1@0000000`3oool000000?ooo`04000005@0oooo00<0003o0?oo
o`3oool0103oool00`00o`00oooo0?ooo`0T0?ooo`030000003oool00000
00<000004P3oool5000000030?ooo`000000oooo00@000004P3oool50000
00@0oooo00D000000?ooo`3oool0oooo0?oo000_0?ooo`00N03oool00`3o
o`00oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`04000000@0oooo00<000000?oo
o`3oool0A`3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo
02@0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030000
00<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`060?oo
o`030000003oool000000080oooo00<000000?ooo`3oool00`0000020?oo
o`@00000103oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo
0?ooo`3oo`00;`3oool007P0oooo00<0ool00?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`@00000103oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool01@3oool0
0`00o`00oooo0?ooo`0T0?ooo`@00000103oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0
oooo100000040?ooo`050000003oool0oooo0?ooo`0000000`3oool01000
0000oooo0?ooo`00000<0?ooo`050000003oool0oooo0?ooo`3oo`00;`3o
ool007P0oooo00<0ool00?ooo`3oool02P3oool00`000000oooo0?ooo`0A
0?ooo`070000003oool0oooo0?ooo`000000oooo0000001:0?ooo`030000
o`3oool0oooo00H0oooo00<00?l00?ooo`3oool0:`3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0000000B0?oo
o`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003o
ool0000000`0oooo00D000000?ooo`3oool0oooo0?oo000_0?ooo`00N@3o
ool00`3oo`00oooo0?ooo`080?ooo`8000004`3oool01`000000oooo0?oo
o`3oool000000?ooo`000000BP3oool00`000?l0oooo0?ooo`060?ooo`03
003o003oool0oooo02/0oooo00L000000?ooo`3oool0oooo0000003oool0
00000080oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`02
0?ooo`070000003oool0oooo0?ooo`000000oooo0000000;0?ooo`800000
0P3oool00`3oo`00oooo0?ooo`0^0?ooo`00N@3oool00`3oo`00oooo0?oo
o`0L0?ooo`8000000P3oool5000004T0oooo00<0003o0?ooo`3oool01`3o
ool00`00o`00oooo0?ooo`0Y0?ooo`8000000`3oool010000000oooo0000
003oool500000100oooo0P0000030?ooo`040000003oool000000?ooo`D0
00003P3oool00`3oo`00oooo0?ooo`0^0?ooo`00N@3oool00`3oo`00oooo
0?ooo`1^0?ooo`030000o`3oool0oooo00L0oooo00<00?l00?ooo`3oool0
;`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01<0oooo
00<0ool00?ooo`3oool0;P3oool007T0oooo00<0ool00?ooo`3oool07@3o
ool00`000000oooo0?ooo`1>0?ooo`030000o`3oool0oooo00P0oooo00<0
0?l00?ooo`3oool0:@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01P0oooo00<0ool00?ooo`3oool0;P3oool007T0oooo00<0ool0
0?ooo`3oool0KP3oool00`000?l0oooo0?ooo`090?ooo`03003o003oool0
oooo0640oooo00<0ool00?ooo`3oool0;P3oool007T0oooo00<0ool00?oo
o`3oool0KP3oool00`000?l0oooo0?ooo`090?ooo`03003o003oool0oooo
0640oooo00<0ool00?ooo`3oool0;P3oool007X0oooo00<0ool00?ooo`3o
ool0K@3oool00`000?l0oooo0?ooo`0:0?ooo`03003o003oool0oooo05l0
oooo00<0ool00?ooo`3oool0;`3oool007X0oooo00<0ool00?ooo`3oool0
K@3oool00`000?l0oooo0?ooo`0:0?ooo`03003o003oool0oooo05l0oooo
00<0ool00?ooo`3oool0;`3oool007X0oooo00<0ool00?ooo`3oool0K@3o
ool00`000?l0oooo0?ooo`0;0?ooo`03003o003oool0oooo05h0oooo00<0
ool00?ooo`3oool0;`3oool007X0oooo00<0ool00?ooo`3oool0K@3oool0
0`000?l0oooo0?ooo`0;0?ooo`03003o003oool0oooo05h0oooo00<0ool0
0?ooo`3oool0;`3oool007X0oooo00<0ool00?ooo`3oool0K@3oool00`00
0?l0oooo0?ooo`0<0?ooo`03003o003oool0oooo05d0oooo00<0ool00?oo
o`3oool0;`3oool007X0oooo00<0ool00?ooo`3oool0K@3oool00`000?l0
oooo0?ooo`0=0?ooo`03003o003oool0oooo05/0oooo00<0ool00?ooo`3o
ool0<03oool007/0oooo00<0ool00?ooo`3oool0K03oool00`000?l0oooo
0?ooo`0=0?ooo`03003o003oool0oooo05/0oooo00<0ool00?ooo`3oool0
<03oool007/0oooo00<0ool00?ooo`3oool0K03oool00`000?l0oooo0?oo
o`0>0?ooo`03003o003oool0oooo05X0oooo00<0ool00?ooo`3oool0<03o
ool007`0oooo00<0ool00?ooo`3oool0J`3oool00`000?l0oooo0?ooo`0>
0?ooo`03003o003oool0oooo05T0oooo00<0ool00?ooo`3oool0<@3oool0
07`0oooo00<0ool00?ooo`3oool0J`3oool00`000?l0oooo0?ooo`0?0?oo
o`03003o003oool0oooo05P0oooo00<0ool00?ooo`3oool0<@3oool007`0
oooo00<0ool00?ooo`3oool0J`3oool00`000?l0oooo0?ooo`0?0?ooo`03
003o003oool0oooo05P0oooo00<0ool00?ooo`3oool0<@3oool007d0oooo
00<0ool00?ooo`3oool0JP3oool00`000?l0oooo0?ooo`0@0?ooo`03003o
003oool0oooo05L0oooo00<0ool00?ooo`3oool0<@3oool007d0oooo00<0
ool00?ooo`3oool0JP3oool00`000?l0oooo0?ooo`0A0?ooo`03003o003o
ool0oooo05H0oooo00<0ool00?ooo`3oool0<@3oool007d0oooo00<0ool0
0?ooo`3oool0JP3oool00`000?l0oooo0?ooo`0A0?ooo`03003o003oool0
oooo05H0oooo00<0ool00?ooo`3oool0<@3oool007d0oooo00<0ool00?oo
o`3oool0JP3oool00`000?l0oooo0?ooo`0B0?ooo`03003o003oool0oooo
05@0oooo00<0ool00?ooo`3oool0<P3oool007d0oooo00<0ool00?ooo`3o
ool0JP3oool00`000?l0oooo0?ooo`0B0?ooo`03003o003oool0oooo05@0
oooo00<0ool00?ooo`3oool0<P3oool007h0oooo00<0ool00?ooo`3oool0
J@3oool00`000?l0oooo0?ooo`0C0?ooo`03003o003oool0oooo0580oooo
00<0ool00?ooo`3oool0<`3oool007h0oooo00<0ool00?ooo`3oool0J@3o
ool00`000?l0oooo0?ooo`0C0?ooo`03003o003oool0oooo0580oooo00<0
ool00?ooo`3oool0<`3oool007h0oooo00<0ool00?ooo`3oool0J@3oool0
0`000?l0oooo0?ooo`0D0?ooo`03003o003oool0oooo0540oooo00<0ool0
0?ooo`3oool0<`3oool007l0oooo00<0ool00?ooo`3oool0J03oool00`00
0?l0oooo0?ooo`0E0?ooo`03003o003oool0oooo04l0oooo00<0ool00?oo
o`3oool0=03oool007l0oooo00<0ool00?ooo`3oool0J03oool00`000?l0
oooo0?ooo`0E0?ooo`03003o003oool0oooo04l0oooo00<0ool00?ooo`3o
ool0=03oool00800oooo00<0ool00?ooo`3oool0I`3oool00`000?l0oooo
0?ooo`0F0?ooo`03003o003oool0oooo04d0oooo00<0ool00?ooo`3oool0
=@3oool00840oooo00<0ool00?ooo`3oool0IP3oool00`000?l0oooo0?oo
o`0F0?ooo`03003o003oool0oooo04d0oooo00<0ool00?ooo`3oool0=@3o
ool00840oooo00<0ool00?ooo`3oool0IP3oool00`000?l0oooo0?ooo`0G
0?ooo`03003o003oool0oooo04`0oooo00<0ool00?ooo`3oool0=@3oool0
0880oooo00<0ool00?ooo`3oool0I@3oool00`000?l0oooo0?ooo`0G0?oo
o`03003o003oool0oooo04/0oooo00<0ool00?ooo`3oool0=P3oool00880
oooo00<0ool00?ooo`3oool0I@3oool00`000?l0oooo0?ooo`0H0?ooo`03
003o003oool0oooo04X0oooo00<0ool00?ooo`3oool0=P3oool00880oooo
00<0ool00?ooo`3oool0I@3oool00`000?l0oooo0?ooo`0I0?ooo`03003o
003oool0oooo04P0oooo00<0ool00?ooo`3oool0=`3oool008<0oooo00<0
ool00?ooo`3oool0I03oool00`000?l0oooo0?ooo`0I0?ooo`03003o003o
ool0oooo04P0oooo00<0ool00?ooo`3oool0=`3oool008<0oooo00<0ool0
0?ooo`3oool0I03oool00`000?l0oooo0?ooo`0J0?ooo`03003o003oool0
oooo04H0oooo00<0ool00?ooo`3oool0>03oool008<0oooo00<0ool00?oo
o`3oool0I03oool00`000?l0oooo0?ooo`0J0?ooo`03003o003oool0oooo
04D0oooo00<0ool00?ooo`3oool0>@3oool008@0oooo00<0ool00?ooo`3o
ool0H`3oool00`000?l0oooo0?ooo`0K0?ooo`03003o003oool0oooo04@0
oooo00<0ool00?ooo`3oool0>@3oool008@0oooo00<0ool00?ooo`3oool0
H`3oool00`000?l0oooo0?ooo`0L0?ooo`03003o003oool0oooo04<0oooo
00<0ool00?ooo`3oool0>@3oool008D0oooo00<0ool00?ooo`3oool0HP3o
ool00`000?l0oooo0?ooo`0L0?ooo`03003o003oool0oooo0480oooo00<0
ool00?ooo`3oool0>P3oool008D0oooo00<0ool00?ooo`3oool0HP3oool0
0`000?l0oooo0?ooo`0M0?ooo`03003o003oool0oooo0440oooo00<0ool0
0?ooo`3oool0>P3oool008H0oooo00<0ool00?ooo`3oool0H@3oool00`00
0?l0oooo0?ooo`0M0?ooo`03003o003oool0oooo0400oooo00<0ool00?oo
o`3oool0>`3oool008L0oooo00<0ool00?ooo`3oool0H03oool00`000?l0
oooo0?ooo`0N0?ooo`03003o003oool0oooo03h0oooo00<0ool00?ooo`3o
ool0?03oool008L0oooo00<0ool00?ooo`3oool0H03oool00`000?l0oooo
0?ooo`0N0?ooo`03003o003oool0oooo03h0oooo00<0ool00?ooo`3oool0
?03oool008P0oooo00<0ool00?ooo`3oool0G`3oool00`000?l0oooo0?oo
o`0O0?ooo`03003o003oool0oooo03`0oooo00<0ool00?ooo`3oool0?@3o
ool008P0oooo00<0ool00?ooo`3oool0G`3oool00`000?l0oooo0?ooo`0P
0?ooo`03003o003oool0oooo03/0oooo00<0ool00?ooo`3oool0?@3oool0
08T0oooo00<0ool00?ooo`3oool0GP3oool00`000?l0oooo0?ooo`0P0?oo
o`03003o003oool0oooo03X0oooo00<0ool00?ooo`3oool0?P3oool008X0
oooo00<0ool00?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0Q0?ooo`03
003o003oool0oooo03P0oooo00<0ool00?ooo`3oool0?`3oool008X0oooo
00<0ool00?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0Q0?ooo`03003o
003oool0oooo03L0oooo00<0ool00?ooo`3oool0@03oool008/0oooo00<0
ool00?ooo`3oool0G03oool00`000?l0oooo0?ooo`0R0?ooo`03003o003o
ool0oooo03H0oooo00<0ool00?ooo`3oool0@03oool008`0oooo00<0ool0
0?ooo`3oool0F`3oool00`000?l0oooo0?ooo`0R0?ooo`03003o003oool0
oooo03D0oooo00<0ool00?ooo`3oool0@@3oool008`0oooo00<0ool00?oo
o`3oool0F`3oool00`000?l0oooo0?ooo`0S0?ooo`03003o003oool0oooo
03@0oooo00<0ool00?ooo`3oool0@@3oool008d0oooo00<0ool00?ooo`3o
ool0FP3oool00`000?l0oooo0?ooo`0T0?ooo`03003o003oool0oooo0380
oooo00<0ool00?ooo`3oool0@P3oool008h0oooo00<0ool00?ooo`3oool0
F@3oool00`000?l0oooo0?ooo`0T0?ooo`03003o003oool0oooo0340oooo
00<0ool00?ooo`3oool0@`3oool008l0oooo00<0ool00?ooo`3oool0F03o
ool00`000?l0oooo0?ooo`0U0?ooo`03003o003oool0oooo0300oooo00<0
ool00?ooo`3oool0@`3oool008l0oooo00<0ool00?ooo`3oool0F03oool0
0`000?l0oooo0?ooo`0U0?ooo`03003o003oool0oooo02l0oooo00<0ool0
0?ooo`3oool0A03oool00900oooo00<0ool00?ooo`3oool0E`3oool00`00
0?l0oooo0?ooo`0V0?ooo`03003o003oool0oooo02d0oooo00<0ool00?oo
o`3oool0A@3oool00940oooo00<0ool00?ooo`3oool0EP3oool00`000?l0
oooo0?ooo`0V0?ooo`03003o003oool0oooo02`0oooo00<0ool00?ooo`3o
ool0AP3oool00980oooo00<0ool00?ooo`3oool0E@3oool00`000?l0oooo
0?ooo`0W0?ooo`03003o003oool0oooo02/0oooo00<0ool00?ooo`3oool0
AP3oool009<0oooo00<0ool00?ooo`3oool0E03oool00`000?l0oooo0?oo
o`0X0?ooo`03003o003oool0oooo02T0oooo00<0ool00?ooo`3oool0A`3o
ool009<0oooo00<0ool00?ooo`3oool0E03oool00`000?l0oooo0?ooo`0X
0?ooo`03003o003oool0oooo02P0oooo00<0ool00?ooo`3oool0B03oool0
09@0oooo00<0ool00?ooo`3oool0D`3oool00`000?l0oooo0?ooo`0Y0?oo
o`03003o003oool0oooo02H0oooo00<0ool00?ooo`3oool0B@3oool009D0
oooo00<0ool00?ooo`3oool0DP3oool00`000?l0oooo0?ooo`0Y0?ooo`03
003o003oool0oooo02D0oooo00<0ool00?ooo`3oool0BP3oool009H0oooo
00<0ool00?ooo`3oool0D@3oool00`000?l0oooo0?ooo`0Z0?ooo`03003o
003oool0oooo02<0oooo00<0ool00?ooo`3oool0B`3oool009L0oooo00<0
ool00?ooo`3oool0D03oool00`000?l0oooo0?ooo`0Z0?ooo`03003o003o
ool0oooo0280oooo00<0ool00?ooo`3oool0C03oool009P0oooo00<0ool0
0?ooo`3oool0C`3oool00`000?l0oooo0?ooo`0[0?ooo`03003o003oool0
oooo0200oooo00<0ool00?ooo`3oool0C@3oool009T0oooo00<0ool00?oo
o`3oool0CP3oool00`000?l0oooo0?ooo`0/0?ooo`03003o003oool0oooo
01h0oooo00<0ool00?ooo`3oool0CP3oool009X0oooo00<0ool00?ooo`3o
ool0C@3oool00`000?l0oooo0?ooo`0/0?ooo`03003o003oool0oooo01d0
oooo00<0ool00?ooo`3oool0C`3oool009/0oooo00<0ool00?ooo`3oool0
C03oool00`000?l0oooo0?ooo`0]0?ooo`03003o003oool0oooo01/0oooo
00<0ool00?ooo`3oool0D03oool009`0oooo00<0ool00?ooo`3oool0B`3o
ool00`000?l0oooo0?ooo`0]0?ooo`03003o003oool0oooo01X0oooo00<0
ool00?ooo`3oool0D@3oool009d0oooo00<0ool00?ooo`3oool0BP3oool0
0`000?l0oooo0?ooo`0^0?ooo`03003o003oool0oooo01P0oooo00<0ool0
0?ooo`3oool0DP3oool009h0oooo00<0ool00?ooo`3oool0B@3oool00`00
0?l0oooo0?ooo`0_0?ooo`03003o003oool0oooo01H0oooo00<0ool00?oo
o`3oool0D`3oool009l0oooo00<0ool00?ooo`3oool0B03oool00`000?l0
oooo0?ooo`0_0?ooo`04003o003oool0oooo003o01@0oooo00<0ool00?oo
o`3oool0E03oool00:00oooo0P3oo`180?ooo`030000o`3oool0oooo0300
oooo0`00o`0C0?ooo`030?oo003oool0oooo05D0oooo002R0?ooo`80ool0
AP3oool00`000?l0oooo0?ooo`0^0?ooo`H00?l0403oool20?oo05P0oooo
002T0?ooo`030?oo003oool0oooo04<0oooo00<0003o0?ooo`3oool0;@3o
ool7003o00l0oooo00<0ool00?ooo`3oool0F03oool00:D0oooo00<0ool0
0?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0^0?ooo`H00?l03P3oool0
0`3oo`00oooo0?ooo`1I0?ooo`00YP3oool00`3oo`00oooo0?ooo`110?oo
o`030000o`3oool0oooo02l0oooo1P00o`0;0?ooo`80ool0G03oool00:L0
oooo00<0ool00?ooo`3oool0@03oool00`000?l0oooo0?ooo`0`0?ooo`D0
0?l02P3oool00`3oo`00oooo0?ooo`1L0?ooo`00Z03oool20?oo0400oooo
00<0003o0?ooo`3oool0<@3oool4003o00P0oooo0P3oo`1O0?ooo`00ZP3o
ool20?oo03h0oooo00<0003o0?ooo`3oool0<P3oool4003o00H0oooo00<0
ool00?ooo`3oool0G`3oool00:`0oooo00<0ool00?ooo`3oool0>`3oool0
0`000?l0oooo0?ooo`0c0?ooo`<00?l01@3oool00`3oo`00oooo0?ooo`1P
0?ooo`00[@3oool00`3oo`00oooo0?ooo`0j0?ooo`030000o`3oool0oooo
03@0oooo0`00o`020?ooo`80ool0H`3oool00:h0oooo0P3oo`0j0?ooo`03
0000o`3oool0oooo03@0oooo1000o`000`3oo`00oooo0?ooo`1S0?ooo`00
/03oool20?oo03P0oooo00<0003o0?ooo`3oool0<`3oool6003o06D0oooo
002b0?ooo`80ool0=P3oool00`000?l0oooo0?ooo`0c0?ooo`H00?l0I@3o
ool00;@0oooo0P3oo`0d0?ooo`030000o`3oool0oooo0380oooo00<0ool0
0?ooo`00o`000`00o`1V0?ooo`00]P3oool00`3oo`00oooo0?ooo`0]0?oo
o`P0003o;`3oool20?oo00<0oooo0P00o`1W0?ooo`00]`3oool30?oo02`0
oooo20000?l]0?ooo`80ool0KP3oool00;X0oooo0P3oo`0[0?ooo`H0003o
:`3oool30?oo0700oooo002l0?ooo`<0ool0:03oool60000obP0oooo0`3o
o`0J0?ooo`D000007@3oool500000380oooo002o0?ooo`<0ool09@3oool6
0000obH0oooo0P3oo`0M0?ooo`050000003oool0oooo0?ooo`0000007@3o
ool01@000000oooo0?ooo`3oool000000380oooo00320?ooo`80ool0903o
ool50000ob<0oooo0`3oo`0P0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0<`3oool00<@0oooo0`3oo`0Q0?ooo`@0003o8@3oool3
0?oo02@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0b
0?ooo`00a`3oool30?oo01h0oooo10000?lO0?ooo`80ool0:03oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo0340oooo003:0?ooo`80
ool07@3oool30000oa`0oooo0`3oo`0[0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0<03oool00<`0oooo1P3oo`0G0?ooo`<0003o
5P3oool60?oo02X0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`05
0000003oool0oooo0?ooo`000000<P3oool00=80oooo0`3oo`0D0?ooo`80
003o503oool30?oo0340oooo0`00000O0?ooo`<00000<`3oool00=D0oooo
203oo`0;0?ooo`@0003o2`3oool80?oo00`0oooo1@00000_0?ooo`030000
003oool0oooo04T0oooo003M0?ooo`X0ool01P000?l:0?oo01<0oooo00<0
00000?ooo`0000006P3oool5000001<0oooo00<000000?ooo`3oool0B@3o
ool00>L0oooo1P000?lM0?ooo`030000003oool0000002<0oooo2P000003
0?ooo`D00000103ooolQ000002@0oooo003X0?ooo`@0003o7P3oool00`00
0000oooo00000003000000d0oooo00<000000?ooo`3oool01`3oool50000
01<0oooo00<000000?ooo`3oool0B@3oool00>T0oooo0P000?lO0?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool0100000040?ooo`04
0000003oool0oooo000000@0oooo0P00000K0?ooo`030000003oool0oooo
04T0oooo003Z0?ooo`030000003oool0oooo01h0oooo100000040?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0<@3oool00>X0oooo00<000000?ooo`3oool09P3oool01`000000
oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0<@3oool0
0>X0oooo00<000000?ooo`3oool09P3oool01`000000oooo0?ooo`3oool0
00000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00/0oooo1@00000A0?ooo`L000001`3oool2000000H0oooo0`00
000Z0?ooo`00_03oool5000001l0oooo1`0000030?ooo`030000003oool0
oooo02D0oooo0P0000020?ooo`D00000103oool01P000000oooo0?ooo`00
0000oooo000000l0oooo00<000000?ooo`3oool04`3oool00`000000oooo
000000090?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0
oooo0000000Y0?ooo`00^`3oool00`000000oooo0000000J0?ooo`D00000
1@3oool00`000000oooo000000050?ooo`030000003oool0oooo0380oooo
00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`000000203oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo02L0oooo002k0?ooo`030000003oool0000002@0
oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool04`3oool00`000000
oooo000000060?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0W0?ooo`00^`3oool00`000000oooo
00000003000000d0oooo00<000000?ooo`3oool01`3oool5000000D0oooo
00<000000?ooo`0000001@3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`0000001`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo0P00000Z0?ooo`00^`3o
ool00`000000oooo000000020?ooo`030000003oool0oooo00@00000103o
ool010000000oooo0?ooo`0000040?ooo`<00000303oool00`000000oooo
000000050?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
4@3oool5000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0W0?ooo`00_03oool4000000@0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000303oool5000000D0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`0R0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0W0?ooo`00a03oool01`000000oooo0?ooo`3oool00000
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo05`0oooo0P00000F0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool00P3oool3000002X0oooo00340?ooo`070000003oool0oooo
0?ooo`000000oooo000000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo02h0oooo00330?ooo`8000000P3oool5000000@0oooo00H00000
0?ooo`3oool000000?ooo`0000240?ooo`030000003oool0oooo02h0oooo
003@0?ooo`050000003oool0oooo0?ooo`000000Q@3oool;000002H0oooo
00340?ooo`030000003oool0oooo0<@0oooo003o0?oooh`0oooo003o0?oo
oh`0oooo003o0?oooh`0oooo003X0?ooo`800000X@3oool00>T0oooo00<0
00000?ooo`3oool0W`3oool00>X0oooo00<000000?ooo`3oool0WP3oool0
0>T0oooo00<000000?ooo`000000W`3oool00>P0oooo00@000000?ooo`3o
ool00000W`3oool00>L0oooo0`0000000`3oool000000000002N0?ooo`00
o`3ooon<0?ooo`00o`3ooon<0?ooo`00o`3ooon<0?ooo`00o`3ooon<0?oo
o`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{395, 312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\tNotice that, when ",
  Cell[BoxData[
      \(\[Theta] = \[Pi]\)]],
  ", we get  ",
  Cell[BoxData[
      \(e\^\[ImaginaryI]\[Pi] = \(\((cos\ \[Pi]\ , 
            sin\ \[Pi])\) = \(\((\(-1\)\ , 0)\) = \(-1\)\)\)\)]],
  ",  so\n\n\t\t\t",
  Cell[BoxData[
      \(e\^\[ImaginaryI]\[Pi] + 1 = 0\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox[ButtonBox["Euler",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Euler.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " was the first to discover this relationship;  it is referred to as \
Euler's identity.  It has been labeled by many mathematicians as the most \
amazing relation in analysis---and with good reason.  Symbols with a rich \
history are miraculously woven together---the constant  used by Hippocrates \
as early as ",
  StyleBox[ButtonBox["Hippocrates",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Hippocrates.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " as early as 400 B.C.;  ",
  Cell[BoxData[
      \(e\)]],
  " the base of the natural logarithms;  the basic concepts of addition (+) \
and equality (=);  the foundational whole numbers 0 and 1;  and ",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  ", the number that is the central focus of this book."
}], "Text"],

Cell[TextData[{
  "\tEuler's formula is of tremendous use in establishing important algebraic \
and geometric properties of complex numbers.  You will see shortly that it \
enables you to multiply complex numbers with great ease. It also allows you \
to express a polar form of the complex number z in a more compact way.  \
Recall that if  ",
  Cell[BoxData[
      \(r\  = \(\(|\)\(z\)\(|\)\)\)]],
  " and  ",
  Cell[BoxData[
      \(\[Theta]\  \[Element] arg\ z\)]],
  ",  then  ",
  Cell[BoxData[
      \(z\  = r \((cos\ \[Theta]\  + \ i\ sin\ \[Theta])\)\)]],
  ".  Using Euler's formula we can now write ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " in its",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["exponential form",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Phasor.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ":  \n\t\n\t\t\t",
  Cell[BoxData[
      \(z = r\ e\^\[ImaginaryI]\[Theta]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  In example 1.10 we investigated the polar form of  ",
  Cell[BoxData[
      \(z = \(-\ \@3\) - \[ImaginaryI]\)],
    AspectRatioFixed->True],
  ",  and saw that ",
  Cell[BoxData[
      \(r = 2\)]],
  "   and  ",
  Cell[BoxData[
      \(\[Theta] = \(-\(\(5  \[Pi]\)\/6\)\)\)]],
  ".  Now we have \n\n\t\t\t",
  Cell[BoxData[
      \(z\  = \ \(\(-\ \@3\) - \[ImaginaryI]\  = \ \(2\ e\^\(\[ImaginaryI] \
\((\(-5\) \[Pi]/6)\)\)\  = \ 
            2\ e\^\(\(-\[ImaginaryI]\) \(5\ \ \[Pi]\)\/6\)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[e, \[Theta], r, z];\)\ \), "\n", 
    \(\(z\  = \ \(-\ \@3\)\  - \ \[ImaginaryI];\)\ \), "\n", 
    \(\(r\  = \ Abs[z];\)\ \), "\n", 
    \(\(\[Theta] = Arg[z];\)\ \), "\n", 
    \(\(Z = 
        r \((Cos[\[Theta]]\  + \ \[ImaginaryI]\ Sin[\[Theta]])\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\  = \ 
        Graphics[{Purple, Arrow[{0, \ 0}, {Re[z], Im[z]}]}];\)\ \), "\n", 
    \(\(Show[V, 
        PlotRange \[Rule] {{\(-2\), 0}, {\(-1\), 
              0}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-2\), 0, 1\/2], 
            Range[\(-1\), 0, 1\/2]}, \[IndentingNewLine]AspectRatio \[Rule] 
          1\/2, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<z = \>", z];\)\ \), "\n", 
    \(\(Print["\<r = |z| = \>", r];\)\ \), "\n", 
    \(\(Print["\<\[Theta] = Arg[z] = \>", \[Theta]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<z = r \!\(e\^\"\<i\[Theta]\>\"\)\>\""\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<z = \>", r, "\< \>", 
        e\^\(i\ \[Theta]\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<z = \>", Z\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<z = \>", ComplexExpand[Z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tTogether with the rules for exponentiation that we will verify in \
Chapter 5, the exponential form has interesting applications.  If ",
  Cell[BoxData[
      \(z\_1 = \(r\_1\) \[ExponentialE]\^\[ImaginaryI]\[Theta]\_1\)]],
  " and ",
  Cell[BoxData[
      \(z\_2 = \(r\_2\) \[ExponentialE]\^\[ImaginaryI]\[Theta]\_2\)]],
  ", then  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\(z\_1\) 
          z\_2\  = \ \(\(r\_1\) \(\[ExponentialE]\^\[ImaginaryI]\[Theta]\_1\) \
\(r\_2\) \[ExponentialE]\^\[ImaginaryI]\[Theta]\_2\  = \ \ \(r\_1\) \(r\_2\) \
\[ExponentialE]\^\(\[ImaginaryI] \((\[Theta]\_1 + \[Theta]\_2)\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(=\)\(\(r\_1\) \(r\_2\) \((cos \((\[Theta]\_1 \
+ \[Theta]\_2)\) + \[ImaginaryI]\ sin \((\[Theta]\_1 + \
\[Theta]\_2)\))\)\)\)\)}]],
  "  \n\n Figure 1.13 illustrates the geometric significance of this \
equation."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006Z0000gB000`400?l0
0000o`00003oo`3ooon[0?ooo`00o`3ooon[0?ooo`00Q03oool40000odL0
oooo0`00001M0?ooo`<00000N03oool008<0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo05d0oooo
00<000000?ooo`3oool0A`3oool2000001L0oooo1@00000<0?ooo`<00000
0`3oool008<0oooo1P000?m70?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00`3oool007P0oooo10000?l3
0?ooo`T0003o0`3oool90000o`80oooo0`000?l60?ooo`@0003o00<0oooo
0000o`000?l00P3oool40000o`80oooo0`000?l:0?ooo`<000000`3oool3
000000040?ooo`00000000000?ooo`8000001P3oool010000000oooo0000
000000020?ooo`<000000P3oool3000000<0oooo1@0000020?ooo`@00000
00<0oooo0000000000000`3oool2000000D0oooo0`0000020?ooo`<00000
1@3oool2000000<0oooo00@000000?ooo`3oool00000103oool3000000H0
oooo0P0000030?ooo`<000000P3oool3000000040?ooo`00000000000?oo
o`80000000<0oooo0000003oool00P0000020?ooo`<0000000<0oooo0000
000000000P3oool2000000030?ooo`000000000000<0oooo0`0000000`3o
ool00000000000020?ooo`L0000000@0oooo000000000000oooo0P000000
103oool000000000000000030?ooo`8000000P3oool3000000040?ooo`00
00000000000000H0oooo1@0000030?ooo`030000003oool0oooo00l0oooo
1@0000030?ooo`030000003oool0oooo00D0oooo1@0000030?ooo`030000
003oool0oooo0080oooo001i0?ooo`80003o1@3oool20000o`030?ooo`00
0?l0oooo00D0oooo0P000?l00`3oool0003o0000o`020?ooo`80003o0P3o
ool20000o`80oooo00<0003o0?ooo`3oool0103oool20000o`80oooo0P00
0?l30?ooo`80003o0P3oool010000?l0oooo0?ooo`000?l;0?ooo`030000
003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000020?oo
o`030000003oool0oooo00<0oooo0P0000020?ooo`040000003oool0oooo
00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo000000020?ooo`04
0000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000
103oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`8000000P3o
ool01P000000oooo0?ooo`000000oooo00000080oooo00H000000?ooo`3o
ool000000?ooo`0000050?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo1@00
00050?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`00N@3oool20000o`D0oooo0P000?l20?ooo`<0003o
0`3oool20000o`030?ooo`000?l0003o0080oooo0P000?l20?ooo`80003o
2@3oool20000o`L0oooo0P000?l50?ooo`80003o2P3oool00`000000oooo
0?ooo`030?ooo`060000003oool0oooo0000003oool00000203oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo000000030?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`06
0000003oool0oooo0?ooo`000000oooo0P0000001@3oool000000?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00H000000?oo
o`3oool000000?ooo`0000060?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000050?ooo`030000003oool0oooo0080oooo0P0000060?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000004@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000030?ooo`00N@3oool20000o`03
0?ooo`000?l0oooo0080oooo0P000?l0103oool0003o0000o`3oool20000
o`80oooo0P000?l00`3oool0003o0000o`020?ooo`80003o0P3oool50000
o`H0oooo0P000?l70?ooo`80003o1@3oool20000o`X0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`000000oooo00@000001@3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo000000030?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00D000000?oo
o`3oool000000?ooo`04000000<0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo000000030?ooo`03
0000003oool0000000<000000P3oool00`000000oooo0?ooo`02000000T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`D0
00001`3oool00`000000oooo0?ooo`020?ooo`8000002@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo001i0?ooo`@0003o
0`3oool20000o`040?ooo`000?l0003o0?ooo`80003o0P3oool20000o`03
0?ooo`000?l0003o0080oooo0P000?l01@3oool0003o0000o`000?l0oooo
0080003o1P3oool20000o`L0oooo0P000?l40?ooo`<0003o2P3oool00`00
0000oooo0?ooo`030?ooo`80000000@0oooo0000003oool000000P3oool0
0`000000oooo0?ooo`030?ooo`8000000P3oool00`000000oooo0?ooo`02
000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000P3oool2
00000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`040000
003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo
0?ooo`020?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo0?ooo`02000000050?ooo`00000000000?ooo`0000000P3oool2
00000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`060000
003oool0oooo0000003oool000001@3oool2000000050?ooo`000000oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`02000000060?ooo`000000
00000?ooo`000000oooo0P0000020?ooo`030000003oool000000080oooo
00<000000?ooo`3oool00P0000001@3oool000000?ooo`3oool0000000D0
oooo00@000000?ooo`3oool000005P3oool010000000oooo0?ooo`00000<
0?ooo`040000003oool0oooo000000T0oooo001i0?ooo`80003o00@0oooo
0000o`3oool0oooo0`000?l20?ooo`P0003o00@0oooo0000o`000?l0oooo
1@000?l0103oool0003o0000o`000?l70?ooo`80003o1`3oool20000o`@0
oooo0P000?l;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00000`3oool2000000D0oooo0P0000000`3oool00000000000020?ooo`80
000000<0oooo0000003oool00`0000030?ooo`80000000<0oooo0000003o
ool00P0000000`3oool00000000000020?ooo`<0000000@0oooo00000000
000000001@3oool300000080oooo0`0000040?ooo`<0000000@0oooo0000
00000000oooo0`000000103oool000000000003oool3000000H0oooo0`00
00020?ooo`<000000P3oool2000000050?ooo`000000oooo0?ooo`000000
0P3oool2000000030?ooo`000000000000<0oooo00<000000?ooo`3oool0
0P0000020?ooo`80000000<0oooo0000000000000`3oool2000000040?oo
o`000000oooo0?ooo`80000000@0oooo000000000000oooo0P0000001@3o
ool000000?ooo`3oool000000080oooo00@000000?ooo`00000000000`3o
ool200000080oooo0P0000000`3oool000000?ooo`03000000D0oooo1@00
000E0?ooo`D000002`3oool5000000P0oooo001i0?ooo`80003o9@3oool2
0000o`L0oooo0P000?l50?ooo`80003o2P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo04`0oooo001i0?ooo`80003o0`3oool010000?l0oooo0000o`000?lN
0?ooo`80003o1`3oool20000o`80oooo00<0003o0?ooo`3oool00P000?l7
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
8@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0C03oool007P0oooo
1`000?l00`3oool0003o0000o`0M0?ooo`<0003o1P3oool30000o`<0oooo
0`000?l80?ooo`L0000000<0oooo000000000000803oool2000001/0oooo
0`00000c0?ooo`8000008P3oool2000004h0oooo003o0?oooj/0oooo003o
0?oooj/0oooo003o0?oooj/0oooo003o0?oooj/0oooo003o0?oooj/0oooo
003o0?oooj/0oooo003o0?oooj/0oooo003o0?oooj/0oooo003o0?oooj/0
oooo003o0?oooj/0oooo003o0?oooj/0oooo002K0?ooo`D00000M`3oool5
000003/0oooo1000001?0?ooo`00W@3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0D03oool009d0
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo04l0oooo002E0?ooo`@00000103oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
CP3oool009d0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`0k0?ooo`040000003oool0oooo000004l0oooo002L0?ooo`800000NP3o
ool2000003h0oooo0P00001@0?ooo`00o`3ooon[0?ooo`00o`3ooon[0?oo
o`00o`3ooon[0?ooo`00o`3ooon[0?ooo`00o`3ooome0?ooo`80000000<0
oooo000000000000<@3oool00?l0ooooMP3oool00`000000oooo0000000b
0?ooo`00NP3ooomP000000030000o`000000000003`0000000<0o`000000
000000008`0000000`00o`0000000000000W000000040000o`0000000000
000000T0oooo00<000000?ooo`3oool0<@3oool009X0oooo00<000000?oo
o`3oool0?03oool00`000?l00?l00?l0000m0?ooo`030?l0003oool0oooo
02<0oooo00<00?l00?ooo`3oool05`3oool00`000000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00P0oooo0P0000000`3oool000000000000a0?oo
o`00f@3oool010000?l00?l00?ooo`3o000l0?ooo`030?l0003oool0oooo
02<0oooo00<00?l00?ooo`3oool09`3oool00`000?l0oooo0?ooo`0n0?oo
o`00f03oool01P000?l0oooo00000000o`00oooo0?l003/0oooo00<0o`00
0?ooo`3oool08`3oool00`00o`00oooo0?ooo`0W0?ooo`030000o`3oool0
oooo03h0oooo003H0?ooo`040000o`3oool00000003o0080oooo00<0o`00
0?ooo`3oool0>03oool00`3o0000oooo0?ooo`0S0?ooo`03003o003oool0
oooo02L0oooo00<0003o0?ooo`3oool0?P3oool00=L0oooo00D0003o0?oo
o`3oool00000003o00030?ooo`030?l0003oool0oooo03L0oooo00<0o`00
0?ooo`3oool08`3oool00`00o`00oooo0?ooo`0W0?ooo`030000o`3oool0
oooo03h0oooo003F0?ooo`060000o`3oool0oooo0?ooo`0000000?l0103o
ool00`3o0000oooo0?ooo`0f0?ooo`030?l0003oool0oooo02<0oooo00<0
0?l00?ooo`3oool09P3oool00`000?l0oooo0?ooo`0o0?ooo`00eP3oool0
1`000?l0oooo0?ooo`3oool000000?ooo`00o`00103oool00`3o0000oooo
0?ooo`0e0?ooo`030?l0003oool0oooo02<0oooo00<00?l00?ooo`3oool0
9P3oool00`000?l0oooo0?ooo`0o0?ooo`00e@3oool00`000?l0oooo0?oo
o`020?ooo`030000003oool00?l000D0oooo00<0o`000?ooo`3oool0<`3o
ool00`3o0000oooo0?ooo`0T0?ooo`03003o003oool0oooo02H0oooo00<0
003o0?ooo`3oool0?`3oool00=D0oooo00<0003o0?ooo`3oool00P3oool0
0`000000oooo003o00060?ooo`030?l0003oool0oooo0380oooo00<0o`00
0?ooo`3oool0903oool00`00o`00oooo0?ooo`0V0?ooo`030000o`3oool0
oooo03l0oooo003D0?ooo`030000o`3oool0oooo00<0oooo00<000000?oo
o`00o`001`3oool00`3o0000oooo0?ooo`0a0?ooo`030?l0003oool0oooo
02@0oooo00<00?l00?ooo`3oool09P3oool00`000?l0oooo0?ooo`0o0?oo
o`00d`3oool00`000?l0oooo0?ooo`040?ooo`040000003oool0oooo003o
00L0oooo00<0o`000?ooo`3oool0<03oool00`3o0000oooo0?ooo`0T0?oo
o`03003o003oool0oooo02H0oooo00<0003o0?ooo`3oool0?`3oool00=<0
oooo00<0003o0?ooo`3oool0103oool010000000oooo0?ooo`00o`080?oo
o`030?l0003oool0oooo02l0oooo00<0o`000?ooo`3oool0903oool00`00
o`00oooo0?ooo`0V0?ooo`030000o`3oool0oooo03l0oooo003B0?ooo`03
0000o`3oool0oooo00D0oooo00@000000?ooo`3oool00?l02@3oool00`3o
0000oooo0?ooo`0^0?ooo`030?l0003oool0oooo02<0oooo00<00?l00?oo
o`3oool09`3oool00`000?l0oooo0?ooo`0o0?ooo`00dP3oool00`000?l0
oooo0?ooo`050?ooo`040000003oool0oooo003o00X0oooo00<0o`000?oo
o`3oool0;03oool00`3o0000oooo0?ooo`0T0?ooo`03003o003oool0oooo
02L0oooo00<0003o0?ooo`3oool0?`3oool00=40oooo00<0003o0?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool00?l000X0oooo00<0o`000?oo
o`3oool0:`3oool00`3o0000oooo0?ooo`0T0?ooo`03003o003oool0oooo
02L0oooo00<0003o0?ooo`3oool0?`3oool00=00oooo00<0003o0?ooo`3o
ool01`3oool01@000000oooo0?ooo`3oool00?l000/0oooo00<0o`000?oo
o`3oool0:P3oool00`3o0000oooo0?ooo`0T0?ooo`03003o003oool0oooo
02L0oooo00<0003o0?ooo`3oool0?`3oool00=00oooo00<0003o0?ooo`3o
ool01`3oool01@000000oooo0?ooo`3oool00?l000`0oooo00<0o`000?oo
o`3oool0:03oool00`3o0000oooo0?ooo`0U0?ooo`03003o003oool0oooo
02H0oooo00<0003o0?ooo`3oool0@03oool00<l0oooo00<0003o0?ooo`3o
ool0203oool01@000000oooo0?ooo`3oool00?l000d0oooo00<0o`000?oo
o`3oool09`3oool00`3o0000oooo0?ooo`0U0?ooo`03003o003oool0oooo
02H0oooo00<0003o0?ooo`3oool0@03oool00<l0oooo00<0003o0?ooo`3o
ool0203oool00`000000oooo0?ooo`020?ooo`03003o003oool0oooo00/0
oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0T0?ooo`03
003o003oool0oooo02L0oooo00<0003o0?ooo`3oool0@03oool00<h0oooo
00<0003o0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`03003o
003oool0oooo00`0oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo
0?ooo`0U0?ooo`03003o003oool0oooo02L0oooo00<0003o0?ooo`3oool0
@03oool00<d0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`03003o003oool0oooo00d0oooo00<0o`000?ooo`3oool08`3o
ool00`3o0000oooo0?ooo`0U0?ooo`03003o003oool0oooo02L0oooo00<0
003o0?ooo`3oool0@03oool00<d0oooo00<0003o0?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`03003o003oool0oooo00h0oooo00<0o`00
0?ooo`3oool08P3oool00`3o0000oooo0?ooo`0U0?ooo`03003o003oool0
oooo02L0oooo00<0003o0?ooo`3oool0@03oool00<`0oooo00<0003o0?oo
o`3oool02`3oool00`000000oooo0?ooo`030?ooo`03003o003oool0oooo
00h0oooo00<0o`000?ooo`3oool0803oool00`3o0000oooo0?ooo`0V0?oo
o`03003o003oool0oooo02L0oooo00<0003o0?ooo`3oool0@03oool00<`0
oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`03
003o003oool0oooo00l0oooo00<0o`000?ooo`3oool07`3oool00`3o0000
oooo0?ooo`0U0?ooo`03003o003oool0oooo02L0oooo00<0003o0?ooo`3o
ool0@@3oool00</0oooo00<0003o0?ooo`3oool0303oool00`000000oooo
0?ooo`030?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool0
7P3oool00`3o0000oooo0?ooo`0U0?ooo`03003o003oool0oooo02L0oooo
00<0003o0?ooo`3oool0@@3oool00<X0oooo00<0003o0?ooo`3oool03@3o
ool00`000000oooo0?ooo`030?ooo`03003o003oool0oooo0140oooo00<0
o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`0V0?ooo`03003o003o
ool0oooo02L0oooo00<0003o0?ooo`3oool0@@3oool00<X0oooo00<0003o
0?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`03003o003oool0
oooo0140oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0V
0?ooo`03003o003oool0oooo02L0oooo00<0003o0?ooo`3oool0@@3oool0
0<T0oooo00<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`040?oo
o`03003o003oool0oooo0180oooo00<0o`000?ooo`3oool06P3oool00`3o
0000oooo0?ooo`070?ooo`D000006@3oool00`00o`00oooo0?ooo`0X0?oo
o`030000o`3oool0oooo0440oooo00380?ooo`030000o`3oool0oooo00l0
oooo00<000000?ooo`3oool0103oool00`00o`00oooo0?ooo`0C0?ooo`03
0?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool02P3oool00`000000
oooo0?ooo`0I0?ooo`03003o003oool0oooo02L0oooo00<0003o0?ooo`3o
ool0@P3oool00<P0oooo00<0003o0?ooo`3oool03`3oool00`000000oooo
0?ooo`040?ooo`03003o003oool0oooo01@0oooo00<0o`000?ooo`3oool0
5`3oool00`3o0000oooo0?ooo`020?ooo`@00000103oool00`000000oooo
0?ooo`0H0?ooo`03003o003oool0oooo02P0oooo00<0003o0?ooo`3oool0
@P3oool00<L0oooo00<0003o0?ooo`3oool0403oool00`000000oooo0?oo
o`050?ooo`03003o003oool0oooo01@0oooo00<0o`000?ooo`3oool05@3o
ool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo0000000J0?ooo`03003o003oool0oooo02P0oooo
00<0003o0?ooo`3oool0@P3oool00<L0oooo00<0003o0?ooo`3oool0403o
ool00`000000oooo0?ooo`050?ooo`03003o003oool0oooo01D0oooo00<0
o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo0000000J0?ooo`03003o
003oool0oooo02P0oooo00<0003o0?ooo`3oool0@P3oool00<H0oooo00<0
003o0?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`03003o003o
ool0oooo01H0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`0000000000
6P3oool00`00o`00oooo0?ooo`0X0?ooo`030000o`3oool0oooo0480oooo
00350?ooo`030000o`3oool0oooo0180oooo00<000000?ooo`3oool01@3o
ool00`00o`00oooo0?ooo`0G0?ooo`030?l0003oool0oooo0100oooo00<0
o`000?ooo`3oool0103oool7000001`0oooo00<00?l00?ooo`3oool0:03o
ool00`000?l0oooo0?ooo`130?ooo`00a@3oool00`000?l0oooo0?ooo`0B
0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool05`3oool0
0`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`03003o003oool0
oooo02P0oooo00<0003o0?ooo`3oool0@`3oool00<@0oooo00<0003o0?oo
o`3oool04`3oool00`000000oooo0?ooo`060?ooo`03003o003oool0oooo
01P0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`070?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`00
o`00oooo0?ooo`0Y0?ooo`030000o`3oool0oooo04<0oooo00340?ooo`03
0000o`3oool0oooo01<0oooo00<000000?ooo`3oool01P3oool00`00o`00
oooo0?ooo`0I0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3o
ool0203oool4000001`0oooo00<00?l00?ooo`3oool0:@3oool00`000?l0
oooo0?ooo`130?ooo`00``3oool00`000?l0oooo0?ooo`0D0?ooo`030000
003oool0oooo00H0oooo00<00?l00?ooo`3oool06P3oool00`3o0000oooo
0?ooo`090?ooo`030?l0003oool0oooo02T0oooo00<00?l00?ooo`3oool0
:03oool00`000?l0oooo0?ooo`140?ooo`00`P3oool00`000?l0oooo0?oo
o`0E0?ooo`030000003oool0oooo00L0oooo00<00?l00?ooo`3oool06P3o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo02T0oooo00<0
0?l00?ooo`3oool0:03oool00`000?l0oooo0?ooo`140?ooo`00`P3oool0
0`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo00<00?l0
0?ooo`3oool06`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
oooo02T0oooo00<00?l00?ooo`3oool0:03oool00`000?l0oooo0?ooo`15
0?ooo`00`@3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo
00L0oooo00<00?l00?ooo`3oool0703oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo02T0oooo00<00?l00?ooo`3oool0:@3oool00`00
0?l0oooo0?ooo`150?ooo`00`@3oool00`000?l0oooo0?ooo`0F0?ooo`03
0000003oool0oooo00L0oooo00<00?l00?ooo`3oool07@3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo02X0oooo00<00?l00?ooo`3o
ool0:@3oool00`000?l0oooo0?ooo`150?ooo`00`03oool00`000?l0oooo
0?ooo`0G0?ooo`030000003oool0oooo00L0oooo00<00?l00?ooo`3oool0
7P3oool0103o0000oooo0?ooo`3o000/0?ooo`03003o003oool0oooo02X0
oooo00<0003o0?ooo`3oool0A@3oool00;l0oooo00<0003o0?ooo`3oool0
603oool00`000000oooo0?ooo`080?ooo`03003o003oool0oooo01h0oooo
0P3o000]0?ooo`03003o003oool0oooo02X0oooo00<0003o0?ooo`3oool0
A@3oool00;l0oooo00<0003o0?ooo`3oool0603oool00`000000oooo0?oo
o`080?ooo`03003o003oool0oooo01l0oooo00<0o`000?ooo`3oool0:P3o
ool00`00o`00oooo0?ooo`0Z0?ooo`030000o`3oool0oooo04H0oooo002n
0?ooo`030000o`3oool0oooo01T0oooo00<000000?ooo`3oool0203oool0
0`00o`00oooo0?ooo`0I0?ooo`D000000P3oool00`3o0000oooo0?ooo`0Y
0?ooo`03003o003oool0oooo02X0oooo00<0003o0?ooo`3oool0AP3oool0
0;h0oooo00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`080?oo
o`03003o003oool0oooo01/0oooo00<000000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0W0?ooo`03003o003oool0oooo02X0oooo00<0003o0?oo
o`3oool0A`3oool00;d0oooo00<0003o0?ooo`3oool06P3oool00`000000
oooo0?ooo`090?ooo`03003o003oool0oooo0140oooo1@0000040?ooo`03
0000003oool0oooo00@0oooo00<0o`000?ooo`3oool09P3oool00`00o`00
oooo0?ooo`0Z0?ooo`030000o`3oool0oooo04L0oooo002l0?ooo`030000
o`3oool0oooo01/0oooo00<000000?ooo`3oool02@3oool00`00o`00oooo
0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`0T0?ooo`03003o003oool0oooo02X0oooo
00<0003o0?ooo`3oool0B03oool00;`0oooo00<0003o0?ooo`3oool06`3o
ool00`000000oooo0?ooo`090?ooo`03003o003oool0oooo01<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool07P3oool00`00o`00oooo0?oo
o`0Z0?ooo`030000o`3oool0oooo04P0oooo002k0?ooo`030000o`3oool0
oooo01`0oooo00<000000?ooo`3oool02@3oool00`00o`00oooo0?ooo`0D
0?ooo`030000003oool0oooo0080oooo0P0000090?ooo`030?l0003oool0
oooo00<0o`007P3oool00`00o`00oooo0?ooo`0[0?ooo`030000o`3oool0
oooo04P0oooo002k0?ooo`030000o`3oool0oooo01`0oooo00<000000?oo
o`3oool02P3oool00`00o`00oooo0?ooo`0C0?ooo`80000000<0oooo0000
003oool0303oool50?l001h0oooo00<00?l00?ooo`3oool0:P3oool00`00
0?l0oooo0?ooo`190?ooo`00^P3oool00`000?l0oooo0?ooo`0M0?ooo`03
0000003oool0oooo00X0oooo00<00?l00?ooo`3oool04P3oool200000003
0?ooo`000000000000d0oooo1P3o000L0?ooo`03003o003oool0oooo02/0
oooo00<0003o0?ooo`3oool0B@3oool00;T0oooo00<0003o0?ooo`3oool0
7P3oool00`000000oooo0?ooo`0:0?ooo`03003o003oool0oooo02<0oooo
1`3o000L0?ooo`03003o003oool0oooo02/0oooo00<0003o0?ooo`3oool0
B@3oool00;T0oooo00<0003o0?ooo`3oool07P3oool00`000000oooo0?oo
o`0:0?ooo`03003o003oool0oooo0280oooo2@3o000J0?ooo`03003o003o
ool0oooo02`0oooo00<0003o0?ooo`3oool0B@3oool00;P0oooo00<0003o
0?ooo`3oool07`3oool00`000000oooo0?ooo`0;0?ooo`03003o003oool0
oooo0280oooo2@3o000H0?ooo`03003o003oool0oooo02`0oooo00<0003o
0?ooo`3oool0BP3oool00;P0oooo00<0003o0?ooo`3oool07`3oool00`00
0000oooo0?ooo`0;0?ooo`03003o003oool0oooo02@0oooo1`3o000G0?oo
o`03003o003oool0oooo02d0oooo00<0003o0?ooo`3oool0BP3oool00;L0
oooo00<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`03
003o003oool0oooo02H0oooo1P3o000E0?ooo`03003o003oool0oooo02d0
oooo00<0003o0?ooo`3oool0B`3oool00;H0oooo00<0003o0?ooo`3oool0
8@3oool00`000000oooo0?ooo`0;0?ooo`03003o003oool0oooo02L0oooo
1P3o000D0?ooo`03003o003oool0oooo02d0oooo00<0003o0?ooo`3oool0
B`3oool00;H0oooo00<0003o0?ooo`3oool08@3oool00`000000oooo0?oo
o`0<0?ooo`03003o003oool0oooo02P0oooo103o000C0?ooo`03003o003o
ool0oooo02d0oooo00<0003o0?ooo`3oool0C03oool00;D0oooo00<0003o
0?ooo`3oool06P3oool5000000<0oooo00<000000?ooo`3oool0303oool0
0`00o`00oooo0?ooo`0Y0?ooo`@0o`004@3oool00`00o`00oooo0?ooo`0^
0?ooo`030000o`3oool0oooo04`0oooo002e0?ooo`030000o`3oool0oooo
01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?oo
o`03003o003oool0oooo02/0oooo0P3o000A0?ooo`03003o003oool0oooo
02d0oooo00<0003o0?ooo`3oool0C@3oool00;@0oooo00<0003o0?ooo`3o
ool07@3oool00`000000oooo0?ooo`030?ooo`8000003@3oool00`00o`00
oooo0?ooo`0R0?ooo`D000001P3oool00`3o0000oooo0?ooo`0=0?ooo`03
003o003oool0oooo02h0oooo00<0003o0?ooo`3oool0C@3oool00;<0oooo
00<0003o0?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00d0oooo00<00?l00?ooo`3oool08`3oool00`000000oooo
0?ooo`0E0?ooo`03003o003oool0oooo02h0oooo00<0003o0?ooo`3oool0
CP3oool00;<0oooo00<0003o0?ooo`3oool07P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00d0oooo00<00?l00?ooo`3oool06`3o
ool5000000<0oooo00<000000?ooo`3oool0503oool00`00o`00oooo0?oo
o`0_0?ooo`030000o`3oool0oooo04h0oooo002b0?ooo`030000o`3oool0
oooo01h0oooo0P0000050?ooo`030000003oool0oooo00d0oooo00<00?l0
0?ooo`3oool0703oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo01<0oooo00<00?l00?ooo`3oool0;`3oool00`000?l0oooo0?oo
o`1?0?ooo`00/P3oool00`000?l0oooo0?ooo`0U0?ooo`030000003oool0
oooo00d0oooo00<00?l00?ooo`3oool07@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01<0oooo00<00?l00?ooo`3oool0;P3oool0
0`000?l0oooo0?ooo`1@0?ooo`00/@3oool00`000?l0oooo0?ooo`0V0?oo
o`030000003oool0oooo00h0oooo00<00?l00?ooo`3oool07@3oool01000
0000oooo0?ooo`3oool2000001@0oooo00<00?l00?ooo`3oool0;`3oool0
0`000?l0oooo0?ooo`1@0?ooo`00/03oool00`000?l0oooo0?ooo`0W0?oo
o`030000003oool0oooo00h0oooo00<00?l00?ooo`3oool06`3oool01000
0000oooo0?ooo`00000G0?ooo`03003o003oool0oooo02l0oooo00<0003o
0?ooo`3oool0D@3oool00;00oooo00<0003o0?ooo`3oool09`3oool00`00
0000oooo0?ooo`0>0?ooo`03003o003oool0oooo01/0oooo1@00000E0?oo
o`03003o003oool0oooo0300oooo00<0003o0?ooo`3oool0D@3oool00:l0
oooo00<0003o0?ooo`3oool0:03oool00`000000oooo0?ooo`0>0?ooo`03
003o003oool0oooo03@0oooo00<00?l00?ooo`3oool0<03oool00`000?l0
oooo0?ooo`1B0?ooo`00[`3oool00`000?l0oooo0?ooo`0X0?ooo`030000
003oool0oooo00l0oooo00<00?l00?ooo`3oool0<P3oool00`00o`00oooo
0?ooo`0a0?ooo`030000o`3oool0oooo0580oooo002^0?ooo`030000o`3o
ool0oooo02T0oooo00<000000?ooo`3oool03`3oool00`00o`00oooo0?oo
o`0a0?ooo`03003o003oool0oooo0340oooo00<0003o0?ooo`3oool0D`3o
ool00:d0oooo00<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0?
0?ooo`03003o003oool0oooo0300oooo00<00?l00?ooo`3oool0<P3oool0
0`000?l0oooo0?ooo`1C0?ooo`00[@3oool00`000?l0oooo0?ooo`0Z0?oo
o`030000003oool0oooo00l0oooo00<00?l00?ooo`3oool0;`3oool00`00
o`00oooo0?ooo`0b0?ooo`030000o`3oool0oooo05@0oooo002/0?ooo`03
0000o`3oool0oooo02/0oooo00<000000?ooo`3oool0403oool00`00o`00
oooo0?ooo`0]0?ooo`03003o003oool0oooo03<0oooo00<0003o0?ooo`3o
ool0E03oool00:`0oooo00<0003o0?ooo`3oool0:`3oool00`000000oooo
0?ooo`0@0?ooo`03003o003oool0oooo02/0oooo0P00o`0e0?ooo`030000
o`3oool0oooo05D0oooo002[0?ooo`030000o`3oool0oooo02`0oooo00<0
00000?ooo`3oool0403oool00`00o`00oooo0?ooo`0Z0?ooo`03003o003o
ool0oooo03@0oooo00<0003o0?ooo`3oool0EP3oool00:X0oooo00<0003o
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0@0?ooo`03003o003oool0
oooo02X0oooo00<00?l00?ooo`3oool0<`3oool00`000?l0oooo0?ooo`1G
0?ooo`00ZP3oool00`000?l0oooo0?ooo`0]0?ooo`030000003oool0oooo
0140oooo00<00?l00?ooo`3oool09`3oool2003o03H0oooo00<0003o0?oo
o`3oool0E`3oool00:T0oooo00<0003o0?ooo`3oool0;P3oool00`000000
oooo0?ooo`0A0?ooo`03003o003oool0oooo02D0oooo0P00o`0g0?ooo`03
0000o`3oool0oooo05P0oooo002X0?ooo`030000o`3oool0oooo02l0oooo
00<000000?ooo`3oool04@3oool00`00o`00oooo0?ooo`0S0?ooo`800?l0
>@3oool00`000?l0oooo0?ooo`1H0?ooo`00Z03oool00`000?l0oooo0?oo
o`0_0?ooo`030000003oool0oooo0140oooo00<00?l00?ooo`3oool08P3o
ool00`00o`00oooo0?ooo`0g0?ooo`80003oF`3oool00:L0oooo00<0003o
0?ooo`3oool0<03oool00`000000oooo0?ooo`0B0?ooo`03003o003oool0
oooo0240oooo00<00?l00?ooo`3oool0=P3oool00`000?l0oooo0?ooo`1K
0?ooo`00Y`3oool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo
0180oooo00<00?l00?ooo`3oool07`3oool2003o03T0oooo00<0003o0?oo
o`3oool0F`3oool00:H0oooo00<0003o0?ooo`3oool0<@3oool00`000000
oooo0?ooo`0B0?ooo`03003o003oool0oooo01d0oooo0P00o`0j0?ooo`03
0000o`3oool0oooo05`0oooo002U0?ooo`030000o`3oool0oooo0380oooo
00<000000?ooo`3oool04P3oool00`00o`00oooo0?ooo`0K0?ooo`800?l0
?03oool00`000?l0oooo0?ooo`1L0?ooo`00Y@3oool00`000?l0oooo0?oo
o`0b0?ooo`030000003oool0oooo0180oooo00<00?l00?ooo`3oool06P3o
ool00`00o`00oooo0?ooo`0k0?ooo`030000o`3oool0oooo05d0oooo002T
0?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool04`3oool0
0`00o`00oooo0?ooo`0G0?ooo`800?l0?@3oool00`000?l0oooo0?ooo`1N
0?ooo`00Y03oool00`000?l0oooo0?ooo`0c0?ooo`030000003oool0oooo
01<0oooo00<00?l00?ooo`3oool05@3oool2003o03h0oooo00<0003o0?oo
o`3oool0G`3oool00:<0oooo00<0003o0?ooo`3oool0=03oool00`000000
oooo0?ooo`0C0?ooo`03003o003oool0oooo01<0oooo0P00o`100?ooo`03
0000o`3oool0oooo05l0oooo002R0?ooo`030000o`3oool0oooo03D0oooo
00<000000?ooo`3oool04`3oool00`00o`00oooo0?ooo`0A0?ooo`800?l0
@@3oool00`000?l0oooo0?ooo`1P0?ooo`00XP3oool00`000?l0oooo0?oo
o`0e0?ooo`030000003oool0oooo01@0oooo00<00?l00?ooo`3oool03P3o
ool2003o0480oooo00<0003o0?ooo`3oool0H@3oool00:40oooo00<0003o
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0D0?ooo`03003o003oool0
oooo00X0oooo1000o`130?ooo`030000o`3oool0oooo0680oooo002Q0?oo
o`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool03`3oool30000
0080oooo00<00?l00?ooo`3oool0203oool2003o0100oooo0`00000d0?oo
o`030000o`3oool0oooo0680oooo002P0?ooo`030000o`3oool0oooo03L0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`03
003o003oool0oooo00H0oooo0P00o`0B0?ooo`030000003oool0oooo0380
oooo0P000?mU0?ooo`00W`3oool00`000?l0oooo0?ooo`0h0?ooo`030000
003oool0oooo00L0oooo1@0000040?ooo`030000003oool0oooo0080oooo
00@00?l00?ooo`3oool0oooo1000o`0=0?ooo`@00000103oool00`000000
oooo0?ooo`0`0?ooo`030000o`3oool0oooo06D0oooo002O0?ooo`030000
o`3oool0oooo03P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo1000o`0@0?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000a0?ooo`03
0000o`3oool0oooo06H0oooo002N0?ooo`030000o`3oool0oooo03T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000<0oooo00<00?l00?ooo`3oool04@3oool00`000000oooo
0?ooo`020?ooo`060000003oool0oooo0000003oool00000;`3oool00`00
0?l0oooo0?ooo`1W0?ooo`00WP3oool00`000?l0oooo0?ooo`0i0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`03003o003oool0oooo0140oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`00000`0?ooo`030000o`3oool0oooo
06L0oooo002M0?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3o
ool02P3oool2000000030?ooo`000000oooo00L0oooo00<00?l00?ooo`3o
ool0403oool700000340oooo0P000?mZ0?ooo`00W03oool00`000?l0oooo
0?ooo`0k0?ooo`030000003oool0oooo00T0oooo0P0000000`3oool00000
000000080?ooo`03003o003oool0oooo0100oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo06X0oooo
002L0?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool05P3o
ool00`00o`00oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`1[0?ooo`00V`3oool0
0`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo01H0oooo00<00?l0
0?ooo`3oool04P3oool4000002l0oooo00<0003o0?ooo`3oool0K03oool0
09/0oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`0G0?oo
o`03003o003oool0oooo04@0oooo00<0003o0?ooo`3oool0K03oool009X0
oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo0?ooo`0G0?ooo`03
003o003oool0oooo0480oooo0P000?m_0?ooo`00V@3oool00`000?l0oooo
0?ooo`0n0?ooo`030000003oool0oooo01L0oooo00<00?l00?ooo`3oool0
@@3oool00`000?l0oooo0?ooo`1_0?ooo`00V@3oool00`000?l0oooo0?oo
o`0n0?ooo`030000003oool0oooo01L0oooo00<00?l00?ooo`3oool0@03o
ool00`000?l0oooo0?ooo`1`0?ooo`00V03oool00`000?l0oooo0?ooo`0o
0?ooo`030000003oool0oooo01P0oooo00<00?l00?ooo`3oool0?@3oool2
0000og<0oooo002H0?ooo`030000o`3oool0oooo03l0oooo00<000000?oo
o`3oool0603oool00`00o`00oooo0?ooo`0l0?ooo`030000o`3oool0oooo
07<0oooo002G0?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3o
ool0603oool00`00o`00oooo0?ooo`02003o03X0oooo00<0003o0?ooo`3o
ool0L`3oool009H0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo
0?ooo`0G0?ooo`H00?l0>03oool20000ogH0oooo002F0?ooo`030000o`3o
ool0oooo0440oooo00<000000?ooo`3oool05@3oool8003o03L0oooo00<0
003o0?ooo`3oool0MP3oool009D0oooo00<0003o0?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0E0?ooo`P00?l0=P3oool00`000?l0oooo0?ooo`1g
0?ooo`00U@3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo
01H0oooo1`00o`0d0?ooo`80003oNP3oool009@0oooo00<0003o0?ooo`3o
ool0@`3oool00`000000oooo0?ooo`0F0?ooo`L00?l0<P3oool20000og`0
oooo002C0?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0
5`3oool6003o0340oooo00<0003o0?ooo`3oool0O03oool009<0oooo00<0
003o0?ooo`3oool0A03oool00`000000oooo0?ooo`0G0?ooo`H00?l0<03o
ool00`000?l0oooo0?ooo`1m0?ooo`00TP3oool00`000?l0oooo0?ooo`15
0?ooo`030000003oool0oooo01P0oooo1@00o`0^0?ooo`80003oP03oool0
0980oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0C0?oo
o`<000000P3oool5003o02`0oooo0P000?n20?ooo`00T@3oool00`000?l0
oooo0?ooo`160?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool00`3oool4003o02/0oooo00<0003o0?ooo`3oool0PP3oool00900oooo
00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`0<0?ooo`D00000
0`3oool00`000000oooo0?ooo`020?ooo`@00?l0:P3oool00`000?l0oooo
0?ooo`230?ooo`00T03oool30000odL0oooo00<000000?ooo`3oool03@3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo
0`00o`0X0?ooo`80003o3`3oool200000140oooo1@00000@0?ooo`<00000
C03oool008l0oooo00D0003o0?ooo`3oool0oooo0000o`160?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000040?ooo`<00?l09P3oool20000oa<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04`0oooo
002?0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0>`3o
ool4000000@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo0P00o`0T0?ooo`80003o303o
ool4000000@0oooo00<000000?ooo`3oool02@3oool4000000@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`@00000103o
ool00`000000oooo0?ooo`1;0?ooo`00SP3oool00`000?l0oooo0?ooo`04
0?ooo`80003o>`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00d0oooo00@000000?ooo`3oool000002P3oool2003o0280oooo0P00
0?l=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`3oool5000000030?ooo`000000oooo00<0oooo
00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0?ooo`3oool0000004d0oooo002=0?oo
o`030000o`3oool0oooo00L0oooo0P000?lj0?ooo`030000003oool0oooo
00@0oooo0P00000>0?ooo`D000002P3oool00`00o`00oooo0?ooo`0N0?oo
o`80003o3`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo
0000003oool000002@3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool5000000030?ooo`000000oooo00<0oooo
00H000000?ooo`3oool000000?ooo`00001<0?ooo`00S@3oool00`000?l0
oooo0?ooo`090?ooo`80003o>@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo03/0oooo0P000?lA0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool00000103oool5000000030?ooo`000000oooo
00@0oooo00@000000?ooo`00000000001P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00@000000?ooo`3oool00000C@3oool008`0oooo00<0
003o0?ooo`3oool0303oool30000oc@0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0h0?ooo`<0003o4`3oool7000000d0oooo
1`0000090?ooo`040000003oool0oooo0?ooo`L00000D03oool008`0oooo
00<0003o0?ooo`3oool03`3oool20000oc<0oooo0P0000050?ooo`030000
003oool0oooo03H0oooo0P000?lF0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`1>0?ooo`00P@3oool2000000P0oooo00<0003o0?ooo`3oool04P3o
ool20000ocP0oooo00<000000?ooo`3oool0=03oool20000oaT0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo04h0oooo00230?ooo`030000003oool0
oooo00@0oooo00<0003o0?ooo`3oool05@3oool20000ocH0oooo00<00000
0?ooo`3oool0<P3oool20000oa`0oooo1000000@0?ooo`@00000403oool4
00000540oooo001j0?ooo`D000000`3oool00`000000oooo0?ooo`050?oo
o`030000o`3oool0oooo01L0oooo0P000?ld0?ooo`030000003oool0oooo
0300oooo0P000?nK0?ooo`00N`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool06P3oool50000
obl0oooo00<000000?ooo`3oool0;@3oool30000oid0oooo001l0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`000000103oool00`000?l0
oooo0?ooo`0P0?ooo`80003o;@3oool00`000000oooo0?ooo`0Y0?ooo`@0
003oX03oool007d0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000o`3oool0oooo0280oooo0P000?l[0?ooo`030000
003oool0oooo02L0oooo0P000?nT0?ooo`00N`3oool010000000oooo0?oo
o`0000080?ooo`030000o`3oool0oooo02D0oooo1@000?lV0?ooo`030000
003oool0oooo02@0oooo0`000?nV0?ooo`00N`3oool5000000L0oooo00<0
003o0?ooo`3oool0:P3oool40000ob80oooo00<000000?ooo`3oool0803o
ool40000ojT0oooo00260?ooo`030000o`3oool0oooo02l0oooo1@000?lM
0?ooo`030000003oool0oooo01/0oooo1@000?n]0?ooo`00Q@3oool00`00
0?l0oooo0?ooo`0e0?ooo`D0003o603oool00`000000oooo0?ooo`0G0?oo
o`@0003o/P3oool008D0oooo00<0003o0?ooo`3oool0>P3oool70000oa40
oooo00<000000?ooo`3oool0403oool70000okH0oooo00240?ooo`030000
o`3oool0oooo0480oooo2`000?l60?ooo`030000003oool0oooo00@0oooo
30000?nm0?ooo`00Q03oool00`000?l0oooo0?ooo`1=0?ooo`d0003ob@3o
ool007l0oooo00D0003o0?ooo`3oool0oooo0000o`1F0?ooo`030000003o
ool0oooo0<d0oooo001o0?ooo`@0003oE`3oool00`000000oooo0?ooo`3=
0?ooo`00OP3oool50000oeL0oooo00<000000?ooo`3oool0c@3oool007h0
oooo1`000?mE0?ooo`030000003oool0oooo0<d0oooo001n0?ooo`P0003o
E03oool00`000000oooo0?ooo`3=0?ooo`00O@3oool80000oeD0oooo00<0
00000?ooo`3oool0c@3oool007d0oooo1`000?mF0?ooo`030000003oool0
oooo0<d0oooo001m0?ooo`H0003oE`3oool00`000000oooo0?ooo`3=0?oo
o`00O03oool60000oeP0oooo00<000000?ooo`3oool0c@3oool007`0oooo
1@000?mI0?ooo`030000003oool0oooo0<d0oooo001l0?ooo`@0003oFP3o
ool00`000000oooo0?ooo`3=0?ooo`00N`3oool40000oa80oooo0P00000A
0?ooo`D000002@3oool3000002D0oooo00<000000?ooo`3oool0c@3oool0
07/0oooo0`000?lE0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
0<d0oooo001k0?ooo`80003o303oool5000000@0oooo00<000000?ooo`3o
ool0203oool5000000@0oooo00@000000?ooo`3oool0oooo1@0000040?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0c@3oool007X0
oooo0P000?l?0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o
ool0oooo1@0000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0c@3oool007X0oooo00<0003o0?ooo`3o
ool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000/0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000009@3oool00`000000
oooo0?ooo`3=0?ooo`00S03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo1@0000040?ooo`030000003oool0oooo0080oooo
0P0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`3=0?ooo`00S03oool2000000030?ooo`00
0000oooo00l0oooo0P0000000`3oool000000?ooo`080?ooo`80000000<0
oooo0000003oool0:03oool00`000000oooo0?ooo`3=0?ooo`00R`3oool2
000000030?ooo`000000000000l0oooo0P0000000`3oool0000000000008
0?ooo`80000000<0oooo000000000000:@3oool00`000000oooo0?ooo`3=
0?ooo`00fP3oool00`000000oooo0?ooo`3=0?ooo`00fP3oool00`000000
oooo0?ooo`3=0?ooo`00fP3oool00`000000oooo0?ooo`3=0?ooo`00o`3o
oon[0?ooo`00o`3ooon[0?ooo`00o`3ooon[0?ooo`00o`3ooon[0?ooo`00
o`3ooon[0?ooo`00o`3ooon[0?ooo`00o`3ooon[0?ooo`00o`3ooon[0?oo
o`00f03oool200000=00oooo003I0?ooo`030000003oool0oooo0<h0oooo
003J0?ooo`030000003oool0oooo0<d0oooo003I0?ooo`030000003oool0
00000<h0oooo003H0?ooo`040000003oool0oooo00000<h0oooo003G0?oo
o`<0000000<0oooo000000000000c@3oool00?l0ooooZ`3oool00?l0oooo
Z`3oool00?l0ooooZ`3oool00?l0ooooZ`3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{426, 221},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\tWe have already seen that the modulus of the product is the product of \
the moduli;  that is, ",
  Cell[BoxData[
      \(\(\(|\)\(\(z\_1\) z\_2\)\(|\)\) = \(\(|\)\(z\_1 || z\_2\)\(|\)\)\)]],
  ".  The above identity establishes that an argument of  ",
  Cell[BoxData[
      \(\(z\_1\) z\_2\)]],
  "  is an argument of ",
  Cell[BoxData[
      \(z\_1\)]],
  " plus an argument of ",
  Cell[BoxData[
      \(z\_2\)]],
  ".  It also answers the question posed at the end of Section 1.3 regarding \
why the product ",
  Cell[BoxData[
      \(\(z\_1\) z\_2\)]],
  " was in a different quadrant than either ",
  Cell[BoxData[
      \(z\_1\)]],
  " or ",
  Cell[BoxData[
      \(z\_2\)]],
  ".  It further offers an interesting explanation as to why the product of \
two negative real numbers is a positive real number.  The negative numbers, \
each of which has an angular displacement of ",
  Cell[BoxData[
      \(\[Pi]\)]],
  " radians, combine to produce a product that is rotated to a point with an \
argument of  ",
  Cell[BoxData[
      \(\[Pi] + \[Pi] = 2  \[Pi]\)]],
  "  radians, coinciding with the positive real axis."
}], "Text"],

Cell[TextData[{
  "\tUsing exponential form, if ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ", we can write  ",
  Cell[BoxData[
      \(arg\ z\)]],
  ",  a little more compactly as \n\n\t\t\t",
  Cell[BoxData[
      \(arg\ z\  = \ {\[Theta] : \ z = 
            r\ \[ExponentialE]\^\[ImaginaryI]\[Theta]}\)]],
  ".  \n\n",
  "Doing so enables us to see a nice relationship between the sets",
  " ",
  Cell[BoxData[
      \(arg \((\(z\_1\) z\_2)\)\)]],
  ", ",
  Cell[BoxData[
      \(arg \((z\_1)\)\)]],
  ", and ",
  Cell[BoxData[
      \(arg \((z\_2)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 1.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(z\_1 = \(r\_1\) \[ExponentialE]\^\[ImaginaryI]\[Theta]\_1 \[NotEqual] 
          0\)]],
  "  and  ",
  Cell[BoxData[
      \(z\_2 = \(r\_2\) \[ExponentialE]\^\[ImaginaryI]\[Theta]\_2 \[NotEqual] 
          0\)]],
  ",  then as sets,\n\n\t\t\t",
  Cell[BoxData[
      \(arg \((\(z\_1\) z\_2)\) = arg \((z\_1)\) + arg \((z\_2)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tBefore proceeding with the proof, we recall two important facts about \
sets.  First, to establish the equality of two sets, we must show that each \
is a subset of the other.  Second, the sum of two sets is the sum of all \
combinations of elements from the first and second sets, respectively.  In \
this case,  ",
  Cell[BoxData[
      RowBox[{\(arg \((z\_1)\) + arg \((z\_2)\)\), " ", "=", " ", 
        RowBox[{"{", 
          RowBox[{\(\[Theta]\_1\), "+", 
            RowBox[{\(\[Theta]\_2\), ":", " ", 
              RowBox[{\(\[Theta]\_1\), "\[Element]", 
                RowBox[{"arg", \((z\_1)\), "  ", 
                  StyleBox["and",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "   ", \(\[Theta]\_2\)}], 
                "\[Element]", \(arg \((z\_2)\)\)}]}]}], "}"}]}]]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Proof",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(\[Theta] \[Element] arg \((\(z\_1\) z\_2)\)\)]],
  ".  Because  ",
  Cell[BoxData[
      \(\(z\_1\) 
          z\_2 = \ \(r\_1\) \(r\_2\) \[ExponentialE]\^\(\[ImaginaryI] \((\
\[Theta]\_1 + \[Theta]\_2)\)\)\)]],
  ",  it follows that  ",
  Cell[BoxData[
      \(\[Theta]\_1 + \[Theta]\_2 \[Element] arg \((\(z\_1\) z\_2)\)\)]],
  ".  Hence, there is some integer ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " such that  ",
  Cell[BoxData[
      \(\[Theta]\  = \ \[Theta]\_1 + \[Theta]\_2 + 2  n\ \[Pi]\)]],
  ".  Further, as  ",
  Cell[BoxData[
      \(z\_1 = \(r\_1\) \[ExponentialE]\^\[ImaginaryI]\[Theta]\_1\)]],
  "  we have  ",
  Cell[BoxData[
      \(\[Theta]\_1 \[Element] arg \((z\_1)\)\)]],
  ".  Likewise,  ",
  Cell[BoxData[
      \(z\_2 = \(r\_2\) \[ExponentialE]\^\[ImaginaryI]\[Theta]\_2\)]],
  "  gives  ",
  Cell[BoxData[
      \(\[Theta]\_2 \[Element] arg \((z\_2)\)\)]],
  ".  But if  ",
  Cell[BoxData[
      \(\[Theta]\_2 \[Element] arg \((z\_2)\)\)]],
  ",  then  ",
  Cell[BoxData[
      \(\[Theta]\_2 + 2  n\ \[Pi] \[Element] arg \((z\_2)\)\)]],
  ".  This result shows that  ",
  Cell[BoxData[
      \(\[Theta]\  = \ \[Theta]\_1 + \((\[Theta]\_2 + 
                2  n\ \[Pi])\) \[Element] 
          arg \((z\_1)\) + arg \((z\_1)\)\)]],
  ".  Thus,  ",
  Cell[BoxData[
      \(arg \((\(z\_1\) z\_2)\)\  \[Subset] \ 
        arg \((z\_1)\) + arg \((z\_2)\)\)]],
  ".  The proof that  ",
  Cell[BoxData[
      \(arg \((z\_1)\) + arg \((z\_2)\)\  \[Subset] \ 
        arg \((\(z\_1\) z\_2)\)\)]],
  "  is left as an exercise."
}], "Text"],

Cell[TextData[{
  "\tUsing the exponential form,  ",
  Cell[BoxData[
      \(z = r\ e\^\[ImaginaryI]\[Theta]\)]],
  ",  we see that  ",
  Cell[BoxData[
      \(z\^\(-1\) = \(1\/z = \(1\/\(r\ e\^\[ImaginaryI]\[Theta]\) = \(1\/r\) 
              e\^\(-\[ImaginaryI]\[Theta]\)\)\)\)]],
  ".  In other words,\n\n\t\t\t",
  Cell[BoxData[{
      \(z\^\(-1\)\  = \ \(1\/r\)[
          cos \((\(-\[Theta]\))\) + \[ImaginaryI]\ sin\ \((\(-\[Theta]\))\)]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \(\(=\)\(\ \)\(\(1\/r\) 
          e\^\(-\[ImaginaryI]\[Theta]\)\)\)\)}]],
  "    "
}], "Text"],

Cell[TextData[{
  "Recalling that ",
  Cell[BoxData[
      \(cos \((\(-\[Theta]\))\) = cos \((\[Theta])\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\(-\[Theta]\))\) = \(-sin\) \((\[Theta])\)\)]],
  ", we also have  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(z\)\(\ \)\)\&_\ \  = \ \(r \((cos\ \[Theta]\  - \ \[ImaginaryI]\ \
sin\ \[Theta])\)\  = \ \ r[
            cos\ \((\(-\[Theta]\))\)\  + \ \[ImaginaryI]\ sin \((\(-\ \
\[Theta]\))\)]\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \(\(=\)\(\ \)\(r\ e\^\(-\[ImaginaryI]\[Theta]\)\)\)\)}]],
  "  \n\t\n\tand\n\n  \t\t\t",
  Cell[BoxData[{
      \(z\_1\/z\_2\  = \ \(r\_1\/r\_2\)[
          cos\ \((\[Theta]\_1 - \[Theta]\_2)\)\  + \ \[ImaginaryI]\ sin \((\
\[Theta]\_1 - \[Theta]\_2)\)]\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \(\(=\)\(\ \)\(\(r\_1\/r\_2\) 
          e\^\(\[ImaginaryI] \((\[Theta]\_1 - \[Theta]\_2)\)\)\)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "If ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " is in the first quadrant, the positions of the numbers  ",
  Cell[BoxData[
      RowBox[{"z", ",", \(\(\(z\)\(\ \)\)\&_\), ",", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", \(z\^\(-1\)\)}]}]]],
  "  are as shown in Figure 1.14 when  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ".  Figure 1.15 depicts the situation when  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(1\)\)\)\)]],
  ". "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400074000142000`400?l0
0000o`00003oo`3oooo50?ooo`00o`3oooo50?ooo`00o`3oooo50?ooo`00
N03oool40000oe/0oooo0`00003Z0?ooo`00M`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo05T0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo02@0oooo001g0?ooo`H0003oF`3oool00`000000oooo0?ooo`0h
0?ooo`8000004`3oool200000380oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02@0oooo001/0?oo
o`@0003o0`3oool90000o`<0oooo2@000?l20?ooo`<0003o1P3oool40000
o`030?ooo`000?l0003o0080oooo10000?l40?ooo`80003o1`3oool30000
00<0oooo0P0000000`3oool00000000000020?ooo`<0000000<0oooo0000
000000000P000000103oool000000000003oool300000080oooo00<00000
0?ooo`3oool00P3oool2000000H0oooo00@000000?ooo`00000000000`3o
ool300000080oooo0`0000020?ooo`<0000000@0oooo000000000000oooo
0`000000103oool000000000000000020?ooo`<0000000<0oooo00000000
00000`0000090?ooo`D00000103oool00`000000oooo0?ooo`060?ooo`D0
00001`3oool00`000000oooo0?ooo`060?ooo`L0000000@0oooo00000000
0000oooo1@0000070?ooo`D000003@3oool2000000T0oooo00@000000?oo
o`3oool000000`3oool3000000040?ooo`00000000000?ooo`8000000P3o
ool3000000030?ooo`000000000000/0oooo00<000000?ooo`3oool01@3o
ool5000000L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`040?ooo`D00000103oool00`000000oooo0?ooo`050?ooo`00K@3oool2
0000o`D0oooo0P000?l00`3oool0003o0?ooo`050?ooo`80003o00<0oooo
0000o`000?l00P3oool20000o`80oooo0P000?l20?ooo`030000o`3oool0
oooo00@0oooo0P000?l20?ooo`80003o0`3oool20000o`D0oooo0P000?l8
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool000000080oooo00@000000?ooo`3oool0
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?oo
o`3oool000001@3oool200000080oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000<0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`3oool0oooo000000040?ooo`8000001`3oool0
1@000000oooo0?ooo`3oool0000000L0oooo0P0000060?ooo`040000003o
ool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000000H
0?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool00000
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo0?ooo`0:0?ooo`8000002@3oool0
0`000000oooo0?ooo`0<0?ooo`00K@3oool20000o`D0oooo0P000?l20?oo
o`<0003o0`3oool20000o`030?ooo`000?l0003o0080oooo0P000?l20?oo
o`80003o2@3oool20000o`L0oooo0P000?l20?ooo`H0003o1`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`060000003o
ool0oooo0000003oool000000P3oool00`000000oooo0?ooo`060?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0
oooo0?ooo`8000000P3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`3oool2000000T0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0@0?ooo`040000003oool0oooo00000080oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0603oool01P000000oooo000000000000oooo0000
00<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`040000003o
ool0oooo000000`0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo0P00000;0?ooo`030000
003oool0oooo00`0oooo001]0?ooo`80003o00<0oooo0000o`3oool00P3o
ool20000o`040?ooo`000?l0003o0?ooo`80003o0P3oool20000o`030?oo
o`000?l0003o0080oooo0P000?l20?ooo`D0003o1P3oool20000o`L0oooo
0P000?l20?ooo`030000o`3oool0oooo0080003o203oool010000000oooo
0?ooo`0000030?ooo`@000000P3oool00`000000oooo0?ooo`0300000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool00000
0080oooo100000050?ooo`070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`040000003oool00000000000@0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo000000030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`0000000000303oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0100oooo0`0000020?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01L0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`050000003oool0oooo0000003oool0100000020?ooo`040000003oool0
oooo000000`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00X0oooo0P0000090?ooo`030000003o
ool0oooo00`0oooo001]0?ooo`@0003o0`3oool20000o`040?ooo`000?l0
003o0?ooo`80003o0P3oool20000o`030?ooo`000?l0003o0080oooo0P00
0?l01@3oool0003o0000o`000?l0oooo0080003o1P3oool20000o`L0oooo
0P000?l30?ooo`040000o`3oool0003o0000o`P0oooo100000030?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`0000000P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`8000000P3oool0
0`000000oooo000000030?ooo`030000003oool000000080oooo00@00000
0?ooo`3oool000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`02000000040?ooo`000000oooo0000
0080oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00000>
0?ooo`040000003oool0oooo00000100oooo00@000000?ooo`3oool00000
0P3oool2000000040?ooo`000000oooo00000080oooo0P0000080?ooo`04
0000003oool0oooo000000L0oooo1@00000<0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00P000000103oool000000?ooo`00
00020?ooo`030000003oool0oooo0080000000<0oooo0000003oool02`3o
ool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00`0oooo001]0?ooo`80003o00@0oooo0000o`3oool0oooo
0`000?l20?ooo`P0003o00@0oooo0000o`000?l0oooo1@000?l0103oool0
003o0000o`000?l70?ooo`80003o1`3oool20000o`<0oooo00@0003o0?oo
o`000?l0003o203oool01@000000oooo0?ooo`3oool0000000<0oooo0P00
00030?ooo`030000003oool0oooo008000000P3oool3000000030?ooo`00
0000000000<000000P3oool2000000030?ooo`000000000000D0oooo0P00
00000`3oool00000000000030?ooo`<000000`3oool3000000040?ooo`00
000000000?ooo`<0000000<0oooo0000000000000P3oool300000080oooo
0P0000000`3oool000000?ooo`020?ooo`<00000203oool5000000d0oooo
1@00000@0?ooo`8000000P3oool2000000030?ooo`000000oooo0080oooo
0P0000000`3oool000000?ooo`070?ooo`D000000P3oool400000080oooo
00<000000?ooo`3oool02`3oool2000000050?ooo`00000000000000003o
ool00P000000103oool000000?ooo`0000030?ooo`8000000P3oool20000
00030?ooo`000000oooo00`0oooo00<000000?ooo`3oool01@3oool50000
00L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?oo
o`00K@3oool20000obD0oooo0P000?l70?ooo`80003o103oool30000o`P0
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`00K@3oool20000o`<0
oooo00@0003o0?ooo`000?l0003o7P3oool20000o`L0oooo0P000?l50?oo
o`80003o203oool01@000000oooo0?ooo`3oool0000000P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo02`0oooo2`00000I0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0503oool2000000h0oooo001/0?oo
o`L0003o00<0oooo0000o`000?l07@3oool30000o`H0oooo0`000?l50?oo
o`80003o1`3oool5000000P0oooo0P00000;0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1;0?oo
o`8000005@3oool00`000000oooo0?ooo`0D0?ooo`800000E@3oool00?l0
ooooEP3oool2000006d0oooo003o0?ooolD0oooo003o0?ooolD0oooo003o
0?ooolD0oooo003o0?ooolD0oooo003o0?ooolD0oooo003o0?ooolD0oooo
003o0?ooolD0oooo003o0?ooolD0oooo003o0?ooolD0oooo003I0?ooo`03
0000003oool0oooo0>P0oooo003I0?ooo`030000003oool0oooo0>P0oooo
003I0?ooo`030000003oool0oooo06X0oooo0P00o`060?ooo`D00000L@3o
ool00=T0oooo00<000000?ooo`3oool0J@3oool4003o00H0oooo00@00000
0?ooo`3oool00000L@3oool00=T0oooo00<000000?ooo`3oool0J03oool6
003o00H0oooo00<000000?ooo`3oool0L@3oool00=T0oooo00<000000?oo
o`3oool0J03oool6003o00L0oooo00<000000?ooo`3oool0L03oool00=T0
oooo00<000000?ooo`3oool0I`3oool6003o00H0oooo00@000000?ooo`3o
ool000001P3oool5000006H0oooo003I0?ooo`030000003oool0oooo06D0
oooo1000o`000`3oool00?l0003o00070?ooo`D0000000<0oooo00000000
00000P0000020?ooo`030000003oool0oooo06H0oooo003A0?ooo`D00000
0`3oool00`000000oooo0?ooo`1S0?ooo`H00?l05P3oool00`000000oooo
0?ooo`1V0?ooo`00d`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0680oooo1P00o`0G0?ooo`030000003oool0oooo06H0oooo003C
0?ooo`X0ol3;G`3oool7003o01P0oooo00<000000?ooo`3oool0IP3oool0
0</0oooo203o`</00`000000oooo0?ooo`030?ooo`040000003oool0oooo
0?ooo`X0ol3;E03oool8003o01L0oooo0P00001X0?ooo`00a03oool70?o0
b`P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?oo
o`P0ol3;C@3oool6003o0880oooo00310?ooo`<0ol3;3P3oool2000000D0
oooo00<000000?ooo`3oool04`3oool20?o0bd`0oooo1@00o`220?ooo`00
_03oool50?o0baP0oooo00<000000?ooo`3oool05@3oool50?o0bdH0oooo
1@00o`230?ooo`00^P3oool20?o0bad0oooo00<000000?ooo`3oool06P3o
ool30?o0bd80oooo00<00?l00?ooo`3oool00`00o`230?ooo`00]`3oool3
0?o0bal0oooo00<000000?ooo`3oool07@3oool20?o0bcl0oooo00<00?l0
0?ooo`3oool00P3oool00`00o`00oooo0?ooo`220?ooo`00]@3oool20?o0
bb80oooo00<000000?ooo`3oool07`3oool20?o0bc`0oooo00<00?l00?oo
o`3oool0R03oool00;40oooo103o`</T0?ooo`030000003oool0oooo0240
oooo1@3o`</f0?ooo`03003o003oool0oooo08T0oooo002_0?ooo`80ol3;
:03oool00`000000oooo0?ooo`0V0?ooo`030?o0b`3oool0oooo0380oooo
00<00?l00?ooo`3oool0RP3oool00:h0oooo00<0ol3;0?ooo`3oool0:03o
ool00`000000oooo0?ooo`0W0?ooo`80ol3;<@3oool00`00o`00oooo0?oo
o`2;0?ooo`00[03oool20?o0bb/0oooo00<000000?ooo`3oool0:@3oool2
0?o0bbh0oooo0P00o`2=0?ooo`00Z@3oool30?o0bbd0oooo00<000000?oo
o`3oool0:`3oool20?o0bb/0oooo00@00?l00?ooo`3oool00?l0S03oool0
0:L0oooo0P3o`</`0?ooo`030000003oool0oooo02d0oooo0P3o`</X0?oo
o`03003o003oool0oooo0080oooo00<00?l00?ooo`3oool0R@3oool00:D0
oooo0P3o`</b0?ooo`030000003oool0oooo02l0oooo0P3o`</U0?ooo`03
003o003oool0oooo00@0oooo00<00?l00?ooo`3oool0R03oool00:@0oooo
00<0ol3;0?ooo`3oool0<P3oool00`000000oooo0?ooo`0a0?ooo`80ol3;
8P3oool00`00o`00oooo0?ooo`060?ooo`03003o003oool0oooo08L0oooo
002S0?ooo`030?o0b`3oool0oooo03<0oooo00<000000?ooo`3oool0<`3o
ool00`3o`</0oooo0?ooo`0N0?ooo`03003o003oool0oooo00P0oooo00<0
0?l00?ooo`3oool0QP3oool00:40oooo0P3o`</f0?ooo`030000003oool0
oooo03@0oooo0P3o`</M0?ooo`03003o003oool0oooo00T0oooo00<00?l0
0?ooo`3oool0QP3oool009l0oooo0P3o`</h0?ooo`030000003oool0oooo
03H0oooo0P3o`</J0?ooo`03003o003oool0oooo00/0oooo00<00?l00?oo
o`3oool0Q@3oool009d0oooo0P3o`</j0?ooo`030000003oool0oooo03P0
oooo00<0ol3;0?ooo`3oool05P3oool00`00o`00oooo0?ooo`0=0?ooo`80
0?l0Q@3oool009`0oooo00<0ol3;0?ooo`3oool0>P3oool00`000000oooo
0?ooo`0i0?ooo`030?o0b`3oool0oooo01@0oooo00<00?l00?ooo`3oool0
403oool00`00o`00oooo0?ooo`220?ooo`00VP3oool20?o0bcd0oooo00<0
00000?ooo`3oool0>P3oool20?o0ba<0oooo00<00?l00?ooo`3oool04P3o
ool00`00o`00oooo0?ooo`210?ooo`00V@3oool00`3o`</0oooo0?ooo`0m
0?ooo`030000003oool0oooo03`0oooo00<0ol3;0?ooo`3oool03`3oool0
0`00o`00oooo0?ooo`0C0?ooo`03003o003oool0oooo0840oooo002H0?oo
o`030?o0b`3oool0oooo03h0oooo00<000000?ooo`3oool0?@3oool00`3o
`</0oooo0?ooo`0=0?ooo`03003o003oool0oooo01D0oooo00<00?l00?oo
o`3oool0P03oool009L0oooo00<0ol3;0?ooo`3oool0?`3oool00`000000
oooo0?ooo`0n0?ooo`030?o0b`3oool0oooo00/0oooo00<00?l00?ooo`3o
ool05P3oool00`00o`00oooo0?ooo`200?ooo`00UP3oool00`3o`</0oooo
0?ooo`100?ooo`030000003oool0oooo03l0oooo00<0ol3;0?ooo`3oool0
2@3oool00`00o`00oooo0?ooo`0H0?ooo`03003o003oool0oooo07l0oooo
002D0?ooo`80ol3;@`3oool00`000000oooo0?ooo`100?ooo`80ol3;203o
ool00`00o`00oooo0?ooo`0J0?ooo`03003o003oool0oooo07h0oooo002C
0?ooo`030?o0b`3oool0oooo04<0oooo00<000000?ooo`3oool0@P3oool0
0`3o`</0oooo0?ooo`040?ooo`03003o003oool0oooo01/0oooo00<00?l0
0?ooo`3oool0OP3oool009<0oooo00<0ol3;0?ooo`3oool0@`3oool00`00
0000oooo0?ooo`130?ooo`030?o0b`3oool0oooo0080oooo00<00?l00?oo
o`3oool07@3oool00`00o`00oooo0?ooo`1m0?ooo`00TP3oool00`3o`</0
oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo00@0ol3;0?ooo`3o
ool00?l08@3oool00`00o`00oooo0?ooo`1l0?ooo`00T@3oool00`3o`</0
oooo0?ooo`150?ooo`030000003oool0oooo04D0oooo00<0ol3;003o003o
ool08P3oool00`00o`00oooo0?ooo`1k0?ooo`00T03oool00`3o`</0oooo
0?ooo`160?ooo`030000003oool0oooo04D0oooo00<00?l00?o0b`3oool0
8`3oool00`00o`00oooo0?ooo`1j0?ooo`00S`3oool00`3o`</0oooo0?oo
o`170?ooo`030000003oool0oooo04@0oooo00@00?l00?ooo`3oool0ol3;
8`3oool00`00o`00oooo0?ooo`1j0?ooo`00S@3oool20?o0bdX0oooo00<0
00000?ooo`3oool0@`3oool00`00o`00oooo0?ooo`020?ooo`030?o0b`3o
ool0oooo0240oooo00<00?l00?ooo`3oool0N@3oool008`0oooo00<0ol3;
0?ooo`3oool0BP3oool00`000000oooo0?ooo`120?ooo`03003o003oool0
oooo00@0oooo00<0ol3;0?ooo`3oool08@3oool00`00o`00oooo0?ooo`1h
0?ooo`00R`3oool00`3o`</0oooo0?ooo`1;0?ooo`030000003oool0oooo
0440oooo00<00?l00?ooo`3oool01P3oool00`3o`</0oooo0?ooo`0P0?oo
o`03003o003oool0oooo07P0oooo002:0?ooo`030?o0b`3oool0oooo04`0
oooo00<000000?ooo`3oool0:`3oool500000100oooo00<00?l00?ooo`3o
ool0203oool00`3o`</0oooo0?ooo`0P0?ooo`03003o003oool0oooo07L0
oooo002:0?ooo`030?o0b`3oool0oooo04`0oooo00<000000?ooo`3oool0
;03oool010000000oooo0?ooo`00000?0?ooo`03003o003oool0oooo00X0
oooo00<0ol3;0?ooo`3oool07`3oool00`00o`00oooo0?ooo`1g0?ooo`00
R@3oool00`3o`</0oooo0?ooo`1=0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool03P3oool00`00o`00oooo0?ooo`0;0?ooo`030?o0
b`3oool0oooo0200oooo00<00?l00?ooo`3oool0MP3oool008P0oooo00<0
ol3;0?ooo`3oool0CP3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00`0oooo00<00?l00?ooo`3oool03@3oool00`3o`</0oooo0?oo
o`0O0?ooo`03003o003oool0oooo07H0oooo00270?ooo`030?o0b`3oool0
oooo04l0oooo00<000000?ooo`3oool0;03oool010000000oooo0?ooo`00
000<0?ooo`03003o003oool0oooo00l0oooo00<0ol3;0?ooo`3oool07`3o
ool00`00o`00oooo0?ooo`1e0?ooo`00QP3oool00`3o`</0oooo0?ooo`1@
0?ooo`030000003oool0oooo02`0oooo1@00000:0?ooo`03003o003oool0
oooo0140oooo00<0ol3;0?ooo`3oool07P3oool00`00o`00oooo0?ooo`1e
0?ooo`00Q@3oool00`3o`</0oooo0?ooo`1A0?ooo`030000003oool0oooo
03X0oooo00<00?l00?ooo`3oool04`3oool00`3o`</0oooo0?ooo`0N0?oo
o`03003o003oool0oooo07@0oooo00250?ooo`030?o0b`3oool0oooo0540
oooo00<000000?ooo`3oool0>@3oool00`00o`00oooo0?ooo`0E0?ooo`03
0?o0b`3oool0oooo01d0oooo00<00?l00?ooo`3oool0M03oool008@0oooo
00<0ol3;0?ooo`3oool0DP3oool00`000000oooo0?ooo`0h0?ooo`03003o
003oool0oooo01H0oooo00<0ol3;0?ooo`3oool07P3oool00`00o`00oooo
0?ooo`1c0?ooo`00P`3oool00`3o`</0oooo0?ooo`1C0?ooo`030000003o
ool0oooo03L0oooo00<00?l00?ooo`3oool0603oool00`3o`</0oooo0?oo
o`0N0?ooo`03003o003oool0oooo00d0oooo1000001Q0?ooo`00P`3oool0
0`3o`</0oooo0?ooo`1C0?ooo`030000003oool0oooo02/0oooo1@000006
0?ooo`03003o003oool0oooo01T0oooo00<0ol3;0?ooo`3oool07P3oool0
0`00o`00oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0GP3oool00880oooo00<0ol3;0?ooo`3oool0E03oool00`00
0000oooo0?ooo`0e0?ooo`03003o003oool0oooo01/0oooo00<0ol3;0?oo
o`3oool07P3oool00`00o`00oooo0?ooo`050?ooo`D0000000<0oooo0000
003oool00`3oool00`000000oooo0?ooo`1N0?ooo`00PP3oool00`3o`</0
oooo0?ooo`1D0?ooo`030000003oool0oooo03@0oooo00<00?l00?ooo`3o
ool0703oool00`3o`</0oooo0?ooo`0N0?ooo`03003o003oool0oooo00/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1M0?ooo`00
P@3oool00`3o`</0oooo0?ooo`1E0?ooo`030000003oool0oooo03<0oooo
00<00?l00?ooo`3oool07P3oool00`3o`</0oooo0?ooo`0N0?ooo`03003o
003oool0oooo00X0oooo1`00001O0?ooo`00P@3oool00`3o`</0oooo0?oo
o`1E0?ooo`030000003oool0oooo03<0oooo00<00?l00?ooo`3oool07`3o
ool00`3o`</0oooo0?ooo`0M0?ooo`03003o003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1M0?ooo`00P03oool0
0`3o`</0oooo0?ooo`1F0?ooo`030000003oool0oooo0380oooo00<00?l0
0?ooo`3oool0803oool00`3o`</0oooo0?ooo`0M0?ooo`03003o003oool0
oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1M
0?ooo`00O`3oool00`3o`</0oooo0?ooo`1G0?ooo`030000003oool0oooo
0340oooo00<00?l00?ooo`3oool08P3oool00`3o`</0oooo0?ooo`0M0?oo
o`03003o003oool0oooo00/0oooo1000001P0?ooo`00OP3oool00`3o`</0
oooo0?ooo`1H0?ooo`030000003oool0oooo02d0oooo0P000?l00`3oool0
0?l00?ooo`0T0?ooo`030?o0b`3oool0oooo01d0oooo00<00?l00?ooo`3o
ool0K`3oool007h0oooo00<0ol3;0?ooo`3oool0F03oool00`000000oooo
0?ooo`0/0?ooo`@0003o9`3oool00`3o`</0oooo0?ooo`0M0?ooo`03003o
003oool0oooo06h0oooo001n0?ooo`030?o0b`3oool0oooo05P0oooo00<0
00000?ooo`3oool0:`3oool60000obL0oooo00<0ol3;0?ooo`3oool0703o
ool00`00o`00oooo0?ooo`1^0?ooo`00O@3oool00`3o`</0oooo0?ooo`1I
0?ooo`030000003oool0oooo02/0oooo1P000?lW0?ooo`030?o0b`3oool0
oooo01d0oooo00<00?l00?ooo`3oool0K@3oool007d0oooo00<0ol3;0?oo
o`3oool0F@3oool00`000000oooo0?ooo`0Z0?ooo`H0003o:@3oool00`3o
`</0oooo0?ooo`0L0?ooo`03003o003oool0oooo06d0oooo001l0?ooo`03
0?o0b`3oool0oooo05X0oooo00<000000?ooo`3oool0:03oool40000o`03
0?ooo`000?l0003o02X0oooo00<0ol3;0?ooo`3oool0703oool00`00o`00
oooo0?ooo`1]0?ooo`00O03oool00`3o`</0oooo0?ooo`1J0?ooo`030000
003oool0oooo02H0oooo1P000?l^0?ooo`030?o0b`3oool0oooo01`0oooo
00<00?l00?ooo`3oool0K03oool007/0oooo00<0ol3;0?ooo`3oool0F`3o
ool00`000000oooo0?ooo`0U0?ooo`H0003o;`3oool00`3o`</0oooo0?oo
o`0L0?ooo`03003o003oool0oooo06`0oooo001k0?ooo`030?o0b`3oool0
oooo05/0oooo00<000000?ooo`3oool08`3oool80000oc00oooo00<0ol3;
0?ooo`3oool06`3oool00`00o`00oooo0?ooo`1/0?ooo`00NP3oool00`3o
`</0oooo0?ooo`1L0?ooo`030000003oool0oooo0280oooo20000?la0?oo
o`030?o0b`3oool0oooo01`0oooo00<00?l00?ooo`3oool0J`3oool007X0
oooo00<0ol3;0?ooo`3oool0G03oool00`000000oooo0?ooo`0S0?ooo`L0
003o<P3oool00`3o`</0oooo0?ooo`0K0?ooo`03003o003oool0oooo06/0
oooo001j0?ooo`030?o0b`3oool0oooo05`0oooo00<000000?ooo`3oool0
8`3oool60000oc<0oooo00<0ol3;0?ooo`3oool06`3oool00`00o`00oooo
0?ooo`1[0?ooo`00N@3oool00`3o`</0oooo0?ooo`1M0?ooo`030000003o
ool0oooo0280oooo0`000?l0103oool0003o0000o`000?lc0?ooo`030?o0
b`3oool0oooo01`0oooo00<00?l00?ooo`3oool0JP3oool007T0oooo00<0
ol3;0?ooo`3oool0G@3oool00`000000oooo0?ooo`0Q0?ooo`<0003o0`3o
ool00`000?l0oooo0?ooo`0c0?ooo`030?o0b`3oool0oooo01/0oooo00<0
0?l00?ooo`3oool0JP3oool007P0oooo00<0ol3;0?ooo`3oool0GP3oool0
0`000000oooo0?ooo`0P0?ooo`<0003o>P3oool00`3o`</0oooo0?ooo`0K
0?ooo`03003o003oool0oooo06X0oooo001h0?ooo`030?o0b`3oool0oooo
05h0oooo00<000000?ooo`3oool07`3oool30000oc`0oooo00<0ol3;0?oo
o`3oool06P3oool00`00o`00oooo0?ooo`1Z0?ooo`00N03oool00`3o`</0
oooo0?ooo`1N0?ooo`030000003oool0oooo01h0oooo0`000?lm0?ooo`03
0?o0b`3oool0oooo01/0oooo00<00?l00?ooo`3oool0J@3oool007L0oooo
00<0ol3;0?ooo`3oool0G`3oool00`000000oooo0?ooo`0M0?ooo`<0003o
?`3oool00`3o`</0oooo0?ooo`0J0?ooo`03003o003oool0oooo06T0oooo
001g0?ooo`030?o0b`3oool0oooo05l0oooo00<000000?ooo`3oool0703o
ool30000o`030?ooo`000?l0oooo03d0oooo00<0ol3;0?ooo`3oool06P3o
ool00`00o`00oooo0?ooo`1Y0?ooo`00MP3oool00`3o`</0oooo0?ooo`1P
0?ooo`030000003oool0oooo01/0oooo0`000?l30?ooo`030000o`3oool0
oooo03/0oooo00<0ol3;0?ooo`3oool06P3oool00`00o`00oooo0?ooo`1Y
0?ooo`00MP3oool00`3o`</0oooo0?ooo`1P0?ooo`030000003oool0oooo
01X0oooo0`000?l50?ooo`030000o`3oool0oooo03X0oooo00<0ol3;0?oo
o`3oool06`3oool00`00o`00oooo0?ooo`1X0?ooo`00MP3oool00`3o`</0
oooo0?ooo`1P0?ooo`030000003oool0oooo01T0oooo0`000?l60?ooo`03
0000o`3oool0oooo03X0oooo00<0ol3;0?ooo`3oool06`3oool00`00o`00
oooo0?ooo`1X0?ooo`00M@3oool00`3o`</0oooo0?ooo`1Q0?ooo`030000
003oool0oooo01P0oooo0`000?l80?ooo`030000o`3oool0oooo03X0oooo
00<0ol3;0?ooo`3oool06P3oool00`00o`00oooo0?ooo`1X0?ooo`00M@3o
ool00`3o`</0oooo0?ooo`1Q0?ooo`030000003oool0oooo01L0oooo0`00
0?l:0?ooo`030000o`3oool0oooo03T0oooo00<0ol3;0?ooo`3oool06`3o
ool00`00o`00oooo0?ooo`1W0?ooo`00M@3oool00`3o`</0oooo0?ooo`1Q
0?ooo`030000003oool0oooo01H0oooo0`000?l<0?ooo`030000o`3oool0
oooo03P0oooo00<0ol3;0?ooo`3oool06`3oool00`00o`00oooo0?ooo`1W
0?ooo`00M@3oool00`3o`</0oooo0?ooo`1Q0?ooo`030000003oool0oooo
01D0oooo0`000?l=0?ooo`030000o`3oool0oooo03T0oooo00<0ol3;0?oo
o`3oool06P3oool00`00o`00oooo0?ooo`1W0?ooo`00M@3oool00`3o`</0
oooo0?ooo`1Q0?ooo`030000003oool0oooo01D0oooo0P000?l?0?ooo`03
0000o`3oool0oooo00`0oooo1000000X0?ooo`030?o0b`3oool0oooo01X0
oooo00<00?l00?ooo`3oool0I`3oool007@0oooo00<0ol3;0?ooo`3oool0
HP3oool00`000000oooo0?ooo`0D0?ooo`80003o403oool00`000?l0oooo
0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
9@3oool00`3o`</0oooo0?ooo`0J0?ooo`03003o003oool0oooo06L0oooo
001d0?ooo`030?o0b`3oool0oooo0680oooo00<000000?ooo`3oool04`3o
ool30000oa40oooo00<0003o0?ooo`3oool0103oool5000000030?ooo`00
0000oooo00<0oooo00<000000?ooo`3oool09@3oool00`3o`</0oooo0?oo
o`0J0?ooo`03003o003oool0oooo06L0oooo001d0?ooo`030?o0b`3oool0
oooo0680oooo00<000000?ooo`3oool04P3oool30000oa80oooo00<0003o
0?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02@0oooo00<0ol3;0?ooo`3oool06P3oool00`00o`00oooo0?ooo`1W
0?ooo`00M03oool00`3o`</0oooo0?ooo`1R0?ooo`030000003oool0oooo
0140oooo0`000?lD0?ooo`030000o`3oool0oooo00T0oooo1`00000W0?oo
o`030?o0b`3oool0oooo01X0oooo00<00?l00?ooo`3oool0IP3oool007@0
oooo00<0ol3;0?ooo`3oool0HP3oool00`000000oooo0?ooo`0@0?ooo`<0
003o5@3oool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool09@3oool00`3o`</0oooo0?ooo`0J0?ooo`03
003o003oool0oooo06H0oooo001c0?ooo`030?o0b`3oool0oooo06<0oooo
00<000000?ooo`3oool03`3oool30000oaL0oooo00<0003o0?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo
00<0ol3;0?ooo`3oool06P3oool00`00o`00oooo0?ooo`1V0?ooo`00L`3o
ool00`3o`</0oooo0?ooo`1S0?ooo`030000003oool0oooo00h0oooo0`00
0?lH0?ooo`030000o`3oool0oooo00X0oooo1000000X0?ooo`030?o0b`3o
ool0oooo01X0oooo00<00?l00?ooo`3oool0IP3oool007<0oooo00<0ol3;
0?ooo`3oool0H`3oool00`000000oooo0?ooo`0=0?ooo`<0003o6P3oool0
0`000?l0oooo0?ooo`0e0?ooo`030?o0b`3oool0oooo01X0oooo00<00?l0
0?ooo`3oool0IP3oool007<0oooo00<0ol3;0?ooo`3oool0H`3oool00`00
0000oooo0?ooo`0<0?ooo`<0003o6`3oool00`000?l0oooo0?ooo`0f0?oo
o`030?o0b`3oool0oooo01T0oooo00<00?l00?ooo`3oool0IP3oool007<0
oooo00<0ol3;0?ooo`3oool0H`3oool00`000000oooo0?ooo`0;0?ooo`<0
003o7@3oool00`000?l0oooo0?ooo`0e0?ooo`030?o0b`3oool0oooo01X0
oooo00<00?l00?ooo`3oool0I@3oool00780oooo00<0ol3;0?ooo`3oool0
I03oool00`000000oooo0?ooo`0:0?ooo`<0003o7P3oool00`000?l0oooo
0?ooo`0e0?ooo`030?o0b`3oool0oooo01X0oooo00<00?l00?ooo`3oool0
I@3oool00780oooo00<0ol3;0?ooo`3oool0I03oool00`000000oooo0?oo
o`090?ooo`<0003o7`3oool00`000?l0oooo0?ooo`0e0?ooo`030?o0b`3o
ool0oooo01X0oooo00<00?l00?ooo`3oool0I@3oool00780oooo00<0ol3;
0000000000000`00001Q0?ooo`030000003oool0oooo00P0oooo0`000?lP
0?ooo`030000o`3oool0oooo03D0oooo00<0ol3;0?ooo`3oool06P3oool0
0`00o`00oooo0?ooo`1U0?ooo`00LP3oool0103o`</0oooo0?ooo`00001S
0?ooo`030000003oool0oooo00L0oooo0`000?lQ0?ooo`030000o`3oool0
oooo03D0oooo00<0ol3;0?ooo`3oool00P3oool5000001<0oooo00<00?l0
0?ooo`3oool0I@3oool00780oooo00@0ol3;0?ooo`3oool00000H`3oool0
0`000000oooo0?ooo`060?ooo`<0003o8`3oool00`000?l0oooo0?ooo`0d
0?ooo`030?o0b`3oool0oooo00@0oooo00<000000?ooo`3oool04`3oool0
0`00o`00oooo0?ooo`1U0?ooo`00K@3oool4000000050?ooo`3o`</0oooo
0?ooo`000000H`3oool00`000000oooo0?ooo`050?ooo`<0003o903oool0
0`000?l0oooo0?ooo`0e0?ooo`030?o0b`3oool0oooo00<0oooo00<00000
0?ooo`3oool04`3oool00`00o`00oooo0?ooo`1U0?ooo`00LP3oool0103o
`</0oooo0?ooo`00001S0?ooo`030000003oool0oooo00@0oooo0`000?lU
0?ooo`030000o`3oool0oooo03D0oooo00<0ol3;0?ooo`3oool00`3oool0
0`000000oooo0?ooo`0C0?ooo`03003o003oool0oooo06D0oooo001b0?oo
o`040?o0b`3oool00000000006<0oooo00<000000?ooo`3oool00`3oool3
0000obH0oooo00<0003o0?ooo`3oool0=@3oool00`3o`</0oooo0?ooo`03
0?ooo`030000003oool0oooo01<0oooo00<00?l00?ooo`3oool0I@3oool0
0780oooo00<0ol3;0?ooo`3oool0I03oool00`000000oooo0?ooo`020?oo
o`<0003o9`3oool00`000?l0oooo0?ooo`0e0?ooo`030?o0b`3oool0oooo
0080oooo0P00000E0?ooo`03003o003oool0oooo06D0oooo001b0?ooo`03
0?o0b`3oool0oooo06@0oooo00@000000?ooo`3oool0oooo0`000?lY0?oo
o`030000o`3oool0oooo03@0oooo00<0ol3;0?ooo`3oool06@3oool00`00
o`00oooo0?ooo`1U0?ooo`00LP3oool00`3o`</0oooo0?ooo`1T0?ooo`03
0000003oool0oooo00<0003o:P3oool00`000?l0oooo0?ooo`0d0?ooo`03
0?o0b`3oool0oooo01T0oooo00<00?l00?ooo`3oool0I@3oool00780oooo
00<0ol3;0?ooo`3oool0I03oool00`000000oooo0000o`020000ob/0oooo
00<0003o0?ooo`3oool0=03oool00`3o`</0oooo0?ooo`0I0?ooo`03003o
003oool0oooo06D0oooo001b0?ooo`030?o0b`3oool0oooo06@0oooo00@0
00000000o`000?l0003o;03oool00`000?l0oooo0?ooo`0d0?ooo`030?o0
b`3oool0oooo01T0oooo00<00?l00?ooo`3oool07@3oool2000000030?oo
o`000000000004<0oooo001b0?ooo`030?o0b`3oool0oooo06@0oooo0`00
0?l]0?ooo`030000o`3oool0oooo03@0oooo00<0ol3;0?ooo`3oool06@3o
ool00`00o`00oooo0?ooo`0N0?ooo`030000003oool0000004@0oooo001b
0?ooo`030?o0b`000000000006<000000`000?l^000000030000o`000000
000003@0000000<0ol3;0000000000006@0000000`00o`0000000000000F
000000T0oooo00<000000?ooo`3oool0@`3oool00780oooo00<0ol3;0?oo
o`3oool0I03oool00`000?l0o`000?ooo`0]0?ooo`030?l0003oool0oooo
03@0oooo00<0ol3;0?ooo`3oool0>@3oool2000000030?ooo`0000000000
04<0oooo001b0?ooo`030?o0b`3oool0oooo06@0oooo00<000000?ooo`3o
0000;@3oool00`3o0000oooo0?ooo`0d0?ooo`030?o0b`3oool0oooo0840
oooo001b0?ooo`030?o0b`3oool0oooo06@0oooo00@000000?ooo`3oool0
o`00;03oool00`3o0000oooo0?ooo`0d0?ooo`030?o0b`3oool0oooo0840
oooo001b0?ooo`030?o0b`3oool0oooo06@0oooo00D000000?ooo`3oool0
oooo0?l0000[0?ooo`030?l0003oool0oooo03@0oooo00<0ol3;0?ooo`3o
ool0P@3oool00780oooo00<0ol3;0?ooo`3oool0I03oool00`000000oooo
0?ooo`020?ooo`030?l0003oool0oooo02P0oooo00<0o`000?ooo`3oool0
=03oool00`3o`</0oooo0?ooo`210?ooo`00LP3oool00`3o`</0oooo0?oo
o`1T0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool09P3o
ool00`3o0000oooo0?ooo`0e0?ooo`030?o0b`3oool0oooo0840oooo001b
0?ooo`030?o0b`3oool0oooo06@0oooo00<000000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo03D0oooo00<0ol3;
0?ooo`3oool0P@3oool00780oooo00<0ol3;0?ooo`3oool0I03oool00`00
0000oooo0?ooo`050?ooo`030?l0003oool0oooo02@0oooo00<0o`000?oo
o`3oool0=@3oool00`3o`</0oooo0?ooo`210?ooo`00LP3oool00`3o`</0
oooo0?ooo`1T0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3o
ool08`3oool00`3o0000oooo0?ooo`0d0?ooo`030?o0b`3oool0oooo0880
oooo001b0?ooo`030?o0b`3oool0oooo06@0oooo00<000000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo03D0oooo
00<0ol3;0?ooo`3oool0PP3oool00780oooo00<0ol3;0?ooo`3oool0I03o
ool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo0200oooo00<0
o`000?ooo`3oool0=@3oool00`3o`</0oooo0?ooo`220?ooo`00LP3oool0
0`3o`</0oooo0?ooo`1T0?ooo`030000003oool0oooo00T0oooo00<0o`00
0?ooo`3oool07`3oool00`3o0000oooo0?ooo`0e0?ooo`030?o0b`3oool0
oooo0880oooo001b0?ooo`030?o0b`3oool0oooo06@0oooo00<000000?oo
o`3oool02P3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo
03D0oooo00<0ol3;0?ooo`3oool0PP3oool007<0oooo00<0ol3;0?ooo`3o
ool0H`3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo01d0
oooo00<0o`000?ooo`3oool0=@3oool00`3o`</0oooo0?ooo`220?ooo`00
L`3oool00`3o`</0oooo0?ooo`1S0?ooo`030000003oool0oooo00`0oooo
00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0f0?ooo`030?o0
b`3oool0oooo0880oooo001c0?ooo`030?o0b`3oool0oooo06<0oooo00<0
00000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003o
ool0oooo03H0oooo00<0ol3;0?ooo`3oool0PP3oool007<0oooo00<0ol3;
0?ooo`3oool0H`3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0
oooo01P0oooo00<0o`000?ooo`3oool0=P3oool00`3o`</0oooo0?ooo`23
0?ooo`00L`3oool00`3o`</0oooo0?ooo`1S0?ooo`030000003oool0oooo
00l0oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0f0?oo
o`030?o0b`3oool0oooo08<0oooo001c0?ooo`030?o0b`3oool0oooo06<0
oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`0E0?ooo`03
0?l0003oool0oooo03L0oooo00<0ol3;0?ooo`3oool0P`3oool007@0oooo
00<0ol3;0?ooo`3oool0HP3oool00`000000oooo0?ooo`0A0?ooo`030?l0
003oool0oooo01@0oooo00<0o`000?ooo`3oool0=`3oool00`3o`</0oooo
0?ooo`230?ooo`00M03oool00`3o`</0oooo0?ooo`1R0?ooo`030000003o
ool0oooo0180oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?oo
o`040?ooo`@00000<03oool00`3o`</0oooo0?ooo`230?ooo`00M03oool0
0`3o`</0oooo0?ooo`1R0?ooo`030000003oool0oooo01<0oooo00<0o`00
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0;03oool00`3o`</0oooo0?ooo`24
0?ooo`00M03oool00`3o`</0oooo0?ooo`1R0?ooo`030000003oool0oooo
01@0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0;03oool00`3o
`</0oooo0?ooo`240?ooo`00M03oool00`3o`</0oooo0?ooo`1R0?ooo`03
0000003oool0oooo01D0oooo00<0o`000?ooo`3oool03P3oool00`3o0000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0:`3oool00`3o`</0oooo0?ooo`240?ooo`00M@3oool00`3o`</0oooo
0?ooo`1Q0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0
303oool00`3o0000oooo0?ooo`050?ooo`L00000;@3oool00`3o`</0oooo
0?ooo`240?ooo`00M@3oool00`3o`</0oooo0?ooo`1Q0?ooo`030000003o
ool0oooo01L0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:`3o
ool00`3o`</0oooo0?ooo`240?ooo`00M@3oool00`3o`</0oooo0?ooo`1Q
0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0:P3oool00`3o`</0oooo0?ooo`250?ooo`00M@3oool00`3o
`</0oooo0?ooo`1Q0?ooo`030000003oool0oooo01T0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`@00000;@3oool00`3o
`</0oooo0?ooo`250?ooo`00M@3oool00`3o`</0oooo0?ooo`1Q0?ooo`03
0000003oool0oooo01X0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`0j0?ooo`030?o0b`3oool0oooo08H0oooo001f0?ooo`030?o0
b`3oool0oooo0600oooo00<000000?ooo`3oool06`3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo03X0oooo00<0ol3;0?ooo`3oool0
QP3oool007H0oooo00<0ol3;0?ooo`3oool0H03oool00`000000oooo0?oo
o`0L0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0>`3o
ool00`3o`</0oooo0?ooo`260?ooo`00M`3oool00`3o`</0oooo0?ooo`1O
0?ooo`030000003oool0oooo01d0oooo00@0o`000?ooo`3oool0o`00?P3o
ool00`3o`</0oooo0?ooo`260?ooo`00M`3oool00`3o`</0oooo0?ooo`1O
0?ooo`030000003oool0oooo01h0oooo0P3o000o0?ooo`030?o0b`3oool0
oooo08H0oooo001h0?ooo`030?o0b`3oool0oooo05h0oooo00<000000?oo
o`3oool07`3oool00`3o0000oooo0?ooo`0l0?ooo`030?o0b`3oool0oooo
08L0oooo001h0?ooo`030?o0b`3oool0oooo05h0oooo00<000000?ooo`3o
ool0803oool00`3o0000oooo0?ooo`0k0?ooo`030?o0b`3oool0oooo08L0
oooo001h0?ooo`030?o0b`3oool0oooo05h0oooo00<000000?ooo`3oool0
8@3oool00`3o0000oooo0?ooo`0i0?ooo`030?o0b`3oool0oooo08P0oooo
001i0?ooo`030?o0b`3oool0oooo05d0oooo00<000000?ooo`3oool08P3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo03<0oooo00<0
ol3;0?ooo`3oool0R03oool007T0oooo00<0ol3;0?ooo`3oool0G@3oool0
0`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo00<0o`00=03oool0
0`3o`</0oooo0?ooo`280?ooo`00NP3oool00`3o`</0oooo0?ooo`1L0?oo
o`030000003oool0oooo02@0oooo1@3o000c0?ooo`030?o0b`3oool0oooo
08T0oooo001j0?ooo`030?o0b`3oool0oooo05`0oooo00<000000?ooo`3o
ool08`3oool70?l00380oooo00<0ol3;0?ooo`3oool0R@3oool007X0oooo
00<0ol3;0?ooo`3oool0G03oool00`000000oooo0?ooo`0R0?ooo`P0o`00
<@3oool00`3o`</0oooo0?ooo`2:0?ooo`00N`3oool00`3o`</0oooo0?oo
o`1K0?ooo`030000003oool0oooo02<0oooo203o000`0?ooo`030?o0b`3o
ool0oooo08X0oooo001k0?ooo`030?o0b`3oool0oooo05/0oooo00<00000
0?ooo`3oool09@3oool60?l002l0oooo00<0ol3;0?ooo`3oool0R`3oool0
07`0oooo00<0ol3;0?ooo`3oool0FP3oool00`000000oooo0?ooo`0V0?oo
o`H0o`00;P3oool00`3o`</0oooo0?ooo`2;0?ooo`00O03oool00`3o`</0
oooo0?ooo`1J0?ooo`030000003oool0oooo02P0oooo103o000^0?ooo`03
0?o0b`3oool0oooo08/0oooo001m0?ooo`030?o0b`3oool0oooo05T0oooo
00<000000?ooo`3oool0:P3oool50?l002X0oooo00<0ol3;0?ooo`3oool0
S03oool007d0oooo00<0ol3;0?ooo`3oool0F@3oool00`000000oooo0?oo
o`0[0?ooo`D0o`00:@3oool00`3o`</0oooo0?ooo`2<0?ooo`00O@3oool0
0`3o`</0oooo0?ooo`1I0?ooo`030000003oool0oooo02/0oooo1P3o000W
0?ooo`030?o0b`3oool0oooo08d0oooo001n0?ooo`030?o0b`3oool0oooo
05P0oooo00<000000?ooo`3oool0:`3oool60?l002H0oooo00<0ol3;0?oo
o`3oool0SP3oool007h0oooo00<0ol3;0?ooo`3oool0F03oool00`000000
oooo0?ooo`0/0?ooo`@0o`009P3oool00`3o`</0oooo0?ooo`2?0?ooo`00
O`3oool00`3o`</0oooo0?ooo`1G0?ooo`030000003oool0oooo02d0oooo
0P3o000W0?ooo`030?o0b`3oool0oooo08l0oooo00200?ooo`030?o0b`3o
ool0oooo05H0oooo00<000000?ooo`3oool0E@3oool00`3o`</0oooo0?oo
o`2@0?ooo`00P@3oool00`3o`</0oooo0?ooo`1E0?ooo`030000003oool0
oooo05D0oooo00<0ol3;0?ooo`3oool0T03oool00840oooo00<0ol3;0?oo
o`3oool0E@3oool00`000000oooo0?ooo`1D0?ooo`030?o0b`3oool0oooo
0940oooo00220?ooo`030?o0b`3oool0oooo05@0oooo00<000000?ooo`3o
ool0E03oool00`3o`</0oooo0?ooo`2A0?ooo`00PP3oool00`3o`</0oooo
0?ooo`1D0?ooo`030000003oool0oooo05<0oooo00<0ol3;0?ooo`3oool0
TP3oool00880oooo00<0ol3;0?ooo`3oool0E03oool00`000000oooo0?oo
o`0[0?ooo`D000008P3oool00`3o`</0oooo0?ooo`2C0?ooo`00P`3oool0
0`3o`</0oooo0?ooo`1C0?ooo`030000003oool0oooo02/0oooo00D00000
0?ooo`3oool0oooo0000000R0?ooo`030?o0b`3oool0oooo09<0oooo0024
0?ooo`030?o0b`3oool0oooo0580oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0R0?ooo`030?o0b`3oool0oooo09@0oooo00250?oo
o`030?o0b`3oool0oooo0540oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0Q0?ooo`030?o0b`3oool0oooo09@0oooo00250?ooo`03
0?o0b`3oool0oooo0540oooo00<000000?ooo`3oool0:`3oool010000000
oooo0?ooo`00000Q0?ooo`030?o0b`3oool0oooo09D0oooo00260?ooo`03
0?o0b`3oool0oooo0500oooo00<000000?ooo`3oool0:`3oool5000001l0
oooo00<0ol3;0?ooo`3oool0UP3oool008L0oooo00<0ol3;0?ooo`3oool0
C`3oool00`000000oooo0?ooo`1>0?ooo`030?o0b`3oool0oooo09L0oooo
00280?ooo`030?o0b`3oool0oooo04h0oooo00<000000?ooo`3oool0C@3o
ool00`3o`</0oooo0?ooo`2H0?ooo`00R@3oool00`3o`</0oooo0?ooo`1=
0?ooo`030000003oool0oooo04`0oooo00<0ol3;0?ooo`3oool0V@3oool0
08X0oooo00<0ol3;0?ooo`3oool0C03oool00`000000oooo0?ooo`1<0?oo
o`030?o0b`3oool0oooo09T0oooo002:0?ooo`030?o0b`3oool0oooo04`0
oooo00<000000?ooo`3oool0B`3oool00`3o`</0oooo0?ooo`2J0?ooo`00
R`3oool00`3o`</0oooo0?ooo`1;0?ooo`030000003oool0oooo04X0oooo
00<0ol3;0?ooo`3oool0V`3oool008`0oooo00<0ol3;0?ooo`3oool0BP3o
ool00`000000oooo0?ooo`190?ooo`030?o0b`3oool0oooo09`0oooo002=
0?ooo`030?o0b`3oool0oooo04T0oooo00<000000?ooo`3oool0B03oool0
0`3o`</0oooo0?ooo`2M0?ooo`00SP3oool00`3o`</0oooo0?ooo`180?oo
o`030000003oool0oooo04L0oooo00<0ol3;0?ooo`3oool0WP3oool008l0
oooo00<0ol3;0?ooo`3oool0A`3oool00`000000oooo0?ooo`170?ooo`03
0?o0b`3oool0oooo09h0oooo002@0?ooo`030?o0b`3oool0oooo04H0oooo
00<000000?ooo`3oool0AP3oool00`3o`</0oooo0?ooo`2O0?ooo`00T@3o
ool00`3o`</0oooo0?ooo`150?ooo`030000003oool0oooo04D0oooo00<0
ol3;0?ooo`3oool0X03oool00980oooo0P3o`<]50?ooo`030000003oool0
oooo04<0oooo0P3o`<^S0?ooo`00T`3oool00`3o`</0oooo0?ooo`130?oo
o`030000003oool0oooo0480oooo00<0ol3;0?ooo`3oool0X`3oool009@0
oooo00<0ol3;0?ooo`3oool0@P3oool00`000000oooo0?ooo`110?ooo`03
0?o0b`3oool0oooo0:@0oooo002E0?ooo`030?o0b`3oool0oooo0440oooo
00<000000?ooo`3oool0@03oool00`3o`</0oooo0?ooo`2U0?ooo`00UP3o
ool00`3o`</0oooo0?ooo`100?ooo`030000003oool0oooo03l0oooo00<0
ol3;0?ooo`3oool0YP3oool009L0oooo0P3o`<]00?ooo`030000003oool0
oooo03d0oooo0P3o`<^Y0?ooo`00V@3oool00`3o`</0oooo0?ooo`0m0?oo
o`030000003oool0oooo03`0oooo00<0ol3;0?ooo`3oool0Z@3oool009X0
oooo00<0ol3;0?ooo`3oool0?03oool00`000000oooo0?ooo`0k0?ooo`03
0?o0b`3oool0oooo0:X0oooo002K0?ooo`80ol3;?03oool00`000000oooo
0?ooo`0i0?ooo`80ol3;[@3oool009d0oooo0P3o`</j0?ooo`030000003o
ool0oooo03P0oooo00<0ol3;0?ooo`3oool0[@3oool009l0oooo00<0ol3;
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0g0?ooo`030?o0b`3oool0
oooo0:h0oooo002P0?ooo`80ol3;=`3oool00`000000oooo0?ooo`0e0?oo
o`80ol3;/@3oool00:80oooo00<0ol3;0?ooo`3oool0=03oool00`000000
oooo0?ooo`0d0?ooo`030?o0b`3oool0oooo0;40oooo002S0?ooo`030?o0
b`3oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool20?o0bk@0oooo
002T0?ooo`80ol3;<`3oool00`000000oooo0?ooo`0`0?ooo`80ol3;]P3o
ool00:H0oooo0`3o`</`0?ooo`030000003oool0oooo02h0oooo0P3o`<^h
0?ooo`00Z@3oool20?o0bbh0oooo00<000000?ooo`3oool0;03oool20?o0
bkX0oooo002[0?ooo`030?o0b`3oool0oooo02/0oooo00<000000?ooo`3o
ool0:`3oool00`3o`</0oooo0?ooo`2j0?ooo`00[03oool00`3o`</0oooo
0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo0P3o`<^m0?ooo`00[@3o
ool30?o0bbT0oooo00<000000?ooo`3oool09`3oool20?o0bkl0oooo002`
0?ooo`80ol3;9`3oool00`000000oooo0?ooo`0T0?ooo`<0ol3;`@3oool0
0;80oooo0P3o`</U0?ooo`030000003oool0oooo0280oooo0P3o`<_40?oo
o`00]03oool50?o0bb00oooo00<000000?ooo`3oool07@3oool50?o0blH0
oooo002i0?ooo`<0ol3;7@3oool00`000000oooo0?ooo`0K0?ooo`80ol3;
b`3oool00;`0oooo0P3o`</K0?ooo`030000003oool0oooo01P0oooo0`3o
`<_=0?ooo`00_P3oool50?o0baH0oooo00<000000?ooo`3oool04`3oool5
0?o0bm00oooo00330?ooo`D0ol3;2@3oool5000000<0oooo00<000000?oo
o`3oool03P3oool50?o0bmD0oooo00380?ooo`P0ol3;0`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo203o`<_J0?ooo`00
d03ooolB0?o0bn80oooo003C0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0j03oool00=<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`3X0?ooo`00dP3oool2000000D0oooo00<000000?oo
o`3oool0j03oool00=T0oooo00<000000?ooo`3oool0j03oool00=T0oooo
00<000000?ooo`3oool0j03oool00=T0oooo00<000000?ooo`3oool0j03o
ool00=T0oooo00<000000?ooo`3oool0j03oool00=T0oooo00<000000?oo
o`3oool0j03oool00=T0oooo00<000000?ooo`3oool0j03oool00=T0oooo
00<000000?ooo`3oool0j03oool00?l0ooooa@3oool00?l0ooooa@3oool0
0?l0ooooa@3oool00?l0ooooa@3oool00?l0ooooa@3oool00?l0ooooa@3o
ool00?l0ooooa@3oool00?l0ooooa@3oool00=L0oooo0P00003[0?ooo`00
f03oool00`000000oooo0?ooo`3Y0?ooo`00f@3oool00`000000oooo0?oo
o`3X0?ooo`00f03oool00`000000oooo0000003Y0?ooo`00e`3oool01000
0000oooo0?ooo`00003Y0?ooo`00eP3oool3000000030?ooo`0000000000
0>P0oooo003o0?ooolD0oooo003o0?ooolD0oooo003o0?ooolD0oooo003o
0?ooolD0oooo003o0?ooolD0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{452, 272},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007>00011R000`400?l0
0000o`00003oo`3oooo?0?ooo`00o`3oooo?0?ooo`00o`3oooo?0?ooo`00
N03oool40000oe/0oooo0`00003d0?ooo`00M`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo05T0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0240oooo001g0?ooo`H0003oF`3oool00`000000oooo0?ooo`15
0?ooo`8000004`3oool200000380oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0240oooo001/0?oo
o`@0003o0`3oool90000o`<0oooo2@000?l20?ooo`<0003o1P3oool40000
o`030?ooo`000?l0003o0080oooo10000?l0103oool0003o0000o`000?l9
0?ooo`<000000`3oool2000000030?ooo`00000000000080oooo0`000000
0`3oool0000000000002000000040?ooo`00000000000?ooo`<000000P3o
ool00`000000oooo0?ooo`020?ooo`8000001P3oool010000000oooo0000
000000030?ooo`<000000P3oool300000080oooo0`000000103oool00000
0000003oool3000000040?ooo`000000000000000080oooo0`0000000`3o
ool0000000000003000000H0oooo0`0000020?ooo`<00000203oool50000
00@0oooo00<000000?ooo`3oool01P3oool5000000L0oooo00<000000?oo
o`3oool01P3oool7000000040?ooo`00000000000?ooo`D000001`3oool5
000000d0oooo0P0000090?ooo`040000003oool0oooo000000<0oooo0`00
0000103oool000000000003oool200000080oooo0`0000000`3oool00000
0000000;0?ooo`030000003oool0oooo00D0oooo1@0000070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool5000000@0oooo
00<000000?ooo`3oool00P3oool006d0oooo0P000?l50?ooo`80003o00<0
oooo0000o`3oool01@3oool20000o`030?ooo`000?l0003o0080oooo0P00
0?l20?ooo`80003o0P3oool00`000?l0oooo0?ooo`040?ooo`80003o0P3o
ool20000o`<0oooo0P000?l20?ooo`80003o00<0oooo0000o`3oool0203o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo000000020?ooo`040000003oool0oooo0000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0
oooo000000D0oooo0P0000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`070?ooo`050000003oool0oooo0?ooo`000000103oool2000000L0oooo
00D000000?ooo`3oool0oooo000000070?ooo`8000001P3oool010000000
oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
603oool010000000oooo0?ooo`0000040?ooo`060000003oool0oooo0000
003oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`3oool02@3oool2000000X0oooo
00<000000?ooo`3oool02@3oool006d0oooo0P000?l50?ooo`80003o0P3o
ool30000o`<0oooo0P000?l00`3oool0003o0000o`020?ooo`80003o0P3o
ool20000o`T0oooo0P000?l70?ooo`80003o1P3oool00`000?l0oooo0?oo
o`060?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000020?ooo`040000003oool0oooo000000<0
oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0
oooo00H0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo
00@000000?ooo`3oool0oooo0P0000020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo0?ooo`800000103oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0
00000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0H0?ooo`060000003oool0
00000000003oool000000`3oool01P000000oooo0?ooo`000000oooo0000
00D0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool2
000000P0oooo00<000000?ooo`3oool02@3oool006d0oooo0P000?l00`3o
ool0003o0?ooo`020?ooo`80003o00@0oooo0000o`000?l0oooo0P000?l2
0?ooo`80003o00<0oooo0000o`000?l00P3oool20000o`80oooo1@000?l6
0?ooo`80003o1`3oool20000o`D0oooo0P000?l80?ooo`040000003oool0
oooo000000<0oooo100000020?ooo`030000003oool0oooo00<000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`000000
0P3oool4000000D0oooo00L000000?ooo`3oool0oooo0000003oool00000
00<0oooo00@000000?ooo`0000000000103oool010000000oooo0?ooo`00
00030?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0000000000060?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0403oool300000080oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool05`3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00D000000?ooo`3oool000000?ooo`0400000080oooo00@000000?oo
o`3oool00000303oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02@3oool2000000X0oooo00<00000
0?ooo`3oool02@3oool006d0oooo10000?l30?ooo`80003o00@0oooo0000
o`000?l0oooo0P000?l20?ooo`80003o00<0oooo0000o`000?l00P3oool2
0000o`050?ooo`000?l0003o0000o`3oool00P000?l60?ooo`80003o1`3o
ool20000o`80oooo1@000?l80?ooo`@000000`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool000000080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo000000030?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00`3oool200000080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`040000003oool0oooo0000
0080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P000000103oool000000?ooo`0000020?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool000003P3oool01000
0000oooo0?ooo`00000@0?ooo`040000003oool0oooo00000080oooo0P00
0000103oool000000?ooo`0000020?ooo`800000203oool010000000oooo
0?ooo`00000H0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00P000000103oool000000?ooo`0000020?ooo`030000003oool0
oooo0080000000<0oooo0000003oool02`3oool00`000000oooo0?ooo`05
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo001]
0?ooo`80003o00@0oooo0000o`3oool0oooo0`000?l20?ooo`P0003o00@0
oooo0000o`000?l0oooo1@000?l0103oool0003o0000o`000?l70?ooo`80
003o1`3oool20000o`80oooo10000?l90?ooo`050000003oool0oooo0?oo
o`0000000`3oool2000000<0oooo00<000000?ooo`3oool00P0000020?oo
o`<0000000<0oooo0000000000000`0000020?ooo`80000000<0oooo0000
000000001@3oool2000000030?ooo`000000000000<0oooo0`0000030?oo
o`<0000000@0oooo000000000000oooo0`0000000`3oool0000000000002
0?ooo`<000000P3oool2000000030?ooo`000000oooo0080oooo0`000005
0?ooo`<000000P3oool3000000P0oooo1@00000=0?ooo`D00000403oool2
00000080oooo0P0000000`3oool000000?ooo`020?ooo`80000000<0oooo
0000003oool01`3oool5000000H0oooo1@00000;0?ooo`80000000D0oooo
00000000000000000?ooo`02000000040?ooo`000000oooo000000<0oooo
0P0000020?ooo`80000000<0oooo0000003oool0303oool00`000000oooo
0?ooo`050?ooo`D000001`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00T0oooo001]0?ooo`80003o9@3oool20000o`L0oooo0P00
0?l20?ooo`030000o`3oool0oooo00X0oooo00D000000?ooo`3oool0oooo
000000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool03@3oool400000080oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`090?ooo`00K@3o
ool20000o`<0oooo00@0003o0?ooo`000?l0003o7P3oool20000o`L0oooo
0P000?l30?ooo`<0003o2@3oool01@000000oooo0?ooo`3oool0000000P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo01h0oooo00@000000?ooo`3oool000005`3oool;0000
01T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0D0?ooo`8000002`3oool006`0oooo1`000?l00`3oool0
003o0000o`0M0?ooo`<0003o1P3oool30000o`<0oooo10000?l70?ooo`D0
0000203oool2000000/0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01/0oooo0`00000j0?ooo`80
00005@3oool00`000000oooo0?ooo`0D0?ooo`800000DP3oool00?l0oooo
I03oool00`000000oooo0?ooo`1X0?ooo`00o`3ooomS0?ooo`800000JP3o
ool00?l0ooooc`3oool00?l0ooooc`3oool00?l0ooooc`3oool00?l0oooo
c`3oool00?l0ooooc`3oool00?l0ooooc`3oool00?l0ooooc`3oool00?l0
ooooc`3oool00?l0ooooc`3oool00=@0oooo00<000000?ooo`3oool0m`3o
ool00=@0oooo00<000000?ooo`3oool0m`3oool00=@0oooo00<000000?oo
o`3oool0m`3oool00=@0oooo00<000000?ooo`3oool0m`3oool00=@0oooo
00<000000?ooo`3oool0S@3oool5000006D0oooo003D0?ooo`030000003o
ool0oooo08h0oooo00@000000?ooo`3oool00000I@3oool00=@0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`1U0?ooo`00c03oool5
000000<0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`1T
0?ooo`00cP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
08h0oooo00@000000?ooo`3oool00000I@3oool00<h0oooo00<000000?oo
o`3oool00`3oool20?o0b`030000003oool0oooo08`0oooo1@00001T0?oo
o`00aP3oool00`000000ol3;0?o0b`0;0?o0b`030000003oool0ol3;00/0
ol3;k03oool00<00oooo1`3o`</70?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02`3oool70?o0bnD0oooo002n0?ooo`80ol3;3@3o
ool2000000D0oooo00<000000?ooo`3oool04P3oool20?o0bn<0oooo002i
0?ooo`D0ol3;5P3oool00`000000oooo0?ooo`0D0?ooo`D0ol3;M03oool5
000006D0oooo002g0?ooo`80ol3;6`3oool00`000000oooo0?ooo`0I0?oo
o`80ol3;g03oool00;80oooo1@3o`</M0?ooo`030000003oool0oooo01/0
oooo1@3o`<_G0?ooo`00/03oool20?o0bb80oooo00<000000?ooo`3oool0
803oool20?o0bmD0oooo002^0?ooo`80ol3;903oool00`000000oooo0?oo
o`0R0?ooo`<0ol3;dP3oool00:/0oooo0`3o`</V0?ooo`030000003oool0
oooo02D0oooo0P3o`<_@0?ooo`00Z@3oool20?o0bbT0oooo00<000000?oo
o`3oool09`3oool20?o0blh0oooo002W0?ooo`80ol3;:`3oool00`000000
oooo0?ooo`0Y0?ooo`80ol3;c03oool00:D0oooo0P3o`</]0?ooo`030000
003oool0oooo02/0oooo0P3o`<_:0?ooo`00Y03oool00`3o`</0oooo0?oo
o`0]0?ooo`030000003oool0oooo02d0oooo00<0ol3;0?ooo`3oool0H@3o
ool20000of@0oooo002S0?ooo`030?o0b`3oool0oooo02h0oooo00<00000
0?ooo`3oool0;P3oool00`3o`</0oooo0?ooo`1L0?ooo`D0003oI@3oool0
0:40oooo0P3o`</a0?ooo`030000003oool0oooo02l0oooo0`3o`<]G0?oo
o`P0003oIP3oool009l0oooo0P3o`</c0?ooo`030000003oool0oooo0380
oooo0P3o`<]B0?ooo`X0003oI`3oool009h0oooo00<0ol3;0?ooo`3oool0
<`3oool00`000000oooo0?ooo`0d0?ooo`030?o0b`3oool0oooo04l0oooo
2@000?mX0?ooo`00W@3oool00`3o`</0oooo0?ooo`0d0?ooo`030000003o
ool0oooo03D0oooo00<0ol3;0?ooo`3oool0C`3oool70000ofT0oooo002K
0?ooo`80ol3;=`3oool00`000000oooo0?ooo`0f0?ooo`80ol3;C`3oool6
0000ofX0oooo002I0?ooo`80ol3;>@3oool00`000000oooo0?ooo`0h0?oo
o`80ol3;C03oool60000of/0oooo002H0?ooo`030?o0b`3oool0oooo03T0
oooo00<000000?ooo`3oool0>P3oool00`3o`</0oooo0?ooo`170?ooo`80
003o0P3oool30000of`0oooo002G0?ooo`030?o0b`3oool0oooo03X0oooo
00<000000?ooo`3oool0>`3oool00`3o`</0oooo0?ooo`150?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0J`3oool009H0oooo00<0
ol3;0?ooo`3oool0>`3oool00`000000oooo0?ooo`0k0?ooo`030?o0b`3o
ool0oooo04<0oooo0P000?md0?ooo`00U@3oool00`3o`</0oooo0?ooo`0l
0?ooo`030000003oool0oooo03`0oooo00<0ol3;0?ooo`3oool0@03oool2
0000ogH0oooo002C0?ooo`80ol3;?`3oool00`000000oooo0?ooo`0m0?oo
o`80ol3;?P3oool20000ogP0oooo002B0?ooo`030?o0b`3oool0oooo03l0
oooo00<000000?ooo`3oool0?`3oool00`3o`</0oooo0?ooo`0j0?ooo`03
0000o`3oool0oooo07P0oooo002A0?ooo`030?o0b`3oool0oooo0400oooo
00<000000?ooo`3oool0@03oool00`3o`</0oooo0?ooo`0g0?ooo`80003o
N`3oool008l0oooo0P3o`<]30?ooo`030000003oool0oooo0440oooo00<0
ol3;0?ooo`3oool0=03oool20000ogd0oooo002>0?ooo`030?o0b`3oool0
oooo04<0oooo00<000000?ooo`3oool0@P3oool00`3o`</0oooo0?ooo`0b
0?ooo`030000o`3oool0oooo07d0oooo002>0?ooo`030?o0b`3oool0oooo
04<0oooo00<000000?ooo`3oool0@`3oool20?o0bc00oooo0P000?n00?oo
o`00S@3oool00`3o`</0oooo0?ooo`140?ooo`030000003oool0oooo04@0
oooo00<0ol3;0?ooo`3oool0;03oool20000oh80oooo002<0?ooo`030?o0
b`3oool0oooo04D0oooo00<000000?ooo`3oool0A@3oool00`3o`</0oooo
0?ooo`0Y0?ooo`80003oQ03oool008/0oooo00<0ol3;0?ooo`3oool0AP3o
ool00`000000oooo0?ooo`160?ooo`030?o0b`3oool0oooo02L0oooo00<0
003o0?ooo`3oool0Q03oool008X0oooo00<0ol3;0?ooo`3oool0A`3oool0
0`000000oooo0?ooo`170?ooo`030?o0b`3oool0oooo02@0oooo0P000?n7
0?ooo`00R@3oool00`3o`</0oooo0?ooo`180?ooo`030000003oool0oooo
04P0oooo00<0ol3;0?ooo`3oool08@3oool20000ohT0oooo00290?ooo`03
0?o0b`3oool0oooo04P0oooo00<000000?ooo`3oool0B@3oool00`3o`</0
oooo0?ooo`0N0?ooo`80003oR`3oool008P0oooo00<0ol3;0?ooo`3oool0
B@3oool00`000000oooo0?ooo`190?ooo`030?o0b`3oool0oooo01d0oooo
00<0003o0?ooo`3oool0R`3oool008L0oooo00<0ol3;0?ooo`3oool0BP3o
ool00`000000oooo0?ooo`1:0?ooo`030?o0b`3oool0oooo01X0oooo0P00
0?n>0?ooo`00QP3oool00`3o`</0oooo0?ooo`1;0?ooo`030000003oool0
oooo04/0oooo00<0ol3;0?ooo`3oool05`3oool20000oi00oooo00260?oo
o`030?o0b`3oool0oooo04/0oooo00<000000?ooo`3oool0C03oool00`3o
`</0oooo0?ooo`0D0?ooo`80003o0P3oool00`000?l0oooo0?ooo`2=0?oo
o`00Q03oool20?o0bdh0oooo00<000000?ooo`3oool0C03oool00`3o`</0
oooo0?ooo`0C0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0S@3oool008@0oooo00<0ol3;0?ooo`3oool0C@3oool00`000000oooo
0?ooo`1=0?ooo`030?o0b`3oool0oooo0100oooo0P000?l60?ooo`030000
o`3oool0oooo08`0oooo00230?ooo`030?o0b`3oool0oooo04h0oooo00<0
00000?ooo`3oool0CP3oool00`3o`</0oooo0?ooo`0=0?ooo`80003o203o
ool00`000?l0oooo0?ooo`2<0?ooo`00P`3oool00`3o`</0oooo0?ooo`1>
0?ooo`030000003oool0oooo04l0oooo00<0ol3;0?ooo`3oool02P3oool2
0000o`X0oooo00<0003o0?ooo`3oool0S03oool00880oooo00<0ol3;0?oo
o`3oool0C`3oool00`000000oooo0?ooo`1?0?ooo`030?o0b`3oool0oooo
00T0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`2<0?oo
o`00P@3oool00`3o`</0oooo0?ooo`1@0?ooo`030000003oool0oooo0500
oooo00<0ol3;0?ooo`3oool01P3oool20000o`h0oooo00<0003o0?ooo`3o
ool0R`3oool00800oooo00<0ol3;0?ooo`3oool0D@3oool00`000000oooo
0?ooo`1@0?ooo`030?o0b`3oool0oooo00@0oooo0P000?lA0?ooo`030000
o`3oool0oooo08X0oooo00200?ooo`030?o0b`3oool0oooo0540oooo00<0
00000?ooo`3oool0D@3oool0103o`</0oooo0?ooo`3oool20000oa<0oooo
00<0003o0?ooo`3oool0RP3oool007l0oooo00<0ol3;0?ooo`3oool0DP3o
ool00`000000oooo0?ooo`1A0?ooo`040?o0b`3oool0oooo0000oaH0oooo
00<0003o0?ooo`3oool0R@3oool007l0oooo00<0ol3;0?ooo`3oool0DP3o
ool00`000000oooo0?ooo`1B0?ooo`80003o5`3oool00`000?l0oooo0?oo
o`290?ooo`00OP3oool00`3o`</0oooo0?ooo`1C0?ooo`030000003oool0
oooo0500oooo0P000?l00`3oool0ol3;0?ooo`0G0?ooo`030000o`3oool0
oooo08P0oooo001n0?ooo`030?o0b`3oool0oooo05<0oooo00<000000?oo
o`3oool0CP3oool20000o`@0oooo00<0ol3;0?ooo`3oool05@3oool00`00
0?l0oooo0?ooo`280?ooo`00O@3oool00`3o`</0oooo0?ooo`1D0?ooo`03
0000003oool0oooo02H0oooo1@00000R0?ooo`030000o`3oool0oooo00@0
oooo00<0ol3;0?ooo`3oool05P3oool00`000?l0oooo0?ooo`270?ooo`00
O03oool00`3o`</0oooo0?ooo`1E0?ooo`030000003oool0oooo02L0oooo
00@000000?ooo`3oool00000803oool20000o`P0oooo00<0ol3;0?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`270?ooo`00N`3oool00`3o`</0oooo
0?ooo`1F0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
7P3oool20000o`X0oooo00<0ol3;0?ooo`3oool05@3oool00`000?l0oooo
0?ooo`270?ooo`00N`3oool00`3o`</0oooo0?ooo`1F0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?oo
o`0;0?ooo`030?o0b`3oool0oooo01@0oooo00<0003o0?ooo`3oool0Q`3o
ool007X0oooo00<0ol3;0?ooo`3oool0E`3oool00`000000oooo0?ooo`0W
0?ooo`040000003oool0oooo000000H0oooo1@00000@0?ooo`80003o3P3o
ool00`3o`</0oooo0?ooo`0E0?ooo`030000o`3oool0oooo08H0oooo001j
0?ooo`030?o0b`3oool0oooo05L0oooo00<000000?ooo`3oool09`3oool5
000000030?ooo`0000000000008000000P3oool00`000000oooo0?ooo`0>
0?ooo`80003o4@3oool00`3o`</0oooo0?ooo`0E0?ooo`030000o`3oool0
oooo08D0oooo001j0?ooo`030?o0b`3oool0oooo05L0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0<0?ooo`80003o4`3oool00`3o
`</0oooo0?ooo`0E0?ooo`030000o`3oool0oooo08D0oooo001i0?ooo`03
0?o0b`3oool0oooo05P0oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo01<0oooo00<0ol3;0?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`250?ooo`00N@3oool00`3o`</0oooo
0?ooo`1H0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
2@3oool20000oaL0oooo00<0ol3;0?ooo`3oool0503oool00`000?l0oooo
0?ooo`250?ooo`00N03oool00`3o`</0oooo0?ooo`1I0?ooo`030000003o
ool0oooo0380oooo0P0000090?ooo`80003o6@3oool00`3o`</0oooo0?oo
o`0E0?ooo`030000o`3oool0oooo08@0oooo001h0?ooo`030?o0b`3oool0
oooo05T0oooo00<000000?ooo`3oool0>`3oool20000oa`0oooo00<0ol3;
0?ooo`3oool0503oool00`000?l0oooo0?ooo`0<0?ooo`@00000M03oool0
07L0oooo00<0ol3;0?ooo`3oool0FP3oool00`000000oooo0?ooo`0j0?oo
o`030000o`3oool0oooo01`0oooo00<0ol3;0?ooo`3oool05@3oool00`00
0?l0oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0L@3oool007L0oooo00<0ol3;0?ooo`3oool0FP3oool00`000000
oooo0?ooo`0h0?ooo`80003o803oool00`3o`</0oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo00@0oooo1@0000000`3oool000000?ooo`030?ooo`03
0000003oool0oooo0740oooo001g0?ooo`030?o0b`3oool0oooo05X0oooo
00<000000?ooo`3oool0=P3oool20000ob80oooo00<0ol3;0?ooo`3oool0
503oool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0L03oool007L0oooo00<0ol3;0?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0d0?ooo`80003o903oool00`3o`</0oooo0?oo
o`0D0?ooo`030000o`3oool0oooo00X0oooo1`00001b0?ooo`00M`3oool0
0`3o`</0oooo0?ooo`1J0?ooo`030000003oool0oooo02d0oooo0P00o`04
0?ooo`030000o`3oool0oooo02@0oooo00<0ol3;0?ooo`3oool05@3oool0
0`000?l0oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0L03oool007H0oooo00<0ol3;0?ooo`3oool0F`3oool00`00
0000oooo0?ooo`0/0?ooo`@00?l000<0oooo0000o`000?l09`3oool00`3o
`</0oooo0?ooo`0E0?ooo`030000o`3oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1`0?ooo`00MP3oool00`3o`</0
oooo0?ooo`1K0?ooo`030000003oool0oooo02/0oooo1P00o`0Z0?ooo`03
0?o0b`3oool0oooo01@0oooo00<0003o0?ooo`3oool02`3oool4000007<0
oooo001e0?ooo`030?o0b`3oool0oooo05`0oooo00<000000?ooo`3oool0
:`3oool6003o02X0oooo00<0ol3;0?ooo`3oool0503oool00`000?l0oooo
0?ooo`220?ooo`00M@3oool00`3o`</0oooo0?ooo`1L0?ooo`030000003o
ool0oooo02T0oooo1`00o`0/0?ooo`030?o0b`3oool0oooo01@0oooo00<0
003o0?ooo`3oool0P@3oool007D0oooo00<0ol3;0?ooo`3oool0G03oool0
0`000000oooo0?ooo`0U0?ooo`X00?l0;@3oool00`3o`</0oooo0?ooo`0D
0?ooo`030000o`3oool0oooo0840oooo001e0?ooo`030?o0b`3oool0oooo
05`0oooo00<000000?ooo`3oool08P3oool:003o0340oooo00<0ol3;0?oo
o`3oool04`3oool00`000?l0oooo0?ooo`210?ooo`00M@3oool00`3o`</0
oooo0?ooo`1L0?ooo`030000003oool0oooo0280oooo2@00o`0b0?ooo`03
0?o0b`3oool0oooo01<0oooo00<0003o0?ooo`3oool0P@3oool007@0oooo
00<0ol3;0?ooo`3oool0G@3oool00`000000oooo0?ooo`0S0?ooo`L00?l0
<`3oool00`3o`</0oooo0?ooo`0C0?ooo`030000o`3oool0oooo0840oooo
001d0?ooo`030?o0b`3oool0oooo05d0oooo00<000000?ooo`3oool08P3o
ool7003o03@0oooo00<0ol3;0?ooo`3oool0503oool00`000?l0oooo0?oo
o`200?ooo`00L`3oool00`3o`</0oooo0?ooo`1N0?ooo`030000003oool0
oooo0200oooo2000o`0e0?ooo`030?o0b`3oool0oooo01@0oooo00<0003o
0?ooo`3oool0P03oool007<0oooo00<0ol3;0?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0N0?ooo`D00?l000@0oooo003o0000o`000?l0=`3oool0
0`3o`</0oooo0?ooo`0C0?ooo`030000o`3oool0oooo0800oooo001c0?oo
o`030?o0b`3oool0oooo05h0oooo00<000000?ooo`3oool0703oool5003o
00@0oooo00<00?l00?ooo`3oool0=P3oool00`3o`</0oooo0?ooo`0C0?oo
o`030000o`3oool0oooo0800oooo001c0?ooo`030?o0b`3oool0oooo05h0
oooo00<000000?ooo`3oool06`3oool4003o03l0oooo00<0ol3;0?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`200?ooo`00L`3oool00`3o`</0oooo
0?ooo`1N0?ooo`030000003oool0oooo01T0oooo1000o`110?ooo`030?o0
b`3oool0oooo01<0oooo00<0003o0?ooo`3oool0P03oool007<0oooo00<0
ol3;0?ooo`3oool0GP3oool00`000000oooo0?ooo`0G0?ooo`D00?l0@P3o
ool00`3o`</0oooo0?ooo`0D0?ooo`030000o`3oool0oooo07l0oooo001c
0?ooo`030?o0b`3oool0oooo05h0oooo00<000000?ooo`3oool05@3oool5
003o04D0oooo00<0ol3;0?ooo`3oool04`3oool00`000?l0oooo0?ooo`1o
0?ooo`00L`3oool00`3o`</0oooo0?ooo`1N0?ooo`030000003oool0oooo
01@0oooo1000o`170?ooo`030?o0b`3oool0oooo01<0oooo00<0003o0?oo
o`3oool0O`3oool00780oooo00<0ol3;0?ooo`3oool0G`3oool00`000000
oooo0?ooo`0B0?ooo`@00?l0B@3oool00`3o`</0oooo0?ooo`0C0?ooo`03
0000o`3oool0oooo07l0oooo001b0?ooo`030?o0b`3oool0oooo05l0oooo
00<000000?ooo`3oool0403oool5003o00030?ooo`00o`00oooo04L0oooo
00<0ol3;0?ooo`3oool04`3oool00`000?l0oooo0?ooo`1o0?ooo`00LP3o
ool00`3o`</0000000000003000005`0oooo00<000000?ooo`3oool03P3o
ool5003o00@0oooo00<00?l00?ooo`3oool0203oool4000003T0oooo00<0
ol3;0?ooo`3oool00P3oool5000000`0oooo00<0003o0?ooo`3oool0O`3o
ool00780oooo00@0ol3;0?ooo`3oool00000GP3oool00`000000oooo0?oo
o`0=0?ooo`@00?l01P3oool00`00o`00oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0=P3oool00`3o`</0oooo0?oo
o`040?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool0O`3o
ool00780oooo00@0ol3;0?ooo`3oool00000GP3oool00`000000oooo0?oo
o`0;0?ooo`@00?l02@3oool00`00o`00oooo0?ooo`05000000030?ooo`00
0000oooo00<0oooo00<000000?ooo`3oool0=P3oool00`3o`</0oooo0?oo
o`040?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool0O`3o
ool006d0oooo100000001@3oool0ol3;0?ooo`3oool0000005h0oooo00<0
00000?ooo`3oool02@3oool5003o00X0oooo00<00?l00?ooo`3oool01P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03D0oooo00<0
ol3;0?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo07h0oooo001b0?ooo`040?o0b`3oool0oooo000005h0oooo00<0
00000?ooo`3oool01`3oool5003o00`0oooo00<00?l00?ooo`3oool01P3o
ool7000003L0oooo00<0ol3;0?ooo`3oool0103oool00`000000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo07h0oooo001b0?ooo`040?o0b`3oool0
0000000005h0oooo00<000000?ooo`3oool01P3oool4003o00h0oooo00<0
0?l00?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03D0oooo00<0ol3;0?ooo`3oool00`3oool2000000l0oooo00<0
003o0?ooo`3oool0OP3oool00780oooo00<0ol3;0?ooo`3oool0G`3oool0
0`000000oooo0?ooo`040?ooo`@00?l04@3oool00`00o`00oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=P3oool0
0`3o`</0oooo0?ooo`0C0?ooo`030000o`3oool0oooo07h0oooo001b0?oo
o`030?o0b`3oool0oooo05l0oooo00<000000?ooo`3oool00P3oool5003o
0180oooo00<00?l00?ooo`3oool01`3oool4000003T0oooo00<0ol3;0?oo
o`3oool04`3oool00`000?l0oooo0?ooo`1n0?ooo`00LP3oool00`3o`</0
oooo0?ooo`1O0?ooo`030000003oool0oooo00D00?l0503oool00`00o`00
oooo0?ooo`140?ooo`030?o0b`3oool0oooo01<0oooo00<0003o0?ooo`3o
ool0OP3oool00780oooo00<0ol3;0?ooo`3oool0G`3oool00`000000oooo
003o0003003o01H0oooo00<00?l00?ooo`3oool0A03oool00`3o`</0oooo
0?ooo`0C0?ooo`030000o`3oool0oooo07h0oooo001b0?ooo`030?o0b`3o
ool0oooo05l0oooo1000o`0H0?ooo`03003o003oool0oooo04@0oooo00<0
ol3;0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0P0?ooo`80000000<0
oooo000000000000F@3oool00780oooo00<0ol3;000000000000GP000004
003o01T0000000<00?l0000000000000A00000000`3o`</000000000000C
000000030000o`000000000001T00000203oool00`000000oooo0000001J
0?ooo`00LP3oool00`3o`</0oooo0?ooo`1O0?ooo`03003o003o0000o`00
0600oooo00<0ol3;0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0R0?oo
o`030000003oool0oooo05T0oooo001b0?ooo`030?o0b`3oool0oooo05l0
oooo00<000000?ooo`3oool00P3o001N0?ooo`030?o0b`3oool0oooo01<0
oooo00<0o`000?ooo`3oool0803oool2000000030?ooo`000000000005T0
oooo001b0?ooo`030?o0b`3oool0oooo05l0oooo00<000000?ooo`3oool0
0P3oool20?l005`0oooo00<0ol3;0?ooo`3oool04`3oool00`3o0000oooo
0?ooo`1n0?ooo`00LP3oool00`3o`</0oooo0?ooo`1O0?ooo`030000003o
ool0oooo00@0oooo00<0o`000?ooo`3oool0F03oool20?o0baD0oooo00<0
o`000?ooo`3oool0OP3oool00780oooo00<0ol3;0?ooo`3oool0G`3oool0
0`000000oooo0?ooo`050?ooo`80o`00F03oool20?o0baD0oooo00<0o`00
0?ooo`3oool0OP3oool00780oooo00<0ol3;0?ooo`3oool0G`3oool00`00
0000oooo0?ooo`070?ooo`80o`00EP3oool00`3o`</0oooo0?ooo`0D0?oo
o`030?l0003oool0oooo07h0oooo001b0?ooo`030?o0b`3oool0oooo05l0
oooo00<000000?ooo`3oool02@3oool20?l005@0oooo00<0ol3;0?ooo`3o
ool0503oool00`3o0000oooo0?ooo`1n0?ooo`00LP3oool00`3o`</0oooo
0?ooo`1O0?ooo`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool0
D@3oool00`3o`</0oooo0?ooo`0D0?ooo`030?l0003oool0oooo07h0oooo
001b0?ooo`030?o0b`3oool0oooo05l0oooo00<000000?ooo`3oool0303o
ool20?l00540oooo00<0ol3;0?ooo`3oool04`3oool00`3o0000oooo0?oo
o`1o0?ooo`00LP3oool00`3o`</0oooo0?ooo`1O0?ooo`030000003oool0
oooo00h0oooo0P3o001?0?ooo`030?o0b`3oool0oooo01<0oooo00<0o`00
0?ooo`3oool0O`3oool00780oooo00<0ol3;0?ooo`3oool0G`3oool00`00
0000oooo0?ooo`0@0?ooo`80o`00C@3oool00`3o`</0oooo0?ooo`0C0?oo
o`030?l0003oool0oooo07l0oooo001b0?ooo`030?o0b`3oool0oooo05l0
oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`1:0?ooo`03
0?o0b`3oool0oooo01<0oooo00<0o`000?ooo`3oool0O`3oool00780oooo
00<0ol3;0?ooo`3oool0G`3oool00`000000oooo0?ooo`0C0?ooo`80o`00
BP3oool00`3o`</0oooo0?ooo`0C0?ooo`030?l0003oool0oooo07l0oooo
001c0?ooo`030?o0b`3oool0oooo05h0oooo00<000000?ooo`3oool05@3o
ool20?l004P0oooo00<0ol3;0?ooo`3oool04`3oool00`3o0000oooo0?oo
o`1o0?ooo`00L`3oool00`3o`</0oooo0?ooo`1N0?ooo`030000003oool0
oooo01L0oooo00<0o`000?ooo`3oool0A@3oool00`3o`</0oooo0?ooo`0C
0?ooo`030?l0003oool0oooo07l0oooo001c0?ooo`030?o0b`3oool0oooo
05h0oooo00<000000?ooo`3oool0603oool20?l004@0oooo00<0ol3;0?oo
o`3oool0503oool00`3o0000oooo0?ooo`1o0?ooo`00L`3oool00`3o`</0
oooo0?ooo`1N0?ooo`030000003oool0oooo01X0oooo0P3o00120?ooo`03
0?o0b`3oool0oooo01<0oooo00<0o`000?ooo`3oool0P03oool007<0oooo
00<0ol3;0?ooo`3oool0GP3oool00`000000oooo0?ooo`0L0?ooo`80o`00
@03oool00`3o`</0oooo0?ooo`0C0?ooo`030?l0003oool0oooo0800oooo
001c0?ooo`030?o0b`3oool0oooo05h0oooo00<000000?ooo`3oool07P3o
ool00`3o0000oooo0?ooo`0m0?ooo`030?o0b`3oool0oooo01<0oooo00<0
o`000?ooo`3oool0P03oool007<0oooo00<0ol3;0?ooo`3oool0GP3oool0
0`000000oooo0?ooo`0O0?ooo`80o`00?@3oool00`3o`</0oooo0?ooo`0C
0?ooo`030?l0003oool0oooo0800oooo001c0?ooo`030?o0b`3oool0oooo
05h0oooo00<000000?ooo`3oool08@3oool20?l003X0oooo00<0ol3;0?oo
o`3oool0503oool00`3o0000oooo0?ooo`200?ooo`00M03oool00`3o`</0
oooo0?ooo`1M0?ooo`030000003oool0oooo02<0oooo0P3o000h0?ooo`03
0?o0b`3oool0oooo01@0oooo00<0o`000?ooo`3oool0P03oool007@0oooo
00<0ol3;0?ooo`3oool0G@3oool00`000000oooo0?ooo`0U0?ooo`030?l0
003oool0oooo03D0oooo00<0ol3;0?ooo`3oool04`3oool00`3o0000oooo
0?ooo`210?ooo`00M@3oool00`3o`</0oooo0?ooo`1L0?ooo`030000003o
ool0oooo02H0oooo0P3o000e0?ooo`030?o0b`3oool0oooo01<0oooo00<0
o`000?ooo`3oool0P@3oool007D0oooo00<0ol3;0?ooo`3oool0G03oool0
0`000000oooo0?ooo`0X0?ooo`80o`00<`3oool00`3o`</0oooo0?ooo`0C
0?ooo`030?l0003oool0oooo0840oooo001e0?ooo`030?o0b`3oool0oooo
05`0oooo00<000000?ooo`3oool0:P3oool20?l00300oooo00<0ol3;0?oo
o`3oool0503oool00`3o0000oooo0?ooo`210?ooo`00M@3oool00`3o`</0
oooo0?ooo`1L0?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`3o
ool0;@3oool00`3o`</0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0840
oooo001e0?ooo`030?o0b`3oool0oooo05`0oooo00<000000?ooo`3oool0
;@3oool20?l002`0oooo00<0ol3;0?ooo`3oool0503oool00`3o0000oooo
0?ooo`220?ooo`00MP3oool00`3o`</0oooo0?ooo`1K0?ooo`030000003o
ool0oooo02l0oooo0P3o000Z0?ooo`030?o0b`3oool0oooo01@0oooo00<0
o`000?ooo`3oool0PP3oool007H0oooo00<0ol3;0?ooo`3oool0F`3oool0
0`000000oooo0?ooo`0a0?ooo`80o`009`3oool00`3o`</0oooo0?ooo`0E
0?ooo`030?l0003oool0oooo0880oooo001g0?ooo`030?o0b`3oool0oooo
05X0oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0T0?oo
o`030?o0b`3oool0oooo01D0oooo00<0o`000?ooo`3oool0PP3oool007L0
oooo00<0ol3;0?ooo`3oool0FP3oool00`000000oooo0?ooo`0d0?ooo`80
o`00903oool00`3o`</0oooo0?ooo`0D0?ooo`030?l0003oool0oooo08<0
oooo001g0?ooo`030?o0b`3oool0oooo05X0oooo00<000000?ooo`3oool0
=P3oool20?l00280oooo00<0ol3;0?ooo`3oool0503oool00`3o0000oooo
0?ooo`070?ooo`@00000N03oool007L0oooo00<0ol3;0?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0h0?ooo`80o`00803oool00`3o`</0oooo0?oo
o`0D0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1e0?ooo`00M`3oool00`3o`</0oooo0?ooo`1J
0?ooo`030000003oool0oooo03X0oooo00<0o`000?ooo`3oool0703oool0
0`3o`</0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1e0?ooo`00N03oool00`3o
`</0oooo0?ooo`1I0?ooo`030000003oool0oooo03/0oooo0P3o000L0?oo
o`030?o0b`3oool0oooo01@0oooo00<0o`000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo07@0oooo001h0?ooo`03
0?o0b`3oool0oooo05T0oooo00<000000?ooo`3oool0?@3oool20?l001T0
oooo00<0ol3;0?ooo`3oool05@3oool00`3o0000oooo0?ooo`070?ooo`L0
0000MP3oool007T0oooo00<0ol3;0?ooo`3oool0F03oool00`000000oooo
0?ooo`0o0?ooo`80o`005`3oool00`3o`</0oooo0?ooo`0D0?ooo`030?l0
003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`1d0?ooo`00N@3oool00`3o`</0oooo0?ooo`1H0?ooo`030000003o
ool0oooo0440oooo00<0o`000?ooo`3oool0503oool00`3o`</0oooo0?oo
o`0D0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1d0?ooo`00NP3oool00`3o`</0oooo0?ooo`1G
0?ooo`030000003oool0oooo0480oooo0P3o000C0?ooo`030?o0b`3oool0
oooo01D0oooo00<0o`000?ooo`3oool02P3oool4000007L0oooo001j0?oo
o`030?o0b`3oool0oooo05L0oooo00<000000?ooo`3oool0A03oool20?l0
0140oooo00<0ol3;0?ooo`3oool05@3oool00`3o0000oooo0?ooo`250?oo
o`00NP3oool00`3o`</0oooo0?ooo`1G0?ooo`030000003oool0oooo04H0
oooo00<0o`000?ooo`3oool03@3oool00`3o`</0oooo0?ooo`0E0?ooo`03
0?l0003oool0oooo08H0oooo001k0?ooo`030?o0b`3oool0oooo05H0oooo
00<000000?ooo`3oool0A`3oool20?l000d0oooo00<0ol3;0?ooo`3oool0
5@3oool00`3o0000oooo0?ooo`260?ooo`00N`3oool00`3o`</0oooo0?oo
o`1F0?ooo`030000003oool0oooo04T0oooo0P3o000:0?ooo`030?o0b`3o
ool0oooo01D0oooo00<0o`000?ooo`3oool0Q`3oool007`0oooo00<0ol3;
0?ooo`3oool0E@3oool00`000000oooo0?ooo`1;0?ooo`80o`00203oool0
0`3o`</0oooo0?ooo`0E0?ooo`030?l0003oool0oooo08L0oooo001m0?oo
o`030?o0b`3oool0oooo05@0oooo00<000000?ooo`3oool0C@3oool00`3o
0000oooo0?ooo`040?ooo`030?o0b`3oool0oooo01H0oooo00<0o`000?oo
o`3oool0Q`3oool007h0oooo00<0ol3;0?ooo`3oool0D`3oool00`000000
oooo0?ooo`1>0?ooo`80o`00103oool00`3o`</0oooo0?ooo`0E0?ooo`03
0?l0003oool0oooo08P0oooo001n0?ooo`030?o0b`3oool0oooo05<0oooo
00<000000?ooo`3oool0D03oool20?l000030?ooo`3o`</0oooo01L0oooo
00<0o`000?ooo`3oool0R03oool007l0oooo00<0ol3;0?ooo`3oool0DP3o
ool00`000000oooo0?ooo`1B0?ooo`80o`005`3oool00`3o0000oooo0?oo
o`290?ooo`00O`3oool00`3o`</0oooo0?ooo`1B0?ooo`030000003oool0
oooo0540oooo00@0ol3;0?ooo`3oool0o`005P3oool00`3o0000oooo0?oo
o`290?ooo`00P03oool00`3o`</0oooo0?ooo`1A0?ooo`030000003oool0
oooo0540oooo00@0ol3;0?ooo`3oool0oooo0P3o000C0?ooo`030?l0003o
ool0oooo08X0oooo00200?ooo`030?o0b`3oool0oooo0540oooo00<00000
0?ooo`3oool0D@3oool00`3o`</0oooo0?ooo`030?ooo`80o`004@3oool0
0`3o0000oooo0?ooo`2:0?ooo`00P@3oool00`3o`</0oooo0?ooo`1@0?oo
o`030000003oool0oooo0500oooo00<0ol3;0?ooo`3oool01P3oool20?l0
00h0oooo00<0o`000?ooo`3oool0R`3oool00840oooo00<0ol3;0?ooo`3o
ool0D03oool00`000000oooo0?ooo`1@0?ooo`030?o0b`3oool0oooo00P0
oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`2<0?ooo`00
PP3oool00`3o`</0oooo0?ooo`1?0?ooo`030000003oool0oooo04l0oooo
00<0ol3;0?ooo`3oool02P3oool20?l000X0oooo00<0o`000?ooo`3oool0
S03oool008<0oooo00<0ol3;0?ooo`3oool0CP3oool00`000000oooo0?oo
o`1>0?ooo`030?o0b`3oool0oooo00d0oooo0P3o00080?ooo`030?l0003o
ool0oooo08`0oooo00230?ooo`030?o0b`3oool0oooo04h0oooo00<00000
0?ooo`3oool0C@3oool00`3o`</0oooo0?ooo`0@0?ooo`80o`001P3oool0
0`3o0000oooo0?ooo`2<0?ooo`00Q03oool00`3o`</0oooo0?ooo`1=0?oo
o`030000003oool0oooo04d0oooo00<0ol3;0?ooo`3oool04P3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo08d0oooo00240?ooo`03
0?o0b`3oool0oooo04d0oooo00<000000?ooo`3oool0C03oool00`3o`</0
oooo0?ooo`0D0?ooo`80o`000P3oool00`3o0000oooo0?ooo`2=0?ooo`00
Q@3oool00`3o`</0oooo0?ooo`1<0?ooo`030000003oool0oooo04`0oooo
00<0ol3;0?ooo`3oool05P3oool20?l00900oooo00260?ooo`80ol3;C03o
ool00`000000oooo0?ooo`1:0?ooo`80ol3;6`3oool20?l008h0oooo0028
0?ooo`030?o0b`3oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool0
0`3o`</0oooo0?ooo`0M0?ooo`030?l0003oool0oooo08/0oooo00290?oo
o`030?o0b`3oool0oooo04P0oooo00<000000?ooo`3oool0B@3oool00`3o
`</0oooo0?ooo`0N0?ooo`80o`00R`3oool008T0oooo00<0ol3;0?ooo`3o
ool0B03oool00`000000oooo0?ooo`180?ooo`030?o0b`3oool0oooo0240
oooo0P3o00290?ooo`00RP3oool00`3o`</0oooo0?ooo`170?ooo`030000
003oool0oooo04L0oooo00<0ol3;0?ooo`3oool0903oool20?l008L0oooo
002;0?ooo`030?o0b`3oool0oooo04H0oooo00<000000?ooo`3oool0AP3o
ool00`3o`</0oooo0?ooo`0W0?ooo`030?l0003oool0oooo08@0oooo002<
0?ooo`030?o0b`3oool0oooo04D0oooo00<000000?ooo`3oool0A@3oool0
0`3o`</0oooo0?ooo`0Y0?ooo`80o`00Q03oool008d0oooo00<0ol3;0?oo
o`3oool0A03oool00`000000oooo0?ooo`140?ooo`030?o0b`3oool0oooo
02`0oooo0P3o00220?ooo`00SP3oool00`3o`</0oooo0?ooo`130?ooo`03
0000003oool0oooo04@0oooo00<0ol3;0?ooo`3oool0;P3oool20?l00800
oooo002>0?ooo`030?o0b`3oool0oooo04<0oooo00<000000?ooo`3oool0
@`3oool00`3o`</0oooo0?ooo`0a0?ooo`030?l0003oool0oooo07d0oooo
002?0?ooo`030?o0b`3oool0oooo0480oooo00<000000?ooo`3oool0@P3o
ool00`3o`</0oooo0?ooo`0c0?ooo`80o`00O@3oool00900oooo0P3o`<]2
0?ooo`030000003oool0oooo0400oooo0P3o`</h0?ooo`80o`00N`3oool0
0980oooo00<0ol3;0?ooo`3oool0?`3oool00`000000oooo0?ooo`0o0?oo
o`030?o0b`3oool0oooo03X0oooo00<0o`000?ooo`3oool0N03oool009<0
oooo00<0ol3;0?ooo`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`03
0?o0b`3oool0oooo03`0oooo0P3o001h0?ooo`00U03oool00`3o`</0oooo
0?ooo`0m0?ooo`030000003oool0oooo03d0oooo00<0ol3;0?ooo`3oool0
?`3oool20?l007H0oooo002E0?ooo`030?o0b`3oool0oooo03`0oooo00<0
00000?ooo`3oool0?03oool00`3o`</0oooo0?ooo`120?ooo`80o`00M03o
ool009H0oooo0P3o`</l0?ooo`030000003oool0oooo03/0oooo00<0ol3;
0?ooo`3oool0A@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo06/0oooo002H0?ooo`030?o0b`3oool0oooo03T0oooo00<000000?oo
o`3oool0>P3oool00`3o`</0oooo0?ooo`170?ooo`80o`000P3oool30?l0
06`0oooo002I0?ooo`030?o0b`3oool0oooo03P0oooo00<000000?ooo`3o
ool0>@3oool00`3o`</0oooo0?ooo`1:0?ooo`H0o`00J`3oool009X0oooo
0P3o`</h0?ooo`030000003oool0oooo03L0oooo0P3o`<]>0?ooo`H0o`00
JP3oool009`0oooo0P3o`</f0?ooo`030000003oool0oooo03D0oooo0P3o
`<]@0?ooo`L0o`00J@3oool009h0oooo00<0ol3;0?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0d0?ooo`030?o0b`3oool0oooo04l0oooo2@3o001X
0?ooo`00W`3oool00`3o`</0oooo0?ooo`0b0?ooo`030000003oool0oooo
0380oooo0P3o`<]B0?ooo`X0o`00I`3oool00:00oooo0P3o`</b0?ooo`03
0000003oool0oooo0300oooo0P3o`<]F0?ooo`T0o`00IP3oool00:80oooo
0P3o`</`0?ooo`030000003oool0oooo02h0oooo0P3o`<]L0?ooo`H0o`00
I@3oool00:@0oooo00<0ol3;0?ooo`3oool0;@3oool00`000000oooo0?oo
o`0]0?ooo`030?o0b`3oool0oooo0600oooo0`3o001T0?ooo`00Y@3oool0
0`3o`</0oooo0?ooo`0/0?ooo`030000003oool0oooo02`0oooo00<0ol3;
0?ooo`3oool0b03oool00:H0oooo0P3o`<//0?ooo`030000003oool0oooo
02X0oooo0P3o`<_;0?ooo`00Z03oool30?o0bbT0oooo00<000000?ooo`3o
ool0:03oool20?o0bld0oooo002[0?ooo`80ol3;9`3oool00`000000oooo
0?ooo`0U0?ooo`<0ol3;c`3oool00:d0oooo0P3o`</U0?ooo`030000003o
ool0oooo02<0oooo0P3o`<_B0?ooo`00[`3oool20?o0bb<0oooo00<00000
0?ooo`3oool08@3oool20?o0bm@0oooo002a0?ooo`D0ol3;7P3oool00`00
0000oooo0?ooo`0L0?ooo`D0ol3;eP3oool00;H0oooo0P3o`</L0?ooo`03
0000003oool0oooo01X0oooo0P3o`<_K0?ooo`00^03oool30?o0baT0oooo
00<000000?ooo`3oool05`3oool30?o0bmd0oooo002k0?ooo`D0ol3;503o
ool00`000000oooo0?ooo`0C0?ooo`@0ol3;h03oool00<00oooo103o`</8
0?ooo`D000000`3oool00`000000oooo0?ooo`0>0?ooo`D0ol3;NP3oool5
000006D0oooo00340?ooo`d0ol3;0`3oool00`000000oooo0?ooo`020?oo
o``0ol3;O`3oool01@000000oooo0?ooo`3oool0000006D0oooo003>0?oo
o`030000003oool0oooo00P0ol3;S03oool00`000000oooo0?ooo`1V0?oo
o`00cP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool0I@3oool00<h0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`2=0?ooo`040000003oool0oooo000006H0
oooo003=0?ooo`8000001@3oool00`000000oooo0?ooo`2=0?ooo`D00000
I@3oool00=@0oooo00<000000?ooo`3oool0m`3oool00=@0oooo00<00000
0?ooo`3oool0m`3oool00=@0oooo00<000000?ooo`3oool0m`3oool00=@0
oooo00<000000?ooo`3oool0m`3oool00=@0oooo00<000000?ooo`3oool0
m`3oool00=@0oooo00<000000?ooo`3oool0m`3oool00?l0ooooc`3oool0
0?l0ooooc`3oool00?l0ooooc`3oool00?l0ooooc`3oool00?l0ooooc`3o
ool00?l0ooooc`3oool00?l0ooooc`3oool00?l0ooooc`3oool00=80oooo
0P00003j0?ooo`00d`3oool00`000000oooo0?ooo`3h0?ooo`00e03oool0
0`000000oooo0?ooo`3g0?ooo`00d`3oool00`000000oooo0000003h0?oo
o`00dP3oool010000000oooo0?ooo`00003h0?ooo`00d@3oool300000003
0?ooo`00000000000?L0oooo003o0?oooll0oooo003o0?oooll0oooo003o
0?oooll0oooo003o0?oooll0oooo003o0?oooll0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{462, 262},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Example 1.13.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  If  ",
  Cell[BoxData[
      \(z\  = \ 1 + \[ImaginaryI]\)]],
  ",  then  ",
  Cell[BoxData[
      \(r = \(\(\(|\)\(1 + \[ImaginaryI]\)\(|\)\) = \(\@\(1 + 1\) = \
\@2\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Theta] = \(Arg \((z)\) = \(Arg \((1 + \[ImaginaryI])\) = \[Pi]\/4\)\
\)\)]],
  ".  Therefore  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(z\^\(-1\) = \ \(1\/r\) 
          e\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(=\)\(\ \)\(\(1\/\@2\)[
          cos \((\(-\(\[Pi]\/4\)\))\) + \[ImaginaryI]\ sin\ \
\((\(-\(\[Pi]\/4\)\))\)]\)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(\(=\)\(\ \)\(\(1\/\@2\) \((\ \@2\/2 - \[ImaginaryI] \
\@ 2\/2)\)\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(=\)\(\ \)\(1\/2 - \[ImaginaryI]\/2\)\)\)}]],
  "\n\nthe modulus is  ",
  Cell[BoxData[
      \(\(\(|\)\(z\^\(-1\)\)\(|\)\) = \(\@\(\((1\/2)\)\^2 + \((1\/2)\)\^2\) = \
\(\@2\/2 = \(1\/\@2 = 1\/\(\(|\)\(z\)\(|\)\)\)\)\)\)]],
  ",  and the argument is  ",
  Cell[BoxData[
      \(\(\(\ \)\(Arg \((z\^\(-1\))\) = \(\(-\(\[Pi]\/4\)\) = \(-Arg\) \
\((z)\)\)\)\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter  ",
  Cell[BoxData[
      \(z\  = \ 1\  + \[ImaginaryI]\)]],
  "  and compute ",
  Cell[BoxData[
      \(1\/z\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[r, w, z];\)\ \), "\n", 
    \(\(z\  = \ 1 + \[ImaginaryI];\)\ \), "\n", 
    \(\(r\  = \ Abs[z];\)\ \), "\n", 
    \(\(z\_1\  = \ Conjugate[z];\)\ \), "\n", 
    \(\(z\_2\  = \ Conjugate[z]\/r;\)\ \), "\n", 
    \(\(z\_3\  = \ 1\/r\ Conjugate[z]\/r;\)\ \), "\[IndentingNewLine]", 
    \(\(w = ComplexExpand[1\/z];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        Graphics[{Red, Arrow[{0, \ 0}, {Re[z], Im[z]}]}];\)\ \), "\n", 
    \(\(V\_2\  = \ 
        Graphics[{Blue, Arrow[{0, \ 0}, {Re[w], Im[w]}]}];\)\ \), "\n", 
    \(\(g1 = 
        Show[V\_1, 
          PlotRange \[Rule] {{\(-0.1\), 1.1}, {\(-0.1\), 
                1.1}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 5, 1], 
              Range[0, 12, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
          Axes \[Rule] True, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\< z = \>", z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(z\&_\) = \>\"", z\_1];\)\ \), "\n", 
    \(\(Print["\< r = |z| = \>", r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\&_\/r\) = \>\"", 
        z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(1\/z\) = \!\(1\/r\)\!\(z\&_\/r\)\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(1\/z\) = \>\"", 1\/r, 
        Conjugate[z]\/r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(1\/z\) = \>\"", 
        z\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(g2 = 
        Show[V\_2, 
          PlotRange \[Rule] {{\(-0.1\), 1.1}, {\(-1.1\), 
                0.1}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 1, 1\/2], 
              Range[\(-1\), 0, 1\/2]}, AspectRatio \[Rule] 1, 
          Axes \[Rule] True, 
          
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 1.14.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given  ",
  Cell[BoxData[
      \(z\_1 = \(8  \[ImaginaryI]\ \ and\ \ z\_2 = 
          1 + \[ImaginaryI]\ \@3\)\)]],
  ",  compute  ",
  Cell[BoxData[
      \(z\_1\/z\_2\)]],
  "  using polar computations.\n\nIf  ",
  Cell[BoxData[
      \(z\_1 = 8  \[ImaginaryI]\)]],
  "  and  ",
  Cell[BoxData[
      \(z\_2 = 1 + \[ImaginaryI]\ \@3\)]],
  ",  then representative polar forms for these numbers are  ",
  Cell[BoxData[
      \(z\_1 = 8 \((cos  \[Pi]\/2 + \[ImaginaryI]\ sin  \[Pi]\/2)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(z\_2 = 2 \((cos  \[Pi]\/3 + \[ImaginaryI]\ sin  \[Pi]\/3)\)\)]],
  ".  Hence  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(z\_1\/z\_2 = \ \(8\/2\) 
          e\^\(\[ImaginaryI] \((\[Pi]\/2 - \[Pi]\/3)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(\(=\)\(\ \)\(\(8\/2\)[
          cos\ \((\[Pi]\/2 - \[Pi]\/3)\)\  + \ \[ImaginaryI]\ sin \((\[Pi]\/2 \
- \[Pi]\/3)\)]\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(\(=\)\(\ \)\(4[
          cos\ \((\[Pi]\/6)\)\  + \ \[ImaginaryI]\ sin \((\[Pi]\/6)\)]\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(=\)\(\ \)\(2\ \@3 + 2\ \[ImaginaryI]\)\)\)}]],
  "    \n\nthe modulus is  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_1\/z\_2\)\(|\)\) = \(8\/2 = \(\(|\)\(z\_1\)\(|\)\)\/\(\(|\
\)\(z\_2\)\(|\)\)\)\)]],
  ",  and the argument is ",
  Cell[BoxData[
      \(\(\(\ \)\(Arg \((z\_1\/z\_2)\) = \(\[Pi]\/6 = \(\[Pi]\/2 - \[Pi]\/3 = 
            Arg \((z\_1)\) - Arg \((z\_2)\)\)\)\)\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Caveat.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  The formula  ",
  Cell[BoxData[
      \(Arg \((z\_1\/z\_2)\) = Arg \((z\_1)\) - Arg \((z\_2)\)\)]],
  " does not hold for all complex numbers ",
  Cell[BoxData[
      RowBox[{\(z\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(z\_2\)}]]],
  ".  Whereas, the formula  ",
  Cell[BoxData[
      \(arg \((z\_1\/z\_2)\) = arg \((z\_1)\) - arg \((z\_2)\)\)]],
  "  does hold for all complex numbers ",
  Cell[BoxData[
      RowBox[{\(z\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(z\_2\)}]]],
  ", and is left for the reader to verify. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter  ",
  Cell[BoxData[
      \(z\_1 = \(8  \[ImaginaryI]\ \ and\ \ z\_2 = 
          1 + \[ImaginaryI]\ \@3\)\)]],
  "   and compute ",
  Cell[BoxData[
      \(z\_1\/z\_2\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[\[Theta], r, w, z];\)\ \), "\n", 
    \(\(z\_1 = 8  \[ImaginaryI];\)\ \), "\n", 
    \(\(z\_2 = 1 + \[ImaginaryI]\ \@3;\)\ \), "\[IndentingNewLine]", 
    \(\(w\_3 = ComplexExpand[z\_1\/z\_2];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(v1\  = \ 
        Graphics[{Red, 
            Arrow[{0, \ 0}, {Re[z\_1], Im[z\_1]}, 
              HeadScaling \[Rule] Absolute]}];\)\ \), "\n", 
    \(\(v2\  = \ 
        Graphics[{Green, 
            Arrow[{0, 0}, {Re[z\_2], Im[z\_2]}, 
              HeadScaling \[Rule] Absolute]}];\)\ \), "\n", 
    \(\(v3\  = \ 
        Graphics[{Blue, 
            Arrow[{0, \ 0}, {Re[w\_3], Im[w\_3]}, 
              HeadScaling \[Rule] Absolute]}];\)\ \), "\n", 
    \(\(Show[v1, v2, v3, 
        PlotRange \[Rule] {{\(-0.5\), 3.5}, {\(-0.5\), 
              8.5}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 3, 1], 
            Range[0, 8, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 9\/4, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\""\ , \ 
        z\_1, \*"\"\<,  \!\(z\_2\) = \>\""\ , \ 
        z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\/z\_2\) = \>\""\ , \ 
        z\_1\/z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\/z\_2\) = \>\""\ , \ 
        z\_1\/z\_2, \*"\"\<\!\(\(1 - \[ImaginaryI]\\\ \@3\)\/\(1 - \
\[ImaginaryI]\\\ \@3\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\/z\_2\) = \>\""\ , \ 
        ComplexExpand[\(z\_1\) \((1 - \[ImaginaryI]\ \
\@3)\)]\/ComplexExpand[\(z\_2\) \((1 - \[ImaginaryI]\ \@3)\)]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\/z\_2\) = \>\""\ , \ 
        w\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(r\_1 = Abs[z\_1];\)\ \), "\n", 
    \(\(\[Theta]\_1 = Arg[z\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", z\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(r\_1\) = |\!\(z\_1\)| = \>\"", r\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Theta]\_1\) = Arg[\!\(z\_1\)] = \>\"", \
\[Theta]\_1];\)\ \), "\n", 
    \(\(r\_2 = Abs[z\_2];\)\ \), "\n", 
    \(\(\[Theta]\_2 = Arg[z\_2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", z\_2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(r\_2\) = |\!\(z\_2\)| = \>\"", r\_2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Theta]\_2\) = Arg[\!\(z\_2\)] = \>\"", \
\[Theta]\_2];\)\ \), "\n", 
    \(\(w\_1 = z\_1\/z\_2;\)\ \), "\n", 
    \(\(w\_2 = 
        r\_1\/r\_2\ \[ExponentialE]\^\(\[ImaginaryI] \((\[Theta]\_1 - \
\[Theta]\_2)\)\);\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\/z\_2\) = \>\"", 
        z\_1\/z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\/z\_2\) = \!\(r\_1\/r\_2\)\!\(\[ExponentialE]\^\
\(\[ImaginaryI] \((\[Theta]\_1 - \[Theta]\_2)\)\)\)\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_1\/z\_2\) = (\>\"", r\_1, "\</\>", 
        r\_2, "\<)(\>", \*"\"\<\!\(\[ExponentialE]\^\[ImaginaryI]\)\>\""\^\
\[Theta]\_1, "\< \>", "\<\>"\^\[Theta]\_2, "\<)\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\/z\_2\) = (\>\"", 
        r\_1\/r\_2, "\<)(\>", \[ExponentialE]\^\(\[ImaginaryI] \((\[Theta]\_1 \
- \[Theta]\_2)\)\), "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\/z\_2\) = (\>\"", r\_1\/r\_2, "\<)(\>", 
        ComplexExpand[\[ExponentialE]\^\(\[ImaginaryI] \((\[Theta]\_1 - \
\[Theta]\_2)\)\)], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\/z\_2\) = \>\"", 
        ComplexExpand[\(r\_1\/r\_2\) \[ExponentialE]\^\(\[ImaginaryI] \((\
\[Theta]\_1 - \[Theta]\_2)\)\)]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Numbers",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexNumbersBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["History of Complex Numbers",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/HistoryComplexBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{996, 621},
WindowMargins->{{-2, Automatic}, {Automatic, 10}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 284669, 5535}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 136, 2, 33, "Text"],
Cell[2241, 66, 579, 13, 71, "Text",
  Evaluatable->False],
Cell[2823, 81, 720, 28, 52, "Text",
  Evaluatable->False],
Cell[3546, 111, 713, 23, 109, "Text"],
Cell[4262, 136, 62296, 1024, 301, 62182, 1020, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[66561, 1162, 632, 23, 55, "Text"],
Cell[67196, 1187, 716, 27, 58, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[67937, 1218, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[68100, 1224, 1581, 30, 451, "Input"]
}, Closed]],
Cell[69696, 1257, 968, 35, 106, "Text"],
Cell[70667, 1294, 1107, 36, 90, "Text"],
Cell[71777, 1332, 1899, 49, 101, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[73701, 1385, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[73864, 1391, 1371, 34, 36, "Text"],
Cell[75238, 1427, 2088, 39, 486, "Input"],
Cell[77329, 1468, 50, 0, 33, "Text"],
Cell[77382, 1470, 1002, 18, 218, "Input"]
}, Closed]],
Cell[78399, 1491, 353, 11, 30, "Text"],
Cell[78755, 1504, 754, 28, 109, "Text"],
Cell[79512, 1534, 245, 10, 36, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[79782, 1548, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[79945, 1554, 544, 10, 164, "Input"]
}, Closed]],
Cell[80504, 1567, 1626, 63, 156, "Text"],
Cell[82133, 1632, 10084, 249, 432, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[92242, 1885, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[92406, 1891, 204, 9, 33, "Text"],
Cell[92613, 1902, 1941, 39, 397, "Input"],
Cell[94557, 1943, 50, 0, 33, "Text"],
Cell[94610, 1945, 1033, 19, 214, "Input"]
}, Closed]],
Cell[95658, 1967, 869, 36, 115, "Text"],
Cell[96530, 2005, 2699, 74, 77, "Text",
  Evaluatable->False],
Cell[99232, 2081, 333, 11, 33, "Text"],
Cell[99568, 2094, 779, 21, 90, "Text"],
Cell[100350, 2117, 966, 23, 135, "Text"],
Cell[101319, 2142, 2543, 56, 291, "Text"],

Cell[CellGroupData[{
Cell[103887, 2202, 101, 2, 33, "Text"],
Cell[103991, 2206, 133, 2, 49, "Input"],
Cell[104127, 2210, 397, 6, 49, "Input"],
Cell[104527, 2218, 399, 6, 49, "Input"],
Cell[104929, 2226, 378, 6, 49, "Input"]
}, Closed]],
Cell[105322, 2235, 364, 10, 30, "Text"],
Cell[105689, 2247, 676, 22, 71, "Text"],
Cell[106368, 2271, 678, 22, 109, "Text"],
Cell[107049, 2295, 44513, 733, 326, 44399, 729, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[151565, 3030, 337, 12, 71, "Text"],
Cell[151905, 3044, 1115, 29, 71, "Text"],
Cell[153023, 3075, 1011, 29, 109, "Text"],
Cell[154037, 3106, 675, 22, 78, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[154737, 3132, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[154901, 3138, 1476, 30, 443, "Input"]
}, Closed]],
Cell[156392, 3171, 954, 21, 142, "Text"],
Cell[157349, 3194, 35769, 589, 235, 35655, 585, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[193121, 3785, 1158, 34, 90, "Text"],
Cell[194282, 3821, 585, 23, 109, "Text"],
Cell[194870, 3846, 537, 18, 71, "Text",
  Evaluatable->False],
Cell[195410, 3866, 1143, 25, 71, "Text",
  Evaluatable->False],
Cell[196556, 3893, 1702, 53, 71, "Text"],
Cell[198261, 3948, 610, 16, 122, "Text"],
Cell[198874, 3966, 954, 22, 236, "Text"],
Cell[199831, 3990, 769, 23, 33, "Text"],
Cell[200603, 4015, 36306, 598, 286, 36192, 594, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[236912, 4615, 34614, 570, 276, 34500, 566, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[271529, 5187, 1362, 38, 274, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[272916, 5229, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[273080, 5235, 159, 8, 36, "Text"],
Cell[273242, 5245, 2149, 45, 685, "Input"]
}, Closed]],
Cell[275406, 5293, 1754, 49, 293, "Text",
  Evaluatable->False],
Cell[277163, 5344, 1130, 33, 58, "Text"],

Cell[CellGroupData[{
Cell[278318, 5381, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[278482, 5387, 217, 9, 39, "Text"],
Cell[278702, 5398, 3897, 75, 1025, "Input"]
}, Closed]],
Cell[282614, 5476, 290, 7, 30, "Text"],
Cell[282907, 5485, 287, 7, 33, "Text"],
Cell[283197, 5494, 298, 7, 33, "Text"],
Cell[283498, 5503, 257, 5, 33, "Text"],
Cell[283758, 5510, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

