(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    215381,       5543]*)
(*NotebookOutlinePosition[    216194,       5573]*)
(*  CellTagsIndexPosition[    216117,       5567]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["1.5 The Algebra of Complex Numbers, Revisited",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tThe real numbers are deficient in the sense that not all algebraic \
operations on them produce real numbers. Thus, for ",
  Cell[BoxData[
      \(\@\(-1\)\)]],
  " to make sense, we must consider the domain of complex numbers. Do complex \
numbers have this same deficiency? That is, if we are to make sense of \
expressions such as ",
  Cell[BoxData[
      \(\@\(1 + \[ImaginaryI]\)\)]],
  ", must we appeal to yet another new number system? The answer to this \
question is no. In other words, any reasonable algebraic operation performed \
on complex numbers gives complex numbers. Later we show how to evaluate \
intriguing expressions such as ",
  Cell[BoxData[
      \(\((\(-1\))\)\^\[ImaginaryI]\)]],
  ". ",
  "For now we only look at integral powers and roots of complex numbers."
}], "Text"],

Cell[TextData[{
  "\tThe important players in this regard are the exponential and polar forms \
of a non-zero complex number   ",
  Cell[BoxData[
      \(z = \(r\ \[ExponentialE]\^\[ImaginaryI]\[Theta] = 
          r \((cos\ \[Theta]\  + \ \[ImaginaryI]\ sin\ \[Theta])\)\)\)]],
  ".  By the laws of exponents (which, you recall, we have promised to prove \
in Chapter 5) we have  \n\n\t\t\t",
  Cell[BoxData[
      \(z\^n = \(\((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\))\)\^n = \
\(r\^n\) \[ExponentialE]\^\(\[ImaginaryI]\ n\ \[Theta]\)\)\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\(r\^n\)[
          cos\ \((n\[Theta])\)\  + \ \[ImaginaryI]\ sin\ \((n\[Theta])\)]\)\)\
\)\)]],
  ",  \n\t\tand\n\t\t\t",
  Cell[BoxData[
      \(z\^\(-n\) = \(\((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\))\)\^\
\(-n\) = \(\(r\^\(-n\)\) \[ExponentialE]\^\(\[ImaginaryI]\ n\ \[Theta]\) = \
\(r\^\(-n\)\)[
              cos\ \((\(-n\[Theta]\))\)\  + \ \[ImaginaryI]\ sin\ \((\(-n\
\[Theta]\))\)]\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.15.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\((\(-\@3\) - \[ImaginaryI])\)\^3 = \(-8\) \[ImaginaryI]\)]],
  "  in two ways.\n\nSolution.  (Method 1):  The binomial formula (Exercise \
14 of Section 1.2) gives  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\((\(-\@3\) - \[ImaginaryI])\)\^3 = 
        1 \((\(-\@3\))\)\^3 + 
          3 \(\((\(-\@3\))\)\^2\) \((\(-\[ImaginaryI]\))\) + 
          3 \((\(-\@3\))\) \((\(-\[ImaginaryI]\))\)\^2 + \
\((\(-\[ImaginaryI]\))\)\^3\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\(-3\)\ \
\@3 + \(-9\)\ \[ImaginaryI] + 
          3\ \@3 + \[ImaginaryI]\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\(-8\) \
\[ImaginaryI]\)\)\)}]],
  "   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "(Method 2):  Using iIdentity stated above and Example 1.12 yields  \n\n\t\t\
\t",
  Cell[BoxData[{
      \(\(\(\((\(-\@3\) - \[ImaginaryI])\)\^3 = \ \((2  \[ExponentialE]\^\(\
\[ImaginaryI] \((\(-5\) \[Pi]/6)\)\))\)\^3\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\((2)\)\^3\ \((\[ExponentialE]\^\(\[ImaginaryI] \((\(-5\) \[Pi]/6)\)\))\)\
\^3\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(8 \
\((\[ExponentialE]\^\(\[ImaginaryI] \((\(-15\) \[Pi]/6)\)\))\)\)\)\(\ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(8 \
\((Cos[\(\(-15\)\ \[Pi]\)\/6] + \[ImaginaryI]\ Sin[\(\(-15\)\ \
\[Pi]\)\/6])\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\(-8\)\ \
\[ImaginaryI]\)\)\)}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.15.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter  ",
  Cell[BoxData[
      \(z\  = \(-\ \@3\) - \[ImaginaryI]\)]],
  "  and compute  ",
  Cell[BoxData[
      \(\((\(-\@3\) - \[ImaginaryI])\)\^3\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[e, \[Theta], r, z, Z];\)\ \), "\n", 
    \(\(z\  = \ \(-\ \@3\)\  - \ \[ImaginaryI];\)\ \), "\n", 
    \(\(r\  = \ Abs[z];\)\ \), "\n", 
    \(\(\[Theta]\  = \ Arg[z];\)\ \), "\n", 
    \(\(Z\  = \ 
        ComplexExpand[
          r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        Graphics[{Blue, 
            Arrow[{0, \ 0}, {Re[z], Im[z]}, 
              HeadScaling \[Rule] Absolute]}];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_2\  = \ 
        Graphics[{Magenta, 
            Arrow[{0, \ 0}, {Re[z\^3], Im[z\^3]}, 
              HeadScaling \[Rule] Absolute]}];\)\ \), "\n", 
    \(\(Show[V\_1, V\_2, 
        PlotRange \[Rule] {{\(-2\), 0.5}, {\(-8\), 
              0.5}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-2\), 0, 1], 
            Range[\(-8\), 0, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 
          8.5\/2.5, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<z = \>", z];\)\ \), "\n", 
    \(\(Print["\<r = |z| = \>", r];\)\ \), "\n", 
    \(\(Print["\<\[Theta] = Arg[z] = \>", \[Theta]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<z = \!\(r\[ExponentialE]\^\[ImaginaryI]\[Theta]\) = \
\>\"", r, e\^\(\[ImaginaryI]\ \[Theta]\)];\)\ \), "\n", 
    \(\(Print[\*"\"\<z = \!\(r\[ExponentialE]\^\[ImaginaryI]\[Theta]\) = \
\>\"", Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^3\) = \>\"", \ 
        z\^3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^3\) = (\>\"", \ z, "\<)\>", 
        z\^2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^3\) = (\>\"", \ z, "\<)\>", "\<(\>", 
        Expand[z\^2], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\^3\) = \>\"", \ 
        Expand[z\^3]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^3\) = \
\!\(r\^3\)\!\(\[ExponentialE]\^\[ImaginaryI]3\[Theta]\) = \>\"", \ r\^3\ , 
        e\^\(\[ImaginaryI]\ 3  \[Theta]\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^3\) = \
\!\(r\^3\)\!\(\[ExponentialE]\^\[ImaginaryI]3\[Theta]\) = \>\"", \ 
        r\^3\ , "\<(Cos[\>", 3  \[Theta], "\<]+ \[ImaginaryI] Sin[\>", 
        3  \[Theta], "\<])\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^3\) = \
\!\(r\^3\)\!\(\[ExponentialE]\^\[ImaginaryI]3\[Theta]\) = \>\"", \ 
        r\^3\ , "\<(\>", 
        Cos[3\ \[Theta]] + \ \[ImaginaryI]\ Sin[
              3\ \[Theta]], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^3\) = \
\!\(r\^3\)\!\(\[ExponentialE]\^\[ImaginaryI]3\[Theta]\) = \>\"", \ 
        r\^3\ \[ExponentialE]\^\(\[ImaginaryI]\ 3\ \[Theta]\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tWhich method would you use if you were asked to compute ",
  Cell[BoxData[
      \(\((\(-\@3\) - \[ImaginaryI])\)\^30\)]],
  "? "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.16.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Evaluate  ",
  Cell[BoxData[
      \(\((\(-\@3\) - \[ImaginaryI])\)\^30\)]],
  ".\n\nSolution.\t\t",
  Cell[BoxData[{
      \(\(\(\((\(-\@3\) - \[ImaginaryI])\)\^30 = \ \((2  \[ExponentialE]\^\(\
\[ImaginaryI] \((\(-5\) \[Pi]/6)\)\))\)\^30\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(2\^30\ \((\[ExponentialE]\^\(\[ImaginaryI] \((\(-5\) \
\[Pi]/6)\)\))\)\^30\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\(2\^30\) \((\[ExponentialE]\^\(\[ImaginaryI] \((\(-150\) \[Pi]/6)\)\))\)\
\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\(2\^30\) \
\((Cos[\(\(-150\)\ \[Pi]\)\/6] + \[ImaginaryI]\ Sin[\(\(-150\)\ \
\[Pi]\)\/6])\)\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\(2\^30\) \
\((Cos[\(-25\)\ \[Pi]] + \[ImaginaryI]\ Sin[\(-25\)\ \[Pi]])\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(-\ 
          2\^30\)\)\)}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.16.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter  ",
  Cell[BoxData[
      \(z\  = \(-\ \@3\) - \[ImaginaryI]\)]],
  "  and compute  ",
  Cell[BoxData[
      \(\((\(-\@3\) - \[ImaginaryI])\)\^30\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[e, \[Theta], r, z, Z];\)\ \), "\n", 
    \(\(z\  = \ \(-\ \@3\)\  - \ \[ImaginaryI];\)\ \), "\n", 
    \(\(r\  = \ Abs[z];\)\ \), "\n", 
    \(\(\[Theta]\  = \ Arg[z];\)\ \), "\n", 
    \(\(Z\  = \ 
        ComplexExpand[
          r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<z = \>", z];\)\ \), "\n", 
    \(\(Print["\<r = |z| = \>", r];\)\ \), "\n", 
    \(\(Print["\<\[Theta] = Arg[z] = \>", \[Theta]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<z = \!\(r\[ExponentialE]\^\[ImaginaryI]\[Theta]\) = \
\>\"", r, e\^\(\[ImaginaryI]\ \[Theta]\)];\)\ \), "\n", 
    \(\(Print[\*"\"\<z = \!\(r\[ExponentialE]\^\[ImaginaryI]\[Theta]\) = \
\>\"", Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^30\) = \!\(r\^30\)\!\(\[ExponentialE]\^\
\[ImaginaryI]30\[Theta]\) = \>\"", \ r\^30\ , 
        e\^\(\[ImaginaryI]\ 30  \[Theta]\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^30\) = \!\(r\^30\)\!\(\[ExponentialE]\^\
\[ImaginaryI]30\[Theta]\) = \>\"", \ r\^30\ , "\<(Cos[\>", 
        30  \[Theta], "\<]+ \[ImaginaryI] Sin[\>", 
        30  \[Theta], "\<])\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^30\) = \!\(r\^30\)\!\(\[ExponentialE]\^\
\[ImaginaryI]30\[Theta]\) = \>\"", \ r\^30\ , "\<(\>", 
        Cos[30\ \[Theta]] + \ \[ImaginaryI]\ Sin[
              30\ \[Theta]], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^30\) = \!\(r\^30\)\!\(\[ExponentialE]\^\
\[ImaginaryI]30\[Theta]\) = \>\"", \ 
        r\^30\ \[ExponentialE]\^\(\[ImaginaryI]\ 30\ \[Theta]\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^30\) = -(\>\"", \ 
        r, \*"\"\<\!\(\()\^30\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Alternate solution\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^30\) = \>\"", \ 
        z\^30];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^30\) = \>\"", \ 
        Expand[\((\(-\ \@3\)\  - \ i)\)\^30]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\^30\) = \>\"", \ 
        Expand[z\^30]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^30\) = -(\>\"", \ 
        r, \*"\"\<\!\(\()\^30\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Evaluate  ",
  Cell[BoxData[
      \(\((\(-\@3\) - \[ImaginaryI])\)\^\(-6\) = \(-\ 1\)\/64\)]],
  "  in two ways."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter  ",
  Cell[BoxData[
      \(z = \(-\ \@3\) - \[ImaginaryI]\)]],
  "  and compute ",
  Cell[BoxData[
      \(\((\(-\@3\) - \[ImaginaryI])\)\^\(-6\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[e, \[Theta], r, z, Z];\)\ \), "\n", 
    \(\(z\  = \(-\ \@3\)\  - \ \[ImaginaryI];\)\ \), "\n", 
    \(\(r\  = \ Abs[z];\)\ \), "\n", 
    \(\(\[Theta]\  = \ Arg[z];\)\ \), "\n", 
    \(\(Z\  = \ 
        ComplexExpand[
          r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        Graphics[{Blue, Arrow[{0, \ 0}, {Re[z], Im[z]}]}];\)\ \), "\n", 
    \(\(V\_2\  = \ 
        Graphics[{Magenta, 
            Arrow[{0, \ 0}, {Re[z\^\(-6\)], Im[z\^\(-6\)]}]}];\)\ \), "\n", 
    \(\(Show[V\_1, 
        PlotRange \[Rule] {{\(-2\), 0.1}, {\(-1\), 
              0.05}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-\@3\), 
              0, \@3], 
            Range[\(-8\), 0, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 
          1\/2, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<z = \>", z];\)\ \), "\n", 
    \(\(Show[V\_2, 
        PlotRange \[Rule] {{\(-0.05\), 0.01}, {\(-0.03\), 
              0.03}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-3\)\/64, 0, 
              1\/64], Range[\(-2\)\/100, 2\/100, 
              1\/100]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^\(-6\)\) = \>\"", \ 
        ExpandAll[z\^\(-6\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<z = \>", z];\)\ \), "\n", 
    \(\(Print["\<r = |z| = \>", r];\)\ \), "\n", 
    \(\(Print["\<\[Theta] = Arg[z] = \>", \[Theta]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<z = \!\(r\[ExponentialE]\^\[ImaginaryI]\[Theta]\) = \
\>\"", r, e\^\(\[ImaginaryI]\ \[Theta]\)];\)\ \), "\n", 
    \(\(Print[\*"\"\<z = \!\(r\[ExponentialE]\^\[ImaginaryI]\[Theta]\) = \
\>\"", Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^6\) = \>\"", z\^6, "\< = \>", 
        Expand[z\^6]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\^\(-6\)\) = \>\"", \ 
        Expand[z\^\(-6\)], \ "\< = \>"\ , \ 
        ExpandAll[z\^\(-6\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\^\(-6\)\) = \
\!\(r\^\(-6\)\)\!\(\[ExponentialE]\^\(-\[ImaginaryI]6\[Theta]\)\) = \>\"", \ 
        r\^\(-6\)\ , 
        e\^\(\(-\[ImaginaryI]\)\ 6\ \[Theta]\)];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^\(-6\)\) = \
\!\(r\^\(-6\)\)\!\(\[ExponentialE]\^\(-\[ImaginaryI]6\[Theta]\)\) = \>\"", \ 
        r\^\(-6\)\ , "\<(Cos[\>", \(-6\) \[Theta], "\<]+ \[ImaginaryI] \
Sin[\>", \(-6\) \[Theta], "\<])\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^\(-6\)\) = \
\!\(r\^\(-6\)\)\!\(\[ExponentialE]\^\(-\[ImaginaryI]6\[Theta]\)\) = \>\"", \ 
        r\^\(-6\)\ , "\<(\>", 
        Cos[\(-6\)\ \[Theta]] + \ \[ImaginaryI]\ Sin[\(-6\)\ \[Theta]], \
"\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\^\(-6\)\) = \
\!\(r\^\(-6\)\)\!\(\[ExponentialE]\^\(-\[ImaginaryI]6\[Theta]\)\) = \>\"", \ 
        r\^\(-6\)\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 6\ \[Theta]\)];\)\ \
\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tAn interesting application of the laws of exponents comes from putting \
the equation ",
  Cell[BoxData[
      \(\((\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\))\)\^n = \
\[ExponentialE]\^\(\[ImaginaryI]\ n\ \[Theta]\)\)]],
  " into its polar form.  Doing so gives\n\n\t\t\t",
  Cell[BoxData[
      \(\((cos\ \[Theta]\  + i\ sin\ \[Theta])\)\^n\  = \ 
        cos \((n\ \[Theta])\)\  + i\ sin\ \((n\ \[Theta])\)\)]],
  ", \n\t\n\twhich is known as ",
  StyleBox[ButtonBox["De Moivre's Formula",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/deMoivresIdentity.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ", in honor of the French mathematician ",
  StyleBox[ButtonBox["Abraham de Moivre",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/De_Moivre.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " (1667--1754)."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.17.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use DeMoivre's formula to show that  ",
  Cell[BoxData[
      \(cos \((5\ \[Theta])\) = \(cos\^5\) \((\[Theta])\) - 
          10\ \(cos\^3\) \((\[Theta])\)\ \(sin\^2\) \((\[Theta])\) + 
          5\ cos[\[Theta]] \((\[Theta])\)\ \(sin\^4\) \((\[Theta])\)\)]],
  ".  \n\nSolution.  If we let ",
  StyleBox["n=5",
    FontFamily->"Courier New"],
  " and use the binomial formula to expand the left side of De Moivre's \
formula, we obtain  \n\n\t\t",
  Cell[BoxData[
      \(\((cos\ \[Theta] + \[ImaginaryI]\ sin\ \[Theta])\)\^5 = \(cos\^5\) \
\[Theta] + \[ImaginaryI]\ 5\ \(cos\^4\) \[Theta]\ sin\ \[Theta] - 
          10\ \(cos\^3\) \[Theta]\ \(sin\^2\) \[Theta] - 
          10  \[ImaginaryI]\ \(cos\^2\) \[Theta]\ \(sin\^3\) \[Theta] + 
          5\ cos\ \[Theta]\ \(sin\^4\) \[Theta] + \[ImaginaryI]\ \(sin\^5\) \
\[Theta]\)]],
  "  \n\n\t\t",
  Cell[BoxData[
      \(\((cos\ \[Theta] + \[ImaginaryI]\ sin\ \[Theta])\)\^5 = \(cos\^5\) \
\[Theta] - 10\ \(cos\^3\) \[Theta]\ \(sin\^2\) \[Theta] + 
          5\ cos\ \[Theta]\ \(sin\^4\) \[Theta] + \[ImaginaryI]\ \((5\ \
\(cos\^4\) \[Theta]\ sin\ \[Theta] - 
                10\ \(cos\^2\) \[Theta]\ \(sin\^3\) \[Theta] + \(sin\^5\) \
\[Theta])\)\)]],
  "\n\n\t\t",
  Cell[BoxData[
      \(cos \((5\ \[Theta])\)\  + \[ImaginaryI]\ sin\ \((5\ \[Theta])\) = \
\(cos\^5\) \[Theta] - 10\ \(cos\^3\) \[Theta]\ \(sin\^2\) \[Theta] + 
          5\ cos\ \[Theta]\ \(sin\^4\) \[Theta] + \[ImaginaryI]\ \((5\ \
\(cos\^4\) \[Theta]\ sin\ \[Theta] - 
                10\ \(cos\^2\) \[Theta]\ \(sin\^3\) \[Theta] + \(sin\^5\) \
\[Theta])\)\)]],
  "\n\nThe real part of right side of this expression is  ",
  Cell[BoxData[
      \(\(cos\^5\) \[Theta] - 10\ \(cos\^3\) \[Theta]\ \(sin\^2\) \[Theta] + 
        5\ cos\ \[Theta]\ \(sin\^4\) \[Theta]\)]],
  ".  Equating it to the real part of  ",
  Cell[BoxData[
      \(cos \((5\ \[Theta])\)\  + \[ImaginaryI]\ sin\ \((5\ \[Theta])\)\)]],
  "  establishes the desired result.  Furthermore, it can be shown that  ",
  Cell[BoxData[
      \(sin\ \((5\ \[Theta])\)\  = \ 
        5\ \(cos\^4\) \[Theta]\ sin\ \[Theta] - 
          10\ \(cos\^2\) \[Theta]\ \(sin\^3\) \[Theta] + \(sin\^5\) \
\[Theta]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.17.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter  ",
  Cell[BoxData[
      \(z\_1 = Cos[n\ \[Theta]] + \[ImaginaryI]\ Sin[n\ \[Theta]]\)],
    AspectRatioFixed->True],
  "  and compute  ",
  Cell[BoxData[
      \(\((Cos[\[Theta]]\  + \ \[ImaginaryI]\ Sin[\[Theta]])\)\^n\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[\[Theta], z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[n];\)\ \), "\[IndentingNewLine]", 
    \(\(n = 5;\)\ \), "\n", 
    \(\(z\_1 = 
        Cos[n\ \[Theta]] + \[ImaginaryI]\ Sin[n\ \[Theta]];\)\ \), "\n", 
    \(\(z\_2\  = \ \((Cos[\[Theta]]\  + \ \[ImaginaryI]\ Sin[\[Theta]])\)\^n;\
\)\ \), "\n", 
    \(\(z\_3\  = \ ComplexExpand[z\_2];\)\ \), "\n", 
    \(\(Print[z\_1, "\< = \>", z\_2];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[z\_1, "\< = \>", z\_3];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Take the real part of both sides and obtain\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[
        ComplexExpand[Re[z\_1]]\  \[Equal] \ 
          ComplexExpand[Re[z\_3]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Take the imaginary part of both sides and obtain\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[
        ComplexExpand[Im[z\_1]]\  \[Equal] \ 
          ComplexExpand[Im[z\_3]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tA key aid in determining roots of complex numbers is a corollary to the \
",
  StyleBox[ButtonBox["Fundamental Theorem of Algebra",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/FundamentalTheoremofAlgebra.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ".  We prove this theorem in Chapter 6.  Our proofs must be independent of \
the conclusions we derive here because we are going to make use of the \
corollary now."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 1.4  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Fundamental Theorem of Algebra",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/FundamentalTheoremofAlgebra.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  StyleBox["P(z)",
    FontFamily->"Courier New"],
  "  is a polynomial of degree  ",
  StyleBox["n",
    FontFamily->"Courier New"],
  "  (",
  Cell[BoxData[
      \(n > 0\)]],
  ")  with complex coefficients, then the equation  ",
  Cell[BoxData[
      \(P \((z)\) = 0\)]],
  "  has precisely  ",
  StyleBox["n",
    FontFamily->"Courier New"],
  "  (not necessarily distinct) solutions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Proof.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "   Refer to Chapter 6. "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.18.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(P \((z)\) = 
        z\^3 + \((2 - 2  \[ImaginaryI])\)\ z\^2 + \((\(-1\) - 
                4  \[ImaginaryI])\) z - 2\)],
    AspectRatioFixed->True],
  ".    and find its zeros.  This polynomial of degree 3 can be written as  \
",
  Cell[BoxData[
      \(P \((z)\) = \((z - \[ImaginaryI])\)\^2\ \((z + 2)\)\)]],
  ".  Hence the equation  ",
  Cell[BoxData[
      \(P \((z)\) = 0\)]],
  "  has solutions  ",
  Cell[BoxData[
      \(z\_1 = \(z\_2 = \[ImaginaryI]\)\)]],
  "  and  ",
  Cell[BoxData[
      \(z\_3 = \(-2\)\)]],
  ".  Thus, in accordance with the Fundamental Theorem of Algebra, we have \
three solutions, with  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(z\_2\)}]]],
  "  being repeated roots."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the polynomial  ",
  Cell[BoxData[
      \(P[z] = 
        z\^3 + \((2 - 2  \[ImaginaryI])\)\ z\^2 + \((\(-1\) - 
                4  \[ImaginaryI])\) z - 2\)],
    AspectRatioFixed->True],
  "  and factor it."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[P, z];\)\ \), "\n", 
    \(\(P[z_]\  = \ 
        z\^3\  + \ \((2 - 2  \[ImaginaryI])\)\ z\^2\  + \ \((\(-1\) - 
                4  \[ImaginaryI])\)\ z\  - \ 
          2;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[P[z] \[Equal] 0, z];\)\ \), "\n", 
    \(\(Print["\<P[z] = \>", P[z]];\)\ \), "\n", 
    \(\(Print["\<P[z] = \>", Factor[P[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<And we can find the roots of P[z]\>"];\)\ \), "\n", 
    \(\(Print["\<Solve \>", P[z]\ , "\< = 0\>"];\)\ \), "\n", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", 
        solset\_\(\(\[LeftDoubleBracket]\)\(3, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tThe corollary implies that if we can find ",
  StyleBox["n distinct",
    FontSlant->"Italic"],
  " solutions to the equation ",
  Cell[BoxData[
      \(z\^n = c\)]],
  "  (or ",
  Cell[BoxData[
      \(z\^n - c = 0\)]],
  ") , we will have found ",
  StyleBox["all",
    FontSlant->"Italic"],
  " the solutions.  We begin our search for these solutions by looking at the \
simpler equation ",
  Cell[BoxData[
      \(z\^n = 1\)]],
  ".  ",
  "Solving this equation will enable us to handle the more general one quite \
easily."
}], "Text"],

Cell[TextData[{
  "\tTo solve  ",
  Cell[BoxData[
      \(z\^n = 1\)]],
  " we first note an important condition that determines when two nonzero \
complex numbers are equal.  If we let  ",
  Cell[BoxData[
      \(z\_1\  = \ \(r\_1\) \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\_1\)\)]],
  "  and   ",
  Cell[BoxData[
      \(z\_2\  = \ \(r\_2\) \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\_2\)\)]],
  ",  then  \n\n\t\t\t",
  Cell[BoxData[
      \(z\_1\  = z\_2\)]],
  "   (i.e., ",
  Cell[BoxData[
      \(\(r\_1\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\_1\) = \(r\_2\) \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\_2\)\)]],
  ")    iff    ",
  Cell[BoxData[
      \(r\_1 = r\_2\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Theta]\_1 = \[Theta]\_2 + 2  \[Pi]\ k\)]],
  ",\n\t\t\t\nwhere ",
  StyleBox["k",
    FontFamily->"Courier New"],
  " is an integer.  That is, two complex numbers are equal iff their moduli \
agree and an argument of one equals an argument of the other to within an \
integral multiple of ",
  Cell[BoxData[
      \(2  \[Pi]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe now find all solutions to  ",
  Cell[BoxData[
      \(z\^n = 1\)]],
  "  in two stages, with each stage corresponding to one direction in the iff \
part of the above relation.  First, we show that if we have a solution to ",
  Cell[BoxData[
      \(z\^n = 1\)]],
  ", then the solution must have a certain form.  Second, we show that any \
quantity with that form is indeed a solution."
}], "Text"],

Cell[TextData[{
  "\tFor the first stage, suppose that  ",
  Cell[BoxData[
      \(z\  = \ r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)]],
  "  is a solution to  ",
  Cell[BoxData[
      \(z\^n = 1\)]],
  ".  Putting the latter equation in exponential form gives  ",
  Cell[BoxData[
      \(r\^n\ \[ExponentialE]\^\(\[ImaginaryI]\ n\ \[Theta]\) = 
        1  \[ExponentialE]\^\(0  \[ImaginaryI]\)\)]],
  ",  so we must have  ",
  Cell[BoxData[
      \(r\^n = 1\)]],
  "  and  ",
  Cell[BoxData[
      \(n\ \[Theta] = 0 + 2  \[Pi]\ k\)]],
  ".   In other words,  ",
  Cell[BoxData[
      \(r = 1\)]],
  "   and   ",
  Cell[BoxData[
      \(\[Theta] = \(2  \[Pi]\ k\)\/n\)]],
  ",  where ",
  StyleBox["k",
    FontFamily->"Courier New"],
  " is an integer."
}], "Text"],

Cell[TextData[{
  "\tSo, if ",
  Cell[BoxData[
      \(z = r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)]],
  " is a solution to ",
  Cell[BoxData[
      \(z\^n = 1\)]],
  ", then ",
  Cell[BoxData[
      \(r = 1\)]],
  " and ",
  Cell[BoxData[
      \(\[Theta] = \(2  \[Pi]\ k\)\/n\)]],
  " must be true.  This observation completes the first stage of our solution \
strategy.  For the second stage, we note that if ",
  Cell[BoxData[
      \(r = 1\)]],
  ", and ",
  Cell[BoxData[
      \(\[Theta] = \(2  \[Pi]\ k\)\/n\)]],
  ", then ",
  Cell[BoxData[
      \(z = \(r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\) = \
\[ExponentialE]\^\(\[ImaginaryI]\ 2  \[Pi]\ k/n\)\)\)]],
  " is indeed a solution to ",
  Cell[BoxData[
      \(z\^n = 1\)]],
  " because  ",
  Cell[BoxData[
      \(z\^n = \(\((\[ExponentialE]\^\(\[ImaginaryI]\ 2  \[Pi]\ k/n\))\)\^n = \
\(\[ExponentialE]\^\(\[ImaginaryI]\ 2  \[Pi]\ k\) = 1\)\)\)]],
  ".  For example, if n=7 and k=3, then  ",
  Cell[BoxData[
      \(z = \[ExponentialE]\^\(\[ImaginaryI]\ 6  \[Pi]\ /7\)\)]],
  "  is a solution to   ",
  Cell[BoxData[
      \(z\^7 = 1\)]],
  "  because ",
  Cell[BoxData[
      \(\((\[ExponentialE]\^\(\[ImaginaryI]\ 6  \[Pi]\ /7\))\)\^7 = \(\
\[ExponentialE]\^\(\[ImaginaryI]\ 6  \[Pi]\) = 1\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tFurthermore, it is easy to verify that we get n distinct solutions to ",
  Cell[BoxData[
      \(z\^n = 1\)]],
  " (and, therefore, all solutions) by setting  k=0,1,2,\[Ellipsis],n-1.  The \
solutions for  k=n,n+1,\[Ellipsis]  merely repeat those for  \
k=0,1,\[Ellipsis],  because the arguments so generated agree to within an \
integral multiple of ",
  Cell[BoxData[
      \(2  \[Pi]\)]],
  ".  As we stated in Section 1.1, the n solutions can be expressed as\n\n\t\t\
\t",
  Cell[BoxData[
      RowBox[{
        SubscriptBox["z", 
          StyleBox["k",
            FontSize->10]], "=", 
        RowBox[{
          SuperscriptBox["\[ExponentialE]", 
            StyleBox[\(\[ImaginaryI]\ 2  k\[Pi]/n\),
              FontSize->10]], " ", "=", 
          " ", \(cos \( 2\ \[Pi]\ k\)\/n + \[ImaginaryI]\ sin \( 2\ \[Pi]\ \
k\)\/n\)}]}]]],
  "   for   ",
  Cell[BoxData[
      \(k = 0, 1, \[CenterEllipsis], n - 1\)]],
  ".\n\nThey are called the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" roots of unity",
    FontColor->RGBColor[0, 0, 1]],
  "."
}], "Text"],

Cell[TextData[{
  "    When ",
  StyleBox["k=0",
    FontFamily->"Courier New"],
  " in the above equation, we get  ",
  Cell[BoxData[
      RowBox[{\(z\_0\), "=", 
        RowBox[{
          SuperscriptBox["\[ExponentialE]", 
            StyleBox[\(\[ImaginaryI]\ 2*0*\[Pi]/n\),
              FontSize->10]], "=", "1"}]}]]],
  ",  which is a rather trivial result.  The first interesting root of unity \
occurs when ",
  StyleBox["k=1",
    FontFamily->"Courier New"],
  ", giving  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), "=", 
        SuperscriptBox["\[ExponentialE]", 
          StyleBox[\(\[ImaginaryI]\ 2  \[Pi]/n\),
            FontSize->10]]}]]],
  ".  This particular value shows up so often that mathematicians have given \
it a special symbol."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 1.9 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Primitive nth Root of Unity",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RootofUnity.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  " For any natural number n, the value ",
  Cell[BoxData[
      SubscriptBox["\[Omega]", 
        StyleBox["n",
          FontSize->10]]]],
  " given by  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        SubscriptBox["\[Omega]", 
          StyleBox["n",
            FontSize->10]], "=", 
        RowBox[{
          SuperscriptBox["\[ExponentialE]", 
            StyleBox[\(\[ImaginaryI]2\ \[Pi]/n\),
              FontSize->10]], 
          "=", \(cos \( 2\ \[Pi]\)\/n + \[ImaginaryI]\ sin \( 2\ \
\[Pi]\)\/n\)}]}]]],
  "\n\nis called the ",
  StyleBox["primitive ",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" root of unity",
    FontColor->RGBColor[0, 0, 1]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tBy De Moivre's formula, the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " roots of unity can be expressed as  \n\n\t\t\t",
  Cell[BoxData[
      \(1, \[Omega]\_n, \[Omega]\_n\%2, \[Omega]\_n\%3,  ... , \
\[Omega]\_n\%\(n - 1\)\)]],
  ".  \n\nGeometrically, the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " roots of unity are equally spaced points that lie on the unit circle ",
  Cell[BoxData[
      \(\(C\_1\) \((0)\) = {z : \ \(\(|\)\(z\)\(|\)\) = 1}\)]],
  " and form the vertices of a regular polygon with ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " sides."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 1.19.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The solutions to the equation  ",
  Cell[BoxData[
      \(z\^8 = 1\)]],
  " are given by the eight values  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        SubscriptBox["z", 
          StyleBox["k",
            FontSize->10]], " ", "=", " ", 
        RowBox[{
          SuperscriptBox["\[ExponentialE]", 
            StyleBox[\(\[ImaginaryI] \( 2\ \[Pi]\ k\)\/8\),
              FontSize->10]], " ", "=", 
          " ", \(cos \( 2\ \[Pi]\ k\)\/8 + \[ImaginaryI]\ sin \( 2\ \[Pi]\ \
k\)\/8\)}]}]]],
  "   for   ",
  Cell[BoxData[
      \(k = 0, 1, 2,  ... , 7\)]],
  ".\n\nIn Cartesian form, these solutions are  ",
  Cell[BoxData[
      \(\(\[PlusMinus]1\), \(\[PlusMinus]\[ImaginaryI]\), \
\(\[PlusMinus]\(\(\@2 + \[ImaginaryI] \@ 2\)\/2\)\), \(\[PlusMinus]\(\(\@2 - \
\[ImaginaryI] \@ 2\)\/2\)\)\)]],
  ".  The primitive ",
  Cell[BoxData[
      \(TraditionalForm\`8\^th\)]],
  " root of unity is \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        SubscriptBox["\[Omega]", 
          StyleBox["n",
            FontSize->10]], " ", "=", " ", 
        RowBox[{
          SuperscriptBox["\[ExponentialE]", 
            StyleBox[\(\[ImaginaryI] \( 2\ \[Pi]\)\/8\),
              FontSize->10]], " ", "=", " ", 
          RowBox[{
            SuperscriptBox["\[ExponentialE]", 
              StyleBox[\(\[ImaginaryI]  \[Pi]\/4\),
                FontSize->10]], " ", "=", 
            " ", \(cos  \[Pi]\/4 + \[ImaginaryI]\ sin  \[Pi]\/4\  = \ \(\@2 + \
\[ImaginaryI] \@ 2\)\/2\)}]}]}]]],
  ".\n\n",
  "Figure 1.18 illustrates this result."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.09091 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.454545 0.545455 0.454545 [
[ 0 0 0 0 ]
[ 1 1.09091 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.09091 L
0 1.09091 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 1 0 r
.5 Mabswid
[ ] 0 setdash
newpath
.5 .54545 .45455 0 365.73 arc
s
1 0 0 r
.5 .54545 m
.95455 .54545 L
s
% Start of user PostScript
0 0 1. 0 MAarrowhead1
% End of user PostScript
0 0 1 r
.5 .54545 m
.82141 .86687 L
s
% Start of user PostScript
0 0 0.707107 0.707107 MAarrowhead1
% End of user PostScript
0 1 0 r
.5 .54545 m
.5 1 L
s
% Start of user PostScript
0 0 0 1. MAarrowhead1
% End of user PostScript
.5 .165 .165 r
.5 .54545 m
.17859 .86687 L
s
% Start of user PostScript
0 0 -0.707107 0.707107 MAarrowhead1
% End of user PostScript
1 0 1 r
.5 .54545 m
.04545 .54545 L
s
% Start of user PostScript
0 0 -1. 0 MAarrowhead1
% End of user PostScript
1 .753 .796 r
.5 .54545 m
.17859 .22404 L
s
% Start of user PostScript
0 0 -0.707107 -0.707107 MAarrowhead1
% End of user PostScript
0 1 1 r
.5 .54545 m
.5 .09091 L
s
% Start of user PostScript
0 0 0 -1. MAarrowhead1
% End of user PostScript
1 .5 0 r
.5 .54545 m
.82141 .22404 L
s
% Start of user PostScript
0 0 0.707107 -0.707107 MAarrowhead1
% End of user PostScript
1 0 0 r
.025 w
.95455 .54545 Mdot
0 0 1 r
.82141 .86687 Mdot
0 1 0 r
.5 1 Mdot
.5 .165 .165 r
.17859 .86687 Mdot
1 0 1 r
.04545 .54545 Mdot
1 .753 .796 r
.17859 .22404 Mdot
0 1 1 r
.5 .09091 Mdot
1 .5 0 r
.82141 .22404 Mdot
0 g
gsave
.86364 .59091 -81.7188 -11.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 10.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
86.063 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.250 15.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
100.438 15.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.84414 .92141 -98.0938 -18.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 37.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 15.375 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.438 15.375 moveto
(\\220) show
85.563 15.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
91.188 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
102.125 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
112.188 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
122.250 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
100.500 19.938 moveto
(\\200\\200\\200\\200\\200\\200\\200\\200) show
121.500 19.938 moveto
(\\200\\200) show
126.750 19.938 moveto
(\\200) show
128.188 19.938 moveto
(\\200) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
106.000 24.000 moveto
(\\217) show
115.875 24.000 moveto
(!) show
118.563 24.000 moveto
(!) show
121.250 24.000 moveto
(!) show
121.938 24.000 moveto
(!) show
116.313 30.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
133.188 19.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 1.03636 -84.2813 -11.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 10.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.438 10.625 moveto
(\\220) show
85.563 10.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
91.188 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
98.375 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
105.563 15.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.02859 .92141 -61 -18.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 37.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 15.375 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.563 15.375 moveto
(\\220) show
90.688 15.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
96.313 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.250 12.938 moveto
(-) show
115.188 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
125.250 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
135.313 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
105.625 19.938 moveto
(\\200\\200\\200\\200\\200\\200\\200\\200) show
126.625 19.938 moveto
(\\200\\200\\200\\200) show
137.125 19.938 moveto
(\\200\\200) show
141.250 19.938 moveto
(\\200) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.063 24.000 moveto
(\\217) show
124.938 24.000 moveto
(!) show
127.625 24.000 moveto
(!) show
130.313 24.000 moveto
(!) show
131.000 24.000 moveto
(!) show
125.375 30.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
146.250 19.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.13636 .59091 -82.75 -11.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.188 15.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
77.375 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
84.563 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
91.750 10.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344p) show
102.500 15.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.02859 .13313 -61 -18.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 37.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 15.375 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.563 15.375 moveto
(\\220) show
90.688 15.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
96.313 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.250 12.938 moveto
(-) show
115.188 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
125.250 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
135.313 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
105.625 19.938 moveto
(\\200\\200\\200\\200\\200\\200\\200\\200) show
126.625 19.938 moveto
(\\200\\200\\200\\200) show
137.125 19.938 moveto
(\\200\\200) show
141.250 19.938 moveto
(\\200) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.063 24.000 moveto
(\\217) show
124.938 24.000 moveto
(!) show
127.625 24.000 moveto
(!) show
130.313 24.000 moveto
(!) show
131.000 24.000 moveto
(!) show
125.375 30.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
146.250 19.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .02273 -90.4375 -11.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 10.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.563 10.625 moveto
(\\220) show
90.688 10.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
96.313 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
103.500 15.188 moveto
(-) show
110.688 15.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
117.875 15.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.8305 .13313 -100.656 -18.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 37.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 15.375 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.563 15.375 moveto
(\\220) show
90.688 15.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
96.313 19.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.250 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
117.313 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
127.375 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
105.625 19.938 moveto
(\\200\\200\\200\\200\\200\\200\\200\\200) show
126.625 19.938 moveto
(\\200\\200) show
131.875 19.938 moveto
(\\200) show
133.313 19.938 moveto
(\\200) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.125 24.000 moveto
(\\217) show
121.000 24.000 moveto
(!) show
123.688 24.000 moveto
(!) show
126.375 24.000 moveto
(!) show
127.063 24.000 moveto
(!) show
121.438 30.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
138.313 19.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{269.563, 294.063},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004=00019R000`400?l00000o`00003oo`3oool>
0?ooo`00o`3oool>0?ooo`00o`3oool>0?ooo`00o`3oool>0?ooo`00J`3oool5000002/0oooo1`00
001[0?ooo`00JP3oool00`000000oooo0000000P0?ooo`D000002`3oool00`000000oooo0000001]
0?ooo`00JP3oool00`000000oooo0000000W0?ooo`D00000103oool00`000000oooo0000001]0?oo
o`00JP3oool00`000000oooo0000000300000180oooo00<000000?ooo`3oool0203oool5000000/0
oooo00<000000?ooo`000000K@3oool006X0oooo00<000000?ooo`0000000P3oool010000000oooo
0?ooo`3oool300000080oooo0P0000000`3oool000000?ooo`030?ooo`030000003oool0000000@0
oooo0`00000C0?ooo`030000003oool0000006d0oooo001[0?ooo`@000001@3oool00`000000oooo
0?ooo`030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0140oooo1@00001]0?ooo`00M03oool00`000000oooo0?ooo`020?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0PP3oool007@0oooo00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo06`0oooo001c0?ooo`8000000`3oool010000000oooo0000003oool5000000<0oooo00H00000
0?ooo`3oool000000?ooo`0000230?ooo`00N@3oool00`000000oooo0?ooo`080?ooo`050000003o
ool0oooo0?ooo`000000Q03oool007@0oooo00<000000?ooo`3oool0UP3oool00?l0oooo3P3oool0
0?l0oooo3P3oool00?l0oooo3P3oool00?l0oooo3P3oool00?l0oooo3P3oool00?l0oooo3P3oool0
0?l0oooo3P3oool00?l0oooo3P3oool008D0oooo0P00oon60?ooo`00@P3oool00`000000oooo0?oo
o`0o0?ooo`@00?ooIP3oool00`000000oooo0?ooo`0L0?ooo`00@P3oool00`000000oooo0?ooo`0d
0?ooo`X0ool01P00ool80?oo05d0oooo00<000000?ooo`3oool0703oool00440oooo0P0000060?oo
o`D000009@3oool60?oo00X0oooo1P00ool80?ooo`T0ool0D`3oool2000000D0oooo1@00000D0?oo
o`00@@3oool00`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000007`3oool60?oo
0140oooo1000oolB0?ooo`H0ool0C@3oool00`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`000000503oool00400oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`0M
0?ooo`<0ool0603oool3003ooaP0oooo0`3oo`190?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool05@3oool003h0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01H0oooo1P3oo`0K0?ooo`<00?oo6`3oool60?oo0440oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo000o0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?oo
o`<0ool0803oool4003oob40oooo0`3oo`0o0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0C0?ooo`00A03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00h0oooo0`3oo`0S0?ooo`@00?oo903oool30?oo0440oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0B0?ooo`00A03oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000003@3oool30?oo02H0oooo1@00oolV0?ooo`80ool0?`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool04P3oool004@0oooo00<000000?ooo`3o
ool00`3oool3000000/0oooo0`3oo`0Y0?ooo`D00?oo:03oool30?oo03`0oooo00<000000?ooo`3o
ool00P3oool3000001D0oooo00150?ooo`030000003oool0oooo00h0oooo0P3oo`0[0?ooo`H00?oo
:`3oool20?oo03/0oooo00<000000?ooo`3oool06@3oool004D0oooo00<000000?ooo`3oool03@3o
ool00`3oo`00oooo0?ooo`0[0?ooo`H00?oo;@3oool20?oo03T0oooo00<000000?ooo`3oool06@3o
ool000X0oooo1@00000f0?ooo``000000P3oool20?oo02h0oooo1`00ool^0?ooo`80ool01@00000b
0?ooo``00000403oool000T0oooo00<000000?ooo`000000803oool5000001l0oooo0`3oo`0_0?oo
o`P00?oo;`3oool00`000000ool00000000O0?ooo`D00000;@3oool000T0oooo00<000000?ooo`00
0000:03ooolV000002P0oooo2000ool_0?ooo`030000003oool000000080ool09P3ooolN000000/0
oooo00090?ooo`030000003oool0000000<000007@3oool5000001/0oooo0P3oo`0h0?ooo`03003o
o`3oool0oooo0300oooo00<000000?ooo`0000000`0000000`3oo`00oooo0?ooo`0I0?ooo`D00000
;@3oool000T0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo02L0oooo00<0ool00?ooo`3oool0>03oool00`00ool0oooo0?ooo`0`0?ooo`030000003o
ool000000080oooo00@000000?ooo`3oo`00ool03P3oool00`000000oooo0?ooo`0j0?ooo`002P3o
ool4000000<0oooo0`0000030?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000
1@3oool3000001l0oooo0P3oo`0k0?ooo`03003oo`3oool0oooo0340oooo100000030?ooo`<00000
0`3oool00`000000oooo000000040?ooo`030000003oool0000000H0oooo0`00000c0?ooo`004P3o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`80ool0?@3oool00`00
ool0oooo0?ooo`0i0?ooo`030000003oool0ool00080oooo00@000000?ooo`3oool000000P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0<P3oool00180oooo00<00000
0?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo000000@0oooo00@000000?ooo`3oool0
oooo1000000D0?ooo`D000000`3oool00`3oo`00oooo0?ooo`0:0?ooo`L00000;03oool00`00ool0
oooo0?ooo`0i0?ooo`030000003oool0oooo0080ool000L000000?ooo`3oool0oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool4000000`0oooo1@00000?0?ooo`L00000303oool0
0180oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0000000@0oooo00L00000
0?ooo`3oool0oooo0000003oool0000001L0oooo00@000000?ooo`3oool0oooo0P3oo`0?0?ooo`03
0000003oool0000002h0oooo00<00?oo0?ooo`3oool0>@3oool00`000000oooo0?ooo`020?ooo`07
0?oo00000000oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000003`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0000000h0oooo000A0?oo
o`8000000`3oool010000000oooo0?ooo`3oool5000000@0oooo00@000000?ooo`3oool0oooo0P00
000=0?ooo`D000001@3oool010000000oooo0?oo003oo`040?ooo`D00000203oool00`000000oooo
0000000^0?ooo`03003oo`3oool0oooo03P0oooo0P0000030?ooo`040000003oool000000?oo00D0
00000`3oool00`000000oooo0?ooo`020?ooo`8000003`3oool00`000000oooo0?ooo`050?ooo`D0
00001`3oool00`000000oooo0000000>0?ooo`005P3oool3000000X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0E0?ooo`030000003oo`00oooo0180oooo00<000000?ooo`000000
;P3oool00`00ool0oooo0?ooo`0m0?ooo`<000000P3oool00`3oo`00oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0000000h0oooo000B0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0000000^0?ooo`03003oo`3oool0oooo03T0oooo00<000000?ooo`3oool01`3o
ool00`3oo`00oooo0?ooo`0I0?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000003P3o
ool003l0oooo00<0ool00000003oool04@3oool5000002h0oooo00<00?oo0?ooo`3oool0A03oool0
0`3oo`00oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo1@00000>0?ooo`00?@3oool20?oo
00030?ooo`000000oooo04@0oooo00<00?oo0?ooo`3oool0A@3oool20?oo01P0oooo00<000000?oo
o`3oool08P3oool003`0oooo00<0ool00?ooo`3oool00P00000E0?ooo`030000003oool0oooo02d0
oooo00<00?oo0?ooo`3oool0A`3oool00`3oo`00oooo0?ooo`0D0?ooo`800000503oool00`000000
oooo0?ooo`0=0?ooo`00>`3oool00`3oo`00oooo0?ooo`180?ooo`03003oo`3oool0oooo04P0oooo
00<0ool00?ooo`3oool0>@3oool003T0oooo0P3oo`1;0?ooo`03003oo`3oool0oooo04T0oooo00<0
ool00?ooo`3oool0>03oool003L0oooo0P3oo`1=0?ooo`03003oo`3oool0oooo04X0oooo0P3oo`0h
0?ooo`00=P3oool00`3oo`00oooo0?ooo`1=0?ooo`03003oo`3oool0oooo04`0oooo0P3oo`0f0?oo
o`00=@3oool00`3oo`00oooo0?ooo`1>0?ooo`03003oo`3oool0oooo04h0oooo00<0ool00?ooo`3o
ool0<`3oool003@0oooo00<0ool00?ooo`3oool0C`3oool00`00ool0oooo0?ooo`1?0?ooo`030?oo
003oool0oooo0380oooo000c0?ooo`030?oo003oool0oooo0500oooo00<00?oo0?ooo`3oool0D03o
ool00`3oo`00oooo0?ooo`0a0?ooo`00;`3oool20?o0b`030?ooo`3oo`00oooo0580oooo00<00?oo
0?ooo`3oool0D@3oool00`3oo`00ogl00?mo000`0?ooo`00;P3oool40?o0b`030?oo003oool0oooo
0540oooo00<00?oo0?ooo`3oool0D@3oool40?mo02l0oooo000]0?ooo`H0ol3;D`3oool00`00ool0
oooo0?ooo`1@0?ooo`H0ogl0;P3oool002d0oooo1P3o`<]C0?ooo`03003oo`3oool0oooo0500oooo
1P3oO`0^0?ooo`00;P3oool40?o0be@0oooo00<00?oo0?ooo`3oool0D@3oool40?mo02l0oooo000]
0?ooo`030?oo003oool0ol3;00@0ol3;DP3oool00`00ool0oooo0?ooo`1?0?ooo`D0ogl000<0oooo
0?oo003oool0;@3oool002`0oooo00<0ool00?ooo`3oool00P3oool40?o0be40oooo00<00?oo0?oo
o`3oool0CP3oool40?mo00@0oooo00<0ool00?ooo`3oool0:`3oool002/0oooo00<0ool00?ooo`3o
ool0103oool50?o0bdl0oooo00<00?oo0?ooo`3oool0C03oool60?mo00D0oooo00<0ool00?ooo`3o
ool0:P3oool002X0oooo00<0ool00?ooo`3oool01@3oool70?o0bdd0oooo00<00?oo0?ooo`3oool0
BP3oool70?mo00L0oooo00<0ool00?ooo`3oool0:@3oool002T0oooo00<0ool00?ooo`3oool01`3o
ool80?o0bd/0oooo00<00?oo0?ooo`3oool0B03oool80?mo00T0oooo00<0ool00?ooo`3oool0:03o
ool002P0oooo00<0ool00?ooo`3oool02@3oool80?o0bdX0oooo00<00?oo0?ooo`3oool0A`3oool9
0?mo00T0oooo00<0ool00?ooo`3oool0:03oool002L0oooo00<0ool00?ooo`3oool02P3oool70?o0
bd/0oooo00<00?oo0?ooo`3oool0B03oool70?mo00/0oooo00<0ool00?ooo`3oool09`3oool002L0
oooo00<0ool00?ooo`3oool02`3oool50?o0bd`0oooo00<00?oo0?ooo`3oool0B@3oool60?mo00`0
oooo00<0ool00?ooo`3oool09P3oool002H0oooo00<0ool00?ooo`3oool03@3oool40?o0bd`0oooo
00<00?oo0?ooo`3oool0B@3oool50?mo00h0oooo00<0ool00?ooo`3oool09@3oool002D0oooo00<0
ool00?ooo`3oool03P3oool30?o0b`030?ooo`3o`</0oooo04X0oooo00<00?oo0?ooo`3oool0B03o
ool00`3oO`00oooo0?ooo`030?mo00l0oooo00<0ool00?ooo`3oool0903oool002@0oooo00<0ool0
0?ooo`3oool0403oool01@3o`</0oooo0?ooo`3oool0ol3;04X0oooo00<00?oo0?ooo`3oool0A`3o
ool00`3oO`00oooo0?ooo`020?ooo`030?mo003oool0oooo00l0oooo00<0ool00?ooo`3oool08`3o
ool002@0oooo00<0ool00?ooo`3oool05@3oool00`3o`</0oooo0?ooo`170?ooo`03003oo`3oool0
oooo04H0oooo00<0ogl00?ooo`3oool05P3oool00`3oo`00oooo0?ooo`0R0?ooo`008`3oool00`3o
o`00oooo0?ooo`0G0?ooo`030?o0b`3oool0oooo04H0oooo00<00?oo0?ooo`3oool0A@3oool00`3o
O`00oooo0?ooo`0G0?ooo`030?oo003oool0oooo0280oooo000S0?ooo`030?oo003oool0oooo01P0
oooo00<0ol3;0?ooo`3oool0A@3oool00`00ool0oooo0?ooo`140?ooo`030?mo003oool0oooo01T0
oooo00<0ool00?ooo`3oool08@3oool00280oooo00<0ool00?ooo`3oool06P3oool00`3o`</0oooo
0?ooo`140?ooo`03003oo`3oool0oooo04<0oooo00<0ogl00?ooo`3oool06`3oool00`3oo`00oooo
0?ooo`0P0?ooo`008@3oool00`3oo`00oooo0?ooo`0L0?ooo`030?o0b`3oool0oooo04<0oooo00<0
0?oo0?ooo`3oool0@P3oool00`3oO`00oooo0?ooo`0M0?ooo`030?oo003oool0oooo01l0oooo000P
0?ooo`030?oo003oool0oooo01h0oooo00<0ol3;0?ooo`3oool0@P3oool00`00ool0oooo0?ooo`11
0?ooo`030?mo003oool0oooo01h0oooo00<0ool00?ooo`3oool07`3oool00200oooo00<0ool00?oo
o`3oool07`3oool00`3o`</0oooo0?ooo`110?ooo`03003oo`3oool0oooo0400oooo00<0ogl00?oo
o`3oool0803oool00`3oo`00oooo0?ooo`0N0?ooo`007`3oool00`3oo`00oooo0?ooo`0Q0?ooo`03
0?o0b`3oool0oooo0400oooo00<00?oo0?ooo`3oool0?`3oool00`3oO`00oooo0?ooo`0Q0?ooo`03
0?oo003oool0oooo01h0oooo000N0?ooo`030?oo003oool0oooo02<0oooo00<0ol3;0?ooo`3oool0
?`3oool00`00ool0oooo0?ooo`0n0?ooo`030?mo003oool0oooo02<0oooo00<0ool00?ooo`3oool0
7@3oool001h0oooo00<0ool00?ooo`3oool0903oool00`3o`</0oooo0?ooo`0n0?ooo`03003oo`3o
ool0oooo03d0oooo00<0ogl00?ooo`3oool09@3oool00`3oo`00oooo0?ooo`0L0?ooo`007@3oool0
0`3oo`00oooo0?ooo`0V0?ooo`030?o0b`3oool0oooo03d0oooo00<00?oo0?ooo`3oool0?03oool0
0`3oO`00oooo0?ooo`0W0?ooo`030?oo003oool0oooo01/0oooo000M0?ooo`030?oo003oool0oooo
02L0oooo00<0ol3;0?ooo`3oool0?03oool00`00ool0oooo0?ooo`0k0?ooo`030?mo003oool0oooo
02P0oooo00<0ool00?ooo`3oool06`3oool001`0oooo00<0ool00?ooo`3oool0:@3oool00`3o`</0
oooo0?ooo`0k0?ooo`03003oo`3oool0oooo03X0oooo00<0ogl00?ooo`3oool0:P3oool00`3oo`00
oooo0?ooo`0J0?ooo`00703oool00`3oo`00oooo0?ooo`0Z0?ooo`030?o0b`3oool0oooo03X0oooo
00<00?oo0?ooo`3oool0>@3oool00`3oO`00oooo0?ooo`0[0?ooo`030?oo003oool0oooo01X0oooo
000K0?ooo`030?oo003oool0oooo02`0oooo00<0ol3;0?ooo`3oool0>@3oool00`00ool0oooo0?oo
o`0h0?ooo`030?mo003oool0oooo02d0oooo00<0ool00?ooo`3oool06@3oool001/0oooo00<0ool0
0?ooo`3oool0;@3oool00`3o`</0oooo0?ooo`0h0?ooo`03003oo`3oool0oooo03L0oooo00<0ogl0
0?ooo`3oool0;P3oool00`3oo`00oooo0?ooo`0I0?ooo`006P3oool00`3oo`00oooo0?ooo`0_0?oo
o`030?o0b`3oool0oooo03L0oooo00<00?oo0?ooo`3oool0=P3oool00`3oO`00oooo0?ooo`0_0?oo
o`030?oo003oool0oooo01T0oooo000I0?ooo`030?oo003oool0oooo0340oooo00<0ol3;0?ooo`3o
ool0=P3oool00`00ool0oooo0?ooo`0e0?ooo`030?mo003oool0oooo0340oooo00<0ool00?ooo`3o
ool0603oool001T0oooo00<0ool00?ooo`3oool0<P3oool00`3o`</0oooo0?ooo`0e0?ooo`03003o
o`3oool0oooo03@0oooo00<0ogl00?ooo`3oool0<`3oool00`3oo`00oooo0?ooo`0G0?ooo`00603o
ool00`3oo`00oooo0?ooo`0d0?ooo`030?o0b`3oool0oooo03@0oooo00<00?oo0?ooo`3oool0<`3o
ool00`3oO`00oooo0?ooo`0d0?ooo`030?oo003oool0oooo01L0oooo000H0?ooo`030?oo003oool0
oooo03D0oooo00<0ol3;0?ooo`3oool0<`3oool00`00ool0oooo0?ooo`0b0?ooo`030?mo003oool0
oooo03H0oooo00<0ool00?ooo`3oool05P3oool001P0oooo00<0ool00?ooo`3oool0=P3oool00`3o
`</0oooo0?ooo`0b0?ooo`03003oo`3oool0oooo0340oooo00<0ogl00?ooo`3oool0=`3oool00`3o
o`00oooo0?ooo`0F0?ooo`005`3oool00`3oo`00oooo0?ooo`0h0?ooo`030?o0b`3oool0oooo0340
oooo00<00?oo0?ooo`3oool0<03oool00`3oO`00oooo0?ooo`0i0?ooo`030?oo003oool0oooo01D0
oooo000G0?ooo`030?oo003oool0oooo03T0oooo00<0ol3;0?ooo`3oool0<03oool00`00ool0oooo
0?ooo`0_0?ooo`030?mo003oool0oooo03X0oooo00<0ool00?ooo`3oool05@3oool001H0oooo00<0
ool00?ooo`3oool0>`3oool00`3o`</0oooo0?ooo`0_0?ooo`03003oo`3oool0oooo02h0oooo00<0
ogl00?ooo`3oool0>`3oool00`3oo`00oooo0?ooo`0E0?ooo`005P3oool00`3oo`00oooo0?ooo`0l
0?ooo`030?o0b`3oool0oooo02h0oooo00<00?oo0?ooo`3oool0;@3oool00`3oO`00oooo0?ooo`0m
0?ooo`030?oo003oool0oooo01@0oooo000E0?ooo`030?oo003oool0oooo03h0oooo00<0ol3;0?oo
o`3oool0;@3oool00`00ool0oooo0?ooo`0/0?ooo`030?mo003oool0oooo03h0oooo00<0ool00?oo
o`3oool0503oool001@0oooo00<0ool00?ooo`3oool0@03oool00`3o`</0oooo0?ooo`0/0?ooo`03
003oo`3oool0oooo02/0oooo00<0ogl00?ooo`3oool0?`3oool00`3oo`00oooo0?ooo`0D0?ooo`00
503oool00`3oo`00oooo0?ooo`110?ooo`030?o0b`3oool0oooo02/0oooo00<00?oo0?ooo`3oool0
:P3oool00`3oO`00oooo0?ooo`110?ooo`030?oo003oool0oooo01<0oooo000D0?ooo`030?oo003o
ool0oooo0480oooo00<0ol3;0?ooo`3oool0:P3oool00`00ool0oooo0?ooo`0Y0?ooo`030?mo003o
ool0oooo04<0oooo00<0ool00?ooo`3oool04P3oool001<0oooo00<0ool00?ooo`3oool0A03oool2
0?o0bbX0oooo00<00?oo0?ooo`3oool0:03oool00`3oO`00oooo0?ooo`140?ooo`030?oo003oool0
oooo0180oooo000C0?ooo`030?oo003oool0oooo04H0oooo00<0ol3;0?ooo`3oool09`3oool00`00
ool0oooo0?ooo`0W0?ooo`030?mo003oool0oooo04H0oooo00<0ool00?ooo`3oool04@3oool001<0
oooo00<0ool00?ooo`3oool0A`3oool00`3o`</0oooo0?ooo`0V0?ooo`03003oo`3oool0oooo02H0
oooo00<0ogl00?ooo`3oool0A`3oool00`3oo`00oooo0?ooo`0A0?ooo`004P3oool00`3oo`00oooo
0?ooo`190?ooo`030?o0b`3oool0oooo02D0oooo00<00?oo0?ooo`3oool09@3oool00`3oO`00oooo
0?ooo`190?ooo`030?oo003oool0oooo0100oooo000B0?ooo`030?oo003oool0oooo04X0oooo00<0
ol3;0?ooo`3oool0903oool00`00ool0oooo0?ooo`0T0?ooo`030?mo003oool0oooo04X0oooo00<0
ool00?ooo`3oool0403oool00180oooo00<0ool00?ooo`3oool0B`3oool00`3o`</0oooo0?ooo`0S
0?ooo`03003oo`3oool0oooo02<0oooo00<0ogl00?ooo`3oool0B`3oool00`3oo`00oooo0?ooo`0@
0?ooo`004@3oool00`3oo`00oooo0?ooo`1=0?ooo`030?o0b`3oool0oooo0280oooo00<00?oo0?oo
o`3oool08P3oool00`3oO`00oooo0?ooo`1<0?ooo`030?oo003oool0oooo0100oooo000A0?ooo`03
0?oo003oool0oooo04h0oooo00<0ol3;0?ooo`3oool08@3oool00`00ool0oooo0?ooo`0Q0?ooo`03
0?mo003oool0oooo04d0oooo00<0ool00?ooo`3oool0403oool00140oooo00<0ool00?ooo`3oool0
C`3oool00`3o`</0oooo0?ooo`0P0?ooo`03003oo`3oool0oooo0200oooo00<0ogl00?ooo`3oool0
CP3oool00`3oo`00oooo0?ooo`0@0?ooo`00403oool00`3oo`00oooo0?ooo`1A0?ooo`030?o0b`3o
ool0oooo01l0oooo00<00?oo0?ooo`3oool07`3oool00`3oO`00oooo0?ooo`1@0?ooo`030?oo003o
ool0oooo00l0oooo000@0?ooo`030?oo003oool0oooo0580oooo00<0ol3;0?ooo`3oool07P3oool0
0`00ool0oooo0?ooo`0N0?ooo`030?mo003oool0oooo0540oooo00<0ool00?ooo`3oool03`3oool0
0100oooo00<0ool00?ooo`3oool0D`3oool00`3o`</0oooo0?ooo`0M0?ooo`03003oo`3oool0oooo
01d0oooo00<0ogl00?ooo`3oool0DP3oool00`3oo`00oooo0?ooo`0?0?ooo`003`3oool00`3oo`00
oooo0?ooo`1E0?ooo`030?o0b`3oool0oooo01`0oooo00<00?oo0?ooo`3oool0703oool00`3oO`00
oooo0?ooo`1D0?ooo`030?oo003oool0oooo00h0oooo000?0?ooo`030?oo003oool0oooo05H0oooo
00<0ol3;0?ooo`3oool06`3oool00`00ool0oooo0?ooo`0K0?ooo`030?mo003oool0oooo05D0oooo
00<0ool00?ooo`3oool03P3oool000l0oooo00<0ool00?ooo`3oool0E`3oool00`3o`</0oooo0?oo
o`0J0?ooo`03003oo`3oool0oooo01X0oooo00<0ogl00?ooo`3oool0EP3oool00`3oo`00oooo0?oo
o`0>0?ooo`003`3oool00`3oo`00oooo0?ooo`1H0?ooo`030?o0b`3oool0oooo01T0oooo00<00?oo
0?ooo`3oool06@3oool00`3oO`00oooo0?ooo`1H0?ooo`030?oo003oool0oooo00d0oooo000?0?oo
o`030?oo003oool0oooo05T0oooo00<0ol3;0?ooo`3oool0603oool00`00ool0oooo0?ooo`0H0?oo
o`030?mo003oool0oooo05T0oooo00<0ool00?ooo`3oool03@3oool000l0oooo00<0ool00?ooo`3o
ool0FP3oool00`3o`</0oooo0?ooo`0G0?ooo`03003oo`3oool0oooo01L0oooo00<0ogl00?ooo`3o
ool0FP3oool00`3oo`00oooo0?ooo`0=0?ooo`003P3oool00`3oo`00oooo0?ooo`1L0?ooo`030?o0
b`3oool0oooo01H0oooo00<00?oo0?ooo`3oool05P3oool00`3oO`00oooo0?ooo`1K0?ooo`030?oo
003oool0oooo00d0oooo000>0?ooo`030?oo003oool0oooo05d0oooo00<0ol3;0?ooo`3oool05@3o
ool00`00ool0oooo0?ooo`0E0?ooo`030?mo003oool0oooo05`0oooo00<0ool00?ooo`3oool03@3o
ool000h0oooo00<0ool00?ooo`3oool0GP3oool00`3o`</0oooo0?ooo`0D0?ooo`03003oo`3oool0
oooo01@0oooo00<0ogl00?ooo`3oool0G@3oool00`3oo`00oooo0?ooo`0=0?ooo`003P3oool00`3o
o`00oooo0?ooo`1O0?ooo`030?o0b`3oool0oooo01<0oooo00<00?oo0?ooo`3oool04`3oool00`3o
O`00oooo0?ooo`1O0?ooo`030?oo003oool0oooo00`0oooo000>0?ooo`030?oo003oool0oooo0600
oooo00<0ol3;0?ooo`3oool04P3oool00`00ool0oooo0?ooo`0B0?ooo`030?mo003oool0oooo0600
oooo00<0ool00?ooo`3oool0303oool000h0oooo00<0ool00?ooo`3oool0H@3oool00`3o`</0oooo
0?ooo`0A0?ooo`03003oo`3oool0oooo0140oooo00<0ogl00?ooo`3oool0H@3oool00`3oo`00oooo
0?ooo`0<0?ooo`003@3oool00`3oo`00oooo0?ooo`1S0?ooo`030?o0b`3oool0oooo0100oooo00<0
0?oo0?ooo`3oool0403oool00`3oO`00oooo0?ooo`1R0?ooo`030?oo003oool0oooo00`0oooo000=
0?ooo`030?oo003oool0oooo06@0oooo00<0ol3;0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?
0?ooo`030?mo003oool0oooo06<0oooo00<0ool00?ooo`3oool0303oool000d0oooo00<0ool00?oo
o`3oool0I@3oool00`3o`</0oooo0?ooo`0>0?ooo`03003oo`3oool0oooo00h0oooo00<0ogl00?oo
o`3oool0I03oool00`3oo`00oooo0?ooo`0<0?ooo`003@3oool00`3oo`00oooo0?ooo`1V0?ooo`03
0?o0b`3oool0oooo00d0oooo00<00?oo0?ooo`3oool03@3oool00`3oO`00oooo0?ooo`1V0?ooo`03
0?oo003oool0oooo00/0oooo000=0?ooo`030?oo003oool0oooo06L0oooo00<0ol3;0?ooo`3oool0
303oool00`00ool0oooo0?ooo`0<0?ooo`030?mo003oool0oooo06L0oooo00<0ool00?ooo`3oool0
2`3oool000d0oooo00<0ool00?ooo`3oool0J03oool00`3o`</0oooo0?ooo`0;0?ooo`03003oo`3o
ool0oooo00/0oooo00<0ogl00?ooo`3oool0J03oool00`3oo`00oooo0?ooo`0;0?ooo`00303oool0
0`3oo`00oooo0?ooo`1Z0?ooo`030?o0b`3oool0oooo00X0oooo00<00?oo0?ooo`3oool02P3oool0
0`3oO`00oooo0?ooo`1Y0?ooo`030?oo003oool0oooo00/0oooo000<0?ooo`030?oo003oool0oooo
06/0oooo00<0ol3;0?ooo`3oool02@3oool00`00ool0oooo0?ooo`090?ooo`030?mo003oool0oooo
06X0oooo00<0ool00?ooo`3oool02`3oool000`0oooo00<0ool00?ooo`3oool0K03oool00`3o`</0
oooo0?ooo`080?ooo`03003oo`3oool0oooo00P0oooo00<0ogl00?ooo`3oool0J`3oool00`3oo`00
oooo0?ooo`0;0?ooo`00303oool00`3oo`00oooo0?ooo`1]0?ooo`030?o0b`3oool0oooo00L0oooo
00<00?oo0?ooo`3oool01`3oool00`3oO`00oooo0?ooo`1/0?ooo`030?oo003oool0oooo00/0oooo
000<0?ooo`030?oo003oool0oooo06h0oooo00<0ol3;0?ooo`3oool01P3oool00`00ool0oooo0?oo
o`060?ooo`030?mo003oool0oooo06h0oooo00<0ool00?ooo`3oool02P3oool000`0oooo00<0ool0
0?ooo`3oool0K`3oool00`3o`</0oooo0?ooo`050?ooo`03003oo`3oool0oooo00D0oooo00<0ogl0
0?ooo`3oool0K`3oool00`3oo`00oooo0?ooo`0:0?ooo`00303oool00`3oo`00oooo0?ooo`1`0?oo
o`030?o0b`3oool0oooo00@0oooo00<00?oo0?ooo`3oool0103oool00`3oO`00oooo0?ooo`1`0?oo
o`030?oo003oool0oooo00X0oooo000<0?ooo`030?oo003oool0oooo0740oooo00<0ol3;0?ooo`3o
ool00`3oool00`00ool0oooo0?ooo`030?ooo`030?mo003oool0oooo0740oooo00<0ool00?ooo`3o
ool02P3oool000`0oooo00<0ool00?ooo`3oool0LP3oool00`3o`</0oooo0?ooo`020?ooo`03003o
o`3oool0oooo0080oooo00<0ogl00?ooo`3oool0LP3oool00`3oo`00oooo0?ooo`0:0?ooo`00303o
ool00`3oo`00oooo0?ooo`1c0?ooo`050?o0b`3oool0oooo0?ooo`00ool00`3oool00`3oO`00oooo
0?ooo`1c0?ooo`030?oo003oool0oooo00X0oooo000<0?ooo`030?oo003oool0oooo00P0oooo0`3o
0?mY0?ooo`040?o0b`3oool0oooo003oo`80oooo00<0ogl00?ooo`3oool0IP3oool30?l000/0oooo
00<0ool00?ooo`3oool02P3oool000/0oooo0P3o0?l60?ooo`L0o`3oJP3oool01@3o`</0oooo003o
o`3oool0ogl006T0oooo1`3o00060?ooo`80o`00303oool000X0oooo103o0?l00`3oool0o`3o0?l0
o`090?l0of/0oooo00<0ol3;003oo`3oO`00JP3oool@0?l000/0oooo00090?ooogd0o`3o00<0ogl0
0?l0003o0000NP3o000:0?ooo`002@3ooolA0?l0of/0oooo00<0ObXZ003o00000?l0JP3ooolA0?l0
00X0oooo000:0?ooo`@0o`3o1@3oool70?l0ofX0oooo00D0ObXZ0?ooo`00o`00oooo0000o`1Y0?oo
o`P0o`00103oool40?l000/0oooo000;0?ooo`80o`3o2P3oool30?l0ofT0oooo00@0ObXZ0?ooo`3o
ool00?l00P3oool00`000?l0oooo0?ooo`1V0?ooo`<0o`002P3oool20?l000`0oooo000<0?ooo`03
0?oo003oool0oooo07<0oooo00D0ObXZ0?ooo`3oool0oooo003o00030?ooo`030000o`3oool0oooo
07<0oooo00<0ool00?ooo`3oool02P3oool000`0oooo00<0ool00?ooo`3oool0LP3oool00`1o:RX0
oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3oool0LP3oool00`3oo`00
oooo0?ooo`0:0?ooo`00303oool00`3oo`00oooo0?ooo`1a0?ooo`0307lZ:P3oool0oooo00<0oooo
00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`1a0?ooo`030?oo003oool0oooo00X0oooo
000<0?ooo`030?oo003oool0oooo0700oooo00<0ObXZ0?ooo`3oool0103oool00`00o`00oooo0?oo
o`040?ooo`030000o`3oool0oooo0700oooo00<0ool00?ooo`3oool02P3oool000`0oooo00<0ool0
0?ooo`3oool0K`3oool00`1o:RX0oooo0?ooo`050?ooo`03003o003oool0oooo00D0oooo00<0003o
0?ooo`3oool0K`3oool00`3oo`00oooo0?ooo`0:0?ooo`00303oool00`3oo`00oooo0?ooo`0:0?oo
o`D000002@3oool500000540oooo00<0ObXZ0?ooo`3oool01P3oool00`00o`00oooo0?ooo`060?oo
o`030000o`3oool0oooo04@0oooo1@00000I0?ooo`D000001`3oool00`3oo`00oooo0?ooo`0:0?oo
o`00303oool00`3oo`00oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo1@000000103oool0
00000?ooo`00001C0?ooo`0307lZ:P3oool0oooo00L0oooo00<00?l00?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`120?ooo`030000003oool0000001D0oooo1@0000040?ooo`030000003oool0oooo
00H0oooo0P3oo`0<0?ooo`00303oool00`3oo`00oooo0?ooo`020?ooo`D000001@3oool00`000000
oooo0?ooo`080?ooo`030000003oool000000580oooo00<0ObXZ0?ooo`3oool0203oool00`00o`00
oooo0?ooo`080?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`0000007P3oool00`000000
oooo0?ooo`060?ooo`030?oo003oool0oooo00/0oooo000<0?ooo`030?oo003oool0oooo00`0oooo
00<000000?ooo`3oool00P3oool5000000030?ooo`000000oooo00@00000CP3oool00`1o:RX0oooo
0?ooo`090?ooo`03003o003oool0oooo00T0oooo00<0003o0?ooo`3oool0@03oool00`000000oooo
0000000300000180oooo1@0000040?ooo`030000003oool0oooo00H0oooo00<0ool00?ooo`3oool0
2`3oool000`0oooo00<0ool00?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool0B`3oool00`1o:RX0oooo0?ooo`0:0?ooo`03003o003o
ool0oooo00X0oooo00<0003o0?ooo`3oool0?`3oool00`000000oooo000000020?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool01P3oool00`3oo`00oooo0?ooo`0;0?ooo`00303oool0
0`3oo`00oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo100000030?ooo`@00000103oool0
0`000000oooo0?ooo`0o0?ooo`0307lZ:P3oool0oooo00/0oooo00<00?l00?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0o0?ooo`@000000`3oool3000000<0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<0ool00?ooo`3oool02`3oool0
00d0oooo00<0ool00?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0?`3oool00`1o:RX0oooo0?ooo`0<0?ooo`03003o003oool0
oooo00`0oooo00<0003o0?ooo`3oool0AP3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`3oo`00
oooo0?ooo`0;0?ooo`003@3oool00`3oo`00oooo0?ooo`0:0?ooo`8000004`3oool01`000000oooo
0?ooo`3oool000000?ooo`000000@03oool00`1o:RX0oooo0?ooo`0=0?ooo`03003o003oool0oooo
00d0oooo00<0003o0?ooo`3oool0A@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool00`000000oooo0000000;0?ooo`800000203oool00`3oo`00oooo0?ooo`0;0?ooo`003@3oool0
0`3oo`00oooo0?ooo`0O0?ooo`070000003oool0oooo0?ooo`000000oooo0000000o0?ooo`0307lZ
:P3oool0oooo00h0oooo00<00?l00?ooo`3oool03P3oool00`000?l0oooo0?ooo`140?ooo`070000
003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0000001@0oooo00<0ool00?oo
o`3oool0303oool000d0oooo00<0ool00?ooo`3oool07P3oool200000080oooo1@00000m0?ooo`03
07lZ:P3oool0oooo00l0oooo00<00?l00?ooo`3oool03`3oool00`000?l0oooo0?ooo`120?ooo`80
00000`3oool010000000oooo0000003oool5000001<0oooo00<0ool00?ooo`3oool0303oool000d0
oooo00<0ool00?ooo`3oool0H`3oool00`1o:RX0oooo0?ooo`0@0?ooo`03003o003oool0oooo0100
oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`0H0?ooo`030?oo003oool0oooo00`0
oooo000>0?ooo`030?oo003oool0oooo01h0oooo00<000000?ooo`3oool0@03oool00`1o:RX0oooo
0?ooo`0A0?ooo`03003o003oool0oooo0140oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo
0?ooo`0M0?ooo`030?oo003oool0oooo00`0oooo000>0?ooo`030?oo003oool0oooo0600oooo00<0
ObXZ0?ooo`3oool04P3oool00`00o`00oooo0?ooo`0B0?ooo`030000o`3oool0oooo0600oooo00<0
ool00?ooo`3oool0303oool000h0oooo00<0ool00?ooo`3oool0G`3oool00`1o:RX0oooo0?ooo`0C
0?ooo`03003o003oool0oooo01<0oooo00<0003o0?ooo`3oool0G`3oool00`3oo`00oooo0?ooo`0<
0?ooo`003P3oool00`3oo`00oooo0?ooo`1N0?ooo`0307lZ:P3oool0oooo01@0oooo00<00?l00?oo
o`3oool0503oool00`000?l0oooo0?ooo`1M0?ooo`030?oo003oool0oooo00d0oooo000>0?ooo`03
0?oo003oool0oooo05d0oooo00<0ObXZ0?ooo`3oool05@3oool00`00o`00oooo0?ooo`0E0?ooo`03
0000o`3oool0oooo05`0oooo00<0ool00?ooo`3oool03@3oool000h0oooo00<0ool00?ooo`3oool0
G03oool00`1o:RX0oooo0?ooo`0F0?ooo`03003o003oool0oooo01H0oooo00<0003o0?ooo`3oool0
F`3oool00`3oo`00oooo0?ooo`0=0?ooo`003`3oool00`3oo`00oooo0?ooo`1J0?ooo`0307lZ:P3o
ool0oooo01L0oooo00<00?l00?ooo`3oool05`3oool00`000?l0oooo0?ooo`1J0?ooo`030?oo003o
ool0oooo00d0oooo000?0?ooo`030?oo003oool0oooo05T0oooo00<0ObXZ0?ooo`3oool0603oool0
0`00o`00oooo0?ooo`0H0?ooo`030000o`3oool0oooo05T0oooo00<0ool00?ooo`3oool03@3oool0
00l0oooo00<0ool00?ooo`3oool0F03oool00`1o:RX0oooo0?ooo`0I0?ooo`03003o003oool0oooo
01T0oooo00<0003o0?ooo`3oool0F03oool00`3oo`00oooo0?ooo`0=0?ooo`003`3oool00`3oo`00
oooo0?ooo`1G0?ooo`0307lZ:P3oool0oooo01X0oooo00<00?l00?ooo`3oool06P3oool00`000?l0
oooo0?ooo`1F0?ooo`030?oo003oool0oooo00h0oooo000?0?ooo`030?oo003oool0oooo05H0oooo
00<0ObXZ0?ooo`3oool06`3oool00`00o`00oooo0?ooo`0K0?ooo`030000o`3oool0oooo05D0oooo
00<0ool00?ooo`3oool03P3oool000l0oooo00<0ool00?ooo`3oool0E@3oool00`1o:RX0oooo0?oo
o`0L0?ooo`03003o003oool0oooo01`0oooo00<0003o0?ooo`3oool0E03oool00`3oo`00oooo0?oo
o`0>0?ooo`00403oool00`3oo`00oooo0?ooo`1C0?ooo`0307lZ:P3oool0oooo01d0oooo00<00?l0
0?ooo`3oool07@3oool00`000?l0oooo0?ooo`1B0?ooo`030?oo003oool0oooo00l0oooo000@0?oo
o`030?oo003oool0oooo0580oooo00<0ObXZ0?ooo`3oool07P3oool00`00o`00oooo0?ooo`0N0?oo
o`030000o`3oool0oooo0540oooo00<0ool00?ooo`3oool03`3oool00100oooo00<0ool00?ooo`3o
ool0D@3oool00`1o:RX0oooo0?ooo`0O0?ooo`03003o003oool0oooo01l0oooo00<0003o0?ooo`3o
ool0D03oool00`3oo`00oooo0?ooo`0?0?ooo`004@3oool00`3oo`00oooo0?ooo`1?0?ooo`0307lZ
:P3oool0oooo0200oooo00<00?l00?ooo`3oool0803oool00`000?l0oooo0?ooo`1>0?ooo`030?oo
003oool0oooo0100oooo000A0?ooo`030?oo003oool0oooo04h0oooo00<0ObXZ0?ooo`3oool08@3o
ool00`00o`00oooo0?ooo`0Q0?ooo`030000o`3oool0oooo04d0oooo00<0ool00?ooo`3oool0403o
ool00140oooo00<0ool00?ooo`3oool0C@3oool00`1o:RX0oooo0?ooo`0R0?ooo`03003o003oool0
oooo0280oooo00<0003o0?ooo`3oool0C03oool00`3oo`00oooo0?ooo`0@0?ooo`004P3oool00`3o
o`00oooo0?ooo`1;0?ooo`0307lZ:P3oool0oooo02<0oooo00<00?l00?ooo`3oool08`3oool00`00
0?l0oooo0?ooo`1:0?ooo`030?oo003oool0oooo0140oooo000B0?ooo`030?oo003oool0oooo04X0
oooo00<0ObXZ0?ooo`3oool0903oool00`00o`00oooo0?ooo`0T0?ooo`030000o`3oool0oooo04T0
oooo00<0ool00?ooo`3oool04@3oool00180oooo00<0ool00?ooo`3oool0B@3oool00`1o:RX0oooo
0?ooo`0U0?ooo`03003o003oool0oooo02D0oooo00<0003o0?ooo`3oool0B03oool00`3oo`00oooo
0?ooo`0A0?ooo`004`3oool00`3oo`00oooo0?ooo`170?ooo`0307lZ:P3oool0oooo02H0oooo00<0
0?l00?ooo`3oool09P3oool00`000?l0oooo0?ooo`160?ooo`030?oo003oool0oooo0180oooo000C
0?ooo`030?oo003oool0oooo04H0oooo00<0ObXZ0?ooo`3oool09`3oool00`00o`00oooo0?ooo`0W
0?ooo`030000o`3oool0oooo04D0oooo00<0ool00?ooo`3oool04P3oool001<0oooo00<0ool00?oo
o`3oool0A03oool207lZ:RX0oooo00<00?l00?ooo`3oool0:03oool00`000?l0oooo0?ooo`140?oo
o`030?oo003oool0oooo0180oooo000D0?ooo`030?oo003oool0oooo0480oooo00<0ObXZ0?ooo`3o
ool0:P3oool00`00o`00oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0480oooo00<0ool00?ooo`3o
ool04`3oool001@0oooo00<0ool00?ooo`3oool0@@3oool00`1o:RX0oooo0?ooo`0[0?ooo`03003o
003oool0oooo02X0oooo00<0003o0?ooo`3oool0@@3oool00`3oo`00oooo0?ooo`0C0?ooo`00503o
ool00`3oo`00oooo0?ooo`100?ooo`0307lZ:P3oool0oooo02`0oooo00<00?l00?ooo`3oool0:`3o
ool00`000?l0oooo0?ooo`0o0?ooo`030?oo003oool0oooo01@0oooo000E0?ooo`030?oo003oool0
oooo03h0oooo00<0ObXZ0?ooo`3oool0;@3oool00`00o`00oooo0?ooo`0/0?ooo`030000o`3oool0
oooo03h0oooo00<0ool00?ooo`3oool0503oool001H0oooo00<0ool00?ooo`3oool0?03oool00`1o
:RX0oooo0?ooo`0^0?ooo`03003o003oool0oooo02d0oooo00<0003o0?ooo`3oool0?@3oool00`3o
o`00oooo0?ooo`0D0?ooo`005P3oool00`3oo`00oooo0?ooo`0k0?ooo`0307lZ:P3oool0oooo02l0
oooo00<00?l00?ooo`3oool0;P3oool00`000?l0oooo0?ooo`0k0?ooo`030?oo003oool0oooo01D0
oooo000G0?ooo`030?oo003oool0oooo03T0oooo00<0ObXZ0?ooo`3oool0<03oool00`00o`00oooo
0?ooo`0_0?ooo`030000o`3oool0oooo03X0oooo00<0ool00?ooo`3oool05@3oool001L0oooo00<0
ool00?ooo`3oool0>03oool00`1o:RX0oooo0?ooo`0a0?ooo`03003o003oool0oooo0300oooo00<0
003o0?ooo`3oool0>@3oool00`3oo`00oooo0?ooo`0E0?ooo`00603oool00`3oo`00oooo0?ooo`0f
0?ooo`0307lZ:P3oool0oooo0380oooo00<00?l00?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0g
0?ooo`030?oo003oool0oooo01H0oooo000H0?ooo`030?oo003oool0oooo03D0oooo00<0ObXZ0?oo
o`3oool0<`3oool00`00o`00oooo0?ooo`0b0?ooo`030000o`3oool0oooo03H0oooo00<0ool00?oo
o`3oool05P3oool001P0oooo00<0ool00?ooo`3oool0=03oool00`1o:RX0oooo0?ooo`0d0?ooo`03
003o003oool0oooo03<0oooo00<0003o0?ooo`3oool0=03oool00`3oo`00oooo0?ooo`0G0?ooo`00
6@3oool00`3oo`00oooo0?ooo`0b0?ooo`0307lZ:P3oool0oooo03D0oooo00<00?l00?ooo`3oool0
=03oool00`000?l0oooo0?ooo`0c0?ooo`030?oo003oool0oooo01L0oooo000I0?ooo`030?oo003o
ool0oooo0340oooo00<0ObXZ0?ooo`3oool0=P3oool00`00o`00oooo0?ooo`0e0?ooo`030000o`3o
ool0oooo0340oooo00<0ool00?ooo`3oool0603oool001X0oooo00<0ool00?ooo`3oool0;`3oool0
0`1o:RX0oooo0?ooo`0g0?ooo`03003o003oool0oooo03H0oooo00<0003o0?ooo`3oool0;`3oool0
0`3oo`00oooo0?ooo`0I0?ooo`006`3oool00`3oo`00oooo0?ooo`0]0?ooo`0307lZ:P3oool0oooo
03P0oooo00<00?l00?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0^0?ooo`030?oo003oool0oooo
01T0oooo000K0?ooo`030?oo003oool0oooo02`0oooo00<0ObXZ0?ooo`3oool0>@3oool00`00o`00
oooo0?ooo`0h0?ooo`030000o`3oool0oooo02d0oooo00<0ool00?ooo`3oool06@3oool001`0oooo
00<0ool00?ooo`3oool0:P3oool00`1o:RX0oooo0?ooo`0j0?ooo`03003o003oool0oooo03T0oooo
00<0003o0?ooo`3oool0:`3oool00`3oo`00oooo0?ooo`0J0?ooo`00703oool00`3oo`00oooo0?oo
o`0Y0?ooo`0307lZ:P3oool0oooo03/0oooo00<00?l00?ooo`3oool0>P3oool00`000?l0oooo0?oo
o`0Z0?ooo`030?oo003oool0oooo01X0oooo000M0?ooo`030?oo003oool0oooo02L0oooo00<0ObXZ
0?ooo`3oool0?03oool00`00o`00oooo0?ooo`0k0?ooo`030000o`3oool0oooo02P0oooo00<0ool0
0?ooo`3oool06`3oool001d0oooo00<0ool00?ooo`3oool09P3oool00`1o:RX0oooo0?ooo`0m0?oo
o`03003o003oool0oooo03`0oooo00<0003o0?ooo`3oool09`3oool00`3oo`00oooo0?ooo`0K0?oo
o`007P3oool00`3oo`00oooo0?ooo`0T0?ooo`0307lZ:P3oool0oooo03h0oooo00<00?l00?ooo`3o
ool0?@3oool00`000?l0oooo0?ooo`0U0?ooo`030?oo003oool0oooo01`0oooo000N0?ooo`030?oo
003oool0oooo02<0oooo00<0ObXZ0?ooo`3oool0?`3oool00`00o`00oooo0?ooo`0n0?ooo`030000
o`3oool0oooo02<0oooo00<0ool00?ooo`3oool07@3oool001l0oooo00<0ool00?ooo`3oool08@3o
ool00`1o:RX0oooo0?ooo`100?ooo`03003o003oool0oooo03l0oooo00<0003o0?ooo`3oool08@3o
ool00`3oo`00oooo0?ooo`0N0?ooo`00803oool00`3oo`00oooo0?ooo`0O0?ooo`0307lZ:P3oool0
oooo0440oooo00<00?l00?ooo`3oool0@03oool00`000?l0oooo0?ooo`0P0?ooo`030?oo003oool0
oooo01h0oooo000P0?ooo`030?oo003oool0oooo01h0oooo00<0ObXZ0?ooo`3oool0@P3oool00`00
o`00oooo0?ooo`110?ooo`030000o`3oool0oooo01h0oooo00<0ool00?ooo`3oool07`3oool00240
oooo00<0ool00?ooo`3oool0703oool00`1o:RX0oooo0?ooo`130?ooo`03003o003oool0oooo0480
oooo00<0003o0?ooo`3oool07@3oool00`3oo`00oooo0?ooo`0O0?ooo`008P3oool00`3oo`00oooo
0?ooo`0J0?ooo`0307lZ:P3oool0oooo04@0oooo00<00?l00?ooo`3oool0@`3oool00`000?l0oooo
0?ooo`0K0?ooo`030?oo003oool0oooo0200oooo000S0?ooo`030?oo003oool0oooo01P0oooo00<0
ObXZ0?ooo`3oool0A@3oool00`00o`00oooo0?ooo`140?ooo`030000o`3oool0oooo01T0oooo00<0
ool00?ooo`3oool08@3oool002<0oooo00<0ool00?ooo`3oool05`3oool00`1o:RX0oooo0?ooo`16
0?ooo`03003o003oool0oooo04D0oooo00<0003o0?ooo`3oool05`3oool00`3oo`00oooo0?ooo`0R
0?ooo`00903oool00`3oo`00oooo0?ooo`0E0?ooo`0307lZ:P3oool0oooo04L0oooo00<00?l00?oo
o`3oool0AP3oool00`000?l0oooo0?ooo`0F0?ooo`030?oo003oool0oooo0280oooo000T0?ooo`03
0?oo003oool0oooo0100oooo00D0ObXZ0?ooo`3oool0oooo07lZ:P1:0?ooo`03003o003oool0oooo
04L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0?0?ooo`030?oo003oool0oooo
02<0oooo000U0?ooo`030?oo003oool0oooo00h0oooo0`1o:RX00`3oool0ObXZ0?ooo`1:0?ooo`03
003o003oool0oooo04P0oooo00<0003o0?ooo`3oool00`000?l?0?ooo`030?oo003oool0oooo02@0
oooo000V0?ooo`030?oo003oool0oooo00d0oooo101o:RY<0?ooo`03003o003oool0oooo04T0oooo
1@000?l>0?ooo`030?oo003oool0oooo02D0oooo000W0?ooo`030?oo003oool0oooo00/0oooo1@1o
:RY<0?ooo`03003o003oool0oooo04T0oooo1P000?l<0?ooo`030?oo003oool0oooo02H0oooo000X
0?ooo`030?oo003oool0oooo00T0oooo1`1o:RY;0?ooo`03003o003oool0oooo04P0oooo1`000?l;
0?ooo`030?oo003oool0oooo02L0oooo000Y0?ooo`030?oo003oool0oooo00P0oooo201o:RY:0?oo
o`03003o003oool0oooo04L0oooo2@000?l90?ooo`030?oo003oool0oooo02P0oooo000Y0?ooo`03
0?oo003oool0oooo00L0oooo201o:RY;0?ooo`03003o003oool0oooo04P0oooo20000?l90?ooo`03
0?oo003oool0oooo02P0oooo000Z0?ooo`030?oo003oool0oooo00D0oooo1`1o:RY=0?ooo`03003o
003oool0oooo04X0oooo1`000?l70?ooo`030?oo003oool0oooo02T0oooo000[0?ooo`030?oo003o
ool0oooo00@0oooo1@1o:RY?0?ooo`03003o003oool0oooo04`0oooo1P000?l50?ooo`030?oo003o
ool0oooo02X0oooo000/0?ooo`030?oo003oool0oooo0080oooo1@1o:RY@0?ooo`03003o003oool0
oooo04d0oooo1@000?l40?ooo`030?oo003oool0oooo02/0oooo000]0?ooo`030?oo003oool0ObXZ
00@0ObXZDP3oool00`00o`00oooo0?ooo`1?0?ooo`D0003o00<0oooo0?oo003oool0;@3oool002h0
oooo101o:RYD0?ooo`03003o003oool0oooo0540oooo10000?l_0?ooo`00;@3oool607lZ:U<0oooo
00<00?l00?ooo`3oool0D03oool60000obh0oooo000]0?ooo`H0ObXZD`3oool00`00o`00oooo0?oo
o`1@0?ooo`H0003o;P3oool002h0oooo101o:RX00`3oo`00oooo0?ooo`1A0?ooo`03003o003oool0
oooo0540oooo10000?l_0?ooo`00;`3oool207lZ:P80oooo00<0ool00?ooo`3oool0303oool00`00
0000oooo0?ooo`110?ooo`03003o003oool0oooo0500oooo00@0ool00?ooo`000?l0003o4P3oool0
0`000000oooo0?ooo`0K0?ooo`00=03oool00`3oo`00oooo0?ooo`0;0?ooo`030000003oool0oooo
00@0oooo1@00000h0?ooo`03003o003oool0oooo04l0oooo00<0ool00?ooo`3oool0503oool00`00
0000oooo0?ooo`030?ooo`D000004`3oool003D0oooo00<0ool00?ooo`3oool02@3oool2000000H0
oooo00D000000?ooo`3oool0oooo0000000h0?ooo`03003o003oool0oooo04h0oooo00<0ool00?oo
o`3oool0503oool2000000D0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`00=P3oool00`3o
o`00oooo0?ooo`080?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0>@3oool00`00
o`00oooo0?ooo`1<0?ooo`80ool05`3oool00`000000oooo000000050?ooo`030000003oool0oooo
01@0oooo000g0?ooo`030?oo003oool0oooo00H0oooo00@000000?ooo`3oool000001`3oool00`00
0000oooo0?ooo`0h0?ooo`03003o003oool0oooo04/0oooo00<0ool00?ooo`3oool05P3oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo01<0oooo000h0?ooo`80ool0103oool00`00
0000oooo000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`00
o`00oooo0?ooo`1:0?ooo`030?oo003oool0oooo01D0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo000j0?ooo`030?oo003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03H0
oooo00<00?l00?ooo`3oool0B@3oool00`3oo`00oooo0?ooo`0G0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00>`3oool00`3oo`00oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000h0?ooo`03
003o003oool0oooo04L0oooo0P3oo`0O0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0A0?ooo`00?03oool00`3oo`00oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo0`00000i0?ooo`03003o003oool0oooo04H0oooo00<0ool00?ooo`3oool07`3oool00`000000
oooo0?ooo`020?ooo`<00000503oool003d0oooo0P3oo`050?ooo`030000003oool0oooo03l0oooo
00<00?l00?ooo`3oool0A@3oool00`3oo`00oooo0?ooo`0P0?ooo`030000003oool0oooo01T0oooo
000o0?ooo`030?oo003oool0oooo00<0oooo00<000000?ooo`3oool0?P3oool00`00o`00oooo0?oo
o`140?ooo`030?oo003oool0oooo0280oooo00<000000?ooo`3oool0603oool00400oooo00<0ool0
0?ooo`3oool00P3oool00`000000oooo0?ooo`0n0?ooo`03003o003oool0oooo04<0oooo00<0ool0
0?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`002P3oool500000380oooo00@0ool00?oo
o`3oool0oooo3000000e0?ooo`03003o003oool0oooo03L0oooo1@0000060?ooo`030?oo003oool0
oooo02@0oooo3000000?0?ooo`002@3oool00`000000oooo0000000P0?ooo`D000004@3oool20?oo
0480oooo00<00?l00?ooo`3oool0=P3oool00`000000oooo000000070?ooo`80ool04@3oool50000
02`0oooo00090?ooo`030000003oool0000002P0oooo9P00000/0?ooo`03003o003oool0oooo03H0
oooo00<000000?ooo`0000001@3oool20?oo01`0oooo7P00000:0?ooo`002@3oool00`000000oooo
0000000300000180oooo00<000000?ooo`3oool0203oool5000001@0oooo0P3oo`0o0?ooo`03003o
003oool0oooo03H0oooo00<000000?ooo`0000000`0000020?oo00/0oooo00<000000?ooo`3oool0
1`3oool5000002`0oooo00090?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`00
00020?ooo`80000000<0oooo0000003oool00`3oool010000000oooo0?ooo`0000050?ooo`<00000
7@3oool20?oo03d0oooo00<00?l00?ooo`3oool0=P3oool00`000000oooo000000020?ooo`030000
003oool0oooo00@00000103oool010000000oooo0?ooo`0000050?ooo`<00000<P3oool000X0oooo
100000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool00`3oo`00oooo
0?ooo`0j0?ooo`03003o003oool0oooo03L0oooo100000040?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0340
oooo000B0?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool00000
00@0oooo00@000000?ooo`3oool0oooo1000000P0?ooo`80ool0>P3oool00`00o`00oooo0?ooo`0g
0?ooo`80ool01P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool010000000oooo
0?ooo`3oool400000380oooo000B0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool0
00000?ooo`0000040?ooo`070000003oool0oooo0?ooo`000000oooo0000000E0?ooo`D000001`3o
ool010000000oooo0?oo003oo`050?ooo`L00000;03oool00`00o`00oooo0?ooo`0e0?ooo`80ool0
203oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01`000000oooo0?ooo`3oool0
00000?ooo`0000003@3oool5000000L0oooo00<000000?ooo`3oool01@3oool7000000/0oooo000A
0?ooo`8000000`3oool010000000oooo0000003oool5000000@0oooo00@000000?ooo`3oool0oooo
0P00000G0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0oooo0P3oo`050?ooo`03
0000003oool0000002X0oooo2000o`0c0?ooo`030?oo003oool0oooo00L0oooo0P0000020?ooo`D0
0000103oool010000000oooo0?ooo`3oool2000000l0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0000000d0oooo000G0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`D000001@3oool00`000000
oooo0?ooo`050?ooo`D000000`3oool30?oo0080oooo00<000000?ooo`000000:P3oool8003o0300
oooo0`3oo`0G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`050?ooo`D000001`3oool00`000000oooo0000000=0?ooo`004P3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool20?oo00030000
003oool0000002/0oooo1`00o`0]0?ooo`<0ool03P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000=0?ooo`00@03o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo00000000:`3o
ool6003o02`0oooo0P3oo`0b0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0000000=0?ooo`00@03oool00`000000oooo0?ooo`0@0?ooo`D0000000<0ool0
0?ooo`3oool0:03oool6003o02X0oooo0P3oo`0d0?ooo`030000003oool0oooo00l0oooo1@00000=
0?ooo`00@03oool00`000000oooo0?ooo`0F0?ooo`80ool0:@3oool5003o02T0oooo00<0ool00?oo
o`3oool0=03oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool2000001D0oooo00<000000?ooo`3o
ool00P3oool30?oo02H0oooo1@00o`0V0?ooo`<0ool0=P3oool2000001@0oooo00<000000?ooo`3o
ool0303oool005h0oooo0`3oo`0S0?ooo`@00?l0903oool30?oo05h0oooo001Q0?ooo`H0ool07@3o
ool4003o01h0oooo1P3oo`1Q0?ooo`00I`3oool30?oo01/0oooo0`00o`0K0?ooo`<0ool0I`3oool0
06X0oooo0`3oo`0H0?ooo`<00?l0603oool30?oo06X0oooo001]0?ooo`H0ool04P3oool2003o01<0
oooo1P3oo`1]0?ooo`00L`3oool90?oo00P0oooo1000o`0:0?ooo`P0ool0L`3oool007`0oooo1`3o
o`06003o00T0ool0N`3oool008<0oooo1P00o`240?ooo`00Q03oool4003o08D0oooo00250?ooo`80
0?l0QP3oool00?l0oooo3P3oool00?l0oooo3P3oool00?l0oooo3P3oool00780oooo1@00000N0?oo
o`L00000L@3oool00740oooo00<000000?ooo`0000006P3oool5000000@0oooo00<000000?ooo`00
0000L`3oool00740oooo00<000000?ooo`0000008`3oool00`000000oooo0000001c0?ooo`00L@3o
ool00`000000oooo00000003000001L0oooo1@0000040?ooo`030000003oool0000007<0oooo001a
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0000007<0oooo001b0?ooo`@000000`3oool4000000@0oooo00<000000?oo
o`000000103oool3000000X0oooo1@00001c0?ooo`00NP3oool010000000oooo0?ooo`0000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`220?ooo`00NP3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0LP3oool007X0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`00N@3o
ool200000080oooo1@0000030?ooo`060000003oool0oooo0000003oool00000PP3oool008D0oooo
00D000000?ooo`3oool0oooo000000230?ooo`00NP3oool00`000000oooo0?ooo`2@0?ooo`00o`3o
ool>0?ooo`00o`3oool>0?ooo`00o`3oool>0?ooo`00o`3oool>0?ooo`00o`3oool>0?ooo`00o`3o
ool>0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 268.563}, {293.063, 0}} -> {-1, -1, 0, 0}}],
  StyleBox["   \n\t\t\tFigure 1.18",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The eight eighth roots of unity."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the polynomial  ",
  Cell[BoxData[
      \(P[z] = z\^8 - 1\)],
    AspectRatioFixed->True],
  "  and find its zeros."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[k, list, set, solset, values, xx, yy, 
        z];\)\ \), "\[IndentingNewLine]", 
    \(\(P[z_]\  = \ z\^8\  - \ 1\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[P[z] \[Equal] 0, z];\)\ \), "\n", 
    \(\(values\  = \ 
        solset[\([Table[k, {k, Length[solset]}], 1, 2]\)];\)\ \), "\n", 
    \(\(set\  = \ 
        N[solset[\([Table[k, {k, Length[solset]}], 1, 2]\)]];\)\ \), "\n", 
    \(\(set\  = \ \ ReplaceAll[set, xx_Real \[Rule] {xx, 0}];\)\ \), "\n", 
    \(\(list\  = \ \ ReplaceAll[set, 
          Complex[xx_, yy_] \[Rule] {xx, yy}];\)\ \), "\[IndentingNewLine]", 
    \(\(ListPlot[list, 
        Prolog \[Rule] {PointSize[0.03], 
            Green}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \[IndentingNewLine]Ticks \
\[Rule] {{\(-1\), \(-1\)\/\@2, 1\/\@2, 1}, {\(-1\), \(-1\)\/\@2, 1\/\@2, 
              1}}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1.1\), 
              1.1}, {\(-1.1\), 1.1}}];\)\ \), "\[IndentingNewLine]", 
    \(\(For[k = 0, 
        k \[LessEqual] 
          7, \(k++\), \[IndentingNewLine]Print["\<z\>"\_k, "\< = Cos[\>", \
\(\(\ \)\(2\ \[Pi]\ k\)\)\/8, "\<] + \[ImaginaryI] Sin[\>", \(\(\ \)\(2\ \
\[Pi]\ k\)\)\/8, "\<] = \>", 
          Cos[\(\(\ \)\(2\ \[Pi]\ k\)\)\/8] + \[ImaginaryI]\ Sin[\(\(\ \)\(2\ \
\[Pi]\ k\)\)\/8]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<P[z] = \>", P[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve \>", P[z] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<The roots of  \!\(z\^8\) = 1  are\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(1\^\(1\/8\)\) = \>\"", 
        values];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The expanded form of the roots are\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(1\^\(1\/8\)\) = \>\"", 
        ComplexExpand[values]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tThe procedure for solving  ",
  Cell[BoxData[
      \(z\^n = 1\)]],
  "  is easy to generalize in solving  ",
  Cell[BoxData[
      \(z\^n = c\)]],
  "  for any nonzero complex number ",
  StyleBox["c",
    FontFamily->"Courier New"],
  ".  If  ",
  Cell[BoxData[
      RowBox[{"c", "=", 
        RowBox[{
          RowBox[{"\[Rho]", " ", 
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                StyleBox["\[ImaginaryI]",
                  FontSize->10], 
                StyleBox[" ",
                  FontSize->10], "\[Phi]"}]]}], " ", 
          "=", \(\[Rho] \((cos\ \[Phi] + \[ImaginaryI]\ sin\ \
\[Phi])\)\)}]}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{"z", "=", 
        RowBox[{"r", " ", 
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{
              StyleBox["\[ImaginaryI]",
                FontSize->10], 
              StyleBox[" ",
                FontSize->10], "\[Theta]"}]]}]}]]],
  ",  then  ",
  Cell[BoxData[
      \(z\^n = c\)]],
  "  iff  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(r\^n\), " ", 
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{
              StyleBox["\[ImaginaryI]",
                FontSize->10], 
              StyleBox[" ",
                FontSize->10], 
              StyleBox["n",
                FontSize->10], 
              StyleBox[" ",
                FontSize->10], "\[Theta]"}]]}], "=", 
        RowBox[{"\[Rho]", " ", 
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{
              StyleBox["\[ImaginaryI]",
                FontSize->10], 
              StyleBox[" ",
                FontSize->10], "\[Phi]"}]]}]}]]],
  ".  But this last equation is satisfied iff\n\n\t\t\t",
  Cell[BoxData[
      \(r\^n\  = \ \[Rho]\)]],
  ",   and   ",
  Cell[BoxData[
      \(n\ \[Theta]\  = \ \[Phi]\  + \ 2\ k\ \[Pi]\)]],
  ",   where ",
  StyleBox["k",
    FontFamily->"Courier New"],
  " is an integer.\n\nAs before, we get ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " distinct solutions given by  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        SubscriptBox["z", 
          StyleBox["k",
            FontSize->10]], " ", "=", "  ", 
        RowBox[{
          RowBox[{\(\[Rho]\^\(1\/n\)\), 
            SuperscriptBox["\[ExponentialE]", 
              StyleBox[\(\[ImaginaryI]\ \(\[Phi]\  + \ 2\ \[Pi]\ k\)\/n\),
                FontSize->10]]}], " ", "=", 
          " ", \(\(\[Rho]\^\(1\/n\)\) \((cos \( \[Phi]\  + \ 2\ \[Pi]\ k\)\/n \
+ \[ImaginaryI]\ sin \( \[Phi]\  + \ 2\ \[Pi]\ k\)\/n)\)\)}]}]]],
  "   for   ",
  Cell[BoxData[
      \(k = 0, 1, \[CenterEllipsis], n - 1\)]],
  ".   \n\n\tEach of the above solutions can be considered an ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " root of ",
  StyleBox["c",
    FontFamily->"Courier New"],
  ".  Geometrically, the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " roots of ",
  StyleBox["c",
    FontFamily->"Courier New"],
  " are equally spaced points that lie on the circle  ",
  Cell[BoxData[
      \(C\_\(\[Rho]\^\(1\/n\)\)\  = \ {z : \ \ \(\(|\)\(z\)\(|\)\) = \[Rho]\^\
\(1\/n\)}\)]],
  "  and form the vertices of a regular polygon with ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " sides.  Figure 1.19 illustrates the case for ",
  StyleBox["n=5",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.15385 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.461538 0.384615 0.384615 0.384615 [
[1.025 .38462 0 -6.28125 ]
[1.025 .38462 10 6.28125 ]
[.46154 1.17885 -5 0 ]
[.46154 1.17885 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1.15385 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .38462 m
1 .38462 L
s
gsave
1.025 .38462 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.46154 0 m
.46154 1.15385 L
s
gsave
.46154 1.17885 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.15385 L
0 1.15385 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 0 1 r
.5 Mabswid
newpath
.46154 .38462 .51923 0 73.125 arc
s
1 0 0 r
newpath
.46154 .38462 .30769 0 14.625 arc
s
1 0 1 r
.46154 .38462 m
.68483 1.12072 L
s
% Start of user PostScript
0 0 0.580569 1.91388 MAarrowhead1
% End of user PostScript
1 0 0 r
.46154 .38462 m
.88903 .49617 L
s
% Start of user PostScript
0 0 1.11148 0.290037 MAarrowhead1
% End of user PostScript
0 0 1 r
.46154 .38462 m
.48755 .82566 L
s
% Start of user PostScript
0 0 0.0676248 1.14671 MAarrowhead1
% End of user PostScript
0 1 0 r
.46154 .38462 m
.05012 .54564 L
s
% Start of user PostScript
0 0 -1.06969 0.418667 MAarrowhead1
% End of user PostScript
1 .5 0 r
.46154 .38462 m
.18126 .04309 L
s
% Start of user PostScript
0 0 -0.728727 -0.887956 MAarrowhead1
% End of user PostScript
0 1 1 r
.46154 .38462 m
.69973 .01252 L
s
% Start of user PostScript
0 0 0.619307 -0.967454 MAarrowhead1
% End of user PostScript
1 0 1 r
.025 w
.68483 1.12072 Mdot
1 0 0 r
.88903 .49617 Mdot
0 0 1 r
.48755 .82566 Mdot
0 1 0 r
.05012 .54564 Mdot
1 .5 0 r
.18126 .04309 Mdot
0 1 1 r
.69973 .01252 Mdot
0 g
gsave
.83868 1.08226 -93.625 -11.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.125 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.125 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 11.563 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
75.813 16.125 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
83.000 16.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
90.188 16.125 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
97.375 16.125 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r\\343) show
111.750 11.563 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344f) show
124.250 16.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.89288 .53463 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.50678 .87181 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05012 .59179 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.09664 .08925 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75358 .05098 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58615 .65385 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
70.188 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.73077 .48077 -74.5313 -11.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
70.188 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.313 10.375 moveto
(\\220) show
80.438 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
86.063 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.92308 .69231 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
70.188 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83462 .41154 -73.7813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.188 12.813 moveto
(\\220) show
77.375 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
84.563 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{249.563, 287.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003i00017b000`400?l00000o`00003oJ`3oool0
0`000000oooo0?ooo`2;0?ooo`00J`3oool00`000000oooo0?ooo`0c0?ooo`<00?ooE@3oool006/0
oooo00<000000?ooo`3oool0<P3oool5003ooe@0oooo001[0?ooo`030000003oool0oooo0380oooo
1@00oomD0?ooo`00J`3oool00`000000oooo0?ooo`0b0?ooo`D00?ooE03oool006/0oooo00<00000
0?ooo`3oool0<@3oool5003ooeD0oooo001[0?ooo`030000003oool0oooo0300oooo1000oomG0?oo
o`00J`3oool00`000000oooo0?ooo`0`0?ooo`<00?ooF03oool002P0oooo0`3oO`100?ooo`030000
003oool0oooo02l0oooo1000oolA0?ooo`<00000A03oool002L0oooo1@3oO`0o0?ooo`030000003o
ool0oooo02h0oooo1@00oolB0?ooo`030000003oool0oooo04<0oooo000W0?ooo`D0ogl0?`3oool0
0`000000oooo0?ooo`0]0?ooo`D00?oo2@3oool5000000<0oooo100000140?ooo`009`3oool50?mo
03l0oooo00<000000?ooo`3oool0;03oool6003oo`X0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo000000150?ooo`00:03oool60?mo03d0oooo00<000000?ooo`3oool0;@3oool5003o
o`/0oooo00<000000?ooo`3oool0103oool2000004D0oooo000[0?ooo`@0ogl0?03oool00`000000
oooo0?ooo`0]0?ooo`@00?oo3@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04<0
oooo000/0?ooo`@0ogl0>`3oool00`000000oooo0?ooo`0/0?ooo`05003oo`3oool0oooo0?ooo`00
ool02`3oool010000000oooo0?ooo`00001;0?ooo`00;03oool60?mo03T0oooo00<000000?ooo`3o
ool0;03oool00`00ool0oooo0?ooo`0=0?ooo`D00000BP3oool002d0oooo1P3oO`0h0?ooo`030000
003oool0oooo02/0oooo00<00?oo0?ooo`3oool0G@3oool00200oooo0P00000;0?ooo`L0ogl0=`3o
ool00`000000oooo0?ooo`0[0?ooo`03003oo`3oool0oooo05d0oooo000R0?ooo`030000003oool0
oooo00T0oooo1@3oO`0h0?ooo`030000003oool0oooo02X0oooo00<00?oo0?ooo`3oool0GP3oool0
01T0oooo1@0000030?ooo`030000003oool0oooo00X0oooo103oO`0i0?ooo`030000003oool0oooo
02T0oooo00<00?oo0?ooo`3oool0G`3oool001X0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0:0?ooo`040?mo003oool0oooo0?mo03P0oooo00<000000?ooo`3oool0:@3oool0
0`00ool0oooo0?ooo`1O0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
0100oooo00<0ogl00?ooo`3oool0=@3oool00`000000oooo0?ooo`0X0?ooo`03003oo`3oool0oooo
0600oooo000L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`3oO`00
oooo0?ooo`0d0?ooo`030000003oool0oooo02L0oooo00<00?oo0?ooo`3oool0H@3oool001X0oooo
00@000000?ooo`3oool000005`3oool00`3oO`00oooo0?ooo`0c0?ooo`030000003oool0oooo02L0
oooo00<00?oo0?ooo`3oool0H@3oool001X0oooo1@00000G0?ooo`030?mo003oool0oooo0380oooo
00<000000?ooo`3oool09P3oool00`00ool0oooo0?ooo`1R0?ooo`00=P3oool00`3oO`00oooo0?oo
o`0b0?ooo`030000003oool0oooo02D0oooo00<00?oo0?ooo`3oool0H`3oool003L0oooo00<0ogl0
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0U0?ooo`03003oo`3oool0oooo06<0oooo000h0?oo
o`030?mo003oool0oooo0300oooo00<000000?ooo`3oool0903oool00`00ool0oooo0?ooo`1T0?oo
o`00>@3oool00`3oO`00oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo00<00?oo0?ooo`3o
ool0I03oool003X0oooo00<0ogl00?ooo`3oool0;P3oool00`000000oooo0?ooo`0S0?ooo`03003o
o`3oool0oooo06D0oooo000j0?ooo`030?mo003oool0oooo02h0oooo00<000000?ooo`3oool08P3o
ool00`00ool0oooo0?ooo`1V0?ooo`00>`3oool00`3oO`00oooo0?ooo`0]0?ooo`030000003oool0
oooo0280oooo00<00?oo0?ooo`3oool0IP3oool003`0oooo00<0ogl00?ooo`3oool0;03oool00`00
0000oooo0?ooo`0Q0?ooo`03003oo`3oool0oooo06L0oooo000m0?ooo`030?mo003oool0oooo02/0
oooo00<000000?ooo`3oool0803oool00`00ool0oooo0?ooo`1X0?ooo`00?P3oool00`3oO`00oooo
0?ooo`0Z0?ooo`030000003oool0oooo0200oooo00<00?oo0?ooo`3oool0J03oool003l0oooo00<0
ogl00?ooo`3oool0:@3oool00`000000oooo0?ooo`0O0?ooo`03003oo`3oool0oooo06T0oooo000o
0?ooo`030?mo003oool0oooo02T0oooo00<000000?ooo`3oool07`3oool00`00ool0oooo0?ooo`1Y
0?ooo`00@03oool00`3oO`00oooo0?ooo`0X0?ooo`030000003oool0oooo01h0oooo00<00?oo0?oo
o`3oool0JP3oool00440oooo00<0ogl00?ooo`3oool09`3oool00`000000oooo0?ooo`0M0?ooo`03
003oo`3oool0oooo06/0oooo00120?ooo`030?mo003oool0oooo02H0oooo00<000000?ooo`3oool0
7@3oool00`00ool0oooo0?ooo`1[0?ooo`00@`3oool00`3oO`00oooo0?ooo`0U0?ooo`030000003o
ool0oooo01`0oooo00<00?oo0?ooo`3oool0K03oool004@0oooo00<0ogl00?ooo`3oool0903oool0
0`000000oooo0?ooo`0K0?ooo`03003oo`3oool0oooo06d0oooo00140?ooo`030?mo003oool0oooo
02@0oooo00<000000?ooo`3oool06`3oool00`00ool0oooo0?ooo`1]0?ooo`00A@3oool00`3oO`00
oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo00<00?oo0?ooo`3oool0KP3oool004H0oooo
00<0ogl00?ooo`3oool08P3oool00`000000oooo0?ooo`0I0?ooo`03003oo`3oool0oooo06l0oooo
00170?ooo`030?mo003oool0oooo0240oooo00<000000?ooo`3oool06@3oool00`00ool0oooo0?oo
o`1_0?ooo`00B03oool00`3oO`00oooo0?ooo`0P0?ooo`030000003oool0oooo01P0oooo00<00?oo
0?ooo`3oool0L03oool004P0oooo00<0ogl00?ooo`3oool0803oool00`000000oooo0?ooo`0H0?oo
o`03003oo`3oool0oooo0700oooo00190?ooo`030?mo003oool0oooo01l0oooo00<000000?ooo`3o
ool05`3oool00`00ool0oooo0?ooo`1a0?ooo`00BP3oool00`3oO`00oooo0?ooo`0N0?ooo`030000
003oool0oooo01H0oooo00<00?oo0?ooo`3oool0LP3oool004/0oooo00<0ogl00?ooo`3oool07@3o
ool00`000000oooo0?ooo`0F0?ooo`03003oo`3oool0oooo0780oooo001<0?ooo`030?mo003oool0
oooo01`0oooo00<000000?ooo`3oool05@3oool00`00ool0oooo0?ooo`1c0?ooo`00C@3oool00`3o
O`00oooo0?ooo`0K0?ooo`030000003oool0oooo01@0oooo00<00?oo0?ooo`3oool0M03oool004d0
oooo00<0ogl00?ooo`3oool06`3oool00`000000oooo0?ooo`0D0?ooo`03003oo`3oool0oooo07@0
oooo001>0?ooo`030?mo003oool0oooo01X0oooo00<000000?ooo`3oool04`3oool00`00ool0oooo
0?ooo`1e0?ooo`00C`3oool00`3oO`00oooo0?ooo`0I0?ooo`030000003oool0oooo0180oooo00<0
0?oo0?ooo`3oool0MP3oool00500oooo00<0ogl00?ooo`3oool0603oool00`000000oooo0?ooo`0B
0?ooo`03003oo`3oool0oooo07H0oooo001A0?ooo`030?mo003oool0oooo01L0oooo00<000000?oo
o`3oool04@3oool00`00ool0oooo0?ooo`1g0?ooo`00D@3oool00`3oO`00oooo0?ooo`0G0?ooo`03
0000003oool0oooo0140oooo00<00?oo0?ooo`3oool0M`3oool00580oooo00<0ogl00?ooo`3oool0
5P3oool00`000000oooo0?ooo`0@0?ooo`03003oo`3oool0oooo07P0oooo001C0?ooo`030?mo003o
ool0oooo01D0oooo00<000000?ooo`3oool03`3oool00`00ool0oooo0?ooo`1i0?ooo`00E03oool0
0`3oO`00oooo0?ooo`0D0?ooo`030000003oool0oooo00l0oooo00<00?oo0?ooo`3oool0N@3oool0
05D0oooo00<0ogl00?ooo`3oool04`3oool00`000000oooo0?ooo`0>0?ooo`03003oo`3oool0oooo
07X0oooo001F0?ooo`030?mo003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`00ool0
oooo0?ooo`1k0?ooo`00EP3oool00`3oO`00oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo
00<00?oo0?ooo`3oool0N`3oool005L0oooo00<0ogl00?ooo`3oool04@3oool00`000000oooo0?oo
o`0<0?ooo`03003oo`3oool0oooo07`0oooo001H0?ooo`030?mo003oool0oooo0100oooo00<00000
0?ooo`3oool0303oool00`00ool0oooo0?ooo`1l0?ooo`00F@3oool00`3oO`00oooo0?ooo`0?0?oo
o`030000003oool0oooo00/0oooo00<00?oo0?ooo`3oool0O@3oool005X0oooo00<0ogl00?ooo`3o
ool03P3oool00`000000oooo0?ooo`0:0?ooo`03003oo`3oool0oooo07h0oooo001K0?ooo`030?mo
003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`00ool0oooo0?ooo`1n0?ooo`00F`3o
ool00`3oO`00oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<00?oo0?ooo`3oool0O`3o
ool005`0oooo00<0ogl00?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`03003oo`3oool0
oooo0800oooo001M0?ooo`030?mo003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`00
ool0oooo0?ooo`200?ooo`00GP3oool00`3oO`00oooo0?ooo`0:0?ooo`030000003oool0oooo00L0
oooo00<00?oo0?ooo`3oool0P@3oool005l0oooo00<0ogl00?ooo`3oool02@3oool00`000000oooo
0?ooo`060?ooo`03003oo`3oool0oooo0880oooo001O0?ooo`030?mo003oool0oooo00T0oooo00<0
00000?ooo`3oool01P3oool00`00ool0oooo0?ooo`220?ooo`00H03oool00`3oO`00oooo0?ooo`08
0?ooo`030000003oool0oooo00D0oooo00<00?oo0?ooo`3oool0P`3oool00640oooo00<0ogl00?oo
o`3oool01`3oool00`000000oooo0?ooo`050?ooo`03003oo`3oool0oooo08<0oooo001R0?ooo`03
0?mo003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00ool0oooo0?ooo`240?ooo`00
H`3oool00`3oO`00oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<00?oo0?ooo`3oool0
Q@3oool006@0oooo00<0ogl00?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03003oo`3o
ool0oooo08D0oooo001T0?ooo`030?mo003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0`00ool0oooo0?ooo`260?ooo`00I@3oool00`3oO`00oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`00ool0R@3oool006H0oooo00<0ogl00?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
0?oo08T0oooo001W0?ooo`050?mo003oool0oooo0?ooo`0000000P3oool00`00ool0oooo0?ooo`28
0?ooo`00J03oool0103oO`00oooo0?ooo`0000020?ooo`03003oo`3oool0oooo08P0oooo001Y0?oo
o`050?mo003oool000000?ooo`00ool0R`3oool006T0oooo00@0ogl00?ooo`0000000?ooS03oool0
06X0oooo00<0ogl000000000ool0P`3oool2000000030?ooo`000000000000@0oooo001Z00000003
003o0000ool0o`0004H0000000<0o`00000000000000;P0000000`3o0?l0000000000002000000P0
oooo00<000000?ooo`0000001@3oool006P0oooo0P00o`000`3oool0003o0?ooo`040?l00440oooo
00<0o`000?ooo`3oool0;`3oool00`3o0?l0oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo
001U0?ooo`<00?l00`3oool00`000?l0o`3o0?ooo`030?ooo`@0o`00?@3oool00`3o0000oooo0?oo
o`0_0?ooo`030?l0o`3oool0oooo00T0oooo0P0000000`3oool00000000000040?ooo`00H`3oool2
003o00H0oooo00<0003o0?l0o`3oool01`3oool40?l003T0oooo00<0o`000?ooo`3oool0103oool0
0`000000oooo0?ooo`0X0?ooo`030?l0o`3oool0oooo0180oooo001P0?ooo`<00?l0203oool00`00
0?l0o`3o0?ooo`0;0?ooo`@0o`00=@3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool08@3oool00`3o0?l0oooo0?ooo`0B0?ooo`00GP3oool2003o00/0
oooo00<0003o0?ooo`3o0?l03`3oool30?l00380oooo00<0o`000?ooo`3oool0103oool3000000@0
oooo00<000000?ooo`3oool0103oool3000001X0oooo00<0o`3o0?ooo`3oool04P3oool005/0oooo
0`00o`0=0?ooo`030000o`3oool0o`3o0180oooo103o000^0?ooo`030?l0003oool0oooo00<0oooo
00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000I0?ooo`030?l0o`3oool0oooo0180oooo001I0?ooo`800?l0403oool00`000?l0
oooo0?l0o`0F0?ooo`@0o`00:P3oool00`3o0000oooo0?ooo`030?ooo`050000003oool000000?oo
o`000000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01L0oooo00<0o`3o0?oo
o`3oool04P3oool005H0oooo0`00o`0B0?ooo`030000o`3oool0o`3o01X0oooo103o000V0?ooo`03
0?l0003oool0oooo00<0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool05`3oool00`3o0?l0oooo0?ooo`0B0?ooo`00E03oool2003o01D0
oooo00@000000000o`3oool0o`3o7@3oool40?l00280oooo00<0o`000?ooo`3oool00`3oool01@00
0000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool3000001T0oooo00<0o`3o
0?ooo`3oool04`3oool00540oooo0`00o`0G0?ooo`04000000000?l0oooo0?l0ob40oooo0`3o000O
0?ooo`030?l0003oool0oooo00@0oooo0`0000060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool06@3oool00`3o0?l0oooo0?ooo`0C0?ooo`00CP3oool3003o01X0oooo00@000000000
o`3oool0o`3o903oool40?l001/0oooo00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`3o0?l0oooo0?ooo`0C
0?ooo`00C03oool2003o01d0oooo00D000000000o`3oool0oooo0?l0o`0W0?ooo`@0o`005`3oool0
0`3o0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo1000
000H0?ooo`030?l0o`3oool0oooo01<0oooo00190?ooo`<00?l07`3oool01@000000003o0?ooo`3o
ool0o`3o02/0oooo103o000B0?ooo`030?l0003oool0oooo02l0oooo00<0o`3o0?ooo`3oool04`3o
ool004L0oooo0P00o`0R0?ooo`05000000000?l0oooo0?ooo`3o0?l0;`3oool40?l000h0oooo00<0
o`000?ooo`3oool0;`3oool00`3o0?l0oooo0?ooo`0C0?ooo`00A03oool3003o02@0oooo00<00000
0000o`3oool00P3oool00`3o0?l0oooo0?ooo`0`0?ooo`@0o`002P3oool00`3o0000oooo0?ooo`0_
0?ooo`030?l0o`3oool0oooo01<0oooo00120?ooo`800?l09`3oool00`000000003o0?ooo`020?oo
o`030?l0o`3oool0oooo03@0oooo0`3o00070?ooo`030?l0003oool0oooo02l0oooo00<0o`3o0?oo
o`3oool04`3oool003l0oooo0`00o`0Y0?ooo`03000000000?l0oooo0080oooo00<0o`3o0?ooo`3o
ool0=`3oool40?l00080oooo00<0o`000?ooo`3oool0<03oool00`3o0?l0oooo0?ooo`0C0?ooo`00
?@3oool2003o02`0oooo00<000000000o`3oool00P3oool00`3o0?l0oooo0?ooo`0[0?ooo`030000
003oool0oooo00d0oooo103o000`0?ooo`030?l0o`3oool0oooo01@0oooo000j0?ooo`<00?l0;P3o
ool00`000000003o0?ooo`030?ooo`030?l0o`3oool0oooo02X0oooo00<000000?ooo`3oool04@3o
ool40?l002`0oooo00<0o`3o0?ooo`3oool0503oool003P0oooo0P00o`0a0?ooo`03000000000?l0
oooo00<0oooo00<0o`3o0?ooo`3oool0:P3oool00`000000oooo00000002000001<0oooo103o000:
0?ooo`030?l0003oool0oooo01/0oooo00<0o`3o0?ooo`3oool0503oool003D0oooo0`00o`0c0?oo
o`03000000000?l0oooo00<0oooo00<0o`3o0?ooo`3oool0:`3oool01@000000oooo0?ooo`3oool0
000001H0oooo0`3o00070?ooo`<0o`006`3oool00`3o0?l0oooo0?ooo`0D0?ooo`00<`3oool2003o
03H0oooo00<000000000o`3oool0103oool00`3o0?l0oooo0?ooo`0Z0?ooo`050000003oool0oooo
0?ooo`0000006@3oool40?l00080oooo1P3o000I0?ooo`030?l0o`3oool0oooo01@0oooo000`0?oo
o`<00?l0>03oool00`000000003o0?ooo`040?ooo`030?l0o`3oool0oooo02X0oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo01<0oooo2@3o000G0?ooo`030?l0o`3oool0
oooo01D0oooo000^0?ooo`800?l0>`3oool00`000000003o0?ooo`040?ooo`030?l0o`3oool0oooo
02X0oooo00H000000?ooo`3oool0oooo0000003oool5000000030?ooo`000000oooo00@0oooo00<0
00000?ooo`3oool03`3oool90?l000040?ooo`3o0000o`000?l00140oooo00<0o`3o0?ooo`3oool0
5@3oool002/0oooo0`00o`0m0?ooo`03000000000?l0oooo00D0oooo00<0o`3o0?ooo`3oool0:P3o
ool3000000@0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00003`3oool?0?l00100oooo00<0o`3o0?ooo`3oool05@3oool002T0oooo0P00o`100?ooo`030000
003oool0003o00D0oooo00<0o`3o0?ooo`3oool0<@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool?0?l00100oooo00<0o`3o0?ooo`3oool0
5@3oool002H0oooo0`00o`120?ooo`030000003oool0003o00D0oooo00<0o`3o0?ooo`3oool0<@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000006P3oool50?l00100oooo
00<0o`3o0?ooo`3oool05@3oool002@0oooo0P00o`150?ooo`030000003oool0003o00H0oooo00<0
o`3o0?ooo`3oool0<03oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000001`0oooo
0`3o000@0?ooo`030?l0o`3oool0oooo01H0oooo000Q0?ooo`<00?l0A`3oool00`000000oooo0000
o`060?ooo`030?l0o`3oool0oooo02l0oooo0P0000050?ooo`030000003oool0oooo00<00000;@3o
ool00`3o0?l0oooo0?ooo`0F0?ooo`007P3oool3003o04X0oooo00<000000?ooo`000?l01P3oool0
0`3o0?l0oooo0?ooo`1Y0?ooo`030?l0o`3oool0oooo01H0oooo000E0?ooo`03003o003oool0oooo
00@0oooo0P00o`1=0?ooo`030000003oool0003o00H0oooo00<0o`3o0?ooo`3oool0J@3oool00`3o
0?l0oooo0?ooo`0F0?ooo`004`3oool3003o00<0oooo0`00o`1?0?ooo`030000003oool0003o00L0
oooo00<0o`3o0?ooo`3oool0FP3oool00`000000oooo0?ooo`0:0?ooo`030?l0o`3oool0oooo01L0
oooo000B0?ooo`L00?l0DP3oool00`000000oooo0000o`070?ooo`030?l0o`3oool0oooo0580oooo
1@0000020?ooo`030000003oool0000000/0oooo00<0o`3o0?ooo`3oool05`3oool00140oooo1P00
o`1D0?ooo`030000003oool0003o00L0oooo00<0o`3o0?ooo`3oool0D`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0000000/0oooo00<0o`3o0?ooo`3oool05`3oool000l0oooo2@00
o`1C0?ooo`030000003oool0003o00P0oooo00<0o`3o0?ooo`3oool0D`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000X0oooo00<0o`3o0?ooo`3oool0603oool000X0oooo0`00o`00
0`3oool00?l0003o0008003o05<0oooo00<000000?ooo`000?l0203oool00`3o0?l0oooo0?ooo`1D
0?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`030?l0o`3oool0oooo01P0oooo
00090?ooo``00?l0EP3oool00`000000oooo0000o`080?ooo`030?l0o`3oool0oooo0580oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`090?ooo`030?l0o`3oool0oooo01P0oooo
00090?ooo`H00?l0G03oool00`000000oooo0000o`090?ooo`030?l0o`3oool0oooo0540oooo1@00
000>0?ooo`030?l0o`3oool0oooo01P0oooo00090?ooo`D00?l0G@3oool00`000000oooo0000o`09
0?ooo`030?l0o`3oool0oooo06<0oooo00<0o`3o0?ooo`3oool06@3oool000X0oooo0`00o`1N0?oo
o`030000003oool0003o00T0oooo00<0o`3o0?ooo`3oool0H`3oool00`3o0?l0oooo0?ooo`0I0?oo
o`00J`3oool00`000000oooo0000o`090?ooo`030?l0o`3oool0oooo06<0oooo00<0o`3o0?ooo`3o
ool06@3oool006/0oooo00<000000?ooo`000?l02P3oool00`3o0?l0oooo0?ooo`1Q0?ooo`030?l0
o`3oool0oooo01X0oooo001[0?ooo`040000003oool0oooo0000o`T0oooo00<0o`3o0?ooo`3oool0
H@3oool00`3o0?l0oooo0?ooo`0J0?ooo`00J`3oool010000000oooo0?ooo`000?l90?ooo`030?l0
o`3oool0oooo0600oooo00<0o`3o0?ooo`3oool06`3oool000d0oooo0`00001K0?ooo`040000003o
ool0oooo0000o`X0oooo00<0o`3o0?ooo`3oool0G`3oool00`3o0?l0oooo0?ooo`0K0?ooo`003@3o
ool00`000000oooo0?ooo`1K0?ooo`040000003oool0oooo0000o`X0oooo00<0o`3o0?ooo`3oool0
GP3oool00`3o0?l0oooo0?ooo`0L0?ooo`001P3oool5000000<0oooo00<000000?ooo`3oool0FP3o
ool010000000oooo0?ooo`000?l:0?ooo`030?l0o`3oool0oooo05h0oooo00<0o`3o0?ooo`3oool0
703oool000L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`1J0?ooo`040000
003oool0oooo0000o`/0oooo00<0o`3o0?ooo`3oool0G03oool00`3o0?l0oooo0?ooo`0M0?ooo`00
203oool00`000000oooo0?ooo`020?ooo`030000003oool0000005/0oooo00@000000?ooo`3oool0
003o2`3oool00`3o0?l0oooo0?ooo`1L0?ooo`030?l0o`3oool0oooo01d0oooo00090?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0FP3oool010000000oooo0?ooo`000?l;0?ooo`03
0?l0o`3oool0oooo05/0oooo00<0o`3o0?ooo`3oool07P3oool000L0oooo00@000000?ooo`3oool0
0000H03oool010000000oooo0?ooo`000?l<0?ooo`030?l0o`3oool0oooo05X0oooo00<0o`3o0?oo
o`3oool07P3oool000L0oooo1@00001O0?ooo`040000003oool0oooo0000o``0oooo00<0o`3o0?oo
o`3oool0FP3oool00`3o0?l0oooo0?ooo`0N0?ooo`00J`3oool010000000oooo0?ooo`000?l<0?oo
o`030?l0o`3oool0oooo05T0oooo00<0o`3o0?ooo`3oool07`3oool006/0oooo00@000000?ooo`3o
ool0003o303oool00`3o0?l0oooo0?ooo`1I0?ooo`030?l0o`3oool0oooo01l0oooo001[0?ooo`04
0000003oool0oooo0000o`d0oooo00<0o`3o0?ooo`3oool0E`3oool00`3o0?l0oooo0?ooo`0P0?oo
o`00J`3oool010000000oooo0?ooo`000?l=0?ooo`030?l0o`3oool0oooo05L0oooo00<0o`3o0?oo
o`3oool0803oool006/0oooo00@000000?ooo`3oool0003o3@3oool00`3o0?l0oooo0?ooo`1F0?oo
o`030?l0o`3oool0oooo0240oooo001[0?ooo`040000003oool0oooo0000o`h0oooo00<0o`3o0?oo
o`3oool0E@3oool00`3o0?l0oooo0?ooo`0Q0?ooo`00J`3oool010000000oooo0?ooo`000?l>0?oo
o`030?l0o`3oool0oooo00@0oooo00<000000?ooo`3oool0C@3oool00`3o0?l0oooo0?ooo`0R0?oo
o`00J`3oool010000000oooo0?ooo`000?l>0?ooo`030?l0o`3oool0oooo00@0oooo00<000000?oo
o`3oool0C@3oool00`3o0?l0oooo0?ooo`0R0?ooo`00J`3oool01@000000oooo0?ooo`3oool0003o
00h0oooo00<0o`3o0?ooo`3oool00`3oool00`000000oooo00000002000004X0oooo00<0o`3o0?oo
o`3oool08`3oool006/0oooo00D000000?ooo`3oool0oooo0000o`0>0?ooo`030?l0o`3oool0oooo
00@0oooo00D000000?ooo`3oool0oooo000000190?ooo`030?l0o`3oool0oooo02<0oooo001[0?oo
o`050000003oool0oooo0?ooo`000?l03P3oool00`3o0?l0oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`000000B03oool00`3o0?l0oooo0?ooo`0T0?ooo`00J`3oool01@000000oooo0?ooo`3o
ool0003o00h0oooo00<0o`3o0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000004L0oooo
00<0o`3o0?ooo`3oool09@3oool006/0oooo00D000000?ooo`3oool0oooo0000o`0?0?ooo`030?l0
o`3oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000160?ooo`030?l0o`3oool0oooo02H0
oooo001[0?ooo`050000003oool0oooo0?ooo`000?l03`3oool00`3o0?l0oooo0?ooo`040?ooo`<0
0000A`3oool00`3o0?l0oooo0?ooo`0V0?ooo`00J`3oool01@000000oooo0?ooo`3oool0003o00l0
oooo00<0o`3o0?ooo`3oool0C@3oool00`3o0?l0oooo0?ooo`0W0?ooo`00J`3oool01@000000oooo
0?ooo`3oool0003o0100oooo00<0o`3o0?ooo`3oool0C03oool00`3o0?l0oooo0?ooo`030?ooo`03
0000003oool0oooo0240oooo001[0?ooo`050000003oool0oooo0?ooo`000?l0403oool00`3o0?l0
oooo0?ooo`1;0?ooo`030?l0o`3oool0oooo00@0oooo00<000000?ooo`3oool08@3oool006/0oooo
00D000000?ooo`3oool0oooo0000o`0@0?ooo`030?l0o`3oool0oooo04X0oooo00<0o`3o0?ooo`3o
ool01@3oool300000240oooo001[0?ooo`050000003oool0oooo0?ooo`000?l04@3oool00`3o0?l0
oooo0?ooo`180?ooo`030?l0o`3oool0oooo00D0oooo00D000000?ooo`000000oooo0000000P0?oo
o`00J`3oool01@000000oooo0?ooo`3oool0003o0140oooo00<0o`3o0?ooo`3oool0B03oool00`3o
0?l0oooo0?ooo`050?ooo`050000003oool000000?ooo`000000803oool006/0oooo00D000000?oo
o`3oool0oooo0000o`0A0?ooo`030?l0o`3oool0oooo04L0oooo00<0o`3o0?ooo`3oool01P3oool0
1@000000oooo0000003oool000000200oooo001[0?ooo`050000003oool0oooo0?ooo`000?l04P3o
ool00`3o0?l0oooo0?ooo`160?ooo`030?l0o`3oool0oooo00H0oooo00D000000?ooo`000000oooo
0000000P0?ooo`00J`3oool01@000000oooo0?ooo`3oool0003o0180oooo00<0o`3o0?ooo`3oool0
A@3oool00`3o0?l0oooo0?ooo`080?ooo`<000008@3oool006/0oooo00D000000?ooo`3oool0oooo
0000o`0B0?ooo`030?l0o`3oool0oooo04@0oooo00<0o`3o0?ooo`3oool02`3oool00`000000oooo
0?ooo`0O0?ooo`00J`3oool01@000000oooo0?ooo`3oool0003o0180oooo00<0o`3o0?ooo`3oool0
@`3oool00`3o0?l0oooo0?ooo`0<0?ooo`030000003oool0oooo01l0oooo001[0?ooo`030000003o
ool0oooo0080oooo00<0003o0?ooo`3oool0403oool00`3o0?l0oooo0?ooo`120?ooo`030?l0o`3o
ool0oooo02h0oooo001[0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0403oool0
0`3o0?l0oooo0?ooo`110?ooo`030?l0o`3oool0oooo02l0oooo001[0?ooo`030000003oool0oooo
0080oooo00<0003o0?ooo`3oool0403oool00`3o0?l0oooo0?ooo`100?ooo`030?l0o`3oool0oooo
0300oooo001[0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool04@3oool00`3o0?l0
oooo0?ooo`0m0?ooo`80o`3o<`3oool006/0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0o`3oool0oooo03`0oooo00<0o`3o0?ooo`3oool0<`3oool006/0oooo00<0
00000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0o`3oool0oooo03`0oooo00<0
o`3o0?ooo`3oool0<`3oool006/0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0B
0?ooo`030?l0o`3oool0oooo03X0oooo00<0o`3o0?ooo`3oool0=03oool006/0oooo00<000000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0o`3oool0oooo03T0oooo00<0o`3o0?oo
o`3oool0=@3oool006/0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0B0?ooo`03
0?l0o`3oool0oooo03P0oooo00<0o`3o0?ooo`3oool0=P3oool006/0oooo00<000000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0o`3oool0oooo03L0oooo00<0o`3o0?ooo`3oool0
=`3oool006/0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0o`3o
ool0oooo03D0oooo00<0o`3o0?ooo`3oool0>03oool006/0oooo00<000000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0C0?ooo`030?l0o`3oool0oooo03@0oooo00<0o`3o0?ooo`3oool0>@3oool0
06/0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0o`3oool0oooo
03<0oooo00<0o`3o0?ooo`3oool0>P3oool006/0oooo00<000000?ooo`000?l01P000?lC0?ooo`03
0?l0o`3oool0oooo0300oooo0P3o0?lm0?ooo`00J`3oool00`000000oooo0000o`060000oa<0oooo
00<0o`3o0?ooo`3oool0;`3oool00`3o0?l0oooo0?ooo`0m0?ooo`00J`3oool00`000000oooo0?oo
o`060000oa<0oooo00<0o`3o0?ooo`3oool0;P3oool00`3o0?l0oooo0?ooo`0n0?ooo`00J`3oool0
0`000000oooo0?ooo`050000oaD0oooo00<0o`3o0?ooo`3oool0;03oool00`3o0?l0oooo0?ooo`0o
0?ooo`00J`3oool00`000000oooo0?ooo`050000oaD0oooo00<0o`3o0?ooo`3oool0:`3oool00`3o
0?l0oooo0?ooo`100?ooo`00J`3oool010000000oooo0?ooo`3oool40000oaD0oooo00<0o`3o0?oo
o`3oool0:@3oool20?l0od<0oooo001[0?ooo`040000003oool0oooo0?ooo`@0003o5@3oool00`3o
0?l0oooo0?ooo`0W0?ooo`80o`3oA@3oool006/0oooo00@000000?ooo`3oool0oooo10000?lF0?oo
o`030?l0o`3oool0oooo02D0oooo00<0o`3o0?ooo`3oool0A@3oool006/0oooo00<000000?ooo`3o
ool00P3oool30000oaH0oooo00<0o`3o0?ooo`3oool09@3oool00`3o0?l0oooo0?ooo`150?ooo`00
J`3oool00`000000oooo0?ooo`020?ooo`80003o5`3oool00`3o0?l0oooo0?ooo`0S0?ooo`80o`3o
B03oool006/0oooo00<000000?ooo`3oool00P3oool30000oaL0oooo00<0o`3o0?ooo`3oool08@3o
ool00`3o0?l0oooo0?ooo`180?ooo`00J`3oool010000000oooo0?ooo`3oool50000oaH0oooo00<0
o`3o0?ooo`3oool07`3oool20?l0od/0oooo001[0?ooo`040000003oool0oooo0?ooo`D0003o5P3o
ool00`3o0?l0oooo0?ooo`0M0?ooo`80o`3oC@3oool006/0oooo00@000000?ooo`3oool0oooo1@00
0?lG0?ooo`030?l0o`3oool0oooo01X0oooo0P3o0?m?0?ooo`00J`3oool00`000000oooo0?ooo`02
0?ooo`<0003o603oool00`3o0?l0oooo0?ooo`0H0?ooo`80o`3oD@3oool006/0oooo00<000000?oo
o`3oool07@3oool00`3o0?l0oooo0?ooo`0F0?ooo`80o`3oD`3oool006/0oooo00<000000?ooo`3o
ool07P3oool00`3o0?l0oooo0?ooo`0D0?ooo`030?l0o`3oool0oooo05<0oooo001[0?ooo`030000
003oool0oooo01h0oooo00<0o`3o0?ooo`3oool04`3oool00`3o0?l0oooo0?ooo`1D0?ooo`00J`3o
ool00`000000oooo0?ooo`0N0?ooo`030?l0o`3oool0oooo0140oooo0P3o0?mG0?ooo`00J`3oool0
0`000000oooo0?ooo`080?ooo`D000004@3oool00`3o0?l0oooo0?ooo`0?0?ooo`80o`3oF@3oool0
06/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`030?l0o`3oool0oooo
00/0oooo0`3o0?mK0?ooo`00J`3oool00`000000oooo0?ooo`020?ooo`D000000`3oool00`000000
oooo0?ooo`0B0?ooo`030?l0o`3oool0oooo00T0oooo0P3o0?mN0?ooo`00J`3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool04P3oool00`3o0?l0
oooo0?ooo`050?ooo`@0o`3oH03oool006/0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01<0oooo00@0o`3o0?ooo`3oool0oooo0`3o0?mT0?ooo`00
J`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`8000005@3oool0103o0?l0
oooo0?l0o`3o0?mW0?ooo`00J`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
01T0oooo0P3o0?mY0?ooo`00J`3oool00`000000oooo0?ooo`030?ooo`D000006@3oool00`3o0?l0
oooo0?ooo`1W0?ooo`00J`3oool00`000000oooo0?ooo`0Q0?ooo`030?l0o`3oool0oooo06L0oooo
001[0?ooo`030000003oool0oooo0240oooo00<0o`3o0?ooo`3oool0I`3oool006/0oooo00<00000
0?ooo`3oool08@3oool00`3o0?l0oooo0?ooo`1W0?ooo`00J`3oool00`000000oooo0?ooo`0R0?oo
o`030?l0o`3oool0oooo06H0oooo001[0?ooo`030000003oool0oooo0280oooo00<0o`3o0?ooo`3o
ool0IP3oool006/0oooo00<000000?ooo`3oool08P3oool00`3o0?l0oooo0?ooo`1V0?ooo`00J`3o
ool00`000000oooo0?ooo`0S0?ooo`030?l0o`3oool0oooo06D0oooo001[0?ooo`030000003oool0
oooo02<0oooo00<0o`3o0?ooo`3oool0I@3oool006/0oooo00<000000?ooo`3oool08`3oool00`3o
0?l0oooo0?ooo`1U0?ooo`00J`3oool00`000000oooo0?ooo`0T0?ooo`030?l0o`3oool0oooo06@0
oooo001[0?ooo`030000003oool0oooo02@0oooo00<0o`3o0?ooo`3oool0I03oool006/0oooo00<0
00000?ooo`3oool0903oool00`3o0?l0oooo0?ooo`1T0?ooo`00J`3oool00`000000oooo0?ooo`0U
0?ooo`030?l0o`3oool0oooo06<0oooo001[0?ooo`030000003oool0oooo02D0oooo00<0o`3o0?oo
o`3oool0H`3oool006/0oooo00<000000?ooo`3oool09@3oool00`3o0?l0oooo0?ooo`1S0?ooo`00
J`3oool00`000000oooo0?ooo`0U0?ooo`030?l0o`3oool0oooo06<0oooo001[0?ooo`030000003o
ool0oooo02H0oooo00<0o`3o0?ooo`3oool0HP3oool006/0oooo00<000000?ooo`3oool09P3oool0
0`3o0?l0oooo0?ooo`1R0?ooo`00J`3oool00`000000oooo0?ooo`0V0?ooo`030?l0o`3oool0oooo
0680oooo001[0?ooo`030000003oool0oooo02L0oooo00<0o`3o0?ooo`3oool0H@3oool006/0oooo
00<000000?ooo`3oool09`3oool00`3o0?l0oooo0?ooo`1Q0?ooo`00J`3oool00`000000oooo0?oo
o`0W0?ooo`030?l0o`3oool0oooo0640oooo001[0?ooo`030000003oool0oooo02P0oooo00<0o`3o
0?ooo`3oool0H03oool006/0oooo00<000000?ooo`3oool0:03oool00`3o0?l0oooo0?ooo`1P0?oo
o`00J`3oool00`000000oooo0?ooo`0X0?ooo`030?l0o`3oool0oooo0600oooo001[0?ooo`030000
003oool0oooo02P0oooo00<0o`3o0?ooo`3oool0H03oool006/0oooo00<000000?ooo`3oool0:@3o
ool00`3o0?l0oooo0?ooo`1O0?ooo`00J`3oool00`000000oooo0?ooo`0Y0?ooo`030?l0o`3oool0
oooo05l0oooo001[0?ooo`030000003oool0oooo02T0oooo00<0o`3o0?ooo`3oool0G`3oool006/0
oooo00<000000?ooo`3oool0:P3oool00`3o0?l0oooo0?ooo`1N0?ooo`00J`3oool00`000000oooo
0?ooo`0Z0?ooo`030?l0o`3oool0oooo05h0oooo001[0?ooo`030000003oool0oooo02X0oooo00<0
o`3o0?ooo`3oool0GP3oool006/0oooo00<000000?ooo`3oool0:`3oool00`3o0?l0oooo0?ooo`1M
0?ooo`00J`3oool00`000000oooo0?ooo`0[0?ooo`030?l0o`3oool0oooo05d0oooo001[0?ooo`03
0000003oool0oooo02/0oooo00<0o`3o0?ooo`3oool0G@3oool006/0oooo00<000000?ooo`3oool0
;03oool00`3o0?l0oooo0?ooo`1L0?ooo`00J`3oool00`000000oooo0?ooo`0/0?ooo`030?l0o`3o
ool0oooo05`0oooo001[0?ooo`030000003oool0oooo02`0oooo00<0o`3o0?ooo`3oool0G03oool0
06/0oooo00<000000?ooo`3oool0;03oool00`3o0?l0oooo0?ooo`1L0?ooo`00J`3oool00`000000
oooo0?ooo`0]0?ooo`030?l0o`3oool0oooo02P0oooo00<000000?ooo`3oool0<03oool006/0oooo
00<000000?ooo`3oool0;@3oool00`3o0?l0oooo0?ooo`0X0?ooo`030000003oool0oooo0300oooo
001[0?ooo`030000003oool0oooo02d0oooo00@0o`3o0?ooo`3o0?l0o`3o1P3oool500000100oooo
0`0000090?ooo`030000003oool00000008000000`3oool5000002H0oooo001[0?ooo`030000003o
ool0oooo02d0oooo103o0?l70?ooo`040000003oool0oooo000000P0oooo1@0000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool500000080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000:@3oool006/0oooo00<000000?ooo`3oool0:`3oool60?l0o`P0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000002T0oooo001[0?ooo`030000003oool0oooo02`0oooo1@3o0?l90?ooo`030000
003oool0oooo00L0oooo1@0000020?ooo`030000003oool0oooo00@0oooo1@0000020?ooo`080000
003oool0oooo0?ooo`000000oooo0000003oool4000002H0oooo001[0?ooo`030000003oool0oooo
02`0oooo1@3o0?l70?ooo`040000003oool0oooo000000l0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0I0?ooo`00J`3oool00`000000oooo0?ooo`0]0?ooo`@0
o`3o1`3oool500000080oooo00<000000?ooo`3oool02P3oool4000000X0oooo0`0000030?ooo`@0
0000103oool500000080oooo0`00000I0?ooo`00J`3oool00`000000oooo0?ooo`0]0?ooo`@0o`3o
3@3oool00`000000oooo0000000X0?ooo`030000003oool000000080oooo00D000000?ooo`000000
oooo0000000H0?ooo`00J`3oool00`000000oooo0?ooo`0^0?ooo`@0o`3o3P3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo0000000H0?ooo`00
J`3oool00`000000oooo0?ooo`0_0?ooo`<0o`3o303oool2000002T0oooo00<000000?ooo`000000
0P3oool01@000000oooo0000003oool0000001P0oooo001[0?ooo`030000003oool0oooo02l0oooo
0`3o0?l<0?ooo`030000003oool0oooo02L0oooo100000030?ooo`<000006@3oool006/0oooo00<0
00000?ooo`3oool0<03oool20?l0o``0oooo0`00000`0?ooo`030000003oool0oooo01L0oooo001[
0?ooo`030000003oool0oooo0300oooo0`3o0?lg0?ooo`030000003oool0oooo01h0oooo001[0?oo
o`030000003oool0oooo02l0oooo1@3o0?mG0?ooo`00J`3oool00`000000oooo0?ooo`0_0?ooo`D0
o`3oE`3oool006/0oooo00<000000?ooo`3oool0;`3oool50?l0oeL0oooo001[0?ooo`030000003o
ool0oooo0300oooo0`3o0?mH0?ooo`00J`3oool00`000000oooo0?ooo`2;0?ooo`00J`3oool00`00
0000oooo0?ooo`2;0?ooo`00J`3oool00`000000oooo0?ooo`2;0?ooo`00J`3oool00`000000oooo
0?ooo`2;0?ooo`00J`3oool00`000000oooo0?ooo`2;0?ooo`00n@3oool00?T0oooo003i0?ooo`00
n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo001Y0?ooo`800000SP3oool006X0oooo00<0
00000?ooo`3oool0S03oool006/0oooo00<000000?ooo`3oool0R`3oool006X0oooo00<000000?oo
o`000000S03oool006T0oooo00@000000?ooo`3oool00000S03oool006P0oooo0`0000000`3oool0
00000000002;0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00001\
\>"],
    ImageRangeCache->{{{0, 248.563}, {286.938, 0}} -> {-1, -1, 0, 0}}],
  StyleBox["   \n\t\t\tFigure 1.19",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The five solutions to the equation  ",
  Cell[BoxData[
      \(z\^5 = c\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tIt is interesting to note that if  ",
  Cell[BoxData[
      \(\[Zeta]\)]],
  "  is any particular solution to the equation ",
  Cell[BoxData[
      \(z\^n = c\)]],
  ", then ",
  StyleBox["all",
    FontSlant->"Italic"],
  " solutions can be generated by multiplying by the various ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " roots of unity.  That is, the solution set is  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\({\[Zeta]\ \[Omega]\_n\%\(\(\ \)\(j\)\)}\_\(j = 0\)\%\(n - 
              1\)\), " ", "=", " ", 
        RowBox[{"{", 
          RowBox[{"\[Zeta]", ",", 
            RowBox[{"\[Zeta]", " ", 
              SubscriptBox["\[Omega]", 
                StyleBox["n",
                  FontSize->10]]}], 
            ",", \(\[Zeta]\ \[Omega]\_n\%\(\(\ \)\(2\)\)\), ",", "...", 
            ",", \(\[Zeta]\ \[Omega]\_n\%\(\(\ \)\(n - 1\)\)\)}], "}"}]}]]],
  ".  \n\n\tThe reason for this is that if  ",
  Cell[BoxData[
      \(\[Zeta]\^\(\(\ \)\(n\)\) = c\)]],
  ",  then for any  ",
  Cell[BoxData[
      \(j = 0, 1, \[CenterEllipsis], n - 1\)]],
  "  we have \n\t\n\t\t\t",
  Cell[BoxData[
      \(\((\[Zeta]\ \[Omega]\_n\%\(\(\ \)\(j\)\))\)\^n\  = \ \
\(\(\[Zeta]\^\(\(\ \)\(n\)\)\) \((\[Omega]\_n\%\(\(\ \)\(j\)\))\)\^n\  = \ \(\
\(\[Zeta]\^\(\(\ \)\(n\)\)\) \((\[Omega]\_n\%\(\(\ \)\(n\)\))\)\^j\  = \ \(\(\
\[Zeta]\^\(\(\ \)\(n\)\)\) \((1)\)\  = \ c\)\)\)\)]],
  ",  \n\t\nand that multiplying a number by  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox["\[Omega]", 
          StyleBox["n",
            FontSize->10]], "=", " ", 
        SuperscriptBox["\[ExponentialE]", 
          StyleBox[\(\[ImaginaryI]\ \(2\ \[Pi]\)\/n\),
            FontSize->10]]}]]],
  "  increases an argument of that number by ",
  Cell[BoxData[
      \(\(2\ \[Pi]\)\/n\)]],
  ",  so that  ",
  Cell[BoxData[
      \({\[Zeta]\ \[Omega]\_n\%\(\(\ \)\(j\)\)}\_\(j = 0\)\%\(n - 1\)\)]],
  "  contain ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " distinct values."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.20.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find all the cube roots of  ",
  Cell[BoxData[
      \(8  \[ImaginaryI] = 
        8 \((cos  \[Pi]\/2 + \[ImaginaryI]\ sin  \[Pi]\/2)\)\)]],
  ",  i.e. find all solutions to the equation  ",
  Cell[BoxData[
      \(z\^3 = 8  \[ImaginaryI]\)]],
  ".  \n\nSolution.\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          SubscriptBox["z", 
            StyleBox["k",
              FontSize->10]], " ", "=", "  ", 
          RowBox[{\(8\^\(1\/3\)\), 
            SuperscriptBox["\[ExponentialE]", 
              StyleBox[\(\[ImaginaryI]\ \((\[Pi]\/2\  + \ 2\ \[Pi]\ k)\)/3\),
                FontSize->10]]}]}], " ", "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        "      ", \(\(=\)\(\ \)\(2 \((cos \( \[Pi]\/2\  + \ 2\ \[Pi]\ k\)\/3 \
+ \[ImaginaryI]\ sin \( \[Pi]\/2\  + \ 2\ \[Pi]\ k\)\/3)\)\)\), 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "      ", \(\(=\)\(\ \)\(2 \((cos \((\ \[Pi]\/6\  + \(2\ k\ \
\[Pi]\)\/3)\) + \[ImaginaryI]\ sin \((\ \[Pi]\/6\  + \(2\ k\ \[Pi]\)\/3)\))\)\
\)\)}]}]],
  "   \n\nfor   ",
  Cell[BoxData[
      \(k = 0, 1,  ... , n - 1\)]],
  ".   The Cartesian forms of the solutions (shown in Figure 1.20) are  \n\n\t\
\t\t",
  Cell[BoxData[
      RowBox[{\(z\_0 = \@3 + \[ImaginaryI]\), ",", 
        " ", \(z\_1 = \(-\@3\) + \[ImaginaryI]\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(z\_2\)}], 
          "=", \(\(-2\) \[ImaginaryI]\)}]}]]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.25625 0.125 [
[1.025 .25625 0 -6.28125 ]
[1.025 .25625 10 6.28125 ]
[.5 1.2875 -5 0 ]
[.5 1.2875 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1.2625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .25625 m
1 .25625 L
s
gsave
1.025 .25625 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 1.2625 L
s
gsave
.5 1.2875 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.2625 L
0 1.2625 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 0 1 r
.5 Mabswid
newpath
matrix currentmatrix
0.4375 0.4375 scale
1.14286 .58571 1 0 90 arc
setmatrix s
1 0 0 r
newpath
matrix currentmatrix
0.2375 0.2375 scale
2.10526 1.07895 1 0 30 arc
setmatrix s
0 1 0 r
newpath
matrix currentmatrix
0.15 0.15 scale
3.33333 1.70833 1 0 150 arc
setmatrix s
0 0 1 r
newpath
matrix currentmatrix
0.0875 0.0875 scale
5.71429 2.92857 1 0 270 arc
setmatrix s
1 0 1 r
.5 .25625 m
.5 1.25625 L
s
% Start of user PostScript
0 0 0 8. MAarrowhead1
% End of user PostScript
1 0 0 r
.5 .25625 m
.71651 .38125 L
s
% Start of user PostScript
0 0 1.73205 1. MAarrowhead1
% End of user PostScript
0 1 0 r
.5 .25625 m
.28349 .38125 L
s
% Start of user PostScript
0 0 -1.73205 1. MAarrowhead1
% End of user PostScript
0 0 1 r
.5 .25625 m
.5 .00625 L
s
% Start of user PostScript
0 0 0 -2. MAarrowhead1
% End of user PostScript
1 0 1 r
.025 w
.5 1.25625 Mdot
1 0 0 r
.71651 .38125 Mdot
0 1 0 r
.28349 .38125 Mdot
0 0 1 r
.5 .00625 Mdot
0 g
gsave
.55625 1.235 -61 -11.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
75.813 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
83.000 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
90.188 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
97.375 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.76651 .40625 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.24599 .425 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5375 .025 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.525 .81875 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.563 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.8375 .59375 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
84.563 12.813 moveto
(\\220) show
91.750 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.938 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78125 .3025 -70.3438 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.750 10.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
65.125 17.250 moveto
(\\200\\200) show
70.375 17.250 moveto
(\\200) show
72.688 17.250 moveto
(\\200) show
66.750 24.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
77.688 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4125 .44375 -75.5 -16.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.750 12.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
73.938 12.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
77.063 12.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
65.125 19.438 moveto
(\\200\\200\\200\\200) show
75.625 19.438 moveto
(\\200\\200) show
80.875 19.438 moveto
(\\200) show
83.000 19.438 moveto
(\\200) show
71.875 27.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
88.000 19.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4375 .11875 -75.5 -16.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.563 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.750 12.563 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
73.938 12.563 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
77.063 12.563 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
65.125 19.563 moveto
(\\200\\200\\200\\200) show
75.625 19.563 moveto
(\\200\\200) show
80.875 19.563 moveto
(\\200) show
83.000 19.563 moveto
(\\200) show
71.875 27.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
88.000 19.563 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{249.563, 315.063},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003i0001>b000`400?l00000o`00003on@3oool0
0780oooo0`000?n40?ooo`00L@3oool50000oh<0oooo001a0?ooo`D0003oP`3oool00740oooo1@00
0?lA0?ooo`<00000K`3oool00780oooo0`000?lB0?ooo`030000003oool0oooo06l0oooo001c0?oo
o`<0003o2P3oool5000000<0oooo00<000000?ooo`3oool0KP3oool007<0oooo0`000?l;0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0KP3oool007<0oooo0`000?l<0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`000000K`3oool00780oooo10000?l=0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0KP3oool00780oooo1@000?l:0?ooo`040000003o
ool0oooo000007@0oooo001b0?ooo`D0003o2P3oool5000007<0oooo001b0?ooo`D0003oPP3oool0
0740oooo1P000?n20?ooo`00L@3oool70000oh40oooo001a0?ooo`L0003oP@3oool007@0oooo00<0
003o0?ooo`3oool0PP3oool007@0oooo00<0003o0?ooo`3oool0PP3oool007@0oooo00<0003o0?oo
o`3oool0PP3oool006<0oooo1@00000<0?ooo`030000o`3oool0oooo0880oooo001S0?ooo`050000
003oool0oooo0?ooo`000000303oool00`000?l0oooo0?ooo`220?ooo`00I03oool00`000000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo0880oooo001U0?ooo`030000003oool0oooo00`0oooo00<0
003o0?ooo`3oool0PP3oool006H0oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`22
0?ooo`00I`3oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0880oooo001S0?ooo`05
0000003oool0oooo0?ooo`000000303oool00`000?l0oooo0?ooo`220?ooo`00I03oool3000000d0
oooo00<0003o0?ooo`3oool0PP3oool007@0oooo00<0003o0?ooo`3oool0PP3oool005/0oooo5@00
00040?ooo`030000o`3oool0oooo0880oooo001d0?ooo`030000o`3oool0oooo0880oooo001d0?oo
o`030000o`3oool0oooo0880oooo001d0?ooo`030000o`3oool0oooo0880oooo001d0?ooo`030000
o`3oool0oooo0880oooo001O0?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0PP3oool005h0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000?l0oooo0?ooo`220?ooo`00HP3o
ool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000L0oooo00<0003o0?ooo`3oool0
PP3oool00680oooo00<000000?ooo`3oool01@3oool00`000000oooo000000070?ooo`030000o`3o
ool0oooo0880oooo001P0?ooo`800000203oool00`000000oooo000000070?ooo`030000o`3oool0
oooo0880oooo001R0?ooo`030000003oool0oooo00<0oooo1`0000050?ooo`030000o`3oool0oooo
0880oooo001N0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000?l0oooo0?ooo`220?oo
o`00G`3oool300000180oooo00<0003o0?ooo`3oool0PP3oool00700oooo1@000?n40?ooo`00K@3o
ool30000o`@0oooo00<0003o0?ooo`3oool0PP3oool006/0oooo0P000?l70?ooo`030000o`3oool0
oooo0880oooo001Y0?ooo`80003o2@3oool00`000?l0oooo0?ooo`220?ooo`00I`3oool20000o`/0
oooo00<0003o0?ooo`3oool0PP3oool006H0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo
0?ooo`220?ooo`00I@3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo0880oooo001T
0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0PP3oool006<0oooo00<0003o0?oo
o`3oool03P3oool00`000?l0oooo0?ooo`220?ooo`00H`3oool00`000?l0oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo0880oooo001R0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0
PP3oool00640oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`220?ooo`00H@3oool0
0`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo0880oooo001Q0?ooo`030000o`3oool0oooo
0100oooo00<0003o0?ooo`3oool0PP3oool00600oooo00<0003o0?ooo`3oool04@3oool00`000?l0
oooo0?ooo`220?ooo`00H03oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo0880oooo
001P0?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool0PP3oool00600oooo00<0003o
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`220?ooo`00H03oool00`000?l0oooo0?ooo`0A0?oo
o`030000o`3oool0oooo07T0oooo0P0000000`3oool00000000000040?ooo`00H03oool00`000?l0
oooo0?ooo`0A0?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`0000001@3oool006000000
00<0003o0000000000004@0000000`000?l000000000000A000000030000o`000000000000`00000
00<00?l00000000000004@0000000`3o000000000000000/000000030?l0o`000000000000`00000
2@3oool00`000000oooo0?ooo`040?ooo`00H03oool00`000?l0oooo0?ooo`0?0?ooo`800?l000<0
o`3o0?l0003o00004@3oool00`000?l0oooo0?ooo`0<0?ooo`03003o003oool0oooo0140oooo00<0
o`000?ooo`3oool0;03oool00`3o0?l0oooo0?ooo`0C0?ooo`80000000<0oooo000000000000103o
ool00600oooo00<0003o0?ooo`3oool03@3oool2003o0080oooo00<0o`3o0?ooo`3oool00P3o000?
0?ooo`030000o`3oool0oooo00`0oooo00<00?l00?ooo`3oool04@3oool00`3o0000oooo0?ooo`06
0?ooo`<000008`3oool00`3o0?l0oooo0?ooo`0L0?ooo`00H03oool00`000?l0oooo0?ooo`0;0?oo
o`800?l0103oool00`3o0?l0oooo0?ooo`020?ooo`80o`003@3oool00`000?l0oooo0?ooo`0<0?oo
o`03003o003oool0oooo0140oooo00<0o`000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0
00000280oooo00<0o`3o0?ooo`3oool0703oool00600oooo00<0003o0?ooo`3oool02P3oool00`00
o`00oooo0?ooo`040?ooo`030?l0o`3oool0oooo00@0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0<0?ooo`03003o003oool0oooo0140oooo00<0o`000?ooo`3oool01@3oool01@00
0000oooo0?ooo`3oool000000280oooo00<0o`3o0?ooo`3oool0703oool00600oooo00<0003o0?oo
o`3oool0203oool2003o00L0oooo00<0o`3o0?ooo`3oool01@3oool20?l000T0oooo00<0003o0?oo
o`3oool0303oool00`00o`00oooo0?ooo`0B0?ooo`030?l0003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo0000000R0?ooo`030?l0o`3oool0oooo01`0oooo001Q0?ooo`030000o`3oool0oooo
00D0oooo0P00o`090?ooo`030?l0o`3oool0oooo00L0oooo0P3o00070?ooo`030000o`3oool0oooo
00`0oooo00<00?l00?ooo`3oool04P3oool00`3o0000oooo0?ooo`050?ooo`@000008P3oool00`3o
0?l0oooo0?ooo`0M0?ooo`00H@3oool00`000?l0oooo0?ooo`030?ooo`800?l02`3oool00`3o0?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0303oool00`00o`00
oooo0?ooo`0B0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`3o0?l0
oooo0?ooo`0M0?ooo`00H@3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00/0oooo
00<0o`3o0?ooo`3oool02P3oool20?l000<0oooo00<0003o0?ooo`3oool03@3oool00`00o`00oooo
0?ooo`0A0?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool08P3oool00`3o0?l0oooo
0?ooo`0M0?ooo`00HP3oool010000?l0oooo003o0000o`0>0?ooo`030?l0o`3oool0oooo00`0oooo
0P3o00000`3oool0003o0?ooo`0>0?ooo`03003o003oool0oooo0140oooo00<0o`000?ooo`3oool0
203oool300000240oooo00<0o`3o0?ooo`3oool07@3oool00680oooo0P00o`0@0?ooo`030?l0o`3o
ool0oooo00h0oooo0P3o000>0?ooo`03003o003oool0oooo0180oooo00<0o`000?ooo`3oool0;03o
ool00`3o0?l0oooo0?ooo`0M0?ooo`00H03oool2003o00030?ooo`000?l0oooo00l0oooo00<0o`3o
0?ooo`3oool03P3oool00`000?l0oooo0?l0000=0?ooo`03003o003oool0oooo0180oooo00<0o`00
0?ooo`3oool00`3oool;000001h0oooo00<0o`3o0?ooo`3oool07@3oool005l0oooo00<00?l00?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0o`3oool0oooo00d0oooo00@0003o0?oo
o`3oool0oooo0P3o000;0?ooo`03003o003oool0oooo0180oooo00<0o`000?ooo`3oool0;03oool0
0`3o0?l0oooo0?ooo`0M0?ooo`00G@3oool2003o00D0oooo00<0003o0?ooo`3oool03@3oool00`3o
0?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00<0oooo0P3o00080?ooo`03003o003oool0oooo
01<0oooo00<0o`000?ooo`3oool0;03oool00`3o0?l0oooo0?ooo`0M0?ooo`00F`3oool2003o00P0
oooo00<0003o0?ooo`3oool0303oool00`3o0?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0B0?ooo`030?l0003oool0oooo02d0
oooo00<0o`3o0?ooo`3oool07@3oool005T0oooo0P00o`0;0?ooo`80003o303oool00`3o0?l0oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00P0oooo0P3o00040?ooo`03003o003oool0oooo01<0oooo
00<0o`000?ooo`3oool0;@3oool00`3o0?l0oooo0?ooo`0M0?ooo`00E`3oool2003o00l0oooo00<0
003o0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`80003o3@3oool20?l00080oooo00<0
0?l00?ooo`3oool04`3oool00`3o0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool07@3oool00`3o0?l0oooo0?ooo`0N0?ooo`00EP3oool00`00o`00oooo0?ooo`0@
0?ooo`030000o`3oool0oooo00P0oooo00<0o`3o0?ooo`3oool01`3oool20000oa40oooo0P3o000E
0?ooo`030?l0003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000P0?ooo`030?l0o`3o
ool0oooo01h0oooo001D0?ooo`<00?l04`3oool20000o`P0oooo00<0o`3o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`0B0?ooo`03003o003o0000oooo01<0oooo00<0o`000?ooo`3oool02@3oool0
10000000oooo0?ooo`00000P0?ooo`030?l0o`3oool0oooo01h0oooo001B0?ooo`800?l00`3oool0
0`00o`00oooo0?ooo`0B0?ooo`<0003o1@3oool00`3o0?l0oooo0?ooo`040?ooo`80003o503oool0
0`00o`00oooo0?ooo`020?l00180oooo00<0o`000?ooo`3oool02P3oool00`000000oooo0000000P
0?ooo`030?l0o`3oool0oooo01h0oooo001@0?ooo`800?l01@3oool00`00o`00oooo0?ooo`0E0?oo
o`D0003o00<0o`3o0000o`000?l010000?lE0?ooo`03003o003oool0oooo00<0oooo0P3o000?0?oo
o`030?l0003oool0oooo00/0oooo00<000000?ooo`000000803oool00`3o0?l0oooo0?ooo`0N0?oo
o`00BP3oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3o
ool06@3oool00`3o0?l0oooo0?ooo`0I0?ooo`03003o003oool0oooo00D0oooo0P3o00040?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool02@3oool7000001d0oooo00<0o`3o0?ooo`3o
ool07`3oool004T0oooo0`00o`000`3oool00?l0003o000:0?ooo`03003o003oool0oooo01P0oooo
00<0o`3o0?ooo`3oool0603oool00`00o`00oooo0?ooo`080?ooo`030?l0003oool0oooo00<0o`00
1P3oool00`3o0000oooo0?ooo`0^0?ooo`030?l0o`3oool0oooo01l0oooo00180?ooo`D00?l03@3o
ool00`00o`00oooo0?ooo`0G0?ooo`030?l0o`3oool0oooo01L0oooo00<00?l00?ooo`3oool02P3o
ool60?l000D0oooo00<0o`000?ooo`3oool0;P3oool00`3o0?l0oooo0?ooo`0O0?ooo`00A`3oool6
003o00h0oooo00<00?l00?ooo`3oool05P3oool00`3o0?l0oooo0?ooo`0F0?ooo`03003o003oool0
oooo00`0oooo1P3o00030?ooo`030?l0003oool0oooo02l0oooo00<0o`3o0?ooo`3oool07`3oool0
04D0oooo2000o`0?0?ooo`03003o003oool0oooo01D0oooo00<0o`3o0?ooo`3oool05@3oool00`00
o`00oooo0?ooo`0=0?ooo`L0o`000P3oool00`3o0000oooo0?ooo`0_0?ooo`030?l0o`3oool0oooo
01l0oooo00140?ooo`X00?l03`3oool00`00o`00oooo0?ooo`0D0?ooo`030?l0o`3oool0oooo01@0
oooo00<00?l00?ooo`3oool03@3oool90?l000030?ooo`3o0000oooo02l0oooo00<0o`3o0?ooo`3o
ool0803oool00400oooo3000o`0B0?ooo`03003o003oool0oooo01<0oooo00<0o`3o0?ooo`3oool0
4`3oool00`00o`00oooo0?ooo`0@0?ooo`/0o`00;P3oool00`3o0?l0oooo0?ooo`0P0?ooo`00?`3o
ool9003o01L0oooo00<00?l00?ooo`3oool04P3oool00`3o0?l0oooo0?ooo`0A0?ooo`800?l05`3o
ool80?l002d0oooo00<0o`3o0?ooo`3oool0803oool003l0oooo1@00o`0L0?ooo`03003o003oool0
oooo0140oooo00<0o`3o0?ooo`3oool0403oool00`00o`00oooo0?ooo`0J0?ooo`D0o`00;03oool0
0`3o0?l0oooo0?ooo`0Q0?ooo`00?`3oool5003o01d0oooo0P00o`0A0?ooo`030?l0o`3oool0oooo
00l0oooo00<00?l00?ooo`3oool06`3oool50?l002`0oooo00<0o`3o0?ooo`3oool08@3oool00400
oooo0`00o`0P0?ooo`<00?l03P3oool00`3o0?l0oooo0?ooo`0=0?ooo`800?l07`3oool30?l002d0
oooo00<0o`3o0?ooo`3oool08@3oool006H0oooo0P00o`0<0?ooo`030?l0o`3oool0oooo00/0oooo
0P00o`0a0?ooo`030000003oool0oooo01d0oooo00<0o`3o0?ooo`3oool08@3oool006P0oooo0`00
o`090?ooo`030?l0o`3oool0oooo00P0oooo0`00o`0Z0?ooo`D000000`3oool00`000000oooo0000
000M0?ooo`030?l0o`3oool0oooo0280oooo001N0?ooo`<000002P3oool3003o00H0oooo00<0o`3o
0?ooo`3oool00P3oool6003o02h0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000
000M0?ooo`030?l0o`3oool0oooo0280oooo001M0?ooo`050000003oool0oooo0?ooo`000000303o
ool6003o00030?l0o`00o`000?l000800?l0=@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000001d0oooo00<0o`3o0?ooo`3oool08P3oool003X0oooo1@00000N0?ooo`050000003oool0
oooo0?ooo`0000004P3oool00`3o0?l0oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`000000703oool00`3o0?l0oooo0?ooo`0S0?ooo`00?03oool00`000000oooo0?ooo`0N
0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`3o0?l0oooo0?ooo`0f0?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0S0?ooo`00<`3o
ool5000000@0oooo00<000000?ooo`3oool07P3oool4000001<0oooo00<0o`3o0?ooo`3oool0=P3o
ool500000200oooo00<0o`3o0?ooo`3oool0903oool003@0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01@0oooo00<0o`3o0?ooo`3oool0F`3o
ool00`3o0?l0oooo0?ooo`0T0?ooo`00=@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool04`3oool00`3o0?l0oooo0?ooo`1J0?ooo`030?l0o`3oool0
oooo02D0oooo000f0?ooo`030000003oool0oooo0080oooo0P00000R0?ooo`<000004P3oool00`3o
0?l0oooo0?ooo`1J0?ooo`030?l0o`3oool0oooo02D0oooo000d0?ooo`040000003oool0oooo0000
03`0oooo00<0o`3o0?ooo`3oool0FP3oool00`3o0?l0oooo0?ooo`0U0?ooo`00=03oool5000001`0
oooo5@00000:0?ooo`030?l0o`3oool0oooo05T0oooo00<0o`3o0?ooo`3oool09P3oool007@0oooo
00<0o`3o0?ooo`3oool0F@3oool00`3o0?l0oooo0?ooo`0V0?ooo`00M03oool00`3o0?l0oooo0?oo
o`1H0?ooo`030?l0o`3oool0oooo02L0oooo001d0?ooo`030?l0o`3oool0oooo05P0oooo00<0o`3o
0?ooo`3oool09`3oool007@0oooo00<0o`3o0?ooo`3oool0E`3oool00`3o0?l0oooo0?ooo`0X0?oo
o`00F@3oool3000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`03
0?l0o`3oool0oooo05L0oooo00<0o`3o0?ooo`3oool0:03oool005P0oooo00D000000?ooo`3oool0
oooo000000050?ooo`050000003oool0oooo0?ooo`0000003@3oool00`3o0?l0oooo0?ooo`1F0?oo
o`030?l0o`3oool0oooo02T0oooo001L0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool000003@3oool00`3o0?l0oooo0?ooo`1E0?ooo`030?l0o`3oool0oooo02X0oooo001L0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`0000003@3oool00`3o0?l0oooo0?ooo`1D0?ooo`03
0?l0o`3oool0oooo02/0oooo001I0?ooo`<00000203oool00`000000oooo0000000=0?ooo`030?l0
o`3oool0oooo05@0oooo00<0o`3o0?ooo`3oool0:`3oool005T0oooo00<000000?ooo`3oool01P3o
ool7000000/0oooo00<0o`3o0?ooo`3oool0D`3oool00`3o0?l0oooo0?ooo`0/0?ooo`00F@3oool0
0`000000oooo0?ooo`0H0?ooo`030?l0o`3oool0oooo05<0oooo00<0o`3o0?ooo`3oool0;03oool0
05T0oooo1000000G0?ooo`030?l0o`3oool0oooo05<0oooo00<0o`3o0?ooo`3oool0;03oool007@0
oooo00<0o`3o0?ooo`3oool0DP3oool00`3o0?l0oooo0?ooo`0]0?ooo`00M03oool00`3o0?l0oooo
0?ooo`1B0?ooo`030?l0o`3oool0oooo02d0oooo001d0?ooo`030?l0o`3oool0oooo0540oooo00<0
o`3o0?ooo`3oool0;P3oool007@0oooo00<0o`3o0?ooo`3oool0D03oool00`3o0?l0oooo0?ooo`0_
0?ooo`00M03oool00`3o0?l0oooo0?ooo`1?0?ooo`030?l0o`3oool0oooo0300oooo001d0?ooo`03
0?l0o`3oool0oooo04l0oooo00<0o`3o0?ooo`3oool0<03oool007@0oooo00<0o`3o0?ooo`3oool0
CP3oool00`3o0?l0oooo0?ooo`0a0?ooo`00M03oool00`3o0?l0oooo0?ooo`1=0?ooo`030?l0o`3o
ool0oooo0380oooo001d0?ooo`030?l0o`3oool0oooo04`0oooo00<0o`3o0?ooo`3oool0<`3oool0
07@0oooo00<0o`3o0?ooo`3oool0C03oool00`3o0?l0oooo0?ooo`0c0?ooo`00M03oool00`3o0?l0
oooo0?ooo`1;0?ooo`030?l0o`3oool0oooo03@0oooo001d0?ooo`030?l0o`3oool0oooo04X0oooo
00<0o`3o0?ooo`3oool0=@3oool007@0oooo00<0o`3o0?ooo`3oool0B03oool20?l0ocP0oooo001d
0?ooo`030?l0o`3oool0oooo04L0oooo00<0o`3o0?ooo`3oool0>03oool007@0oooo00<0o`3o0?oo
o`3oool0A`3oool00`3o0?l0oooo0?ooo`0h0?ooo`00M03oool00`3o0?l0oooo0?ooo`160?ooo`03
0?l0o`3oool0oooo03T0oooo001d0?ooo`030?l0o`3oool0oooo04D0oooo00<0o`3o0?ooo`3oool0
>P3oool007@0oooo00<0o`3o0?ooo`3oool0A03oool00`3o0?l0oooo0?ooo`0k0?ooo`00M03oool0
0`3o0?l0oooo0?ooo`130?ooo`030?l0o`3oool0oooo03`0oooo001d0?ooo`030?l0o`3oool0oooo
0440oooo0P3o0?l<0?ooo`030000003oool0oooo0300oooo001d0?ooo`030?l0o`3oool0oooo0400
oooo00<0o`3o0?ooo`3oool0303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01X0
oooo001d0?ooo`030?l0o`3oool0oooo03l0oooo00<0o`3o0?ooo`3oool03@3oool3000000X0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000050?ooo`D000004P3oool007@0oooo
00<0o`3o0?ooo`3oool0?P3oool00`3o0?l0oooo0?ooo`0=0?ooo`050000003oool000000?ooo`00
00000`3oool500000080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo0000000B0?ooo`00M03oool00`3o0?l0oooo0?ooo`0m0?oo
o`030?l0o`3oool0oooo00h0oooo00D000000?ooo`000000oooo0000000;0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`00M03oool0
0`3o0?l0oooo0?ooo`0l0?ooo`030?l0o`3oool0oooo00l0oooo00D000000?ooo`000000oooo0000
00030?ooo`D00000103oool00`000000oooo000000040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool04P3oool007@0oooo00<0o`3o0?ooo`3oool0>`3oool00`3o0?l0oooo0?ooo`0@
0?ooo`050000003oool000000?ooo`000000303oool00`000000oooo000000050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool04@3oool007@0oooo00<0o`3o0?ooo`3oool0>P3oool0
0`3o0?l0oooo0?ooo`0B0?ooo`<000002`3oool7000000<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0@0?ooo`00M03oool00`3o0?l0oooo0?ooo`0h0?ooo`80o`3o5`3oool00`00
0000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0@
0?ooo`00M03oool00`3o0?l0oooo0?ooo`0f0?ooo`80o`3o6@3oool00`000000oooo0?ooo`0D0?oo
o`040000003oool0oooo0?ooo`<000004`3oool007@0oooo00<0o`3o0?ooo`3oool0=@3oool00`3o
0?l0oooo0?ooo`1:0?ooo`00M03oool00`3o0?l0oooo0?ooo`0c0?ooo`80o`3oC@3oool007@0oooo
00<0o`3o0?ooo`3oool0<@3oool20?l0odl0oooo001d0?ooo`030?l0o`3oool0oooo0300oooo00<0
o`3o0?ooo`3oool0C`3oool007@0oooo00<0o`3o0?ooo`3oool0;`3oool00`3o0?l0oooo0?ooo`1@
0?ooo`00M03oool00`3o0?l0oooo0?ooo`0]0?ooo`80o`3oD`3oool007@0oooo00<0o`3o0?ooo`3o
ool0:P3oool30?l0oeD0oooo001d0?ooo`030?l0o`3oool0oooo02P0oooo0P3o0?mH0?ooo`00M03o
ool00`3o0?l0oooo0?ooo`0V0?ooo`80o`3oFP3oool007@0oooo00<0o`3o0?ooo`3oool0903oool2
0?l0oe`0oooo001d0?ooo`030?l0o`3oool0oooo0240oooo0`3o0?mN0?ooo`00M03oool00`3o0?l0
oooo0?ooo`0O0?ooo`80o`3oH@3oool007@0oooo00<0o`3o0?ooo`3oool06P3oool50?l0of<0oooo
001d0?ooo`030?l0o`3oool0oooo01P0oooo0P3o0?mX0?ooo`00M03oool00`3o0?l0oooo0?ooo`0C
0?ooo`D0o`3oJP3oool007@0oooo00<0o`3o0?ooo`3oool03P3oool50?l0ofl0oooo001d0?ooo`03
0?l0o`3oool0oooo00H0oooo203o0?md0?ooo`00M03oool90?l0og`0oooo001d0?ooo`030?l0o`3o
ool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo
0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo
001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?oo
o`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0
o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0
oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880
oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d
0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`03
0?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3o
ool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo
0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo00D0oooo
00<000000?ooo`3oool0NP3oool007@0oooo00<0o`3o0?ooo`3oool01@3oool00`000000oooo0?oo
o`1j0?ooo`00M03oool00`3o0?l0oooo0?ooo`050?ooo`030000003oool00000008000002P3oool5
000006T0oooo001d0?ooo`030?l0o`3oool0oooo00H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`D000000P3oool01@000000oooo0?ooo`3oool0000006T0oooo001d0?ooo`030?l0o`3oool0
oooo00H0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo06X0oooo001d
0?ooo`030?l0o`3oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`D00000103o
ool00`000000oooo0?ooo`1Y0?ooo`00M03oool00`3o0?l0oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`000000303oool00`000000oooo0?ooo`1X0?ooo`00M03oool00`3o0?l0oooo0?ooo`07
0?ooo`<000003P3oool00`000000oooo0?ooo`1W0?ooo`00M03oool00`3o0?l0oooo0?ooo`0D0?oo
o`050000003oool0oooo0?ooo`000000J@3oool007@0oooo00<0o`3o0?ooo`3oool05@3oool30000
06X0oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo
001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?oo
o`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0
o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0
oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880
oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d
0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`03
0?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3o
ool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo
0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo
001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?oo
o`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0
o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0
oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880
oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d
0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`03
0?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3o
ool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo
0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo
001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?oo
o`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0
o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0
oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880
oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d
0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`03
0?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3o
ool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo
0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo
001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?oo
o`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0
o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0
oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880
oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d
0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`03
0?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3o
ool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo
0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo
001d0?ooo`030?l0o`3oool0oooo0880oooo001d0?ooo`030?l0o`3oool0oooo0880oooo001a0?oo
o`L0o`3oP@3oool00740oooo1`3o0?n10?ooo`00L@3oool60?l0oh80oooo001b0?ooo`D0o`3oPP3o
ool00780oooo1@3o0?l=0?ooo`D00000403oool3000000<0oooo1`00001C0?ooo`00LP3oool50?l0
o`h0oooo00@000000?ooo`3oool00000203oool500000080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0000005D0oooo001b0?ooo`@0o`3o403oool00`000000oooo0?ooo`0?
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0000001E0?ooo`00L`3oool3
0?l0oa40oooo00<000000?ooo`3oool01`3oool500000080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0000005D0oooo001c0?ooo`<0o`3o3`3oool010000000oooo0?ooo`00
000@0?ooo`<000001@3oool00`000000oooo0000001E0?ooo`00L`3oool30?l0o`l0oooo1@000000
0`3oool000000000000;0?ooo`050000003oool0oooo0?ooo`0000000P3oool5000005D0oooo001b
0?ooo`<0o`3o603oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000G03o
ool00740oooo1@3o0?lF0?ooo`030000003oool0oooo00X0oooo0`0000060?ooo`030000003oool0
oooo05@0oooo001a0?ooo`D0o`3o5`3oool00`000000oooo0?ooo`1Y0?ooo`00L@3oool50?l0oaD0
oooo00<000000?ooo`000000J`3oool00780oooo0`3o0?lG0?ooo`030000003oool0oooo06X0oooo
003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00LP3oool20000
08D0oooo001c0?ooo`030000003oool0oooo08<0oooo001d0?ooo`030000003oool0oooo0880oooo
001c0?ooo`030000003oool0000008<0oooo001b0?ooo`040000003oool0oooo000008<0oooo001a
0?ooo`<0000000<0oooo000000000000PP3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i
0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 248.563}, {314.063, 0}} -> {-4, -2, 0, 0}}],
  StyleBox["   \n\t\tFigure 1.20",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The point  ",
  Cell[BoxData[
      \(z = 8  \[ImaginaryI]\)]],
  "  and its three cube roots  ",
  Cell[BoxData[
      RowBox[{\(z\_0\), ",", \(z\_1\), ",", " ", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", \(z\_2\)}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.20.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the polynomial  ",
  Cell[BoxData[
      \(P[z] = z\^3 - 8  \[ImaginaryI]\)],
    AspectRatioFixed->True],
  "  and find its zeros."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[k, list, set, solset, values, xx, yy, 
        z];\)\ \), "\[IndentingNewLine]", 
    \(\(P[z_]\  = \ z\^3 - 8  \[ImaginaryI]\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[P[z] \[Equal] 0, z];\)\ \), "\n", 
    \(\(values\  = \ 
        solset[\([Table[k, {k, Length[solset]}], 1, 2]\)];\)\ \), "\n", 
    \(\(set\  = \ 
        N[solset[\([Table[k, {k, Length[solset]}], 1, 2]\)]];\)\ \), "\n", 
    \(\(set\  = \ ReplaceAll[set, xx_Real \[Rule] {xx, 0}];\)\ \), "\n", 
    \(\(list\  = \ \ ReplaceAll[set, 
          Complex[xx_, yy_] \[Rule] {xx, yy}];\)\ \), "\[IndentingNewLine]", 
    \(\(ListPlot[list, 
        Prolog \[Rule] {PointSize[0.03], 
            Orange}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \[IndentingNewLine]Ticks \
\[Rule] {{\(-\@3\), \(-1\), 1, \@3}, 
            Range[\(-2\), 2, 
              1]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-2.1\), 
              2.1}, {\(-2.1\), 2.1}}];\)\ \), "\[IndentingNewLine]", 
    \(\(For[k = 0, 
        k \[LessEqual] 
          2, \(k++\), \[IndentingNewLine]Print["\<z\>"\_k, "\< = 2 Cos[\>", \ \
\[Pi]\/6\  + \(2\ k\ \[Pi]\)\/3, "\<] + \[ImaginaryI] 2 Sin[\>", \ \[Pi]\/6\  \
+ \(2\ k\ \[Pi]\)\/3, "\<] = \>", 
          2  Cos[\ \[Pi]\/6\  + \(2\ k\ \[Pi]\)\/3] + \[ImaginaryI]\ 2\ Sin[\ \
\[Pi]\/6\  + \(2\ k\ \[Pi]\)\/3]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<P[z] = \>", P[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve \>", P[z] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The cube roots of  8\[ImaginaryI]  are\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<(8\[ImaginaryI]\!\(\()\^\(1\/3\)\)\) = \>\"", 
        values];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The expanded form of the cube roots are\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<(8\[ImaginaryI]\!\(\()\^\(1\/3\)\)\) = \>\"", 
        ComplexExpand[values]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tIs the quadratic formula valid in the complex domain?  The answer is yes, \
provided we are careful with our terms.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 1.5  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Quadratic Formula",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/QuadraticEquation.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(a\ z\^2 + \ b\ z\  + \ c\  = \ \ 0\)]],
  ",  then the solution set for ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " is \n\n\t\t\t",
  Cell[BoxData[
      \({\(\(-b\)\  + \ \((b\^2 - 4\ a\ c)\)\^\(1\/2\)\)\/\(2\ a\)}\)]],
  ",  \n\nwhere by  ",
  Cell[BoxData[
      \(\((b\^2 - 4\ a\ c)\)\^\(1\/2\)\)]],
  "  we mean all distinct square roots of the number inside the parenthesis. \
"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Proof .",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  The proof is left as an exercise for the reader."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.21.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find all solutions to the equation  ",
  Cell[BoxData[
      \(z\^2 + \((1 + \[ImaginaryI])\) z + 5  \[ImaginaryI] = 0\)],
    AspectRatioFixed->True],
  ".  \n\nSolution.  The quadratic formula gives  ",
  Cell[BoxData[
      \(\(\(-\((1 + \[ImaginaryI])\)\)\  + \ \((\((1 + \[ImaginaryI])\)\^2 - \
4\ \((1)\)\ \((5  \[ImaginaryI])\))\)\^\(1\/2\)\)\/\(2 \((1)\)\)\  = \ \
\(\(-\((1 + \[ImaginaryI])\)\)\  + \ \((\(-18\)\ \[ImaginaryI])\)\^\(1\/2\)\)\
\/2\)]],
  ".  As  ",
  Cell[BoxData[
      \(\(-18\)\ \[ImaginaryI]\  = \ 
        18  \[ExponentialE]\^\(\[ImaginaryI] \((\(-\(\[Pi]\/2\)\))\)\)\)]],
  ",  we compute  ",
  Cell[BoxData[
      \(\((\(-18\)\ \[ImaginaryI])\)\^\(1\/2\)\  = \ \(\((18\ )\)\^\(1\/2\)\) \
\[ExponentialE]\^\(\[ImaginaryI] \((\(-\(\[Pi]\/2\)\) + 2  k\ \
\[Pi])\)/2\)\)]],
  "  for ",
  Cell[BoxData[
      \(k = 0\)],
    AspectRatioFixed->True],
  " and ",
  Cell[BoxData[
      \(k = 1\)],
    AspectRatioFixed->True],
  ".  In Cartesian form, this expression reduces to \n\n\t\t",
  Cell[BoxData[
      \(\(\((18\ )\)\^\(1\/2\)\) \[ExponentialE]\^\(\[ImaginaryI] \((\(-\(\
\[Pi]\/4\)\))\)\) = \(3\ \(\@2\) \((cos \(-\[Pi]\)\/4 + \[ImaginaryI]\ sin \
\(-\[Pi]\)\/4)\) = \(3\ \(\@2\) \((\(1 - \[ImaginaryI]\)\/\@2)\) = \ 
            3 - 3\ \[ImaginaryI]\)\)\)]],
  ",  \n\tand\n\t\t",
  Cell[BoxData[
      \(\(\((18\ )\)\^\(1\/2\)\) \[ExponentialE]\^\(\[ImaginaryI] \((\(3\ \
\[Pi]\)\/4)\)\) = \(3\ \(\@2\) \((cos \( 3  \[Pi]\)\/4 + \[ImaginaryI]\ sin \
\( 3  \[Pi]\)\/4)\) = \(3\ \(\@2\) \((\(\(-1\) + \[ImaginaryI]\)\/\@2)\) = \ \
\(-3\) + 3\ \[ImaginaryI]\)\)\)]],
  ".  \n\t\t\nThus, our solution set is  ",
  Cell[BoxData[
      \({\(\(-\((1 + \[ImaginaryI])\)\)\  + \ \((3 - 3\ \
\[ImaginaryI])\)\)\/2, \(\(-\((1 + \[ImaginaryI])\)\)\  + \ \((\(-3\) + 3\ \
\[ImaginaryI])\)\)\/2}\  = \ {1 - 
            2\ \[ImaginaryI], \ \(-2\) + \[ImaginaryI]}\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the polynomial  ",
  Cell[BoxData[
      \(P[z] = z\^2 + \((1 + \[ImaginaryI])\) z + 5  \[ImaginaryI]\)],
    AspectRatioFixed->True],
  "  and find its zeros."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[k, list, set, solset, values, xx, yy, 
        z];\)\ \), "\[IndentingNewLine]", 
    \(\(P[z_]\  = \ 
        z\^2 + \((1 + \[ImaginaryI])\) z + 
          5  \[ImaginaryI]\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[P[z] \[Equal] 0, z];\)\ \), "\n", 
    \(\(values\  = \ 
        solset[\([Table[k, {k, Length[solset]}], 1, 2]\)];\)\ \), "\n", 
    \(\(set\  = \ 
        N[solset[\([Table[k, {k, Length[solset]}], 1, 2]\)]];\)\ \), "\n", 
    \(\(set\  = \ ReplaceAll[set, xx_Real \[Rule] {xx, 0}];\)\ \), "\n", 
    \(\(list\  = \ \ ReplaceAll[set, 
          Complex[xx_, yy_] \[Rule] {xx, yy}];\)\ \), "\[IndentingNewLine]", 
    \(\(ListPlot[list, 
        Prolog \[Rule] {PointSize[0.03], 
            Orange}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \[IndentingNewLine]Ticks \
\[Rule] {{\(-\@3\), \(-1\), 1, \@3}, 
            Range[\(-2\), 2, 
              1]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-2.1\), 
              2.1}, {\(-2.1\), 2.1}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<P[z] = \>", P[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve \>", P[z] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The solution set is \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[values];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Remark. The roots are not a conjugate pair.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tIn Exercise 5 of Section 1.2 we asked you to show that a polynomial with \
nonreal coefficients must have some roots that do not occur in complex \
conjugate pairs.  This last example gives an illustration of such a \
phenomenon. \
\>", "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["DeMoivre's Theorem",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/DeMoivreBib.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Roots of Cubic Equations",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/CubicEquationBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Roots of Quartic Equations",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/QuarticEquationBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Roots of Polynomials",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/PolyRootComplexBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Quaternions",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/QuaternionBib.html"], None},
  
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{994, 645},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 215996, 5559}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 135, 2, 33, "Text"],
Cell[2240, 66, 823, 18, 90, "Text"],
Cell[3066, 86, 1021, 23, 128, "Text"],
Cell[4090, 111, 1001, 25, 186, "Text",
  Evaluatable->False],
Cell[5094, 138, 1113, 24, 233, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[6232, 166, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[6396, 172, 194, 8, 33, "Text"],
Cell[6593, 182, 3000, 60, 606, "Input"]
}, Closed]],
Cell[9608, 245, 162, 5, 30, "Text"],
Cell[9773, 252, 1354, 33, 271, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[11152, 289, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[11316, 295, 195, 8, 33, "Text"],
Cell[11514, 305, 2397, 45, 495, "Input"]
}, Closed]],
Cell[13926, 353, 283, 10, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[14234, 367, 162, 4, 33, "Text",
  Evaluatable->False],
Cell[14399, 373, 196, 8, 33, "Text"],
Cell[14598, 383, 3392, 67, 704, "Input"]
}, Closed]],
Cell[18005, 453, 994, 25, 106, "Text"],
Cell[19002, 480, 2364, 53, 242, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[21391, 537, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[21555, 543, 299, 10, 33, "Text"],
Cell[21857, 555, 1185, 27, 370, "Input"]
}, Closed]],
Cell[23057, 585, 514, 12, 49, "Text"],
Cell[23574, 599, 903, 32, 52, "Text",
  Evaluatable->False],
Cell[24480, 633, 135, 5, 33, "Text"],
Cell[24618, 640, 1190, 38, 71, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[25833, 682, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[25997, 688, 246, 8, 33, "Text"],
Cell[26246, 698, 1177, 23, 270, "Input"]
}, Closed]],
Cell[27438, 724, 561, 20, 49, "Text"],
Cell[28002, 746, 1078, 35, 109, "Text"],
Cell[29083, 783, 422, 10, 52, "Text"],
Cell[29508, 795, 773, 27, 55, "Text"],
Cell[30284, 824, 1294, 42, 77, "Text"],
Cell[31581, 868, 1141, 33, 131, "Text"],
Cell[32725, 903, 769, 23, 52, "Text"],
Cell[33497, 928, 1241, 41, 112, "Text"],
Cell[34741, 971, 680, 20, 109, "Text",
  Evaluatable->False],
Cell[35424, 993, 1709, 50, 210, "Text",
  Evaluatable->False],
Cell[37136, 1045, 65901, 1563, 333, "Text"],

Cell[CellGroupData[{
Cell[103062, 2612, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[103226, 2618, 154, 6, 33, "Text"],
Cell[103383, 2626, 2063, 38, 526, "Input"]
}, Closed]],
Cell[105461, 2667, 3374, 108, 240, "Text"],
Cell[108838, 2777, 49204, 1222, 326, "Text"],
Cell[158045, 4001, 2018, 56, 212, "Text"],
Cell[160066, 4059, 1931, 53, 252, "Text",
  Evaluatable->False],
Cell[162000, 4114, 43045, 1147, 354, "Text"],

Cell[CellGroupData[{
Cell[205070, 5265, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[205234, 5271, 169, 6, 33, "Text"],
Cell[205406, 5279, 2137, 39, 506, "Input"]
}, Closed]],
Cell[207558, 5321, 141, 3, 30, "Text"],
Cell[207702, 5326, 902, 29, 127, "Text",
  Evaluatable->False],
Cell[208607, 5357, 163, 5, 33, "Text"],
Cell[208773, 5364, 2067, 52, 254, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[210865, 5420, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[211029, 5426, 197, 6, 33, "Text"],
Cell[211229, 5434, 1593, 31, 395, "Input"]
}, Closed]],
Cell[212837, 5468, 256, 5, 49, "Text"],
Cell[213096, 5475, 290, 7, 33, "Text"],
Cell[213389, 5484, 279, 6, 33, "Text"],
Cell[213671, 5492, 295, 7, 33, "Text"],
Cell[213969, 5501, 299, 7, 33, "Text"],
Cell[214271, 5510, 301, 7, 33, "Text"],
Cell[214575, 5519, 277, 7, 33, "Text"],
Cell[214855, 5528, 257, 5, 33, "Text"],
Cell[215115, 5535, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

