(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    490202,       9114]*)
(*NotebookOutlinePosition[    491043,       9145]*)
(*  CellTagsIndexPosition[    490966,       9139]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["1.6 The Topology of Complex Numbers",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tIn this section we investigate some basic ideas concerning sets of \
points in the plane.  The first concept is that of a curve. Intuitively, we \
think of a curve as a piece of string placed on a flat surface in some type \
of meandering pattern.  More formally, we define a curve to be the range of a \
continuous complex-valued function ",
  Cell[BoxData[
      \(z \((t)\)\)]],
  " defined on the interval ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  ".  That is, a curve C is the range of a function given by  ",
  Cell[BoxData[
      \(z \((t)\) = \(\((x \((t)\), y \((t)\))\) = 
          x \((t)\) + \[ImaginaryI]\ y \((t)\)\)\)]],
  ",  for ",
  Cell[BoxData[
      \(\(\(\ \)\(a \[LessEqual] t \[LessEqual] b\)\)\)]],
  ",  where both ",
  Cell[BoxData[
      \(x \((t)\)\)]],
  " and ",
  Cell[BoxData[
      \(y \((t)\)\)]],
  " are continuous real-valued functions.  If both ",
  Cell[BoxData[
      \(x \((t)\)\)]],
  " and ",
  Cell[BoxData[
      \(y \((t)\)\)]],
  " are differentiable, we say that the curve is smooth.  A curve for which \
",
  Cell[BoxData[
      \(x \((t)\)\)]],
  " and ",
  Cell[BoxData[
      \(y \((t)\)\)]],
  " are differentiable except for a finite number of points is called \
piecewise smooth.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Definition  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Curve",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Curve.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  \n\n\tWe specify a curve ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " as  \n\n\t\t\t",
  Cell[BoxData[
      \(C : \ z \((t)\) = 
        x \((t)\) + \[ImaginaryI]\ y \((t)\)\ \ \ for\ \ \ a \[LessEqual] 
          t \[LessEqual] b\)]],
  ",  \n\nand say that ",
  Cell[BoxData[
      \(z \((t)\)\)]],
  " is a parametrization for the curve ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".  Notice that with this parametrization, we are specifying a direction \
the curve ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", and we say that ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a curve that goes from the initial point  ",
  Cell[BoxData[
      RowBox[{\(z \((a)\)\), "=", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{\(x \((a)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(y \((a)\)\)}], ")"}], 
          "=", \(x \((a)\) + \[ImaginaryI]\ y \((a)\)\)}]}]]],
  "  to the terminal point  ",
  Cell[BoxData[
      RowBox[{\(z \((b)\)\), "=", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{\(x \((b)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(y \((b)\)\)}], ")"}], 
          "=", \(x \((b)\) + \[ImaginaryI]\ y \((b)\)\)}]}]]],
  ".  If we had another function whose range was the same set of points as \
z(t) but whose initial and final points were reversed, we would indicate the \
curve this function defines by ",
  StyleBox["-C",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 1.22.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find parametrizations for ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["-C",
    FontFamily->"Courier New"],
  ", where ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is the straight line segment beginning at ",
  Cell[BoxData[
      \(z\_0 = x\_0 + \[ImaginaryI]\ y\_0\)]],
  " and ending at ",
  Cell[BoxData[
      \(z\_1 = x\_1 + \[ImaginaryI]\ y\_1\)]],
  ".  \n\nSolution.  Refer to Figure 1.21. The vector form of a line shows \
that the direction of ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is ",
  Cell[BoxData[
      \(z\_1 - z\_0\)]],
  ".  As ",
  Cell[BoxData[
      \(z\_0\)]],
  " is a point on ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", its vector equation is\n\n",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox[\((1 - 48)\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->RGBColor[0, 0, 0.996109],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              "                      ", \(C : \ z \((t)\)\)}], " ", "=", " ", 
            
            RowBox[{
              RowBox[{\(z\_0\), " ", "+", " ", 
                RowBox[{\((z\_1 - z\_0)\), "t", "    ", 
                  StyleBox["for",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "    ", "0"}]}], "\[LessEqual]",
               "t", "\[LessEqual]", "1"}]}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["  ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["or",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], "\n"}], "\n", 
      RowBox[{"                                   ", 
        RowBox[{\(C : \ z \((t)\)\), " ", "=", " ", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["(",
                  FontSize->16], \(x\_0 + \((x\_1 - x\_0)\) t\), 
                StyleBox[")",
                  FontSize->16]}], " ", "+", " ", 
              RowBox[{"\[ImaginaryI]", 
                RowBox[{
                  StyleBox["(",
                    FontSize->16], \(y\_0 + \((y\_1 - y\_0)\) t\), 
                  StyleBox[")",
                    FontSize->16]}], "  ", 
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "   ", "0"}]}], "\[LessEqual]", 
            "t", "\[LessEqual]", 
            RowBox[{"1", 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Clearly one parametrization for  ",
  Cell[BoxData[
      \(\(-C\)\)]],
  "  is \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(-\(C : \ \[Gamma] \((t)\)\)\), " ", "=", " ", 
          RowBox[{
            RowBox[{\(z\_1\), " ", "+", " ", 
              RowBox[{\((z\_0 - z\_1)\), "t", "    ", 
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "    ", "0"}]}], "\[LessEqual]", 
            "t", "\[LessEqual]", " ", "1"}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["  ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["or",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  "\n\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  Note that  ",
  Cell[BoxData[
      \(\[Gamma] \((t)\)\  = \ z \((1 - t)\)\)]],
  ",  which illustrates a general principle:  If ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a curve parametrized by  ",
  Cell[BoxData[
      \(z \((t)\)\)]],
  "  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  ",  then one parametrization for  ",
  Cell[BoxData[
      \(\(-C\)\)]],
  "  will be  ",
  Cell[BoxData[
      \(\[Gamma] \((t)\)\  = \ z \((1 - t)\)\)]],
  ",  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.22.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter  ",
  Cell[BoxData[
      \(z\_0\ \ and\ \ z\_1\)]],
  "  and construct the line segment."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[t, x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_0 = x\_0 + \[ImaginaryI]\ y\_0;\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1 = x\_1 + \[ImaginaryI]\ y\_1;\)\ \), "\[IndentingNewLine]", 
    \(\(z[t_]\  = \ 
        z\_0 + \((z\_1 - z\_0)\) t;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_0\) = \>\"", 
        z\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", 
        z\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<z[t] = \!\(z\_0\) + (\!\(z\_1\)-\!\(z\_0\))t\>\""];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<z[t] = \>", z[t]];\)\ \), "\n", 
    \(\(z[t_]\  = \ 
        x\_0 + \((x\_1 - x\_0)\) 
            t + \[ImaginaryI] \((y\_0 + \((y\_1 - y\_0)\) 
                  t)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The equation of, C, a line segment\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<starting at \!\(z\_0\) and ending at \
\!\(z\_1\).\>\""];\)\ \), "\n", 
    \(\(Print["\<z[t] = \>", z[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       for  0 \[LessEqual] t \[LessEqual] 1\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<z[0] = \>", z[0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<z[1] = \>", z[1]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[t, x, 
        y, \[Gamma]];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_0 = x\_0 + \[ImaginaryI]\ y\_0;\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1 = x\_1 + \[ImaginaryI]\ y\_1;\)\ \), "\[IndentingNewLine]", 
    \(\(\[Gamma][t_]\  = \ 
        z\_1 + \((z\_0 - z\_1)\) t;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_0\) = \>\"", 
        z\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", 
        z\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\[Gamma][t] = \!\(z\_1\)+(\!\(z\_0\)-\!\(z\_1\))t\>\""];\
\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Gamma][t] = \>", \[Gamma][t]];\)\ \), "\n", 
    \(\(\[Gamma][t_]\  = \ 
        x\_1 + \((x\_0 - x\_1)\) 
            t + \[ImaginaryI] \((y\_1 + \((y\_0 - y\_1)\) 
                  t)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The equation of, -C, a line segment\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<starting at \!\(z\_1\) and ending at \
\!\(z\_0\).\>\""];\)\ \), "\n", 
    \(\(Print["\<\[Gamma][t] = \>", \[Gamma][
          t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       for  0 \[LessEqual] t \[LessEqual] 1\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[Gamma][0] = \>", \[Gamma][
          0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Gamma][1] = \>", \[Gamma][
          1]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<z[t] = \>", 
        z[t], "\<       for  0 \[LessEqual] t \[LessEqual] 1\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<z[0] = \>", z[0], "\<   z[1] = \>", 
        z[1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Gamma][t] = \>", \[Gamma][
          t], "\<,       for  0 \[LessEqual] t \[LessEqual] 1\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[Gamma][0] = \>", \[Gamma][
          0], "\<,    \[Gamma][1] = \>", \[Gamma][
          1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Note that\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<z[1-t] = \>", z[1 - t]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<z[1-t] = \>", 
        ComplexExpand[z[1 - t]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  z[1-t] = \[Gamma][t] ?  \>", \ 
        ComplexExpand[\ z[1 - t] \[Equal] \[Gamma][t]]\ ];\)\)}], "Input"]
}, Closed]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooomb
0?ooo`80000000<0oooo0000000000007@3oool00?l0ooooL`3oool00`00
0000oooo0000000N0?ooo`00O@3oooo]000000T0oooo00<000000?ooo`3o
ool07@3oool00?l0oooo:P3oool00`000000oooo0?ooo`150?ooo`800000
00<0oooo0000000000007@3oool00?l0oooo:P3oool00`000000oooo0?oo
o`1W0?ooo`00o`3ooolZ0?ooo`030000003oool0oooo06L0oooo003o0?oo
obX0oooo00<000000?ooo`3oool0I`3oool00?l0oooo:P3oool00`000000
oooo0?ooo`1W0?ooo`00o`3ooolZ0?ooo`030000003oool0oooo06L0oooo
003o0?ooobX0oooo00<000000?ooo`3oool0I`3oool00?l0oooo:P3oool0
0`000000oooo0?ooo`1W0?ooo`00o`3ooolZ0?ooo`030000003oool0oooo
06L0oooo003o0?ooobX0oooo00<000000?ooo`3oool0I`3oool00?l0oooo
:P3oool00`000000oooo0?ooo`1W0?ooo`00o`3ooolZ0?ooo`030000003o
ool0oooo06L0oooo003o0?ooobX0oooo00<000000?ooo`3oool0I`3oool0
0?l0oooo:P3oool00`000000oooo0?ooo`1W0?ooo`00o`3ooolZ0?ooo`03
0000003oool0oooo06L0oooo003o0?ooobX0oooo00<000000?ooo`3oool0
I`3oool00?l0oooo:P3oool00`000000oooo0?ooo`1W0?ooo`00o`3ooolZ
0?ooo`030000003oool0oooo06L0oooo003o0?ooobX0oooo00<000000?oo
o`3oool0I`3oool00?l0oooo:P3oool00`000000oooo0?ooo`1W0?ooo`00
o`3ooolZ0?ooo`030000003oool0oooo06L0oooo003o0?ooobX0oooo00<0
00000?ooo`3oool0I`3oool00?l0oooo:P3oool00`000000oooo0?ooo`1W
0?ooo`00o`3ooolZ0?ooo`030000003oool0oooo06L0oooo003o0?ooobX0
oooo00<000000?ooo`3oool0I`3oool00?l0oooo:P3oool00`000000oooo
0?ooo`1W0?ooo`00o`3ooolZ0?ooo`030000003oool0oooo06L0oooo003o
0?ooobX0oooo00<000000?ooo`3oool0I`3oool00?l0oooo:P3oool00`00
0000oooo0?ooo`1W0?ooo`00o`3ooolZ0?ooo`030000003oool0oooo06L0
oooo003o0?ooobX0oooo00<000000?ooo`3oool0I`3oool00?l0oooo:P3o
ool00`000000oooo0?ooo`1W0?ooo`00o`3ooolZ0?ooo`030000003oool0
oooo06L0oooo003o0?ooobX0oooo00<000000?ooo`3oool0I`3oool00?l0
oooo:P3oool00`000000oooo0?ooo`1W0?ooo`00o`3ooolZ0?ooo`030000
003oool0oooo06L0oooo003o0?ooobX0oooo00<000000?ooo`3oool0I`3o
ool00?l0oooo:P3oool00`000000oooo0?ooo`1W0?ooo`00o`3ooolZ0?oo
o`030000003oool0oooo06L0oooo003o0?ooobX0oooo00<000000?ooo`3o
ool0I`3oool00?l0oooo:P3oool00`000000oooo0?ooo`0B0?ooo`D00000
503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02l0oooo
003o0?ooobX0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0;P3o
ool00?l0oooo:P3oool00`000000oooo0?ooo`0<0?ooo`D000000`3oool0
0`000000oooo0?ooo`090?ooo`D00000103oool00`000000oooo0?ooo`02
0?ooo`D00000103oool00`000000oooo0?ooo`0]0?ooo`00o`3ooolZ0?oo
o`030000003oool0oooo00d0oooo00@000000?ooo`3oool000000`3oool0
10000000oooo0?ooo`3oool5000000<0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0]0?ooo`00o`3ooolZ0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02d0oooo003o
0?ooobX0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`3o
ool2000000<0oooo1@0000050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02d0oooo003o0?ooobX0oooo00<000000?ooo`3oool03@3oool0
10000000oooo0?ooo`00000?0?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo02d0oooo003o0?ooobX0oooo00<000000?ooo`3oool03@3o
ool5000000h0oooo1@0000040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0]0?ooo`00o`3ooolZ
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo02h0oooo003o0?oo
obX0oooo00<000000?ooo`3oool0:`3oool010000000oooo0?ooo`3oool2
000000@0oooo00<000000?ooo`3oool0;`3oool00?l0oooo:P3oool00`00
0000oooo0?ooo`1W0?ooo`00o`3ooolZ0?ooo`030000003oool0oooo06L0
oooo003o0?ooobX0oooo00<000000?ooo`3oool0I`3oool00?l0oooo:P3o
ool00`000000oooo0?ooo`1W0?ooo`00o`3ooolZ0?ooo`030000003oool0
oooo06L0oooo003o0?ooobX0oooo00<000000?ooo`3oool0<P3oool20?l0
03<0oooo003o0?ooobX0oooo00<000000?ooo`3oool0<03oool60?l00340
oooo003o0?ooobX0oooo00<000000?ooo`3oool0<03oool60?l00340oooo
003o0?ooobX0oooo00<000000?ooo`3oool0;`3oool80?l00300oooo003o
0?ooobX0oooo00<000000?ooo`3oool0;@3oool20000o`P0o`00<03oool0
0?l0oooo:P3oool00`000000oooo0?ooo`0Y0?ooo`@0003o0`3oool60?l0
0340oooo003o0?ooobX0oooo00<000000?ooo`3oool09P3oool30000o`L0
oooo1P3o000a0?ooo`00o`3ooolZ0?ooo`030000003oool0oooo02<0oooo
0`000?l<0?ooo`80o`00<`3oool00?l0oooo:P3oool00`000000oooo0?oo
o`0O0?ooo`@0003oA03oool00?l0oooo:P3oool00`000000oooo0?ooo`0K
0?ooo`@0003oB03oool00?l0oooo:P3oool00`000000oooo0?ooo`0G0?oo
o`@0003oC03oool00?40oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo01@0oooo0`000?m@0?ooo`00
l03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool04@3oool30000oe<0oooo003V0?ooo`D00000103o
ool00`000000oooo0?ooo`040?ooo`<00000103oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo00d0oooo10000?mF0?ooo`00iP3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`090?ooo`@0003oFP3oool00>L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`050?ooo`@0003oGP3oool00>P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`<0003oHP3oool0
0>H0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0000o`020000ofD0oooo003V0?ooo`D00000103oool00`00
0000oooo0?ooo`020?ooo`D00000103oool00`000000oooo0?ooo`0W0?oo
o`@0003oJ03oool00?00oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo02@0oooo10000?l20?ooo`03
0000003oool0oooo06L0oooo003a0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool08@3oool40000o`H0oooo00<000000?ooo`3oool0
I`3oool00?l0oooo7@3oool30000o`X0oooo00<000000?ooo`3oool0I`3o
ool00?l0oooo6P3oool30000o`d0oooo00<000000?ooo`3oool0I`3oool0
0?l0oooo5P3oool40000oa00oooo00<000000?ooo`3oool0I`3oool00?l0
oooo4P3oool40000oa@0oooo00<000000?ooo`3oool0I`3oool00?l0oooo
3P3oool40000oaP0oooo00<000000?ooo`3oool0I`3oool00?l0oooo2`3o
ool30000oa`0oooo00<000000?ooo`3oool0I`3oool00?l0oooo203oool3
0000oal0oooo00<000000?ooo`3oool0I`3oool00?l0oooo103oool40000
ob80oooo00<000000?ooo`3oool0I`3oool00?l0oooo10000?lV0?ooo`03
0000003oool0oooo06L0oooo003j0?ooo`D0003o:P3oool00`000000oooo
0?ooo`1W0?ooo`00mP3oool40000obl0oooo00<000000?ooo`3oool0I`3o
ool00?80oooo10000?lc0?ooo`030000003oool0oooo06L0oooo003_0?oo
o`<0003o=`3oool00`000000oooo0?ooo`1W0?ooo`00k03oool30000ocX0
oooo00<000000?ooo`3oool0I`3oool00>T0oooo0`000?lm0?ooo`030000
003oool0oooo06L0oooo003U0?ooo`@0003o@03oool00`000000oooo0?oo
o`1W0?ooo`00h@3oool40000od@0oooo00<000000?ooo`3oool0I`3oool0
08P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0380oooo0`000?m80?ooo`030000003oool0oooo
06L0oooo00270?ooo`030000003oool0000001@0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0]0?ooo`@0003oB`3oool00`000000
oooo0?ooo`1W0?ooo`00P03oool500000080oooo00<000000?ooo`000000
2P3oool5000000@0oooo00<000000?ooo`3oool00`3oool3000000D0oooo
00<000000?ooo`3oool0:@3oool30000odl0oooo00<000000?ooo`3oool0
I`3oool00840oooo00@000000?ooo`3oool000000P3oool00`000000oooo
000000030?ooo`D000000P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool09@3oool40000oe80oooo00<000000?oo
o`3oool0I`3oool00880oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool08@3oool40000oeH0oooo00<000000?ooo`3oool0I`3oool008<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`D0
0000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
01h0oooo0`000?lH0?ooo`<00000?`3oool00`000000oooo0?ooo`1W0?oo
o`00P@3oool010000000oooo0?ooo`00000?0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool06`3oool30000oaX0oooo00D0
00000?ooo`3oool0oooo0000000n0?ooo`030000003oool0oooo06L0oooo
00210?ooo`D000003P3oool5000000@0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
5`3oool40000oad0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`1W0?ooo`00WP3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo0000000E0?ooo`D0003o8@3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo06L0oooo002O0?ooo`040000
003oool0oooo0?ooo`<000000`3oool00`000000oooo0?ooo`0@0?ooo`@0
003o9P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo06L0
oooo002i0?ooo`<0003o:P3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo06L0oooo002f0?ooo`<0003o;@3oool01@000000oooo0?oo
o`3oool0000003h0oooo00<000000?ooo`3oool0I`3oool00;80oooo1000
0?la0?ooo`@00000?P3oool00`000000oooo0?ooo`1W0?ooo`00[P3oool4
0000ogL0oooo00<000000?ooo`3oool0I`3oool00:X0oooo10000?mk0?oo
o`030000003oool0oooo06L0oooo002X0?ooo`80003oO`3oool00`000000
oooo0?ooo`1W0?ooo`00Y@3oool30000oh40oooo00<000000?ooo`3oool0
I`3oool00:40oooo10000?n40?ooo`030000003oool0oooo06L0oooo002M
0?ooo`@0003oR03oool00`000000oooo0?ooo`1W0?ooo`00V@3oool40000
oh`0oooo00<000000?ooo`3oool0I`3oool009H0oooo0`000?n@0?ooo`03
0000003oool0oooo06L0oooo00270?ooo`800?l02@3oool40000oi<0oooo
00<000000?ooo`3oool0I`3oool008D0oooo1P00o`040?ooo`<0003oU`3o
ool00`000000oooo0?ooo`1W0?ooo`00Q@3oool6003o00@0003oVP3oool0
0`000000oooo0?ooo`1W0?ooo`00Q03oool8003o09d0oooo00<000000?oo
o`3oool0I`3oool008@0oooo2000o`3o0?ooo`P0oooo00250?ooo`H00?l0
o`3oool90?ooo`00Q@3oool6003o0?l0oooo2@3oool008L0oooo0P00o`3o
0?ooo`/0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo
003o0?oooi@0oooo003o0?ooobP0oooo0P00001Z0?ooo`00o`3ooolY0?oo
o`030000003oool0oooo06P0oooo003o0?ooobX0oooo00<000000?ooo`3o
ool0I`3oool00?l0oooo:@3oool00`000000oooo0000001X0?ooo`00o`3o
oolX0?ooo`040000003oool0oooo000006P0oooo003o0?ooobL0oooo0`00
00000`3oool000000000001W0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\tFigure 1.21",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The straight-line segment ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " joining ",
  Cell[BoxData[
      RowBox[{\(z\_0\), " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(z\_1\)}]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the equation of the line segment with the initial point  ",
  Cell[BoxData[
      \(z\_0 = \(-3\) + 2  \[ImaginaryI]\)],
    AspectRatioFixed->True],
  "  and the terminal point  ",
  Cell[BoxData[
      \(z\_1 = \ 1\  + \ \[ImaginaryI]\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the initial point  ",
  Cell[BoxData[
      \(z\_0 = \(-3\) + 2  \[ImaginaryI]\)],
    AspectRatioFixed->True],
  "  and the terminal point  ",
  Cell[BoxData[
      \(z\_1 = \ 1\  + \ \[ImaginaryI]\)],
    AspectRatioFixed->True],
  "  and construct the line segment."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[t, x, y, z];\)\ \), "\n", 
    \(\(z\_0 = \(-3\) + 2  \[ImaginaryI];\)\ \), "\n", 
    \(\(z\_1 = \ 1\  + \ \[ImaginaryI];\)\ \), "\n", 
    \(x\_0 = Re[z\_0]; \ \ y\_0 = Im[z\_0]; \ \ x\_1 = Re[z\_1]; \ \ y\_1 = 
      Im[z\_1];\ \), "\n", 
    \(\(z[t_]\  = \ 
        x\_0 + \((x\_1 - x\_0)\) 
            t + \[ImaginaryI] \((y\_0 + \((y\_1 - y\_0)\) 
                  t)\);\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dot0 = 
        Graphics[{PointSize[0.03], Green, 
            Point[{Re[z\_0], Im[z\_0]}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(dot1 = 
        Graphics[{PointSize[0.03], Red, 
            Point[{Re[z\_1], Im[z\_1]}]}];\)\ \), "\n", 
    \(\(gr = 
        ParametricPlot[{Re[z[t]], Im[z[t]]}, {t, 0, 
            1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 1}, {0, 
                2}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-3\), 1, 1], 
              Range[0, 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1\/2, 
          PlotStyle \[Rule] Magenta, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \
\[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[gr, dot0, dot1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), "\n", 
    \(\(Print["\<Equation of a line segment:\>"];\)\ \), "\n", 
    \(\(Print["\<z[t] = \>", 
        z[t], "\<  for  0 \[LessEqual] t \[LessEqual] 1\>"];\)\ \), "\n", 
    \(\(Print["\<Initial  point (green)  z[0] = \>", \ z[0]];\)\ \), "\n", 
    \(\(Print["\<Terminal point (red)    z[1] = \>", \ 
        z[1]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tA curve ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " having the property that  ",
  Cell[BoxData[
      \(z \((a)\) = z \((b)\)\)]],
  "  is said to be a closed curve.  The line segment",
  StyleBox[" (1-48)",
    FontColor->RGBColor[0, 0, 1]],
  " is not a closed curve.  The range of  ",
  Cell[BoxData[
      \(z \((t)\)\  = \ x \((t)\) + \[ImaginaryI]\ y \((t)\)\)]],
  ",  where  ",
  Cell[BoxData[
      RowBox[{\(x \((t)\) = sin\ 2  t\ cos\ t\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "y", \((t)\)}], 
          "=", \(sin\ 2  t\ sin\ t\)}]}]]],
  "  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 2  \[Pi]\)]],
  "  is a closed curve because  ",
  Cell[BoxData[
      RowBox[{\(z \((0)\)\), "=", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"0", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "0"}], ")"}], 
          "=", \(z \((2  \[Pi])\)\)}]}]]],
  ".  The range of ",
  Cell[BoxData[
      \(z \((t)\)\)]],
  " is the four-leaved rose shown in Figure 1.22.  Note that, as ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " goes from ",
  Cell[BoxData[
      RowBox[{"0", " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\[Pi]\/2\)}]]],
  ", the point is on leaf  ",
  StyleBox["1",
    FontFamily->"Courier New"],
  " ;   from ",
  Cell[BoxData[
      RowBox[{\(\[Pi]\/2\), " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[Pi]"}]]],
  " to , it is on leaf  ",
  StyleBox["2",
    FontFamily->"Courier New"],
  " ;  between ",
  Cell[BoxData[
      RowBox[{"\[Pi]", " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\(3  \[Pi]\)\/2\)}]]],
  ", it is on leaf ",
  StyleBox["3",
    FontFamily->"Courier New"],
  ";  and finally, for ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " between ",
  Cell[BoxData[
      RowBox[{\(\(3  \[Pi]\)\/2\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", "\[Pi]"}]]],
  ", it is on leaf ",
  StyleBox["4",
    FontFamily->"Courier New"],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0000lb000`400?l0
0000o`00003oo`3ooomR0?ooo`00o`3ooomR0?ooo`00o`3ooomR0?ooo`00
o`3ooomR0?ooo`00o`3ooomR0?ooo`00o`3ooomR0?ooo`00o`3ooomR0?oo
o`00o`3ooomR0?ooo`00o`3ooomR0?ooo`00o`3ooomR0?ooo`00cP3oool2
000000@0oooo0P0000040?ooo`800000Q@3oool00<d0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000240?ooo`00c@3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo
0`00001n0?ooo`00a`3oool400000080oooo00@000000?ooo`3oool00000
2@3oool2000000@0oooo00<000000?ooo`3oool0OP3oool00<d0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo07h0oooo003>0?ooo`8000002P3oool2000000@0oooo
00<000000?ooo`3oool0OP3oool009L0oooo1P00o`130?ooo`030000003o
ool0oooo0480oooo1P00o`0f0?ooo`00T03ooolE003o03/0oooo00<00000
0?ooo`3oool0>P3ooolF003o02h0oooo002<0?ooo``00?l0103oool<003o
03P0oooo00<000000?ooo`3oool0=@3oool>003o00@0oooo2`00o`0/0?oo
o`00RP3oool7003o01<0oooo1P00o`0f0?ooo`030000003oool0oooo03<0
oooo1`00o`0E0?ooo`H00?l0:@3oool008P0oooo1@00o`0J0?ooo`H00?l0
<`3oool00`000000oooo0?ooo`0b0?ooo`@00?l06`3oool6003o02L0oooo
00270?ooo`@00?l07P3oool6003o0340oooo00<000000?ooo`3oool0<03o
ool4003o0200oooo1000o`0V0?ooo`00QP3oool3003o02<0oooo1P00o`0^
0?ooo`030000003oool0oooo02h0oooo1@00o`0S0?ooo`<00?l09@3oool0
08@0oooo1000o`0V0?ooo`D00?l0;@3oool00`000000oooo0?ooo`0]0?oo
o`@00?l09P3oool3003o02@0oooo00230?ooo`@00?l0:P3oool4003o02/0
oooo00<000000?ooo`3oool0:`3oool4003o02T0oooo0`00o`0S0?ooo`00
P`3oool2003o02d0oooo1000o`0Z0?ooo`030000003oool0oooo02X0oooo
1000o`0[0?ooo`<00?l08P3oool00880oooo0P00o`0`0?ooo`<00?l0:@3o
ool00`000000oooo0?ooo`0X0?ooo`@00?l0;P3oool3003o0240oooo0021
0?ooo`800?l0<P3oool4003o02L0oooo00<000000?ooo`3oool09`3oool4
003o0300oooo0P00o`0Q0?ooo`00P@3oool00`00o`00oooo0?ooo`0b0?oo
o`@00?l09P3oool00`000000oooo0?ooo`0U0?ooo`@00?l0<`3oool2003o
0200oooo00200?ooo`800?l0=P3oool4003o02@0oooo00<000000?ooo`3o
ool0903oool4003o03D0oooo0P00o`0O0?ooo`00O`3oool2003o03P0oooo
1000o`0S0?ooo`030000003oool0oooo0280oooo1000o`0h0?ooo`03003o
003oool0oooo01d0oooo001n0?ooo`800?l0>`3oool3003o0280oooo00<0
00000?ooo`3oool08@3oool4003o03T0oooo0P00o`0N0?ooo`00OP3oool0
0`00o`00oooo0?ooo`0k0?ooo`<00?l08@3oool00`000000oooo0?ooo`0P
0?ooo`<00?l0?03oool00`00o`00oooo0?ooo`0L0?ooo`00O@3oool2003o
03h0oooo0`00o`0P0?ooo`030000003oool0oooo01l0oooo0`00o`0m0?oo
o`800?l07@3oool007d0oooo00<00?l00?ooo`3oool0?P3oool3003o01l0
oooo00<000000?ooo`3oool07P3oool3003o03l0oooo00<00?l00?ooo`3o
ool06`3oool007`0oooo0P00o`110?ooo`<00?l07P3oool00`000000oooo
0?ooo`0M0?ooo`<00?l0@03oool2003o01`0oooo001l0?ooo`800?l0@P3o
ool3003o01d0oooo00<000000?ooo`3oool0703oool3003o0480oooo00<0
0?l00?ooo`3oool06P3oool007`0oooo0P00o`130?ooo`<00?l0703oool0
0`000000oooo0?ooo`0K0?ooo`<00?l0@P3oool2003o01`0oooo001l0?oo
o`800?l0A03oool3003o01/0oooo00<000000?ooo`3oool06P3oool3003o
04<0oooo0`00o`0K0?ooo`00O03oool00`00o`00oooo0?ooo`140?ooo`<0
0?l06P3oool00`000000oooo0?ooo`0I0?ooo`<00?l0A@3oool2003o01/0
oooo001k0?ooo`800?l0A`3oool3003o01T0oooo00<000000?ooo`3oool0
603oool3003o04H0oooo0P00o`0K0?ooo`00N`3oool2003o04P0oooo0`00
o`0H0?ooo`030000003oool0oooo01L0oooo0`00o`170?ooo`800?l06`3o
ool007/0oooo0P00o`190?ooo`800?l0603oool00`000000oooo0?ooo`0G
0?ooo`800?l0B03oool2003o01/0oooo001k0?ooo`800?l0BP3oool2003o
01L0oooo00<000000?ooo`3oool05P3oool2003o04T0oooo0P00o`0K0?oo
o`00N`3oool2003o04X0oooo0`00o`0F0?ooo`030000003oool0oooo01D0
oooo0P00o`1:0?ooo`800?l06`3oool007/0oooo00<00?l00?ooo`3oool0
BP3oool3003o01D0oooo00<000000?ooo`3oool05@3oool00`00o`00oooo
0?ooo`190?ooo`800?l06`3oool007X0oooo0P00o`1=0?ooo`<00?l0503o
ool00`000000oooo0?ooo`0D0?ooo`800?l0B`3oool2003o01/0oooo001j
0?ooo`<00?l0C@3oool3003o01<0oooo00<000000?ooo`3oool04`3oool2
003o04`0oooo0P00o`0K0?ooo`00N`3oool2003o04h0oooo0P00o`0C0?oo
o`030000003oool0oooo0180oooo0P00o`1=0?ooo`800?l06`3oool007/0
oooo0P00o`1?0?ooo`800?l04P3oool00`000000oooo0?ooo`0B0?ooo`03
003o003oool0oooo04`0oooo0P00o`0K0?ooo`00N`3oool2003o04l0oooo
0`00o`0A0?ooo`030000003oool0oooo0140oooo0P00o`1>0?ooo`800?l0
6`3oool007/0oooo0P00o`1@0?ooo`800?l04@3oool00`000000oooo0?oo
o`0@0?ooo`800?l0C`3oool2003o01/0oooo001k0?ooo`800?l0D@3oool2
003o0100oooo00<000000?ooo`3oool0403oool00`00o`00oooo0?ooo`1>
0?ooo`800?l06`3oool007/0oooo0P00o`1B0?ooo`03003o003oool0oooo
00h0oooo00<000000?ooo`3oool03`3oool2003o0500oooo0P00o`0K0?oo
o`00O03oool00`00o`00oooo0?ooo`1@0?ooo`800?l03`3oool00`000000
oooo0?ooo`0>0?ooo`800?l0D@3oool00`00o`00oooo0?ooo`0J0?ooo`00
O03oool2003o0580oooo00<00?l00?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`03003o003oool0oooo04l0oooo0P00o`0L0?ooo`00O@3o
ool00`00o`00oooo0?ooo`1@0?ooo`800?l03P3oool00`000000oooo0?oo
o`0=0?ooo`800?l0D@3oool2003o01`0oooo001l0?ooo`800?l0D`3oool0
0`00o`00oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo0P00o`1B
0?ooo`800?l0703oool007`0oooo0`00o`1B0?ooo`800?l03@3oool00`00
0000oooo0?ooo`0<0?ooo`03003o003oool0oooo0540oooo0P00o`0L0?oo
o`00O@3oool2003o05<0oooo0P00o`0<0?ooo`030000003oool0oooo00/0
oooo0P00o`1C0?ooo`800?l0703oool007d0oooo0P00o`1D0?ooo`03003o
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool2003o05<0oooo
0`00o`0L0?ooo`00O@3oool3003o05<0oooo0P00o`0;0?ooo`030000003o
ool0oooo00X0oooo00<00?l00?ooo`3oool0DP3oool2003o01d0oooo001n
0?ooo`800?l0E03oool00`00o`00oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo0P00o`1D0?ooo`800?l07@3oool007h0oooo0P00o`0`0?oo
o`<00?l08@3oool2003o00X0oooo00<000000?ooo`3oool0203oool3003o
02X0oooo1@00o`0T0?ooo`<00?l07@3oool007l0oooo0P00o`0^0?ooo`05
003o003oool0oooo0?ooo`00o`008@3oool00`00o`00oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo0P00o`0[0?ooo`05003o003oool0oooo
0?ooo`00o`00903oool2003o01h0oooo001o0?ooo`800?l0<P3oool00`00
o`00oooo0?ooo`0O0?ooo`800?l02@3oool00`000000oooo0?ooo`080?oo
o`800?l0;03oool00`00o`00oooo0?ooo`0U0?ooo`800?l07P3oool00800
oooo00<00?l00?ooo`3oool0<03oool00`00o`00oooo0?ooo`0O0?ooo`80
0?l02@3oool00`000000oooo0?ooo`070?ooo`<00?l0;@3oool00`00o`00
oooo0?ooo`0T0?ooo`03003o003oool0oooo01d0oooo00200?ooo`800?l0
;`3oool2003o0280oooo0`00o`080?ooo`030000003oool0oooo00L0oooo
0P00o`0_0?ooo`03003o003oool0oooo0280oooo0P00o`0O0?ooo`00P@3o
ool00`00o`00oooo0?ooo`0_0?ooo`03003o003oool0oooo0200oooo0P00
o`080?ooo`030000003oool0oooo00H0oooo0`00o`0_0?ooo`03003o003o
ool0oooo0240oooo0P00o`0P0?ooo`00P@3oool2003o0300oooo00<00?l0
0?ooo`3oool0803oool3003o00L0oooo00<000000?ooo`3oool01P3oool2
003o0340oooo00<00?l00?ooo`3oool0803oool00`00o`00oooo0?ooo`0O
0?ooo`00PP3oool2003o02/0oooo00D00?l00?ooo`3oool0oooo003o000S
0?ooo`800?l01`3oool00`000000oooo0?ooo`060?ooo`800?l0;@3oool0
1@00o`00oooo0?ooo`3oool00?l00240oooo0P00o`0Q0?ooo`00P`3oool0
0`00o`00oooo0?ooo`0Z0?ooo`<00?l0903oool2003o00L0oooo00<00000
0?ooo`3oool01@3oool3003o02h0oooo0`00o`0Q0?ooo`800?l08P3oool0
08<0oooo0P00o`1B0?ooo`<00?l01P3oool00`000000oooo0?ooo`050?oo
o`800?l0D`3oool00`00o`00oooo0?ooo`0Q0?ooo`00Q03oool2003o0580
oooo0P00o`060?ooo`030000003oool0oooo00D0oooo0P00o`1B0?ooo`80
0?l08`3oool008@0oooo0`00o`1A0?ooo`800?l01P3oool00`000000oooo
0?ooo`040?ooo`<00?l0D@3oool2003o02@0oooo00250?ooo`800?l0D@3o
ool3003o00D0oooo00<000000?ooo`3oool0103oool2003o0580oooo00<0
0?l00?ooo`3oool08`3oool008H0oooo0P00o`1A0?ooo`800?l01@3oool0
0`000000oooo0?ooo`030?ooo`<00?l0D@3oool2003o02D0oooo00260?oo
o`<00?l0D03oool3003o00@0oooo00<000000?ooo`3oool00`3oool2003o
0540oooo0P00o`0V0?ooo`00Q`3oool3003o0500oooo0P00o`040?ooo`03
0000003oool0oooo00<0oooo0P00o`1@0?ooo`800?l09`3oool008P0oooo
0`00o`1?0?ooo`800?l0103oool00`000000oooo0?ooo`020?ooo`<00?l0
D03oool00`00o`00oooo0?ooo`0V0?ooo`00R@3oool2003o04l0oooo0`00
o`030?ooo`030000003oool0oooo0080oooo0P00o`1@0?ooo`800?l0:03o
ool008X0oooo0P00o`1?0?ooo`800?l00`3oool00`000000oooo0?ooo`02
0?ooo`800?l0C`3oool2003o02T0oooo002:0?ooo`<00?l0CP3oool2003o
00<0oooo00@000000?ooo`3oool0oooo0`00o`1>0?ooo`800?l0:P3oool0
08/0oooo0`00o`1=0?ooo`800?l00`3oool010000000oooo0?ooo`3oool2
003o04h0oooo0`00o`0Z0?ooo`00S03oool3003o04`0oooo0`00o`020?oo
o`040000003oool0oooo0?ooo`800?l0C@3oool3003o02/0oooo002=0?oo
o`<00?l0C03oool2003o0080oooo00@000000?ooo`3oool0oooo0P00o`1<
0?ooo`<00?l0;03oool008h0oooo0`00o`1;0?ooo`800?l00P3oool00`00
0000oooo0?ooo`03003o04/0oooo0`00o`0]0?ooo`00S`3oool3003o04X0
oooo0`00o`00103oool000000?ooo`3oool2003o04/0oooo0`00o`0^0?oo
o`00T03oool3003o04X0oooo0P00o`00103oool000000?ooo`3oool2003o
04X0oooo0`00o`0_0?ooo`00T@3oool3003o04T0oooo0P00o`00103oool0
00000?ooo`3oool2003o04T0oooo0`00o`0`0?ooo`00TP3oool3003o04P0
oooo0P00o`000`3oool000000?ooo`03003o04P0oooo0`00o`0a0?ooo`00
T`3oool3003o04L0oooo0P00o`000`3oool000000?ooo`02003o04P0oooo
0`00o`0b0?ooo`00U03oool3003o04L0oooo0P00o`0010000000oooo003o
0000o`170?ooo`<00?l0<`3oool009D0oooo1000o`150?ooo`800?l000@0
00000?ooo`00o`000?l0A@3oool4003o03@0oooo002F0?ooo`@00?l0A03o
ool2003o000400000000o`000?l0003o04@0oooo1000o`0e0?ooo`00V03o
ool4003o0480oooo0P00o`000`0000000?l0003o00130?ooo`@00?l0=`3o
ool009T0oooo1000o`110?ooo`800?l000<00000003o0000o`00@P3oool4
003o03P0oooo002K0?ooo`@00?l0?`3oool2003o000300000000o`000?l0
0440oooo0`00o`0j0?ooo`00W03oool4003o03h0oooo0P00o`000`000000
0?l0003o000o0?ooo`@00?l0>`3oool009h0oooo1000o`0l0?ooo`800?l0
00<00000003o0000o`00?P3oool4003o03`0oooo002O0?ooo`D00?l0>`3o
ool4003o03`0oooo1000o`0n0?ooo`00X@3oool5003o03T0oooo1000o`0i
0?ooo`H00?l0?`3oool00:<0oooo1@00o`0g0?ooo`@00?l0=`3oool6003o
0440oooo002U0?ooo`D00?l0=@3oool4003o03D0oooo1@00o`140?ooo`00
Y`3oool5003o03<0oooo0`00o`0d0?ooo`D00?l0AP3oool00:T0oooo1@00
o`0a0?ooo`<00?l0<`3oool4003o04P0oooo002[0?ooo`D00?l0;`3oool3
003o0340oooo1000o`1:0?ooo`00M03oool2000000@0oooo0P0000040?oo
o`800000:`3oool5003o02d0oooo0`00o`0_0?ooo`D00?l0;03oool20000
00@0oooo0P0000040?ooo`8000004@3oool007<0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`00000/0?ooo`D00?l0:`3oool3
003o02`0oooo1P00o`0]0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool00000403oool007<0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000^0?ooo`H00?l0:03oool3003o02X0
oooo1P00o`0_0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000403oool006d0oooo100000020?ooo`040000003oool0oooo
000000T0oooo0P00000a0?ooo`H00?l09P3oool3003o02L0oooo1P00o`0b
0?ooo`040000003oool0oooo000000T0oooo0P00000A0?ooo`00L`3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000003<0oooo
1P00o`0S0?ooo`<00?l08`3oool8003o03@0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`00000@0?ooo`00M03oool2000000X0
oooo0P00000f0?ooo`P00?l07`3oool2003o01l0oooo2@00o`0i0?ooo`80
00002P3oool200000140oooo002l0?ooo`P00?l06`3oool2003o01/0oooo
2@00o`1L0?ooo`00`03oool8003o01L0oooo0P00o`0F0?ooo`T00?l0H@3o
ool00<@0oooo3000o`0?0?ooo`800?l04P3oool9003o06D0oooo00380?oo
o`/00?l0303oool2003o00h0oooo2000o`1J0?ooo`80000000<0oooo0000
000000002`3oool007P0ooooF000000S003o05L00000203oool00`000000
oooo0000000<0?ooo`00N03oool00`000000oooo0?ooo`1C0?ooobH00?l0
E@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo
001h0?ooo`030000003oool0oooo04`0oooo5000o`040?ooo`800?l01`3o
oolA003o0500oooo00<000000?ooo`3oool01@3oool2000000030?ooo`00
0000000000/0oooo00330?ooo`/00?l04@3oool2003o01<0oooo3000o`1Q
0?ooo`00_P3oool9003o01P0oooo0P00o`0H0?ooo`/00?l0G@3oool00;/0
oooo2000o`0L0?ooo`800?l07`3oool6003o05/0oooo002g0?ooo`L00?l0
8@3oool3003o0240oooo1P00o`1H0?ooo`00]@3oool6003o02@0oooo0`00
o`0S0?ooo`L00?l0E@3oool00;80oooo1P00o`0W0?ooo`<00?l09P3oool7
003o0580oooo002`0?ooo`H00?l0:@3oool3003o02X0oooo1P00o`1?0?oo
o`00[P3oool5003o02`0oooo0`00o`0]0?ooo`D00?l0C@3oool00:/0oooo
1P00o`0^0?ooo`<00?l0;`3oool5003o04/0oooo002Y0?ooo`H00?l0<03o
ool3003o0340oooo1P00o`180?ooo`00Y`3oool5003o03<0oooo0`00o`0c
0?ooo`H00?l0AP3oool00:D0oooo1@00o`0e0?ooo`<00?l0=P3oool5003o
04@0oooo002S0?ooo`D00?l0=`3oool4003o03L0oooo1@00o`120?ooo`00
XP3oool4003o03T0oooo1000o`0i0?ooo`@00?l0@@3oool00:00oooo1000
o`0j0?ooo`800?l000<00000003o0000o`00>`3oool4003o03l0oooo002O
0?ooo`@00?l0>`3oool2003o000300000000o`000?l003`0oooo1000o`0n
0?ooo`00W@3oool4003o03d0oooo0P00o`000`0000000?l0003o000n0?oo
o`@00?l0?03oool009`0oooo1000o`0n0?ooo`800?l000<00000003o0000
o`00?`3oool4003o03/0oooo002J0?ooo`@00?l0@03oool2003o00030000
0000o`000?l00440oooo0`00o`0j0?ooo`00V@3oool4003o0440oooo0P00
o`000`0000000?l0003o00120?ooo`@00?l0>03oool009L0oooo1000o`13
0?ooo`800?l000@00000003o0000o`000?l0@P3oool4003o03L0oooo002F
0?ooo`@00?l0A03oool2003o00040000003oool00?l0003o04@0oooo1000
o`0e0?ooo`00U@3oool3003o04H0oooo0P00o`0010000000oooo003o0000
o`150?ooo`@00?l0=03oool009@0oooo0`00o`160?ooo`<00?l000@00000
0?ooo`00o`000?l0A`3oool3003o03<0oooo002C0?ooo`<00?l0A`3oool2
003o00030?ooo`000000oooo00<00?l0A`3oool3003o0380oooo002B0?oo
o`<00?l0B03oool2003o00040?ooo`000000oooo0?ooo`800?l0B03oool3
003o0340oooo002A0?ooo`<00?l0B@3oool2003o00040?ooo`000000oooo
0?ooo`800?l0B@3oool3003o0300oooo002@0?ooo`<00?l0B@3oool3003o
00040?ooo`000000oooo0?ooo`800?l0BP3oool3003o02l0oooo002?0?oo
o`<00?l0BP3oool2003o0080oooo00<000000?ooo`3oool00`00o`1:0?oo
o`<00?l0;P3oool008h0oooo0`00o`1;0?ooo`800?l00P3oool010000000
oooo0?ooo`3oool2003o04/0oooo0`00o`0]0?ooo`00S@3oool3003o04`0
oooo0P00o`020?ooo`040000003oool0oooo0?ooo`800?l0C03oool3003o
02`0oooo002<0?ooo`<00?l0C03oool3003o0080oooo00@000000?ooo`3o
ool0oooo0`00o`1<0?ooo`<00?l0:`3oool008/0oooo0`00o`1=0?ooo`80
0?l00`3oool00`000000oooo0?ooo`020?ooo`800?l0C@3oool3003o02X0
oooo002:0?ooo`<00?l0CP3oool2003o00<0oooo00<000000?ooo`3oool0
0P3oool2003o04h0oooo0`00o`0Y0?ooo`00R@3oool3003o04l0oooo0P00
o`030?ooo`030000003oool0oooo0080oooo0`00o`1>0?ooo`800?l0:@3o
ool008P0oooo0`00o`1@0?ooo`800?l00`3oool00`000000oooo0?ooo`03
0?ooo`800?l0C`3oool2003o02P0oooo00270?ooo`<00?l0D03oool3003o
00<0oooo00<000000?ooo`3oool00`3oool2003o04l0oooo0`00o`0W0?oo
o`00Q`3oool2003o0540oooo0P00o`040?ooo`030000003oool0oooo00<0
oooo0`00o`1?0?ooo`<00?l09P3oool008H0oooo0P00o`1A0?ooo`<00?l0
103oool00`000000oooo0?ooo`040?ooo`800?l0D03oool3003o02D0oooo
00260?ooo`03003o003oool0oooo0500oooo0P00o`050?ooo`030000003o
ool0oooo00@0oooo0P00o`1A0?ooo`<00?l0903oool008D0oooo0P00o`1B
0?ooo`800?l01@3oool00`000000oooo0?ooo`040?ooo`800?l0DP3oool2
003o02@0oooo00240?ooo`800?l0DP3oool3003o00D0oooo00<000000?oo
o`3oool0103oool3003o0580oooo0P00o`0S0?ooo`00Q03oool00`00o`00
oooo0?ooo`1A0?ooo`800?l01P3oool00`000000oooo0?ooo`050?ooo`80
0?l0DP3oool3003o0280oooo00230?ooo`800?l0D`3oool2003o00H0oooo
00<000000?ooo`3oool01@3oool2003o05<0oooo0`00o`0Q0?ooo`00P`3o
ool00`00o`00oooo0?ooo`1A0?ooo`800?l01`3oool00`000000oooo0?oo
o`050?ooo`800?l0E03oool2003o0240oooo00220?ooo`800?l0D`3oool0
0`00o`00oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00?l0
0?ooo`3oool0DP3oool3003o0200oooo00210?ooo`800?l0D`3oool2003o
00P0oooo00<000000?ooo`3oool01P3oool2003o05@0oooo0P00o`0P0?oo
o`00P@3oool00`00o`00oooo0?ooo`1B0?ooo`03003o003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`00o`00oooo0?ooo`1B0?ooo`80
0?l0803oool00800oooo0P00o`0T0?ooo`<00?l0;03oool2003o00T0oooo
00<000000?ooo`3oool01`3oool2003o02d0oooo1@00o`0Q0?ooo`<00?l0
7`3oool00800oooo00<00?l00?ooo`3oool0903oool00`00o`00oooo0?oo
o`0[0?ooo`03003o003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`00o`00oooo0?ooo`0]0?ooo`03003o003oool0oooo0280oooo0P00
o`0O0?ooo`00O`3oool2003o02H0oooo00<00?l00?ooo`3oool0:P3oool2
003o00X0oooo00<000000?ooo`3oool0203oool2003o02h0oooo00<00?l0
0?ooo`3oool08P3oool3003o01h0oooo001n0?ooo`<00?l08P3oool6003o
02/0oooo00<00?l00?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`03003o003oool0oooo02`0oooo00<00?l00?ooo`3oool08`3oool2003o
01h0oooo001n0?ooo`800?l0903oool01000o`00oooo0?ooo`00o`0/0?oo
o`03003o003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool2003o
02d0oooo00<00?l00?ooo`3oool08`3oool2003o01h0oooo001n0?ooo`80
0?l0903oool01000o`00oooo0?ooo`00o`0[0?ooo`800?l02`3oool00`00
0000oooo0?ooo`0:0?ooo`03003o003oool0oooo02/0oooo00<00?l00?oo
o`3oool08`3oool3003o01d0oooo001m0?ooo`<00?l09@3oool00`00o`00
oooo003o000[0?ooo`03003o003oool0oooo00X0oooo00<000000?ooo`3o
ool02P3oool2003o02`0oooo00<00?l00?ooo`3oool0903oool2003o01d0
oooo001m0?ooo`800?l09P3oool00`00o`00oooo003o000Z0?ooo`800?l0
303oool00`000000oooo0?ooo`0;0?ooo`03003o003oool0oooo02P0oooo
0`00o`0V0?ooo`800?l07@3oool007d0oooo0P00o`0W0?ooo`800?l0:P3o
ool00`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo0P00
o`0[0?ooo`03003o003oool0oooo02D0oooo00<00?l00?ooo`3oool06`3o
ool007`0oooo0`00o`1B0?ooo`800?l03@3oool00`000000oooo0?ooo`0<
0?ooo`03003o003oool0oooo0540oooo0P00o`0L0?ooo`00O03oool2003o
05<0oooo00<00?l00?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`800?l0D`3oool00`00o`00oooo0?ooo`0J0?ooo`00O03oool2003o0580
oooo0P00o`0>0?ooo`030000003oool0oooo00d0oooo00<00?l00?ooo`3o
ool0D@3oool2003o01/0oooo001k0?ooo`<00?l0D@3oool2003o00l0oooo
00<000000?ooo`3oool03@3oool2003o0580oooo0P00o`0K0?ooo`00N`3o
ool2003o0580oooo00<00?l00?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`800?l0D@3oool2003o01/0oooo001k0?ooo`800?l0D@3oool2
003o0100oooo00<000000?ooo`3oool03`3oool2003o0500oooo0P00o`0K
0?ooo`00N`3oool2003o0500oooo0P00o`0A0?ooo`030000003oool0oooo
0100oooo00<00?l00?ooo`3oool0CP3oool2003o01/0oooo001k0?ooo`80
0?l0D03oool00`00o`00oooo0?ooo`0@0?ooo`030000003oool0oooo0100
oooo0P00o`1?0?ooo`800?l06`3oool007/0oooo0P00o`1?0?ooo`800?l0
4P3oool00`000000oooo0?ooo`0A0?ooo`800?l0CP3oool2003o01/0oooo
001k0?ooo`800?l0CP3oool2003o01<0oooo00<000000?ooo`3oool04P3o
ool00`00o`00oooo0?ooo`1<0?ooo`800?l06`3oool007/0oooo0P00o`1>
0?ooo`03003o003oool0oooo0180oooo00<000000?ooo`3oool04P3oool2
003o04d0oooo0P00o`0K0?ooo`00NP3oool3003o04d0oooo0P00o`0D0?oo
o`030000003oool0oooo01<0oooo0P00o`1<0?ooo`800?l06`3oool007X0
oooo0P00o`1=0?ooo`800?l05@3oool00`000000oooo0?ooo`0D0?ooo`80
0?l0B`3oool2003o01/0oooo001j0?ooo`<00?l0B`3oool2003o01H0oooo
00<000000?ooo`3oool05@3oool2003o04X0oooo0P00o`0K0?ooo`00N`3o
ool2003o04X0oooo0`00o`0F0?ooo`030000003oool0oooo01D0oooo0`00
o`190?ooo`800?l06`3oool007/0oooo0P00o`190?ooo`<00?l05`3oool0
0`000000oooo0?ooo`0F0?ooo`<00?l0B03oool2003o01/0oooo001k0?oo
o`800?l0B03oool3003o01P0oooo00<000000?ooo`3oool05`3oool3003o
04L0oooo0P00o`0K0?ooo`00N`3oool2003o04L0oooo0`00o`0I0?ooo`03
0000003oool0oooo01P0oooo0P00o`170?ooo`800?l06`3oool007/0oooo
0P00o`170?ooo`800?l06P3oool00`000000oooo0?ooo`0I0?ooo`800?l0
AP3oool2003o01/0oooo001l0?ooo`03003o003oool0oooo04@0oooo0P00
o`0K0?ooo`030000003oool0oooo01T0oooo0`00o`150?ooo`03003o003o
ool0oooo01X0oooo001l0?ooo`800?l0A03oool3003o01/0oooo00<00000
0?ooo`3oool06P3oool3003o04<0oooo0P00o`0L0?ooo`00O@3oool00`00
o`00oooo0?ooo`110?ooo`<00?l0703oool00`000000oooo0?ooo`0K0?oo
o`<00?l0@P3oool2003o01`0oooo001l0?ooo`800?l0@P3oool3003o01d0
oooo00<000000?ooo`3oool0703oool3003o0440oooo0P00o`0L0?ooo`00
O@3oool00`00o`00oooo0?ooo`0o0?ooo`<00?l07P3oool00`000000oooo
0?ooo`0M0?ooo`<00?l0@03oool2003o01`0oooo001m0?ooo`800?l0?`3o
ool3003o01l0oooo00<000000?ooo`3oool07P3oool3003o03h0oooo0`00
o`0L0?ooo`00OP3oool00`00o`00oooo0?ooo`0k0?ooo`@00?l0803oool0
0`000000oooo0?ooo`0O0?ooo`@00?l0?03oool2003o01d0oooo001n0?oo
o`800?l0>`3oool4003o0240oooo00<000000?ooo`3oool0803oool4003o
03X0oooo0P00o`0N0?ooo`00O`3oool00`00o`00oooo0?ooo`0h0?ooo`<0
0?l08`3oool00`000000oooo0?ooo`0R0?ooo`<00?l0>@3oool00`00o`00
oooo0?ooo`0M0?ooo`00O`3oool2003o03P0oooo0`00o`0T0?ooo`030000
003oool0oooo02<0oooo0`00o`0g0?ooo`800?l07`3oool00800oooo0P00
o`0e0?ooo`@00?l09@3oool00`000000oooo0?ooo`0T0?ooo`@00?l0=@3o
ool00`00o`00oooo0?ooo`0N0?ooo`00P@3oool2003o03<0oooo1000o`0V
0?ooo`030000003oool0oooo02D0oooo1000o`0c0?ooo`800?l0803oool0
0880oooo0P00o`0a0?ooo`<00?l0:03oool00`000000oooo0?ooo`0W0?oo
o`<00?l0<P3oool00`00o`00oooo0?ooo`0O0?ooo`00PP3oool3003o02h0
oooo1000o`0Y0?ooo`030000003oool0oooo02P0oooo1000o`0_0?ooo`80
0?l08@3oool008<0oooo0`00o`0[0?ooo`D00?l0:P3oool00`000000oooo
0?ooo`0Y0?ooo`@00?l0;@3oool2003o0280oooo00240?ooo`<00?l0:03o
ool5003o02`0oooo00<000000?ooo`3oool0:`3oool4003o02T0oooo0`00
o`0S0?ooo`00Q@3oool3003o02D0oooo1@00o`0^0?ooo`030000003oool0
oooo02`0oooo1@00o`0U0?ooo`D00?l08`3oool008H0oooo0`00o`0S0?oo
o`@00?l0<03oool00`000000oooo0?ooo`0^0?ooo`@00?l08`3oool4003o
02D0oooo00270?ooo`@00?l07`3oool4003o0380oooo00<000000?ooo`3o
ool0<03oool4003o01l0oooo1000o`0W0?ooo`00R03oool5003o01X0oooo
1P00o`0c0?ooo`030000003oool0oooo0340oooo2000o`0I0?ooo`@00?l0
:03oool008X0oooo1P00o`0E0?ooo`H00?l0=@3oool00`000000oooo0?oo
o`0c0?ooo`T00?l04P3oool6003o02X0oooo002<0?ooo`P00?l03@3oool7
003o03P0oooo00<000000?ooo`3oool0>@3oool6003o00`0oooo2000o`0[
0?ooo`00S`3ooolG003o03X0oooo00<000000?ooo`3oool0>`3ooolD003o
02l0oooo002C0?ooo`l00?l0?P3oool00`000000oooo0?ooo`0n0?ooo`h0
0?l0<P3oool00<h0oooo0P0000040?ooo`800000103oool2000000@0oooo
00<000000?ooo`3oool0OP3oool00<d0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo07h0
oooo003=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000`3oool3000007h0oooo003=0?ooo`040000003oool0oooo0000
00T0oooo0P0000250?ooo`00c@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000008@0oooo003>0?ooo`8000002P3oool20000
08D0oooo003o0?ooof80oooo003o0?ooof80oooo003o0?ooof80oooo003o
0?ooof80oooo003N0?ooo`800000P@3oool00=l0oooo00<000000?ooo`3o
ool0O`3oool00>00oooo00<000000?ooo`3oool0OP3oool00=l0oooo00<0
00000?ooo`000000O`3oool00=h0oooo00@000000?ooo`3oool00000O`3o
ool00=d0oooo0`0000000`3oool000000000001n0?ooo`00o`3ooomR0?oo
o`00o`3ooomR0?ooo`00o`3ooomR0?ooo`00o`3ooomR0?ooo`00o`3ooomR
0?ooo`00o`3ooomR0?ooo`00o`3ooomR0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{353, 243},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\tFigure 1.22",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The curve ",
  Cell[BoxData[
      RowBox[{\(x \((t)\) = sin\ 2  t\ cos\ t\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "y", \((t)\)}], 
          "=", \(sin\ 2  t\ sin\ t\)}]}]]],
  " for ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 2  \[Pi]\)]],
  ", which forms a four-leaved rose."
}], "Text"],

Cell[TextData[{
  "\tNote further, in Figure 1.22, that at the point ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "0"}], ")"}]]],
  ", the curve has crossed over itself (at points other than those \
corresponding with   ",
  Cell[BoxData[
      RowBox[{"t", "=", 
        RowBox[{
          RowBox[{"0", " ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", "t"}], "=", \(2  \[Pi]\)}]}]]],
  ");  we want to be able to distinguish when a curve does not cross over \
itself in this way.  The curve ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is called simple if it does not cross over itself, except possibly at its \
initial and terminal points.  In other words, the curve  ",
  Cell[BoxData[
      \(C : \ z \((t)\)\)]],
  ",  for  ",
  Cell[BoxData[
      \(a \[LessEqual] t \[LessEqual] b\)]],
  ",  is simple provided that  ",
  Cell[BoxData[
      \(z \((t\_1)\) \[NotEqual] z \((t\_2)\)\)]],
  "  whenever  ",
  Cell[BoxData[
      \(t\_1 \[NotEqual] t\_2\)]],
  ",  except possibly when  ",
  Cell[BoxData[
      RowBox[{\(t\_1\), "=", 
        RowBox[{
          RowBox[{"a", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(t\_2\)}], "=", "b"}]}]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The curve  ",
  Cell[BoxData[
      RowBox[{\(x \((t)\) = sin\ 2  t\ cos\ t\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "y", \((t)\)}], 
          "=", \(sin\ 2  t\ sin\ t\)}]}]]],
  "  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 2  \[Pi]\)]],
  ".  \n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The curve looks like a \"four leafed rose\"."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Extra Solution 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the curve and plot it.", "Text"],

Cell[BoxData[{
    \(\(Clear[t, x, y];\)\ \), "\[IndentingNewLine]", 
    \(\(x[t_] = Sin[2  t] Cos[t];\)\ \), "\[IndentingNewLine]", 
    \(\(y[t_] = Sin[2  t] Sin[t];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[{x[t], y[t]}, \[IndentingNewLine]{t, 0, 2  \[Pi]}, 
        PlotRange \[Rule] {{\(-0.8\), 0.8}, {\(-0.8\), 
              0.8}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-0.8\), 0.8, 
              0.8], Range[\(-0.8\), 0.8, 
              0.8]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Prolog \[Rule] {Thickness[0.01], Green}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x = \>", x[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = \>", \ 
        y[t], "\<  for  0 \[LessEqual] t \[LessEqual] 2\[Pi]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 1.23.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the circle ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " with center ",
  Cell[BoxData[
      \(z\_0 = x\_0 + \[ImaginaryI]\ y\_0\)]],
  " and radius ",
  Cell[BoxData[
      \(R\)]],
  " can be parameterized to form a simple closed curve.\n\nSolution.  Note \
that the required parametrization is \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(C : \ z \((t)\)\ \  = \ \ z\_0\  + \ 
            R\ \[ExponentialE]\^\(\[ImaginaryI]\ t\)\), "\n"}], 
    "\[IndentingNewLine]", 
      RowBox[{\(C : \ z \((t)\)\ \  = \ \ x\_0 + \[ImaginaryI]\ y\_0\  + \ 
            R\ \[ExponentialE]\^\(\[ImaginaryI]\ t\)\), 
        "\[IndentingNewLine]"}], "\n", 
      RowBox[{\(C : \ 
            z \((t)\)\ \  = \ \ \((x\_0 + 
                R\ cos\ t)\)\  + \ \[ImaginaryI]\ \((y\_0 + \ R\ sin\ t)\)\), 
        
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "                            ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "   ", "0"}], "\[LessEqual]", "t", 
          "\[LessEqual]", 
          RowBox[{"2", 
            RowBox[{"\[Pi]", " ", 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tFigure 1.23 shows that, as t varies from ",
  Cell[BoxData[
      RowBox[{"0", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "2", "\[Pi]"}]]],
  ", the circle is traversed counterclockwise.  If you were traveling around \
the circle in this manner, its interior would be on your left.  When a simple \
closed curve is parametrized in this fashion, we say that the curve has a \
positive orientation.  We will have more to say about this idea shortly."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 1.23.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter  ",
  Cell[BoxData[
      \(z\_0\ \ and\ \ R\)]],
  "  and construct the standard parameterization for the circle.\nUse the \
complex exponential form ",
  Cell[BoxData[
      \(z[t] = z\_0 + R\ \[ExponentialE]\^\(\[ImaginaryI]\ t\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[t, x, y, z];\)\ \ \), "\[IndentingNewLine]", 
    \(\(z\_0 = 2 + \[ImaginaryI];\)\ \ \), "\[IndentingNewLine]", 
    \(\(R = 2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(z[t_]\  = \ 
        z\_0 + R\ \[ExponentialE]\^\(\[ImaginaryI]\ t\);\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(x[t_] = ComplexExpand[Re[z[t]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(y[t_] = ComplexExpand[Im[z[t]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[{x[t], y[t]}, \[IndentingNewLine]{t, 0, 2  \[Pi]}, 
        PlotRange \[Rule] {{0.0, 5.0}, {\(-1.5\), 
              3.5}}, \[IndentingNewLine]Ticks \[Rule] {Range[0.0, 5.0, 1.0], 
            Range[\(-1.0\), 3.0, 
              1.0]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Prolog \[Rule] {Thickness[0.01], Green}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The equation of, C, a circle\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<with center \!\(z\_0\) = \>\"", 
        z\_0, "\< and radius R = \>", R];\)\ \ \), "\n", 
    \(\(Print["\<       for  0 \[LessEqual] t \[LessEqual] 2\[Pi]\>"];\)\ \ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<z[t] = \>", z[t]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<       for  0 \[LessEqual] t \[LessEqual] 2\[Pi]\>"];\)\ \ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x = \>", x[t]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = \>", \ y[t]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<       for  0 \[LessEqual] t \[LessEqual] 2\[Pi]\>"];\)\ \ \
\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007;0000m2000`400?l0
0000o`00003oo`3oooo<0?ooo`00o`3oooo<0?ooo`00o`3oooo<0?ooo`00
o`3oooo<0?ooo`00o`3oooo<0?ooo`00o`3oooo<0?ooo`00o`3oooo<0?oo
o`00o`3oooo<0?ooo`00o`3oooo<0?ooo`00o`3oooo<0?ooo`00o`3oooo<
0?ooo`00o`3ooonc0?ooo`80000000<0oooo000000000000503oool007P0
ooooo`00000b000000X0oooo00<000000?ooo`0000005@3oool007P0oooo
00<000000?ooo`3oool0o`3ooolj0?ooo`030000003oool0oooo01@0oooo
001h0?ooo`030000003oool0oooo0?l0oooo>03oool2000000030?ooo`00
0000000001@0oooo001h0?ooo`030000003oool0oooo0?l0ooooD@3oool0
07P0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00N03oool00`000000
oooo0?ooo`3o0?oooe40oooo001h0?ooo`030000003oool0oooo0?l0oooo
D@3oool007P0oooo00<000000?ooo`3oool0QP3oool400000<H0oooo001h
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0a`3oool0
07P0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`360?oo
o`00N03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0<D0
oooo001h0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0;X0
oooo001h0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
2@3oool2000000/0oooo00<000000?ooo`3oool0^@3oool007P0oooo00<0
00000?ooo`3oool0L`3oool4000000<0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`2h0?ooo`00N03oool00`000000oooo0?ooo`1d
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool8
000000030?ooo`000000000000H000001@3oool00`000000oooo0?ooo`2h
0?ooo`00N03oool00`000000oooo0?ooo`1c0?ooo`030000003oool00000
00@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`2h0?oo
o`00N03oool00`000000oooo0?ooo`1c0?ooo`@000000`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0;P0oooo001h0?ooo`030000
003oool0oooo07/0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`2i0?ooo`00N03oool00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0^P3oool007P0oooo00<00000
0?ooo`3oool0P`3oool2000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2o0?ooo`00N03oool00`000000oooo0?ooo`220?oo
o`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000`P3o
ool007P0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`04
0?ooo`030000003oool000000<80oooo001h0?ooo`030000003oool0oooo
08D0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000320?oo
o`00N03oool00`000000oooo0?ooo`220?ooo`040000003oool0oooo0000
00@0oooo1@0000310?ooo`00N03oool00`000000oooo0?ooo`230?ooo`80
0000b`3oool007P0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00N03o
ool00`000000oooo0?ooo`3o0?oooe40oooo001h0?ooo`030000003oool0
oooo0?l0ooooD@3oool007P0oooo00<000000?ooo`3oool0N`3oool20?l0
0=<0oooo001h0?ooo`030000003oool0oooo07T0oooo1P3o003A0?ooo`00
N03oool00`000000oooo0?ooo`1h0?ooo`P0o`00d03oool007P0oooo00<0
00000?ooo`3oool0LP3oool60000o`P0o`001P000?o:0?ooo`00N03oool0
0`000000oooo0?ooo`1/0?ooo`/0003o2P3o000;0000ol@0oooo001h0?oo
o`030000003oool0oooo06H0oooo4@000?l:0?l000l0003o`03oool007P0
oooo00<000000?ooo`3oool0I03oool?0000o`D0oooo203o00050?oooa00
003o^`3oool007P0oooo00<000000?ooo`3oool0H@3oool<0000o`/0oooo
203o000;0?ooo`h0003o]`3oool007P0oooo00<000000?ooo`3oool0G`3o
ool80000oa80oooo1P3o000A0?ooo``0003o]03oool007P0oooo00<00000
0?ooo`3oool0G03oool90000oaH0oooo0P3o000H0?ooo`T0003o/P3oool0
07P0oooo00<000000?ooo`3oool0FP3oool80000ocH0oooo2@000?n_0?oo
o`00N03oool00`000000oooo0?ooo`1G0?ooo`T0003o>`3oool80000ojd0
oooo001h0?ooo`030000003oool0oooo05D0oooo20000?m00?ooo`L0003o
[03oool007P0oooo00<000000?ooo`3oool0D`3oool80000odD0oooo1P00
0?nZ0?ooo`00N03oool00`000000oooo0?ooo`1B0?ooo`H0003oBP3oool6
0000ojP0oooo001h0?ooo`030000003oool0oooo0500oooo1P000?m=0?oo
o`H0003oY`3oool007P0oooo00<000000?ooo`3oool0CP3oool60000oe40
oooo1P000?nU0?ooo`00N03oool00`000000oooo0?ooo`1=0?ooo`H0003o
E03oool60000oj<0oooo001h0?ooo`030000003oool0oooo04/0oooo1P00
0?mG0?ooo`H0003oXP3oool007P0oooo00<000000?ooo`3oool0BP3oool5
0000oe/0oooo1@000?nQ0?ooo`00N03oool00`000000oooo0?ooo`190?oo
o`D0003oGP3oool40000oj00oooo001h0?ooo`030000003oool0oooo04L0
oooo1@000?mQ0?ooo`D0003oWP3oool007P0oooo00<000000?ooo`3oool0
AP3oool50000of<0oooo1@000?l20?ooo`03003o003oool0oooo09P0oooo
001h0?ooo`030000003oool0oooo04D0oooo0P000?l00`00o`00003o0000
o`1U0?ooo`80003o00<00?l00000o`000?l00`00o`2I0?ooo`00N03oool0
0`000000oooo0?ooo`140?ooo`040000o`00o`000?l00000ofT0oooo00<0
003o003o0000o`000`00o`2I0?ooo`00N03oool00`000000oooo0?ooo`12
0?ooo`030000o`00o`000?l000800?l0J`3oool6003o09P0oooo001h0?oo
o`030000003oool0oooo0440oooo1@00o`1[0?ooo`L00?l0V03oool007P0
oooo00<000000?ooo`3oool0@03oool6003o06X0oooo2@00o`2G0?ooo`00
N03oool00`000000oooo0?ooo`0n0?ooo`L00?l0K03oool9003o09H0oooo
001h0?ooo`030000003oool0oooo03`0oooo2000o`1_0?ooo`L00?l0UP3o
ool007P0oooo00<000000?ooo`3oool0>P3oool:003o0740oooo1P00o`2E
0?ooo`00N03oool00`000000oooo0?ooo`0i0?ooo`X00?l0L`3oool6003o
09@0oooo001h0?ooo`030000003oool0oooo03X0oooo2000o`1f0?ooo`@0
0?l000<0003o0?ooo`3oool0T@3oool007P0oooo00<000000?ooo`3oool0
>P3oool00`000?l00?l0003o0005003o07L0oooo1000o`000`000?l0oooo
0?ooo`2@0?ooo`00N03oool00`000000oooo0?ooo`0j0?ooo`80003o1@00
o`1j0?ooo`800?l00P000?nA0?ooo`00N03oool00`000000oooo0?ooo`0i
0?ooo`80003o00<00?l00000o`3oool00`00o`1k0?ooo`040000o`00o`00
003o0000oi00oooo001h0?ooo`030000003oool0oooo03P0oooo10000?l3
0?ooo`03003o003oool0oooo07/0oooo10000?n?0?ooo`00N03oool00`00
0000oooo0?ooo`0h0?ooo`<0003oP`3oool30000ohl0oooo001h0?ooo`03
0000003oool0oooo03L0oooo10000?n40?ooo`<0003oSP3oool007P0oooo
00<000000?ooo`3oool0=P3oool40000ohD0oooo10000?n=0?ooo`00N03o
ool00`000000oooo0?ooo`0f0?ooo`<0003oQ`3oool40000oh`0oooo001h
0?ooo`030000003oool0oooo03D0oooo10000?n80?ooo`<0003oS03oool0
07P0oooo00<000000?ooo`3oool0=03oool40000ohX0oooo0`000?n;0?oo
o`00N03oool00`000000oooo0?ooo`0d0?ooo`<0003oR`3oool40000ohX0
oooo001h0?ooo`030000003oool0oooo03<0oooo10000?n<0?ooo`<0003o
RP3oool007P0oooo00<000000?ooo`3oool0<P3oool40000ohd0oooo1000
0?n90?ooo`00N03oool00`000000oooo0?ooo`0b0?ooo`<0003oS`3oool3
0000ohT0oooo001h0?ooo`030000003oool0oooo0340oooo10000?n?0?oo
o`@0003oR03oool007P0oooo00<000000?ooo`3oool0<@3oool30000oi40
oooo10000?n70?ooo`00N03oool00`000000oooo0?ooo`0`0?ooo`@0003o
TP3oool30000ohL0oooo001h0?ooo`030000003oool0oooo02l0oooo1000
0?nC0?ooo`@0003oQP3oool007P0oooo00<000000?ooo`3oool0;`3oool3
0000oiD0oooo0`000?n60?ooo`00N03oool00`000000oooo0?ooo`0^0?oo
o`@0003oU@3oool40000ohD0oooo001h0?ooo`030000003oool0oooo02h0
oooo0`000?nG0?ooo`<0003oQ@3oool007P0oooo00<000000?ooo`3oool0
;P3oool30000oiL0oooo0`000?n50?ooo`00N03oool00`000000oooo0?oo
o`0]0?ooo`@0003oU`3oool40000oh@0oooo001h0?ooo`030000003oool0
oooo02d0oooo0`000?nI0?ooo`<0003oQ03oool007P0oooo00<000000?oo
o`3oool0;@3oool30000oiT0oooo10000?n30?ooo`00N03oool00`000000
oooo0?ooo`0/0?ooo`@0003oVP3oool30000oh<0oooo001h0?ooo`030000
003oool0oooo02`0oooo0`000?nK0?ooo`<0003oP`3oool007P0oooo00<0
00000?ooo`3oool0;03oool30000oi/0oooo10000?n20?ooo`00N03oool0
0`000000oooo0?ooo`0[0?ooo`@0003oW03oool30000oh80oooo001h0?oo
o`030000003oool0oooo02/0oooo0`000?nM0?ooo`<0003oPP3oool007P0
oooo00<000000?ooo`3oool0:P3oool40000oid0oooo0`000?n20?ooo`00
N03oool00`000000oooo0?ooo`0Z0?ooo`<0003oW`3oool30000oh40oooo
001h0?ooo`030000003oool0oooo02X0oooo0`000?nO0?ooo`<0003oP@3o
ool007P0oooo00<000000?ooo`3oool0:@3oool40000oil0oooo0`000?n1
0?ooo`00N03oool00`000000oooo0?ooo`0Y0?ooo`<0003oX03oool40000
oh00oooo001h0?ooo`030000003oool0oooo02T0oooo0`000?nQ0?ooo`<0
003oP03oool007P0oooo00<000000?ooo`3oool0:@3oool30000oj40oooo
0`000?n00?ooo`00N03oool00`000000oooo0?ooo`0X0?ooo`<0003oXP3o
ool40000ogl0oooo001h0?ooo`030000003oool0oooo02P0oooo0`000?nS
0?ooo`<0003oO`3oool007P0oooo00<000000?ooo`3oool0:03oool30000
oj<0oooo0`000?mo0?ooo`00N03oool00`000000oooo0?ooo`0X0?ooo`<0
003oX`3oool30000ogl0oooo001h0?ooo`030000003oool0oooo02P0oooo
0`000?m;0?ooo`030000003oool0oooo05D0oooo0`000?mo0?ooo`00N03o
ool00`000000oooo0?ooo`0X0?ooo`<0003oBP3oool00`000000oooo0000
001F0?ooo`<0003oO`3oool007P0oooo00<000000?ooo`3oool0:03oool3
0000od<0oooo1@0000020?ooo`030000003oool0000005H0oooo0`000?mo
0?ooo`00N03oool00`000000oooo0?ooo`0W0?ooo`@0003oA03oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0000005H0oooo10000?mn
0?ooo`00N03oool00`000000oooo0?ooo`0W0?ooo`<0003oAP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000005L0oooo0`000?mn0?oo
o`00N03oool00`000000oooo0?ooo`0W0?ooo`<0003oA`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo0`000?mn0?ooo`00
N03oool00`000000oooo0?ooo`0W0?ooo`<0003oA@3oool010000000oooo
0?ooo`00001L0?ooo`<0003oOP3oool007P0oooo00<000000?ooo`3oool0
9`3oool30000odD0oooo1@00001K0?ooo`<0003oOP3oool007P0oooo00<0
00000?ooo`3oool09`3oool30000ojD0oooo0`000?mn0?ooo`00N03oool0
0`000000oooo0?ooo`0W0?ooo`<0003oY@3oool30000ogh0oooo001h0?oo
o`030000003oool0oooo02L0oooo0P3o00000`000?l0oooo0?ooo`1?0?oo
o`80003oDP3oool00`000?l0o`000?l0001n0?ooo`00N03oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0203oool60?l004h0oooo1P000?m?0?ooo`H0o`003P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0b0?ooo`00N03oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1P3oool80?l004`0oooo20000?m=0?ooo`P0o`00303oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0a0?ooo`00N03oool00`000000oooo0?oo
o`080?ooo`@000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000070?ooo`P0o`00C03oool80000o`@0
o`3o0`3oool90?l0o`<0oooo2@3o0?l30?ooo`X0o`3o0`3oool90?l0o`<0
oooo2@3o0?l30?ooo`T0o`3o203o00040?ooo`@000000`3oool00`000000
oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`070?ooo`@0
0000203oool4000000<0oooo00<000000?ooo`3oool00P3oool400000003
0?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo0000000b0?oo
o`00N03oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00@0oooo2P3o001:0?ooo`X0003o0`3o0?l30?oo
o`T0o`3o0`3oool90?l0o`<0oooo2P3o0?l30?ooo`T0o`3o0`3oool90?l0
o`<0oooo203o0?l:0?l000@0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0503oool00`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0300oooo001h0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0103oool:
0?l004X0oooo2P000?l30?l0o`<0oooo2@3o0?l30?ooo`T0o`3o0`3oool:
0?l0o`<0oooo2@3o0?l30?ooo`T0o`3o0`3oool80?l0o`X0o`000`3oool0
0`000000oooo000000040?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`070?ooo`@00000203o
ool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003o
ool0oooo0300oooo001h0?ooo`030000003oool0oooo00P0oooo10000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`050?ooo`P0o`00C03oool80000obh0oooo0`00o`0L
0?ooo`P0o`00103oool4000000<0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo01<0oooo1000
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000040?ooo`030000003oool0oooo0300oooo001h
0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0oooo1@00
00020?ooo`030000003oool0oooo00H0oooo203o001<0?ooo`P0003o00<0
o`3o0?ooo`3oool0:`3oool3003o01`0oooo203o000<0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001h0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00D000000P3oool00`000000oooo0?ooo`0a0?ooo`00N03oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0203oool60?l004h0oooo1P000?l30?l0ob/0oooo1000o`0M0?ooo`H0
o`003P3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?oo
o`3oool07P3oool010000000oooo0?ooo`3oool2000000T0oooo00<00000
0?ooo`3oool0<P3oool007P0oooo00<000000?ooo`3oool09`3oool20?l0
00030000o`3oool0oooo04l0oooo0P000?l20?ooo`@0o`3o:P3oool3003o
01l0oooo00<0003o0?l0003o0000OP3oool007P0oooo00<000000?ooo`3o
ool09`3oool30000oeH0oooo103o0?lY0?ooo`<00?l07`3oool30000ogh0
oooo001h0?ooo`030000003oool0oooo02L0oooo0`000?mG0?ooo`@0o`3o
:03oool3003o01l0oooo0`000?mn0?ooo`00N03oool00`000000oooo0?oo
o`0W0?ooo`<0003oF03oool40?l0obL0oooo0`00o`0O0?ooo`<0003oOP3o
ool007P0oooo00<000000?ooo`3oool09`3oool30000oeT0oooo103o0?lV
0?ooo`<00?l07`3oool30000ogh0oooo001h0?ooo`030000003oool0oooo
02L0oooo0`000?mJ0?ooo`@0o`3o9@3oool3003o01l0oooo0`000?mn0?oo
o`00N03oool00`000000oooo0?ooo`0W0?ooo`<0003oF`3oool40?l0ob<0
oooo1000o`0O0?ooo`<0003oOP3oool007P0oooo00<000000?ooo`3oool0
9`3oool30000oe`0oooo103o0?lR0?ooo`<00?l07`3oool40000ogh0oooo
001h0?ooo`030000003oool0oooo02L0oooo0`000?mM0?ooo`@0o`3o8@3o
ool3003o01l0oooo0`000?mo0?ooo`00N03oool00`000000oooo0?ooo`0W
0?ooo`<0003oGP3oool40?l0ob00oooo0`00o`0O0?ooo`<0003oO`3oool0
07P0oooo00<000000?ooo`3oool0:03oool30000oeh0oooo103o0?lO0?oo
o`<00?l07`3oool30000ogl0oooo001h0?ooo`030000003oool0oooo02P0
oooo0`000?mO0?ooo`@0o`3o7@3oool4003o01l0oooo0`000?mo0?ooo`00
N03oool00`000000oooo0?ooo`0X0?ooo`<0003oH03oool40?l0oa`0oooo
0`00o`0P0?ooo`<0003oO`3oool007P0oooo00<000000?ooo`3oool0:03o
ool30000of40oooo103o0?lJ0?ooo`@00?l0803oool30000ogl0oooo001h
0?ooo`030000003oool0oooo02P0oooo0`000?mR0?ooo`@0o`3o6@3oool3
003o0200oooo0`000?n00?ooo`00N03oool00`000000oooo0?ooo`0Y0?oo
o`<0003oHP3oool40?l0oaP0oooo0`00o`0P0?ooo`<0003oP03oool007P0
oooo00<000000?ooo`3oool0:@3oool30000of<0oooo103o0?lF0?ooo`@0
0?l0803oool30000oh00oooo001h0?ooo`030000003oool0oooo02T0oooo
0`000?mT0?ooo`@0o`3o5@3oool3003o00H0oooo0P00000I0?ooo`<0003o
P03oool007P0oooo00<000000?ooo`3oool0:@3oool40000of@0oooo103o
0?lC0?ooo`@00?l01@3oool010000000oooo0?ooo`00000G0?ooo`@0003o
P03oool007P0oooo00<000000?ooo`3oool0:P3oool30000ofD0oooo103o
0?lA0?ooo`@00?l01P3oool00`000000oooo0?ooo`0H0?ooo`<0003oP@3o
ool007P0oooo00<000000?ooo`3oool0:P3oool30000ofH0oooo103o0?l?
0?ooo`@00?l01P3oool5000001L0oooo0`000?n10?ooo`00N03oool00`00
0000oooo0?ooo`0Z0?ooo`@0003oIP3oool40?l0o`h0oooo0`00o`080?oo
o`030000003oool0oooo01L0oooo10000?n10?ooo`00N03oool00`000000
oooo0?ooo`0[0?ooo`<0003oI`3oool40?l0o``0oooo1000o`0R0?ooo`<0
003oPP3oool007P0oooo00<000000?ooo`3oool0:`3oool40000ofL0oooo
103o0?l;0?ooo`<00?l08P3oool40000oh80oooo001h0?ooo`030000003o
ool0oooo02`0oooo0`000?mX0?ooo`@0o`3o2P3oool3003o0280oooo0`00
0?n30?ooo`00N03oool00`000000oooo0?ooo`0/0?ooo`<0003oJ@3oool4
0?l0o`P0oooo1000o`0R0?ooo`<0003oP`3oool007P0oooo00<000000?oo
o`3oool0;03oool40000ofT0oooo103o0?l60?ooo`@00?l08P3oool40000
oh<0oooo001h0?ooo`030000003oool0oooo02d0oooo0`000?mZ0?ooo`@0
o`3o103oool4003o02<0oooo0`000?n40?ooo`00N03oool00`000000oooo
0?ooo`0]0?ooo`@0003oJP3oool40?l0o`80oooo1000o`0S0?ooo`@0003o
Q03oool007P0oooo00<000000?ooo`3oool0;P3oool30000of/0oooo103o
0?l4003o02@0oooo0`000?n50?ooo`00N03oool00`000000oooo0?ooo`0^
0?ooo`<0003oH@3oool300000080oooo00<000000?ooo`3oool00`3oool4
0?l0o`800?l0903oool40000ohD0oooo001h0?ooo`030000003oool0oooo
02h0oooo10000?mQ0?ooo`040000003oool0oooo000000L0oooo103o0?lU
0?ooo`<0003oQP3oool007P0oooo00<000000?ooo`3oool0;`3oool30000
of40oooo0`0000090?ooo`@0o`3o8`3oool40000ohH0oooo001h0?ooo`03
0000003oool0oooo02l0oooo10000?mP0?ooo`040000003oool0oooo0000
00T0oooo103o0?lR0?ooo`<0003oQ`3oool007P0oooo00<000000?ooo`3o
ool0<03oool30000of00oooo00@000000?ooo`3oool000002P3oool40?l0
ob40oooo0`000?n70?ooo`00N03oool00`000000oooo0?ooo`0`0?ooo`@0
003oGP3oool4000000`0oooo103o0?lO0?ooo`@0003oQ`3oool007P0oooo
00<000000?ooo`3oool0<@3oool40000ofh0oooo103o0?lN0?ooo`<0003o
R03oool007P0oooo00<000000?ooo`3oool0<P3oool30000ofl0oooo103o
0?lL0?ooo`@0003oR03oool007P0oooo00<000000?ooo`3oool0<P3oool4
0000ofl0oooo103o0?lK0?ooo`<0003oR@3oool007P0oooo00<000000?oo
o`3oool0<`3oool30000og00oooo103o0?lI0?ooo`@0003oR@3oool007P0
oooo00<000000?ooo`3oool0<`3oool40000og00oooo103o0?lG0?ooo`@0
003oRP3oool007P0oooo00<000000?ooo`3oool0=03oool40000og00oooo
103o0?lF0?ooo`<0003oR`3oool007P0oooo00<000000?ooo`3oool0=@3o
ool30000og40oooo103o0?lD0?ooo`@0003oR`3oool007P0oooo00<00000
0?ooo`3oool0=@3oool40000og40oooo103o0?lB0?ooo`@0003oS03oool0
07P0oooo00<000000?ooo`3oool0=P3oool40000og40oooo103o0?lA0?oo
o`<0003oS@3oool007P0oooo00<000000?ooo`3oool0=`3oool30000og80
oooo103o0?l?0?ooo`@0003oS@3oool007P0oooo00<000000?ooo`3oool0
=`3oool40000og80oooo103o0?l=0?ooo`@0003oSP3oool007P0oooo00<0
00000?ooo`3oool0>03oool40000og80oooo103o0?l<0?ooo`<0003oS`3o
ool007P0oooo00<000000?ooo`3oool0>@3oool40000og80oooo103o0?l:
0?ooo`<0003oT03oool007P0oooo00<000000?ooo`3oool0>P3oool00`00
0?l00?l00000o`1c0?ooo`@0o`3o203oool40000oi00oooo001h0?ooo`03
0000003oool0oooo03X0oooo0P000?l2003o07<0oooo103o0?l60?ooo`@0
003oT@3oool007P0oooo00<000000?ooo`3oool0>`3oool00`000?l00?l0
003o0002003o0780oooo103o0?l0103oool00?l0003o003oool40000oi80
oooo001h0?ooo`030000003oool0oooo03`0oooo00<0003o003o0000o`00
0P00o`1b0?ooo`80o`3o1P00o`020000oi<0oooo001h0?ooo`030000003o
ool0oooo03`0oooo00<0003o003o0000o`001000o`1a0?ooo`P00?l0U03o
ool007P0oooo00<000000?ooo`3oool0?@3oool00`000?l00?l0003o0004
003o0700oooo2000o`2D0?ooo`00N03oool00`000000oooo0?ooo`0n0?oo
o`030000o`00o`000?l000D00?l0K@3oool:003o09<0oooo001h0?ooo`03
0000003oool0oooo03l0oooo2@00o`1[0?ooo`X00?l0T`3oool007P0oooo
00<000000?ooo`3oool0@03oool9003o06/0oooo2000o`0B0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0MP3oool007P0oooo00<0
00000?ooo`3oool0@@3oool7003o06/0oooo00<0003o003o0000o`001P00
o`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0M@3o
ool007P0oooo00<000000?ooo`3oool0@@3oool6003o06/0oooo0`000?l6
003o00X0oooo100000030?ooo`030000003oool0oooo00<0oooo0P000005
0?ooo`030000003oool0oooo07@0oooo001h0?ooo`030000003oool0oooo
0480oooo1@00o`000`000?l0oooo0?ooo`1W0?ooo`@0003o0P3oool2003o
00d0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0M03oool0
07P0oooo00<000000?ooo`3oool0@P3oool3003o0080003o00<00?l00000
o`000?l0IP3oool40000oa40oooo00<000000?ooo`000000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0M03oool007P0oooo00<000000?ooo`3oool0@`3oool00`00o`00
oooo0?ooo`050000of<0oooo1@000?lB0?ooo`@000000`3oool010000000
oooo0?ooo`3oool5000000@0oooo00<000000?ooo`3oool0M03oool007P0
oooo00<000000?ooo`3oool0A`3oool60000oel0oooo1P000?lK0?ooo`05
0000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`1e0?oo
o`00N03oool00`000000oooo0?ooo`190?ooo`D0003oG@3oool50000oah0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1f0?ooo`00
N03oool00`000000oooo0?ooo`1:0?ooo`H0003oF@3oool60000oj40oooo
001h0?ooo`030000003oool0oooo04`0oooo1@000?mF0?ooo`H0003oX`3o
ool007P0oooo00<000000?ooo`3oool0C@3oool60000oe<0oooo1P000?nT
0?ooo`00N03oool00`000000oooo0?ooo`1?0?ooo`H0003oC`3oool60000
ojH0oooo001h0?ooo`030000003oool0oooo0500oooo1P000?m<0?ooo`H0
003oZ03oool007P0oooo00<000000?ooo`3oool0DP3oool60000odT0oooo
1P000?nY0?ooo`00N03oool00`000000oooo0?ooo`1D0?ooo`H0003oA03o
ool70000oj/0oooo001h0?ooo`030000003oool0oooo05D0oooo20000?ln
0?ooo`P0003o[@3oool007P0oooo00<000000?ooo`3oool0E`3oool90000
ocT0oooo2@000?n^0?ooo`00N03oool00`000000oooo0?ooo`1I0?ooo`X0
003o<`3oool90000ok40oooo001h0?ooo`030000003oool0oooo05`0oooo
2@000?l_0?ooo`P0003o]03oool007P0oooo00<000000?ooo`3oool0G`3o
ool90000oa<0oooo0P3o000D0?ooo`T0003o]P3oool007P0oooo00<00000
0?ooo`3oool0HP3oool:0000o`d0oooo1P3o000<0?ooo``0003o^@3oool0
07P0oooo00<000000?ooo`3oool0I03ooolA0000o`<0oooo203o00040?oo
oa40003o^`3oool007P0oooo00<000000?ooo`3oool0I`3ooolA0000o`P0
o`004P000?nn0?ooo`00N03oool00`000000oooo0?ooo`1/0?ooo`/0003o
2P3o000;0000ol@0oooo001h0?ooo`030000003oool0oooo07@0oooo0`00
0?l:0?l000@0003ob`3oool007P0oooo00<000000?ooo`3oool0N03oool8
0?l00=00oooo001h0?ooo`030000003oool0oooo07P0oooo203o003@0?oo
o`00N03oool00`000000oooo0?ooo`1i0?ooo`H0o`00d@3oool007P0oooo
00<000000?ooo`3oool0N`3oool20?l00=<0oooo001h0?ooo`030000003o
ool0oooo0?l0ooooD@3oool007P0oooo00<000000?ooo`3oool0P`3oool4
00000<T0oooo001h0?ooo`030000003oool0oooo08<0oooo00<000000?oo
o`3oool0bP3oool007P0oooo00<000000?ooo`3oool0Q03oool00`000000
oooo0?ooo`390?ooo`00N03oool00`000000oooo0?ooo`250?ooo`030000
003oool0oooo0<P0oooo003n0?ooo`040000003oool0oooo00000<T0oooo
003h0?ooo`030000003oool0oooo00@0oooo0P0000060?ooo`030000003o
ool0oooo0<40oooo003g0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0`03oool00>l0oooo100000030?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0_`3oool00?00oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`030?ooo`P000001@3oool00`000000
oooo0?ooo`2o0?ooo`00k`3oool00`000000oooo000000040?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0_`3oool00>l0oooo1000
00030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0_`3o
ool00?L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`30
0?ooo`00n03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`310?oo
o`00oP3oool010000000oooo0?ooo`0000390?ooo`00M`3oool2000008H0
oooo00<000000?ooo`000000b@3oool007P0oooo00<000000?ooo`3oool0
Q03oool00`000000oooo000000390?ooo`00N@3oool00`000000oooo0?oo
o`220?ooo`D00000b03oool007P0oooo00<000000?ooo`000000o`3ooomA
0?ooo`00M`3oool010000000oooo0?ooo`00003o0?oooe40oooo001f0?oo
o`<0000000<0oooo000000000000o`3ooom@0?ooo`00o`3oooo<0?ooo`00
o`3oooo<0?ooo`00o`3oooo<0?ooo`00o`3oooo<0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{459, 244},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\tFigure 1.23",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The simple closed curve  ",
  Cell[BoxData[
      \(z \((t)\)\ \  = \ \ z\_0\  + \ 
          R\ \[ExponentialE]\^\(\[ImaginaryI]\ t\)\)]],
  ",  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 2  \[Pi]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tWe need to develop some vocabulary that will help describe sets of \
points in the plane.  One fundamental idea is that of an ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  " neighborhood of the point ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  It is the open disk of radius ",
  Cell[BoxData[
      \(\(\(\[Element]\)\(\(>\)\(0\)\)\)\)]],
  " about ",
  Cell[BoxData[
      \(z\_0\)]],
  " shown in Figure 1.24.  Formally, it is the set of all points satisfying \
the inequality ",
  Cell[BoxData[
      \(\(D\_\[Epsilon]\) \((z\_0)\) = {z : \(\(|\)\(z - 
                z\_0\)\(|\)\(\(<\)\(\[Element]\)\)\)}\)]],
  "  and is denoted ",
  Cell[BoxData[
      \(\(D\_\[Epsilon]\) \((z\_0)\)\)]],
  ".  That is,  \n\n",
  StyleBox["(1-49)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\(D\_\[Epsilon]\) \((z\_0)\)\ \  = \ \ {z : \ \ \(\(|\)\(z - 
                z\_0\)\(|\)\(\(<\)\(\[Element]\)\)\)}\)]],
  ". "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000aB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooomk
0?ooo`80000000<0oooo000000000000503oool00?l0ooooO03oool00`00
0000oooo0000000E0?ooo`00N@3ooooj000000T0oooo00<000000?ooo`3o
ool0503oool007T0oooo00<000000?ooo`3oool0oP3oool2000000030?oo
o`000000000001@0oooo001i0?ooo`030000003oool0oooo0?l0oooo603o
ool007T0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00N@3oool00`00
0000oooo0?ooo`3o0?oooaP0oooo001i0?ooo`030000003oool0oooo0?l0
oooo603oool007T0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00N@3o
ool00`000000oooo0?ooo`3o0?oooaP0oooo001i0?ooo`030000003oool0
oooo0?l0oooo603oool007T0oooo00<000000?ooo`3oool0o`3ooolH0?oo
o`00N@3oool00`000000oooo0?ooo`3o0?oooaP0oooo001i0?ooo`030000
003oool0oooo0?l0oooo603oool007T0oooo00<000000?ooo`3oool0o`3o
oolH0?ooo`00N@3oool00`000000oooo0?ooo`3o0?oooaP0oooo001i0?oo
o`030000003oool0oooo0?l0oooo603oool007T0oooo00<000000?ooo`3o
ool0o`3ooolH0?ooo`00N@3oool00`000000oooo0?ooo`3o0?oooaP0oooo
001i0?ooo`030000003oool0oooo0?l0oooo603oool007T0oooo00<00000
0?ooo`3oool0o`3ooolH0?ooo`00N@3oool00`000000oooo0?ooo`3o0?oo
oaP0oooo001i0?ooo`030000003oool0oooo0?l0oooo603oool007T0oooo
00<000000?ooo`3oool0o`3ooolH0?ooo`00N@3oool00`000000oooo0?oo
o`3o0?oooaP0oooo001i0?ooo`030000003oool0oooo0?l0oooo603oool0
07T0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00N@3oool00`000000
oooo0?ooo`3o0?oooaP0oooo001i0?ooo`030000003oool0oooo0?l0oooo
603oool007T0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00N@3oool0
0`000000oooo0?ooo`3o0?oooaP0oooo001i0?ooo`030000003oool0oooo
0?l0oooo603oool007T0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00
N@3oool00`000000oooo0?ooo`3o0?oooaP0oooo001i0?ooo`030000003o
ool0oooo0?l0oooo603oool007T0oooo00<000000?ooo`3oool0o`3ooolH
0?ooo`00N@3oool00`000000oooo0?ooo`3o0?oooaP0oooo001i0?ooo`03
0000003oool0oooo0?l0oooo603oool007T0oooo00<000000?ooo`3oool0
o`3ooolH0?ooo`00N@3oool00`000000oooo0?ooo`3o0?oooaP0oooo001i
0?ooo`030000003oool0oooo0?l0oooo603oool007T0oooo00<000000?oo
o`3oool0o`3ooolH0?ooo`00N@3oool00`000000oooo0?ooo`1f0?ooo`03
003o003oool0oooo09h0oooo001i0?ooo`030000003oool0oooo07@0oooo
1`00o`2L0?ooo`00N@3oool00`000000oooo0?ooo`1a0?ooo`X00?l0103`
oo080?ooo`03003o003oool0oooo08d0oooo001i0?ooo`030000003oool0
oooo06h0oooo0`3`oo04003o00h0l?o`1`00o`2=0?ooo`00N@3oool00`00
0000oooo0?ooo`1X0?ooo`03003o003oool0l?o`01P0l?o`2000o`2<0?oo
o`00N@3oool00`000000oooo0?ooo`1V0?ooo`@00?l07`3`oo03003o08/0
oooo001i0?ooo`030000003oool0oooo06D0oooo1000o`0P0?3ol0<00?l0
R`3oool007T0oooo00<000000?ooo`3oool0H`3oool4003o02L0l?o`R@3o
ool007T0oooo00<000000?ooo`3oool0H@3oool5003o02X0l?o`Q`3oool0
07T0oooo00<000000?ooo`3oool0H03oool4003o02h0l?o`Q@3oool007T0
oooo00<000000?ooo`3oool0H03oool00`3`oo000?l00?3ol00`0?3ol003
0?ooo`00o`00oooo0840oooo001i0?ooo`030000003oool0oooo05l0oooo
=03`oo03003o0840oooo001i0?ooo`030000003oool0oooo05h0oooo=P3`
oo03003o0800oooo001i0?ooo`030000003oool0oooo05d0oooo>03`oo03
003o07l0oooo001i0?ooo`030000003oool0oooo05`0oooo>P3`oo03003o
07h0oooo001i0?ooo`030000003oool0oooo05T0oooo00<00?l00?ooo`3`
oo00>`3`oo03003o07d0oooo001i0?ooo`030000003oool0oooo05T0oooo
00<00?l00?3ol03`oo00?03`oo03003o07`0oooo001i0?ooo`030000003o
ool0oooo05P0oooo0P00o`0o0?3ol0<00?l0N`3oool007T0oooo00<00000
0?ooo`3oool0E`3oool3003o0400l?o`00<00?l00?ooo`3oool0NP3oool0
07T0oooo00<000000?ooo`3oool0EP3oool3003o04<0l?o`N`3oool007T0
oooo00<000000?ooo`3oool0EP3oool2003o04D0l?o`NP3oool007T0oooo
00<000000?ooo`3oool0EP3oool00`00o`00l?o`0?3ol0140?3ol7X0oooo
001i0?ooo`030000003oool0oooo05D0oooo0P00o`170?3ol7T0oooo001i
0?ooo`030000003oool0oooo05D0oooo00<00?l00?3ol03`oo00AP3`oo1i
0?ooo`00N@3oool00`000000oooo0?ooo`1E0?ooo`03003o003`oo00l?o`
04L0l?o`N03oool007T0oooo00<000000?ooo`3oool0E03ooom;0?3ol003
003o003oool0oooo07D0oooo001i0?ooo`030000003oool0oooo05@0oooo
BP3`oo03003o07H0oooo001i0?ooo`030000003oool0oooo05<0ooooC03`
oo03003o07D0oooo001i0?ooo`030000003oool0oooo05<0ooooC03`oo02
003o07H0oooo001i0?ooo`030000003oool0oooo0580ooooC@3`oo02003o
07H0oooo001i0?ooo`030000003oool0oooo0580ooooC@3`oo03003o07D0
oooo001i0?ooo`030000003oool0oooo0580oooo:P3`oo000`000000l?o`
0?3ol00R0?3ol003003o003oool0oooo07<0oooo001i0?ooo`030000003o
ool0oooo0580oooo:@3`oo000`000000l?o`0000000S0?3ol0800?l0M03o
ool007T0oooo00<000000?ooo`3oool0D03oool2003o0280l?o`1@000002
0?3ol0030000003`oo00000002@0l?o`00<00?l00?ooo`3oool0LP3oool0
07T0oooo00<000000?ooo`3oool0D03oool2003o02<0l?o`00@000000?3o
l03`oo0000000P3`oo000`000000l?o`0000000T0?3ol003003o003oool0
oooo0780oooo001i0?ooo`030000003oool0oooo0500oooo0P00o`0T0?3o
l0030000003`oo00l?o`0080l?o`00<000000?3ol0000000903`oo1e0?oo
o`00N@3oool00`000000oooo0?ooo`1@0?ooo`800?l09@3`oo000`000000
l?o`0?3ol0020?3ol0030000003`oo00l?o`02<0l?o`M@3oool007T0oooo
00<000000?ooo`3oool0C`3oool2003o02@0l?o`00@000000?3ol03`oo00
0000:@3`oo1e0?ooo`00N@3oool00`000000oooo0?ooo`1?0?ooo`800?l0
903`oo05000002T0l?o`M03oool007T0oooo00<000000?ooo`3oool0C`3o
ool2003o00d0l?o`0P3o0?m30?3ol7@0oooo001i0?ooo`030000003oool0
oooo04l0oooo0P00o`090?3ol0H0o`3o6@3`oo020000obP0l?o`M03oool0
07T0oooo00<000000?ooo`3oool0C`3oool2003o00D0l?o`2P3o0?lG0?3o
l0H0003o9P3`oo1d0?ooo`00N@3oool00`000000oooo0?ooo`1?0?ooo`80
0?l000<0l?o`0?l0o`3o0?l0303o0?lG0?3ol0H0003o9P3`oo1d0?ooo`00
N@3oool00`000000oooo0?ooo`1?0?ooo`03003o003o0?l0o`3o02@0o`3o
20000?lT0?3ol0800?l0L`3oool007T0oooo00<000000?ooo`3oool0C`3o
ool2003o0080l?o`3@3o0?lF0?3ol0P0003o903`oo02003o07<0oooo001i
0?ooo`030000003oool0oooo04l0oooo0P00o`070?3ol0P0o`3o5`3`oo06
0000obD0l?o`0P00o`1c0?ooo`00N@3oool00`000000oooo0?ooo`1@0?oo
o`d0l?o`0`3o0?lG0?3ol0H0003o9@3`oo02003o07<0oooo001i0?ooo`03
0000003oool0oooo0500oooo:@3`oo020000obL0l?o`0P00o`1c0?ooo`00
N@3oool00`000000oooo0?ooo`1@0?oooe80l?o`0P00o`1c0?ooo`00N@3o
ool00`000000oooo0?ooo`1@0?oooe40l?o`0P00o`1d0?ooo`00N@3oool0
0`000000oooo0?ooo`1A0?oooaX0l?o`1000000b0?3ol0800?l0M03oool0
07T0oooo00<000000?ooo`3oool0D@3ooolI0?3ol0030000003`oo00l?o`
03@0l?o`0P00o`1d0?ooo`00N@3oool00`000000oooo0?ooo`1A0?oooaT0
l?o`00<000000?3ol03`oo00=03`oo02003o07@0oooo001i0?ooo`030000
003oool0oooo0540oooo6@3`oo05000003<0l?o`M@3oool007T0oooo00<0
00000?ooo`3oool0D@3oool2003o01L0l?o`00<000000?3ol03`oo00=@3`
oo1e0?ooo`00N@3oool00`000000oooo0?ooo`1A0?ooo`800?l0603`oo04
00000380l?o`MP3oool007T0oooo00<000000?ooo`3oool0D@3oool2003o
04h0l?o`MP3oool007T0oooo00<000000?ooo`3oool0D@3oool2003o04d0
l?o`M`3oool007T0oooo00<000000?ooo`3oool0D@3oool3003o04`0l?o`
M`3oool007T0oooo00<000000?ooo`3oool0D`3oool00`00o`00l?o`0?3o
l01:0?3ol7L0oooo001i0?ooo`030000003oool0oooo05<0oooo0P00o`1:
0?3ol003003o003oool0oooo07D0oooo001i0?ooo`030000003oool0oooo
05<0oooo0`00o`190?3ol003003o003oool0oooo07D0oooo001i0?ooo`03
0000003oool0oooo05@0oooo0`00o`170?3ol0800?l0M`3oool007T0oooo
00<000000?ooo`3oool0E@3oool00`00o`00l?o`0?3ol0150?3ol0<00?l0
M`3oool007T0oooo00<000000?ooo`3oool0EP3ooom60?3ol0<00?l0N03o
ool007T0oooo00<000000?ooo`3oool0E`3ooom50?3ol0800?l0N@3oool0
07T0oooo00<000000?ooo`3oool0E`3ooom40?3ol0<00?l0N@3oool007T0
oooo00<000000?ooo`3oool0F03ooom20?3ol0<00?l0NP3oool007T0oooo
00<000000?ooo`3oool0F03ooom20?3ol0030?ooo`00o`00oooo07X0oooo
001i0?ooo`030000003oool0oooo05X0oooo00<00?l00?3ol03`oo00?03`
oo1n0?ooo`00N@3oool00`000000oooo0?ooo`1I0?ooo`<00?l0?03`oo1o
0?ooo`00N@3oool00`000000oooo0?ooo`1J0?ooo`<00?l0>P3`oo200?oo
o`00N@3oool00`000000oooo0?ooo`1K0?ooo`<00?l0>03`oo210?ooo`00
N@3oool00`000000oooo0?ooo`1L0?ooo`<00?l0=`3`oo210?ooo`00N@3o
ool00`000000oooo0?ooo`1M0?ooo`@00?l0<P3`oo000`00o`00l?o`0?oo
o`210?ooo`00N@3oool00`000000oooo0?ooo`1N0?ooo`@00?l0<03`oo03
003o0880oooo001i0?ooo`030000003oool0oooo05l0oooo0P00o`0`0?3o
l0@00?l0PP3oool007T0oooo00<000000?ooo`3oool0G`3oool2003o0003
0?ooo`3`oo00l?o`02`0l?o`0`00o`240?ooo`00N@3oool00`000000oooo
0?ooo`1S0?ooob/0l?o`1000o`250?ooo`00N@3oool00`000000oooo0?oo
o`1U0?ooobL0l?o`1@00o`260?ooo`00N@3oool00`000000oooo0?ooo`1V
0?ooo`@0l?o`00<00?l00?3ol03`oo007`3`oo03003o08P0oooo001i0?oo
o`030000003oool0oooo06P0oooo1@00o`0M0?3ol8d0oooo001i0?ooo`03
0000003oool0oooo06P0oooo1`00o`0D0?3ol004003o003`oo00l?o`0?3o
l900oooo001i0?ooo`030000003oool0oooo06`0oooo1P00o`0?0?3ol0@0
0?l0TP3oool007T0oooo00<000000?ooo`3oool0K@3oool5003o00P0l?o`
2P00o`2C0?ooo`00N@3oool00`000000oooo0?ooo`1j0?ooo`P00?l0U@3o
ool007T0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00N@3oool00`00
0000oooo0?ooo`3o0?oooaP0oooo001i0?ooo`030000003oool0oooo0?l0
oooo603oool007T0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00N@3o
ool00`000000oooo0?ooo`3o0?oooaP0oooo001i0?ooo`030000003oool0
oooo0?l0oooo603oool007T0oooo00<000000?ooo`3oool0o`3ooolH0?oo
o`00N@3oool00`000000oooo0?ooo`3o0?oooaP0oooo001i0?ooo`030000
003oool0oooo0?l0oooo603oool007T0oooo00<000000?ooo`3oool0o`3o
oolH0?ooo`00N@3oool00`000000oooo0?ooo`3o0?oooaP0oooo001i0?oo
o`030000003oool0oooo0?l0oooo603oool007T0oooo00<000000?ooo`3o
ool0o`3ooolH0?ooo`00N@3oool00`000000oooo0?ooo`3o0?oooaP0oooo
001i0?ooo`030000003oool0oooo0?l0oooo603oool007T0oooo00<00000
0?ooo`3oool0o`3ooolH0?ooo`00N@3oool00`000000oooo0?ooo`3o0?oo
oaP0oooo001i0?ooo`030000003oool0oooo0?l0oooo603oool007T0oooo
00<000000?ooo`3oool0o`3ooolH0?ooo`00N@3oool00`000000oooo0?oo
o`3o0?oooaP0oooo001i0?ooo`030000003oool0oooo0?l0oooo603oool0
07T0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00N@3oool00`000000
oooo0?ooo`3o0?oooaP0oooo001i0?ooo`030000003oool0oooo0?l0oooo
603oool007T0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00N@3oool0
0`000000oooo0?ooo`3o0?oooaP0oooo001i0?ooo`030000003oool0oooo
0?l0oooo603oool007T0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00
N@3oool00`000000oooo0?ooo`3o0?oooaP0oooo001i0?ooo`030000003o
ool0oooo0?l0oooo603oool007T0oooo00<000000?ooo`3oool0o`3ooolH
0?ooo`00N@3oool00`000000oooo0?ooo`3o0?oooaP0oooo001i0?ooo`03
0000003oool0oooo0?l0oooo603oool007T0oooo00<000000?ooo`3oool0
o`3ooolH0?ooo`00N@3oool00`000000oooo0?ooo`3o0?oooaP0oooo001i
0?ooo`030000003oool0oooo0?l0oooo603oool007T0oooo00<000000?oo
o`3oool0o`3ooolH0?ooo`00N@3oool00`000000oooo0?ooo`3o0?oooaP0
oooo001i0?ooo`030000003oool0oooo0?l0oooo603oool007T0oooo00<0
00000?ooo`3oool0o`3ooolH0?ooo`00N@3oool00`000000oooo0?ooo`3o
0?oooaP0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo
003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0
oooo003o0?oooi@0oooo001g0?ooo`800000o`3ooolK0?ooo`00N03oool0
0`000000oooo0?ooo`3o0?oooaT0oooo001i0?ooo`030000003oool0oooo
0?l0oooo603oool007P0oooo00<000000?ooo`000000o`3ooolI0?ooo`00
M`3oool010000000oooo0?ooo`00003o0?oooaT0oooo001f0?ooo`<00000
00<0oooo000000000000o`3ooolH0?ooo`00o`3ooonD0?ooo`00o`3ooonD
0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 197},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\tFigure 1.24",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   An ",
  Cell[BoxData[
      \( \[Element] \)]],
  " neighborhood of the point ",
  Cell[BoxData[
      \(z\_0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.24.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The solution sets of the inequalities  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ",  ",
  Cell[BoxData[
      \(\(\(|\)\(z - \[ImaginaryI]\)\(|\)\(\(<\)\(2\)\)\)\)]],
  ",  and  ",
  Cell[BoxData[
      \(\(\(|\)\(z + 1 + 2  \[ImaginaryI]\)\(|\)\(\(<\)\(3\)\)\)\)]],
  "  are neighborhoods of the points  ",
  Cell[BoxData[
      RowBox[{"0", ",", "\[ImaginaryI]", ",", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "-", "1", 
          "-", \(2  \[ImaginaryI]\)}]}]]],
  ",  with radii  ",
  Cell[BoxData[
      RowBox[{"1", ",", "2", ",", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "3"}]}]]],
  ",  respectively.  They can also be expressed as  ",
  Cell[BoxData[
      \(\(D\_1\) \((0)\)\)]],
  ",  ",
  Cell[BoxData[
      \(\(D\_2\) \((\[ImaginaryI])\)\)]],
  ",  and  ",
  Cell[BoxData[
      \(\(D\_3\) \((\(-1\) - 2  \[ImaginaryI])\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tWe also define  ",
  Cell[BoxData[
      \(\(\(D\_\[Epsilon]\)\&_\) \((z\_0)\)\)]],
  ",  the closed disk of radius ",
  Cell[BoxData[
      \( \[Element] \)]],
  " centered at ",
  Cell[BoxData[
      \(z\_0\)]],
  ", and  ",
  Cell[BoxData[
      \(\(D\_\[Epsilon]\%*\) \((z\_0)\)\)]],
  ",  the punctured disk of radius ",
  Cell[BoxData[
      \( \[Element] \)]],
  " centered at ",
  Cell[BoxData[
      \(z\_0\)]],
  "as   \n\n",
  StyleBox["(1-50)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\(\(D\_\[Epsilon]\)\&_\) \((z\_0)\)\ \  = \ \ {z : \ \ \(\(|\)\(z - 
                z\_0\)\(|\)\(\(\[LessEqual]\)\(\[Element]\)\)\)}\)]],
  ",   and  \n\n",
  StyleBox["(1-51)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\(D\_\[Epsilon]\%*\) \((z\_0)\)\ \  = \ \ {z : \ \ \(\(0\)\(<\)\) | 
              z - z\_0 | \(\(<\)\(\[Element]\)\)}\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Definitions (Interior Point, Exterior Point, Boundary Point).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  \n\n\tThe point ",
  Cell[BoxData[
      \(z\_0\)]],
  " is said to be an interior point of the set ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " provided that there exists an ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  " neighborhood of ",
  Cell[BoxData[
      \(z\_0\)]],
  " that contains only points of ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ";  ",
  Cell[BoxData[
      \(z\_0\)]],
  " is called an exterior point of the set ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " if there exists an ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  " neighborhood of ",
  Cell[BoxData[
      \(z\_0\)]],
  " that contains no points of ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ".  If ",
  Cell[BoxData[
      \(z\_0\)]],
  " is neither an interior point nor an exterior point of ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ", then it is called a boundary point of ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " and has the property that each ",
  Cell[BoxData[
      \( \[Element] \)]],
  " neighborhood of ",
  Cell[BoxData[
      \(z\_0\)]],
  " contains both points in ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " and points not in ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ".  Figure 1.25 illustrates this situation."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00N@3oool00`000000oooo0?ooo`3o
0?oooaP0oooo001i0?ooo`030000003oool0oooo0?l0oooo603oool007T0
oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00N@3oool00`000000oooo
0?ooo`3o0?oooaP0oooo001i0?ooo`030000003oool0oooo0?l0oooo603o
ool007T0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00N@3oool00`00
0000oooo0?ooo`3o0?oooaP0oooo001i0?ooo`030000003oool0oooo0?l0
oooo603oool007T0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00N@3o
ool00`000000oooo0?ooo`3o0?oooaP0oooo001i0?ooo`030000003oool0
oooo0?l0oooo603oool007T0oooo00<000000?ooo`3oool0o`3ooolH0?oo
o`00N@3oool00`000000oooo0?ooo`3o0?oooaP0oooo001i0?ooo`030000
003oool0oooo0?h0oooo0P0000000`3oool000000000000D0?ooo`00N@3o
ool00`000000oooo0?ooo`3o0?ooo`030000003oool0000001D0oooo001i
0?ooooX000002@3oool00`000000oooo0?ooo`0D0?ooo`00N@3oool00`00
0000oooo0?ooo`3n0?ooo`80000000<0oooo000000000000503oool007T0
oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00N@3oool00`000000oooo
0?ooo`1Z0?ooo`@00000Z@3oool007T0oooo00<000000?ooo`3oool0K03o
ool00`000000oooo0?ooo`2X0?ooo`00N@3oool00`000000oooo0?ooo`0h
0?ooo`D00000103oool3000000@0oooo0P0000000`3oool0000000000003
000000040?ooo`000000000000000080oooo1@0000020?ooo`D0000000<0
oooo0000000000000`0000040?ooo`030000003oool0oooo0:P0oooo001i
0?ooo`030000003oool0oooo03T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0200000080oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool01@3oool200000:T0oooo001i0?oo
o`030000003oool0oooo03T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0000002Y
0?ooo`00N@3oool00`000000oooo0?ooo`0i0?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000<0oooo100000030?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`3oool000001@3oool3
0?l0oj00oooo001i0?ooo`030000003oool0oooo03T0oooo100000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool000000080oooo0P0000020?ooo`040000003oool0oooo00000080oooo
0P0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000@0
oooo00D000000?ooo`3oool0oooo000000080?ooo`@0o`3oW03oool007T0
oooo00<000000?ooo`3oool0>@3oool01@000000oooo0?ooo`3oool00000
00<0oooo0`0000020?ooo`8000000P3oool2000000040?ooo`0000000000
0?ooo`800000103oool2000000030?ooo`000000oooo0080oooo0`000003
0?ooo`80000000@0oooo000000000000oooo0`000000103oool000000000
0000000;0?ooo`@0o`3o3P3oool00`3o0?l0oooo0?ooo`270?ooo`00N@3o
ool00`000000oooo0?ooo`0i0?ooo`050000003oool0oooo0?ooo`000000
6`3oool00`000000oooo0?ooo`0S0?ooo`D0o`3o2@3oool30?l0oa/0oooo
2@00o`0>0?ooo`/00?l0BP3oool007T0oooo00<000000?ooo`3oool0>03o
ool5000001/0oooo0P00000Z0?ooo`@0o`3o1@3oool50?l0oa@0oooo00<0
l?o`003o0000o`000P00o`090?3ol0h00?l02`3`oo03003o04L0oooo001i
0?ooo`030000003oool0oooo08P0oooo103o0?l00`3oool0o`3o0?l0o`05
0?l0oa40oooo0P00o`0Y0?3ol0800?l0A@3oool007T0oooo00<000000?oo
o`3oool0903oool3003o06D0oooo2P3o0?l=0?ooo`800?l0;@3`oo02003o
04<0oooo001i0?ooo`030000003oool0oooo0240oooo0`00o`020?3ol0P0
0?l0GP3oool<0?l0o`X0oooo00<00?l00?3ol03`oo00;`3`oo000`00o`00
oooo0?ooo`100?ooo`00N@3oool00`000000oooo0?ooo`0O0?ooo`800?l0
303`oo000`3oool00?l0003o0005003o05L0oooo3P3o0?l60?ooo`800?l0
<`3`oo02003o0400oooo001i0?ooo`030000003oool0oooo01d0oooo0P00
o`0C0?3ol0<0oooo1`00o`1@0?oooa00o`3o0`3oool00`00o`00l?o`0?3o
l00d0?3ol003003o003oool0oooo03h0oooo001i0?ooo`030000003oool0
oooo01T0oooo0P3`oo02003o01l0l?o`1@00o`1L0?ooo`800?l0>03`oo00
0`00o`00oooo0?ooo`0m0?ooo`00N@3oool00`000000oooo0?ooo`0G0?oo
o`80l?o`0P00o`0V0?3ol0P00?l0D`3oool00`00o`00l?o`0?3ol00i0?3o
l003003o003oool0oooo03`0oooo001i0?ooo`030000003oool0oooo01D0
oooo0P3`oo02003o0300l?o`1000o`1>0?ooo`03003o003`oo00l?o`03X0
l?o`00<00?l00?ooo`3oool0?03oool007T0oooo00<000000?ooo`3oool0
503oool00`3`oo000?l0003o000f0?3ol0@00?l0B@3oool00`00o`00l?o`
0?3ol00k0?3ol0030?ooo`00o`00oooo03`0oooo001i0?ooo`030000003o
ool0oooo0180oooo00<0l?o`003o0000o`00?03`oo02003o04H0oooo00<0
0?l00?3ol03`oo00?@3`oo000`00o`00oooo0?ooo`0k0?ooo`00N@3oool0
0`000000oooo0?ooo`0@0?ooo`030?3ol000o`000?l00400l?o`0P00o`13
0?ooo`03003o003`oo00l?o`03h0l?o`00<00?l00?ooo`3oool0>`3oool0
07T0oooo00<000000?ooo`3oool03P3oool00`3`oo000?l0003o00140?3o
l0800?l0@@3oool00`00o`00l?o`0?3ol00n0?3ol003003o003oool0oooo
03/0oooo001i0?ooo`030000003oool0oooo00d0oooo00<0l?o`003o003`
oo00A`3`oo02003o03h0oooo00<00?l00?3ol03`oo00?`3`oo000`00o`00
oooo0?ooo`0k0?ooo`00N@3oool00`000000oooo0?ooo`0<0?ooo`800?l0
B`3`oo02003o03/0oooo00<00?l00?3ol03`oo00@03`oo000`00o`00oooo
0?ooo`0k0?ooo`00N@3oool00`000000oooo0?ooo`0;0?ooo`03003o003`
oo00l?o`04d0l?o`0P00o`0h0?ooo`03003o003`oo00l?o`0440l?o`00<0
0?l00?ooo`3oool0>`3oool007T0oooo00<000000?ooo`3oool02P3oool0
0`00o`00l?o`0?3ol01@0?3ol0800?l0=P3oool00`00o`00l?o`0?3ol011
0?3ol003003o003oool0oooo03/0oooo001i0?ooo`030000003oool0oooo
00T0oooo0P00o`1D0?3ol0800?l0<`3oool00`00o`00oooo0?3ol0120?3o
l003003o003oool0oooo03/0oooo001i0?ooo`030000003oool0oooo00T0
oooo00<00?l00?3ol03`oo00E@3`oo02003o0340oooo00<00?l00?3ol03`
oo00@@3`oo000`00o`00oooo0?ooo`0l0?ooo`00N@3oool00`000000oooo
0?ooo`090?ooo`03003o003`oo00l?o`05L0l?o`0`00o`0^0?ooo`03003o
003`oo00l?o`0400l?o`00<00?l00?ooo`3oool0?@3oool007T0oooo00<0
00000?ooo`3oool02@3oool00`00o`00l?o`0?3ol01J0?3ol0800?l0:`3o
ool00`00o`00l?o`0?3ol0100?3ol0800?l0?`3oool007T0oooo00<00000
0?ooo`3oool02@3oool2003o05d0l?o`0P00o`0Y0?ooo`03003o003`oo00
l?o`03l0l?o`00<00?l00?ooo`3oool0?`3oool007T0oooo00<000000?oo
o`3oool02P3oool00`00o`00l?o`0?3ol01M0?3ol0800?l09`3oool00`00
o`00l?o`0?3ol00m0?3ol0030?ooo`00o`00oooo0440oooo001i0?ooo`03
0000003oool0oooo00/0oooo00<00?l00?3ol03`oo00GP3`oo03003o02@0
oooo00<00?l00?3ol03`oo00?03`oo000`3oool00?l00?ooo`120?ooo`00
N@3oool00`000000oooo0?ooo`0<0?ooo`03003o003`oo00l?o`05l0l?o`
00<0oooo003o0000o`008@3oool00`00o`00l?o`0?3ol00l0?3ol0800?l0
A03oool007T0oooo00<000000?ooo`3oool0303oool00`3`oo000?l00?3o
l01R0?3ol0800?l07`3oool00`00o`00l?o`0?3ol00i0?3ol0<00?l0AP3o
ool007T0oooo00<000000?ooo`3oool03P3oool00`00o`00l?o`0?3ol01R
0?3ol0<00?l0703oool00`00o`00l?o`0?3ol00f0?3ol0<00?l0B@3oool0
07T0oooo00<000000?ooo`3oool03`3oool00`00o`00l?o`0?3ol01T0?3o
l0<00?l06@3oool00`00o`00l?o`0?3ol00d0?3ol0030?ooo`00o`00oooo
04/0oooo001i0?ooo`030000003oool0oooo0100oooo00<00?l00?3ol03`
oo00I@3`oo000`3oool00?l0003o000F0?ooo`030?3ol000o`00l?o`03@0
l?o`00<0oooo003o003oool0C03oool007T0oooo00<000000?ooo`3oool0
4@3oool2003o06P0l?o`0`00o`0C0?ooo`03003o003`oo00l?o`03<0l?o`
0P00o`1>0?ooo`00N@3oool00`000000oooo0?ooo`0C0?ooo`800?l0J@3`
oo03003o00l0oooo00<00?l00?3ol03`oo00<`3`oo000`00o`00oooo0?oo
o`1>0?ooo`00N@3oool00`000000oooo0?ooo`0D0?ooo`030?3ol000o`00
0?l006X0l?o`0P00o`0<0?ooo`03003o003`oo00l?o`03@0l?o`00<00?l0
0?ooo`3oool0CP3oool007T0oooo00<000000?ooo`3oool05P3oool00`3`
oo000?l0003o001Z0?3ol0`00?l0=P3`oo000`00o`00oooo0?ooo`1?0?oo
o`00N@3oool00`000000oooo0?ooo`0H0?ooo`030?3ol000o`000?l00:T0
l?o`00<00?l00?ooo`3oool0D03oool007T0oooo00<000000?ooo`3oool0
6@3oool20?3ol0800?l0Y`3`oo000`00o`00oooo0?ooo`1@0?ooo`00N@3o
ool00`000000oooo0?ooo`0L0?ooo`030?3ol000o`000?l00:@0l?o`00<0
0?l00?ooo`3oool0D@3oool007T0oooo00<000000?ooo`3oool07`3oool2
003o0:40l?o`00<00?l00?ooo`3oool0DP3oool007T0oooo00<000000?oo
o`3oool08@3oool2003o09h0l?o`00<00?l00?ooo`3oool0D`3oool007T0
oooo00<000000?ooo`3oool08`3oool2003o09/0l?o`00<0oooo003o003o
ool0E03oool007T0oooo00<000000?ooo`3oool0903oool00`3`oo000?l0
003o002I0?3ol003003o003oool0oooo05@0oooo001i0?ooo`030000003o
ool0oooo02L0oooo0P00o`2F0?3ol003003o003oool0oooo05D0oooo001i
0?ooo`030000003oool0oooo02T0oooo0P00o`2C0?3ol003003o003oool0
oooo05H0oooo001i0?ooo`030000003oool0oooo02/0oooo0`00o`2>0?3o
l0800?l0F@3oool007T0oooo00<000000?ooo`3oool0;P3oool2003o0440
l?o`1@0000001@3`oo000000000000000000l?o`00<000000`3`oo030000
00<0l?o`100000020?3ol0D000000P3`oo05000000<0l?o`0`0000030?3o
l0D00000503`oo000`00o`00oooo0?ooo`1I0?ooo`00N@3oool00`000000
oooo0?ooo`0`0?ooo`<00?l0@03`oo000`000000l?o`0?3ol0020?3ol005
0000003`oo00l?o`0?3ol00000000`3`oo001`000000l?o`0?3ol03`oo00
00000?3ol00000001`3`oo000`000000l?o`0?3ol0050?3ol0030000003`
oo00l?o`0080l?o`00D000000?3ol03`oo00l?o`000000030?3ol0030000
003`oo00l?o`0180l?o`0`00o`1L0?ooo`00N@3oool00`000000oooo0?oo
o`0c0?ooo`800?l0?P3`oo000`000000l?o`0?3ol0020?3ol0050000003`
oo00l?o`0?3ol00000000`3`oo000`000000l?o`0?3ol0030?3ol0030000
003`oo00l?o`00D0l?o`00<000000?3ol03`oo001@3`oo000`000000l?o`
0?3ol0020?3ol0050000003`oo00l?o`0?3ol00000000`3`oo000`000000
l?o`0?3ol00@0?3ol0800?l0G`3oool007T0oooo00<000000?ooo`3oool0
=@3oool2003o03`0l?o`00<000000?3ol03`oo000P3`oo001@000000l?o`
0?3ol03`oo00000000<0l?o`00<000000?3ol03`oo000`3`oo05000000<0
l?o`00<000000?3ol03`oo001@3`oo000`000000l?o`0?3ol0020?3ol005
0000003`oo00l?o`0?3ol00000000`3`oo000`000000l?o`0?3ol00?0?3o
l003003o003oool0oooo05l0oooo001i0?ooo`030000003oool0oooo03L0
oooo0`00o`0i0?3ol0030000003`oo00l?o`0080l?o`0P0000020?3ol005
0000003`oo00l?o`0?3ol00000001@3`oo001@000000l?o`0?3ol03`oo00
000000<0l?o`0P0000060?3ol0030000003`oo00l?o`0080l?o`00D00000
0?3ol03`oo00l?o`000000030?3ol08000003P3`oo02003o0680oooo001i
0?ooo`030000003oool0oooo03X0oooo1000o`0e0?3ol0040000003`oo00
l?o`0?3ol080000000<0l?o`0000000000000`3`oo05000000<0l?o`0`00
00030?3ol080000000<0l?o`0000000000000P3`oo03000000D0l?o`0`00
00030?3ol080000000<0l?o`0000000000002`3`oo000`00o`00oooo0?oo
o`1R0?ooo`00N@3oool00`000000oooo0?ooo`0n0?ooo`@00?l0<@3`oo00
0`000000l?o`0?3ol00:0?3ol0030000003`oo00l?o`02d0l?o`0P00o`0=
0?ooobl00?l0:@3oool007T0oooo00<000000?ooo`3oool0@P3oool4003o
02/0l?o`1@00000P0?3ol0030000003`oo00l?o`01H0l?o`00<00?l00?oo
o`3oool02@3oool4003o02h0l?o`1000o`0V0?ooo`00N@3oool00`000000
oooo0?ooo`160?ooo`<00?l0I@3`oo000`00o`00oooo0?ooo`050?ooo`D0
0?l0=P3`oo000`00o`00oooo0?ooo`0S0?ooo`00N@3oool00`000000oooo
0?ooo`190?ooo`@00?l0H03`oo09003o03`0l?o`00<00?l00?ooo`3oool0
8P3oool007T0oooo00<000000?ooo`3oool0C@3oool4003o0:80l?o`00<0
0?l00?ooo`3oool08@3oool007T0oooo00<000000?ooo`3oool0D@3oool4
003o09h0l?o`00<00?l00?ooo`3oool08@3oool007T0oooo00<000000?oo
o`3oool0E03oool00`3`oo000?l0003o0002003o09X0l?o`00<00?l00?oo
o`3oool08@3oool007T0oooo00<000000?ooo`3oool0F@3oool3003o09L0
l?o`00<00?l00?ooo`3oool08@3oool007T0oooo00<000000?ooo`3oool0
F03oool2003o09T0l?o`00<00?l00?ooo`3oool08@3oool007T0oooo00<0
00000?ooo`3oool0EP3oool2003o09/0l?o`00<00?l00?ooo`3oool08@3o
ool007T0oooo00<000000?ooo`3oool0E03oool2003o09d0l?o`00<00?l0
0?ooo`3oool08@3oool007T0oooo00<000000?ooo`3oool0D@3oool3003o
09l0l?o`00<00?l00?ooo`3oool08@3oool007T0oooo00<000000?ooo`3o
ool0C`3oool2003o0:40l?o`00<00?l00?ooo`3oool08P3oool007T0oooo
00<000000?ooo`3oool0C@3oool2003o0:80l?o`00<00?l00?ooo`3oool0
8`3oool007T0oooo00<000000?ooo`3oool0B`3oool2003o0:@0l?o`00<0
0?l00?ooo`3oool08`3oool007T0oooo00<000000?ooo`3oool0A`3oool4
003o0:H0l?o`00<00?l00?ooo`3oool08`3oool007T0oooo00<000000?oo
o`3oool0A03oool3003o0:T0l?o`00<0oooo003o003oool0903oool007T0
oooo00<000000?ooo`3oool0@P3oool2003o0:`0l?o`00<00?l00?ooo`3o
ool0903oool007T0oooo00<000000?ooo`3oool0?`3oool3003o0:d0l?o`
00<0oooo003o003oool09@3oool007T0oooo00<000000?ooo`3oool0?@3o
ool2003o0;00l?o`00<00?l00?ooo`3oool09@3oool007T0oooo00<00000
0?ooo`3oool0?03oool2003o03<0l?o`1@00o`1h0?3ol003003o003oool0
oooo02H0oooo001i0?ooo`030000003oool0oooo03/0oooo00<00?l00?3o
l03`oo00<P3`oo000`00o`00oooo0?ooo`030?ooo`800?l0MP3`oo000`00
o`00oooo0?ooo`0V0?ooo`00N@3oool00`000000oooo0?ooo`0j0?ooo`80
0?l0<`3`oo000`00o`00oooo0?ooo`060?ooo`03003o003`oo00l?o`0780
l?o`00<00?l00?ooo`3oool09`3oool007T0oooo00<000000?ooo`3oool0
>P3oool00`00o`00l?o`0?3ol00a0?3ol003003o003oool0oooo00P0oooo
00<00?l00?3ol03`oo00;P3`oo000`000000l?o`00000002000003d0l?o`
00<0oooo003o003oool0:03oool007T0oooo00<000000?ooo`3oool0>P3o
ool00`00o`00l?o`0?3ol00a0?3ol003003o003oool0oooo00T0oooo00<0
0?l00?3ol03`oo00;@3`oo02000000<0l?o`00<000000?3ol03`oo00>@3`
oo000`3oool00?l00?ooo`0Y0?ooo`00N@3oool00`000000oooo0?ooo`0j
0?ooo`800?l0<@3`oo000`00o`00oooo0?ooo`0:0?ooo`03003o003`oo00
l?o`0380l?o`00<000000?3ol03`oo00>@3`oo000`00o`00oooo0?ooo`0Y
0?ooo`00N@3oool00`000000oooo0?ooo`0k0?ooo`03003o003`oo00l?o`
02l0l?o`00<00?l00?ooo`3oool02P3oool00`00o`00l?o`0?3ol00b0?3o
l0030000003`oo00l?o`03P0l?o`00<00?l00?ooo`3oool0:P3oool007T0
oooo00<000000?ooo`3oool0?03oool00`00o`00l?o`0?3ol00]0?3ol003
003o003oool0oooo00/0oooo00<00?l00?3ol03`oo00;P3`oo04000003/0
l?o`00<00?l00?ooo`3oool0:P3oool007T0oooo00<000000?ooo`3oool0
?@3oool2003o02`0l?o`00<0oooo003o003oool0303oool00`00o`00l?o`
0?3ol00]0?3ol0030000003`oo00l?o`03`0l?o`00<00?l00?ooo`3oool0
:`3oool007T0oooo00<000000?ooo`3oool0?`3oool2003o02X0l?o`00<0
0?l00?ooo`3oool0303oool00`00o`00l?o`0?3ol00]0?3ol0040000003`
oo00l?o`0?3ol0800000>03`oo000`00o`00oooo0?ooo`0/0?ooo`00N@3o
ool00`000000oooo0?ooo`110?ooo`800?l09`3`oo000`3oool00?l00?oo
o`0=0?ooo`03003o003`oo00l?o`02h0l?o`0`0000000`3`oo0000000?3o
l00f0?3ol0030?ooo`00o`00oooo02d0oooo001i0?ooo`030000003oool0
oooo04<0oooo0P00o`0T0?3ol0030?ooo`00o`00oooo00h0oooo00<00?l0
0?3ol03`oo00J@3`oo000`3oool00?l00?ooo`0^0?ooo`00N@3oool00`00
0000oooo0?ooo`140?ooo`030?3ol000o`000?l00240l?o`0P00o`0@0?oo
o`03003o003`oo00l?o`06P0l?o`0P00o`0`0?ooo`00N@3oool00`000000
oooo0?ooo`170?ooo`800?l07P3`oo000`00o`00oooo0?ooo`0@0?ooo`03
003o003`oo00l?o`06L0l?o`00<00?l00?ooo`3oool0<03oool007T0oooo
00<000000?ooo`3oool0B@3oool2003o01/0l?o`00<00?l00?ooo`3oool0
4@3oool00`00o`00l?o`0?3ol01V0?3ol003003o003oool0oooo0340oooo
001i0?ooo`030000003oool0oooo04/0oooo0P00o`0I0?3ol003003o003o
ool0oooo0140oooo0P00o`1U0?3ol0800?l0=03oool007T0oooo00<00000
0?ooo`3oool0C@3oool2003o01D0l?o`0P00o`0E0?ooo`03003o003`oo00
l?o`0640l?o`0P00o`0f0?ooo`00N@3oool00`000000oooo0?ooo`0B0?oo
o`H0000000<0oooo0000000000000P3oool2000000@0oooo0`0000030?oo
o`@000000P3oool500000080oooo1@0000030?ooo`<000000`3oool50000
00H0oooo0`00o`0A0?3ol003003o003oool0oooo01H0oooo00<00?l00?3o
l03`oo00F`3`oo05003o03P0oooo001i0?ooo`030000003oool0oooo01<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`80
0?l03@3`oo02003o01X0oooo00<00?l00?3ol03`oo00D@3`oo09003o03d0
oooo001i0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
1@3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool0303oool=003o01d0oooo0P00o`1:0?3ol0L00?l000<0l?o`0?ooo`3o
ool0@`3oool007T0oooo00<000000?ooo`3oool04`3oool00`000000oooo
000000050?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`D00000
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo03P0
oooo0`00o`120?3ol0D00?l0C@3oool007T0oooo00<000000?ooo`3oool0
4`3oool3000000@0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool20000
00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000<0oooo0P00000l0?ooo`<00?l0?P3`oo000`00o`00oooo0?ooo`1@
0?ooo`00N@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool00000
00<0oooo0P0000020?ooo`8000000P3oool5000000<0oooo0`0000030?oo
o`80000000<0oooo0000000000000P3oool3000000D0oooo0`0000030?oo
o`80000000<0oooo000000000000?@3oool3003o03X0l?o`00<00?l00?oo
o`3oool0D@3oool007T0oooo00<000000?ooo`3oool04`3oool01@000000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0I03oool3003o
03L0l?o`00<00?l00?ooo`3oool0D@3oool007T0oooo00<000000?ooo`3o
ool04P3oool600000200oooo00<000000?ooo`3oool0D@3oool4003o03<0
l?o`00<00?l00?ooo`3oool0D@3oool007T0oooo00<000000?ooo`3oool0
T03oool6003o02`0l?o`00<00?l00?ooo`3oool0DP3oool007T0oooo00<0
00000?ooo`3oool0UP3oool6003o02@0l?o`0P00o`1E0?ooo`00N@3oool0
0`000000oooo0?ooo`2L0?ooo`P00?l06@3`oo03003o05L0oooo001i0?oo
o`030000003oool0oooo0:<0oooo00<0l?o`003o0000o`005`00o`1J0?oo
o`00N@3oool00`000000oooo0?ooo`3o0?oooaP0oooo003o0?oooi@0oooo
003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0
oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo001g0?oo
o`800000o`3ooolK0?ooo`00N03oool00`000000oooo0?ooo`3o0?oooaT0
oooo001i0?ooo`030000003oool0oooo0?l0oooo603oool007P0oooo00<0
00000?ooo`000000o`3ooolI0?ooo`00M`3oool010000000oooo0?ooo`00
003o0?oooaT0oooo001f0?ooo`<0000000<0oooo000000000000o`3ooolH
0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3o
oonD0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\tFigure 1.25",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The interior, exterior, and boundary of a set ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe boundary of  ",
  Cell[BoxData[
      \(\(D\_R\) \((z\_0)\)\)]],
  "  is the circle depicted in Figure 1.23.  We denote this circle  ",
  Cell[BoxData[
      \(\(C\_R\) \((z\_0)\)\)]],
  "  and refer to it as the circle of radius ",
  StyleBox["R",
    FontFamily->"Courier New"],
  " centered at ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  Thus  \n\n",
  StyleBox["(1-52)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\(C\_R\) \((z\_0)\)\ \  = \ \ {z : \ \ \(\(|\)\(z - z\_0\)\(|\)\) = 
            R}\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe use the notation ",
  Cell[BoxData[
      \(\(C\_R\%+\) \((z\_0)\)\)]],
  " to indicate that the parametrization we chose for this simple closed \
curve resulted in a positive orientation;  ",
  Cell[BoxData[
      \(\(C\_R\%-\) \((z\_0)\)\)]],
  " denotes the same circle, but with a negative orientation.  (In both \
cases, counterclockwise denotes the positive direction.)  Using notation that \
we have already introduced, we get  ",
  Cell[BoxData[
      \(\(C\_R\%-\) \((z\_0)\) = \(-\ \(C\_R\%+\)\) \((z\_0)\)\)]],
  "."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008D0000bB000`400?l0
0000o`00003oo`3ooooo0?oooaH0oooo003o0?ooool0oooo5P3oool00?l0
ooooo`3ooolF0?ooo`00o`3ooooo0?oooaH0oooo003o0?ooool0oooo5P3o
ool00?l0ooooo`3ooolF0?ooo`00o`3ooooo0?oooaH0oooo003o0?ooool0
oooo5P3oool00?l0ooooo`3ooolF0?ooo`00o`3ooooo0?oooaH0oooo003o
0?ooo`80oooo0P0000000`3oool000000000003N0?ooo`80000000<0oooo
000000000000:`3oool00?l0oooo0`3oool00`000000oooo0000003P0?oo
o`030000003oool0000002`0oooo001>0?ooojd00000203oool00`000000
oooo0?ooo`0[0?ooojd00000203oool00`000000oooo0?ooo`0[0?ooo`00
CP3oool00`000000oooo0?ooo`2`0?ooo`80000000<0oooo000000000000
:`3oool00`000000oooo0?ooo`2`0?ooo`80000000<0oooo000000000000
:`3oool004h0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?oo
o`3P0?ooo`00CP3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0
oooo0>00oooo001>0?ooo`030000003oool0oooo0>00oooo00<000000?oo
o`3oool0h03oool004h0oooo00<000000?ooo`3oool0h03oool00`000000
oooo0?ooo`3P0?ooo`00CP3oool00`000000oooo0?ooo`3P0?ooo`030000
003oool0oooo0>00oooo001>0?ooo`030000003oool0oooo0>00oooo00<0
00000?ooo`3oool0h03oool004h0oooo00<000000?ooo`3oool0h03oool0
0`000000oooo0?ooo`3P0?ooo`00CP3oool00`000000oooo0?ooo`3P0?oo
o`030000003oool0oooo0>00oooo001>0?ooo`030000003oool0oooo0>00
oooo00<000000?ooo`3oool0h03oool004h0oooo00<000000?ooo`3oool0
h03oool00`000000oooo0?ooo`3P0?ooo`00CP3oool00`000000oooo0?oo
o`3P0?ooo`030000003oool0oooo0>00oooo001>0?ooo`030000003oool0
oooo0>00oooo00<000000?ooo`3oool0h03oool004h0oooo00<000000?oo
o`3oool0h03oool00`000000oooo0?ooo`3P0?ooo`00CP3oool00`000000
oooo0?ooo`3P0?ooo`030000003oool0oooo0>00oooo001>0?ooo`030000
003oool0oooo0>00oooo00<000000?ooo`3oool0h03oool004h0oooo00<0
00000?ooo`3oool0h03oool00`000000oooo0?ooo`3P0?ooo`00CP3oool0
0`000000oooo0?ooo`3P0?ooo`030000003oool0oooo0>00oooo001>0?oo
o`030000003oool0oooo0>00oooo00<000000?ooo`3oool0h03oool004h0
oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`3P0?ooo`00
CP3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo0>00oooo
001>0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0h03o
ool004h0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`3P
0?ooo`00CP3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo
0>00oooo001>0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3o
ool0h03oool004h0oooo00<000000?ooo`3oool0F`3ooolD0000og40oooo
00<000000?ooo`3oool0F`3ooolD0000og40oooo001>0?ooo`030000003o
ool0oooo05@0oooo1`000?lD0?ooo`D0003oK03oool00`000000oooo0?oo
o`1D0?ooo`L0003o503oool50000of`0oooo001>0?ooo`030000003oool0
oooo0580oooo0P000?lP0?ooo`@0003oJ03oool00`000000oooo0?ooo`1B
0?ooo`80003o803oool40000ofP0oooo001>0?ooo`030000003oool0oooo
0500oooo0P000?lV0?ooo`@0003oI03oool00`000000oooo0?ooo`1@0?oo
o`80003o9P3oool40000of@0oooo001>0?ooo`030000003oool0oooo04d0
oooo0`000?l/0?ooo`80003oHP3oool00`000000oooo0?ooo`1=0?ooo`<0
003o;03oool20000of80oooo001>0?ooo`030000003oool0oooo04X0oooo
0`000?la0?ooo`<0003oG`3oool00`000000oooo0?ooo`1:0?ooo`<0003o
<@3oool30000oel0oooo001>0?ooo`030000003oool0oooo04L0oooo0`00
0?lg0?ooo`80003oG@3oool00`000000oooo0?ooo`170?ooo`<0003o=`3o
ool20000oed0oooo001>0?ooo`030000003oool0oooo04D0oooo0P000?ll
0?ooo`80003oF`3oool00`000000oooo0?ooo`150?ooo`80003o?03oool2
0000oe/0oooo001>0?ooo`030000003oool0oooo04<0oooo0P000?m00?oo
o`80003oF@3oool00`000000oooo0?ooo`130?ooo`80003o@03oool20000
oeT0oooo001>0?ooo`030000003oool0oooo0480oooo00<0003o0?ooo`3o
ool0@P3oool20000oeL0oooo00<000000?ooo`3oool0@P3oool00`000?l0
oooo0?ooo`120?ooo`80003oE`3oool004h0oooo00<000000?ooo`3oool0
@03oool20000odL0oooo0P000?mE0?ooo`030000003oool0oooo0400oooo
0P000?m70?ooo`80003oE@3oool004h0oooo00<000000?ooo`3oool0?P3o
ool20000od/0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?oo
o`0n0?ooo`80003oB`3oool00`000?l0oooo0?ooo`1B0?ooo`00CP3oool0
0`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo04`0oooo00<0003o
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`1;0?ooo`030000003oool0
oooo03L0oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`1<
0?ooo`030000o`3oool0oooo0540oooo001>0?ooo`030000003oool0oooo
03/0oooo0P000?m@0?ooo`040000o`3oool0oooo0?ooo`<00?l0C03oool0
0`000000oooo0?ooo`0f0?ooo`<00?l00P3oool20000oe00oooo00<0003o
0?ooo`3oool0D03oool004h0oooo00<000000?ooo`3oool0>P3oool00`00
0?l0oooo0?ooo`1A0?ooo`80003o1000o`1<0?ooo`030000003oool0oooo
03H0oooo1000o`000`000?l0oooo0?ooo`1A0?ooo`80003oD03oool004h0
oooo00<000000?ooo`3oool0>@3oool00`00o`00oooo0?ooo`1B0?ooo`L0
0?l0B`3oool00`000000oooo0?ooo`0e0?ooo`L00?l0E03oool00`00o`00
oooo0?ooo`1=0?ooo`00CP3oool00`000000oooo0?ooo`0g0?ooo`800?l0
E03oool8003o04/0oooo00<000000?ooo`3oool0=@3oool8003o05@0oooo
0P00o`1=0?ooo`00CP3oool00`000000oooo0?ooo`0e0?ooo`@00?l0D`3o
ool:003o04X0oooo00<000000?ooo`3oool0=03oool:003o05<0oooo1000
o`1;0?ooo`00CP3oool00`000000oooo0?ooo`0d0?ooo`@00?l0E@3oool:
003o04T0oooo00<000000?ooo`3oool0<`3oool:003o05D0oooo1000o`1:
0?ooo`00CP3oool00`000000oooo0?ooo`0b0?ooo`H00?l0E`3oool8003o
04T0oooo00<000000?ooo`3oool0<`3oool8003o05L0oooo1P00o`180?oo
o`00CP3oool00`000000oooo0?ooo`0a0?ooo`H00?l0FP3oool7003o04P0
oooo00<000000?ooo`3oool0<P3oool7003o05X0oooo1P00o`170?ooo`00
CP3oool00`000000oooo0?ooo`0_0?ooo`L00?l0G@3oool6003o04L0oooo
00<000000?ooo`3oool0<@3oool6003o05d0oooo1`00o`150?ooo`00CP3o
ool00`000000oooo0?ooo`0]0?ooo`T00?l0GP3oool5003o04L0oooo00<0
00000?ooo`3oool0<@3oool5003o05h0oooo2@00o`130?ooo`00CP3oool0
0`000000oooo0?ooo`0/0?ooo`T00?l0H@3oool4003o04H0oooo00<00000
0?ooo`3oool0<03oool4003o0640oooo2@00o`120?ooo`00CP3oool00`00
0000oooo0?ooo`0]0?ooo`L00?l0I03oool2003o00030000o`3oool0oooo
04<0oooo00<000000?ooo`3oool0<03oool2003o06@0oooo1`00o`130?oo
o`00CP3oool00`000000oooo0?ooo`0^0?ooo`H00?l0IP3oool00`00o`00
oooo0?ooo`130?ooo`030000003oool0oooo02l0oooo00<00?l00?ooo`3o
ool0I03oool6003o04@0oooo001>0?ooo`030000003oool0oooo02l0oooo
1000o`1X0?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0
;`3oool00`000?l0oooo0?ooo`1U0?ooo`@00?l000<0003o0?ooo`3oool0
@P3oool004h0oooo00<000000?ooo`3oool0;P3oool00`000?l0oooo003o
0002003o06P0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`030000o`3oool0oooo06H0oooo0`00o`000`3oool0003o0?oo
o`130?ooo`00CP3oool00`000000oooo0?ooo`0]0?ooo`050000o`3oool0
oooo0?ooo`00o`00JP3oool00`000?l0oooo0?ooo`110?ooo`030000003o
ool0oooo02d0oooo00<0003o0?ooo`3oool0J03oool01@00o`00oooo0?oo
o`3oool0003o04<0oooo001>0?ooo`030000003oool0oooo02`0oooo00<0
003o0?ooo`3oool0KP3oool00`000?l0oooo0?ooo`100?ooo`030000003o
ool0oooo02`0oooo00<0003o0?ooo`3oool0KP3oool00`000?l0oooo0?oo
o`100?ooo`00CP3oool00`000000oooo0?ooo`0/0?ooo`030000o`3oool0
oooo06h0oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`0/
0?ooo`030000o`3oool0oooo06h0oooo00<0003o0?ooo`3oool0@03oool0
04h0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`1`0?oo
o`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0:`3oool00`00
0?l0oooo0?ooo`1`0?ooo`030000o`3oool0oooo03l0oooo001>0?ooo`03
0000003oool0oooo02X0oooo00<0003o0?ooo`3oool0LP3oool00`000?l0
oooo0?ooo`0n0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3o
ool0LP3oool00`000?l0oooo0?ooo`0n0?ooo`00CP3oool00`000000oooo
0?ooo`0Z0?ooo`030000o`3oool0oooo0780oooo00<0003o0?ooo`3oool0
?P3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo0780oooo
00<0003o0?ooo`3oool0?P3oool004h0oooo00<000000?ooo`3oool0:@3o
ool00`000?l0oooo0?ooo`1d0?ooo`030000o`3oool0oooo03d0oooo00<0
00000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`1d0?ooo`030000o`3o
ool0oooo03d0oooo001>0?ooo`030000003oool0oooo02T0oooo00<0003o
0?ooo`3oool0M03oool00`000?l0oooo0?ooo`0m0?ooo`030000003oool0
oooo02T0oooo00<0003o0?ooo`3oool0M03oool00`000?l0oooo0?ooo`0m
0?ooo`00CP3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo
07H0oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`0X0?oo
o`030000o`3oool0oooo07H0oooo00<0003o0?ooo`3oool0?03oool004h0
oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`1f0?ooo`03
0000o`3oool0oooo03`0oooo00<000000?ooo`3oool0:03oool00`000?l0
oooo0?ooo`1f0?ooo`030000o`3oool0oooo03`0oooo001>0?ooo`030000
003oool0oooo02L0oooo00<0003o0?ooo`3oool0N03oool00`000?l0oooo
0?ooo`0k0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0
N03oool00`000?l0oooo0?ooo`0k0?ooo`00CP3oool00`000000oooo0?oo
o`0W0?ooo`030000o`3oool0oooo07P0oooo00<0003o0?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo07P0oooo00<0
003o0?ooo`3oool0>`3oool004h0oooo00<000000?ooo`3oool09P3oool0
0`000?l0oooo0?ooo`1j0?ooo`030000o`3oool0oooo03X0oooo00<00000
0?ooo`3oool09P3oool00`000?l0oooo0?ooo`1j0?ooo`030000o`3oool0
oooo03X0oooo001>0?ooo`030000003oool0oooo02H0oooo00<0003o0?oo
o`3oool0NP3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo
02H0oooo00<0003o0?ooo`3oool0NP3oool00`000?l0oooo0?ooo`0j0?oo
o`00CP3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo07`0
oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`0U0?ooo`03
0000o`3oool0oooo07`0oooo00<0003o0?ooo`3oool0>@3oool004h0oooo
00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`1l0?ooo`030000
o`3oool0oooo03T0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo
0?ooo`1l0?ooo`030000o`3oool0oooo03T0oooo001>0?ooo`030000003o
ool0oooo02@0oooo00<0003o0?ooo`3oool0OP3oool00`000?l0oooo0?oo
o`0h0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0OP3o
ool00`000?l0oooo0?ooo`0h0?ooo`00CP3oool00`000000oooo0?ooo`0T
0?ooo`030000o`3oool0oooo07h0oooo00<0003o0?ooo`3oool0>03oool0
0`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo07h0oooo00<0003o
0?ooo`3oool0>03oool004h0oooo00<000000?ooo`3oool08`3oool00`00
0?l0oooo0?ooo`200?ooo`030000o`3oool0oooo03L0oooo00<000000?oo
o`3oool08`3oool00`000?l0oooo0?ooo`200?ooo`030000o`3oool0oooo
03L0oooo001>0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3o
ool0P03oool00`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo02<0
oooo00<0003o0?ooo`3oool0P03oool00`000?l0oooo0?ooo`0g0?ooo`00
CP3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0800oooo
00<0003o0?ooo`3oool0=`3oool00`000000oooo0?ooo`0S0?ooo`030000
o`3oool0oooo0800oooo00<0003o0?ooo`3oool0=`3oool004h0oooo00<0
00000?ooo`3oool08P3oool00`000?l0oooo0?ooo`220?ooo`030000o`3o
ool0oooo03H0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?oo
o`220?ooo`030000o`3oool0oooo03H0oooo001>0?ooo`030000003oool0
oooo0280oooo00<0003o0?ooo`3oool0PP3oool00`000?l0oooo0?ooo`0f
0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool0PP3oool0
0`000?l0oooo0?ooo`0f0?ooo`00CP3oool00`000000oooo0?ooo`0R0?oo
o`030000o`3oool0oooo0880oooo00<0003o0?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0880oooo00<0003o0?oo
o`3oool0=P3oool004h0oooo00<000000?ooo`3oool08P3oool00`000?l0
oooo0?ooo`220?ooo`030000o`3oool0oooo03H0oooo00<000000?ooo`3o
ool08P3oool00`000?l0oooo0?ooo`220?ooo`030000o`3oool0oooo03H0
oooo001>0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool0
P`3oool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo0280oooo
00<0003o0?ooo`3oool0P`3oool00`000?l0oooo0?ooo`0e0?ooo`00CP3o
ool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo08@0oooo00<0
003o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3o
ool0oooo08@0oooo00<0003o0?ooo`3oool0=@3oool004h0oooo00<00000
0?ooo`3oool08@3oool00`000?l0oooo0?ooo`240?ooo`030000o`3oool0
oooo03D0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`24
0?ooo`030000o`3oool0oooo03D0oooo001>0?ooo`030000003oool0oooo
0240oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`150?oo
o`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool08@3oool00`00
0?l0oooo0?ooo`0l0?ooo`030000003oool0oooo04D0oooo00<0003o0?oo
o`3oool0=@3oool004h0oooo00<000000?ooo`3oool08@3oool00`000?l0
oooo0?ooo`0k0?ooo`030000003oool0000004H0oooo00<0003o0?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo03/0
oooo00<000000?ooo`000000AP3oool00`000?l0oooo0?ooo`0e0?ooo`00
CP3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo03@0oooo
1@0000020?ooo`030000003oool0000004H0oooo00<0003o0?ooo`3oool0
=@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo03@0oooo
1@0000020?ooo`030000003oool0000004H0oooo00<0003o0?ooo`3oool0
=@3oool004h0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?oo
o`0e0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`000000
AP3oool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo0240oooo
00<0003o0?ooo`3oool0=@3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0000004H0oooo00<0003o0?ooo`3oool0=@3oool004h0oooo
00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`0g0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`000000A`3oool00`000?l0oooo
0?ooo`0d0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0
=`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000004L0oooo
00<0003o0?ooo`3oool0=03oool004h0oooo00<000000?ooo`3oool0803o
ool00`000?l0oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0AP3oool00`000?l0oooo0?ooo`0d0?ooo`030000003o
ool0oooo0200oooo00<0003o0?ooo`3oool0>03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool0=03o
ool004h0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`0f
0?ooo`040000003oool0oooo000004`0oooo00<0003o0?ooo`3oool0=03o
ool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo03H0oooo00@0
00000?ooo`3oool00000C03oool00`000?l0oooo0?ooo`0d0?ooo`00CP3o
ool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo03H0oooo1@00
001;0?ooo`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool0803o
ool00`000?l0oooo0?ooo`0f0?ooo`D00000B`3oool00`000?l0oooo0?oo
o`0d0?ooo`00CP3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0
oooo08H0oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`0P
0?ooo`030000o`3oool0oooo08H0oooo00<0003o0?ooo`3oool0=03oool0
04h0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`260?oo
o`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool0803oool00`00
0?l0oooo0?ooo`260?ooo`030000o`3oool0oooo03@0oooo001>0?ooo`03
0000003oool0oooo0200oooo00<0003o0?ooo`3oool0@@3oool20000od<0
oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`03
0000o`3oool0oooo0440oooo0P000?m30?ooo`030000o`3oool0oooo03@0
oooo001>0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0
@03oool40000od80oooo00<0003o0?ooo`3oool0=03oool00`000000oooo
0?ooo`0P0?ooo`030000o`3oool0oooo0400oooo10000?m20?ooo`030000
o`3oool0oooo03@0oooo001>0?ooo`030000003oool0oooo0200oooo00<0
003o0?ooo`3oool0?`3oool60000od40oooo00<0003o0?ooo`3oool0=03o
ool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo03l0oooo1P00
0?m10?ooo`030000o`3oool0oooo03@0oooo001>0?ooo`030000003oool0
oooo0200oooo00<0003o0?ooo`3oool0?`3oool60000od40oooo00<0003o
0?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0
oooo03l0oooo1P000?m10?ooo`030000o`3oool0oooo03@0oooo001>0?oo
o`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0@03oool40000
od80oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?oo
o`030000o`3oool0oooo0400oooo10000?m20?ooo`030000o`3oool0oooo
03@0oooo001>0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3o
ool0@@3oool20000od<0oooo00<0003o0?ooo`3oool0=03oool00`000000
oooo0?ooo`0P0?ooo`030000o`3oool0oooo0440oooo0P000?m30?ooo`03
0000o`3oool0oooo03@0oooo001>0?ooo`030000003oool0oooo0200oooo
00<0003o0?ooo`3oool0QP3oool00`000?l0oooo0?ooo`0d0?ooo`030000
003oool0oooo0200oooo00<0003o0?ooo`3oool0QP3oool00`000?l0oooo
0?ooo`0d0?ooo`00CP3oool00`000000oooo0?ooo`0P0?ooo`030000o`3o
ool0oooo08H0oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?oo
o`0P0?ooo`030000o`3oool0oooo08H0oooo00<0003o0?ooo`3oool0=03o
ool004h0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`26
0?ooo`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool0803oool0
0`000?l0oooo0?ooo`260?ooo`030000o`3oool0oooo03@0oooo001>0?oo
o`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0QP3oool00`00
0?l0oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo00<0003o0?oo
o`3oool0QP3oool00`000?l0oooo0?ooo`0d0?ooo`00CP3oool00`000000
oooo0?ooo`0P0?ooo`030000o`3oool0oooo08H0oooo00<0003o0?ooo`3o
ool0=03oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo08H0
oooo00<0003o0?ooo`3oool0=03oool004h0oooo00<000000?ooo`3oool0
803oool00`000?l0oooo0?ooo`260?ooo`030000o`3oool0oooo03@0oooo
00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`260?ooo`030000
o`3oool0oooo03@0oooo001>0?ooo`030000003oool0oooo0200oooo00<0
003o0?ooo`3oool0Q@3oool00`000?l0oooo0?ooo`0e0?ooo`030000003o
ool0oooo0200oooo00<0003o0?ooo`3oool0Q@3oool00`000?l0oooo0?oo
o`0e0?ooo`00CP3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0
oooo08D0oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0P
0?ooo`030000o`3oool0oooo08D0oooo00<0003o0?ooo`3oool0=@3oool0
04h0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`250?oo
o`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0803oool00`00
0?l0oooo0?ooo`250?ooo`030000o`3oool0oooo03D0oooo001>0?ooo`03
0000003oool0oooo0240oooo00<0003o0?ooo`3oool0Q03oool00`000?l0
oooo0?ooo`0e0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3o
ool0Q03oool00`000?l0oooo0?ooo`0e0?ooo`00CP3oool00`000000oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo08@0oooo00<0003o0?ooo`3oool0
=@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo08@0oooo
00<0003o0?ooo`3oool0=@3oool004h0oooo00<000000?ooo`3oool08@3o
ool00`000?l0oooo0?ooo`240?ooo`030000o`3oool0oooo03D0oooo00<0
00000?ooo`3oool08@3oool00`000?l0oooo0?ooo`240?ooo`030000o`3o
ool0oooo03D0oooo001>0?ooo`030000003oool0oooo0240oooo00<0003o
0?ooo`3oool0P`3oool00`000?l0oooo0?ooo`0f0?ooo`030000003oool0
oooo0240oooo00<0003o0?ooo`3oool0P`3oool00`000?l0oooo0?ooo`0f
0?ooo`00CP3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo
0880oooo00<0003o0?ooo`3oool0=P3oool00`000000oooo0?ooo`0R0?oo
o`030000o`3oool0oooo0880oooo00<0003o0?ooo`3oool0=P3oool004h0
oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`220?ooo`03
0000o`3oool0oooo03H0oooo00<000000?ooo`3oool08P3oool00`000?l0
oooo0?ooo`220?ooo`030000o`3oool0oooo03H0oooo001>0?ooo`030000
003oool0oooo0280oooo00<0003o0?ooo`3oool0PP3oool00`000?l0oooo
0?ooo`0f0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool0
PP3oool00`000?l0oooo0?ooo`0f0?ooo`00CP3oool00`000000oooo0?oo
o`0R0?ooo`030000o`3oool0oooo0840oooo00<0003o0?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0840oooo00<0
003o0?ooo`3oool0=`3oool004h0oooo00<000000?ooo`3oool08`3oool0
0`000?l0oooo0?ooo`200?ooo`030000o`3oool0oooo03L0oooo00<00000
0?ooo`3oool08`3oool00`000?l0oooo0?ooo`200?ooo`030000o`3oool0
oooo03L0oooo001>0?ooo`030000003oool0oooo02<0oooo00<0003o0?oo
o`3oool0P03oool00`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo
02<0oooo00<0003o0?ooo`3oool0P03oool00`000?l0oooo0?ooo`0g0?oo
o`00CP3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo07l0
oooo00<0003o0?ooo`3oool0>03oool00`000000oooo0?ooo`0S0?ooo`03
0000o`3oool0oooo07l0oooo00<0003o0?ooo`3oool0>03oool004h0oooo
00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`1n0?ooo`030000
o`3oool0oooo03P0oooo00<000000?ooo`3oool0903oool00`000?l0oooo
0?ooo`1n0?ooo`030000o`3oool0oooo03P0oooo001>0?ooo`030000003o
ool0oooo02@0oooo00<0003o0?ooo`3oool0O@3oool00`000?l0oooo0?oo
o`0i0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0O@3o
ool00`000?l0oooo0?ooo`0i0?ooo`00CP3oool00`000000oooo0?ooo`0U
0?ooo`030000o`3oool0oooo07`0oooo00<0003o0?ooo`3oool0>@3oool0
0`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo07`0oooo00<0003o
0?ooo`3oool0>@3oool004h0oooo00<000000?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`1l0?ooo`030000o`3oool0oooo03T0oooo00<000000?oo
o`3oool09@3oool00`000?l0oooo0?ooo`1l0?ooo`030000o`3oool0oooo
03T0oooo001>0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3o
ool0NP3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo02H0
oooo00<0003o0?ooo`3oool0NP3oool00`000?l0oooo0?ooo`0j0?ooo`00
CP3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo07X0oooo
00<0003o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0V0?ooo`030000
o`3oool0oooo07X0oooo00<0003o0?ooo`3oool0>P3oool004h0oooo00<0
00000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1h0?ooo`030000o`3o
ool0oooo03/0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?oo
o`1h0?ooo`030000o`3oool0oooo03/0oooo001>0?ooo`030000003oool0
oooo02L0oooo00<0003o0?ooo`3oool0N03oool00`000?l0oooo0?ooo`0k
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0N03oool0
0`000?l0oooo0?ooo`0k0?ooo`00CP3oool00`000000oooo0?ooo`0X0?oo
o`030000o`3oool0oooo07H0oooo00<0003o0?ooo`3oool0?03oool00`00
0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo07H0oooo00<0003o0?oo
o`3oool0?03oool004h0oooo00<000000?ooo`3oool0:03oool00`000?l0
oooo0?ooo`1f0?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3o
ool0:03oool00`000?l0oooo0?ooo`1f0?ooo`030000o`3oool0oooo03`0
oooo001>0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`3oool0
M03oool00`000?l0oooo0?ooo`0m0?ooo`030000003oool0oooo02T0oooo
00<0003o0?ooo`3oool0M03oool00`000?l0oooo0?ooo`0m0?ooo`00CP3o
ool00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo07@0oooo00<0
003o0?ooo`3oool0?@3oool00`000000oooo0?ooo`0Y0?ooo`030000o`3o
ool0oooo07@0oooo00<0003o0?ooo`3oool0?@3oool004h0oooo00<00000
0?ooo`3oool0:P3oool00`000?l0oooo0?ooo`1b0?ooo`030000o`3oool0
oooo03h0oooo00<000000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`1b
0?ooo`030000o`3oool0oooo03h0oooo001>0?ooo`030000003oool0oooo
02X0oooo00<0003o0?ooo`3oool0LP3oool00`000?l0oooo0?ooo`0n0?oo
o`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0LP3oool00`00
0?l0oooo0?ooo`0n0?ooo`00CP3oool00`000000oooo0?ooo`0[0?ooo`03
0000o`3oool0oooo0700oooo00<0003o0?ooo`3oool0?`3oool00`000000
oooo0?ooo`0[0?ooo`030000o`3oool0oooo0700oooo00<0003o0?ooo`3o
ool0?`3oool004h0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo
0?ooo`1^0?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3oool0
;03oool00`000?l0oooo0?ooo`1^0?ooo`030000o`3oool0oooo0400oooo
001>0?ooo`030000003oool0oooo02`0oooo00<0003o0?ooo`3oool0J@3o
ool01@00o`00oooo0?ooo`3oool0003o04<0oooo00<000000?ooo`3oool0
;03oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo06P0oooo
00<0003o0?ooo`3oool0@@3oool004h0oooo00<000000?ooo`3oool0;@3o
ool00`000?l0oooo0?ooo`1W0?ooo`<00?l00P3oool00`000?l0oooo0?oo
o`110?ooo`030000003oool0oooo02d0oooo00<0003o0?ooo`3oool00`00
o`1Y0?ooo`030000o`3oool0oooo0440oooo001>0?ooo`030000003oool0
oooo02h0oooo00<0003o0?ooo`3oool0IP3oool4003o00030000o`3oool0
oooo0480oooo00<000000?ooo`3oool0;P3oool00`000?l00?l0003o0002
003o06P0oooo00<0003o0?ooo`3oool0@P3oool004h0oooo00<000000?oo
o`3oool0;`3oool00`000?l0oooo0?ooo`1T0?ooo`D00?l0A@3oool00`00
0000oooo0?ooo`0^0?ooo`H00?l0IP3oool00`000?l0oooo0?ooo`130?oo
o`00CP3oool00`000000oooo0?ooo`0_0?ooo`03003o003oool0oooo06@0
oooo1P00o`140?ooo`030000003oool0oooo02h0oooo1P00o`1U0?ooo`03
0000o`00o`00oooo04@0oooo001>0?ooo`030000003oool0oooo0300oooo
0P00o`1S0?ooo`P00?l0@`3oool00`000000oooo0?ooo`0]0?ooo`P00?l0
H`3oool2003o04H0oooo001>0?ooo`030000003oool0oooo0300oooo1000
o`1Q0?ooo`T00?l0@P3oool00`000000oooo0?ooo`0/0?ooo`T00?l0H@3o
ool4003o04H0oooo001>0?ooo`030000003oool0oooo0340oooo1@00o`0M
0?ooo`<000000P3oool2000003X0oooo2@00o`130?ooo`030000003oool0
oooo02d0oooo2@00o`1N0?ooo`D00?l0A`3oool004h0oooo00<000000?oo
o`3oool0<@3oool6003o01d0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05`3oool8
003o04D0oooo00<000000?ooo`3oool0;`3oool8003o01`0oooo0`000002
0?ooo`8000001`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo01L0oooo1P00o`170?ooo`00CP3oool00`000000oooo0?ooo`0b0?oo
o`L00?l06`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0
oooo00d0oooo0`0000070?ooo`030000003oool0oooo01H0oooo1P00o`17
0?ooo`030000003oool0oooo0340oooo1P00o`0M0?ooo`050000003oool0
oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0=0?ooo`<000001`3o
ool00`000000oooo0?ooo`0D0?ooo`L00?l0B03oool004h0oooo00<00000
0?ooo`3oool0<`3oool8003o01X0oooo100000070?ooo`030000003oool0
oooo00`0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo01D0oooo1P00o`180?ooo`030000003oool0oooo0380oooo1P00
o`0L0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0
303oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3o
ool04P3oool8003o04T0oooo001>0?ooo`030000003oool0oooo03<0oooo
2P00o`0A0?ooo`<00000103oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`3oool01@3oool600000080oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0oooo01@0oooo1000o`1:0?oo
o`030000003oool0oooo03@0oooo1000o`0F0?ooo`<00000103oool40000
00H0oooo00<000000?ooo`3oool01@3oool600000080oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo00l0oooo2P00o`19
0?ooo`00CP3oool00`000000oooo0?ooo`0d0?ooo`X00?l03`3oool01000
0000oooo0?ooo`3oool200000080oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000
oooo0?ooo`0C0?ooo`@00?l0B`3oool00`000000oooo0?ooo`0e0?ooo`@0
0?l0503oool010000000oooo0?ooo`3oool200000080oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
1`3oool00`000000oooo0?ooo`0>0?ooo`X00?l0BP3oool004h0oooo00<0
00000?ooo`3oool0=@3oool8003o00l0oooo00<000000?ooo`3oool01@3o
ool5000000H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`0B0?ooo`030000o`00o`000?l004d0oooo00<000000?ooo`3oool0
=`3oool2003o01<0oooo00<000000?ooo`3oool01P3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001`3oool00`00
0000oooo0?ooo`0?0?ooo`P00?l0B`3oool004h0oooo00<000000?ooo`3o
ool0=@3oool7003o0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0oooo0140oooo00<0003o003o
003oool0CP3oool00`000000oooo0?ooo`0i0?ooo`03003o00000?l0oooo
0100oooo00<000000?ooo`3oool01@3oool5000000H0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo0?ooo`0@0?ooo`L00?l0B`3oool0
04h0oooo00<000000?ooo`3oool0=P3oool5003o00030000o`3oool0oooo
00h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0080oooo0`0000080?ooo`030000003oool0oooo
0100oooo00<0003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`0k0?oo
o`030000o`3oool0oooo00h0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo0`0000080?oo
o`030000003oool0oooo0100oooo00<0003o003o0000o`000`00o`1<0?oo
o`00CP3oool00`000000oooo0?ooo`0f0?ooo`<00?l00`3oool00`000?l0
oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?oo
o`3oool03P3oool20000oe80oooo00<000000?ooo`3oool0?03oool00`00
0?l0oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool01P3oool01@000000oooo0?ooo`3oool0000000h0oooo00<00000
0?ooo`3oool03P3oool20000o`<0oooo0`00o`1<0?ooo`00CP3oool00`00
0000oooo0?ooo`0g0?ooo`03003o003oool0oooo00<0oooo0P000?l>0?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00000007
0?ooo`030000003oool0oooo00H0oooo1P00000=0?ooo`030000003oool0
oooo00d0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`0m
0?ooo`80003o3P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01P3oool6000000d0oooo00<00000
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0
oooo04/0oooo001>0?ooo`030000003oool0oooo03l0oooo00<0003o0?oo
o`3oool0303oool010000000oooo0?ooo`3oool2000000<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00`0oooo0P000?mE0?ooo`030000003oool0oooo03l0oooo00<0003o
0?ooo`3oool0303oool010000000oooo0?ooo`3oool2000000`0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`80003oE@3o
ool004h0oooo00<000000?ooo`3oool0@03oool20000o`d0oooo0`000000
0`3oool000000?ooo`05000000H0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0:0?ooo`80003oE`3oool00`000000oooo0?ooo`10
0?ooo`80003o3@3oool3000000030?ooo`000000oooo00/0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0:0?ooo`80003oE`3oool0
04h0oooo00<000000?ooo`3oool0@P3oool20000oa<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00X0oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo0?ooo`120?oo
o`80003o4@3oool5000000L0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo05L0oooo001>0?ooo`03
0000003oool0oooo04@0oooo0P000?lA0?ooo`030000003oool0oooo02X0
oooo0P000?mJ0?ooo`030000003oool0oooo04@0oooo0P000?ln0?ooo`80
003oFP3oool004h0oooo00<000000?ooo`3oool0AP3oool30000ocP0oooo
0`000?mL0?ooo`030000003oool0oooo04H0oooo0`000?lh0?ooo`<0003o
G03oool004h0oooo00<000000?ooo`3oool0B@3oool20000oc@0oooo0P00
0?mO0?ooo`030000003oool0oooo04T0oooo0P000?ld0?ooo`80003oG`3o
ool004h0oooo00<000000?ooo`3oool0B`3oool20000oc00oooo0P000?mQ
0?ooo`030000003oool0oooo04/0oooo0P000?l`0?ooo`80003oH@3oool0
04h0oooo00<000000?ooo`3oool0C@3oool20000ob`0oooo0P000?mS0?oo
o`030000003oool0oooo04d0oooo0P000?l/0?ooo`80003oH`3oool004h0
oooo00<000000?ooo`3oool0C`3oool40000ob@0oooo10000?mU0?ooo`03
0000003oool0oooo04l0oooo10000?lT0?ooo`@0003oI@3oool004h0oooo
00<000000?ooo`3oool0D`3oool40000oad0oooo0`000?mY0?ooo`030000
003oool0oooo05<0oooo10000?lM0?ooo`<0003oJ@3oool004h0oooo00<0
00000?ooo`3oool0E`3oool50000oa80oooo1P000?m/0?ooo`030000003o
ool0oooo05L0oooo1@000?lB0?ooo`H0003oK03oool004h0oooo00<00000
0?ooo`3oool0G03ooolB0000og80oooo00<000000?ooo`3oool0G03ooolB
0000og80oooo001>0?ooo`030000003oool0oooo0>00oooo00<000000?oo
o`3oool0h03oool004h0oooo00<000000?ooo`3oool0h03oool00`000000
oooo0?ooo`3P0?ooo`00CP3oool00`000000oooo0?ooo`3P0?ooo`030000
003oool0oooo0>00oooo001>0?ooo`030000003oool0oooo0>00oooo00<0
00000?ooo`3oool0h03oool004h0oooo00<000000?ooo`3oool0h03oool0
0`000000oooo0?ooo`3P0?ooo`00CP3oool00`000000oooo0?ooo`3P0?oo
o`030000003oool0oooo0>00oooo001>0?ooo`030000003oool0oooo0>00
oooo00<000000?ooo`3oool0h03oool004h0oooo00<000000?ooo`3oool0
h03oool00`000000oooo0?ooo`3P0?ooo`00CP3oool00`000000oooo0?oo
o`3P0?ooo`030000003oool0oooo0>00oooo003o0?ooool0oooo5P3oool0
0?l0ooooo`3ooolF0?ooo`00o`3ooooo0?oooaH0oooo003o0?ooool0oooo
5P3oool00?l0ooooo`3ooolF0?ooo`00o`3ooooo0?oooaH0oooo001<0?oo
o`800000h@3oool200000><0oooo001=0?ooo`030000003oool0oooo0>00
oooo00<000000?ooo`3oool0h@3oool004h0oooo00<000000?ooo`3oool0
h03oool00`000000oooo0?ooo`3P0?ooo`00C@3oool00`000000oooo0000
003P0?ooo`030000003oool000000>40oooo001<0?ooo`040000003oool0
oooo00000=l0oooo00@000000?ooo`3oool00000h@3oool004/0oooo0`00
00000`3oool000000000003M0?ooo`<0000000<0oooo000000000000h03o
ool00?l0ooooo`3ooolF0?ooo`00o`3ooooo0?oooaH0oooo003o0?ooool0
oooo5P3oool00?l0ooooo`3ooolF0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{532, 201},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\tFigure 1.C",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The positively oriented curve ",
  Cell[BoxData[
      \(\(C\_R\%+\) \((z\_0)\)\)]],
  " and its opposite ",
  Cell[BoxData[
      \(\(C\_R\%-\) \((z\_0)\) = \(-\ \(C\_R\%+\)\) \((z\_0)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.25.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(S = {z : \(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)}\)]],
  ".  ",
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Find the interior of S.  ",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Find the exterior of S.  ",
  StyleBox["(c)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Find boundary of  S."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We show that every point of ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " is an interior point of ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ".  Let ",
  Cell[BoxData[
      \(z\_0\)]],
  " be a point of S.  Then  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_0\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ",  and we can choose  ",
  Cell[BoxData[
      \(\[Epsilon]\  = \ \(\(1\)\(-\)\) | z\_0 | \(\(>\)\(\ \)\(0\)\)\)]],
  ".  We claim that  ",
  Cell[BoxData[
      \(\(D\_\[Epsilon]\) \((z\_0)\) \[Subset] S\)]],
  ".  If  ",
  Cell[BoxData[
      \(z \[Element] \(D\_\[Epsilon]\) \((z\_0)\)\)]],
  ",  then\n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(\(|\)\(z\)\(|\)\), " ", "=", " ", 
        RowBox[{"|", \(z - z\_0 + z\_0\), "|", " ", 
          RowBox[{"\[LessEqual]", " ", 
            RowBox[{"|", \(z - z\_0\), "|", 
              RowBox[{"+", 
                RowBox[{"|", \(z\_0\), "|", 
                  StyleBox["a",
                    FontColor->GrayLevel[1]]}]}]}]}]}]}], 
    "\[IndentingNewLine]", 
      RowBox[{
        "          ", \(\(\(<\)\(\ \ \)\(\(\[Epsilon]\)\(+\)\)\) | 
            z\_0 |  = \ \ \(\(\(1\)\(-\)\) | 
              z\_0 | \(+\(\(|\)\(z\_0\)\(|\)\)\)\  = \ 1\)\)}]}]],
  "\n\nHence the ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  " neighborhood of ",
  Cell[BoxData[
      \(z\_0\)]],
  " is contained in ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ", which shows that ",
  Cell[BoxData[
      \(z\_0\)]],
  " is an interior point of ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ".  \nIt follows that the interior of ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " is the set ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " itself. "
}], "Text"],

Cell[TextData[{
  "\tSimilarly, it can be shown that the exterior of ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " is the set ",
  Cell[BoxData[
      \({z : \(\(|\)\(z\)\(|\)\(\(>\)\(1\)\)\)}\)]],
  ".  The boundary of ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " is the unit circle  ",
  Cell[BoxData[
      \(\(C\_1\) \((0)\)\  = {z : \(\(|\)\(z\)\(|\)\) = 1}\)]],
  ".  This condition is true because if  ",
  Cell[BoxData[
      \(z\_0 = \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\_0\)\)]],
  "  is any point on the circle, then any ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  "-neighborhood of ",
  Cell[BoxData[
      \(z\_0\)]],
  " will contain the point  ",
  Cell[BoxData[
      \(\((1 - \[Epsilon]\/2)\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\_0\
\)\)]],
  ",  which belongs to ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ", and  ",
  Cell[BoxData[
      \(\((1 + \[Epsilon]\/2)\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\_0\
\)\)]],
  ",  which does not belong to ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ".  We leave the details as an exercise."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore Solution 1.25 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Find the interior of ",
  StyleBox["S",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Let  ",
  Cell[BoxData[
      \(z\_0\)]],
  " be a point of  S.  Then  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_0\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  so that we can choose  ",
  Cell[BoxData[
      \(\[Epsilon] = \(\(1\)\(-\)\) | z\_0 | \(\(>\)\(0\)\)\)]],
  ".  If  z  lies in the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z - z\_0\)\(|\)\(\(<\)\(\ \)\(\[Epsilon]\)\)\)\)]],
  ",  then  \n\n",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = \(\(|\)\(z\_0 + z - 
            z\_0\)\(|\)\(\(\[LessEqual]\)\(\ \)\(\(|\)\(z\_0\)\(|\)\(+\(\(|\)\
\(z - z\_0\)\(|\)\(\(<\)\(\ \)\(\(|\)\(z\_0\)\(|\)\(\ \)\(\(+\ \[Epsilon]\)\  \
< \ 1\)\)\)\)\)\)\)\)\)]],
  ".  \n\nHence the ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  "-neighborhood of  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  is contained in  S,  and  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  is an interior point of  S.  It follows that the interior of  S  is the \
open unit disk."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{PointSize[0.03], 
            Point[{0.3, 0.7}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(r = 1 - \@\(0.3\^2 + 0.7\^2\);\)\ \), "\[IndentingNewLine]", 
    \(\(disk\  = \ 
        Graphics[{Yellow, 
            Disk[{0.3, 0.7}, r]}];\)\ \), "\[IndentingNewLine]", 
    \(\(bdd\  = \ Graphics[{Circle[{0, 0}, 1]}];\)\ \), "\n", 
    \(\(Show[bdd, disk, dot, \ 
        PlotRange \[Rule] {{\(-1.5\), 1.5}, {\(-1.5\), 1.5}}, 
        Ticks \[Rule] {Range[\(-1.5\), 1.5, 0.5], 
            Range[\(-1.5\), 1.5, 
              0.5]}, \n\ \ \ \ \ \ \ \ \ \ AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The \[Epsilon]-neighborhood of \!\(z\_0\) is contained \
in S = {z:|z|<1}.\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(int\  = \ Graphics[{Yellow, Disk[{0, 0}, 1]}];\)\ \), "\n", 
    \(\(Show[int, \ PlotRange \[Rule] {{\(-1.5\), 1.5}, {\(-1.5\), 1.5}}, 
        Ticks \[Rule] {Range[\(-1.5\), 1.5, 1.5], 
            Range[\(-1.5\), 1.5, 
              1.5]}, \n\ \ \ \ \ \ \ \ \ \ AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The interior of the set S is the unit disk {z: |z| < \
1}.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore Solution 1.25 (b). ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  " Find the exterior of ",
  StyleBox["S",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  "If  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_0\)\(|\)\(\(>\)\(\ \)\(1\)\)\)\)]],
  " then a similar argument will produce an ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  "-neighborhood of  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  that lies entirely in the region  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(\ \)\(1\)\)\)\)]],
  ",  hence ",
  Cell[BoxData[
      \(z\_0\)]],
  "  is an exterior point of  S.  It follows that the exterior of  S  is the \
open region  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(\ \)\(1\)\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{PointSize[0.03], 
            Point[{0.4, 1.1}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(r = \@\(0.4\^2 + 1.1\^2\) - 1;\)\ \), "\[IndentingNewLine]", 
    \(\(disk\  = \ 
        Graphics[{Cyan, Disk[{0.4, 1.1}, r]}];\)\ \), "\[IndentingNewLine]", 
    \(\(bdd\  = \ Graphics[{Circle[{0, 0}, 1]}];\)\ \), "\n", 
    \(\(Show[bdd, disk, dot, \ 
        PlotRange \[Rule] {{\(-1.5\), 1.5}, {\(-1.5\), 1.5}}, 
        Ticks \[Rule] {Range[\(-1.5\), 1.5, 0.5], 
            Range[\(-1.5\), 1.5, 
              0.5]}, \n\ \ \ \ \ \ \ \ \ \ AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The \[Epsilon]-neighborhood of \!\(z\_0\) is contained \
in the region |z| > 1.\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ext\  = \ 
        Graphics[{{Cyan, 
              Disk[{0, 0}, 3]}, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {White, 
              Disk[{0, 0}, 1]}}];\)\ \), "\n", 
    \(\(Show[ext, \ 
        PlotRange \[Rule] {{\(-1.5\), 1.5}, {\(-1.5\), 
              1.5}}, \n\ \ \ \ \ \ \ \ \ \ AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The exterior of the set S is the open region {z: |z| > \
1}.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore Solution 1.25 (c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Find the boundary of ",
  StyleBox["S",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "If  ",
  Cell[BoxData[
      \(z\_0 = \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\_0\)\)]],
  " is any point on the unit circle, then any ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  "-neighborhood of  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  will contain the point  ",
  Cell[BoxData[
      \(\((1 - \[Epsilon]\/2)\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\_0\
\)\)]],
  ", which belongs to  S,  and  ",
  Cell[BoxData[
      \(\((1 + \[Epsilon]\/2)\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\_0\
\)\)]],
  "  which does not belong to  S.  It follows that the boundary of  S  is the \
unit circle  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = \ 1\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{PointSize[0.03], 
            Point[{0.4, \@\(1 - 0.4\^2\)}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(r = 0.2;\)\ \), "\[IndentingNewLine]", 
    \(\(disk\  = \ 
        Graphics[{YellowBrown, 
            Disk[{0.4, \@\(1 - 0.4\^2\)}, 
              r]}];\)\ \), "\[IndentingNewLine]", 
    \(\(bdd\  = \ Graphics[{Circle[{0, 0}, 1]}];\)\ \), "\n", 
    \(\(Show[disk, bdd, dot, \ 
        PlotRange \[Rule] {{\(-1.5\), 1.5}, {\(-1.5\), 1.5}}, 
        Ticks \[Rule] {Range[\(-1.5\), 1.5, 0.5], 
            Range[\(-1.5\), 1.5, 
              0.5]}, \n\ \ \ \ \ \ \ \ \ \ AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Every \[Epsilon]-neighborhood of \!\(z\_0\) contains \
points of S\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and points that do not belong to S.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(bdd\  = \ 
        Graphics[{Brown, Thickness[0.01], Circle[{0, 0}, 1]}];\)\ \), "\n", 
    \(\(Show[bdd, \ PlotRange \[Rule] {{\(-1.5\), 1.5}, {\(-1.5\), 1.5}}, 
        Ticks \[Rule] {Range[\(-1.5\), 1.5, 0.5], 
            Range[\(-1.5\), 1.5, 
              0.5]}, \n\ \ \ \ \ \ \ \ \ \ AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The boundary of the set S = {z:|z|<1 is the unit circle {z: \
|z| = 1}.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tThe point ",
  Cell[BoxData[
      \(z\_0\)]],
  " is called an accumulation point of the set ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " if, for each ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  ", the punctured disk ",
  Cell[BoxData[
      \(\(D\_\[Epsilon]\%*\) \((z\_0)\)\)]],
  " contains at least one point of ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ".  We ask you to show in the exercises that the set of accumulation points \
of ",
  Cell[BoxData[
      \(\(D\_1\) \((0)\)\)]],
  " is ",
  Cell[BoxData[
      \(\(\(D\_1\)\&_\) \((0)\)\)]],
  ", and that there is only one accumulation point of ",
  Cell[BoxData[
      RowBox[{"S", "=", 
        RowBox[{"{", 
          RowBox[{\(\(\[ImaginaryI]\/n\) : \ n = 1\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "2", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["...",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}], "}"}]}]]],
  ", namely, the point ",
  StyleBox["0",
    FontFamily->"Courier New"],
  ".  \nWe also ask you to prove that a set is closed if and only if it \
contains all of its accumulation points."
}], "Text"],

Cell[TextData[{
  "\tA set ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " is called an open set if every point of ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " is an interior point of  ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ".  Thus, Example 1.25 shows that ",
  Cell[BoxData[
      \(\(D\_1\) \((0)\)\)]],
  " is open.  A set ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " s called a closed set if it contains all its boundary points.  A set ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " is said to be a connected set if every pair of points ",
  Cell[BoxData[
      RowBox[{\(z\_1\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(z\_2\)}]]],
  " contained in ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " can be joined by a curve that lies entirely in ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ".  Roughly speaking, a connected set consists of a \"single piece.\"   The \
unit disk  ",
  Cell[BoxData[
      \(\(D\_1\) \((0)\) = {z : \(\(|\)\(z || \(\(<\)\(1\)\)\)\)}\)]],
  "  is a connected open set.  We ask you to verify in the exercises that, if \
",
  Cell[BoxData[
      RowBox[{\(z\_1\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(z\_2\)}]]],
  " lie in ",
  Cell[BoxData[
      \(\(D\_1\) \((0)\)\)]],
  ", then the straight-line segment joining them lies entirely in ",
  Cell[BoxData[
      \(\(D\_1\) \((0)\)\)]],
  ".  The annulus  ",
  Cell[BoxData[
      \(A = {z : \ \(\(1\)\(<\)\) | z | \(\(<\)\(2\)\)}\)]],
  "  is a connected open set because any two points in A can be joined by a \
curve C that lies entirely in A, as shown in Figure 1.26.  The set  ",
  Cell[BoxData[
      RowBox[{"B", "=", 
        RowBox[{"{", 
          RowBox[{"z", ":", 
            RowBox[{"|", \(z + 2\), "|", 
              RowBox[{"<", 
                RowBox[{"1", "  ", 
                  StyleBox["or",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]}], " ", "|", \(z - 2\), 
              "|", \(\(<\)\(1\)\)}]}], "}"}]}]]],
  "  consists of two disjoint disks.  We leave it as an exercise for you to \
show that the set is not connected, as shown in Figure 1.27."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005>0000fR000`400?l0
0000o`00003oo`3ooom?0?ooo`00o`3ooom?0?ooo`00o`3ooom?0?ooo`00
o`3ooom?0?ooo`00o`3ooom?0?ooo`00cP3oool00`000000oooo0?ooo`1m
0?ooo`00cP3oool00`000000oooo0?ooo`1m0?ooo`00cP3oool00`000000
oooo0?ooo`1m0?ooo`00cP3oool00`000000oooo0?ooo`1m0?ooo`00cP3o
ool00`000000oooo0?ooo`1m0?ooo`00cP3oool00`000000oooo0?ooo`1m
0?ooo`00cP3oool00`000000oooo0?ooo`1m0?ooo`00cP3oool00`000000
oooo0?ooo`1m0?ooo`00cP3oool00`000000oooo0?ooo`1m0?ooo`00cP3o
ool00`000000oooo0?ooo`1m0?ooo`00cP3oool00`000000oooo0?ooo`1m
0?ooo`00b@3oool00`00o`00oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<00?l00?ooo`3oool0N03oool00<40oooo2000o`050?3ol003
0000003`oo00l?o`00<0l?o`2000o`1b0?ooo`00_`3oool2003o00d0l?o`
00<000000?3ol03`oo002`3`oo000`00o`00oooo0?ooo`1_0?ooo`00^@3o
oolE0?3ol0030000003`oo00l?o`0180l?o`J`3oool00;D0oooo0P00o`0G
0?3ol0030000003`oo00l?o`01D0l?o`0`00o`1U0?ooo`00/`3oool2003o
01T0l?o`00<000000?3ol03`oo00603`oo02003o06<0oooo002^0?ooo`D0
0?l06`3`oo000`000000l?o`0?3ol00J0?3ol0@00?l0G`3oool00:`0oooo
00<0l?o`003o003`oo007`3`oo000`000000l?o`0?3ol00N0?3ol003003o
003oool0oooo05`0oooo002[0?ooob<0l?o`00<000000?3ol03`oo008@3`
oo1L0?ooo`00Z@3ooolU0?3ol0030000003`oo00l?o`02<0l?o`FP3oool0
0:L0oooo9`3`oo000`000000l?o`0?3ol00U0?3ol5P0oooo002T0?ooo`03
003o003`oo00l?o`02L0l?o`00<000000?3ol03`oo009P3`oo000`3oool0
0?l00?ooo`1D0?ooo`00X`3oool00`00o`00l?o`0?3ol00X0?3ol0030000
003`oo00l?o`02P0l?o`00<00?l00?ooo`3oool0DP3oool00:40oooo0P00
o`0[0?3ol0030000003`oo00l?o`02T0l?o`0P00o`1B0?ooo`00W`3oool2
003o02d0l?o`00<000000?3ol03`oo00:`3`oo02003o0500oooo002M0?oo
o`800?l0;`3`oo000`000000l?o`0?3ol00]0?3ol0800?l0CP3oool009`0
oooo00<00?l00?3ol03`oo00;`3`oo000`000000l?o`0?3ol00_0?3ol003
003o003oool0oooo04/0oooo002L0?oooc80l?o`00<000000?3ol03`oo00
<03`oo1=0?ooo`00VP3ooold0?3ol0030000003`oo00l?o`0340l?o`C03o
ool009P0oooo=P3`oo000`000000l?o`0?3ol00c0?3ol4X0oooo002G0?oo
ocL0l?o`00<000000?3ol03`oo00=03`oo190?ooo`00UP3ooolh0?3ol003
0000003`oo00l?o`03D0l?o`B03oool009D0oooo>@3`oo000`000000l?o`
0?3ol00f0?3ol0030?ooo`00o`00oooo04@0oooo002C0?ooo`800?l0>@3`
oo000`000000l?o`0?3ol00h0?3ol003003o003oool0oooo0480oooo002B
0?ooo`03003o003`oo00l?o`03T0l?o`00<000000?3ol03`oo00>03`oo00
0`00o`00oooo0?ooo`120?ooo`00TP3oool00`00o`00l?o`0?3ol00i0?3o
l0030000003`oo00l?o`03T0l?o`00<00?l00?ooo`3oool0@@3oool00900
oooo0P00o`0l0?3ol0030000003`oo00l?o`03X0l?o`0P00o`110?ooo`00
S`3oool00`00o`00l?o`0?3ol00l0?3ol0030000003`oo00l?o`03/0l?o`
00<00?l00?ooo`3oool0?`3oool008l0oooo00<00?l00?3ol03`oo00?03`
oo000`000000l?o`0?3ol00l0?3ol003003o003oool0oooo03h0oooo002=
0?ooo`800?l0?`3`oo000`000000l?o`0?3ol00m0?3ol0800?l0?P3oool0
08d0oooo@@3`oo000`000000l?o`0?3ol00n0?3ol3l0oooo002<0?oood80
l?o`00<000000?3ol03`oo00?`3`oo0n0?ooo`00R`3ooolO0?3ol0<00000
8@3`oo000`000000l?o`0?3ol0100?3ol3d0oooo002:0?oooaT0l?o`1@00
00020?3ol0030000003`oo00l?o`0240l?o`00<000000?3ol03`oo00@@3`
oo0l0?ooo`00RP3ooolJ0?3ol0040000003`oo00l?o`000000<0l?o`00<0
00000?3ol03`oo00803`oo000`000000l?o`0?3ol0120?3ol3/0oooo0029
0?oooa`0l?o`00<000000?3ol03`oo000`3`oo000`000000l?o`0?3ol00P
0?3ol0030000003`oo00l?o`0480l?o`>`3oool008P0oooo7P3`oo001`00
0000l?o`0?3ol03`oo0000000?3ol00000008@3`oo000`000000l?o`0?3o
l0130?3ol3X0oooo00270?ooo`03003o003`oo00l?o`01@0l?o`0P3o0004
0?3ol0040000003`oo00l?o`000000<0l?o`00<000000?3ol03`oo00803`
oo000`000000l?o`0?3ol0140?3ol003003o003oool0oooo03H0oooo0027
0?ooo`03003o003`oo00l?o`01<0l?o`103o00030?3ol0D000009@3`oo00
0`000000l?o`0?3ol00X0?3ol0<000000P3`oo03000001D0l?o`00<00?l0
0?ooo`3oool0=@3oool008H0oooo00<00?l00?3ol03`oo004`3`oo060?l0
02`0l?o`00<000000?3ol03`oo00:@3`oo000`000000l?o`0?3ol0020?3o
l0030000003`oo00l?o`01@0l?o`00<00?l00?ooo`3oool0=@3oool008D0
oooo00<00?l00?3ol03`oo00503`oo060?l002`0l?o`00<000000?3ol03`
oo00:P3`oo04000001P0l?o`00<00?l00?ooo`3oool0=03oool008@0oooo
00<00?l00?3ol03`oo005P3`oo040?l002d0l?o`00<000000?3ol03`oo00
:P3`oo0010000000l?o`0?3ol000000H0?3ol003003o003oool0oooo03@0
oooo00240?ooo`03003o003`oo00l?o`01D0l?o`00@0o`3o0?3ol03o0000
o`00;P3`oo000`000000l?o`0?3ol00Z0?3ol0040000003`oo00l?o`0000
01T0l?o`00<00?l00?ooo`3oool0<`3oool008<0oooo00<00?l00?3ol03`
oo005@3`oo000`3o0?l0l?o`0?3ol00`0?3ol0030000003`oo00l?o`02/0
l?o`0P00000J0?3ol003003o003oool0oooo03<0oooo00230?ooo`03003o
003`oo00l?o`01@0l?o`00<0o`3o0?3ol03`oo00:P3`oo07003o00030000
0000o`000?l002/0l?o`0P00000K0?3ol003003o003oool0oooo0380oooo
00220?ooo`03003o003`oo00l?o`01D0l?o`00<0o`3o0?3ol03`oo009`3`
oo0:0?ooo`030000003oool0oooo00L0oooo0P3`oo000`00o`00l?o`0?3o
l00N0?3ol0<00000703`oo000`00o`00oooo0?ooo`0a0?ooo`00PP3ooolG
0?3ol0030?l0o`3`oo00l?o`02@0l?o`3P3oool00`000000oooo0?ooo`0:
0?ooo`800?l0?P3`oo0c0?ooo`00P@3ooolH0?3ol0030?l0o`3`oo00l?o`
0200l?o`0P00o`0@0?ooo`030000003oool0oooo00`0oooo1000o`0j0?3o
l3<0oooo00210?oooaP0l?o`00<0o`3o0?3ol03`oo007P3`oo02003o0180
oooo00<000000?ooo`3oool0403oool2003o03T0l?o`<P3oool00800oooo
603`oo000`3o0?l0l?o`0?3ol00M0?3ol0800?l0503oool00`000000oooo
0?ooo`0B0?ooo`03003o003`oo00l?o`03H0l?o`<P3oool00800oooo5`3`
oo000`3o0?l0l?o`0?3ol00M0?3ol003003o003oool0oooo01@0oooo00<0
00000?ooo`3oool05@3ooolg0?3ol340oooo001o0?oooaP0l?o`00<0o`3o
0?3ol03`oo00703`oo000`00o`00oooo0?ooo`0E0?ooo`030000003oool0
oooo01H0oooo=P3`oo0a0?ooo`00O`3ooolG0?3ol0030?l0o`3`oo00l?o`
01`0l?o`00<00?l00?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?oo
ocL0l?o`<03oool007h0oooo5`3`oo000`3o0?l0l?o`0?3ol00K0?3ol1/0
oooo00<000000?ooo`3oool0603ooole0?3ol300oooo001n0?ooo`03003o
003`oo00l?o`01@0l?o`00<0o`3o0?3ol03`oo006@3`oo0M0?ooo`030000
003oool0oooo01X0oooo<`3`oo000`00o`00oooo0?ooo`0]0?ooo`00OP3o
ool00`00o`00l?o`0?3ol00D0?3ol0030?l0o`3`oo00l?o`01T0l?o`7@3o
ool00`000000oooo0?ooo`0J0?ooo`03003o003`oo00l?o`0340l?o`00<0
0?l00?ooo`3oool0;03oool007d0oooo00<00?l00?3ol03`oo005@3`oo00
0`3o0?l0l?o`0?3ol00H0?3ol1h0oooo00<000000?ooo`3oool06`3oool0
0`00o`00l?o`0?3ol00`0?3ol003003o003oool0oooo02`0oooo001m0?oo
o`03003o003`oo00l?o`01@0l?o`00<0o`3o0?3ol03`oo005`3`oo0P0?oo
o`030000003oool0oooo01`0oooo0P00o`0`0?3ol003003o003oool0oooo
02`0oooo001l0?ooo`03003o003`oo00l?o`01@0l?o`00<0o`3o0?3ol03`
oo00603`oo000`00o`00oooo0?ooo`0M0?ooo`030000003oool0oooo01d0
oooo00<00?l00?3ol03`oo00;P3`oo000`00o`00oooo0?ooo`0/0?ooo`00
O03oool00`00o`00l?o`0?3ol00D0?3ol0030?l0o`3`oo00l?o`01L0l?o`
00<00?l00?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`03003o
003`oo00l?o`02h0l?o`00<00?l00?ooo`3oool0:`3oool007/0oooo00<0
0?l00?3ol03`oo005@3`oo000`3o0?l0l?o`0?3ol00F0?3ol003003o003o
ool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`00o`00l?o`0?3o
l00]0?3ol003003o003oool0oooo02/0oooo001k0?ooo`03003o003`oo00
l?o`01D0l?o`00<0o`3o0?3ol03`oo005P3`oo000`00o`00oooo0?ooo`0O
0?ooo`030000003oool0oooo0200oooo00<00?l00?3ol03`oo00;@3`oo00
0`00o`00oooo0?ooo`0Z0?ooo`00N`3oool00`00o`00l?o`0?3ol00D0?3o
l0030?l0o`3`oo00l?o`01D0l?o`0P00o`0R0?ooo`030000003oool0oooo
0200oooo00<00?l00?3ol03`oo00;@3`oo000`00o`00oooo0?ooo`0Z0?oo
o`00N`3oool00`00o`00l?o`0?3ol00C0?3ol0030?l0o`3`oo00l?o`01D0
l?o`00<00?l00?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?ooobh0
l?o`00<00?l00?ooo`3oool0:P3oool007/0oooo5P3`oo000`3o0?l0l?o`
0?3ol00E0?3ol003003o003oool0oooo0280oooo00<000000?ooo`3oool0
8P3oool_0?3ol2`0oooo001j0?oooaL0l?o`00<0o`3o0?3ol03`oo00503`
oo000`00o`00oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo;P3`
oo0/0?ooo`00NP3ooolG0?3ol0030?l0o`3`oo00l?o`01@0l?o`00<00?l0
0?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooobh0l?o`;03oool0
07X0oooo5`3`oo000`3o0?l0l?o`0?3ol00D0?3ol2H0oooo00<000000?oo
o`3oool0903oool]0?3ol2`0oooo001j0?oooaH0l?o`00<0o`3o0?3ol03`
oo00503`oo0W0?ooo`030000003oool0oooo02@0oooo;@3`oo0/0?ooo`00
NP3ooolF0?3ol0030?l0o`3`oo00l?o`01@0l?o`9`3oool00`000000oooo
0?ooo`0U0?ooobd0l?o`:`3oool007T0oooo5`3`oo000`3o0?l0l?o`0?3o
l00C0?3ol2P0oooo00<000000?ooo`3oool09@3oool00`00o`00l?o`0?3o
l00Z0?3ol2/0oooo001i0?oooaL0l?o`00<0o`3o0?3ol03`oo004`3`oo0X
0?ooo`030000003oool0oooo02D0oooo00<00?l00?3ol03`oo00:P3`oo0[
0?ooo`00N@3ooolF0?3ol0030?l0o`3`oo00l?o`01<0l?o`:@3oool00`00
0000oooo0?ooo`0V0?ooo`03003o003`oo00l?o`02T0l?o`00<00?l00?oo
o`3oool0:03oool007T0oooo00<00?l00?3ol03`oo004`3`oo000`3o0?l0
l?o`0?3ol00C0?3ol2T0oooo00<000000?ooo`3oool09P3oool00`00o`00
l?o`0?3ol00Y0?3ol003003o003oool0oooo02P0oooo001i0?ooo`03003o
003`oo00l?o`01<0l?o`00<0o`3o0?3ol03`oo004`3`oo0Y0?ooo`030000
003oool0oooo02H0oooo00<00?l00?3ol03`oo00:P3`oo000`00o`00oooo
0?ooo`0W0?ooo`00N03oool00`00o`00l?o`0?3ol00D0?3ol0030?l0o`3`
oo00l?o`0180l?o`00<00?l00?ooo`3oool09`3oool00`000000oooo0?oo
o`0V0?ooo`03003o003`oo00l?o`02X0l?o`00<00?l00?ooo`3oool09`3o
ool007P0oooo00<00?l00?3ol03`oo00503`oo000`3o0?l0l?o`0?3ol00B
0?3ol003003o003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool0
0`00o`00l?o`0?3ol00Y0?3ol003003o003oool0oooo02L0oooo001h0?oo
o`03003o003`oo00l?o`01@0l?o`00<0o`3o0?3ol03`oo004P3`oo000`00
o`00oooo0?ooo`0W0?ooo`030000003oool0oooo02L0oooo00<00?l00?3o
l03`oo00:@3`oo000`00o`00oooo0?ooo`0W0?ooo`00N03oool00`00o`00
l?o`0?3ol00D0?3ol0030?l0o`3`oo00l?o`0180l?o`00<00?l00?ooo`3o
ool09`3oool00`000000oooo0?ooo`0W0?ooo`03003o003`oo00l?o`02T0
l?o`00<00?l00?ooo`3oool09`3oool007P0oooo00<00?l00?3ol03`oo00
503`oo000`3o0?l0l?o`0?3ol00A0?3ol003003o003oool0oooo02P0oooo
00<000000?ooo`3oool09`3oool00`00o`00l?o`0?3ol00Y0?3ol003003o
003oool0oooo02L0oooo001h0?ooo`03003o003`oo00l?o`01@0l?o`00<0
o`3o0?3ol03`oo004@3`oo000`00o`00oooo0?ooo`0X0?ooo`030000003o
ool0oooo0280oooo1@0000000`3oool00?l00?3ol00Y0?3ol003003o003o
ool0oooo00@000008`3oool007P0oooo00<00?l00?3ol03`oo00503`oo00
0`3o0?l0l?o`0?3ol00A0?3ol003003o003oool0oooo02P0oooo00<00000
0?ooo`3oool0903oool010000000oooo0?ooo`3oool[0?3ol004003o003o
ool0oooo000002H0oooo001h0?ooo`03003o003`oo00l?o`01@0l?o`00<0
o`3o0?3ol03`oo004@3`oo000`00o`00oooo0?ooo`0X0?ooo`030000003o
ool0oooo02@0oooo00@000000?ooo`3oool0oooo:`3`oo001@00o`00oooo
0?ooo`3oool0000002D0oooo001h0?ooo`03003o003`oo00l?o`01<0l?o`
00<0o`3o0?3ol03`oo004P3`oo000`00o`00oooo0?ooo`0X0?ooo`030000
003oool0oooo02@0oooo00@000000?ooo`3oool0oooo;03`oo040?ooo`03
0000003oool0oooo0280oooo001h0?ooo`03003o003`oo00l?o`01<0l?o`
00<0o`3o0?3ol03`oo004P3`oo000`00o`00oooo0?ooo`0X0?ooo`030000
003oool0oooo02@0oooo00@000000?ooo`3oool0oooo;03`oo020?ooo`04
0000003oool0oooo000002<0oooo001h0?ooo`03003o003`oo00l?o`01<0
l?o`00<0o`3o0?3ol03`oo004P3`oo000`00o`00oooo0?ooo`0X0?ooo`03
0000003oool0oooo02<0oooo0P0000030?ooob`0l?o`0`3oool2000000`0
oooo0P0000000`3oool000000000000C0?ooo`00N03oool00`00o`00l?o`
0?3ol00C0?3ol0030?l0o`3`oo00l?o`0180l?o`00<00?l00?ooo`3oool0
:03oool00`000000oooo0?ooo`0X0?ooob`0l?o`4P3oool00`000000oooo
0000000D0?ooo`00K@3oooo3000000P0oooo00<000000?ooo`3oool04`3o
ool007P0oooo5P3`oo000`3o0?l0l?o`0?3ol00B0?3ol2/0oooo00<00000
0?ooo`3oool0:03oool00`00o`00l?o`0?3ol00Y0?3ol003003o003oool0
oooo00h0oooo0P0000000`3oool000000000000C0?ooo`00N03ooolG0?3o
l0030?l0o`3`oo00l?o`0140l?o`:`3oool00`000000oooo0?ooo`0X0?oo
o`03003o003`oo00l?o`02T0l?o`00<00?l00?ooo`3oool09P3oool007P0
oooo5`3`oo000`3o0?l0l?o`0?3ol00A0?3ol2/0oooo00<000000?ooo`3o
ool0:03oool00`00o`00l?o`0?3ol00X0?3ol003003o003oool0oooo02L0
oooo001h0?oooaL0l?o`00<0o`3o0?3ol03`oo004@3`oo0[0?ooo`030000
003oool0oooo02P0oooo00<00?l00?3ol03`oo00:03`oo000`00o`00oooo
0?ooo`0W0?ooo`00N03ooolG0?3ol0030?l0o`3`oo00l?o`0140l?o`:`3o
ool00`000000oooo0?ooo`0X0?ooo`03003o003`oo00l?o`02P0l?o`00<0
0?l00?ooo`3oool09`3oool007P0oooo5`3`oo000`3o0?l0l?o`0?3ol00A
0?3ol2/0oooo00<000000?ooo`3oool0:03oool00`00o`00l?o`0?3ol00X
0?3ol003003o003oool0oooo02L0oooo001h0?oooaL0l?o`00<0o`3o0?3o
l03`oo004P3`oo0Z0?ooo`030000003oool0oooo02L0oooo00<00?l00?3o
l03`oo00:@3`oo000`00o`00oooo0?ooo`0W0?ooo`00N03ooolG0?3ol003
0?l0o`3`oo00l?o`0180l?o`:P3oool00`000000oooo0?ooo`0W0?ooo`03
003o003`oo00l?o`02T0l?o`00<00?l00?ooo`3oool09`3oool007P0oooo
00<00?l00?3ol03`oo00503`oo000`3o0?l0l?o`0?3ol00B0?3ol003003o
003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`00o`00l?o`
0?3ol00Y0?3ol003003o003oool0oooo02L0oooo001h0?ooo`03003o003`
oo00l?o`01D0l?o`00<0o`3o0?3ol03`oo004@3`oo000`00o`00oooo0?oo
o`0W0?ooo`030000003oool0oooo02L0oooo;03`oo000`00o`00oooo0?oo
o`0W0?ooo`00N03oool00`00o`00l?o`0?3ol00E0?3ol0030?l0o`3`oo00
l?o`0140l?o`00<00?l00?ooo`3oool09`3oool00`000000oooo0?ooo`0W
0?ooob`0l?o`:P3oool007P0oooo00<00?l00?3ol03`oo005@3`oo000`3o
0?l0l?o`0?3ol00B0?3ol003003o003oool0oooo02H0oooo00<000000?oo
o`3oool09`3oool/0?3ol2X0oooo001i0?ooo`03003o003`oo00l?o`01@0
l?o`00<0o`3o0?3ol03`oo004P3`oo000`00o`00oooo0?ooo`0V0?ooo`03
0000003oool0oooo02H0oooo;@3`oo0Z0?ooo`00N@3oool00`00o`00l?o`
0?3ol00D0?3ol0030?l0o`3`oo00l?o`0180l?o`00<00?l00?ooo`3oool0
9P3oool00`000000oooo0?ooo`0V0?ooobd0l?o`:P3oool007T0oooo00<0
0?l00?3ol03`oo00503`oo000`3o0?l0l?o`0?3ol00B0?3ol003003o003o
ool0oooo02H0oooo00<000000?ooo`3oool09P3oool/0?3ol2/0oooo001i
0?ooo`03003o003`oo00l?o`01D0l?o`00<0o`3o0?3ol03`oo004@3`oo00
0`00o`00oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo;03`oo0[
0?ooo`00N@3oool00`00o`00l?o`0?3ol00E0?3ol0030?l0o`3`oo00l?o`
0180l?o`00<00?l00?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?oo
obd0l?o`:`3oool007X0oooo00<00?l00?3ol03`oo00503`oo000`3o0?l0
l?o`0?3ol00C0?3ol003003o003oool0oooo02@0oooo00<000000?ooo`3o
ool09@3oool]0?3ol2/0oooo001j0?oooaP0l?o`00<0o`3o0?3ol03`oo00
4P3`oo0W0?ooo`030000003oool0oooo02@0oooo00<00?l00?3ol03`oo00
:P3`oo000`00o`00oooo0?ooo`0Y0?ooo`00NP3ooolH0?3ol0030?l0o`3`
oo00l?o`01<0l?o`9P3oool00`000000oooo0?ooo`0S0?ooo`03003o003`
oo00l?o`02/0l?o`00<00?l00?ooo`3oool0:@3oool007X0oooo603`oo00
0`3o0?l0l?o`0?3ol00D0?3ol2D0oooo00<000000?ooo`3oool08P3oool0
0`00o`00l?o`0?3ol00/0?3ol003003o003oool0oooo02T0oooo001k0?oo
oaP0l?o`00<0o`3o0?3ol03`oo004`3`oo0U0?ooo`030000003oool0oooo
0280oooo00<00?l00?3ol03`oo00:`3`oo000`00o`00oooo0?ooo`0Z0?oo
o`00N`3ooolH0?3ol0030?l0o`3`oo00l?o`01@0l?o`903oool00`000000
oooo0?ooo`0Q0?ooo`03003o003`oo00l?o`02`0l?o`00<00?l00?ooo`3o
ool0:P3oool007/0oooo603`oo000`3o0?l0l?o`0?3ol00D0?3ol2@0oooo
00<000000?ooo`3oool08@3oool00`00o`00l?o`0?3ol00/0?3ol003003o
003oool0oooo02X0oooo001k0?oooaP0l?o`00<0o`3o0?3ol03`oo005@3`
oo0S0?ooo`030000003oool0oooo0200oooo00<00?l00?3ol03`oo00;@3`
oo000`00o`00oooo0?ooo`0Z0?ooo`00O03ooolH0?3ol0030?l0o`3`oo00
l?o`01D0l?o`8P3oool00`000000oooo0?ooo`0P0?ooo`03003o003`oo00
l?o`02`0l?o`00<00?l00?ooo`3oool0:`3oool007`0oooo6@3`oo000`3o
0?l0l?o`0?3ol00D0?3ol003003o003oool0oooo01l0oooo00<000000?oo
o`3oool07`3oool00`00o`00l?o`0?3ol00]0?3ol003003o003oool0oooo
02/0oooo001l0?ooo`03003o003`oo00l?o`01H0l?o`00<0o`3o0?3ol03`
oo005@3`oo000`00o`00oooo0?ooo`0N0?ooo`030000003oool0oooo01h0
oooo<@3`oo000`00o`00oooo0?ooo`0[0?ooo`00O@3oool00`00o`00l?o`
0?3ol00F0?3ol0030?l0o`3`oo00l?o`01D0l?o`00<00?l00?ooo`3oool0
7@3oool00`000000oooo0?ooo`0M0?oooc40l?o`;`3oool007d0oooo00<0
0?l00?3ol03`oo005P3`oo000`3o0?l0l?o`0?3ol00F0?3ol003003o003o
ool0oooo01`0oooo00<000000?ooo`3oool0703ooolU0?3ol0D00000203`
oo0_0?ooo`00OP3oool00`00o`00l?o`0?3ol00E0?3ol0030?l0o`3`oo00
l?o`01L0l?o`00<00?l00?ooo`3oool06`3oool00`000000oooo0?ooo`0K
0?ooobP0l?o`00<000000?3ol03`oo00203`oo0_0?ooo`00OP3oool00`00
o`00l?o`0?3ol00F0?3ol0030?l0o`3`oo00l?o`01L0l?o`00<00?l00?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooob40l?o`1@0000030?3o
l0030000003`oo00l?o`00P0l?o`;`3oool007h0oooo00<00?l00?3ol03`
oo005P3`oo000`3o0?l0l?o`0?3ol00H0?3ol0800?l06P3oool00`000000
oooo0?ooo`0I0?ooob<0l?o`00@000000?3ol03`oo0000000`3`oo000`00
0000l?o`0?3ol0070?3ol300oooo001n0?ooo`03003o003`oo00l?o`01L0
l?o`00<0o`3o0?3ol03`oo00603`oo0K0?ooo`030000003oool0oooo01P0
oooo00<00?l00?3ol03`oo008P3`oo000`000000l?o`0?3ol0030?3ol003
0000003`oo00l?o`00L0l?o`<03oool007l0oooo00<00?l00?3ol03`oo00
5`3`oo000`3o0?l0l?o`0?3ol00I0?3ol1T0oooo00<000000?ooo`3oool0
5P3oool2003o02H0l?o`00@000000?3ol03`oo00l?o`0P0000080?3ol340
oooo001o0?ooo`03003o003`oo00l?o`01L0l?o`00<0o`3o0?3ol03`oo00
6`3`oo0G0?ooo`030000003oool0oooo01D0oooo00<00?l00?3ol03`oo00
903`oo0010000000l?o`0?3ol000000<0?3ol340oooo00200?ooo`03003o
003`oo00l?o`01L0l?o`00<0o`3o0?3ol03`oo006`3`oo0F0?ooo`030000
003oool0oooo01<0oooo0P00o`0W0?3ol0D000002P3`oo000`00o`00oooo
0?ooo`0_0?ooo`00P@3ooolJ0?3ol0030?l0o`3`oo00l?o`01`0l?o`503o
ool00`000000oooo0?ooo`0A0?ooo`800?l0=`3`oo000`00o`00oooo0?oo
o`0`0?ooo`00P@3ooolJ0?3ol0030?l0o`3`oo00l?o`01d0l?o`0P00o`0A
0?ooo`030000003oool0oooo00l0oooo00<0l?o`003o003`oo00>03`oo00
0`00o`00oooo0?ooo`0`0?ooo`00PP3ooolJ0?3ol0030?l0o`3`oo00l?o`
01h0l?o`0P00o`0?0?ooo`030000003oool0oooo00d0oooo?03`oo000`00
o`00oooo0?ooo`0a0?ooo`00PP3ooolK0?3ol0030?l0o`3`oo00l?o`01l0
l?o`1000o`0;0?ooo`030000003oool0oooo00/0oooo<P3`oo020000o`03
0?l0o`3`oo00l?o`00L0l?o`00<00?l00?ooo`3oool0<@3oool008<0oooo
6P3`oo000`3o0?l0l?o`0?3ol00S0?3ol0800?l02@3oool00`000000oooo
0?ooo`040?ooo`@00?l0=03`oo040000o`P0l?o`00<00?l00?ooo`3oool0
<P3oool008<0oooo6`3`oo000`3o0?l0l?o`0?3ol00X0?3ol0D0oooo00<0
0000003o0000o`001000o`0g0?3ol0H0003o1`3`oo000`00o`00oooo0?oo
o`0b0?ooo`00Q03ooolK0?3ol0030?l0o`3`oo00l?o`02`0l?o`00<00000
0?3ol03`oo00>`3`oo060000o`H0l?o`00<00?l00?ooo`3oool0<`3oool0
08@0oooo00<0l?o`003o003`oo006@3`oo000`3o0?l0l?o`0?3ol00[0?3o
l0030000003`oo00l?o`03`0l?o`10000?l70?3ol003003o003oool0oooo
03<0oooo00250?ooo`03003o003`oo00l?o`01T0l?o`00<0o`3o0?3ol03`
oo00:P3`oo000`000000l?o`0?3ol00l0?3ol0030?l0o`000?l0003o00L0
l?o`00<00?l00?ooo`3oool0=03oool008D0oooo00<00?l00?3ol03`oo00
6P3`oo000`3o0?l0l?o`0?3ol00Y0?3ol0030000003`oo00l?o`03/0l?o`
00<0o`3o0?3ol03`oo00203`oo0g0?ooo`00QP3oool2003o01/0l?o`00<0
o`3o0?3ol03`oo00:03`oo000`000000l?o`0?3ol00i0?3ol080o`3o2P3`
oo0h0?ooo`00Q`3oool00`00o`00l?o`0?3ol00J0?3ol0030?l0o`3`oo00
l?o`02L0l?o`00<000000?3ol03`oo00>03`oo000`3o0?l0l?o`0?3ol009
0?3ol3T0oooo00280?ooo`03003o003`oo00l?o`01X0l?o`00<0o`3o0?3o
l03`oo009P3`oo000`000000l?o`0?3ol00g0?3ol0030?l0o`3`oo00l?o`
00T0l?o`>P3oool008P0oooo00<00?l00?3ol03`oo006`3`oo000`3o0?l0
l?o`0?3ol00U0?3ol0030000003`oo00l?o`03L0l?o`00<0o`3o0?3ol03`
oo002@3`oo0j0?ooo`00R@3oool00`00o`00l?o`0?3ol00K0?3ol0030?l0
o`3`oo00l?o`02@0l?o`00<000000?3ol03`oo00=P3`oo000`3o0?l0l?o`
0?3ol0090?3ol3/0oooo002:0?ooo`03003o003`oo00l?o`01/0l?o`00<0
o`3o0?3ol03`oo008`3`oo000`000000l?o`0?3ol00d0?3ol080o`3o303`
oo0k0?ooo`00RP3ooolO0?3ol080o`3o8`3`oo000`000000l?o`0?3ol00c
0?3ol0030?l0o`3`oo00l?o`00/0l?o`00<00?l00?ooo`3oool0>@3oool0
08`0oooo7`3`oo000`3o0?l0l?o`0?3ol00P0?3ol0030000003`oo00l?o`
0340l?o`0P3o0?l<0?3ol0800?l0?03oool008d0oooo7`3`oo020?l0ob00
l?o`00<000000?3ol03`oo00<03`oo000`3o0?l0l?o`0?3ol00;0?3ol003
003o003oool0oooo03`0oooo002=0?ooob40l?o`00<0o`3o0?3ol03`oo00
7@3`oo000`000000l?o`0?3ol00^0?3ol080o`3o3P3`oo000`00o`00oooo
0?ooo`0l0?ooo`00SP3ooolQ0?3ol080o`3o7@3`oo000`000000l?o`0?3o
l00]0?3ol0030?l0o`3`oo00l?o`00d0l?o`00<00?l00?ooo`3oool0?@3o
ool008l0oooo8P3`oo000`3o0?l0l?o`0?3ol00J0?3ol0030000003`oo00
l?o`02/0l?o`0P3o0?l?0?3ol003003o003oool0oooo03h0oooo002@0?oo
ob80l?o`00<0o`3o0?3ol03`oo006@3`oo000`000000l?o`0?3ol00Z0?3o
l0030?l0o`3`oo00l?o`00h0l?o`00<00?l00?ooo`3oool0?`3oool00940
oooo00<00?l00?3ol03`oo007`3`oo020?l0oaT0l?o`00<000000?3ol03`
oo00:@3`oo000`3o0?l0l?o`0?3ol00>0?3ol003003o003oool0oooo0400
oooo002B0?ooo`03003o003`oo00l?o`0200l?o`0`3o0?lF0?3ol0030000
003`oo00l?o`02L0l?o`0P3o0?l@0?3ol4@0oooo002C0?ooo`03003o003`
oo00l?o`0280l?o`00<0o`3o0?3ol03`oo004`3`oo000`000000l?o`0?3o
l00T0?3ol0<0o`3o4@3`oo150?ooo`00U03oool00`00o`00l?o`0?3ol00R
0?3ol080o`3o4`3`oo000`000000l?o`0?3ol00R0?3ol080o`3o4`3`oo16
0?ooo`00U@3oool00`00o`00l?o`0?3ol00S0?3ol0<0o`3o403`oo000`00
0000l?o`0?3ol00O0?3ol0<0o`3o503`oo170?ooo`00UP3oool00`00o`00
l?o`0?3ol00U0?3ol0@0o`3o303`oo000`000000l?o`0?3ol00M0?3ol080
o`3o5P3`oo180?ooo`00U`3oool2003o02T0l?o`0`3o0?l90?3ol0030000
003`oo00l?o`01X0l?o`0`3o0?lF0?3ol4X0oooo002I0?ooob`0l?o`103o
0?l50?3ol0030000003`oo00l?o`01D0l?o`1@3o0?lH0?3ol0030?ooo`00
o`00oooo04P0oooo002J0?ooobl0l?o`1@3o0?l00`000000o`3o0?3ol00>
0?3ol0L0o`3o703`oo02003o04X0oooo002L0?oooc80l?o`00<000000?3o
l03o0?l03P3o0?lR0?3ol003003o003oool0oooo04X0oooo002M0?oooc40
l?o`00<000000?3ol03`oo00;P3`oo02003o04d0oooo002O0?ooobl0l?o`
00<000000?3ol03`oo00;03`oo02003o04l0oooo002P0?ooo`03003o003`
oo00l?o`02/0l?o`00<000000?3ol03`oo00:`3`oo000`00o`00oooo0?oo
o`1?0?ooo`00X@3oool00`00o`00l?o`0?3ol00Z0?3ol0030000003`oo00
l?o`02X0l?o`D`3oool00:80oooo0P00o`0Z0?3ol0030000003`oo00l?o`
02P0l?o`E@3oool00:@0oooo0P00o`0X0?3ol0030000003`oo00l?o`02H0
l?o`E`3oool00:H0oooo0P00o`0V0?3ol0030000003`oo00l?o`02D0l?o`
F03oool00:P0oooo00<00?l00?3ol03`oo008`3`oo000`000000l?o`0?3o
l00R0?3ol003003o003oool0oooo05P0oooo002Z0?ooob@0l?o`00<00000
0?3ol03`oo007`3`oo03003o05/0oooo002^0?ooob00l?o`00<000000?3o
l03`oo007@3`oo02003o05h0oooo002`0?ooo`030?3ol000o`00l?o`01/0
l?o`00<000000?3ol03`oo006`3`oo02003o0600oooo002b0?ooo`@00?l0
603`oo000`000000l?o`0?3ol00I0?3ol0800?l0HP3oool00;H0oooo0P00
o`0F0?3ol0030000003`oo00l?o`01@0l?o`J@3oool00;P0oooo0`00o`0C
0?3ol0030000003`oo00l?o`0100l?o`00<00?l00?3ol03oool0JP3oool0
0;d0oooo4@3`oo000`000000l?o`0?3ol00:0?3ol0H00?l0K@3oool00<<0
oooo00<0l?o`003o0000o`002000o`000`000000l?o`0?3ol0060?3ol0@0
0?l0L`3oool00<h0oooo00<000000?ooo`3oool0O@3oool00<h0oooo00<0
00000?ooo`3oool0O@3oool00<h0oooo00<000000?ooo`3oool0O@3oool0
0<h0oooo00<000000?ooo`3oool0O@3oool00<h0oooo00<000000?ooo`3o
ool0O@3oool00<h0oooo00<000000?ooo`3oool0O@3oool00<h0oooo00<0
00000?ooo`3oool0O@3oool00<h0oooo00<000000?ooo`3oool0O@3oool0
0<h0oooo00<000000?ooo`3oool0O@3oool00<h0oooo00<000000?ooo`3o
ool0O@3oool00<h0oooo00<000000?ooo`3oool0O@3oool00?l0ooooC`3o
ool00?l0ooooC`3oool00?l0ooooC`3oool00?l0ooooC`3oool00?l0oooo
C`3oool00?l0ooooC`3oool00?l0ooooC`3oool00<`0oooo0P0000200?oo
o`00c@3oool00`000000oooo0?ooo`1n0?ooo`00cP3oool00`000000oooo
0?ooo`1m0?ooo`00c@3oool00`000000oooo0000001n0?ooo`00c03oool0
10000000oooo0?ooo`00001n0?ooo`00b`3oool3000000030?ooo`000000
000007d0oooo003o0?ooodl0oooo003o0?ooodl0oooo003o0?ooodl0oooo
003o0?ooodl0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{334, 218},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\tFigure 1.26",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The annulus  ",
  Cell[BoxData[
      \(A = {z : \ \(\(1\)\(<\)\) | z | \(\(<\)\(2\)\)}\)]],
  "  is a connected set."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006a0000U2000`400?l0
0000o`00003oo`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00
o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3oool30?oo
o`030000003oool0oooo0:`0oooo003o0?ooo`<0oooo00<000000?ooo`3o
ool0[03oool00?l0oooo0`3oool00`000000oooo0?ooo`2/0?ooo`00o`3o
ool30?ooo`030000003oool0oooo0:`0oooo003o0?ooo`<0oooo00<00000
0?ooo`3oool0[03oool00?l0oooo0`3oool00`000000oooo0?ooo`2/0?oo
o`00o`3oool30?ooo`030000003oool0oooo0:`0oooo003o0?ooo`<0oooo
00<000000?ooo`3oool0[03oool00?l0oooo0`3oool00`000000oooo0?oo
o`2/0?ooo`00o`3oool30?ooo`030000003oool0oooo0:`0oooo003o0?oo
o`<0oooo00<000000?ooo`3oool0[03oool00?l0oooo0`3oool00`000000
oooo0?ooo`2/0?ooo`00o`3oool30?ooo`030000003oool0oooo0:`0oooo
003o0?ooo`<0oooo00<000000?ooo`3oool0[03oool00?l0oooo0`3oool0
0`000000oooo0?ooo`2/0?ooo`00o`3oool30?ooo`030000003oool0oooo
0:`0oooo003o0?ooo`<0oooo00<000000?ooo`3oool0[03oool00?l0oooo
0`3oool00`000000oooo0?ooo`2/0?ooo`00o`3oool30?ooo`030000003o
ool0oooo0:`0oooo003i0?ooo`D00000103oool00`000000oooo0?ooo`2/
0?ooo`00Z@3oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo
0440oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`170?oo
o`03003o003oool0oooo00/0oooo00<00?l00?ooo`3oool0E03oool00:D0
oooo00<00?l00?ooo`00o`000`00o`080?ooo`L00?l0@@3oool00`000000
oooo0?ooo`040?ooo`800000A03oool00`00o`00oooo003o0003003o00L0
oooo2000o`1D0?ooo`00Y03oool6003o00T0l?o`2000o`0h0?ooo`@00000
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0440oooo
1`00o`080?3ol0T00?l0D`3oool00:<0oooo1@00o`0A0?3ol004003o003`
oo00l?o`0?3ol3h0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`100?ooo`H00?l04@3`oo001000o`00l?o`0?3ol03`oo1A0?ooo`00
X03oool40?3ol003003o003`oo00l?o`01X0l?o`0P3oool00`00o`00oooo
0?ooo`0d0?ooo`8000001P3oool00`000000oooo0?ooo`0m0?ooo`@0l?o`
00<00?l00?3ol03`oo006`3`oo020?ooo`03003o003oool0oooo04P0oooo
002N0?ooob@0l?o`1000o`0l0?ooo`030000003oool0oooo03/0oooo9@3`
oo03003o04T0oooo002J0?ooo`03003o003oool0l?o`02H0l?o`1000o`0k
0?ooo`030000003oool0oooo03P0oooo00<00?l00?ooo`3`oo009P3`oo04
003o04L0oooo002I0?ooo`<00?l0:@3`oo04003o03T0oooo00<000000?oo
o`3oool0=P3oool4003o02P0l?o`1@00o`150?ooo`00U`3oool4003o02/0
l?o`1000o`0h0?ooo`030000003oool0oooo03D0oooo1000o`0[0?3ol0@0
0?l0A03oool009H0oooo1000o`0^0?3ol003003o003`oo00oooo03L0oooo
00<000000?ooo`3oool0=03oool3003o02h0l?o`0P00o`150?ooo`00UP3o
ool2003o03<0l?o`=`3oool00`000000oooo0?ooo`0c0?ooo`<00?l0<P3`
oo140?ooo`00U@3oool00`3`oo000?l00?3ol00c0?3ol3L0oooo00<00000
0?ooo`3oool0<P3oool3003o03@0l?o`@`3oool009D0oooo00<0l?o`003o
003`oo00=@3`oo0e0?ooo`030000003oool0oooo0380oooo00<0l?o`003o
003`oo00=@3`oo120?ooo`00U03ooolj0?3ol3@0oooo00<000000?ooo`3o
ool0<@3ooolj0?3ol440oooo002C0?oooc`0l?o`<`3oool00`000000oooo
0?ooo`0`0?oooc`0l?o`@03oool00940oooo?P3`oo000`3oool00?l00?oo
o`0`0?ooo`030000003oool0oooo02l0oooo?P3`oo000`00o`00oooo0?oo
o`0l0?ooo`00T@3oooln0?3ol0<00?l0<03oool00`000000oooo0?ooo`0^
0?oooch0l?o`0`00o`0m0?ooo`00T03ooom00?3ol0<00?l0;`3oool00`00
0000oooo0?ooo`0]0?oood00l?o`0`00o`0l0?ooo`00S`3ooom20?3ol0<0
0?l0;P3oool00`000000oooo0?ooo`0/0?ooo`03003o003`oo00l?o`03l0
l?o`0`00o`0k0?ooo`00S@3oool2003o04<0l?o`0P00o`0^0?ooo`030000
003oool0oooo02/0oooo0`00o`110?3ol0<00?l0>P3oool008d0oooo0P00
o`140?3ol003003o003oool0oooo02`0oooo00<000000?ooo`3oool0:P3o
ool3003o04<0l?o`0`00o`0i0?ooo`00S@3oool2003o04@0l?o`00<00?l0
0?ooo`3oool0;03oool00`000000oooo0?ooo`0Z0?ooo`800?l0A@3`oo00
0`00o`00oooo0?ooo`0h0?ooo`00S03oool3003o04D0l?o`;P3oool00`00
0000oooo0?ooo`0Y0?ooo`<00?l0AP3`oo0j0?ooo`00R`3oool3003o04L0
l?o`;@3oool00`000000oooo0?ooo`0X0?ooo`<00?l0B03`oo0i0?ooo`00
S03oool00`00o`00l?o`0?3ol0160?3ol2d0oooo00<000000?ooo`3oool0
:@3oool00`00o`00l?o`0?3ol0170?3ol3T0oooo002;0?oood/0l?o`;03o
ool00`000000oooo0?ooo`0X0?oood/0l?o`>@3oool008/0ooooC03`oo0[
0?ooo`030000003oool0oooo02P0ooooC03`oo0h0?ooo`00RP3ooom=0?3o
l2/0oooo00<000000?ooo`3oool0:03ooom<0?3ol3P0oooo002:0?ooodd0
l?o`:`3oool00`000000oooo0?ooo`0X0?ooodd0l?o`=`3oool008T0oooo
CP3`oo000`00o`00oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo
CP3`oo0g0?ooo`00R@3ooom=0?3ol0<00?l0:@3oool00`000000oooo0?oo
o`0W0?ooodd0l?o`0P00o`0f0?ooo`00PP3oool2000000D0ooooCP3`oo03
003o00H0oooo1@00000M0?ooo`030000003oool0oooo01/0oooo1@000007
0?ooodd0l?o`0P00o`080?ooo`800000;03oool007/0oooo100000020?oo
o`040000003oool0oooo000000@0ooooCP3`oo02003o00030?ooo`000000
000000800000103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool01`3ooom=0?3ol0<00?l01P3oool0
10000000oooo0?ooo`00000[0?ooo`00P`3oool00`000000oooo0?ooo`02
0?ooodl0l?o`0P00o`090?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooodl0l?o`0P00o`08
0?ooo`030000003oool0oooo02X0oooo00240?ooo`030000003oool0oooo
00800?l0CP3`oo02003o00T0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00D0oooo0P00o`1>0?3o
l0800?l02@3oool00`000000oooo0?ooo`0Y0?ooo`00P@3oool010000000
oooo0?ooo`0000020?ooo`800?l0CP3`oo02003o00T0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00D0oooo0P00o`1>0?3ol0800?l01P3oool010000000oooo0?ooo`00000[
0?ooo`00PP3oool2000000<0oooo0P00o`1>0?3ol0800?l0203oool20000
01l0oooo00<000000?ooo`3oool0703oool2000000L0oooo0P00o`1>0?3o
l0800?l01`3oool2000002`0oooo00270?ooo`800?l0D03`oo0Y0?ooo`03
0000003oool0oooo02@0oooo0P00o`1@0?3ol3H0oooo00270?ooo`800?l0
D03`oo0Y0?ooo`030000003oool0oooo02@0oooo0P00o`1@0?3ol3H0oooo
00270?ooo`800?l0D03`oo0Y0?ooo`030000003oool0oooo02@0oooo0P00
o`1@0?3ol3H0oooo00270?ooo`800?l0D03`oo0Y0?ooo`030000003oool0
oooo02@0oooo0P00o`1A0?3ol003003o003oool0oooo01@0oooo0P000000
0`3oool000000000000I0?ooo`00N@3ooooo000001<000002@3oool00`00
0000oooo0000000J0?ooo`00R03ooom@0?3ol0800?l0:03oool00`000000
oooo0?ooo`0U0?oooe40l?o`0P00o`0H0?ooo`030000003oool0oooo01T0
oooo00280?oooe00l?o`0P00o`0X0?ooo`030000003oool0oooo02D0oooo
D03`oo02003o01L0oooo0P0000000`3oool000000000000I0?ooo`00R03o
oom@0?3ol0800?l0:03oool00`000000oooo0?ooo`0U0?oooe00l?o`0P00
o`0e0?ooo`00R03ooom@0?3ol0800?l0:03oool00`000000oooo0?ooo`0U
0?oooe00l?o`0P00o`0e0?ooo`00R03ooom@0?3ol0800?l0:03oool00`00
0000oooo0?ooo`0V0?ooodl0l?o`0P00o`0e0?ooo`00R03ooom@0?3ol080
0?l0:03oool00`000000oooo0?ooo`0V0?ooodl0l?o`0P00o`0e0?ooo`00
R03oool00`00o`00l?o`0?3ol01=0?3ol0800?l0:03oool00`000000oooo
0?ooo`0V0?ooo`03003o003`oo00l?o`04`0l?o`0P00o`0e0?ooo`00R03o
ool00`00o`00l?o`0?3ol01=0?3ol2X0oooo00<000000?ooo`3oool09P3o
ool00`00o`00l?o`0?3ol01=0?3ol3H0oooo00280?ooo`800?l0CP3`oo0Z
0?ooo`030000003oool0oooo02H0oooo0P00o`1>0?3ol3H0oooo00280?oo
o`800?l0CP3`oo0Z0?ooo`030000003oool0oooo02H0oooo0P00o`1=0?3o
l3L0oooo00280?ooo`800?l0CP3`oo0Z0?ooo`030000003oool0oooo02H0
oooo0P00o`1=0?3ol3L0oooo00280?ooo`<00?l0C03`oo0[0?ooo`030000
003oool0oooo02H0oooo0P00o`1=0?3ol3L0oooo00280?ooo`@00?l0B`3`
oo0[0?ooo`030000003oool0oooo02H0oooo0P00o`1=0?3ol3L0oooo002:
0?ooo`03003o003`oo00l?o`04T0l?o`;03oool00`000000oooo0?ooo`0V
0?ooo`800?l0C03`oo0h0?ooo`00R`3ooom;0?3ol003003o003oool0oooo
02T0oooo00<000000?ooo`3oool0:03ooom<0?3ol3P0oooo002;0?oood/0
l?o`00<00?l00?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooodX0
l?o`0P00o`0h0?ooo`00S03ooom90?3ol0800?l0:`3oool00`000000oooo
0?ooo`0Y0?ooodT0l?o`0P00o`0h0?ooo`00S03ooom90?3ol003003o003o
ool0oooo02X0oooo00<000000?ooo`3oool0:@3ooom90?3ol0800?l0>03o
ool008d0oooo803`oo0500000280l?o`0P00o`0/0?ooo`030000003oool0
oooo02X0oooo8@3`oo0500000280l?o`0P00o`0h0?ooo`00S@3ooolQ0?3o
l0050000003`oo00l?o`0?3ol0000000803`oo03003o02`0oooo00<00000
0?ooo`3oool0:P3ooolR0?3ol0050000003`oo00l?o`0?3ol0000000803`
oo03003o03P0oooo002>0?ooob00l?o`00D000000?3ol03`oo00l?o`0000
000O0?3ol0<00?l0;@3oool00`000000oooo0?ooo`0[0?ooob40l?o`00D0
00000?3ol03`oo00l?o`0000000O0?3ol0<00?l0>@3oool008l0oooo00<0
0?l00?3ol03`oo00703`oo001@000000l?o`0?3ol03`oo0000000200l?o`
00<00?l00?ooo`3oool0;03oool00`000000oooo0?ooo`0/0?ooo`03003o
003`oo00l?o`01d0l?o`00D000000?3ol03`oo00l?o`0000000O0?3ol003
0?ooo`00o`00oooo03T0oooo002?0?ooo`03003o003`oo00l?o`01`0l?o`
1000000P0?3ol300oooo00<000000?ooo`3oool0;03oool00`00o`00l?o`
0?3ol00M0?3ol0@000007`3`oo0m0?ooo`00S`3oool2003o01d0l?o`00D0
00000?3ol03`oo00l?o`0000000O0?3ol300oooo00<000000?ooo`3oool0
;03oool2003o01h0l?o`00D000000?3ol03`oo00l?o`0000000N0?3ol3d0
oooo002?0?ooo`<00?l0703`oo001@000000l?o`0?3ol03`oo00000001h0
l?o`<@3oool00`000000oooo0?ooo`0/0?ooo`@00?l0703`oo001@000000
l?o`0?3ol03`oo00000001d0l?o`?P3oool00900oooo0`00o`0J0?3ol0D0
00007@3`oo0c0?ooo`030000003oool0oooo02d0oooo1000o`0J0?3ol0D0
00007@3`oo0o0?ooo`00T@3oool3003o03/0l?o`<`3oool00`000000oooo
0?ooo`0_0?ooo`<00?l0>P3`oo100?ooo`00TP3oool00`00o`00l?o`0?3o
l00g0?3ol003003o003`oo00oooo03<0oooo00<000000?ooo`3oool0<03o
ool00`00o`00l?o`0?3ol00g0?3ol003003o003oool0oooo03l0oooo002D
0?ooocP0l?o`00<00?l00?ooo`3oool0<`3oool00`000000oooo0?ooo`0a
0?ooocP0l?o`0`00o`100?ooo`00U@3ooolf0?3ol0800?l0=@3oool00`00
0000oooo0?ooo`0b0?ooocH0l?o`0`00o`110?ooo`00U@3ooole0?3ol080
0?l0=P3oool00`000000oooo0?ooo`0c0?oooc@0l?o`0`00o`120?ooo`00
U`3ooola0?3ol0@00?l0=P3oool00`000000oooo0?ooo`0e0?oooc40l?o`
0`00o`130?ooo`00V@3oool00`3`oo000?l00?3ol00[0?3ol0@00?l0=`3o
ool00`000000oooo0?ooo`0f0?ooo`80l?o`00<00?l00?3ol03`oo00:P3`
oo03003o04@0oooo002I0?ooo`@00?l0:@3`oo020?ooo`03003o003oool0
oooo03L0oooo00<000000?ooo`3oool0=`3oool4003o02T0l?o`0P3oool0
0`00o`00oooo0?ooo`130?ooo`00VP3oool5003o02H0l?o`?@3oool00`00
0000oooo0?ooo`0g0?ooo`D00?l09P3`oo1:0?ooo`00W03oool4003o02<0
l?o`?`3oool00`000000oooo0?ooo`0j0?ooo`@00?l08P3`oo1<0?ooo`00
WP3oool3003o01h0l?o`00<00?l00?3ol03oool0@03oool00`000000oooo
0?ooo`0k0?ooo`@00?l07@3`oo000`00o`00l?o`0?3ol01=0?ooo`00W`3o
ool00`00o`00oooo0?3ol00I0?3ol003003o003`oo000?l000<00?l0@@3o
ool00`000000oooo0?ooo`0m0?ooo`03003o003oool0l?o`01T0l?o`00<0
0?l00?3ol000o`000P00o`1>0?ooo`00X`3oool80?3ol003003o003`oo00
l?o`00`0l?o`1P00o`0i0?ooo`D00000103oool00`000000oooo0?ooo`11
0?ooo`P0l?o`00<00?l00?3ol03`oo002`3`oo06003o04l0oooo002W0?oo
o`030?3ol000o`000?l000@00?l02`3`oo05003o03d0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`150?ooo`030?3ol000o`000?l0
00@00?l02P3`oo06003o0500oooo002X0?ooo`P00?l00`3`oo070?ooo`03
003o003oool0oooo03h0oooo00<000000?ooo`3oool0103oool2000004L0
oooo1`00o`040?3ol0H0oooo00<00?l00?ooo`3oool0DP3oool00:`0oooo
1000o`1;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
BP3oool3003o05l0oooo003k0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0[03oool00?X0oooo0P0000060?ooo`030000003oool0
oooo0:`0oooo003o0?ooo`<0oooo00<000000?ooo`3oool0[03oool00?l0
oooo0`3oool00`000000oooo0?ooo`2/0?ooo`00o`3oool30?ooo`030000
003oool0oooo0:`0oooo003o0?ooo`<0oooo00<000000?ooo`3oool0[03o
ool00?l0oooo0`3oool00`000000oooo0?ooo`2/0?ooo`00o`3oool30?oo
o`030000003oool0oooo0:`0oooo003o0?ooo`<0oooo00<000000?ooo`3o
ool0[03oool00?l0oooo0`3oool00`000000oooo0?ooo`2/0?ooo`00o`3o
ool30?ooo`030000003oool0oooo0:`0oooo003o0?ooo`<0oooo00<00000
0?ooo`3oool0[03oool00?l0oooo0`3oool00`000000oooo0?ooo`2/0?oo
o`00o`3oool30?ooo`030000003oool0oooo0:`0oooo003o0?ooo`<0oooo
00<000000?ooo`3oool0[03oool00?l0oooo0`3oool00`000000oooo0?oo
o`2/0?ooo`00o`3oool30?ooo`030000003oool0oooo0:`0oooo003o0?oo
o`<0oooo00<000000?ooo`3oool0[03oool00?l0oooo0`3oool00`000000
oooo0?ooo`2/0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3o
oonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3oool10?ooo`80
0000[`3oool00?l0oooo0P3oool00`000000oooo0?ooo`2]0?ooo`00o`3o
ool30?ooo`030000003oool0oooo0:`0oooo003o0?ooo`80oooo00<00000
0?ooo`000000[@3oool00?l0oooo0@3oool010000000oooo0?ooo`00002]
0?ooo`00o`3oool3000000030?ooo`00000000000:`0oooo003o0?oook80
oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{433, 148},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\tFigure 1.27",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The set  ",
  Cell[BoxData[
      RowBox[{"B", "=", 
        RowBox[{"{", 
          RowBox[{"z", ":", 
            RowBox[{"|", \(z + 2\), "|", 
              RowBox[{"<", 
                RowBox[{"1", "  ", 
                  StyleBox["or",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]}], " ", "|", \(z - 2\), 
              "|", \(\(<\)\(1\)\)}]}], "}"}]}]]],
  "  is not a connected set."
}], "Text"],

Cell[TextData[{
  "\tWe call a connected open set a domain.  In the exercises we ask you to \
show that the open unit disk  ",
  Cell[BoxData[
      \(\(D\_1\) \((0)\) = {z : \(\(|\)\(z || \(\(<\)\(1\)\)\)\)}\)]],
  "  is a domain and that the closed unit disk  ",
  Cell[BoxData[
      \(\(\(D\_1\)\&_\) \((0)\) = {z : \(\(|\)\(z || \
\(\(\[LessEqual]\)\(1\)\)\)\)}\)]],
  "  is not a domain.  The term domain is a noun and is a type of set.  In \
Chapter 2 we note that it also refers to the set of points on which a \
function is defined.  In the latter context, it does not necessarily mean a \
connected open set."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.26.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the right half-plane  ",
  Cell[BoxData[
      \(H = {z : \ Re \((z)\) > 0}\)]],
  "  is a domain."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  First we show that ",
  StyleBox["H",
    FontFamily->"Courier New"],
  " is connected. Let ",
  Cell[BoxData[
      RowBox[{\(z\_0\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(z\_1\)}]]],
  " be any two points in ",
  StyleBox["H",
    FontFamily->"Courier New"],
  ".  We claim the obvious, that the straight-line segment ",
  StyleBox[" ",
    FontFamily->"Courier New"],
  Cell[BoxData[
      \(C : \ z \((t)\) = \ z\_0\  + \((z\_1 - z\_0)\) t\)]],
  ",  for  ",
  Cell[BoxData[
      RowBox[{\(0 \[LessEqual] t \[LessEqual] 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  "  lies entirely within  ",
  StyleBox["H",
    FontFamily->"Courier New"],
  ".  To prove this claim, we let  ",
  Cell[BoxData[
      \(z \((\(t\^*\))\) = \ z\_0\  + \((z\_1 - z\_0)\) \(t\^*\)\)]],
  ",  for some  ",
  Cell[BoxData[
      \(\(t\^*\) \[Element] \([0, 1]\)\)]],
  ",  be an arbitrary point on ",
  Cell[BoxData[
      \(C\)]],
  ".  We must show that  ",
  Cell[BoxData[
      \(Re[z \((\(t\^*\))\)] > 0\)]],
  ".  Now,  \n\t\t\n",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[\((1 - 53)\),
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->RGBColor[0, 0, 0.996109],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            "                      ", \(Re[z \((\(t\^*\))\)]\)}], " ", "=", 
          "  ", \(Re[z\_0\  + \((z\_1 - z\_0)\) \(t\^*\)]\)}], 
        "\[IndentingNewLine]"}], "\n", 
      RowBox[{
        "                                                          ", \(\(=\)\
\(\ \ \)\(Re[\ \((1 - \(t\^*\))\) z\_0\  + \ \(t\^*\) z\_1]\)\), 
        "\[IndentingNewLine]"}], "\n", 
      RowBox[{
        "                                                          ", \(\(=\)\
\(\ \ \)\(Re[\ \((1 - \(t\^*\))\) z\_0]\  + \ \ \ Re[\(t\^*\) z\_1]\)\), 
        "\[IndentingNewLine]"}], "\n", 
      RowBox[{
        "                                                          ", \(\(=\)\
\(\ \ \ \)\(\((1 - \(t\^*\))\) Re[z\_0]\  + \ \ \ \(t\^*\) Re[z\_1]\)\)}]}]],
  "     "
}], "Text"],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(t = 0\)]],
  ", the last expression becomes ",
  Cell[BoxData[
      \(Re[z\_0]\)]],
  ", which is greater than zero because ",
  Cell[BoxData[
      \(z\_0 \[Element] H\)]],
  ".  Likewise, if ",
  Cell[BoxData[
      \(t = 1\)]],
  ", then Equation ",
  StyleBox["(1-53)",
    FontColor->RGBColor[0, 0, 1]],
  " becomes ",
  Cell[BoxData[
      \(Re[z\_1]\)]],
  ", which also is positive.  Finally, if  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  ",  then each term in Equation ",
  StyleBox["(1-53)",
    FontColor->RGBColor[0, 0, 1]],
  " is positive, so in this case we also have  ",
  Cell[BoxData[
      \(Re[z \((\(t\^*\))\)] > 0\)]],
  ".\n\tTo show that ",
  StyleBox["H",
    FontFamily->"Courier New"],
  " is open, we suppose without loss of generality that  ",
  Cell[BoxData[
      \(Re[z\_0] < Re[z\_1]\)]],
  ".  We claim that  ",
  Cell[BoxData[
      \(\(D\_\[Epsilon]\) \((z\_0)\) \[Subset] H\)]],
  ",  where ",
  Cell[BoxData[
      \(\(\(\[Element]\)\(\(=\)\(Re[z\_0]\)\)\)\)]],
  ".  We leave the proof of this claim as an exercise."
}], "Text"],

Cell[TextData[{
  "\tA domain, together with some, none, or all its boundary points, is \
called a region.  For example, the horizontal strip  ",
  Cell[BoxData[
      \({z : \ 1 < Im \((z)\)}\)]],
  "  is a region.  A set formed by taking the union of a domain and its \
boundary is called a closed region; thus  ",
  Cell[BoxData[
      \({z : \ 1 \[LessEqual] Im \((z)\) \[LessEqual] 2}\)]],
  "  is a closed region.  A set ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " is said to be a bounded set if it can be completely contained in some \
closed disk, that is, if there exists an  ",
  Cell[BoxData[
      \(R > 0\)]],
  "  such that for each ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " in ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " we have ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(\[LessEqual]\)\(\ \)\(R\)\)\)\)]],
  ".  The rectangle given by  ",
  Cell[BoxData[
      \({z : \(\(|\)\(x\)\(|\)\(\(\[LessEqual]\)\(4\ \ and\)\)\(\ \ \
\)\(|\)\(y\)\(|\)\(\(\[LessEqual]\)\(3\)\)\)}\)]],
  " is bounded because it is contained inside the disk ",
  Cell[BoxData[
      \(\(\(D\_5\)\&_\) \((0)\) = {z : \ \
\(\(|\)\(z\)\(|\)\(\(\[LessEqual]\)\(\ \)\(5\)\)\)}\)]],
  ".  A set that cannot be enclosed by any closed disk is called an unbounded \
set.  "
}], "Text"],

Cell[TextData[{
  "\tWe mentioned earlier that a simple closed curve is positively oriented \
if its interior is on the left when the curve is traversed.  How do we know, \
though, that any given simple closed curve will have an interior and \
exterior?  Theorem 1.6 guarantees that this is indeed the case.  It is due in \
part to the work of the French mathematician ",
  StyleBox[ButtonBox["Marie Ennemond Camille Jordan",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Jordan.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " (1838--1922)."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 1.6 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Jordan Curve Theorem",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/JordanCurveTheorem.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The compliment of any simple closed curve ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " can be partitioned into two mutually exclusive domains ",
  StyleBox["I",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["E",
    FontFamily->"Courier New"],
  " in such a way that ",
  StyleBox["I",
    FontFamily->"Courier New"],
  " is bounded,  ",
  StyleBox["E",
    FontFamily->"Courier New"],
  " is unbounded, and ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is the boundary for both ",
  StyleBox["I",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["E",
    FontFamily->"Courier New"],
  ".   In addition  ",
  Cell[BoxData[
      \(I \[Union] E \[Union] C\)]],
  "  is the entire complex plane.  The domain ",
  StyleBox["I",
    FontFamily->"Courier New"],
  " is called the interior of ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ",  and  the domain ",
  StyleBox["E",
    FontFamily->"Courier New"],
  " is called the exterior of ",
  StyleBox["C",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe Jordan curve theorem is a classic example of a result in mathematics \
that seems obvious but is very hard to demonstrate, and its proof is beyond \
the scope of this book.  ",
  StyleBox[ButtonBox["Jordan's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Jordan.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " original argument, in fact, was inadequate, and not until 1905 was a \
correct version finally given by the American topologist ",
  StyleBox[ButtonBox["Oswald Veblen",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Veblen.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " (1880-1960).  The difficulty lies in describing the interior and exterior \
of a simple closed curve analytically, and in showing that they are connected \
sets.  For example, in which domain (interior or exterior) do the two points \
depicted in Figure 1.28 lie?  If they are in the same domain, how, \
specifically, can they be connected with a curve?  If you appreciated the \
subtleties involved in showing that the right half-plane of Example 1.26 is \
connected, you can begin to appreciate the obstacles that Veblen had to \
navigate."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006I00019B000`400?l0
0000o`00003oo`3ooonJ0?ooo`00o`3ooonJ0?ooo`00o`3ooonJ0?ooo`00
o`3ooonJ0?ooo`00o`3ooonJ0?ooo`00o`3ooonJ0?ooo`00o`3ooonJ0?oo
o`00o`3ooonJ0?ooo`00o`3ooonJ0?ooo`00o`3ooonJ0?ooo`00kP3ooolN
000008d0oooo003S0?ooo`/000007P3oool4000008T0oooo003N0?ooo`D0
0000;@3oool5000008@0oooo003J0?ooo`@00000=`3oool5000007l0oooo
003F0?ooo`@00000@03oool4000007/0oooo003C0?ooo`<00000B03oool3
000007P0oooo003@0?ooo`<00000CP3oool3000007D0oooo003=0?ooo`<0
00009`3oool=00000200oooo0`00001b0?ooo`00bP3oool3000001X0oooo
4000000=0?ooo`P000006`3oool3000006l0oooo00380?ooo`8000005`3o
ool6000002D0oooo2000000F0?ooo`800000K@3oool00<D0oooo0`00000E
0?ooo`@00000<`3oool4000001@0oooo0`00001Z0?ooo`00``3oool20000
01D0oooo0`00000k0?ooo`8000005@3oool3000006L0oooo00310?ooo`80
0000503oool300000400oooo0`00000E0?ooo`800000I@3oool00;l0oooo
0P00000C0?ooo`<00000AP3oool4000001<0oooo0P00001S0?ooo`00_@3o
ool200000140oooo1000001=0?ooo`@000004@3oool200000640oooo002k
0?ooo`8000003`3oool400000200oooo5@00000P0?ooo`<00000403oool2
000005l0oooo002i0?ooo`8000003P3oool3000001d0oooo1`00000E0?oo
o`X000006@3oool200000100oooo0P00001M0?ooo`00^03oool00`000000
oooo0?ooo`0<0?ooo`8000006@3oool7000002H0oooo1@00000F0?ooo`80
0000403oool2000005/0oooo002f0?ooo`8000003@3oool2000001L0oooo
1000000b0?ooo`D000004`3oool200000100oooo00<000000?ooo`3oool0
F03oool00;@0oooo0P00000=0?ooo`800000503oool5000003/0oooo0`00
000B0?ooo`8000003`3oool2000005P0oooo002b0?ooo`8000003@3oool2
00000180oooo100000130?ooo`<000004@3oool3000000h0oooo0P00001F
0?ooo`00/03oool2000000d0oooo0P00000@0?ooo`@00000BP3oool30000
0140oooo0P00000>0?ooo`800000E03oool00:l0oooo00<000000?ooo`3o
ool02`3oool200000100oooo0P00001A0?ooo`8000004@3oool2000000h0
oooo00<000000?ooo`3oool0D@3oool00:d0oooo0P00000<0?ooo`800000
403oool2000001/0oooo8@00000I0?ooo`<00000403oool2000000d0oooo
0P00001A0?ooo`00[03oool00`000000oooo0?ooo`0:0?ooo`800000403o
ool2000001L0oooo1P00000Q0?ooo`@00000603oool3000000l0oooo0P00
000=0?ooo`800000C`3oool00:/0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0>0?ooo`8000005@3oool4000002/0oooo1@00000F
0?ooo`8000003`3oool2000000d0oooo00<000000?ooo`3oool0C03oool0
0:T0oooo0P00000;0?ooo`8000003`3oool2000001<0oooo1000000d0?oo
o`@00000503oool2000000l0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1;0?ooo`00Z03oool00`000000oooo0?ooo`090?ooo`80
00003`3oool200000140oooo1000000l0?ooo`@000004P3oool2000000h0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1:0?ooo`00
YP3oool2000000X0oooo0P00000?0?ooo`800000403oool3000004@0oooo
0P00000B0?ooo`8000003@3oool2000000`0oooo0P00001:0?ooo`00Y@3o
ool00`000000oooo0?ooo`080?ooo`8000003`3oool200000100oooo0P00
00190?ooo`<000004@3oool2000000d0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`170?ooo`00Y03oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00d0oooo0P00000?0?ooo`<000007@3oool?
00000280oooo0`00000@0?ooo`800000303oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo04H0oooo002R0?ooo`8000002P3oool00`00
0000oooo0?ooo`0<0?ooo`8000003P3oool3000001T0oooo1`00000?0?oo
o`h000005`3oool200000100oooo00<000000?ooo`3oool02P3oool20000
00`0oooo00<000000?ooo`3oool0A@3oool00:40oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0;0?ooo`8000003P3oool2000001D0
oooo1`00000T0?ooo`D00000503oool2000000l0oooo0P00000<0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool00:00oooo
00<000000?ooo`3oool0203oool2000000`0oooo0P00000>0?ooo`800000
4`3oool400000300oooo1000000B0?ooo`<000003P3oool2000000/0oooo
0P00000;0?ooo`800000A03oool009h0oooo0P00000:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0303oool200000140oooo1000
000h0?ooo`<000004P3oool2000000h0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0440oooo002M
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool2
000000d0oooo0P00000A0?ooo`800000?`3oool200000180oooo0P00000=
0?ooo`8000002`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0400oooo002L0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool2000000d0oooo0P00000@0?ooo`<00000@`3oool30000
0140oooo0P00000=0?ooo`8000002P3oool2000000/0oooo00<000000?oo
o`3oool0?`3oool009/0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo0P00000@0?ooo`80
0000B@3oool300000100oooo0P00000=0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0n0?ooo`00
VP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool200000100oooo0P00000I0?oooa/00000
6P3oool200000100oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo0P00000n0?ooo`00V@3o
ool00`000000oooo0?ooo`080?ooo`8000002`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00h0oooo0P00000F0?ooo`D000006`3o
ool7000001D0oooo0P00000?0?ooo`800000303oool2000000X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0k0?ooo`00V03oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo0P00000;
0?ooo`8000003`3oool2000001@0oooo1000000W0?ooo`D000004P3oool2
000000l0oooo0P00000<0?ooo`030000003oool0oooo00P0oooo0P00000;
0?ooo`030000003oool0oooo03X0oooo002H0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00d0oooo0P00000B0?ooo`@00000<03oool30000
0140oooo0P00000?0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
03T0oooo002G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0
oooo0P00000@0?ooo`@00000=`3oool300000100oooo0P00000>0?ooo`80
00002`3oool2000000X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0h0?ooo`00UP3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool2000000d0oooo
0P00000?0?ooo`<00000?P3oool200000100oooo0P00000>0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo03P0oooo002E0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00/0oooo0P00000?0?ooo`800000@`3o
ool3000000l0oooo0P00000=0?ooo`8000002`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=`3o
ool009@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo0P00000<0?ooo`8000003`3oool2
000004P0oooo0`00000>0?ooo`8000003@3oool2000000X0oooo0P000009
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=P3oool0
09<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool20000
00l0oooo0P00000G0?oooa`000006P3oool2000000h0oooo0P00000=0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo03D0oooo002B0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool2000000X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`80
0000503oool5000001`0oooo1@00000G0?ooo`8000003P3oool2000000`0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`80
00002@3oool00`000000oooo0?ooo`0d0?ooo`00T@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`8000003P3oool2000001<0oooo
0`00000V0?ooo`@000005@3oool2000000h0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0c0?ooo`00T03o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`8000003P3o
ool200000180oooo0`00000]0?ooo`@000004`3oool2000000d0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0c0?ooo`00S`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00`0oooo0P00000@0?ooo`@00000=03oool3
00000180oooo0P00000<0?ooo`8000002`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0b0?ooo`00SP3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo0P00000?0?oo
o`<00000>`3oool300000140oooo0P00000<0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0<@3oool008d0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo0P00000:0?ooo`030000003oool0oooo00X0
oooo0P00000?0?ooo`800000@@3oool4000000l0oooo0P00000;0?ooo`03
0000003oool0oooo00T0oooo0P00000:0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0`0?ooo`00
S03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`800000
303oool00`000000oooo0?ooo`0=0?ooo`8000006`3ooolC000001T0oooo
0P00000?0?ooo`8000002P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo02l0oooo002;0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3o
ool2000000h0oooo0P00000G0?ooo`H000004`3oool6000001D0oooo0P00
000?0?ooo`030000003oool0oooo00P0oooo0P00000;0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02h0oooo002:0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0<0?ooo`800000503oool5000001l0oooo1000000C
0?ooo`8000003P3oool2000000X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0^0?ooo`00RP3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02`3oool2000001<0oooo0`00000X0?oo
o`<000004P3oool2000000h0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
02d0oooo00290?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02@3oool2000000`0oooo0P00000A0?ooo`@0
0000;P3oool300000140oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`080?ooo`8000002P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0/0?ooo`00R@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`8000002`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00d0oooo1000000e0?ooo`<000003`3oool2000000d0oooo
0P00000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0:`3oool008P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo0P00000>0?ooo`800000?03oool2000000l0oooo0P00
000=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0[0?ooo`00Q`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00T0oooo0P00000;0?ooo`8000003P3oool200000400oooo0`00000>
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo02X0oooo00270?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`8000003P3oool2000001T0oooo5@00000G0?ooo`8000003@3oool20000
00`0oooo0P0000090?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0:@3oool008H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool2000001D0
oooo1P00000E0?ooo`D00000503oool2000000d0oooo0P00000<0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0Y0?ooo`00QP3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`800000
4P3oool500000200oooo1000000B0?ooo`8000003@3oool2000000/0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02P0oooo00250?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`800000303oool200000140oooo0`00
000Y0?ooo`8000004P3oool2000000d0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool09`3oool008@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool2
00000100oooo0`00000^0?ooo`@00000403oool2000000`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09`3oool0
08@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool200000100oooo0P00000e0?ooo`<000003`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo02H0oooo00230?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool2000000X0
oooo00<000000?ooo`3oool0203oool2000000l0oooo0`00000j0?ooo`80
00003P3oool2000000/0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool09P3oool008<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo0P0000090?ooo`8000003`3oool2000001X0oooo
2P00000K0?ooo`8000003P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02D0oooo
00220?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03@3oool2000001H0oooo1P00
000:0?ooo`T00000503oool2000000d0oooo0P00000:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02@0oooo0021
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0303oool200000140oooo1`00000I
0?ooo`800000503oool2000000d0oooo00<000000?ooo`3oool0203oool2
000000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo00210?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool02`3oool200000100oooo0`00000R0?oo
o`<000004`3oool2000000`0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?oo
o`00P03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo0P00000@0?ooo`80
0000:03oool400000140oooo0P00000;0?ooo`8000002P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`00
P03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo0P00000?0?ooo`<00000
;P3oool300000100oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0280oooo001o0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo0P00000;0?ooo`030000003o
ool0oooo00d0oooo0P00000d0?ooo`8000003`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool08@3oool007l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo0P00000h
0?ooo`8000003P3oool2000000/0oooo0P0000090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0200oooo001n0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool02@3oool2000000d0oooo0P00000G0?oo
oa0000005@3oool2000000h0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0200oooo001n0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0;0?ooo`8000004`3oool600000100
oooo1@00000B0?ooo`8000003@3oool2000000/0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0O0?ooo`00O@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool200000140oooo1000000K0?ooo`<00000
4@3oool2000000d0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01l0oooo001m0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203o
ool2000000/0oooo0P00000?0?ooo`@000008P3oool4000000l0oooo0P00
000<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0N0?ooo`00O03oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`800000:P3oool2
000000l0oooo0P00000;0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0N0?ooo`00O03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02@3oool2000000h0oooo0P00000^0?oo
o`8000003`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0M0?ooo`00N`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0<0?ooo`800000<P3oool2000000h0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool07@3oool007/0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool2000003H0oooo
0P00000=0?ooo`8000002P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0703oool007/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00P0oooo0P00000<0?ooo`8000004P3o
oolF00000180oooo0P00000=0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo001j
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00X0oooo0P00000A0?ooo`<000005P3oool4
00000100oooo0P00000<0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo001j0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool40000
01d0oooo0P00000@0?ooo`8000002`3oool2000000T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo001j0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo0P00000>0?ooo`8000008`3oool3000000l0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0K0?ooo`00
N@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo
0P00000X0?ooo`8000003P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01X0oooo001i0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`8000002`3oool00`000000oooo0?oo
o`0:0?ooo`<00000;03oool2000000d0oooo0P00000;0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01X0oooo001h0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo0P00000;
0?ooo`800000<@3oool2000000d0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0I0?ooo`00N03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo0P00000F0?ooo`T000005P3oool20000
00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?oo
o`00N03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool03`3oool7000000T0oooo1`00000A0?ooo`80
00002`3oool2000000X0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool007L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`800000
403oool2000001L0oooo1000000?0?ooo`8000002`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01P0oooo001g0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0>0?ooo`8000007@3oool3000000h0oooo0P00000:0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0603oool007L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00`0oooo0`00000R0?ooo`8000003P3oool00`000000oooo0?ooo`08
0?ooo`8000002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`00MP3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02`3oool2000002L0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool05`3oool007H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`800000303oool2000002X0oooo0P00000=0?ooo`80
00002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0
oooo001f0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0:0?ooo`800000;P3oool2000000d0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01L0oooo001e0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`8000004P3o
ool?00000140oooo0P00000<0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`00M@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`D000003`3oool3
00000100oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool0
07D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool20000
01L0oooo0`00000>0?ooo`8000002`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool007D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00P0oooo0P00000=0?ooo`800000703oool3000000d0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool007@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool200000240oooo
0P00000<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo
001d0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo0P00
000U0?ooo`8000002`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0D0?ooo`00M03oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`09
0?ooo`800000:@3oool2000000X0oooo0P0000090?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D
0?ooo`00M03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01@0oooo001c0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0
oooo0P00000?0?ooo`P0000000<0oooo0000000000001@00000@0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0503oool007<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool2000000l0oooo0P00000@0?ooo`<000003P3oool2000000X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool007<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0<0?ooo`<000005@3oool2000000h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`00L`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00/0oooo0P00000J0?ooo`<00000303oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo001b0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02P3oool2000001l0oooo0P00000;0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00780
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`080?ooo`8000008`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool04`3oool00780oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02@0oooo
0P00000:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool04`3oool00780oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00d0oooo2P00000@0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0B0?ooo`00LP3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool4
000000X0oooo0`00000>0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B
0?ooo`00L@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool20000
0140oooo0`00000<0?ooo`8000002@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo001a0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool2000000X0oooo0P00000F0?ooo`<000002`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool04P3oool00740oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`00L@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0203oool2000001d0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3o
ool00740oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0A0?ooo`00L03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0P0?ooo`8000002@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool04@3oool00700oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool;000000d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool04@3oool00700oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02@3oool3000000/0oooo0P00000<0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo
001`0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03P3oool2000000X0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403o
ool00700oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0403oool00700oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0@0?ooo`00L03oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0
oooo0P0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0100oooo001_0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0100oooo001_0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3oool6000000`0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0@0?ooo`00K`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`000005
0?ooo`8000002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo001_0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool2000000X0oooo0`0000090?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0403oool006l0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo001_0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`00K`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo0P00000A0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`00K`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool0
06l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00l0oooo001_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool2000001@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0
oooo001_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0?0?ooo`00K`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool03`3oool006l0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`8000005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool03`3oool006l0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00P0oooo0P0000090?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`00K`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool200000080
oooo0P0000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0?0?ooo`00K`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3`3oool006l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0?0?ooo`00K`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo1@000007
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00l0oooo001_0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`00K`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00700oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo
001`0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0?0?ooo`00L03oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo0P000008
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?
0?ooo`00L03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0403oool00700oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool5000000<0oooo0`00000:0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`00
L03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0;0?ooo`<00000303oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0403oool00700oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0403oool00700oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool0
0700oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3o00000P3o00020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0@0?ooo`00L03oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000o`000?l000030?l00003
0?ooo`000000oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0203oool2000001<0oooo0P0000090?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0403oool00740oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?l0003o00000`3o00020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2@3oool2000000l0oooo0P00000:0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
403oool00740oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?l0003o00000`3o00020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3o
ool2000000/0oooo0P00000;0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403o
ool00740oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00@000000?l0003o0000o`000`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo2`00
000<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0403oool00740oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@
0?ooo`00L@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`000?l00P000?l30?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool04@3oool00740oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`80
00007@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000000o`00
0?l00`000?l20?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00740oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`8000006@3oool2000000X0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000003o
0000o`030000o`030?ooo`000000oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00780oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`8000005P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000000o`000?l00`000?l00`3oool000000?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo001b
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02P3oool200000100oooo1000000;0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`000?l20?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool0
0780oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0;0?ooo`@000001`3oool5000000h0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool007<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0>0?ooo`L000004@3oool2000000X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0140oooo001c0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00L`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`8000008P3o
ool2000000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo001c
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`8000002`3oool2000001l0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool0
07@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool20000
01`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04P3oool007@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02`3oool2000001P0oooo0P00000<0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0B0?ooo`00M03oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0<0?ooo`@000003`3oool5000000`0oooo0P0000090?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4P3oool007@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00P0oooo0P00000@0?ooo`l000003`3o
ool2000000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0C0?ooo`00M@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C
0?ooo`00M@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool02@3oool2000002P0oooo0P00000;0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04`3oool007D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`080?ooo`8000002`3oool2000002@0oooo0P00000<0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool04`3oool007D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo0P00000P0?ooo`800000
3@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01@0oooo001f0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`8000006`3o
ool3000000h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0D0?ooo`00MP3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00T0oooo0P00000=0?ooo`8000005P3oool3
000000l0oooo0P00000:0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01@0oooo001f0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`H000003P3oool20000
0140oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0E0?ooo`00M`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`80
00002`3oool200000180oooo3P00000A0?ooo`8000002`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0E0?ooo`00M`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01D0oooo001g0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool2000002/0oooo0P00000<0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01H0oooo001h0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00T0oooo0P00000<0?ooo`8000009`3oool2000000`0oooo0P000009
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0F0?ooo`00N03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00/0oooo0`00000Q0?ooo`<000003@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`00N@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo0`00000L0?ooo`80
00003`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`00
N@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
203oool2000000/0oooo0P00000@0?ooo`<000004`3oool6000000l0oooo
0P00000;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0G0?ooo`00N@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0100oooo1`0000070?ooo`D000004`3o
ool2000000`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01L0oooo001j0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00X0oooo0P00000G0?ooo`L000005P3oool2000000`0oooo0P000009
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05`3oool0
07X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00T0oooo0P00000<0?ooo`800000<03oool2000000d0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01P0oooo001k0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo0P00000/0?ooo`80
00003P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0603oool007/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`8000002`3oool00`000000oooo0?ooo`0<0?ooo`800000
:03oool2000000h0oooo0P00000;0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0603oool007`0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo0P00000>0?ooo`8000008`3o
ool3000000l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01P0oooo001l0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00d0oooo1@00000J0?ooo`@000004@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06@3oool0
07d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool04@3oool500000140oooo1000000C0?oo
o`800000303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
01T0oooo001m0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool2000000/0
oooo0P00000F0?oooa4000005@3oool2000000`0oooo0P0000090?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01X0oooo001n0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`800000>03oool2000000d0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0J0?ooo`00OP3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00T0oooo0P00000<0?ooo`800000=03o
ool2000000d0oooo0P00000:0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01/0oooo001o
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo0P00000;0?ooo`800000303oool3000002l0oooo0P00000>
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06`3oool0
07l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00`0oooo0`00000X0?ooo`@000003P3oool2000000X0oooo0P00000:0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0L0?oo
o`00P03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo0P00000?0?ooo`80
00008`3oool300000140oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0L0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool03P3oool5000001`0oooo0P00000B0?ooo`800000
2`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0L0?ooo`00P@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`800000303o
ool00`000000oooo0?ooo`0B0?ooo`P000002`3oool900000180oooo0P00
000;0?ooo`8000002`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool07@3oool00880oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`8000006P3oool;000001T0oooo0P00000<0?ooo`030000003oool0
oooo00T0oooo0P0000090?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool07@3oool0
0880oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`800000>@3oool30000
00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool07P3oool008<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool2000000d0
oooo0`00000d0?ooo`8000003`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0N0?ooo`00
P`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool2000000`0oooo
0P00000>0?ooo`<00000;P3oool3000000l0oooo0P00000;0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?ooo`00Q03o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00h0oooo0`00000Y0?ooo`8000004@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0O0?ooo`00Q03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0203oool2000000`0oooo0P00000A0?ooo`8000008P3oool5
00000140oooo0P00000;0?ooo`8000002`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0200oooo00250?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00/0oooo0P00000A0?ooo`T000005@3oool40000
01@0oooo0P00000<0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0P0?ooo`00Q@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool2000000d0oooo00<000000?ooo`3oool05`3ooolE000001H0
oooo0P00000=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0Q0?ooo`00QP3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo0P00000;0?ooo`030000
003oool0oooo00/0oooo0P0000100?ooo`8000003@3oool2000000/0oooo
0P0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0240oooo00270?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo0P00000:0?ooo`030000003oool0oooo00T0oooo0P00
000=0?ooo`800000>`3oool3000000h0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0280oooo00270?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo1000000e
0?ooo`8000003`3oool2000000`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R
0?ooo`00R03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool20000
0100oooo1000000^0?ooo`<000003`3oool2000000`0oooo0P00000;0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
02<0oooo00290?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`80
00004P3oool4000002L0oooo0`00000A0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0T0?ooo`00RP3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool2000000X0oooo00<000000?ooo`3oool0203oool2000000d0oooo
0P00000D0?ooo`<00000803oool400000180oooo0P00000<0?ooo`800000
303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0T0?ooo`00RP3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303o
ool2000001D0oooo1P00000D0?ooo`H00000503oool2000000d0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0U0?ooo`00R`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03@3oool2000001T0oooo5000000G0?ooo`<000003@3oool2
000000`0oooo0P0000090?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0V
0?ooo`00S03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`8000002P3oool2000000l0oooo0`00000o0?ooo`8000003`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo02H0oooo002=0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool200000100
oooo0`00000j0?ooo`8000003`3oool2000000`0oooo0P00000:0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0W0?ooo`00S@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0403oool3000003D0oooo0P00000?0?ooo`800000
3@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0W0?ooo`00SP3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`8000002`3oool2000001<0oooo0P00000_0?ooo`@00000403o
ool00`000000oooo0?ooo`0;0?ooo`8000002`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0:03oool008l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`8000004`3oool4
000002H0oooo1@00000B0?ooo`8000003@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`00T03oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0203oool2000000/0oooo00<000000?ooo`3oool02`3oool20000
01D0oooo1P00000J0?ooo`H000005P3oool00`000000oooo0?ooo`0;0?oo
o`800000303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:@3oool00900
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool2000000d0
oooo0P00000I0?ooo`H000003P3oool6000001X0oooo0P00000=0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02X0
oooo002A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0303oool4000001/0oooo3P00000N0?ooo`800000
3@3oool2000000`0oooo0P00000:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0:P3oool00980oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00T0oooo0P00000;0?ooo`800000403oool200000480oooo0`00
000=0?ooo`8000003@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:`3o
ool009<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`8000002`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00l0oooo0P00000l0?ooo`@000003P3oool2000000d0oooo0P00000;
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0;03oool009@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool200000140oooo0P00000g0?ooo`<00000403oool20000
00h0oooo00<000000?ooo`3oool02@3oool2000000T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0;@3oool009D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo0P00000<0?ooo`8000004@3oool4000002l0oooo1000000A0?ooo`80
00003P3oool2000000/0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0^0?ooo`00UP3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`8000004`3oool6000002<0oooo
1P00000C0?ooo`8000003`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
;P3oool009L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303o
ool2000001L0oooo1`00000E0?ooo`L000005`3oool2000000l0oooo0P00
000;0?ooo`8000002P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0_0?ooo`00V03oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool2000000h0oooo0`00000K
0?oooaD00000703oool200000100oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0300oooo002I0?ooo`8000002@3oool00`000000oooo0?ooo`090?oo
o`800000303oool2000000l0oooo100000150?ooo`<00000403oool20000
00/0oooo0P00000;0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0340oooo002K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0;0?ooo`8000004@3oool300000400
oooo0P00000A0?ooo`800000303oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0380oooo002L0?ooo`030000
003oool0oooo00L0oooo0P00000;0?ooo`8000003@3oool200000180oooo
0`00000k0?ooo`8000004@3oool2000000d0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0c0?ooo`00W@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0303oool2000001<0oooo0`00000e0?ooo`<000004@3o
ool2000000d0oooo0P00000;0?ooo`8000002`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=03o
ool009h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:
0?ooo`8000003P3oool2000001@0oooo0`00000^0?ooo`@000004P3oool2
000000h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`09
0?ooo`8000002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo03D0oooo002O0?ooo`030000003oool0oooo00P0oooo0P00000<0?oo
o`8000003P3oool2000001D0oooo1000000T0?ooo`H000004`3oool30000
00h0oooo0P00000;0?ooo`8000002`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=@3oool00:00
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00d0oooo0P00000G0?ooo`L000005P3oool7000001L0
oooo0P00000@0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0=P3oool00:40oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0;0?ooo`8000003`3oool3000001/0oooo
5P00000L0?ooo`800000403oool2000000`0oooo00<000000?ooo`3oool0
2@3oool2000000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0g0?ooo`00XP3oool00`000000oooo0?ooo`090?ooo`8000003@3o
ool00`000000oooo0?ooo`0?0?ooo`<00000A`3oool300000100oooo0P00
000<0?ooo`8000002`3oool00`000000oooo0?ooo`0?0?ooo`040000003o
ool0oooo0?ooo`800000>P3oool00:<0oooo0P00000;0?ooo`030000003o
ool0oooo00/0oooo0P00000B0?ooo`800000@@3oool400000140oooo0P00
000=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3o
ool3000003`0oooo002U0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0303oool200000180oooo0`00000j0?ooo`@000004`3oool2
000000d0oooo0P00000;0?ooo`800000D`3oool00:H0oooo00<000000?oo
o`3oool02@3oool2000000h0oooo0P00000C0?ooo`@00000<`3oool30000
01D0oooo0P00000>0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0D`3oool00:L0oooo0P00000;0?ooo`8000003P3oool3000001@0
oooo1@00000[0?ooo`<000005P3oool2000000h0oooo0P00000<0?ooo`03
0000003oool0oooo05@0oooo002Y0?ooo`030000003oool0oooo00X0oooo
0P00000?0?ooo`8000005`3oool700000200oooo1000000F0?ooo`<00000
3P3oool2000000`0oooo0P00001G0?ooo`00ZP3oool00`000000oooo0?oo
o`0;0?ooo`8000003`3oool3000001/0oooo2000000<0?ooo``000005`3o
ool3000000l0oooo0P00000=0?ooo`030000003oool0oooo05L0oooo002[
0?ooo`8000003@3oool200000100oooo0`00000P0?ooo``00000803oool3
00000100oooo0P00000=0?ooo`800000FP3oool00:d0oooo00<000000?oo
o`3oool0303oool200000140oooo0P0000170?ooo`<000004@3oool20000
00d0oooo0P00001L0?ooo`00[P3oool00`000000oooo0?ooo`0=0?ooo`80
00004@3oool300000440oooo0`00000B0?ooo`8000003P3oool00`000000
oooo0?ooo`1L0?ooo`00[`3oool2000000l0oooo0P00000B0?ooo`<00000
>`3oool3000001<0oooo0P00000>0?ooo`800000G`3oool00;40oooo00<0
00000?ooo`3oool03P3oool300000180oooo1000000d0?ooo`<00000503o
ool2000000l0oooo00<000000?ooo`3oool0G`3oool00;80oooo0P00000A
0?ooo`800000503oool7000002T0oooo1000000D0?ooo`<000003`3oool2
00000680oooo002d0?ooo`8000004@3oool2000001T0oooo2000000K0?oo
o`H000005@3oool300000100oooo0P00001T0?ooo`00]P3oool200000140
oooo0P00000O0?oooa/000006@3oool200000180oooo00<000000?ooo`3o
ool0I03oool00;P0oooo0P00000A0?ooo`<00000C@3oool300000180oooo
0P00001W0?ooo`00^P3oool200000180oooo100000160?ooo`<000004`3o
ool2000006T0oooo002l0?ooo`<000004`3oool400000400oooo0P00000D
0?ooo`800000J`3oool00;l0oooo0`00000D0?ooo`@00000>@3oool30000
01@0oooo0P00001]0?ooo`00`P3oool3000001D0oooo1@00000^0?ooo`H0
00005@3oool2000006l0oooo00350?ooo`800000603oool4000002<0oooo
1`00000H0?ooo`<00000L@3oool00<L0oooo0P00000J0?ooo`H00000603o
ool5000001`0oooo0`00001d0?ooo`00b@3oool3000001d0oooo6000000N
0?ooo`<00000M`3oool00<`0oooo0`00001>0?ooo`800000NP3oool00<l0
oooo0`0000180?ooo`<00000O03oool00=80oooo100000100?ooo`@00000
O`3oool00=H0oooo1000000g0?ooo`D00000P`3oool00=X0oooo1@00000]
0?ooo`D00000R03oool00=l0oooo1000000T0?ooo`D00000S@3oool00><0
oooo9000002B0?ooo`00o`3ooonJ0?ooo`00o`3ooonJ0?ooo`00o`3ooonJ
0?ooo`00o`3ooonJ0?ooo`00o`3ooonJ0?ooo`00o`3ooonJ0?ooo`00o`3o
oonJ0?ooo`00o`3ooonJ0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{409, 293},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\tFigure 1.28",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Are the points ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(z\_1\), " ", 
          StyleBox[\((blue)\),
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman"], " ", \(z\_2\), " ", 
          StyleBox[\((red)\),
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}]]],
  " in the interior or exterior of this simple closed curve?"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006F00019B000`400?l0
0000o`00003oo`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00
o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?oo
o`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00kP3ooolN
000008X0oooo003S0?ooo`/000007P3`oo04000008H0oooo003N0?ooo`D0
0000;@3`oo0500000840oooo003J0?ooo`@00000=`3`oo05000007`0oooo
003F0?ooo`@00000@03`oo04000007P0oooo003C0?ooo`<00000B03`oo03
000007D0oooo003@0?ooo`<00000CP3`oo0300000780oooo003=0?ooo`<0
00009`3`oo0=00000200l?o`0`00001_0?ooo`00bP3oool3000001X0l?o`
4000000=0?ooo`P000006`3`oo03000006`0oooo00380?ooo`8000005`3`
oo06000002D0oooo2000000F0?3ol0800000JP3oool00<D0oooo0`00000E
0?3ol0@00000<`3oool4000001@0l?o`0`00001W0?ooo`00``3oool20000
01D0l?o`0`00000k0?ooo`8000005@3`oo03000006@0oooo00310?ooo`80
0000503`oo0300000400oooo0`00000E0?3ol0800000HP3oool00;l0oooo
0P00000C0?3ol0<00000AP3oool4000001<0l?o`0P00001P0?ooo`00_@3o
ool200000140l?o`1000001=0?ooo`@000004@3`oo02000005h0oooo002k
0?ooo`8000003`3`oo0400000200oooo5@00000P0?ooo`<00000403`oo02
000005`0oooo002i0?ooo`8000003P3`oo03000001d0oooo1`00000E0?3o
l0X000006@3oool200000100l?o`0P00001J0?ooo`00^03oool00`000000
l?o`0?3ol00<0?3ol08000006@3oool7000002H0l?o`1@00000F0?ooo`80
0000403`oo02000005P0oooo002f0?ooo`8000003@3`oo02000001L0oooo
1000000b0?3ol0D000004`3oool200000100l?o`00<000000?ooo`3oool0
E@3oool00;@0oooo0P00000=0?3ol0800000503oool5000003/0l?o`0`00
000B0?ooo`8000003`3`oo02000005D0oooo002b0?ooo`8000003@3`oo02
00000180oooo100000130?3ol0<000004@3oool3000000h0l?o`0P00001C
0?ooo`00/03oool2000000d0l?o`0P00000@0?ooo`@00000BP3`oo030000
0140oooo0P00000>0?3ol0800000D@3oool00:l0oooo00<000000?3ol03`
oo002`3`oo0200000100oooo0P00001A0?3ol08000004@3oool2000000h0
l?o`00<000000?ooo`3oool0CP3oool00:d0oooo0P00000<0?3ol0800000
403oool2000001/0l?o`8@00000I0?3ol0<00000403oool2000000d0l?o`
0P00001>0?ooo`00[03oool00`000000l?o`0?3ol00:0?3ol0800000403o
ool2000001L0l?o`1P00000Q0?ooo`@00000603`oo03000000l0oooo0P00
000=0?3ol0800000C03oool00:/0oooo00<000000?3ol03`oo002P3`oo00
0`000000oooo0?ooo`0>0?ooo`8000005@3`oo04000002/0oooo1@00000F
0?3ol08000003`3oool2000000d0l?o`00<000000?ooo`3oool0B@3oool0
0:T0oooo0P00000;0?3ol08000003`3oool2000001<0l?o`1000000d0?oo
o`@00000503`oo02000000l0oooo00<000000?3ol03`oo002`3`oo000`00
0000oooo0?ooo`180?ooo`00Z03oool00`000000l?o`0?3ol0090?3ol080
00003`3oool200000140l?o`1000000l0?ooo`@000004P3`oo02000000h0
oooo00<000000?3ol03`oo002`3`oo000`000000oooo0?ooo`170?ooo`00
YP3oool2000000X0l?o`0P00000?0?ooo`800000403`oo03000004@0oooo
0P00000B0?3ol08000003@3oool2000000`0l?o`0P0000170?ooo`00Y@3o
ool00`000000l?o`0?3ol0080?3ol08000003`3oool200000100l?o`0P00
00190?ooo`<000004@3`oo02000000d0oooo00<000000?3ol03`oo002`3`
oo000`000000oooo0?ooo`140?ooo`00Y03oool00`000000l?o`0?3ol008
0?3ol0030000003oool0oooo00d0oooo0P00000?0?3ol0<000007@3oool?
00000280oooo0`00000@0?3ol0800000303oool00`000000l?o`0?3ol00;
0?3ol0030000003oool0oooo04<0oooo002R0?ooo`8000002P3`oo000`00
0000oooo0?ooo`0<0?ooo`8000003P3`oo03000001T0oooo1`00000?0?3o
l0h000005`3oool200000100l?o`00<000000?ooo`3oool02P3oool20000
00`0l?o`00<000000?ooo`3oool0@P3oool00:40oooo00<000000?3ol03`
oo002@3`oo000`000000oooo0?ooo`0;0?ooo`8000003P3`oo02000001D0
oooo1`00000T0?3ol0D00000503oool2000000l0l?o`0P00000<0?ooo`03
0000003`oo00l?o`00X0l?o`00<000000?ooo`3oool0@@3oool00:00oooo
00<000000?3ol03`oo00203`oo02000000`0oooo0P00000>0?3ol0800000
4`3oool400000300l?o`1000000B0?ooo`<000003P3`oo02000000/0oooo
0P00000;0?3ol0800000@@3oool009h0oooo0P00000:0?3ol0030000003o
ool0oooo00/0oooo00<000000?3ol03`oo00303`oo0200000140oooo1000
000h0?3ol0<000004P3oool2000000h0l?o`00<000000?ooo`3oool02P3o
ool00`000000l?o`0?3ol00:0?3ol0030000003oool0oooo03h0oooo002M
0?ooo`030000003`oo00l?o`00T0l?o`00<000000?ooo`3oool02P3oool2
000000d0l?o`0P00000A0?ooo`800000?`3`oo0200000180oooo0P00000=
0?3ol08000002`3oool00`000000l?o`0?3ol00:0?3ol0030000003oool0
oooo03d0oooo002L0?ooo`030000003`oo00l?o`00T0l?o`00<000000?oo
o`3oool02@3oool2000000d0l?o`0P00000@0?ooo`<00000@`3`oo030000
0140oooo0P00000=0?3ol08000002P3oool2000000/0l?o`00<000000?oo
o`3oool0?03oool009/0oooo00<000000?3ol03`oo002@3`oo000`000000
oooo0?ooo`090?ooo`030000003`oo00l?o`00/0l?o`0P00000@0?ooo`80
0000B@3`oo0300000100oooo0P00000=0?3ol0030000003oool0oooo00T0
oooo00<000000?3ol03`oo002@3`oo000`000000oooo0?ooo`0k0?ooo`00
VP3oool00`000000l?o`0?3ol0090?3ol0030000003oool0oooo00T0oooo
00<000000?3ol03`oo002P3`oo0200000100oooo0P00000I0?3ol1/00000
6P3`oo0200000100oooo00<000000?3ol03`oo002`3`oo000`000000oooo
0?ooo`090?ooo`030000003`oo00l?o`00T0l?o`0P00000k0?ooo`00V@3o
ool00`000000l?o`0?3ol0080?3ol08000002`3oool00`000000l?o`0?3o
l00:0?3ol0030000003oool0oooo00h0oooo0P00000F0?3ol0D000006`3o
ool7000001D0l?o`0P00000?0?ooo`800000303`oo02000000X0oooo00<0
00000?3ol03`oo002P3`oo000`000000oooo0?ooo`0h0?ooo`00V03oool0
0`000000l?o`0?3ol0080?3ol0030000003oool0oooo00T0oooo0P00000;
0?3ol08000003`3oool2000001@0l?o`1000000W0?ooo`D000004P3`oo02
000000l0oooo0P00000<0?3ol0030000003oool0oooo00P0oooo0P00000;
0?3ol0030000003oool0oooo03L0oooo002H0?ooo`030000003`oo00l?o`
00L0l?o`00<000000?ooo`3oool02@3oool00`000000l?o`0?3ol00:0?3o
l0030000003oool0oooo00d0oooo0P00000B0?3ol0@00000<03oool30000
0140l?o`0P00000?0?ooo`030000003`oo00l?o`00X0l?o`00<000000?oo
o`3oool02@3oool00`000000l?o`0?3ol0090?3ol0030000003oool0oooo
03H0oooo002G0?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3o
ool02@3oool00`000000l?o`0?3ol00:0?3ol0030000003oool0oooo00`0
oooo0P00000@0?3ol0@00000=`3oool300000100l?o`0P00000>0?ooo`80
00002`3`oo02000000X0oooo00<000000?3ol03`oo002@3`oo000`000000
oooo0?ooo`0e0?ooo`00UP3oool00`000000l?o`0?3ol0070?3ol0030000
003oool0oooo00T0oooo00<000000?3ol03`oo002@3`oo02000000d0oooo
0P00000?0?3ol0<00000?P3oool200000100l?o`0P00000>0?ooo`030000
003`oo00l?o`00X0l?o`00<000000?ooo`3oool0203oool00`000000l?o`
0?3ol0080?3ol0030000003oool0oooo03D0oooo002E0?ooo`030000003`
oo00l?o`00L0l?o`00<000000?ooo`3oool02@3oool00`000000l?o`0?3o
l0090?3ol0030000003oool0oooo00/0oooo0P00000?0?3ol0800000@`3o
ool3000000l0l?o`0P00000=0?ooo`8000002`3`oo000`000000oooo0?oo
o`080?ooo`030000003`oo00l?o`00P0l?o`00<000000?ooo`3oool0=03o
ool009@0oooo00<000000?3ol03`oo001`3`oo000`000000oooo0?ooo`09
0?ooo`030000003`oo00l?o`00P0l?o`0P00000<0?ooo`8000003`3`oo02
000004P0oooo0`00000>0?3ol08000003@3oool2000000X0l?o`0P000009
0?ooo`030000003`oo00l?o`00P0l?o`00<000000?ooo`3oool0<`3oool0
09<0oooo00<000000?3ol03`oo001`3`oo000`000000oooo0?ooo`090?oo
o`030000003`oo00l?o`00P0l?o`00<000000?ooo`3oool02P3oool20000
00l0l?o`0P00000G0?oooa`000006P3oool2000000h0l?o`0P00000=0?oo
o`030000003`oo00l?o`00T0l?o`00<000000?ooo`3oool01`3oool00`00
0000l?o`0?3ol0080?3ol0030000003oool0oooo0380oooo002B0?ooo`03
0000003`oo00l?o`00L0l?o`00<000000?ooo`3oool0203oool2000000X0
l?o`00<000000?ooo`3oool02P3oool00`000000l?o`0?3ol00=0?3ol080
0000503oool5000001`0l?o`1@00000G0?ooo`8000003P3`oo02000000`0
oooo00<000000?3ol03`oo002@3`oo000`000000oooo0?ooo`070?ooo`80
00002@3`oo000`000000oooo0?ooo`0a0?ooo`00T@3oool00`000000l?o`
0?3ol0070?3ol0030000003oool0oooo00P0oooo00<000000?3ol03`oo00
2@3`oo000`000000oooo0?ooo`090?ooo`8000003P3`oo02000001<0oooo
0`00000V0?3ol0@000005@3oool2000000h0l?o`00<000000?ooo`3oool0
2P3oool00`000000l?o`0?3ol0090?3ol0030000003oool0oooo00P0oooo
00<000000?3ol03`oo001`3`oo000`000000oooo0?ooo`0`0?ooo`00T03o
ool00`000000l?o`0?3ol0080?3ol0030000003oool0oooo00L0oooo00<0
00000?3ol03`oo002@3`oo000`000000oooo0?ooo`080?ooo`8000003P3`
oo0200000180oooo0`00000]0?3ol0@000004`3oool2000000d0l?o`00<0
00000?ooo`3oool02P3oool00`000000l?o`0?3ol0090?3ol0030000003o
ool0oooo00P0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?oo
o`0`0?ooo`00S`3oool00`000000l?o`0?3ol0080?3ol0030000003oool0
oooo00L0oooo00<000000?3ol03`oo002@3`oo000`000000oooo0?ooo`08
0?ooo`030000003`oo00l?o`00`0l?o`0P00000@0?ooo`@00000=03`oo03
00000180oooo0P00000<0?3ol08000002`3oool00`000000l?o`0?3ol009
0?3ol0030000003oool0oooo00P0oooo00<000000?3ol03`oo001P3`oo00
0`000000oooo0?ooo`0_0?ooo`00SP3oool00`000000l?o`0?3ol0080?3o
l0030000003oool0oooo00L0oooo00<000000?3ol03`oo002@3`oo000`00
0000oooo0?ooo`080?ooo`030000003`oo00l?o`00/0l?o`0P00000?0?oo
o`<00000>`3`oo0300000140oooo0P00000<0?3ol0030000003oool0oooo
00T0oooo00<000000?3ol03`oo002@3`oo000`000000oooo0?ooo`080?oo
o`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0;P3oool008d0
oooo00<000000?3ol03`oo00203`oo000`000000oooo0?ooo`070?ooo`03
0000003`oo00l?o`00P0l?o`0P00000:0?ooo`030000003`oo00l?o`00X0
l?o`0P00000?0?ooo`800000@@3`oo04000000l0oooo0P00000;0?3ol003
0000003oool0oooo00T0oooo0P00000:0?3ol0030000003oool0oooo00P0
oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`0]0?ooo`00
S03oool00`000000l?o`0?3ol0080?3ol0030000003oool0oooo00L0oooo
00<000000?3ol03`oo00203`oo000`000000oooo0?ooo`080?ooo`800000
303`oo000`000000oooo0?ooo`0=0?ooo`8000006`3`oo0C000001T0l?o`
0P00000?0?ooo`8000002P3`oo000`000000oooo0?ooo`0:0?ooo`030000
003`oo00l?o`00P0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`
0?3ol0070?3ol0030000003oool0oooo02`0oooo002;0?ooo`030000003`
oo00l?o`00P0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3o
l0080?3ol0030000003oool0oooo00P0oooo00<000000?3ol03`oo002P3`
oo02000000h0oooo0P00000G0?3ol0H000004`3oool6000001D0l?o`0P00
000?0?ooo`030000003`oo00l?o`00P0l?o`0P00000;0?ooo`030000003`
oo00l?o`00P0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3o
l0070?3ol0030000003oool0oooo02/0oooo002:0?ooo`030000003`oo00
l?o`00P0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol008
0?3ol0030000003oool0oooo00P0oooo00<000000?3ol03`oo002P3`oo00
0`000000oooo0?ooo`0<0?ooo`800000503`oo05000001l0oooo1000000C
0?3ol08000003P3oool2000000X0l?o`00<000000?ooo`3oool02@3oool0
0`000000l?o`0?3ol0080?3ol0030000003oool0oooo00L0oooo00<00000
0?3ol03`oo001P3`oo000`000000oooo0?ooo`0[0?ooo`00RP3oool00`00
0000l?o`0?3ol0070?3ol0030000003oool0oooo00L0oooo00<000000?3o
l03`oo00203`oo000`000000oooo0?ooo`080?ooo`030000003`oo00l?o`
00X0l?o`00<000000?ooo`3oool02`3oool2000001<0l?o`0`00000X0?oo
o`<000004P3`oo02000000h0oooo00<000000?3ol03`oo00203`oo000`00
0000oooo0?ooo`090?ooo`030000003`oo00l?o`00P0l?o`00<000000?oo
o`3oool01`3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo
02X0oooo00290?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3o
ool01`3oool00`000000l?o`0?3ol0080?3ol0030000003oool0oooo00P0
oooo00<000000?3ol03`oo002@3`oo02000000`0oooo0P00000A0?3ol0@0
0000;P3oool300000140l?o`00<000000?ooo`3oool0303oool00`000000
l?o`0?3ol0080?3ol08000002P3oool00`000000l?o`0?3ol0080?3ol003
0000003oool0oooo00H0oooo00<000000?3ol03`oo001`3`oo000`000000
oooo0?ooo`0Y0?ooo`00R@3oool00`000000l?o`0?3ol0070?3ol0030000
003oool0oooo00L0oooo00<000000?3ol03`oo001`3`oo000`000000oooo
0?ooo`070?ooo`8000002`3`oo000`000000oooo0?ooo`0;0?ooo`030000
003`oo00l?o`00d0l?o`1000000e0?ooo`<000003`3`oo02000000d0oooo
0P00000:0?3ol0030000003oool0oooo00P0oooo00<000000?3ol03`oo00
203`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00L0l?o`
00<000000?ooo`3oool0:03oool008P0oooo00<000000?3ol03`oo001`3`
oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00L0l?o`00<0
00000?ooo`3oool01`3oool00`000000l?o`0?3ol00:0?3ol0030000003o
ool0oooo00X0oooo0P00000>0?3ol0800000?03oool2000000l0l?o`0P00
000=0?ooo`030000003`oo00l?o`00P0l?o`00<000000?ooo`3oool0203o
ool00`000000l?o`0?3ol0080?3ol0030000003oool0oooo00H0oooo00<0
00000?3ol03`oo001P3`oo000`000000oooo0?ooo`0X0?ooo`00Q`3oool0
0`000000l?o`0?3ol0070?3ol0030000003oool0oooo00L0oooo00<00000
0?3ol03`oo001`3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00
l?o`00T0l?o`0P00000;0?ooo`8000003P3`oo0200000400oooo0`00000>
0?3ol0030000003oool0oooo00/0oooo00<000000?3ol03`oo00203`oo00
0`000000oooo0?ooo`080?ooo`030000003`oo00l?o`00L0l?o`00<00000
0?ooo`3oool01`3oool00`000000l?o`0?3ol0060?3ol0030000003oool0
oooo02L0oooo00270?ooo`030000003`oo00l?o`00H0l?o`00<000000?oo
o`3oool01`3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo
00L0oooo00<000000?3ol03`oo002@3`oo000`000000oooo0?ooo`090?oo
o`8000003P3`oo02000001T0oooo5@00000G0?ooo`8000003@3`oo020000
00`0oooo0P0000090?3ol0030000003oool0oooo00P0oooo00<000000?3o
l03`oo001`3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`
00H0l?o`00<000000?ooo`3oool09P3oool008H0oooo00<000000?3ol03`
oo001`3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00L0
l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol0090?3ol003
0000003oool0oooo00T0oooo00<000000?3ol03`oo00303`oo02000001D0
oooo1P00000E0?3ol0D00000503oool2000000d0l?o`0P00000<0?ooo`03
0000003`oo00l?o`00L0l?o`00<000000?ooo`3oool01`3oool00`000000
l?o`0?3ol0080?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`
oo001P3`oo000`000000oooo0?ooo`0V0?ooo`00QP3oool00`000000l?o`
0?3ol0060?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo00
1`3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00T0l?o`
00<000000?ooo`3oool02@3oool00`000000l?o`0?3ol00;0?3ol0800000
4P3oool500000200l?o`1000000B0?ooo`8000003@3`oo02000000/0oooo
00<000000?3ol03`oo001`3`oo000`000000oooo0?ooo`070?ooo`030000
003`oo00l?o`00P0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`
0?3ol0060?3ol0030000003oool0oooo02D0oooo00250?ooo`030000003`
oo00l?o`00H0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3o
l0070?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`oo002@3`
oo000`000000oooo0?ooo`080?ooo`800000303`oo0200000140oooo0`00
000Y0?3ol08000004P3oool2000000d0l?o`00<000000?ooo`3oool02@3o
ool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo00L0oooo00<0
00000?3ol03`oo001`3`oo000`000000oooo0?ooo`070?ooo`030000003`
oo00l?o`00H0l?o`00<000000?ooo`3oool0903oool008@0oooo00<00000
0?3ol03`oo001P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00
l?o`00P0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol008
0?3ol0030000003oool0oooo00P0oooo00<000000?3ol03`oo002P3`oo02
00000100oooo0`00000^0?3ol0@00000403oool2000000`0l?o`00<00000
0?ooo`3oool02@3oool00`000000l?o`0?3ol0070?3ol0030000003oool0
oooo00L0oooo00<000000?3ol03`oo001`3`oo000`000000oooo0?ooo`07
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0903oool0
08@0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`060?oo
o`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool01`3oool00`00
0000l?o`0?3ol0080?3ol0030000003oool0oooo00P0oooo00<000000?3o
l03`oo002@3`oo0200000100oooo0P00000e0?3ol0<000003`3oool00`00
0000l?o`0?3ol00:0?3ol0030000003oool0oooo00T0oooo00<000000?3o
l03`oo001`3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`
00L0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol0060?3o
l0030000003oool0oooo02<0oooo00230?ooo`030000003`oo00l?o`00H0
l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol0070?3ol003
0000003oool0oooo00L0oooo00<000000?3ol03`oo001`3`oo02000000X0
oooo00<000000?3ol03`oo00203`oo02000000l0oooo0`00000j0?3ol080
00003P3oool2000000/0l?o`00<000000?ooo`3oool02@3oool00`000000
l?o`0?3ol0070?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`
oo001`3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool08`3oool008<0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00H0l?o`
00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol0070?3ol0030000
003oool0oooo00P0oooo0P0000090?3ol08000003`3oool2000001X0l?o`
2P00000K0?3ol08000003P3oool00`000000l?o`0?3ol0090?3ol0030000
003oool0oooo00T0oooo00<000000?3ol03`oo001`3`oo000`000000oooo
0?ooo`060?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool0
1P3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo0280oooo
00220?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01`3o
ool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00L0oooo00<0
00000?3ol03`oo001`3`oo000`000000oooo0?ooo`080?ooo`030000003`
oo00l?o`00P0l?o`00<000000?ooo`3oool03@3oool2000001H0l?o`1P00
000:0?ooo`T00000503`oo02000000d0oooo0P00000:0?3ol0030000003o
ool0oooo00T0oooo00<000000?3ol03`oo001`3`oo000`000000oooo0?oo
o`060?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool01P3o
ool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo0240oooo0021
0?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01P3oool0
0`000000l?o`0?3ol0060?3ol0030000003oool0oooo00L0oooo00<00000
0?3ol03`oo001`3`oo000`000000oooo0?ooo`080?ooo`030000003`oo00
l?o`00P0l?o`00<000000?ooo`3oool0303oool200000140l?o`1`00000I
0?ooo`800000503`oo02000000d0oooo00<000000?3ol03`oo00203`oo02
000000X0oooo00<000000?3ol03`oo001`3`oo000`000000oooo0?ooo`06
0?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool01P3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo0240oooo00210?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01`3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00P0oooo00<000000?3o
l03`oo001P3`oo000`000000oooo0?ooo`080?ooo`030000003`oo00l?o`
00P0l?o`00<000000?ooo`3oool02`3oool200000100l?o`0`00000R0?oo
o`<000004`3`oo02000000`0oooo00<000000?3ol03`oo002@3`oo000`00
0000oooo0?ooo`080?ooo`030000003`oo00l?o`00L0l?o`00<000000?oo
o`3oool01P3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`0P0?oo
o`00P03oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00L0
oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`070?ooo`03
0000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0203oool00`000000
l?o`0?3ol0080?3ol0030000003oool0oooo00X0oooo0P00000@0?3ol080
0000:03oool400000140l?o`0P00000;0?ooo`8000002P3`oo000`000000
oooo0?ooo`080?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo00H0
oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`0O0?ooo`00
P03oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00L0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`070?ooo`030000
003`oo00l?o`00H0l?o`00<000000?ooo`3oool0203oool00`000000l?o`
0?3ol0080?3ol0030000003oool0oooo00T0oooo0P00000?0?3ol0<00000
;P3oool300000100l?o`00<000000?ooo`3oool02P3oool00`000000l?o`
0?3ol0080?3ol0030000003oool0oooo00P0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00L0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000
003oool0oooo01l0oooo001o0?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool01`3oool00`000000l?o`0?3ol0060?3ol0030000003o
ool0oooo00H0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?oo
o`080?ooo`030000003`oo00l?o`00L0l?o`0P00000;0?ooo`030000003`
oo00l?o`00d0l?o`0P00000d0?ooo`8000003`3`oo000`000000oooo0?oo
o`0:0?ooo`030000003`oo00l?o`00P0l?o`00<000000?ooo`3oool0203o
ool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00H0oooo00<0
00000?3ol03`oo001`3`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00H0l?o`00<000000?ooo`3oool07P3oool007l0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00
l?o`00H0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol007
0?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`oo001`3`oo00
0`000000oooo0?ooo`0:0?ooo`030000003`oo00l?o`00`0l?o`0P00000h
0?ooo`8000003P3`oo02000000/0oooo0P0000090?3ol0030000003oool0
oooo00P0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`06
0?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0070?3ol0030000003oool0oooo01d0oooo001n0?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01`3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00L0oooo00<000000?3o
l03`oo001P3`oo000`000000oooo0?ooo`080?ooo`030000003`oo00l?o`
00H0l?o`00<000000?ooo`3oool02@3oool2000000d0l?o`0P00000G0?oo
oa0000005@3oool2000000h0l?o`00<000000?ooo`3oool02P3oool00`00
0000l?o`0?3ol0070?3ol0030000003oool0oooo00L0oooo00<000000?3o
l03`oo001P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`
00L0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3o
l0030000003oool0oooo01d0oooo001n0?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol0060?3ol003
0000003oool0oooo00H0oooo00<000000?3ol03`oo001P3`oo000`000000
oooo0?ooo`080?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3o
ool02@3oool00`000000l?o`0?3ol00;0?3ol08000004`3oool600000100
l?o`1@00000B0?ooo`8000003@3`oo02000000/0oooo00<000000?3ol03`
oo001`3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00H0
l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol0060?3ol003
0000003oool0oooo00H0oooo00<000000?3ol03`oo001P3`oo000`000000
oooo0?ooo`0L0?ooo`00O@3oool00`000000l?o`0?3ol0050?3ol0030000
003oool0oooo00L0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0
203oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00T0oooo
00<000000?3ol03`oo002P3`oo0200000140oooo1000000K0?3ol0<00000
4@3oool2000000d0l?o`00<000000?ooo`3oool02@3oool00`000000l?o`
0?3ol0060?3ol0030000003oool0oooo00P0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000
003oool0oooo01`0oooo001m0?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool01P3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00L0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`080?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0203o
ool2000000/0l?o`0P00000?0?ooo`@000008P3`oo04000000l0oooo0P00
000<0?3ol0030000003oool0oooo00P0oooo00<000000?3ol03`oo001`3`
oo000`000000oooo0?ooo`080?ooo`030000003`oo00l?o`00H0l?o`00<0
00000?ooo`3oool01P3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00H0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?oo
o`0K0?ooo`00O03oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00H0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`06
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0203oool0
0`000000l?o`0?3ol0060?3ol0030000003oool0oooo00P0oooo00<00000
0?3ol03`oo002P3`oo000`000000oooo0?ooo`0=0?ooo`800000:P3`oo02
000000l0oooo0P00000;0?3ol0030000003oool0oooo00P0oooo00<00000
0?3ol03`oo001`3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00
l?o`00H0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol006
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001P3`oo00
0`000000oooo0?ooo`0K0?ooo`00O03oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00H0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`00<000000?oo
o`3oool01`3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo
00L0oooo00<000000?3ol03`oo002@3`oo02000000h0oooo0P00000^0?3o
l08000003`3oool00`000000l?o`0?3ol0090?3ol0030000003oool0oooo
00P0oooo00<000000?3ol03`oo001`3`oo000`000000oooo0?ooo`070?oo
o`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01P3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo00<000000?3o
l03`oo001P3`oo000`000000oooo0?ooo`0J0?ooo`00N`3oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`
oo001P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol0070?3ol003
0000003oool0oooo00L0oooo00<000000?3ol03`oo002@3`oo000`000000
oooo0?ooo`0<0?ooo`800000<P3`oo02000000h0oooo00<000000?3ol03`
oo002@3`oo000`000000oooo0?ooo`080?ooo`030000003`oo00l?o`00H0
l?o`00<000000?ooo`3oool0203oool00`000000l?o`0?3ol0060?3ol003
0000003oool0oooo00H0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3o
ool06P3oool007/0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`060?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
1P3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00P0oooo
00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`070?ooo`030000
003`oo00l?o`00T0l?o`00<000000?ooo`3oool02`3oool2000003H0l?o`
0P00000=0?ooo`8000002P3`oo000`000000oooo0?ooo`080?ooo`030000
003`oo00l?o`00H0l?o`00<000000?ooo`3oool0203oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`
00<000000?ooo`3oool06@3oool007/0oooo00<000000?3ol03`oo00103`
oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`00<0
00000?ooo`3oool01P3oool00`000000l?o`0?3ol0040?3ol0030000003o
ool0oooo00P0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?oo
o`070?ooo`030000003`oo00l?o`00P0l?o`0P00000<0?ooo`8000004P3`
oo0F00000180l?o`0P00000=0?ooo`030000003`oo00l?o`00P0l?o`00<0
00000?ooo`3oool01`3oool00`000000l?o`0?3ol0070?3ol0030000003o
ool0oooo00L0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?oo
o`060?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo01T0oooo001j
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01P3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00
l?o`00H0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol008
0?3ol0030000003oool0oooo00X0oooo0P00000A0?3ol0<000005P3oool4
00000100l?o`0P00000<0?ooo`030000003`oo00l?o`00P0l?o`00<00000
0?ooo`3oool01`3oool00`000000l?o`0?3ol0070?3ol0030000003oool0
oooo00L0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`06
0?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0060?3ol0030000003oool0oooo01P0oooo001j0?oo
o`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01P3oool00`00
0000l?o`0?3ol0060?3ol0030000003oool0oooo00D0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`
00L0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol0080?3o
l0030000003oool0oooo00X0oooo00<000000?3ol03`oo003@3`oo040000
01d0oooo0P00000@0?3ol08000002`3oool2000000T0l?o`00<000000?oo
o`3oool01`3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo
00P0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`060?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0060?3ol0030000003oool0oooo01P0oooo001j0?ooo`03
0000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01P3oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00H0
l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol0080?3ol003
0000003oool0oooo00T0oooo0P00000>0?3ol08000008`3oool3000000l0
l?o`00<000000?ooo`3oool02P3oool00`000000l?o`0?3ol0070?3ol003
0000003oool0oooo00L0oooo00<000000?3ol03`oo001P3`oo000`000000
oooo0?ooo`070?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool01P3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00D0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`0H0?ooo`00
N@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`
0?3ol0060?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo00
203`oo000`000000oooo0?ooo`090?ooo`030000003`oo00l?o`00`0l?o`
0P00000X0?ooo`8000003P3`oo000`000000oooo0?ooo`0:0?ooo`030000
003`oo00l?o`00L0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`
0?3ol0070?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00D0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000
003oool0oooo01L0oooo001i0?ooo`030000003`oo00l?o`00@0l?o`00<0
00000?ooo`3oool01P3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?oo
o`060?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01P3o
ool00`000000l?o`0?3ol0070?3ol08000002`3oool00`000000l?o`0?3o
l00:0?3ol0<00000;03oool2000000d0l?o`0P00000;0?ooo`030000003`
oo00l?o`00L0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3o
l0070?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo01L0oooo001h0?ooo`030000003`oo00l?o`00D0l?o`00<00000
0?ooo`3oool01P3oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`06
0?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0070?3ol0030000003oool0oooo00T0oooo0P00000;
0?3ol0800000<@3oool2000000d0l?o`00<000000?ooo`3oool02@3oool0
0`000000l?o`0?3ol0070?3ol0030000003oool0oooo00H0oooo00<00000
0?3ol03`oo001P3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001P3`oo00
0`000000oooo0?ooo`0F0?ooo`00N03oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<000000?oo
o`3oool01P3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo
00H0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`090?oo
o`030000003`oo00l?o`00T0l?o`0P00000F0?ooo`T000005P3oool20000
00`0l?o`00<000000?ooo`3oool02@3oool00`000000l?o`0?3ol0070?3o
l0030000003oool0oooo00H0oooo00<000000?3ol03`oo001P3`oo000`00
0000oooo0?ooo`060?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool01P3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`0F0?oo
o`00N03oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01P3oool00`000000
l?o`0?3ol0060?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`
oo001P3`oo000`000000oooo0?ooo`090?ooo`030000003`oo00l?o`00T0
l?o`00<000000?ooo`3oool03`3oool7000000T0l?o`1`00000A0?ooo`80
00002`3`oo02000000X0oooo00<000000?3ol03`oo001P3`oo000`000000
oooo0?ooo`060?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3o
ool01P3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00H0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool05P3oool007L0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0060?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`
00<000000?ooo`3oool02@3oool00`000000l?o`0?3ol0080?3ol0800000
403oool2000001L0l?o`1000000?0?ooo`8000002`3`oo000`000000oooo
0?ooo`080?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0
1P3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00H0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`060?ooo`030000
003`oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo01D0oooo001g0?ooo`030000003`
oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`00<0
00000?ooo`3oool01P3oool00`000000l?o`0?3ol0060?3ol0030000003o
ool0oooo00P0oooo00<000000?3ol03`oo00203`oo000`000000oooo0?oo
o`0>0?ooo`8000007@3`oo03000000h0oooo0P00000:0?3ol0030000003o
ool0oooo00P0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?oo
o`060?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01P3o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00D0l?o`00<000000?ooo`3oool05@3oool007L0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol006
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001P3`oo00
0`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`00<00000
0?ooo`3oool0203oool00`000000l?o`0?3ol0080?3ol0030000003oool0
oooo00`0oooo0`00000R0?3ol08000003P3oool00`000000l?o`0?3ol008
0?3ol08000002@3oool00`000000l?o`0?3ol0060?3ol0030000003oool0
oooo00H0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01P3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo00<00000
0?3ol03`oo00103`oo000`000000oooo0?ooo`0E0?ooo`00MP3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00H0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00H0oooo00<000000?3ol03`oo001P3`oo000`00
0000oooo0?ooo`080?ooo`030000003`oo00l?o`00P0l?o`00<000000?oo
o`3oool02`3oool2000002L0l?o`00<000000?ooo`3oool0303oool00`00
0000l?o`0?3ol0090?3ol0030000003oool0oooo00H0oooo00<000000?3o
l03`oo001`3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00H0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00H0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool0503oool007H0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3o
ool01P3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0
oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`060?ooo`03
0000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01`3oool00`000000
l?o`0?3ol0070?3ol0800000303oool2000002X0l?o`0P00000=0?ooo`80
00002P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00L0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`060?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo01@0
oooo001f0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`
0?3ol0060?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`oo00
1`3`oo000`000000oooo0?ooo`0:0?ooo`800000;P3`oo02000000d0oooo
00<000000?3ol03`oo001`3`oo000`000000oooo0?ooo`070?ooo`030000
003`oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0070?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00D0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000
003oool0oooo01@0oooo001e0?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01P3o
ool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00L0oooo00<0
00000?3ol03`oo001`3`oo000`000000oooo0?ooo`090?ooo`8000004P3`
oo0?00000140l?o`0P00000<0?ooo`030000003`oo00l?o`00L0l?o`00<0
00000?ooo`3oool01`3oool00`000000l?o`0?3ol0060?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01P3o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`0C0?ooo`00M@3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00H0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo001P3`oo00
0`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00L0l?o`00<00000
0?ooo`3oool02@3oool00`000000l?o`0?3ol00=0?3ol0D000003`3oool3
00000100l?o`00<000000?ooo`3oool02P3oool00`000000l?o`0?3ol007
0?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo001P3`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00L0l?o`00<00000
0?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`06
0?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool04`3oool0
07D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`
00H0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol0070?3o
l0030000003oool0oooo00T0oooo00<000000?3ol03`oo00303`oo020000
01L0oooo0`00000>0?3ol08000002`3oool00`000000l?o`0?3ol0070?3o
l0030000003oool0oooo00H0oooo00<000000?3ol03`oo001P3`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00H0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool04P3oool007D0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000
l?o`0?3ol0060?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol0060?3ol003
0000003oool0oooo00P0oooo0P00000=0?3ol0800000703oool3000000d0
l?o`00<000000?ooo`3oool02@3oool00`000000l?o`0?3ol0060?3ol003
0000003oool0oooo00L0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3o
ool0103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00H0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool04P3oool007@0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`
0?3ol0060?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`
00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol0060?3ol0030000
003oool0oooo00P0oooo00<000000?3ol03`oo002`3`oo0200000240oooo
0P00000<0?3ol0030000003oool0oooo00T0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00D0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo0180oooo
001d0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00D0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3o
l0050?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo001`3`
oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00X0l?o`0P00
000U0?ooo`8000002`3`oo000`000000oooo0?ooo`080?ooo`030000003`
oo00l?o`00L0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3o
l0060?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo001P3`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`0A0?ooo`00M03oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`04
0?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00L0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol009
0?3ol0800000:@3oool2000000X0l?o`0P0000090?ooo`030000003`oo00
l?o`00L0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001P3`oo00
0`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00H0l?o`00<00000
0?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`0A
0?ooo`00M03oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`
00H0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol0090?3o
l0030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`00
0000l?o`0?3ol0090?3ol0030000003oool0oooo00L0oooo00<000000?3o
l03`oo001P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`
00H0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0060?3o
l0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
0140oooo001c0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0060?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`
oo001P3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00P0
l?o`0P00000?0?ooo`P0000000<0l?o`0000000000001@00000@0?ooo`03
0000003`oo00l?o`00T0l?o`00<000000?ooo`3oool01`3oool00`000000
l?o`0?3ol0060?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0
l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo001P3`oo000`000000
oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool04@3oool007<0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00H0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0070?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`oo00
1P3`oo02000000l0oooo0P00000@0?3ol0<000003P3oool2000000X0l?o`
00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol0050?3ol0030000
003oool0oooo00H0oooo00<000000?3ol03`oo001P3`oo000`000000oooo
0?ooo`040?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000
003`oo00l?o`00H0l?o`00<000000?ooo`3oool0403oool007<0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`
oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3o
l0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000003o
ool0oooo00L0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?oo
o`0<0?ooo`<000005@3`oo02000000h0oooo00<000000?3ol03`oo001`3`
oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00H0l?o`00<0
00000?ooo`3oool01P3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`0@0?ooo`00L`3oool0
0`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<00000
0?ooo`3oool01`3oool00`000000l?o`0?3ol0060?3ol0030000003oool0
oooo00/0oooo0P00000J0?3ol0<00000303oool00`000000l?o`0?3ol007
0?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`00<00000
0?ooo`3oool0103oool00`000000l?o`0?3ol0060?3ol0030000003oool0
oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo0100oooo001b0?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0060?3o
l0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`070?ooo`030000003`oo00l?o`00H0l?o`00<000000?oo
o`3oool02P3oool2000001l0l?o`0P00000;0?ooo`030000003`oo00l?o`
00L0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol0060?3o
l0030000003oool0oooo00H0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0403oool00780
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00@0l?o`00<000000?ooo`3oool0103oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`
oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol0050?3ol003
0000003oool0oooo00L0oooo00<000000?3ol03`oo001P3`oo000`000000
oooo0?ooo`080?ooo`8000008`3`oo000`000000oooo0?ooo`090?ooo`03
0000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01`3oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool0403oool00780oooo00<000000?3ol03`oo00103`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`080?ooo`030000003`oo00l?o`02@0l?o`
0P00000:0?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0
1P3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0060?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
103`oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`
00<000000?ooo`3oool0403oool00780oooo00<000000?3ol03`oo00103`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo00<0
00000?3ol03`oo001P3`oo000`000000oooo0?ooo`080?ooo`030000003`
oo00l?o`00d0l?o`2P00000@0?3ol0030000003oool0oooo00P0oooo00<0
00000?3ol03`oo001P3`oo000`000000oooo0?ooo`060?ooo`030000003`
oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`0?0?ooo`00LP3oool00`000000l?o`0?3ol0040?3ol0030000003oool0
oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00P0oooo00<000000?3ol03`oo002P3`oo04
000000X0oooo0`00000>0?3ol0030000003oool0oooo00P0oooo00<00000
0?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00H0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo00103`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<00000
0?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`0?
0?ooo`00L@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01P3oool00`00
0000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00D0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00P0oooo00<000000?3ol03`oo002@3`oo020000
0140oooo0`00000<0?3ol08000002@3oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00H0oooo00<000000?3ol03`oo001P3`oo000`00
0000oooo0?ooo`040?ooo`030000003`oo00l?o`00H0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo
00H0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`050?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00l0oooo001a0?ooo`03
0000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000
oooo0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3o
ool01P3oool2000000X0l?o`0P00000F0?ooo`<000002`3`oo000`000000
oooo0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00D0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool03`3oool00740oooo00<000000?3ol03`oo00
103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`
00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`060?ooo`030000
003`oo00l?o`00T0l?o`00<000000?ooo`3oool06@3oool00`000000l?o`
0?3ol0090?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`
00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3ol0030000
003oool0oooo00H0oooo00<000000?3ol03`oo00103`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`0?0?ooo`00L@3o
ool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00H0oooo00<000000?3ol03`oo00203`oo02000001d0oooo00<0
00000?3ol03`oo00203`oo000`000000oooo0?ooo`070?ooo`030000003`
oo00l?o`00H0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3o
l0060?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00@0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool03P3o
ool00740oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00@0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol004
0?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00L0l?o`00<00000
0?ooo`3oool07P3oool00`000000l?o`0?3ol0080?3ol0030000003oool0
oooo00H0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol004
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`0>0?ooo`00L03oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`060?oo
o`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo00<000000?3o
l03`oo001`3`oo000`000000oooo0?ooo`0P0?ooo`8000002@3`oo000`00
0000oooo0?ooo`060?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`
00D0l?o`00<000000?ooo`3oool03P3oool00700oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`060?ooo`03
0000003`oo00l?o`00H0l?o`00<000000?ooo`3oool02`3oool;000000d0
oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`060?ooo`03
0000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00@0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol003
0000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool03P3oool00700oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0040?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`
00<000000?ooo`3oool02@3oool3000000/0l?o`0P00000<0?ooo`030000
003`oo00l?o`00H0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00h0oooo
001`0?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`
oo00l?o`00H0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3o
l0050?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool01P3oool00`000000l?o`0?3ol0060?3ol0030000003o
ool0oooo00P0oooo00<000000?3ol03`oo003P3`oo02000000X0oooo00<0
00000?3ol03`oo001P3`oo000`000000oooo0?ooo`060?ooo`030000003`
oo00l?o`00D0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3o
l0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool03@3o
ool00700oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<00000
0?3ol03`oo001P3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<00000
0?ooo`3oool0203oool00`000000l?o`0?3ol00A0?3ol0030000003oool0
oooo00P0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`06
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0040?3ol0030000003oool0oooo00H0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<00000
0?ooo`3oool03@3oool00700oooo00<000000?3ol03`oo00103`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0040?3ol0030000003oool0oooo00H0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00D0l?o`00<000000?ooo`3oool01`3oool2000001D0l?o`00<000000?oo
o`3oool0203oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00H0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`
00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`0=0?ooo`00L03oool00`000000l?o`0?3ol0040?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool0103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`
oo001P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`01H0
l?o`0P0000080?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3o
ool01P3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`
oo001P3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00@0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol003
0000003oool0oooo00d0oooo001_0?ooo`030000003`oo00l?o`00D0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo00
6@3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00D0l?o`
00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol0050?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00@0oooo
00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`040?ooo`030000
003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00d0oooo001_0?ooo`030000003`
oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103o
ool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo002@3`oo06000000`0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00H0oooo00<0
00000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3o
l0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00103`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool0103oool00`000000l?o`0?3ol0040?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`0=0?ooo`00K`3oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00P0l?o`0`000005
0?ooo`8000002`3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00H0l?o`00<00000
0?ooo`3oool0103oool00`000000l?o`0?3ol0040?3ol0030000003oool0
oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`04
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0040?3ol0030000003oool0oooo00d0oooo001_0?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3o
l03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo
00H0oooo00<000000?3ol03`oo001P3`oo02000000X0oooo0`0000090?3o
l0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`060?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool0103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00@0l?o`00<000000?ooo`3oool03@3oool006l0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0060?3ol0030000003oool0oooo00`0oooo00<000000?3ol03`
oo001`3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool0103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00`0oooo001_0?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`0=0?ooo`030000
003`oo00l?o`00L0l?o`00<000000?ooo`3oool0103oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000
003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`0<0?ooo`00K`3o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00103`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00@0l?o`0P00000A0?ooo`030000003`
oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0050?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?oo
o`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`0<0?ooo`00K`3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol004
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<00000
0?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0
oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`04
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool04@3oool0
0`000000l?o`0?3ol0060?3ol0030000003oool0oooo00@0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<00000
0?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0
oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0303oool0
06l0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<000000?3o
l03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3o
l0030000003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool0103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
0140oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`050?oo
o`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`
00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3o
l0030000003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00`0oooo001_0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool0103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0
oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`
oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol003
0000003oool0oooo00@0oooo00<000000?3ol03`oo00103`oo02000001@0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00`0
oooo001_0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo
0?ooo`0D0?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`0<0?ooo`00K`3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00103`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<0
00000?ooo`3oool0503oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool0303oool006l0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<00000
0?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0
oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol004
0?3ol08000005@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`04
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol004
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<00000
0?ooo`3oool0303oool006l0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`050?oo
o`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<000000?3o
l03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00P0oooo0P0000090?ooo`030000003`oo00l?o`
00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`050?oo
o`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`0<0?ooo`00K`3oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01P3oool200000080
oooo0P0000070?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0
oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`
oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3ol003
0000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`0<0?ooo`00K`3oool00`000000l?o`0?3ol0050?3ol0030000
003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00H0l?o`
00<000000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3oool0
1P3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000
003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
303oool006l0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000003o
ool0oooo00<0oooo00<000000?3ol03`oo00103oool00`000000oooo0?oo
o`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00103`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`0<0?ooo`00K`3oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<00000
0?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00L0l?o`1@000004
0?3ol0<0oooo00<000000?ooo`3oool0103oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<00000
0?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0
oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool0303oool006l0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`
00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`040?ooo`030000003`oo00l?o`00@0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol00@0?3ol080oooo00<000000?ooo`3oool0103oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3o
l0030000003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0303oool006l0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3ol003
0000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol00A0?3ol0030000003oool0oooo00D0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`
oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`040?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00`0
oooo001`0?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000
003oool0oooo00H0oooo00<000000?3ol03`oo00403`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`
00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0040?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`0<0?ooo`00L03oool00`000000l?o`0?3ol0040?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00@0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00h0l?o`00<0
00000?ooo`3oool01P3oool00`000000l?o`0?3ol0040?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00103`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool0303oool00700oooo00<000000?3ol03`oo00103`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<00000
0?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00H0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol00;
0?3ol0800000203oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol004
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<00000
0?ooo`3oool0303oool00700oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`040?ooo`030000003`oo00l?o`00@0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`050?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`
00H0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol0090?3o
l0030000003oool0oooo00L0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`060?ooo`030000003`oo00l?o`00@0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3o
l03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3o
l0030000003oool0oooo00d0oooo001`0?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0040?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000
l?o`0?3ol0070?3ol0030000003oool0oooo00L0oooo1@0000030?3ol0<0
00002P3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00H0
oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3o
ool03@3oool00700oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`040?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00L0l?o`
00<000000?ooo`3oool02`3oool3000000`0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0040?3ol0030000003oool0oooo00d0oooo001`0?ooo`030000003`
oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3o
l0050?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<0
00000?ooo`3oool01P3oool00`000000l?o`0?3ol0040?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo01P0oooo00<0
00000?3ol03`oo001`3`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00103`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00d0oooo001`
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol004
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<00000
0?ooo`3oool01@3oool00`000000l?o`0?3ol0080?3ol0030000003oool0
oooo01H0oooo00<000000?3ol03`oo001`3`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<00000
0?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0
oooo00d0oooo001`0?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`060?oo
o`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0o`000080o`000P3oool00`00
0000l?o`0?3ol0060?3ol0030000003oool0oooo00@0oooo00<000000?3o
l03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00P0l?o`00<000000?ooo`3oool05@3oool00`000000l?o`0?3ol0070?3o
l0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool0103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`050?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`00
0000l?o`0?3ol0040?3ol0030000003oool0oooo00H0oooo00<000000?3o
l03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00@0l?o`00<000000?ooo`3oool03@3oool00700oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol003
0000003oool0oooo00H0oooo00<000000?3ol03`oo00103`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?l0003o
00000`3o00000`3oool000000?3ol0070?3ol0030000003oool0oooo00D0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`060?ooo`03
0000003`oo00l?o`00P0l?o`0P00000C0?ooo`8000002@3`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00@0
oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`060?ooo`03
0000003`oo00l?o`00@0l?o`00<000000?ooo`3oool0103oool00`000000
l?o`0?3ol0060?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`
oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol003
0000003oool0oooo00d0oooo001a0?ooo`030000003`oo00l?o`00@0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0050?3ol0030000003o0000o`0000<0o`00
0P3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`060?ooo`030000
003`oo00l?o`00T0l?o`0P00000?0?ooo`8000002P3`oo000`000000oooo
0?ooo`060?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`
0?3ol0060?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo00
103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000
003oool0oooo00d0oooo001a0?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool0103oool00`000000l?o`0?3ol0040?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103o
ool00`000000l?o`0?3ol0050?3ol0030000003o0000o`0000<0o`000P3o
ool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`070?ooo`030000003`
oo00l?o`00X0l?o`0P00000;0?ooo`8000002`3`oo000`000000oooo0?oo
o`060?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01P3o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3o
l0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00103`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00d0oooo001a0?ooo`030000003`oo00l?o`00D0l?o`00<00000
0?ooo`3oool0103oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0050?3ol0040000003o0000o`000?l000<0oooo00<0
00000?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00H0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3o
l00;0?3ol0/00000303`oo000`000000oooo0?ooo`070?ooo`030000003`
oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0060?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00d0oooo001a
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo00103`oo000`000000oooo0?ooo`060?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`00<00000
0?ooo`3oool01`3oool00`000000l?o`0?3ol00P0?3ol0030000003oool0
oooo00L0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`06
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<00000
0?ooo`3oool03@3oool00740oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?oo
o`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0103oool00`00
0000l?o`0?3ol0060?3ol0030000003oool0oooo00D0oooo00<000000?3o
l03`oo001`3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`
01h0l?o`00<000000?ooo`3oool0203oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00H0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?oo
o`3oool01P3oool00`000000l?o`0?3ol0040?3ol0030000003oool0003o
0080003o0`3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`040?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0040?3ol0030000003oool0oooo00h0oooo001a0?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0060?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`060?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3o
ool01`3oool2000001d0l?o`00<000000?ooo`3oool0203oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol003
000000000?l0003o00<0003o0P3oool00`000000l?o`0?3ol0050?3ol003
0000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00h0
oooo001a0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00L0l?o`
00<000000?ooo`3oool0203oool2000001T0l?o`0P00000:0?ooo`030000
003`oo00l?o`00H0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`
00<000000000o`000?l00`000?l00`3oool000000?3ol0060?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo00h0oooo
001b0?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0060?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001P3`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00P0l?o`00<0
00000?ooo`3oool02@3oool2000001H0l?o`00<000000?ooo`3oool02@3o
ool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00H0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`060?ooo`030000003`
oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0050?3ol003000000000?l0003o00<0003o00<0oooo0000003`oo001P3`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?oo
o`0>0?ooo`00LP3oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<00000
0?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00H0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol008
0?3ol0030000003oool0oooo00X0oooo0P00000@0?3ol0@000002`3oool0
0`000000l?o`0?3ol0070?3ol0030000003oool0oooo00H0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00
l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00<0003o0P3oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`00<00000
0?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00h0oooo001b0?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0060?3ol0030000003oool0oooo00D0oooo00<000000?3o
l03`oo001P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`
00P0l?o`00<000000?ooo`3oool02`3oool4000000L0l?o`1@00000>0?oo
o`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool01P3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00@0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00h0oooo001c0?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0
oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`060?ooo`03
0000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0060?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`
oo001P3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00T0
l?o`00<000000?ooo`3oool03P3oool700000140oooo0P00000:0?3ol003
0000003oool0oooo00H0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`060?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3o
ool01P3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0
oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`0>0?ooo`00L`3oool00`000000l?o`
0?3ol0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo001P3`oo000`000000oooo
0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0
1P3oool00`000000l?o`0?3ol0090?3ol0030000003oool0oooo02@0oooo
00<000000?3ol03`oo002@3`oo000`000000oooo0?ooo`060?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
3P3oool007<0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00@0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00H0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3o
l0060?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo002@3`
oo0200000280oooo0P00000;0?3ol0030000003oool0oooo00H0oooo00<0
00000?3ol03`oo001P3`oo000`000000oooo0?ooo`060?ooo`030000003`
oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?oo
o`0?0?ooo`00L`3oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00D0oooo00<000000?3ol03`oo00103`oo000`000000oooo0?ooo`05
0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01P3oool0
0`000000l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo001P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00
l?o`00L0l?o`00<000000?ooo`3oool01P3oool2000000/0l?o`0P00000O
0?ooo`030000003`oo00l?o`00X0l?o`00<000000?ooo`3oool01P3oool0
0`000000l?o`0?3ol0060?3ol0030000003oool0oooo00H0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol004
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00H0l?o`00<00000
0?ooo`3oool0103oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00l0oooo001d0?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool0103oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0060?3ol0030000003oool0oooo00H0oooo00<000000?3o
l03`oo001`3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`
00X0l?o`0P00000L0?ooo`030000003`oo00l?o`00X0l?o`00<000000?oo
o`3oool01P3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo
00H0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`040?ooo`030000003`oo00l?o`
00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00l0oooo001d0?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0040?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool01P3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00H0
oooo00<000000?3ol03`oo001`3`oo000`000000oooo0?ooo`080?ooo`03
0000003`oo00l?o`00/0l?o`0P00000H0?ooo`800000303`oo000`000000
oooo0?ooo`070?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3o
ool01P3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00H0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool03`3oool007@0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00@0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0
1P3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo00P0oooo
00<000000?3ol03`oo00303`oo04000000l0oooo1@00000<0?3ol0800000
2@3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00L0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0040?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000
003oool0oooo00l0oooo001d0?ooo`030000003`oo00l?o`00H0l?o`00<0
00000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00@0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01P3o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00L0oooo00<0
00000?3ol03`oo001`3`oo000`000000oooo0?ooo`080?ooo`800000403`
oo0?000000l0l?o`0P00000:0?ooo`030000003`oo00l?o`00L0l?o`00<0
00000?ooo`3oool01P3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00H0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<0
00000?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00@0l?o`00<000000?ooo`3oool0403oool007D0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00@0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001P3`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<00000
0?ooo`3oool01`3oool00`000000l?o`0?3ol0070?3ol0030000003oool0
oooo00T0oooo00<000000?3ol03`oo00:P3`oo000`000000oooo0?ooo`09
0?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool01`3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo001P3`oo00
0`000000oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<00000
0?ooo`3oool0403oool007D0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool0103oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`060?oo
o`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01P3oool00`00
0000l?o`0?3ol0080?3ol0030000003oool0oooo00T0oooo0P00000X0?3o
l08000002`3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo
00L0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`060?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo00<000000?3o
l03`oo00103`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00H0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo0100oooo001e0?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3o
ool01P3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00H0
oooo00<000000?3ol03`oo00203`oo02000000/0oooo0P00000T0?3ol080
0000303oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo00P0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol003
0000003oool0oooo0100oooo001e0?ooo`030000003`oo00l?o`00H0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000
003oool0oooo00@0oooo00<000000?3ol03`oo001P3`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
1P3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00L0oooo
00<000000?3ol03`oo002@3`oo000`000000oooo0?ooo`0:0?ooo`800000
803`oo02000000d0oooo00<000000?3ol03`oo00203`oo000`000000oooo
0?ooo`070?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
1P3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool0103oool00`000000l?o`
0?3ol0060?3ol0030000003oool0oooo00@0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`0A0?ooo`00MP3oool00`000000l?o`0?3o
l0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000003o
ool0oooo00H0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?oo
o`070?ooo`030000003`oo00l?o`00T0l?o`00<000000?ooo`3oool02`3o
ool2000001/0l?o`0`00000>0?ooo`030000003`oo00l?o`00P0l?o`00<0
00000?ooo`3oool01`3oool00`000000l?o`0?3ol0060?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00D0l?o`00<000000?ooo`3oool04@3oool007H0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00H0l?o`00<000000?ooo`3oool0103oool00`000000l?o`0?3ol006
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001P3`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00L0l?o`00<00000
0?ooo`3oool01`3oool00`000000l?o`0?3ol0090?3ol08000003@3oool2
000001H0l?o`0`00000?0?ooo`8000002P3`oo000`000000oooo0?ooo`07
0?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01P3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol005
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`0A0?ooo`00MP3oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00H0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo
00H0oooo00<000000?3ol03`oo001`3`oo000`000000oooo0?ooo`070?oo
o`030000003`oo00l?o`00X0l?o`00<000000?ooo`3oool0303oool60000
00h0l?o`0P00000A0?ooo`030000003`oo00l?o`00T0l?o`00<000000?oo
o`3oool01`3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`050?oo
o`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo00@0oooo00<000000?3o
l03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00@0l?o`00<000000?ooo`3oool04P3oool007L0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo001P3`oo000`000000
oooo0?ooo`060?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3o
ool01`3oool2000000/0l?o`0P00000B0?ooo`h000004@3oool2000000/0
l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol0070?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo001P3`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3o
ool01@3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00@0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool04P3oool007L0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00P0l?o`
00<000000?ooo`3oool0203oool00`000000l?o`0?3ol00:0?3ol0030000
003oool0oooo02d0oooo00<000000?3ol03`oo002P3`oo000`000000oooo
0?ooo`070?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool0
1P3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00H0l?o`00<000000?ooo`3oool0103oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
1@3`oo000`000000oooo0?ooo`0B0?ooo`00M`3oool00`000000l?o`0?3o
l0050?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo001@3`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<0
00000?ooo`3oool01@3oool00`000000l?o`0?3ol0070?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo001`3`oo000`000000oooo0?oo
o`090?ooo`030000003`oo00l?o`00X0l?o`0P00000[0?ooo`800000303`
oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00L0l?o`00<0
00000?ooo`3oool01P3oool00`000000l?o`0?3ol0060?3ol0030000003o
ool0oooo00D0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0103o
ool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo00103`oo000`000000oooo0?ooo`0C0?ooo`00N03oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol006
0?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo001`3`oo00
0`000000oooo0?ooo`090?ooo`800000303`oo02000002L0oooo0P00000<
0?3ol08000002@3oool00`000000l?o`0?3ol0070?3ol0030000003oool0
oooo00L0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`06
0?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool0
0`000000l?o`0?3ol0060?3ol0030000003oool0oooo00@0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool04`3oool007P0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00H0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3o
l0030000003oool0oooo00D0oooo00<000000?3ol03`oo001`3`oo000`00
0000oooo0?ooo`060?ooo`030000003`oo00l?o`00L0l?o`00<000000?oo
o`3oool02P3oool00`000000l?o`0?3ol00;0?3ol0<000008@3oool30000
00d0l?o`00<000000?ooo`3oool02@3oool00`000000l?o`0?3ol0070?3o
l0030000003oool0oooo00H0oooo00<000000?3ol03`oo001P3`oo000`00
0000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo
00D0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?oo
o`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool04`3oool007T0
oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`
oo001P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00P0
l?o`00<000000?ooo`3oool02P3oool00`000000l?o`0?3ol00=0?3ol0<0
0000703oool2000000l0l?o`00<000000?ooo`3oool02@3oool00`000000
l?o`0?3ol0070?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`
oo001P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00H0
l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3ol003
0000003oool0oooo00@0oooo00<000000?3ol03`oo001P3`oo000`000000
oooo0?ooo`040?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool0503oool007T0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00H0oooo
00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`060?ooo`030000
003`oo00l?o`00P0l?o`0P00000;0?ooo`800000403`oo03000001<0oooo
1P00000?0?3ol08000002`3oool00`000000l?o`0?3ol0070?3ol0030000
003oool0oooo00L0oooo00<000000?3ol03`oo001P3`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0
1@3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool0503oool007T0oooo00<0
00000?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0060?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo001P3`
oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00T0l?o`00<0
00000?ooo`3oool02P3oool00`000000l?o`0?3ol00@0?3ol0L000001`3o
ool5000001<0l?o`0P00000<0?ooo`030000003`oo00l?o`00L0l?o`00<0
00000?ooo`3oool01`3oool00`000000l?o`0?3ol0060?3ol0030000003o
ool0oooo00H0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0103o
ool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`0D0?ooo`00NP3oool0
0`000000l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo001P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol007
0?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo002@3`oo00
0`000000oooo0?ooo`0:0?ooo`8000005`3`oo07000001H0l?o`0P00000<
0?ooo`8000002@3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00
l?o`00H0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol006
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001P3`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<00000
0?ooo`3oool0103oool00`000000l?o`0?3ol0060?3ol0030000003oool0
oooo01@0oooo001j0?ooo`030000003`oo00l?o`00H0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0050?3ol0030000003oool0oooo
00H0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`060?oo
o`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool01P3oool00`00
0000l?o`0?3ol0090?3ol0800000303oool200000300l?o`0P00000=0?oo
o`030000003`oo00l?o`00P0l?o`00<000000?ooo`3oool01`3oool00`00
0000l?o`0?3ol0070?3ol0030000003oool0oooo00D0oooo00<000000?3o
l03`oo001`3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00H0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`0E0?ooo`00N`3oool00`000000l?o`0?3ol0050?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo001P3`oo000`000000
oooo0?ooo`060?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3o
ool01`3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo00H0
oooo00<000000?3ol03`oo002P3`oo000`000000oooo0?ooo`0;0?ooo`80
0000;03`oo02000000h0oooo00<000000?3ol03`oo00203`oo000`000000
oooo0?ooo`070?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3o
ool01P3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00D0
oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0103oool00`000000
l?o`0?3ol0060?3ol0030000003oool0oooo01D0oooo001k0?ooo`030000
003`oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00H0l?o`
00<000000?ooo`3oool01`3oool2000000/0l?o`00<000000?ooo`3oool0
303oool2000002P0l?o`0P00000>0?ooo`8000002`3`oo000`000000oooo
0?ooo`060?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool0
1P3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo00D0oooo
00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000
003`oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`
0?3ol0060?3ol0030000003oool0oooo01D0oooo001l0?ooo`030000003`
oo00l?o`00D0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0060?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo001P3`
oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00H0l?o`00<0
00000?ooo`3oool0203oool00`000000l?o`0?3ol0090?3ol08000003P3o
ool2000002<0l?o`0`00000?0?ooo`030000003`oo00l?o`00X0l?o`00<0
00000?ooo`3oool01P3oool00`000000l?o`0?3ol0070?3ol0030000003o
ool0oooo00H0oooo00<000000?3ol03`oo001`3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01@3o
ool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00D0oooo00<0
00000?3ol03`oo001P3`oo000`000000oooo0?ooo`0E0?ooo`00O03oool0
0`000000l?o`0?3ol0060?3ol0030000003oool0oooo00D0oooo00<00000
0?3ol03`oo001@3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00
l?o`00L0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol007
0?3ol0030000003oool0oooo00P0oooo00<000000?3ol03`oo002P3`oo00
0`000000oooo0?ooo`0=0?ooo`D000006P3`oo0400000140oooo00<00000
0?3ol03`oo002P3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00
l?o`00L0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol007
0?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo001P3`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00D0l?o`00<00000
0?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000003oool0
oooo01H0oooo001m0?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo
00H0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`070?oo
o`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool0203oool00`00
0000l?o`0?3ol00:0?3ol0030000003oool0oooo0140oooo1@00000A0?3o
l0@000004`3oool2000000`0l?o`00<000000?ooo`3oool01`3oool00`00
0000l?o`0?3ol0070?3ol0030000003oool0oooo00H0oooo00<000000?3o
l03`oo001`3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`
00H0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3o
l0030000003oool0oooo00D0oooo00<000000?3ol03`oo001P3`oo000`00
0000oooo0?ooo`0F0?ooo`00O@3oool00`000000l?o`0?3ol0060?3ol003
0000003oool0oooo00D0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`070?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3o
ool01`3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo00P0
oooo0P00000;0?3ol08000005P3ooolA000001D0oooo0P00000<0?3ol080
00002@3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo00H0
oooo00<000000?3ol03`oo00203`oo000`000000oooo0?ooo`050?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01P3oool00`000000
l?o`0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`
oo001P3`oo000`000000oooo0?ooo`0G0?ooo`00OP3oool00`000000l?o`
0?3ol0050?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00L0l?o`
00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol0070?3ol0030000
003oool0oooo00T0oooo00<000000?3ol03`oo002P3`oo02000003P0oooo
0P00000=0?3ol0030000003oool0oooo00P0oooo00<000000?3ol03`oo00
1`3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00L0l?o`
00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000
003oool0oooo00D0oooo00<000000?3ol03`oo001P3`oo000`000000oooo
0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0
5`3oool007h0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?oo
o`050?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01P3o
ool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo00L0oooo00<0
00000?3ol03`oo001`3`oo000`000000oooo0?ooo`090?ooo`800000303`
oo02000003@0oooo0P00000=0?3ol08000002P3oool00`000000l?o`0?3o
l0070?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`oo001`3`
oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<0
00000?ooo`3oool01P3oool00`000000l?o`0?3ol0050?3ol0030000003o
ool0oooo00H0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`0H0?ooo`00O`3oool00`000000l?o`0?3ol0050?3ol0030000003oool0
oooo00D0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`07
0?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool01`3oool0
0`000000l?o`0?3ol0070?3ol08000002`3oool2000000`0l?o`0`00000_
0?ooo`8000003P3`oo000`000000oooo0?ooo`090?ooo`030000003`oo00
l?o`00L0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol007
0?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo001P3`oo00
0`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0l?o`00<00000
0?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000003oool0
oooo01P0oooo001o0?ooo`030000003`oo00l?o`00H0l?o`00<000000?oo
o`3oool01@3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo
00L0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`080?oo
o`030000003`oo00l?o`00P0l?o`00<000000?ooo`3oool02P3oool00`00
0000l?o`0?3ol00<0?3ol0<00000:03oool4000000h0l?o`0P00000:0?oo
o`8000002P3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`
00L0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3ol0060?3o
l0030000003oool0oooo00H0oooo00<000000?3ol03`oo001@3`oo000`00
0000oooo0?ooo`060?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool06@3oool00800oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`050?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3o
ool01P3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo00L0
oooo00<000000?3ol03`oo002@3`oo000`000000oooo0?ooo`0:0?ooo`80
00003`3`oo02000002<0oooo0`00000A0?3ol0030000003oool0oooo00T0
oooo00<000000?3ol03`oo002@3`oo000`000000oooo0?ooo`070?ooo`03
0000003`oo00l?o`00L0l?o`00<000000?ooo`3oool01P3oool00`000000
l?o`0?3ol0060?3ol0030000003oool0oooo00D0oooo00<000000?3ol03`
oo001P3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00H0
l?o`00<000000?ooo`3oool06@3oool00800oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`050?ooo`030000003`oo00l?o`00L0l?o`
00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol0070?3ol0030000
003oool0oooo00L0oooo00<000000?3ol03`oo002@3`oo000`000000oooo
0?ooo`0;0?ooo`030000003`oo00l?o`00h0l?o`1@00000L0?ooo`800000
4P3`oo02000000/0oooo00<000000?3ol03`oo002@3`oo000`000000oooo
0?ooo`070?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool0
1P3oool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00H0oooo
00<000000?3ol03`oo001@3`oo000`000000oooo0?ooo`060?ooo`030000
003`oo00l?o`00H0l?o`00<000000?ooo`3oool06@3oool00840oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`060?ooo`030000003`
oo00l?o`00H0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3o
l0070?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`oo002@3`
oo02000000`0oooo00<000000?3ol03`oo004P3`oo08000000/0oooo2@00
000B0?3ol08000002`3oool2000000/0l?o`00<000000?ooo`3oool01`3o
ool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo00L0oooo00<0
00000?3ol03`oo001P3`oo000`000000oooo0?ooo`050?ooo`030000003`
oo00l?o`00H0l?o`00<000000?ooo`3oool01@3oool00`000000l?o`0?3o
l0060?3ol0030000003oool0oooo01X0oooo00220?ooo`030000003`oo00
l?o`00D0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol006
0?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`oo001`3`oo00
0`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00X0l?o`00<00000
0?ooo`3oool02P3oool2000001X0l?o`2`00000I0?3ol0800000303oool0
0`000000l?o`0?3ol0090?3ol08000002@3oool00`000000l?o`0?3ol007
0?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`oo001P3`oo00
0`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00D0l?o`00<00000
0?ooo`3oool01P3oool00`000000l?o`0?3ol0060?3ol0030000003oool0
oooo01X0oooo00220?ooo`030000003`oo00l?o`00D0l?o`00<000000?oo
o`3oool01P3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo
00H0oooo00<000000?3ol03`oo00203`oo000`000000oooo0?ooo`070?oo
o`030000003`oo00l?o`00X0l?o`00<000000?ooo`3oool02`3oool20000
03T0l?o`0`00000=0?ooo`030000003`oo00l?o`00T0l?o`00<000000?oo
o`3oool0203oool00`000000l?o`0?3ol0080?3ol0030000003oool0oooo
00H0oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`060?oo
o`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01P3oool00`00
0000l?o`0?3ol0050?3ol0030000003oool0oooo01/0oooo00230?ooo`03
0000003`oo00l?o`00D0l?o`00<000000?ooo`3oool01P3oool00`000000
l?o`0?3ol0060?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`
oo00203`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00X0
l?o`0P00000=0?ooo`<00000=03`oo02000000l0oooo00<000000?3ol03`
oo002@3`oo000`000000oooo0?ooo`080?ooo`030000003`oo00l?o`00P0
l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3ol0070?3ol003
0000003oool0oooo00H0oooo00<000000?3ol03`oo001@3`oo000`000000
oooo0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3o
ool06`3oool008<0oooo00<000000?3ol03`oo001@3`oo000`000000oooo
0?ooo`070?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0
1`3oool00`000000l?o`0?3ol0080?3ol0030000003oool0oooo00L0oooo
0P00000<0?3ol08000003P3oool3000002h0l?o`0`00000?0?ooo`800000
2`3`oo000`000000oooo0?ooo`090?ooo`030000003`oo00l?o`00L0l?o`
00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol0060?3ol0030000
003oool0oooo00H0oooo00<000000?3ol03`oo001P3`oo000`000000oooo
0?ooo`060?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0
703oool008@0oooo00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`060?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool01`3o
ool00`000000l?o`0?3ol0080?3ol0030000003oool0oooo00P0oooo00<0
00000?3ol03`oo002`3`oo000`000000oooo0?ooo`0>0?ooo`<00000:@3`
oo0200000140oooo00<000000?3ol03`oo002P3`oo000`000000oooo0?oo
o`090?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool01`3o
ool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00L0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`060?ooo`030000003`
oo00l?o`00H0l?o`00<000000?ooo`3oool0703oool008@0oooo00<00000
0?3ol03`oo001P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00
l?o`00L0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol008
0?3ol0030000003oool0oooo00P0oooo0P00000<0?3ol08000004@3oool2
00000280l?o`1@00000A0?ooo`8000002`3`oo02000000/0oooo00<00000
0?3ol03`oo001`3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00
l?o`00H0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol006
0?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo001@3`oo00
0`000000oooo0?ooo`0M0?ooo`00Q@3oool00`000000l?o`0?3ol0060?3o
l0030000003oool0oooo00H0oooo00<000000?3ol03`oo001P3`oo000`00
0000oooo0?ooo`080?ooo`030000003`oo00l?o`00P0l?o`00<000000?oo
o`3oool02@3oool00`000000l?o`0?3ol00;0?3ol08000004@3oool90000
01D0l?o`1000000D0?ooo`800000303`oo000`000000oooo0?ooo`0:0?oo
o`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool01`3oool00`00
0000l?o`0?3ol0070?3ol0030000003oool0oooo00L0oooo00<000000?3o
l03`oo001@3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`
00H0l?o`00<000000?ooo`3oool07@3oool008D0oooo00<000000?3ol03`
oo001P3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00H0
l?o`00<000000?ooo`3oool0203oool00`000000l?o`0?3ol0080?3ol003
0000003oool0oooo00T0oooo0P00000=0?3ol0030000003oool0oooo01L0
oooo5@00000F0?ooo`8000003@3`oo000`000000oooo0?ooo`0:0?ooo`03
0000003`oo00l?o`00L0l?o`00<000000?ooo`3oool01`3oool00`000000
l?o`0?3ol0070?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`
oo001@3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00D0
l?o`00<000000?ooo`3oool07P3oool008H0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00L0l?o`
00<000000?ooo`3oool0203oool00`000000l?o`0?3ol0080?3ol0800000
2`3oool00`000000l?o`0?3ol00;0?3ol0800000@03oool2000000d0l?o`
0P00000;0?ooo`8000002@3`oo000`000000oooo0?ooo`070?ooo`030000
003`oo00l?o`00L0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`
0?3ol0060?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`0N0?ooo`00Q`3oool00`000000l?o`0?3o
l0060?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo001`3`
oo000`000000oooo0?ooo`080?ooo`8000002P3`oo000`000000oooo0?oo
o`090?ooo`8000003@3`oo02000003/0oooo0`00000>0?3ol0030000003o
ool0oooo00X0oooo00<000000?3ol03`oo002@3`oo000`000000oooo0?oo
o`070?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool01`3o
ool00`000000l?o`0?3ol0060?3ol0030000003oool0oooo00L0oooo00<0
00000?3ol03`oo001@3`oo000`000000oooo0?ooo`0O0?ooo`00Q`3oool0
0`000000l?o`0?3ol0070?3ol0030000003oool0oooo00H0oooo00<00000
0?3ol03`oo001`3`oo000`000000oooo0?ooo`090?ooo`030000003`oo00
l?o`00P0l?o`00<000000?ooo`3oool02P3oool00`000000l?o`0?3ol00<
0?3ol0@00000=@3oool2000000l0l?o`0P00000<0?ooo`030000003`oo00
l?o`00T0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol007
0?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo001P3`oo00
0`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00H0l?o`00<00000
0?ooo`3oool07`3oool008P0oooo00<000000?3ol03`oo001P3`oo000`00
0000oooo0?ooo`070?ooo`030000003`oo00l?o`00L0l?o`00<000000?oo
o`3oool02@3oool00`000000l?o`0?3ol0080?3ol0030000003oool0oooo
00X0oooo0P00000@0?3ol0@00000;P3oool3000000l0l?o`0P00000<0?oo
o`8000002`3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`
00L0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol0050?3o
l0030000003oool0oooo00L0oooo00<000000?3ol03`oo001P3`oo000`00
0000oooo0?ooo`0P0?ooo`00R@3oool00`000000l?o`0?3ol0060?3ol003
0000003oool0oooo00L0oooo00<000000?3ol03`oo001`3`oo000`000000
oooo0?ooo`090?ooo`030000003`oo00l?o`00P0l?o`00<000000?ooo`3o
ool02`3oool200000180l?o`1000000W0?ooo`<000004@3`oo000`000000
oooo0?ooo`0;0?ooo`030000003`oo00l?o`00X0l?o`00<000000?ooo`3o
ool01`3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo00L0
oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`060?ooo`03
0000003`oo00l?o`00H0l?o`00<000000?ooo`3oool08@3oool008X0oooo
00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`070?ooo`030000
003`oo00l?o`00L0l?o`0P00000:0?ooo`030000003`oo00l?o`00P0l?o`
0P00000=0?ooo`800000503`oo0300000200oooo1000000B0?3ol0800000
303oool2000000`0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`
0?3ol0070?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`oo00
1P3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00H0l?o`
00<000000?ooo`3oool08@3oool008X0oooo00<000000?3ol03`oo001`3`
oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00P0l?o`00<0
00000?ooo`3oool0203oool00`000000l?o`0?3ol0090?3ol0030000003o
ool0oooo00`0oooo0P00000E0?3ol0H00000503oool6000001@0l?o`0P00
000=0?ooo`030000003`oo00l?o`00/0l?o`00<000000?ooo`3oool01`3o
ool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo00L0oooo00<0
00000?3ol03`oo001P3`oo000`000000oooo0?ooo`070?ooo`030000003`
oo00l?o`00H0l?o`00<000000?ooo`3oool08P3oool008/0oooo00<00000
0?3ol03`oo001`3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00
l?o`00P0l?o`00<000000?ooo`3oool0203oool00`000000l?o`0?3ol009
0?3ol0030000003oool0oooo00d0oooo0P00000I0?3ol1@000005`3`oo03
000000d0oooo0P00000<0?3ol08000002@3oool00`000000l?o`0?3ol007
0?3ol0030000003oool0oooo00L0oooo00<000000?3ol03`oo001`3`oo00
0`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00H0l?o`00<00000
0?ooo`3oool08`3oool008`0oooo00<000000?3ol03`oo001P3`oo000`00
0000oooo0?ooo`080?ooo`030000003`oo00l?o`00P0l?o`00<000000?oo
o`3oool0203oool2000000X0l?o`0P00000?0?ooo`<00000?`3`oo020000
00l0oooo00<000000?3ol03`oo002`3`oo000`000000oooo0?ooo`080?oo
o`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool01`3oool00`00
0000l?o`0?3ol0070?3ol0030000003oool0oooo00L0oooo00<000000?3o
l03`oo001P3`oo000`000000oooo0?ooo`0S0?ooo`00S@3oool00`000000
l?o`0?3ol0060?3ol0030000003oool0oooo00P0oooo00<000000?3ol03`
oo00203`oo000`000000oooo0?ooo`090?ooo`030000003`oo00l?o`00T0
l?o`0P00000@0?ooo`<00000>P3`oo02000000l0oooo0P00000<0?3ol080
00002P3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo00P0
oooo00<000000?3ol03`oo001P3`oo000`000000oooo0?ooo`070?ooo`03
0000003`oo00l?o`00H0l?o`00<000000?ooo`3oool0903oool008d0oooo
00<000000?3ol03`oo001`3`oo000`000000oooo0?ooo`080?ooo`030000
003`oo00l?o`00P0l?o`00<000000?ooo`3oool02@3oool00`000000l?o`
0?3ol00:0?3ol0030000003oool0oooo0100oooo0`00000e0?3ol0800000
3`3oool2000000d0l?o`00<000000?ooo`3oool02@3oool00`000000l?o`
0?3ol0070?3ol0030000003oool0oooo00P0oooo00<000000?3ol03`oo00
1`3`oo000`000000oooo0?ooo`060?ooo`030000003`oo00l?o`00L0l?o`
00<000000?ooo`3oool0903oool008h0oooo00<000000?3ol03`oo001`3`
oo000`000000oooo0?ooo`080?ooo`030000003`oo00l?o`00P0l?o`00<0
00000?ooo`3oool02@3oool2000000/0l?o`0P00000C0?ooo`800000;`3`
oo0400000100oooo00<000000?3ol03`oo002`3`oo02000000/0oooo00<0
00000?3ol03`oo00203`oo000`000000oooo0?ooo`070?ooo`030000003`
oo00l?o`00L0l?o`00<000000?ooo`3oool01P3oool00`000000l?o`0?3o
l0070?3ol0030000003oool0oooo02D0oooo002?0?ooo`030000003`oo00
l?o`00L0l?o`00<000000?ooo`3oool0203oool00`000000l?o`0?3ol008
0?3ol0030000003oool0oooo00X0oooo00<000000?3ol03`oo002P3`oo02
000001<0oooo1000000V0?3ol0D000004P3oool2000000d0l?o`00<00000
0?ooo`3oool02P3oool00`000000l?o`0?3ol0080?3ol0030000003oool0
oooo00L0oooo00<000000?3ol03`oo001`3`oo000`000000oooo0?ooo`07
0?ooo`030000003`oo00l?o`00H0l?o`00<000000?ooo`3oool09P3oool0
0900oooo00<000000?3ol03`oo001`3`oo000`000000oooo0?ooo`080?oo
o`030000003`oo00l?o`00P0l?o`0P00000;0?ooo`030000003`oo00l?o`
00/0l?o`0P00000E0?ooo`H000006P3`oo06000001H0oooo00<000000?3o
l03`oo002`3`oo02000000`0oooo00<000000?3ol03`oo00203`oo000`00
0000oooo0?ooo`070?ooo`030000003`oo00l?o`00L0l?o`00<000000?oo
o`3oool01`3oool00`000000l?o`0?3ol0070?3ol0030000003oool0oooo
02H0oooo002@0?ooo`030000003`oo00l?o`00P0l?o`00<000000?ooo`3o
ool0203oool00`000000l?o`0?3ol0090?3ol0030000003oool0oooo00T0
oooo0P00000=0?3ol08000006@3oool6000000h0l?o`1P00000J0?ooo`80
00003@3`oo000`000000oooo0?ooo`0;0?ooo`030000003`oo00l?o`00P0
l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol0070?3ol003
0000003oool0oooo00L0oooo00<000000?3ol03`oo001`3`oo000`000000
oooo0?ooo`0W0?ooo`00T@3oool00`000000l?o`0?3ol0080?3ol0030000
003oool0oooo00P0oooo00<000000?3ol03`oo002@3`oo000`000000oooo
0?ooo`0:0?ooo`030000003`oo00l?o`00`0l?o`1000000K0?ooo`h00000
7P3oool2000000d0l?o`0P00000<0?ooo`8000002P3`oo000`000000oooo
0?ooo`070?ooo`030000003`oo00l?o`00P0l?o`00<000000?ooo`3oool0
1P3oool00`000000l?o`0?3ol0080?3ol0030000003oool0oooo02L0oooo
002B0?ooo`030000003`oo00l?o`00P0l?o`00<000000?ooo`3oool0203o
ool00`000000l?o`0?3ol0090?3ol08000002`3oool200000100l?o`0P00
00120?ooo`<000003@3`oo02000000d0oooo00<000000?3ol03`oo002@3`
oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00P0l?o`00<0
00000?ooo`3oool01P3oool00`000000l?o`0?3ol0080?3ol0030000003o
ool0oooo02P0oooo002C0?ooo`030000003`oo00l?o`00P0l?o`00<00000
0?ooo`3oool0203oool2000000/0l?o`00<000000?ooo`3oool02P3oool0
0`000000l?o`0?3ol00?0?3ol0800000?03oool4000000h0l?o`0P00000=
0?ooo`8000002`3`oo000`000000oooo0?ooo`070?ooo`030000003`oo00
l?o`00P0l?o`00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol007
0?3ol0030000003oool0oooo02T0oooo002D0?ooo`030000003`oo00l?o`
00P0l?o`00<000000?ooo`3oool02@3oool00`000000l?o`0?3ol0090?3o
l0030000003oool0oooo00X0oooo0P00000A0?3ol0800000=`3oool30000
0100l?o`0P00000>0?ooo`030000003`oo00l?o`00T0l?o`0P0000090?oo
o`030000003`oo00l?o`00P0l?o`00<000000?ooo`3oool01`3oool00`00
0000l?o`0?3ol0070?3ol0030000003oool0oooo02X0oooo002E0?ooo`03
0000003`oo00l?o`00P0l?o`00<000000?ooo`3oool02@3oool00`000000
l?o`0?3ol0090?3ol0800000303oool200000140l?o`1000000_0?ooo`@0
00004@3`oo02000000h0oooo0P00000;0?3ol0030000003oool0oooo00P0
oooo00<000000?3ol03`oo00203`oo000`000000oooo0?ooo`070?ooo`03
0000003`oo00l?o`00L0l?o`00<000000?ooo`3oool0:`3oool009H0oooo
00<000000?3ol03`oo00203`oo000`000000oooo0?ooo`090?ooo`030000
003`oo00l?o`00X0l?o`00<000000?ooo`3oool02`3oool2000001<0l?o`
1P00000S0?ooo`H000004`3`oo02000000l0oooo00<000000?3ol03`oo00
2P3`oo000`000000oooo0?ooo`080?ooo`030000003`oo00l?o`00P0l?o`
00<000000?ooo`3oool01`3oool00`000000l?o`0?3ol0080?3ol0030000
003oool0oooo02/0oooo002G0?ooo`030000003`oo00l?o`00P0l?o`00<0
00000?ooo`3oool02@3oool00`000000l?o`0?3ol00:0?3ol0030000003o
ool0oooo00`0oooo0P00000G0?3ol0L000005@3oool7000001L0l?o`0P00
000?0?ooo`8000002`3`oo02000000X0oooo00<000000?3ol03`oo00203`
oo000`000000oooo0?ooo`070?ooo`030000003`oo00l?o`00P0l?o`00<0
00000?ooo`3oool0;03oool009P0oooo00<000000?3ol03`oo00203`oo00
0`000000oooo0?ooo`090?ooo`030000003`oo00l?o`00X0l?o`0P00000>
0?ooo`<000006`3`oo0E000001`0l?o`0P00000@0?ooo`030000003`oo00
l?o`00X0l?o`00<000000?ooo`3oool02@3oool00`000000l?o`0?3ol009
0?3ol0030000003oool0oooo00H0oooo00<000000?3ol03`oo00203`oo00
0`000000oooo0?ooo`0]0?ooo`00V@3oool2000000T0l?o`00<000000?oo
o`3oool02@3oool2000000`0l?o`0P00000?0?ooo`@00000A@3`oo030000
0100oooo0P00000;0?3ol08000002`3oool00`000000l?o`0?3ol0090?3o
l0030000003oool0oooo00L0oooo00<000000?3ol03`oo001`3`oo000`00
0000oooo0?ooo`0^0?ooo`00V`3oool00`000000l?o`0?3ol0070?3ol003
0000003oool0oooo00X0oooo00<000000?3ol03`oo002`3`oo0200000140
oooo0`0000100?3ol08000004@3oool2000000`0l?o`00<000000?ooo`3o
ool02P3oool00`000000l?o`0?3ol0090?3ol0030000003oool0oooo00L0
oooo00<000000?3ol03`oo001`3`oo000`000000oooo0?ooo`0_0?ooo`00
W03oool00`000000l?o`0?3ol0070?3ol08000002`3oool2000000d0l?o`
0P00000B0?ooo`<00000>`3`oo0200000140oooo0P00000=0?3ol0030000
003oool0oooo00X0oooo00<000000?3ol03`oo002@3`oo000`000000oooo
0?ooo`070?ooo`030000003`oo00l?o`00L0l?o`00<000000?ooo`3oool0
<03oool009d0oooo00<000000?3ol03`oo00203`oo000`000000oooo0?oo
o`0:0?ooo`030000003`oo00l?o`00`0l?o`0P00000C0?ooo`<00000=@3`
oo0300000140oooo0P00000=0?3ol08000002`3oool2000000/0l?o`00<0
00000?ooo`3oool0203oool00`000000l?o`0?3ol0060?3ol0030000003o
ool0oooo0340oooo002N0?ooo`030000003`oo00l?o`00P0l?o`00<00000
0?ooo`3oool02P3oool2000000h0l?o`0P00000D0?ooo`<00000;P3`oo04
00000180oooo0P00000>0?3ol0030000003oool0oooo00X0oooo00<00000
0?3ol03`oo002@3`oo02000000X0oooo00<000000?ooo`3oool01P3`oo00
0`000000oooo0?ooo`0b0?ooo`00W`3oool00`000000l?o`0?3ol0080?3o
l0800000303oool2000000h0l?o`0P00000E0?ooo`@00000903`oo060000
01<0oooo0`00000>0?3ol08000002`3oool2000000/0l?o`00<000000?oo
o`3oool02P3oool010000000oooo0?ooo`3oool50?3ol0030000003oool0
oooo0380oooo002P0?ooo`030000003`oo00l?o`00T0l?o`00<000000?oo
o`3oool02`3oool00`000000l?o`0?3ol00=0?3ol08000005`3oool70000
01H0l?o`1`00000G0?ooo`800000403`oo000`000000oooo0?ooo`0:0?oo
o`030000003`oo00l?o`00X0l?o`00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`020?ooo`<0l?o`00<000000?ooo`3oool0<`3oool00:40
oooo00<000000?3ol03`oo002@3`oo000`000000oooo0?ooo`0;0?ooo`80
00003`3`oo03000001/0oooo5P00000L0?ooo`800000403`oo02000000`0
oooo00<000000?3ol03`oo002@3`oo02000000l0oooo00<000000?ooo`3o
ool00P3oool00`3`oo0000000?ooo`0e0?ooo`00XP3oool00`000000l?o`
0?3ol0090?3ol08000003@3oool00`000000l?o`0?3ol00?0?3ol0<00000
A`3oool300000100l?o`0P00000<0?ooo`8000002`3`oo000`000000oooo
0?ooo`0?0?ooo`040000003oool0oooo0?ooo`800000=`3oool00:<0oooo
0P00000;0?3ol0030000003oool0oooo00/0oooo0P00000B0?3ol0800000
@@3oool400000140l?o`0P00000=0?ooo`030000003`oo00l?o`00X0l?o`
00<000000?ooo`3oool04@3oool3000003T0oooo002U0?ooo`030000003`
oo00l?o`00T0l?o`00<000000?ooo`3oool0303oool200000180l?o`0`00
000j0?ooo`@000004`3`oo02000000d0oooo0P00000;0?3ol0800000D03o
ool00:H0oooo00<000000?3ol03`oo002@3`oo02000000h0oooo0P00000C
0?3ol0@00000<`3oool3000001D0l?o`0P00000>0?ooo`030000003`oo00
l?o`00X0l?o`00<000000?ooo`3oool0D03oool00:L0oooo0P00000;0?3o
l08000003P3oool3000001@0l?o`1@00000[0?ooo`<000005P3`oo020000
00h0oooo0P00000<0?3ol0030000003oool0oooo0540oooo002Y0?ooo`03
0000003`oo00l?o`00X0l?o`0P00000?0?ooo`8000005`3`oo0700000200
oooo1000000F0?3ol0<000003P3oool2000000`0l?o`0P00001D0?ooo`00
ZP3oool00`000000l?o`0?3ol00;0?3ol08000003`3oool3000001/0l?o`
2000000<0?ooo``000005`3`oo03000000l0oooo0P00000=0?3ol0030000
003oool0oooo05@0oooo002[0?ooo`8000003@3`oo0200000100oooo0`00
000P0?3ol0`00000803`oo0300000100oooo0P00000=0?3ol0800000E`3o
ool00:d0oooo00<000000?3ol03`oo00303`oo0200000140oooo0P000017
0?3ol0<000004@3oool2000000d0l?o`0P00001I0?ooo`00[P3oool00`00
0000l?o`0?3ol00=0?3ol08000004@3oool300000440l?o`0`00000B0?oo
o`8000003P3`oo000`000000oooo0?ooo`1I0?ooo`00[`3oool2000000l0
l?o`0P00000B0?ooo`<00000>`3`oo03000001<0oooo0P00000>0?3ol080
0000G03oool00;40oooo00<000000?3ol03`oo003P3`oo0300000180oooo
1000000d0?3ol0<00000503oool2000000l0l?o`00<000000?ooo`3oool0
G03oool00;80oooo0P00000A0?3ol0800000503oool7000002T0l?o`1000
000D0?ooo`<000003`3`oo02000005l0oooo002d0?ooo`8000004@3`oo02
000001T0oooo2000000K0?3ol0H000005@3oool300000100l?o`0P00001Q
0?ooo`00]P3oool200000140l?o`0P00000O0?oooa/000006@3oool20000
0180l?o`00<000000?ooo`3oool0H@3oool00;P0oooo0P00000A0?3ol0<0
0000C@3oool300000180l?o`0P00001T0?ooo`00^P3oool200000180l?o`
100000160?ooo`<000004`3`oo02000006H0oooo002l0?ooo`<000004`3`
oo0400000400oooo0P00000D0?3ol0800000J03oool00;l0oooo0`00000D
0?3ol0@00000>@3oool3000001@0l?o`0P00001Z0?ooo`00`P3oool30000
01D0l?o`1@00000^0?ooo`H000005@3`oo02000006`0oooo00350?ooo`80
0000603`oo04000002<0oooo1`00000H0?3ol0<00000KP3oool00<L0oooo
0P00000J0?3ol0H00000603oool5000001`0l?o`0`00001a0?ooo`00b@3o
ool3000001d0l?o`6000000N0?3ol0<00000M03oool00<`0oooo0`00001>
0?3ol0800000M`3oool00<l0oooo0`0000180?3ol0<00000N@3oool00=80
oooo100000100?3ol0@00000O03oool00=H0oooo1000000g0?3ol0D00000
P03oool00=X0oooo1@00000]0?3ol0D00000Q@3oool00=l0oooo1000000T
0?3ol0D00000RP3oool00><0oooo9000002?0?ooo`00o`3ooonG0?ooo`00
o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?oo
o`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{406, 293},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell["\<\
\tAlthough an introductory treatment of complex analysis can be given without \
using this theorem, we think it is important for the well-informed student at \
least to be aware of it. \
\>", "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Numbers",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexNumbersBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["History of Complex Numbers",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/HistoryComplexBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Quaternions",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/QuaternionBib.html"], None},
  
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{971, 648},
WindowMargins->{{3, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 490845, 9131}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 125, 2, 33, "Text"],
Cell[2230, 66, 1275, 39, 109, "Text"],
Cell[3508, 107, 2450, 72, 185, "Text",
  Evaluatable->False],
Cell[5961, 181, 4509, 128, 145, "Text",
  Evaluatable->False],
Cell[10473, 311, 2224, 70, 128, "Text"],

Cell[CellGroupData[{
Cell[12722, 385, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[12886, 391, 127, 5, 33, "Text"],
Cell[13016, 398, 1447, 29, 370, "Input"],
Cell[14466, 429, 1591, 33, 390, "Input"],
Cell[16060, 464, 1049, 20, 230, "Input"]
}, Closed]],
Cell[17124, 487, 10324, 172, 160, 10210, 168, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[27451, 661, 553, 19, 33, "Text"],
Cell[28007, 682, 453, 15, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[28485, 701, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[28652, 707, 306, 10, 33, "Text"],
Cell[28961, 719, 1720, 35, 406, "Input"]
}, Closed]],
Cell[30696, 757, 4538, 143, 93, "Text"],
Cell[35237, 902, 20881, 345, 257, 20767, 341, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[56121, 1249, 992, 30, 33, "Text"],
Cell[57116, 1281, 2008, 58, 71, "Text"],
Cell[59127, 1341, 886, 28, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[60038, 1373, 248, 9, 33, "Text",
  Evaluatable->False],
Cell[60289, 1384, 44, 0, 33, "Text"],
Cell[60336, 1386, 924, 16, 230, "Input"]
}, Closed]],
Cell[61275, 1405, 2666, 75, 218, "Text",
  Evaluatable->False],
Cell[63944, 1482, 759, 18, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[64728, 1504, 245, 9, 33, "Text",
  Evaluatable->False],
Cell[64976, 1515, 282, 9, 52, "Text"],
Cell[65261, 1526, 1802, 33, 450, "Input"]
}, Closed]],
Cell[67078, 1562, 20889, 345, 255, 20775, 341, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[87970, 1909, 351, 12, 33, "Text"],
Cell[88324, 1923, 969, 30, 109, "Text"],
Cell[89296, 1955, 10572, 176, 211, 10458, 172, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[99871, 2133, 246, 11, 33, "Text"],
Cell[100120, 2146, 1573, 50, 52, "Text",
  Evaluatable->False],
Cell[101696, 2198, 942, 34, 109, "Text"],
Cell[102641, 2234, 1463, 56, 109, "Text"],
Cell[104107, 2292, 16644, 276, 163, 16530, 272, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[120754, 2570, 227, 8, 33, "Text"],
Cell[120984, 2580, 577, 21, 71, "Text"],
Cell[121564, 2603, 563, 14, 52, "Text"],
Cell[122130, 2619, 29234, 482, 215, 29120, 478, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[151367, 3103, 320, 11, 33, "Text"],
Cell[151690, 3116, 578, 22, 33, "Text",
  Evaluatable->False],
Cell[152271, 3140, 1760, 59, 164, "Text"],
Cell[154034, 3201, 1118, 37, 74, "Text"],

Cell[CellGroupData[{
Cell[155177, 3242, 259, 10, 33, "Text",
  Evaluatable->False],
Cell[155439, 3254, 964, 30, 109, "Text"],
Cell[156406, 3286, 979, 20, 193, "Input"],
Cell[157388, 3308, 575, 11, 110, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[158000, 3324, 210, 8, 30, "Text"],
Cell[158213, 3334, 586, 21, 52, "Text"],
Cell[158802, 3357, 969, 19, 193, "Input"],
Cell[159774, 3378, 593, 13, 130, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[160404, 3396, 259, 10, 30, "Text",
  Evaluatable->False],
Cell[160666, 3408, 700, 23, 55, "Text"],
Cell[161369, 3433, 1086, 23, 218, "Input"],
Cell[162458, 3458, 615, 12, 110, "Input"]
}, Closed]],
Cell[163088, 3473, 1887, 57, 71, "Text"],
Cell[164978, 3532, 2889, 81, 128, "Text"],
Cell[167870, 3615, 21410, 354, 232, 21296, 350, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[189283, 3971, 240, 8, 33, "Text"],
Cell[189526, 3981, 11564, 192, 162, 11450, 188, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[201093, 4175, 784, 22, 33, "Text"],
Cell[201880, 4199, 631, 13, 71, "Text"],
Cell[202514, 4214, 277, 10, 33, "Text",
  Evaluatable->False],
Cell[202794, 4226, 2695, 77, 202, "Text"],
Cell[205492, 4305, 1141, 41, 90, "Text"],
Cell[206636, 4348, 1305, 35, 90, "Text"],
Cell[207944, 4385, 649, 14, 71, "Text"],
Cell[208596, 4401, 1460, 53, 71, "Text"],
Cell[210059, 4456, 1352, 28, 109, "Text"],
Cell[211414, 4486, 137745, 2261, 307, 137631, 2257, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[349162, 6749, 1225, 36, 33, "Text"],

Cell[CellGroupData[{
Cell[350412, 6789, 101, 2, 33, "Text"],
Cell[350516, 6793, 137769, 2261, 307, 137655, 2257, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False]
}, Closed]],
Cell[488300, 9057, 209, 4, 30, "Text"],
Cell[488512, 9063, 290, 7, 33, "Text"],
Cell[488805, 9072, 287, 7, 33, "Text"],
Cell[489095, 9081, 298, 7, 33, "Text"],
Cell[489396, 9090, 277, 7, 33, "Text"],
Cell[489676, 9099, 257, 5, 33, "Text"],
Cell[489936, 9106, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

