(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    545457,      10296]*)
(*NotebookOutlinePosition[    546271,      10326]*)
(*  CellTagsIndexPosition[    546193,      10320]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 2  Complex Functions",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[StyleBox["Overview",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
\tThe last chapter developed a basic theory of complex numbers. For the next \
few chapters we turn our attention to functions of complex numbers. They are \
defined in a similar way to functions of real numbers that you studied in \
calculus; the only difference is that they operate on complex numbers rather \
than real numbers. This chapter focuses primarily on very basic functions, \
their representations, and properties associated with functions such as \
limits and continuity. You will learn some interesting applications as well \
as some exciting new ideas. \
\>", "Text"],

Cell[TextData[StyleBox["2.1 Functions and Linear Mappings",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tA complex-valued function ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " of the complex variable z is a rule that assigns to each complex number \
",
  StyleBox["z",
    FontFamily->"Courier New"],
  " in a set ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " one and only one complex number ",
  StyleBox["w",
    FontFamily->"Courier New"],
  ".  We write  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  and call ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " the image of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " under ",
  StyleBox["f",
    FontFamily->"Courier New"],
  ".   A simple example of a complex-valued function is given by the formula  \
",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^4\)\)]],
  ".  The set ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " is called the domain of ",
  StyleBox["f",
    FontFamily->"Courier New"],
  ", and the set of all images  ",
  Cell[BoxData[
      \({w = f \((z)\) : z \[Element] D}\)]],
  "  is called the range of ",
  StyleBox["f",
    FontFamily->"Courier New"],
  ".  When the context is obvious, we omit the phrase complex-valued, and \
simply refer to a function ",
  StyleBox["f",
    FontFamily->"Courier New"],
  ", or to a complex function ",
  StyleBox["f",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe can define the domain to be any set that makes sense for a given \
rule, so for  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^4\)\)]],
  ",  we could have the entire complex plane for the domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", or we might artificially restrict the domain to some set such as  ",
  Cell[BoxData[
      \(D = \(\(D\_1\) \((0)\) = {z : \ \
\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)}\)\)]],
  ".  Determining the range for a function defined by a formula is not always \
easy, but we will see plenty of examples later on.  In some contexts \
functions are referred to as mappings or transformations."
}], "Text"],

Cell["\<\
\tIn Section 1.6, we used the term domain to indicate a connected open set.  \
When speaking about the domain of a function, however, we mean only the set \
of points on which the function is defined.  This distinction is worth \
noting, and context will make clear the use intended.\
\>", "Text"],

Cell[TextData[{
  "\tJust as z can be expressed by its real and imaginary parts,  ",
  Cell[BoxData[
      \(z\  = \ x + \[ImaginaryI]\ y\)]],
  ",  we write  ",
  Cell[BoxData[
      \(f \((z)\) = \ \(w\  = \ v + \[ImaginaryI]\ v\)\)]],
  ",  where ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " are the real and imaginary parts of ",
  StyleBox["w",
    FontFamily->"Courier New"],
  ", respectively.  Doing so gives us the representation  \n\n\t\t\t",
  Cell[BoxData[
      \(w = \(f \((z)\) = \(f \((x, y)\) = \(f \((x + \[ImaginaryI]\ y)\) = 
              u + \[ImaginaryI]\ v\)\)\)\)]],
  ".\n\nBecause u and v depend on ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["y",
    FontFamily->"Courier New"],
  ", they can be considered to be real-valued functions of the real variables \
",
  StyleBox["x",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["y",
    FontFamily->"Courier New"],
  "; that is,\n\n\t\t\t  ",
  Cell[BoxData[
      \(u = u \((x, y)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(v = v \((x, y)\)\)]],
  ".  \n\nCombining these ideas, we often write a complex function ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " in the form\n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\) = \(f \((x + \[ImaginaryI]\ y)\) = 
          u \((x, y)\) + \[ImaginaryI]\ v \((x, y)\)\)\)]],
  ".  \n\nFigure 2.1 illustrates the notion of a function (mapping) using \
these symbols."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008N0000hb000`400?l0
0000o`00003oo`3ooooo0?ooob00oooo003o0?ooool0oooo803oool00?l0
ooooo`3ooolP0?ooo`00o`3ooooo0?ooob00oooo003o0?ooool0oooo803o
ool00?l0ooooo`3ooolP0?ooo`00I`3oool00`000000oooo0?ooo`3o0?oo
okD0oooo001W0?ooo`030000003oool0oooo0?l0oooo]@3oool006L0oooo
00<000000?ooo`3oool0o`3ooone0?ooo`00I`3oool00`000000oooo0?oo
o`3o0?oookD0oooo001W0?ooo`030000003oool0oooo0=l0oooo00<00000
0?ooo`3oool0dP3oool006L0oooo00<000000?ooo`3oool05@3oool;003o
0;l0oooo00<000000?ooo`3oool0^P3oool4000001@0oooo001W0?ooo`03
0000003oool0oooo0140oooo1000o`0;0?3ol0<00?l0Z@3oooo8000000L0
oooo00@000000?ooo`3oool000005@3oool006L0oooo00<000000?ooo`3o
ool03P3oool3003o0180l?o`0`00o`2i0?ooo`030000003oool0oooo0;T0
oooo00@000000?ooo`3oool000005@3oool006L0oooo00<000000?ooo`3o
ool0303oool2003o01P0l?o`0P00o`2g0?ooo`030000003oool0oooo0;P0
oooo0P0000000`3oool000000000000E0?ooo`00I`3oool00`000000oooo
0?ooo`090?ooo`<00?l0703`oo000`00o`00oooo0?ooo`2d0?ooo`030000
003oool0oooo06@0oooo3000o`1R0?ooo`00I`3oool00`000000oooo0?oo
o`060?ooo`<00?l0803`oo000`00o`00oooo0?ooo`2c0?ooo`030000003o
ool0oooo0640oooo0`00o`0<0?3ol0D00?l0G@3oool006L0oooo00<00000
0?ooo`3oool0103oool2003o02@0l?o`0P00o`2c0?ooo`030000003oool0
oooo05d0oooo1000o`0D0?3ol0@00?l0F@3oool006L0oooo00@000000?oo
o`3oool0oooo0`00o`0W0?3ol0030?ooo`00o`00oooo0;40oooo00<00000
0?ooo`3oool0F@3oool4003o01`0l?o`0`00o`1F0?ooo`00I`3oool01000
00000?l0003o0000o`0[0?3ol003003o003oool0oooo0;00oooo00<00000
0?ooo`3oool0E`3oool2003o02<0l?o`0P00o`1D0?ooo`00IP3oool2003o
02l0l?o`00<00?l00?ooo`3oool0[`3oool00`000000oooo0?ooo`0;003o
04X0oooo0P00o`0W0?3ol0<00?l0D@3oool006@0oooo0P00o`0b0?3ol003
003o003oool0oooo0:h0oooo0`00o`0;0?3ol0@00?l0A@3oool00`00o`00
l?o`0?3ol00Z0?3ol0<00?l0CP3oool00640oooo0`00o`0e0?3ol003003o
003oool0oooo0:/0oooo0P00o`0B0?3ol0@00?l0?`3oool2003o0300l?o`
0P00o`1<0?ooo`00G`3oool2003o03P0l?o`00<00?l00?ooo`3oool0ZP3o
ool00`00o`00l?o`0?3ol00F0?3ol0<00?l0>P3oool2003o03@0l?o`0P00
o`1:0?ooo`00G03oool3003o03/0l?o`00<00?l00?ooo`3oool0Z03oool0
0`00o`00l?o`0?3ol00J0?3ol0800?l0=P3oool2003o03P0l?o`0P00o`18
0?ooo`00FP3oool2003o03l0l?o`00<00?l00?ooo`3oool0YP3oool00`00
o`00l?o`0?3ol00M0?3ol0800?l0<`3oool00`00o`00l?o`0?3ol00j0?3o
l0<00?l0A@3oool005P0oooo0P00o`110?3ol003003o003`oo00oooo0:D0
oooo00<00?l00?3ol03`oo00803`oo02003o02l0oooo0P00o`100?3ol080
0?l0@`3oool005D0oooo0`00o`140?3ol003003o003oool0oooo0:<0oooo
00<00?l00?3ol03`oo008`3`oo03003o02/0oooo00<00?l00?3ol03`oo00
@P3`oo02003o0440oooo001D0?ooo`03003o003`oo00l?o`04H0l?o`00<0
0?l00?ooo`3oool0X@3oool00`00o`00l?o`0?3ol00W0?3ol0800?l09`3o
ool2003o04L0l?o`0`00o`0n0?ooo`00E03oool00`00o`00l?o`0?3ol017
0?3ol003003o003oool0oooo0:00oooo00<00?l00?3ol03`oo00:@3`oo03
003o0280oooo0P00o`1<0?3ol0800?l0?03oool005<0oooo00<00?l00?3o
l03`oo00B03`oo000`00o`00oooo0?ooo`2O0?ooo`03003o003`oo00l?o`
02d0l?o`0P00o`0O0?ooo`03003o003`oo00l?o`04h0l?o`0P00o`0j0?oo
o`00DP3oool00`00o`00l?o`0?3ol01:0?3ol003003o003oool0oooo09h0
oooo00<00?l00?3ol03`oo00;`3`oo02003o01`0oooo00<00?l00?3ol03`
oo00D@3`oo02003o03P0oooo001B0?ooo`03003o003`oo00l?o`04/0l?o`
00<00?l00?ooo`3oool0W03oool00`00o`00l?o`0?3ol00b0?3ol0800?l0
603oool2003o05H0l?o`0P00o`0f0?ooo`00D@3oool00`00o`00l?o`0?3o
l01=0?3ol003003o003oool0oooo09/0oooo00<00?l00?3ol03`oo00=03`
oo03003o01@0oooo00<00?l00?3ol03`oo00F03`oo02003o03@0oooo001@
0?ooo`030?3ol000o`00l?o`04h0l?o`00<00?l00?ooo`3oool0V`3oool0
0`00o`00l?o`0?3ol00g0?3ol0800?l0403oool2003o05d0l?o`0P00o`0b
0?ooo`00D03oool00`00o`00l?o`0?3ol01?0?3ol003003o003oool0oooo
09T0oooo00<00?l00?3ol03`oo00>P3`oo03003o00X0oooo0`00o`1Q0?3o
l003003o003oool0oooo02l0oooo001@0?ooo`03003o003`oo00l?o`04l0
l?o`00<00?l00?ooo`3oool0V@3oool00`00o`00l?o`0?3ol00m0?3ol0@0
0?l00`3oool3003o06D0l?o`0P00o`0_0?ooo`00C`3oool00`00o`00l?o`
0?3ol01A0?3ol003003o003oool0oooo09P0oooo00<00?l00?3ol03`oo00
@@3`oo03003o06X0l?o`00<00?l00?ooo`3oool0;03oool004l0oooo00<0
0?l00?3ol03`oo00D@3`oo000`00o`00oooo0?ooo`2H0?ooo`03003o003`
oo00l?o`0:l0l?o`00<00?l00?ooo`3oool0:`3oool004h0oooo00<00?l0
0?3ol03`oo00D`3`oo000`00o`00oooo0?ooo`2F0?ooo`03003o003`oo00
l?o`0;40l?o`00<00?l00?ooo`3oool0:P3oool004h0oooo00<00?l00?3o
l03`oo00E03`oo000`00o`00oooo0?ooo`1c0?ooo`80000000<0oooo0000
000000007@3oool00`00o`00l?o`0?3ol02b0?3ol003003o003oool0oooo
02T0oooo001>0?ooo`03003o003`oo00l?o`05@0l?o`00<00?l00?ooo`3o
ool0M03oool00`000000oooo0000000N0?ooo`03003o003`oo00l?o`0;80
l?o`00<00?l00?ooo`3oool0:@3oool004T0oooo1@0000000`00o`00l?o`
0?3ol01E0?3ol003003o00000000000006`00000203oool00`000000oooo
0?ooo`0M0?ooo`03003o003`oo00l?o`0;<0l?o`00<00?l00?ooo`3oool0
:03oool004h0oooo00<00?l00?3ol03`oo00E@3`oo000`00o`00l?o`0?oo
o`1b0?ooo`80000000<0oooo000000000000703oool00`00o`00l?o`0?3o
l02e0?3ol003003o003oool0oooo02L0oooo001>0?ooo`03003o003`oo00
l?o`05H0l?o`00<00?l00?ooo`3oool0TP3oool00`00o`00l?o`0?3ol02e
0?3ol003003o003oool0oooo02L0oooo001>0?ooo`03003o003`oo00l?o`
05L0l?o`00<00?l00?ooo`3oool0T@3oool00`00o`00l?o`0?3ol02f0?3o
l003003o003oool0oooo02H0oooo001>0?ooo`03003o003`oo00l?o`05P0
l?o`00<00?l00?ooo`3oool0T03oool00`00o`00l?o`0?3ol02f0?3ol003
003o003oool0oooo02H0oooo001>0?ooo`03003o003`oo00l?o`05P0l?o`
00<00?l00?ooo`3oool0S`3oool00`00o`00l?o`0?3ol02h0?3ol003003o
003oool0oooo02D0oooo001>0?ooo`03003o003`oo00l?o`05T0l?o`00<0
0?l00?ooo`3oool0SP3oool00`00o`00l?o`0?3ol02h0?3ol003003o003o
ool0oooo02D0oooo001>0?ooo`03003o003`oo00l?o`05X0l?o`00<00?l0
0?ooo`3oool0S@3oool00`00o`00l?o`0?3ol02i0?3ol003003o003oool0
oooo02@0oooo001>0?ooo`03003o003`oo00l?o`05/0l?o`00<00?l00?oo
o`3oool0S03oool00`00o`00l?o`0?3ol02i0?3ol003003o003oool0oooo
02@0oooo001>0?ooo`03003o003`oo00l?o`05`0l?o`00<00?l00?ooo`3o
ool0R`3oool00`00o`00l?o`0?3ol02i0?3ol003003o003oool0oooo02@0
oooo001>0?ooo`03003o003`oo00l?o`05d0l?o`00<00?l00?ooo`3oool0
RP3oool00`00o`00l?o`0?3ol02i0?3ol003003o003oool0oooo02@0oooo
001>0?ooo`03003o003`oo00l?o`05d0l?o`00<0oooo003o003oool0RP3o
ool00`00o`00l?o`0?3ol02i0?3ol003003o003oool0oooo02@0oooo001>
0?ooo`03003o003`oo00l?o`05l0l?o`00<00?l00?ooo`3oool0R03oool0
0`00o`00l?o`0?3ol02i0?3ol003003o003oool0oooo02@0oooo001?0?oo
o`03003o003`oo00l?o`05l0l?o`0`00o`270?ooo`03003o003`oo00l?o`
0;T0l?o`00<00?l00?ooo`3oool0903oool004l0oooo00<00?l00?3ol03`
oo00HP3`oo0K003o06`0oooo00<00?l00?3ol03`oo00^P3`oo000`00o`00
oooo0?ooo`0S0?ooo`00C`3oool00`00o`00l?o`0?3ol01m0?3ol0X00?l0
HP3oool00`00o`00l?o`0?3ol02j0?3ol003003o003oool0oooo02<0oooo
001@0?ooo`03003o003`oo00l?o`08H0l?o`1000o`1N0?ooo`03003o003`
oo00l?o`0;X0l?o`00<00?l00?ooo`3oool08`3oool00500oooo00<00?l0
0?3ol03`oo00RP3`oo04003o05X0oooo00<00?l00?3ol03`oo00^P3`oo00
0`00o`00oooo0?ooo`0S0?ooo`00D03oool00`00o`00l?o`0?3ol02>0?3o
l0800?l0F03oool00`00o`00l?o`0?3ol02j0?3ol003003o003oool0oooo
02<0oooo001A0?ooo`03003o003`oo00l?o`08l0l?o`0`00o`1E0?ooo`03
003o003`oo00l?o`0;X0l?o`00<00?l00?ooo`3oool08`3oool00540oooo
00<00?l00?3ol03`oo00TP3`oo03003o0580oooo00<00?l00?3ol03`oo00
^P3`oo000`00o`00oooo0?ooo`0S0?ooo`00D@3oool00`00o`00l?o`0?3o
l02E0?3ol0800?l0D03oool00`00o`00l?o`0?3ol02j0?3ol003003o003o
ool0oooo02<0oooo001B0?ooo`03003o003`oo00l?o`09H0l?o`0P00o`1>
0?ooo`03003o003`oo00l?o`0;X0l?o`00<00?l00?ooo`3oool08`3oool0
0580oooo00<00?l00?3ol03`oo00V03`oo000`00o`00oooo0?ooo`1;0?oo
o`03003o003`oo00l?o`0;X0l?o`00<00?l00?ooo`3oool08`3oool005<0
oooo00<00?l00?3ol03`oo00V03`oo02003o04/0oooo00<00?l00?3ol03`
oo00^@3`oo000`00o`00oooo0?ooo`0T0?ooo`00E03oool00`00o`00l?o`
0?3ol02I0?3ol003003o003oool0oooo04P0oooo00<00?l00?3ol03`oo00
^@3`oo000`00o`00oooo0?ooo`0T0?ooo`00E03oool00`00o`00l?o`0?3o
l02J0?3ol0800?l0B03oool00`00o`00l?o`0?3ol02i0?3ol003003o003o
ool0oooo02@0oooo001E0?ooo`03003o003`oo00l?o`09/0l?o`00<00?l0
0?ooo`3oool0A@3oool00`00o`00l?o`0?3ol02i0?3ol003003o003oool0
oooo02@0oooo001E0?ooo`03003o003`oo00l?o`09`0l?o`00<00?l00?oo
o`3oool0A03oool00`00o`00l?o`0?3ol02i0?3ol003003o003oool0oooo
02@0oooo001F0?ooo`03003o003`oo00l?o`09`0l?o`0P00o`140?ooo`03
003o003`oo00l?o`0;T0l?o`00<00?l00?ooo`3oool0903oool005H0oooo
00<00?l00?3ol03`oo00WP3`oo000`00o`00oooo0?ooo`110?ooo`03003o
003`oo00l?o`0;T0l?o`00<00?l00?ooo`3oool0903oool005L0oooo00<0
0?l00?3ol03`oo00WP3`oo02003o0440oooo00<00?l00?3ol03`oo00^03`
oo000`00o`00oooo0?ooo`0U0?ooo`00E`3oool00`00o`00oooo0?3ol02P
0?3ol003003o003oool0oooo03h0oooo00<00?l00?3ol03`oo00^03`oo00
0`00o`00oooo0?ooo`0U0?ooo`00F03oool00`00o`00l?o`0?3ol02P0?3o
l0800?l0?P3oool00`00o`00l?o`0?3ol02h0?3ol003003o003oool0oooo
02D0oooo001I0?ooo`03003o003`oo00l?o`0:40l?o`00<00?l00?ooo`3o
ool0>`3oool00`00o`00l?o`0?3ol02h0?3ol003003o003oool0oooo02D0
oooo001I0?ooo`03003o003oool0l?o`0:80l?o`00<00?l00?ooo`3oool0
>P3oool00`00o`00l?o`0?3ol02g0?3ol003003o003oool0oooo02H0oooo
001J0?ooo`03003o003`oo00l?o`0:80l?o`0P00o`0j0?ooo`03003o003`
oo00l?o`0;L0l?o`00<00?l00?ooo`3oool09P3oool005/0oooo00<00?l0
0?3ol03`oo00X`3`oo000`00o`00oooo0?ooo`0g0?ooo`03003o003`oo00
l?o`0;L0l?o`00<00?l00?ooo`3oool09P3oool005`0oooo00<00?l00?3o
l03`oo00X`3`oo02003o03L0oooo00<00?l00?3ol03`oo00]P3`oo000`00
o`00oooo0?ooo`0W0?ooo`00G03oool00`00o`00oooo0?3ol02U0?3ol003
003o003oool0oooo03D0oooo00<00?l00?3ol03`oo00]@3`oo000`00o`00
oooo0?ooo`0W0?ooo`00G@3oool00`00o`00l?o`0?3ol02U0?3ol0800?l0
=@3oool00`00o`00l?o`0?3ol02e0?3ol003003o003oool0oooo02L0oooo
001N0?ooo`03003o003`oo00l?o`0:H0l?o`0P00o`0d0?ooo`03003o003`
oo00l?o`0;@0l?o`00<00?l00?ooo`3oool09`3oool005l0oooo00<00?l0
0?3ol03`oo00Y`3`oo000`00o`00oooo0?ooo`0b0?ooo`03003o003`oo00
l?o`0;80l?o`00<00?l00?ooo`3oool0:03oool00600oooo00<00?l00?3o
l03`oo00Y`3`oo000`00o`00oooo0?ooo`0a0?ooo`03003o003`oo00l?o`
0;80l?o`00<00?l00?ooo`3oool0:03oool00640oooo0P00o`2X0?3ol003
003o003oool0oooo0340oooo00<00?l00?3ol03`oo00/@3`oo000`00o`00
oooo0?ooo`0X0?ooo`00HP3oool00`3`oo000?l00?3ol02W0?3ol003003o
003oool0oooo0340oooo00<00?l00?3ol03`oo00[`3`oo000`00o`00oooo
0?ooo`0Y0?ooo`00H`3oool00`3`oo000?l00?3ol02V0?3ol003003o003o
ool0oooo0380oooo00<00?l00?3ol03`oo00[P3`oo000`00o`00oooo0?oo
o`0Y0?ooo`00I03oool00`3`oo000?l00?3ol02V0?3ol003003o003oool0
oooo0380oooo00<00?l00?3ol03`oo00[@3`oo000`00o`00oooo0?ooo`0Y
0?ooo`00I@3oool00`3`oo000?l00?3ol02V0?3ol003003o003oool0oooo
0380oooo0P00o`2]0?3ol003003o003oool0oooo02T0oooo001W0?ooo`03
003o003`oo00l?o`0:@0l?o`00<00?l00?ooo`3oool0=03oool00`00o`00
l?o`0?3ol02Y0?3ol003003o003oool0oooo02X0oooo001W0?ooo`030000
0000o`00l?o`0:@0l?o`0P00o`0f0?ooo`03003o003`oo00l?o`0:P0l?o`
00<00?l00?ooo`3oool0:P3oool006L0oooo00@000000?ooo`00o`000?l0
Y03`oo000`00o`00oooo0?ooo`0e0?ooo`800?l0Z03`oo000`00o`00oooo
0?ooo`0Z0?ooo`00I`3oool01@000000oooo0?ooo`3`oo000?l00:<0l?o`
00<00?l00?ooo`3oool0=`3oool00`00o`00l?o`0?3ol02U0?3ol003003o
003oool0oooo02X0oooo001W0?ooo`060000003oool0oooo0?ooo`3`oo00
0?l0XP3`oo000`00o`00oooo0?ooo`0g0?ooo`0300000000o`000?l00:@0
l?o`00<00?l00?ooo`3oool0:`3oool006L0oooo00<000000?ooo`3oool0
0P3oool00`3`oo000?l00?3ol02P0?3ol003003o003oool0oooo03L0oooo
00<000000?ooo`3oool00`00o`2Q0?3ol003003o003oool0oooo02/0oooo
001W0?ooo`030000003oool0oooo00<0oooo00<0l?o`003o003`oo00W`3`
oo000`00o`00oooo0?ooo`0g0?ooo`030000003oool0oooo00<0oooo0`00
o`2N0?3ol003003o003oool0oooo02/0oooo001W0?ooo`030000003oool0
oooo00@0oooo00<0l?o`003o003`oo00W@3`oo000`00o`00oooo0?ooo`0h
0?ooo`030000003oool0oooo00H0oooo1000o`120?3ol0<000000`3`oo00
0`000000l?o`0?3ol01?0?3ol003003o003oool0oooo02/0oooo001W0?oo
o`030000003oool0oooo00H0oooo00<00?l00?3ol03`oo00V`3`oo000`00
o`00oooo0?ooo`0h0?ooo`030000003oool0oooo00X0oooo1@00o`0n0?3o
l0050000003`oo00l?o`0?3ol0000000D@3`oo000`00o`00oooo0?ooo`0/
0?ooo`00I`3oool00`000000oooo0?ooo`070?ooo`03003o003`oo00l?o`
09X0l?o`00<00?l00?ooo`3oool0>03oool00`000000oooo0?ooo`0?0?oo
o`<00?l0>`3`oo0010000000l?o`0?3ol000001B0?3ol003003o003oool0
oooo02`0oooo001W0?ooo`030000003oool0oooo00P0oooo00<00?l00?3o
l03`oo00V@3`oo000`00o`00oooo0?ooo`0h0?ooo`030000003oool0oooo
0180oooo0`00o`0h0?3ol0@00000DP3`oo000`00o`00oooo0?ooo`0/0?oo
o`00I`3oool00`000000oooo0?ooo`090?ooo`03003o003`oo00l?o`09L0
l?o`00<00?l00?ooo`3oool0>@3oool00`000000oooo0?ooo`0E0?ooo`D0
0?l0<`3`oo001@000000l?o`0?3ol03`oo0000000500l?o`00<00?l00?oo
o`3oool0;@3oool006L0oooo00<000000?ooo`3oool02P3oool00`00o`00
l?o`0?3ol02F0?3ol003003o003oool0oooo03T0oooo00<000000?ooo`3o
ool06P3oool4003o02l0l?o`00D000000?3ol03`oo00l?o`0000001@0?3o
l003003o003oool0oooo02d0oooo001W0?ooo`030000003oool0oooo00/0
oooo00<00?l00?3ol03`oo00U03`oo000`00o`00oooo0?ooo`0j0?ooo`03
0000003oool0oooo01h0oooo0`00o`0/0?3ol0050000003`oo00l?o`0?3o
l0000000D03`oo000`00o`00oooo0?ooo`0]0?ooo`00I`3oool00`000000
oooo0?ooo`0<0?ooo`03003o003`oo00l?o`09<0l?o`00<00?l00?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0Q0?ooo`<00?l0:03`oo0500000500
l?o`00<00?l00?ooo`3oool0;P3oool006L0oooo00<000000?ooo`3oool0
303oool00`00o`00l?o`0?3ol02B0?3ol003003o003oool0oooo03/0oooo
00<000000?ooo`3oool0903oool2003o07/0l?o`00<00?l00?ooo`3oool0
;P3oool006L0oooo00<000000?ooo`3oool03@3oool00`00o`00l?o`0?3o
l02A0?3ol003003o003oool0oooo03/0oooo00<000000?ooo`3oool09P3o
ool2003o07T0l?o`00<00?l00?ooo`3oool0;P3oool006L0oooo00<00000
0?ooo`3oool03P3oool00`00o`00l?o`0?3ol02?0?3ol003003o003oool0
oooo03`0oooo00<000000?ooo`3oool0:03oool00`00o`00l?o`0?3ol01f
0?3ol003003o003oool0oooo02h0oooo001W0?ooo`030000003oool0oooo
00h0oooo00<00?l00?3ol03`oo00S`3`oo000`00o`00oooo0?ooo`0l0?oo
o`030000003oool0oooo02T0oooo00<00?l00?3ol03`oo00M03`oo000`00
o`00oooo0?ooo`0_0?ooo`00I`3oool00`000000oooo0?ooo`0?0?ooo`03
003o003`oo00l?o`08d0l?o`00<00?l00?ooo`3oool0?@3oool00`000000
oooo0?ooo`0Z0?ooo`03003o003`oo00l?o`07<0l?o`00<00?l00?ooo`3o
ool0;`3oool006L0oooo00<000000?ooo`3oool03`3oool00`00o`00l?o`
0?3ol02=0?3ol003003o003oool0oooo03d0oooo00<000000?ooo`3oool0
:`3oool00`00o`00l?o`0?3ol01b0?3ol003003o003oool0oooo02l0oooo
001W0?ooo`030000003oool0oooo00l0oooo00<00?l00?3ol03`oo008`3`
oo04000006D0l?o`00<00?l00?ooo`3oool0?P3oool00`000000oooo0?oo
o`0[0?ooo`03003o003`oo00l?o`0740l?o`00<00?l00?ooo`3oool0<03o
ool006L0oooo00<000000?ooo`3oool03`3oool00`00o`00l?o`0?3ol00T
0?3ol0040000003`oo00l?o`000006@0l?o`00<00?l00?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0/0?ooo`03003o003`oo00l?o`03@0l?o`0`00
000i0?3ol003003o003oool0oooo0300oooo001W0?ooo`030000003oool0
oooo00l0oooo00<00?l00?3ol03`oo00903`oo001@000000l?o`0?3ol03`
oo0000000680l?o`00<00?l00?ooo`3oool0?`3oool00`000000oooo0?oo
o`0/0?ooo`03003o003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=P3`
oo000`00o`00oooo0?ooo`0`0?ooo`00I`3oool00`000000oooo0?ooo`0?
0?ooo`03003o003`oo00l?o`02@0l?o`00D000000?3ol03`oo00l?o`0000
001Q0?3ol003003o003oool0oooo0400oooo00<000000?ooo`3oool0;03o
ool00`00o`00l?o`0?3ol00M0?3ol0<000000`3`oo000`000000l?o`0?3o
l008000000040?3ol0000000000000000080l?o`100000030?3ol0@00000
<03`oo000`00o`00oooo0?ooo`0a0?ooo`00I`3oool00`000000oooo0?oo
o`0?0?ooo`03003o003`oo00l?o`02@0l?o`00D000000?3ol03`oo00l?o`
0000001Q0?3ol003003o003oool0oooo0400oooo00<000000?ooo`3oool0
;@3oool00`00o`00l?o`0?3ol00M0?3ol0050000003`oo00l?o`0?3ol000
00000P3`oo001@000000l?o`0?3ol03`oo0000000080l?o`00D000000?3o
l03`oo00l?o`000000020?3ol0050000003`oo00l?o`0?3ol00000000P3`
oo000`000000l?o`0?3ol00b0?3ol003003o003oool0oooo0340oooo001W
0?ooo`030000003oool0oooo00l0oooo00<00?l00?3ol03`oo00903`oo00
1@000000l?o`0?3ol03`oo0000000600l?o`00<00?l00?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0]0?ooo`03003o003`oo00l?o`01d0l?o`00@0
00000?3ol03`oo0000000`3`oo001@000000l?o`0?3ol03`oo0000000080
l?o`00D000000?3ol03`oo00l?o`000000020?3ol0050000003`oo00l?o`
0?3ol00000000P3`oo000`000000l?o`0?3ol00b0?3ol003003o003oool0
oooo0340oooo001W0?ooo`030000003oool0oooo00l0oooo00<00?l00?3o
l03`oo00903`oo0010000000l?o`0?3ol000001Q0?3ol003003o003oool0
oooo0440oooo00<000000?ooo`3oool0;@3oool00`00o`00l?o`0?3ol00M
0?3ol0@00000103`oo0400000080l?o`00D000000?3ol03`oo00l?o`0000
00020?3ol0050000003`oo00l?o`0?3ol00000000P3`oo0500000300l?o`
00<00?l00?ooo`3oool0<@3oool006L0oooo00<000000?ooo`3oool03`3o
ool00`00o`00l?o`0?3ol00S0?3ol0@00000H@3`oo000`00o`00oooo0?oo
o`120?ooo`030000003oool0oooo02d0oooo00<00?l00?3ol03`oo007@3`
oo001@000000l?o`0?3ol03`oo0000000080l?o`00D000000?3ol03`oo00
l?o`000000020?3ol08000000P3`oo0010000000l?o`0?3ol00000020?3o
l08000000P3`oo001@000000l?o`0?3ol03`oo00000002l0l?o`00<00?l0
0?ooo`3oool0<P3oool006L0oooo00<000000?ooo`3oool03`3oool00`00
o`00l?o`0?3ol0280?3ol003003o003oool0oooo0480oooo00<000000?oo
o`3oool0;@3oool00`00o`00l?o`0?3ol00M0?3ol0050000003`oo00l?o`
0?3ol00000000`3`oo0300000080l?o`0P0000000`3`oo00000000000004
0?3ol080000000<0l?o`0000000000000P3`oo0300000300l?o`00<00?l0
0?ooo`3oool0<P3oool006L0oooo00<000000?ooo`3oool03P3oool00`00
o`00l?o`0?3ol0280?3ol003003o003oool0oooo04<0oooo00<000000?oo
o`3oool0;@3oool00`00o`00l?o`0?3ol00M0?3ol0050000003`oo00l?o`
0?3ol0000000B`3`oo000`00o`00oooo0?ooo`0b0?ooo`00I`3oool00`00
0000oooo0?ooo`0>0?ooo`03003o003`oo00l?o`08L0l?o`00<00?l00?oo
o`3oool0A03oool00`000000oooo0?ooo`0]0?ooo`03003o003`oo00l?o`
01`0l?o`1@00001<0?3ol003003o003oool0oooo0380oooo001W0?ooo`03
0000003oool0oooo00h0oooo00<00?l00?3ol03`oo00Q`3`oo000`00o`00
oooo0?ooo`140?ooo`030000003oool0oooo02d0oooo00<00?l00?3ol03`
oo00K03`oo000`00o`00oooo0?ooo`0c0?ooo`00I`3oool00`000000oooo
0?ooo`0>0?ooo`03003o003`oo00l?o`08H0l?o`00<00?l00?ooo`3oool0
A@3oool00`000000oooo0?ooo`0]0?ooo`03003o003`oo00l?o`06`0l?o`
00<00?l00?ooo`3oool0<`3oool006L0oooo00<000000?ooo`3oool03@3o
ool00`00o`00l?o`0?3ol0270?3ol003003o003oool0oooo04D0oooo00<0
00000?ooo`3oool0;@3oool00`00o`00l?o`0?3ol01/0?3ol003003o003o
ool0oooo03<0oooo001W0?ooo`030000003oool0oooo00d0oooo00<00?l0
0?3ol03`oo00QP3`oo000`00o`00oooo0?ooo`160?ooo`030000003oool0
oooo02d0oooo00<00?l00?3ol03`oo00J`3`oo000`00o`00oooo0?ooo`0d
0?ooo`00I`3oool00`000000oooo0?ooo`0<0?ooo`03003o003`oo00l?o`
02H0l?o`100000050?3ol0<000000P3`oo0700000080l?o`1@0000000`3`
oo00000000000003000000050?3ol000000000000000003`oo000`00000g
0?3ol003003o003oool0oooo04H0oooo00<000000?ooo`3oool0;@3oool0
0`00o`00l?o`0?3ol01[0?3ol003003o003oool0oooo03@0oooo001W0?oo
o`030000003oool0oooo00`0oooo00<00?l00?3ol03`oo009`3`oo001000
0000l?o`0?3ol00000030?3ol0050000003`oo00l?o`0?3ol00000000P3`
oo001@000000l?o`0000003`oo0000000080l?o`00D000000?3ol03`oo00
l?o`000000040?3ol0030000003`oo00l?o`0080l?o`00D000000?3ol03`
oo00l?o`0000000g0?3ol003003o003oool0oooo04L0oooo00<000000?oo
o`3oool0;03oool00`00o`00l?o`0?3ol01/0?3ol003003o003oool0oooo
03@0oooo001W0?ooo`030000003oool0oooo00`0oooo00<00?l00?3ol03`
oo009`3`oo001@000000l?o`0?3ol03`oo0000000080l?o`00D000000?3o
l03`oo00l?o`000000020?3ol0050000003`oo0000000?3ol00000000P3`
oo001@000000l?o`0?3ol03`oo00000000@0l?o`00<000000?3ol03`oo00
0P3`oo001@000000l?o`0?3ol03`oo00000003L0l?o`00<00?l00?ooo`3o
ool0A`3oool00`000000oooo0?ooo`0/0?ooo`03003o003`oo00l?o`06/0
l?o`00<00?l00?ooo`3oool0=@3oool006L0oooo00<000000?ooo`3oool0
303oool00`00o`00l?o`0?3ol00W0?3ol0050000003`oo00l?o`0?3ol000
00000P3`oo001@000000l?o`0?3ol03`oo0000000080l?o`00D000000?3o
l0000000l?o`000000030?3ol0@00000103`oo000`000000l?o`0?3ol002
0?3ol0050000003`oo00l?o`0?3ol0000000=P3`oo000`00o`00oooo0?oo
o`180?ooo`030000003oool0oooo02`0oooo00<00?l00?3ol03`oo00J`3`
oo000`00o`00oooo0?ooo`0e0?ooo`00I`3oool00`000000oooo0?ooo`0;
0?ooo`03003o003`oo00l?o`02P0l?o`00D000000?3ol03`oo00l?o`0000
00020?3ol0050000003`oo00l?o`0?3ol00000000P3`oo001@000000l?o`
0000003`oo0000000080l?o`00D000000?3ol03`oo00l?o`000000040?3o
l0030000003`oo00l?o`0080l?o`0P0000020?3ol0030000003`oo00l?o`
03@0l?o`00<00?l00?ooo`3oool0B03oool00`000000oooo0?ooo`0[0?oo
o`03003o003`oo00l?o`06`0l?o`00<00?l00?ooo`3oool0=@3oool006L0
oooo00<000000?ooo`3oool02`3oool00`00o`00l?o`0?3ol00X0?3ol005
0000003`oo00l?o`0?3ol00000000`3`oo0300000080l?o`0`0000000`3`
oo0000000?3ol0030?3ol0<000000`3`oo03000000<0l?o`0P0000000`3`
oo0000000000000f0?3ol003003o003oool0oooo04T0oooo00<000000?oo
o`3oool0:`3oool00`00o`00l?o`0?3ol01/0?3ol003003o003oool0oooo
03D0oooo001W0?ooo`030000003oool0oooo00/0oooo00<00?l00?3ol03`
oo00:03`oo0010000000l?o`0?3ol000001I0?3ol003003o003oool0oooo
04T0oooo00<000000?ooo`3oool0:`3oool00`00o`00l?o`0?3ol01[0?3o
l003003o003oool0oooo03H0oooo001W0?ooo`030000003oool0oooo00X0
oooo00<00?l00?3ol03`oo00:03`oo04000001/0l?o`00<000000?3ol03`
oo00>`3`oo000`00o`00oooo0?ooo`1:0?ooo`030000003oool0oooo02X0
oooo00<00?l00?3ol03`oo00K03`oo000`00o`00oooo0?ooo`0f0?ooo`00
I`3oool00`000000oooo0?ooo`0:0?ooo`03003o003`oo00l?o`08D0l?o`
00<00?l00?ooo`3oool0BP3oool00`000000oooo0?ooo`0Z0?ooo`03003o
003`oo00l?o`06`0l?o`00<00?l00?ooo`3oool0=P3oool006L0oooo00<0
00000?ooo`3oool02@3oool00`00o`00l?o`0?3ol0250?3ol003003o003o
ool0oooo04/0oooo00<000000?ooo`3oool0:P3oool00`00o`00l?o`0?3o
l01[0?3ol003003o003oool0oooo03L0oooo001W0?ooo`030000003oool0
oooo00T0oooo00<00?l00?3ol03`oo00Q@3`oo000`00o`00oooo0?ooo`1;
0?ooo`030000003oool0oooo02T0oooo00<00?l00?3ol03`oo00K03`oo00
0`00o`00oooo0?ooo`0g0?ooo`00I`3oool00`000000oooo0?ooo`080?oo
o`03003o003`oo00l?o`08D0l?o`00<00?l00?ooo`3oool0C03oool00`00
0000oooo0?ooo`0Y0?ooo`03003o003`oo00l?o`06`0l?o`00<00?l00?oo
o`3oool0=`3oool006L0oooo00<000000?ooo`3oool0203oool00`00o`00
l?o`0?3ol0250?3ol003003o003oool0oooo04`0oooo00<000000?ooo`3o
ool0:@3oool00`00o`00l?o`0?3ol01[0?3ol003003o003oool0oooo03P0
oooo001W0?ooo`030000003oool0oooo00L0oooo00<00?l00?3ol03`oo00
Q@3`oo000`00o`00oooo0?ooo`1=0?ooo`030000003oool0oooo02P0oooo
00<00?l00?3ol03`oo00K03`oo000`00o`00oooo0?ooo`0h0?ooo`00I`3o
ool00`000000oooo0?ooo`070?ooo`03003o003`oo00l?o`08D0l?o`00<0
0?l00?ooo`3oool0C@3oool00`000000oooo0?ooo`0X0?ooo`03003o003`
oo00l?o`06`0l?o`00<00?l00?ooo`3oool0>03oool006L0oooo00<00000
0?ooo`3oool01P3oool00`00o`00l?o`0?3ol0250?3ol003003o003oool0
oooo04h0oooo00<000000?ooo`3oool09`3oool00`00o`00l?o`0?3ol01/
0?3ol003003o003oool0oooo03T0oooo001W0?ooo`030000003oool0oooo
00H0oooo00<00?l00?3ol03`oo00Q@3`oo000`00o`00oooo0?ooo`1>0?oo
o`030000003oool0oooo02H0oooo00<00?l00?3ol03`oo00K@3`oo000`00
o`00oooo0?ooo`0i0?ooo`00I`3oool00`000000oooo0?ooo`050?ooo`03
003o003`oo00l?o`08D0l?o`00<00?l00?ooo`3oool0C`3oool00`000000
oooo0?ooo`0U0?ooo`03003o003`oo00l?o`06d0l?o`00<00?l00?ooo`3o
ool0>P3oool006L0oooo00<000000?ooo`3oool01@3oool00`00o`00l?o`
0?3ol0250?3ol003003o003oool0oooo04l0oooo00<000000?ooo`3oool0
9@3oool00`00o`00l?o`0?3ol01]0?3ol003003o003oool0oooo03X0oooo
001W0?ooo`030000003oool0oooo00@0oooo00<00?l00?3ol03`oo00Q@3`
oo000`00o`00oooo0?ooo`1@0?ooo`030000003oool0oooo02D0oooo00<0
0?l00?3ol03`oo00K03`oo000`00o`00oooo0?ooo`0k0?ooo`00I`3oool0
0`000000oooo0?ooo`030?ooo`03003o003`oo00l?o`08H0l?o`00<00?l0
0?ooo`3oool0D03oool00`000000oooo0?ooo`0T0?ooo`03003o003`oo00
l?o`06d0l?o`00<00?l00?ooo`3oool0>`3oool006L0oooo00<000000?oo
o`3oool00`3oool00`00o`00l?o`0?3ol0250?3ol003003o003oool0oooo
0540oooo00<000000?ooo`3oool0903oool00`00o`00l?o`0?3ol01/0?3o
l003003o003oool0oooo03`0oooo001W0?ooo`030000003oool0oooo0080
oooo00<00?l00?3ol03`oo00QP3`oo000`00o`00oooo0?ooo`1A0?ooo`03
0000003oool0oooo02@0oooo00<00?l00?3ol03`oo00K03`oo000`00o`00
oooo0?ooo`0l0?ooo`00I`3oool01@000000oooo0?ooo`3oool00?l008P0
l?o`00<00?l00?ooo`3oool0DP3oool00`000000oooo0?ooo`0T0?ooo`03
003o003`oo00l?o`06/0l?o`00<00?l00?ooo`3oool0?@3oool006L0oooo
00D000000?ooo`3oool0oooo003o00280?3ol003003o003oool0oooo0580
oooo00<000000?ooo`3oool0903oool00`00o`00l?o`0?3ol01[0?3ol003
003o003oool0oooo03d0oooo001W0?ooo`040000003oool0oooo003o08P0
l?o`00<00?l00?ooo`3oool0D`3oool00`000000oooo0?ooo`0T0?ooo`03
003o003`oo00l?o`06/0l?o`00<00?l00?ooo`3oool0?@3oool006L0oooo
00<000000?ooo`00o`00R@3`oo000`00o`00oooo0?ooo`1C0?ooo`030000
003oool0oooo02D0oooo00<00?l00?3ol03`oo00J@3`oo000`00o`00oooo
0?ooo`0n0?ooo`00I`3oool00`000000oooo003o00280?3ol003003o003o
ool0oooo05@0oooo00<000000?ooo`3oool09@3oool00`00o`00l?o`0?3o
l01Y0?3ol003003o003oool0oooo03h0oooo001W0?ooo`0300000000o`00
l?o`08P0l?o`00<00?l00?ooo`3oool0E03oool00`000000oooo0?ooo`0U
0?ooo`03003o003`oo00l?o`06P0l?o`00<00?l00?ooo`3oool0?`3oool0
06L0oooo00<00000003o003`oo00Q`3`oo000`00o`00oooo0?ooo`1E0?oo
o`030000003oool0oooo02H0oooo00<00?l00?3ol03`oo00I`3`oo000`00
o`00oooo0?ooo`0o0?ooo`00I`3oool00`00o`00l?o`0?3ol0260?3ol003
003o003oool0oooo05H0oooo00<000000?ooo`3oool09P3oool00`00o`00
l?o`0?3ol01V0?3ol003003o003oool0oooo0400oooo001W0?ooo`03003o
003`oo00l?o`08H0l?o`00<00?l00?ooo`3oool0EP3oool00`000000oooo
0?ooo`0W0?ooo`03003o003`oo00l?o`06D0l?o`00<00?l00?ooo`3oool0
@03oool006H0oooo00<00?l00?3ol03`oo00QP3`oo000`00o`00oooo0?oo
o`1G0?ooo`030000003oool0oooo02L0oooo00<00?l00?3ol03`oo00I03`
oo000`00o`00oooo0?ooo`110?ooo`00IP3oool00`00o`00l?o`0?3ol026
0?3ol003003o003oool0oooo05L0oooo00<000000?ooo`3oool09`3oool0
0`00o`00l?o`0?3ol01T0?3ol003003o003oool0oooo0440oooo001V0?oo
o`03003o003`oo00l?o`08D0l?o`00<00?l00?ooo`3oool0F03oool00`00
0000oooo0?ooo`0X0?ooo`03003o003`oo00l?o`0680l?o`00<00?l00?oo
o`3oool0@P3oool006H0oooo00<00?l00?3ol03`oo00Q03`oo000`00o`00
oooo0?ooo`1I0?ooo`030000003oool0oooo02P0oooo00<00?l00?3ol03`
oo00H@3`oo000`00o`00oooo0?ooo`130?ooo`00IP3oool00`00o`00l?o`
0?3ol0230?3ol003003o003oool0oooo05X0oooo00<000000?ooo`3oool0
:@3oool00`00o`00l?o`0?3ol01O0?3ol003003o003oool0oooo04@0oooo
001V0?ooo`03003o003`oo00l?o`08<0l?o`00<00?l00?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0Y0?ooo`03003o003`oo00l?o`05l0l?o`00<0
0?l00?ooo`3oool0A03oool006H0oooo00<00?l00?3ol03`oo00PP3`oo00
0`00o`00oooo0?ooo`1K0?ooo`030000003oool0oooo02X0oooo00<00?l0
0?3ol03`oo00G@3`oo000`00o`00oooo0?ooo`150?ooo`00IP3oool00`00
o`00l?o`0?3ol0210?3ol003003o003oool0oooo05`0oooo00<000000?oo
o`3oool0:P3oool00`00o`00l?o`0?3ol01L0?3ol003003o003oool0oooo
04H0oooo001W0?ooo`03003o003`oo00l?o`07l0l?o`00<00?l00?ooo`3o
ool0G@3oool00`000000oooo0?ooo`0[0?ooo`03003o003`oo00l?o`05X0
l?o`00<00?l00?ooo`3oool0A`3oool006L0oooo00<00?l00?3ol03`oo00
OP3`oo000`00o`00oooo0?ooo`1N0?ooo`030000003oool0oooo02/0oooo
00<00?l00?3ol03`oo00F@3`oo000`00o`00oooo0?ooo`180?ooo`00I`3o
ool00`0000000?l00?3ol01m0?3ol003003o003oool0oooo05l0oooo00<0
00000?ooo`3oool0;03oool00`00o`00l?o`0?3ol01H0?3ol003003o003o
ool0oooo04P0oooo001W0?ooo`0300000000o`00l?o`07`0l?o`00<00?l0
0?ooo`3oool0H03oool00`000000oooo0?ooo`0/0?ooo`03003o003`oo00
l?o`05L0l?o`00<00?l00?ooo`3oool0B@3oool006L0oooo00<000000?oo
o`00o`00NP3`oo000`3oool00?l00?ooo`1R0?ooo`030000003oool0oooo
02d0oooo00<00?l00?3ol03`oo00E@3`oo000`00o`00oooo0?ooo`1:0?oo
o`00I`3oool010000000oooo0?ooo`00o`1h0?3ol0030?ooo`00o`00oooo
06<0oooo00<000000?ooo`3oool0;@3oool00`00o`00l?o`0?3ol01D0?3o
l003003o003oool0oooo04/0oooo001W0?ooo`050000003oool0oooo0?oo
o`00o`00MP3`oo000`3oool00?l00?ooo`1T0?ooo`030000003oool0oooo
02h0oooo00<00?l00?3ol03`oo00DP3`oo000`00o`00oooo0?ooo`1<0?oo
o`00I`3oool00`000000oooo0?ooo`020?ooo`03003o003`oo00l?o`0780
l?o`0P00o`1V0?ooo`030000003oool0oooo02h0oooo00<00?l00?3ol03`
oo00D03`oo02003o04l0oooo001W0?ooo`030000003oool0oooo00<0oooo
00<00?l00?3ol03`oo00L03`oo000`00o`00oooo0?ooo`1V0?ooo`030000
003oool0oooo02l0oooo00<00?l00?3ol03`oo00CP3`oo000`00o`00oooo
0?ooo`1?0?ooo`00I`3oool00`000000oooo0?ooo`040?ooo`800?l0K`3`
oo000`00o`00oooo0?ooo`1W0?ooo`030000003oool0oooo0300oooo00<0
0?l00?3ol03`oo00C03`oo000`00o`00oooo0?ooo`1@0?ooo`00I`3oool0
0`000000oooo0?ooo`050?ooo`030?3ol000o`00l?o`06`0l?o`00<00?l0
0?ooo`3oool0J03oool00`000000oooo0?ooo`0`0?ooo`03003o003`oo00
l?o`04/0l?o`00<00?l00?ooo`3oool0D@3oool006L0oooo00<000000?oo
o`3oool01P3oool00`3`oo000?l00?3ol01Z0?3ol003003o003oool0oooo
06T0oooo00<000000?ooo`3oool0<@3oool00`00o`00l?o`0?3ol0190?3o
l003003o003oool0oooo0580oooo001W0?ooo`030000003oool0oooo00L0
oooo00<0l?o`003o003`oo00I`3`oo02003o06`0oooo00<000000?ooo`3o
ool0<@3oool00`00o`00l?o`0?3ol0180?3ol003003o003oool0oooo05<0
oooo001W0?ooo`030000003oool0oooo00T0oooo0P00o`1U0?3ol003003o
003oool0oooo06`0oooo00<000000?ooo`3oool0<P3oool00`00o`00l?o`
0?3ol0160?3ol003003o003oool0oooo05@0oooo001W0?ooo`030000003o
ool0oooo00/0oooo00<00?l00?3ol03`oo00H@3`oo000`00o`00oooo0?oo
o`1]0?ooo`030000003oool0oooo0380oooo00<00?l00?3ol03`oo00A@3`
oo000`00o`00oooo0?ooo`1E0?ooo`00I`3oool00`000000oooo0?ooo`0<
0?ooo`03003o003`oo00l?o`05l0l?o`00<00?l00?ooo`3oool0KP3oool0
0`000000oooo0?ooo`0c0?ooo`03003o003`oo00l?o`04<0l?o`00<00?l0
0?ooo`3oool0EP3oool006L0oooo00<000000?ooo`3oool03@3oool2003o
05h0l?o`00<00?l00?ooo`3oool0K`3oool00`000000oooo0?ooo`0d0?oo
o`03003o003`oo00l?o`0440l?o`00<00?l00?ooo`3oool0E`3oool006L0
oooo00<000000?ooo`3oool03`3oool2003o05/0l?o`00<00?l00?ooo`3o
ool0L03oool00`000000oooo0?ooo`0d0?ooo`03003o003`oo00l?o`0400
l?o`00<00?l00?ooo`3oool0F03oool006L0oooo00<000000?ooo`3oool0
4@3oool2003o05P0l?o`00<00?l00?ooo`3oool0L@3oool00`000000oooo
0?ooo`0e0?ooo`03003o003`oo00l?o`03d0l?o`0P00o`1K0?ooo`00I`3o
ool00`000000oooo0?ooo`0C0?ooo`800?l0E@3`oo000`00o`00oooo0?oo
o`1b0?ooo`030000003oool0oooo03H0oooo00<00?l00?3ol03`oo00>`3`
oo000`00o`00oooo0?ooo`1K0?ooo`00I`3oool00`000000oooo0?ooo`0E
0?ooo`800?l0DP3`oo000`00o`00oooo0?ooo`1c0?ooo`030000003oool0
oooo03L0oooo00<00?l00?3ol03`oo00>@3`oo000`00o`00oooo0?ooo`1L
0?ooo`00I`3oool00`000000oooo0?ooo`0G0?ooo`800?l0C`3`oo000`00
o`00oooo0?ooo`1d0?ooo`030000003oool0oooo03L0oooo00<00?l00?3o
l03`oo00>03`oo000`00o`00oooo0?ooo`1M0?ooo`00I`3oool00`000000
oooo0?ooo`0I0?ooo`800?l0B`3`oo02003o07L0oooo00<000000?ooo`3o
ool0>03oool00`00o`00l?o`0?3ol00e0?3ol0800?l0H03oool006L0oooo
00<000000?ooo`3oool06`3oool2003o04P0l?o`00<00?l00?ooo`3oool0
M`3oool00`000000oooo0?ooo`0i0?ooo`03003o003`oo00l?o`03<0l?o`
00<00?l00?ooo`3oool0H03oool006L0oooo00<000000?ooo`3oool07@3o
ool2003o04D0l?o`00<00?l00?ooo`3oool0N03oool00`000000oooo0?oo
o`0j0?ooo`03003o003`oo00l?o`0340l?o`00<00?l00?ooo`3oool0H@3o
ool006L0oooo00<000000?ooo`3oool07`3oool2003o0480l?o`00<00?l0
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0j0?ooo`03003o003`oo00
l?o`02l0l?o`0P00o`1T0?ooo`00I`3oool00`000000oooo0?ooo`0Q0?oo
o`<00?l0?@3`oo02003o07`0oooo00<000000?ooo`3oool0>`3oool00`00
o`00l?o`0?3ol00]0?3ol003003o003oool0oooo06@0oooo001W0?ooo`03
0000003oool0oooo02@0oooo0P00o`0j0?3ol003003o003oool0oooo07`0
oooo00<000000?ooo`3oool0?03oool00`00o`00l?o`0?3ol00Z0?3ol080
0?l0I`3oool006L0oooo00<000000?ooo`3oool09P3oool3003o03D0l?o`
0P00o`1o0?ooo`030000003oool0oooo03d0oooo00<00?l00?3ol03`oo00
:03`oo000`00o`00oooo0?ooo`1W0?ooo`00I`3oool00`000000oooo0?oo
o`0X0?ooo`030?3ol000o`000?l00380l?o`00<00?l00?3ol03oool0O`3o
ool00`000000oooo0?ooo`0m0?ooo`03003o003`oo00l?o`02H0l?o`0P00
o`1Z0?ooo`00I`3oool00`000000oooo0?ooo`0[0?ooo`<00?l0;@3`oo02
003o0880oooo00<000000?ooo`3oool0?P3oool00`00o`00l?o`0?3ol00S
0?3ol0800?l0K03oool006L0oooo00<000000?ooo`3oool0;P3oool2003o
02T0l?o`0P00o`240?ooo`030000003oool0oooo03l0oooo0P00o`0R0?3o
l003003o003oool0oooo06`0oooo001W0?ooo`030000003oool0oooo0300
oooo0`00o`0T0?3ol0800?l0QP3oool00`000000oooo0?ooo`110?ooo`03
003o003`oo00l?o`01d0l?o`0P00o`1_0?ooo`00I`3oool00`000000oooo
0?ooo`0c0?ooo`800?l08@3`oo000`00o`00oooo0?ooo`260?ooo`030000
003oool0oooo0480oooo00<00?l00?3ol03`oo006P3`oo02003o0740oooo
001W0?ooo`030000003oool0oooo03D0oooo0`00o`0L0?3ol0800?l0R@3o
ool00`000000oooo0?ooo`130?ooo`800?l0603`oo02003o07<0oooo001W
0?ooo`030000003oool0oooo03P0oooo0`00o`0F0?3ol0<00?l0R`3oool0
0`000000oooo0?ooo`150?ooo`800?l0503`oo02003o07D0oooo001W0?oo
o`030000003oool0oooo03/0oooo1000o`0=0?3ol0D00?l0SP3oool00`00
0000oooo0?ooo`170?ooo`@00?l0303`oo04003o07L0oooo001W0?ooo`03
0000003oool0oooo03l0oooo3@00o`2C0?ooo`030000003oool0oooo04/0
oooo3000o`1k0?ooo`00I`3oool00`000000oooo0?ooo`3O0?ooo`030000
003oool0oooo0=80oooo001W0?ooo`030000003oool0oooo0=l0oooo00<0
00000?ooo`3oool0dP3oool006L0oooo00<000000?ooo`3oool0g`3oool0
0`000000oooo0?ooo`3B0?ooo`00I`3oool00`000000oooo0?ooo`3O0?oo
o`030000003oool0oooo0=80oooo001W0?ooo`030000003oool0oooo0=l0
oooo00<000000?ooo`3oool0dP3oool00?l0ooooo`3ooolP0?ooo`00o`3o
oooo0?ooob00oooo003o0?ooool0oooo803oool00?l0ooooo`3ooolP0?oo
o`00o`3ooooo0?ooob00oooo003o0?ooool0oooo803oool00?l0ooooo`3o
oolP0?ooo`00I@3oool200000?l0oooo^03oool006H0oooo00<000000?oo
o`3oool0o`3ooonf0?ooo`00I`3oool00`000000oooo0?ooo`3N0?ooo`80
0000e03oool006H0oooo00<000000?ooo`000000g`3oool200000=@0oooo
001U0?ooo`040000003oool0oooo00000=h0oooo00@000000?ooo`3oool0
0000d`3oool006@0oooo0`0000000`3oool000000000003L0?ooo`800000
0P3oool200000=80oooo003o0?ooool0oooo803oool00?l0ooooo`3ooolP
0?ooo`00o`3ooooo0?ooob00oooo003o0?ooool0oooo803oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{542, 227},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\tFigure 2.1",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The mapping  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = u \((x, y)\) + \[ImaginaryI]\ v \((x, y)\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThere are two methods for defining a ",
  StyleBox["complex function",
    FontColor->RGBColor[0, 0, 1]],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Before we start, make ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["y",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " real variables."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[u, v, x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, X, Y, U, V, Z];\)\ \), "\n", 
    \(\(TagSet[x, Im[x], 0];\)\ \), "\n", 
    \(\(TagSet[y, Im[y], 0];\)\ \), "\n", 
    \(\(TagSet[u, Im[u[x, y]], 0];\)\ \), "\n", 
    \(\(TagSet[v, Im[v[x, y]], 0];\)\ \), "\n", 
    \(\(TagSet[x, Re[x], x];\)\ \), "\n", 
    \(\(TagSet[y, Re[y], y];\)\ \), "\n", 
    \(\(TagSet[u, Re[u[x, y]], u[x, y]];\)\ \), "\n", 
    \(\(TagSet[v, Re[v[x, y]], v[x, y]];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Make  ",
  StyleBox["f[x,y]",
    FontFamily->"Courier New"],
  "  a function of two real variables ",
  StyleBox["(x,y)",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[x_, y_] := u[x, y] + \[ImaginaryI]\ v[x, y];\)\ \), "\n", 
    \(\(Print["\<f[x,y] = \>", f[x, y]];\)\ \), "\n", 
    \(\(Print["\<f[2,1] = \>", f[2, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Re[f[x,y]] = \>", ComplexExpand[Re[f[x, y]]]];\)\ \), "\n", 
    \(\(Print["\<Im[f[x,y]] = \>", 
        ComplexExpand[Im[f[x, y]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Re[f[2,1]] = \>", ComplexExpand[Re[f[2, 1]]]];\)\ \), "\n", 
    \(\(Print["\<Im[f[2,1]] = \>", 
        ComplexExpand[Im[f[2, 1]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Make  ",
  StyleBox["F[z]",
    FontFamily->"Courier New"],
  "  a function of  ",
  Cell[BoxData[
      \(z = x\  + \ \[ImaginaryI]\ y\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(F[Z_] := 
        Module[{x = Re[Z], y = Im[Z]}, \[IndentingNewLine]Return[
            u[x, y]\  + \ \[ImaginaryI]\ v[x, y]]\ ];\)\ \), "\n", 
    \(\(Print["\<F[x + \[ImaginaryI] y] = \>", 
        F[x + \[ImaginaryI]\ y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<F[x + \[ImaginaryI] y] = \>", \[IndentingNewLine]MapAll[
          ComplexExpand, 
          F[x + \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  F[2 + \[ImaginaryI]] = \>", 
        F[2 + \[ImaginaryI]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Re[F[2 + \[ImaginaryI]]] = \>", 
        ComplexExpand[
          Re[F[2 + \[ImaginaryI]]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Im[F[2 + \[ImaginaryI]]] = \>", 
        ComplexExpand[
          Im[F[2 + \[ImaginaryI]]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  It was necessary to use the power of  ",
  StyleBox["MapAll",
    FontFamily->"Courier New"],
  "  to find the real and imaginary parts of  ",
  Cell[BoxData[
      \(F[x\  + \ \[ImaginaryI]\ y]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<F[x + \[ImaginaryI] y] = \>", 
        F[x + \[ImaginaryI]\ y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Re[F[x + \[ImaginaryI] y]] = \>", 
        Re[F[x + \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Re[F[x + \[ImaginaryI] y]] = \>", 
        MapAll[ComplexExpand, \ 
          Re[F[x + \[ImaginaryI]\ y]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Im[F[x + \[ImaginaryI] y]] = \>", 
        Im[F[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(Print["\<Im[F[x + \[ImaginaryI] y]] = \>", 
        MapAll[ComplexExpand, \ 
          Im[F[x + \[ImaginaryI]\ y]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell["\<\
We now give several examples that illustrate how to express a complex \
function.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 2.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Write  ",
  Cell[BoxData[
      \(f \((z)\) = z\^4\)]],
  "  in the for  ",
  Cell[BoxData[
      \(f \((z)\) = u \((x, y)\) + \[ImaginaryI]\ v \((x, y)\)\)]],
  ". \n\nSolution.  Using the binomial formula, we obtain \n\n\t\t\t",
  Cell[BoxData[{
      \(f \((z)\)\  = \ \ \(f \((x + \[ImaginaryI]\ y)\)\  = \ \((x + \
\[ImaginaryI]\ y)\)\^4\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(x\^4 + 
          4\ \ x\^3\ \((\[ImaginaryI]\ y)\) + 
          6\ x\^2\ \((\[ImaginaryI]\ y)\)\^2 + 
          4\ \ x\ \((\[ImaginaryI]\ y)\)\^3 + \((\[ImaginaryI]\ y)\)\^4\)\)\
\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(x\^4 + 
          4\ \[ImaginaryI]\ x\^3\ y - 6\ x\^2\ y\^2 - 
          4\ \[ImaginaryI]\ x\ y\^3 + y\^4\)\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(x\^4 - 6\ x\^2\ y\^2 + 
          y\^4\  + \ \[ImaginaryI]\ \((4\ x\^3\ y - 
                4\ x\ y\^3)\)\)\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(u \((x, 
              y)\)\  + \ \[ImaginaryI]\ v \((x, y)\)\)\)\)}]],
  "\n\nso that  ",
  Cell[BoxData[
      RowBox[{\(u \((x, y)\)\), "=", 
        RowBox[{
          RowBox[{\(x\^4\), "-", \(6\ x\^2\ y\^2\), "+", 
            RowBox[{\(y\^4\), "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "v", \((x, y)\)}]}], 
          "=", \(4\ x\^3\ y - 4\ x\ y\^3\)}]}]]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Use Method 1 to construct  f[x,y].  ", "Text"],

Cell[BoxData[{
    \(\(Clear[x, y, z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F];\)\ \), "\[IndentingNewLine]", 
    \(\(TagSet[x, Im[x], 0];\)\ \), "\n", 
    \(\(TagSet[y, Im[y], 0];\)\ \), "\n", 
    \(\(TagSet[x, Re[x], x];\)\ \), "\n", 
    \(\(TagSet[y, Re[y], y];\)\ \), "\n", 
    \(\(f[x_, y_] = \((x + \[ImaginaryI]\ y)\)\^4;\)\ \), "\n", 
    \(\(Print["\<f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(f[x_, y_] = 
        ComplexExpand[\((x + \[ImaginaryI]\ y)\)\^4];\)\ \), "\n", 
    \(\(Print["\<f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Check out a few points.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[0,1] = \>", f[0, 1]];\)\ \), "\n", 
    \(\(Print["\<f[1,1] = \>", f[1, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[1,\!\(1\/2\)] = \>\"", 
        f[1, 1\/2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Use Method 2 to construct  F[z].  ", "Text"],

Cell[BoxData[{
    \(\(F[z_] := 
        Module[{x = Re[z], y = Im[z], Z}, \[IndentingNewLine]Z = 
            x + \[ImaginaryI]\ y; \ \[IndentingNewLine]Return[
            ComplexExpand[Z\^4]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = x\  + \ \[ImaginaryI]\ y;\)\ \), "\n", 
    \(\(Print["\<F[\>", Z, "\<] = \>", z\^4];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\>", Z, "\<] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Check out a few points.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = 9\/10;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\>", Z, "\<] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = \[ImaginaryI];\)\ \), "\n", 
    \(\(Print["\<F[\>", Z, "\<] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = 1\  + \ \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\>", Z, "\<] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = 1\  + \ \[ImaginaryI]\/2;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\>", Z, "\<] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = 1\/2\  + \ \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\>", Z, "\<] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = 1\/2\  + \ \[ImaginaryI]\/2;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\>", Z, "\<] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " plot the image of a region under the mapping w = f[z]."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[d, f, g, Iden, z];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^4;\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {0, 1, 0.1}, {0, 1, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.1\), 
              1}, {\(-0.1\), 1}}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[0, 1, 1\/2], Range[0, 1, 1\/2]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Magenta, Pink}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A unit square in the z-plane.\>"];\)\ \), "\n", 
    \(\(CartesianMap[
        f, \ {0, 1, 0.1}, {0, 1, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-4\), 1}, {\(-2\), 
              2}}, \[IndentingNewLine]AspectRatio \[Rule] 4\/5, 
        Ticks \[Rule] {Range[\(-4\), 0, 1], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Magenta, Pink}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image region,\>"];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(d[z_] = z + \(1 + \[ImaginaryI]\)\/2;\)\ \), "\n", 
    \(\(g[z_] = f[z + \(1 + \[ImaginaryI]\)\/2];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(PolarMap[
        d\ , \ {0, 1\/2, 1\/20}, {0, 
          2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
              1}, {0, 1}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 1, 1\/2], 
            Range[0, 1, 1\/2]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {DarkGreen, Green}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The disk |z-\!\(\(1 + \[ImaginaryI]\)\/2\)| < \!\(1\/2\) \
in the z-plane.\>\""];\)\ \), "\n", 
    \(\(PolarMap[
        g\ , {\ 0, 1\/2, 1\/20}, {0, 
          2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{\(-2.2\
\), 1.0}, {\(-1.6\), 1.6}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-2\), 1, 1], 
            Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {DarkGreen, Green}];\)\ \), "\n", 
    \(\(Print["\<The image region in the w = u + \[ImaginaryI]v plane\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Express the function  ",
  Cell[BoxData[
      \(f \((z)\) = \(\(z\)\(\ \)\)\&_\ Re[z] + z\^2 + Im[z]\)]],
  "  in the form  ",
  Cell[BoxData[
      \(f \((z)\) = u \((x, y)\) + \[ImaginaryI]\ v \((x, y)\)\)]],
  ".\n\nSolution.  Using the elementary properties of complex numbers, it \
follows that  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(\((x - \[ImaginaryI]\ y)\) 
              x + \((x + \[ImaginaryI]\ y)\)\^2 + 
            y\ \  = \ \((2\ x\^2 - y\^2 + 
                y)\) + \[ImaginaryI]\ \((x\ y)\)\)\)]],
  "\n\nso that  ",
  Cell[BoxData[
      RowBox[{\(u \((x, y)\)\), "=", 
        RowBox[{
          RowBox[{\(2\ x\^2\), "-", \(y\^2\), "+", 
            RowBox[{"y", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "v", \((x, y)\)}]}], 
          "=", \(x\ y\)}]}]]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Use Method 1 to construct  f[x,y].  ", "Text"],

Cell[BoxData[{
    \(\(Clear[x, y, z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F];\)\ \), "\[IndentingNewLine]", 
    \(\(TagSet[x, Im[x], 0];\)\ \), "\n", 
    \(\(TagSet[y, Im[y], 0];\)\ \), "\n", 
    \(\(TagSet[x, Re[x], x];\)\ \), "\n", 
    \(\(TagSet[y, Re[y], y];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = x + \[ImaginaryI]\ y;\)\ \), "\n", 
    \(\(f[x_, y_] = \[IndentingNewLine]ComplexExpand[
          Conjugate[Z] Re[Z] + Z\^2 + Im[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x,y] = \>", 
        Conjugate[Z] Re[Z] + Z\^2 + Im[Z]];\)\ \), "\n", 
    \(\(Print["\<f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Check out a few points.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[1,0] = \>", f[1, 0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[0,1] = \>", f[0, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[1,1] = \>", f[1, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(1\/2\),1] = \>\"", 
        f[1\/2, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[1,\!\(1\/2\)] = \>\"", 
        f[1, 1\/2]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[3,2] = \>", f[3, 2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Use Method 2 to construct  F[z].  ", "Text"],

Cell[BoxData[{
    \(\(F[Z_] := 
        Module[{x = Re[Z], y = Im[Z], z}, \[IndentingNewLine]z = 
            x + \[ImaginaryI]\ y; \ \[IndentingNewLine]Return[
            ComplexExpand[Conjugate[z] Re[z] + z\^2 + Im[z]]]];\)\ \), "\n", 
    \(\(Z = x\  + \ \[ImaginaryI]\ y;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x,y] = \>", 
        Conjugate[Z] Re[Z] + Z\^2 + Im[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\>", Z, "\<] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Check out a few points.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\>", Z, "\<] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\>", Z, "\<] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = 1\  + \ \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\>", Z, "\<] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = 1\/2 + \ \ \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\>", Z, "\<] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = 1 + \ 1\/2\ \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\>", Z, "\<] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = 3\  + \ 2\ \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\>", Z, "\<] = \>", F[Z]];\)\ \), "\n", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " plot the image of a region under the mapping w = f[z]."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Iden[z_] = z;\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = 
        Conjugate[z] Re[z] + z\^2 + Im[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {0, 1, 0.1}, {0, 1, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.1\), 
              1}, {\(-0.1\), 1}}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[0, 1, 1\/2], Range[0, 1, 1\/2]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<A unit square in the z-plane.\>"];\)\ \), "\n", 
    \(\(CartesianMap[
        f, {0, 1, 0.1}, {0, 1, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{0, 2.3}, {0, 
              1.15}}, \[IndentingNewLine]AspectRatio \[Rule] 1\/2, 
        Ticks \[Rule] {Range[0, 2, 1\/2], Range[0, 1, 1\/2]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image region in the w = u + \[ImaginaryI]v plane\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<                   w = \>", 
        MapAll[ComplexExpand, 
          f[x + \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tExamples 2.1 and 2.2 show how to find ",
  StyleBox["u(x,y)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v(x,y)",
    FontFamily->"Courier New"],
  " when a rule for computing f is given. Conversely, if ",
  StyleBox["u(x,y)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v(x,y)",
    FontFamily->"Courier New"],
  " are two real-valued functions of the real \nvariables ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["y",
    FontFamily->"Courier New"],
  ", they determine a complex-valued function    ",
  Cell[BoxData[
      \(f \((z)\) = u \((x, y)\) + \[ImaginaryI]\ v \((x, y)\)\)]],
  ",  and we can use the formulas\n\n\t\t\t",
  Cell[BoxData[
      \(x = \(z\  + \ \(\(z\)\(\ \)\)\&_\)\/2\)]],
  "  and  ",
  Cell[BoxData[
      \(y = \(z\  - \ \(\(z\)\(\ \)\)\&_\)\/\(2  \[ImaginaryI]\)\)]],
  " \n\nto find a formula for f involving the variables z and ",
  Cell[BoxData[
      \(\(\(z\)\(\ \)\)\&_\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 2.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Express  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ 4  x\^2\  + \ \[ImaginaryI]\ 4  y\^2\)],
    AspectRatioFixed->True],
  "  by a formula involving the variables  ",
  Cell[BoxData[
      \(z\ \ and\ \ \(\(z\)\(\ \)\)\&_\)]],
  ".  \n\nSolution.  Calculation reveals that \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\  = \ 
        4 \((\(z\  + \ \(\(z\)\(\ \)\)\&_\)\/2)\)\^2 + \[ImaginaryI]\ 4 \
\((\(z\  - \ \(\(z\)\(\ \)\)\&_\)\/\(2  \[ImaginaryI]\))\)\^2\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(z\^2 + 
          2\ z\ \(\(z\)\(\ \)\)\&_ + \(\(\(\(z\)\(\ \)\)\&_\)\(\ \)\)\^2 - \
\[ImaginaryI]\ \((z\^2 - 
                2\ z\ \(\(z\)\(\ \)\)\&_ + \(\(\(\(z\)\(\ \)\)\&_\)\(\ \
\)\)\^2)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(\((1 - \[ImaginaryI])\) 
            z\^2 + \((2 + 
                2  \[ImaginaryI])\)\ z\ \(\(z\)\(\ \)\)\&_ + \((1 - \
\[ImaginaryI])\) \(\(\(\(z\)\(\ \)\)\&_\)\(\ \)\)\^2\)\)\)}]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the function.", "Text"],

Cell[BoxData[{
    \(\(Clear[w, x, y, z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f];\)\ \), "\[IndentingNewLine]", 
    \(\(TagSet[x, Im[x], 0];\)\ \), "\n", 
    \(\(TagSet[y, Im[y], 0];\)\ \), "\n", 
    \(\(TagSet[x, Re[x], x];\)\ \), "\n", 
    \(\(TagSet[y, Re[y], y];\)\ \), "\[IndentingNewLine]", 
    \(\(w\  = \ 4  x\^2\  + \ \[ImaginaryI]\ 4  y\^2;\)\ \), "\n", 
    \(\(f[x_, y_]\  = \ 
        ReplaceAll[
          w\ , \[IndentingNewLine]{x \[Rule] \(z\  + \ Conjugate[z]\)\/2, 
            y \[Rule] \(z\  - \ Conjugate[z]\)\/\(2  \[ImaginaryI]\)}];\)\ \
\), "\n", 
    \(\(Print["\<    f[z] = \>", w];\)\ \), "\n", 
    \(\(Print["\<    f[z] = \>", f[x, y]];\)\ \), "\n", 
    \(\(Print["\<    f[z] = \>", 
        Expand[f[x, y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Clear[Z];\)\), "\n", 
    \(\(u[x, y] = ComplexExpand[Re[w]];\)\ \), "\[IndentingNewLine]", 
    \(\(v[x, y] = ComplexExpand[Im[w]];\)\ \), "\[IndentingNewLine]", 
    \(\(F[Z_] := 
        Module[{x = Re[Z], y = Im[Z]}, \[IndentingNewLine]Return[
            u[x, y]\  + \ \[ImaginaryI]\ v[x, 
                  y]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\>", Z, "\<] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\>", x + \[ImaginaryI]\ y, "\<] = \>", 
        F[x + \[ImaginaryI]\ y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " plot the image of a region under the mapping w = f[z]."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Iden[z_] = z;\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = 
        4  Re[z]\^2 + \[ImaginaryI]\ 4 
             Im[z]\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {0, 1, 0.1}, {0, 1, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.1\), 
              1}, {\(-0.1\), 1}}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[0, 1, 1\/2], Range[0, 1, 1\/2]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<A unit square in the z-plane.\>"];\)\ \), "\n", 
    \(\(CartesianMap[
        f, {0, 1, 0.1}, {0, 1, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{0, 4.2}, {0, 
              4.2}}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[0, 4, 1\/2], Range[0, 4, 1\/2]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image region in the w = u + \[ImaginaryI]v plane\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<                   w = \>", 
        MapAll[ComplexExpand, 
          f[x + \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tUsing  ",
  Cell[BoxData[
      \(z\  = \ r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)]],
  "  in the expression of a complex function f may be convenient.  It gives \
us the polar representation  \n\n\t\t\t\t",
  Cell[BoxData[
      \(f \((z\ )\) = \ \(f \((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\))\)\  = \ 
          U \((r, \[Theta])\)\  + \ \[ImaginaryI]\ V \((r, \[Theta])\)\)\)]],
  ", \n\nwhere ",
  StyleBox["U",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["V",
    FontFamily->"Courier New"],
  " are real functions of the real variables ",
  StyleBox["r",
    FontFamily->"Courier New"],
  " and ",
  Cell[BoxData[
      \(\[Theta]\)]],
  ".\n\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  For a given function ",
  StyleBox["f",
    FontFamily->"Courier New"],
  ", the functions u and v defined above are different from those used \
previously in  ",
  Cell[BoxData[
      \(f \((z)\) = \(f \((x + \[ImaginaryI]\ y)\) = 
          u \((x, y)\) + \[ImaginaryI]\ v \((x, y)\)\)\)]],
  "  which used Cartesian coordinates instead of polar coordinates."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 2.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Express  ",
  Cell[BoxData[
      \(f \((z)\) = z\^2\)],
    AspectRatioFixed->True],
  "  in both Cartesian and polar form. \n\nSolution.  For the Cartesian form, \
a simple calculation gives \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\  = \ \ \(f \((x + \[ImaginaryI]\ y)\)\  = \ \((x + \
\[ImaginaryI]\ y)\)\^2\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(x\^2 - y\^2\  + \ 
          2\ \[ImaginaryI]\ x\ y\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(u \((x, 
              y)\)\  + \ \[ImaginaryI]\ v \((x, y)\)\)\)\)}]],
  " \n\nso that  ",
  Cell[BoxData[
      RowBox[{\(u \((x, y)\)\), "=", 
        RowBox[{
          RowBox[{\(x\^2\), "-", 
            RowBox[{\(y\^2\), "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "v", \((x, y)\)}]}], 
          "=", \(2  x\ y\)}]}]]],
  ". \n\nFor the polar form, we get v \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\  = \ \(f \((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\))\)\  = \ \(\((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\))\)\^2\  = \(r\^2\) \[ExponentialE]\^\(\[ImaginaryI]\ 2  \[Theta]\)\
\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(\(r\^2\) \((cos\ 2  \[Theta] + \
\[ImaginaryI]\ sin\ 2  \[Theta])\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(\(r\^2\) 
            cos\ 2  \[Theta]\  + \ \[ImaginaryI]\ \(r\^2\) 
            sin\ 2  \[Theta]\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(U \((r, \[Theta])\)\  + \ \
\[ImaginaryI]\ V \((r, \[Theta])\)\)\)\)}]],
  "\n\nso that  ",
  Cell[BoxData[
      \(U \((r, \[Theta])\) = \(\(r\^2\) 
            cos\ 2  \[Theta]\ \ and\ \ V \((r, \[Theta])\) = \(r\^2\) 
            sin\ 2  \[Theta]\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the function.", "Text"],

Cell[BoxData[{
    \(\(Clear[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, r, \[Theta]];\)\ \), "\n", 
    \(\(f[z_] = z\^2;\)\ \), "\n", 
    \(\(F[r_, \[Theta]_]\  = \ 
        ReplaceAll[
          f[z]\ , \[IndentingNewLine]{z\^2 \[Rule] 
              r\^2\ Cos[2  \[Theta]] + \[ImaginaryI]\ r\^2\ Sin[
                    2  \[Theta]], \[IndentingNewLine]z\^5 \[Rule] 
              r\^5\ Cos[5  \[Theta]] + \[ImaginaryI]\ r\^5\ Sin[
                    5  \[Theta]]}];\)\ \), "\n", 
    \(\(Print["\<      f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[1+\[ImaginaryI] \!\(\@3\)] = \>\"", 
        f[1 + \[ImaginaryI]\ \@3]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<      f[z] = \>", 
        ComplexExpand[Re[f[x + \[ImaginaryI]\ y]]], "\< + \[ImaginaryI](\>", 
        ComplexExpand[
          Im[f[x + \[ImaginaryI]\ y]]], "\<)\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[1+\[ImaginaryI] \!\(\@3\)] = \>\"", 
        ComplexExpand[
          f[1 + \[ImaginaryI]\ \@3]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  f[r \!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)] = \>\
\"", f[r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< f[2 \!\(\[ExponentialE]\^\(\[ImaginaryI]\[Pi]/3\)\)] = \
\>\"", f[2\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/3\)]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< f[2 \!\(\[ExponentialE]\^\(\[ImaginaryI]\[Pi]/3\)\)] = \
\>\"", ComplexExpand[
          f[2\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/3\)]]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<  F[r,\[Theta]] = \>", 
        F[r, \[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< F[2,\!\(\[Pi]\/3\)] = \>\"", 
        ComplexExpand[F[2, \[Pi]\/3]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Once we have defined ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " for a function ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " in Cartesian form, we must use different symbols if we want to express ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " in polar form. As is clear here, the functions ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["U",
    FontFamily->"Courier New"],
  " are quite different, as are ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["V",
    FontFamily->"Courier New"],
  ".  Of course, if we are working only in one context, we can use any \
symbols we choose.\n\nFor a given function f, the functions u and v defined \
here are different from those defined by equation (2-1), because equation \
(2-1) involves Cartesian coordinates and equation (2-2) involves polar \
coordinates."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 2.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Express  ",
  Cell[BoxData[
      \(f \((z)\) = z\^5 + 4\ z\^2 - 6\)],
    AspectRatioFixed->True],
  "  in polar form. \n\nSolution. We obtain\n\n\t\t\t",
  Cell[BoxData[{
      \(f \((z)\)\  = \ \(f \((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\))\)\  = \ \((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\))\)\^5 \
+ 4 \((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\))\)\^2 - 
            6\)\ \[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(\(r\^5\) \[ExponentialE]\^\(\
\[ImaginaryI]\ 5  \[Theta]\)\  + \ 
          4 \( r\^2\) \[ExponentialE]\^\(\[ImaginaryI]\ 2  \[Theta]\)\  - \ 
          6\)\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(r\^5\ cos\ 5\ \[Theta] + 
          4\ r\^2\ cos\ 2\ \[Theta] - 
          6 + \[ImaginaryI]\ \((\(r\^5\) sin\ 5\ \[Theta] + 
                4\ r\^2\ sin\ 2\ \[Theta])\)\)\)\n\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(U \((r, \[Theta])\)\  + \ \
\[ImaginaryI]\ V \((r, \[Theta])\)\)\)\)}]],
  "  \n\nso that  ",
  Cell[BoxData[
      \(U \((r, \[Theta])\) = \(r\^5\ cos\ 5\ \[Theta] + 
            4\ r\^2\ cos\ 2\ \[Theta] - 
            6\ \ and\ \ V \((r, \[Theta])\) = \(r\^5\) sin\ 5\ \[Theta] + 
            4\ r\^2\ sin\ 2\ \[Theta]\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the function.", "Text"],

Cell[BoxData[{
    \(\(Clear[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, r, \[Theta]];\)\ \), "\n", 
    \(\(f[z_] = z\^5 + 4\ z\^2 - 6;\)\ \), "\n", 
    \(\(F[r_, \[Theta]_]\  = \ 
        ReplaceAll[
          f[z]\ , \[IndentingNewLine]{z\^2 \[Rule] 
              r\^2\ Cos[2  \[Theta]] + \[ImaginaryI]\ r\^2\ Sin[
                    2  \[Theta]], \[IndentingNewLine]z\^5 \[Rule] 
              r\^5\ Cos[5  \[Theta]] + \[ImaginaryI]\ r\^5\ Sin[
                    5  \[Theta]]}];\)\ \), "\n", 
    \(\(Print["\<      f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[1+\[ImaginaryI] \!\(\@3\)] = \>\"", 
        f[1 + \[ImaginaryI]\ \@3]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[1+\[ImaginaryI] \!\(\@3\)] = \>\"", 
        ComplexExpand[
          f[1 + \[ImaginaryI]\ \@3]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  f[r \!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)] = \>\
\"", f[r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< f[2 \!\(\[ExponentialE]\^\(\[ImaginaryI]\[Pi]/3\)\)] = \
\>\"", f[2\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/3\)]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< f[2 \!\(\[ExponentialE]\^\(\[ImaginaryI]\[Pi]/3\)\)] = \
\>\"", ComplexExpand[
          f[2\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/3\)]]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<  F[r,\[Theta]] = \>", 
        F[r, \[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< F[2,\!\(\[Pi]\/3\)] = \>\"", 
        ComplexExpand[F[2, \[Pi]\/3]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " plot the image of a region under the mapping w = f[z]."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, Iden, z];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^5 + 4\ z\^2 - 6;\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {0, 1, 0.1}, {0, 1, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.1\), 
              1}, {\(-0.1\), 1}}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[0, 1, 1\/2], Range[0, 1, 1\/2]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Magenta, Pink}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<A unit square in the z-plane.\>"];\)\ \), "\n", 
    \(\(CartesianMap[
        f, \ {0, 1, 0.1}, {0, 1, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-10\), 0}, {0, 
              6}}, \[IndentingNewLine]AspectRatio \[Rule] 6\/10, 
        Ticks \[Rule] {Range[\(-10\), 0, 1], Range[0, 6, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Magenta, Pink}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image region in the w = u + \[ImaginaryI]v plane\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Iden\ , \ {0, 1, 
          1\/20}, {0, \[Pi]\/2, \[Pi]\/24}, \[IndentingNewLine]PlotRange \
\[Rule] {{0, 1}, {0, 1}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 1, 1\/2], 
            Range[0, 1, 1\/2]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {DarkGreen, Green}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<A quarter disk in the z-plane.\>"];\)\ \), "\n", 
    \(\(PolarMap[
        f\ , {0, 1, 
          1\/20}, {0, \[Pi]\/2, \[Pi]\/24}, \[IndentingNewLine]PlotRange \
\[Rule] {{\(-10\), 0}, {0, 4}}, 
        AspectRatio \[Rule] 
          4\/10, \[IndentingNewLine]Ticks \[Rule] {Range[\(-10\), 0, 1], 
            Range[0, 4, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {DarkGreen, Green}];\)\ \), "\n", 
    \(\(Print["\<The image region in the w = u + \[ImaginaryI]v plane\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tWe now look at the geometric interpretation of a complex function.  If \
",
  StyleBox["D",
    FontFamily->"Courier New"],
  " is the domain of real-valued functions ",
  StyleBox["u(x,y)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v(x,y)",
    FontFamily->"Courier New"],
  ", the equations  \n\n\t\t\t",
  Cell[BoxData[
      \(u = u \((x, y)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(v = v \((x, y)\)\)]],
  " \n\ndescribe a transformation (or mapping) from ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " in the xy plane into the ",
  StyleBox["uv",
    FontFamily->"Courier New"],
  " plane, also called the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane. Therefore, we can also consider the function  \n\n\t\t\t",
  Cell[BoxData[
      \(w = \(f \((z)\) = u \((x, y)\) + \[ImaginaryI]\ v \((x, y)\)\)\)]],
  "  \n\nto be a transformation (or mapping) from the set ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " in the z plane onto the range ",
  StyleBox["R",
    FontFamily->"Courier New"],
  " in the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane.  This idea was illustrated in Figure 2.1. In the following \
paragraphs we present some additional key ideas. They are staples for any \
kind of function, and you should memorize all the terms in bold.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tIf ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " is a subset of the domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " of ",
  StyleBox["f",
    FontFamily->"Courier New"],
  ", the set  ",
  Cell[BoxData[
      \(B = {w = f \((z)\) : z \[Element] A}\)]],
  "  is called the image of the set ",
  StyleBox["A",
    FontFamily->"Courier New"],
  ", and ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is said to map ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " onto ",
  StyleBox["B",
    FontFamily->"Courier New"],
  ".  The image of a single point is a single point, and the image of the \
entire domain, ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", is the range, ",
  StyleBox["R",
    FontFamily->"Courier New"],
  ".  The mapping  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  is said to be from ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " into ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " if the image of ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " is contained in ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ".  Mathematicians use the notation  ",
  Cell[BoxData[
      \(f : A \[Rule] S\)]],
  " to indicate that a function maps ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " into ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ".  Figure 2.2 illustrates a function f whose domain is ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " and whose range is ",
  StyleBox["R",
    FontFamily->"Courier New"],
  ".  The shaded areas depict that the function maps ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " onto ",
  StyleBox["B",
    FontFamily->"Courier New"],
  ".  The function also maps ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " into ",
  StyleBox["R",
    FontFamily->"Courier New"],
  ", and, of course, it maps ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " onto ",
  StyleBox["R",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008i00019B000`400?l0
0000o`00003oo`3ooooo0?oooc/0oooo003o0?ooool0oooo>`3oool00?l0
ooooo`3ooolk0?ooo`00o`3ooooo0?oooc/0oooo003o0?ooool0oooo>`3o
ool00?l0ooooo`3ooolk0?ooo`00o`3ooooo0?oooc/0oooo002:0?ooo`03
0000003oool0oooo0?l0oooo[@3oool008X0oooo00<000000?ooo`3oool0
o`3ooon]0?ooo`00RP3oool00`000000oooo0?ooo`3P0?ooo`030000003o
ool0oooo0<T0oooo002:0?ooo`030000003oool0oooo0>00oooo00<00000
0?ooo`3oool0_`3oool4000000H0oooo002:0?ooo`030000003oool0oooo
0>00oooo00<000000?ooo`3oool0_P3oool010000000oooo0?ooo`000007
0?ooo`00RP3oool00`000000oooo0?ooo`3=0?ooold000001`3oool01000
0000oooo0?ooo`0000070?ooo`00RP3oool00`000000oooo0?ooo`0G0?oo
o`T00?l0`03oool00`000000oooo0?ooo`2m0?ooo`80000000<0oooo0000
000000001`3oool008X0oooo00<000000?ooo`3oool0503oool3003o00T0
l?o`0P00o`2n0?ooo`030000003oool0oooo0<T0oooo002:0?ooo`030000
003oool0oooo0180oooo0P00o`0>0?3ol0800?l0_03oool00`000000oooo
0?ooo`1]0?ooo`L00?l0E@3oool008X0oooo00<000000?ooo`3oool03`3o
ool3003o0180l?o`00<00?l00?ooo`3oool0^@3oool00`000000oooo0?oo
o`1X0?ooo`D00?l01`3`oo05003o0500oooo002:0?ooo`030000003oool0
oooo00`0oooo0`00o`0F0?3ol0800?l0^@3oool00`000000oooo0?ooo`1T
0?ooo`@00?l04@3`oo02003o04h0oooo002:0?ooo`030000003oool0oooo
00T0oooo0`00o`0K0?3ol0800?l0]`3oool00`000000oooo0?ooo`1Q0?oo
o`<00?l05`3`oo03003o04/0oooo002:0?ooo`030000003oool0oooo00L0
oooo0P00o`0O0?3ol003003o003oool0oooo0;D0oooo00<000000?ooo`3o
ool0GP3oool3003o01d0l?o`0P00o`190?ooo`00RP3oool00`000000oooo
0?ooo`050?ooo`800?l08P3`oo000`00o`00oooo0?ooo`2d0?ooo`030000
003oool0oooo05`0oooo0P00o`0R0?3ol0800?l0A`3oool008X0oooo00<0
00000?ooo`3oool0103oool00`00o`00l?o`0?3ol00S0?3ol0800?l0]03o
ool00`000000oooo0?ooo`1J0?ooo`800?l09P3`oo02003o04D0oooo002:
0?ooo`030000003oool0oooo0080oooo0P00o`0W0?3ol0030?ooo`00o`00
oooo0;80oooo00@000000?ooo`3oool0oooo2`00o`1<0?ooo`800?l0:P3`
oo02003o04<0oooo002:0?ooo`030000003oool0oooo00800?l0:P3`oo00
0`00o`00oooo0?ooo`2a0?ooo`040000003oool00?l0003o00/0l?o`0`00
o`180?ooo`03003o003`oo00l?o`02`0l?o`0P00o`110?ooo`00RP3oool0
0`000000oooo003o000]0?3ol003003o003oool0oooo0;00oooo0P00o`0@
0?3ol0800?l0A03oool2003o0340l?o`0P00o`0o0?ooo`00RP3oool2003o
02l0l?o`00<00?l00?ooo`3oool0[@3oool2003o01@0l?o`0`00o`100?oo
o`03003o003`oo00l?o`03<0l?o`00<00?l00?ooo`3oool0?03oool008P0
oooo0P00o`0a0?3ol003003o003oool0oooo0:`0oooo00<00?l00?3ol03`
oo005`3`oo02003o03`0oooo0P00o`0g0?3ol0800?l0?03oool008H0oooo
0P00o`0d0?3ol003003o003oool0oooo0:X0oooo00<00?l00?3ol03`oo00
6P3`oo02003o03T0oooo00<00?l00?3ol03`oo00>@3`oo02003o03X0oooo
00240?ooo`800?l0=`3`oo000`00o`00oooo0?ooo`2X0?ooo`03003o003`
oo00l?o`01d0l?o`0P00o`0f0?ooo`03003o003`oo00l?o`03`0l?o`00<0
0?l00?ooo`3oool0=`3oool008<0oooo00<00?l00?3ol03`oo00=`3`oo00
0`00o`00oooo0?ooo`2X0?ooo`03003o003`oo00l?o`01l0l?o`0P00o`0b
0?ooo`800?l0@03`oo02003o03L0oooo00210?ooo`800?l0>`3`oo000`00
o`00oooo0?ooo`2V0?ooo`03003o003`oo00l?o`0280l?o`0P00o`0_0?oo
o`03003o003`oo00l?o`0480l?o`00<00?l00?ooo`3oool0=03oool007l0
oooo0P00o`0m0?3ol003003o003oool0oooo0:D0oooo00<00?l00?3ol03`
oo009@3`oo02003o02`0oooo00<00?l00?3ol03`oo00A03`oo02003o03@0
oooo001m0?ooo`800?l0@03`oo000`00o`00oooo0?ooo`2T0?ooo`03003o
003`oo00l?o`02L0l?o`0P00o`0Y0?ooo`03003o003`oo00l?o`04L0l?o`
0P00o`0b0?ooo`00N`3oool2003o0480l?o`00<00?l00?ooo`3oool0X`3o
ool00`00o`00l?o`0?3ol00Z0?3ol003003o003oool0oooo02D0oooo00<0
0?l00?3ol03`oo00BP3`oo000`00o`00oooo0?ooo`0_0?ooo`00N@3oool2
003o04D0l?o`00<00?l00?ooo`3oool0XP3oool00`00o`00l?o`0?3ol00[
0?3ol0800?l0903oool00`00o`00l?o`0?3ol01<0?3ol0800?l0;`3oool0
07P0oooo00<00?l00?3ol03`oo00A@3`oo000`00o`00oooo0?ooo`2Q0?oo
o`03003o003`oo00l?o`02h0l?o`0P00o`0Q0?ooo`03003o003`oo00l?o`
04l0l?o`0P00o`0]0?ooo`00M`3oool00`00o`00l?o`0?3ol0170?3ol003
003o003oool0oooo0:00oooo00<00?l00?3ol03`oo00<03`oo000`00o`00
oooo0?ooo`0M0?ooo`03003o003`oo00l?o`0580l?o`0P00o`0[0?ooo`00
M`3oool00`00o`00l?o`0?3ol0170?3ol003003o003oool0oooo0:00oooo
00<00?l00?3ol03`oo00<@3`oo02003o01/0oooo0P00o`1G0?3ol003003o
003oool0oooo02P0oooo001f0?ooo`03003o003`oo00l?o`04T0l?o`00<0
0?l00?ooo`3oool0WP3oool00`00o`00l?o`0?3ol00d0?3ol003003o003o
ool0oooo01L0oooo00<00?l00?3ol03`oo00F03`oo02003o02P0oooo001e
0?ooo`03003o003`oo00l?o`04X0l?o`00<00?l00?ooo`3oool0WP3oool0
0`00o`00l?o`0?3ol00e0?3ol0800?l05P3oool00`00o`00l?o`0?3ol01K
0?3ol003003o003oool0oooo02D0oooo001e0?ooo`03003o003`oo00l?o`
04/0l?o`00<00?l00?ooo`3oool0W@3oool00`00o`00l?o`0?3ol00g0?3o
l0800?l04`3oool00`00o`00l?o`0?3ol01M0?3ol0800?l09@3oool007@0
oooo00<00?l00?3ol03`oo00C03`oo000`00o`00oooo0?ooo`2M0?ooo`03
003o003`oo00l?o`03T0l?o`0P00o`0@0?ooo`03003o003`oo00l?o`0600
l?o`00<00?l00?ooo`3oool08P3oool007@0oooo00<00?l00?3ol03`oo00
C@3`oo000`00o`00oooo0?ooo`2K0?ooo`03003o003`oo00l?o`03`0l?o`
0P00o`0=0?ooo`03003o003`oo00l?o`0680l?o`00<00?l00?ooo`3oool0
8@3oool007@0oooo00<00?l00?3ol03`oo00C@3`oo000`00o`00oooo0?oo
o`2K0?ooo`03003o003`oo00l?o`03h0l?o`0P00o`090?ooo`800?l0IP3`
oo000`00o`00oooo0?ooo`0P0?ooo`00L`3oool00`00o`00l?o`0?3ol01?
0?3ol003003o003oool0oooo09X0oooo00<00?l00?3ol03`oo00@03`oo09
003o06T0l?o`0P00o`0P0?ooo`00L`3oool00`00o`00l?o`0?3ol01?0?3o
l003003o003oool0oooo09X0oooo00<00?l00?3ol03`oo00]03`oo000`00
o`00oooo0?ooo`0M0?ooo`00L`3oool00`00o`00l?o`0?3ol01@0?3ol003
003o003oool0oooo09T0oooo00<00?l00?3ol03`oo00]@3`oo000`00o`00
oooo0?ooo`0L0?ooo`00LP3oool00`00o`00l?o`0?3ol01A0?3ol003003o
003oool0oooo09P0oooo00<00?l00?3ol03`oo00]`3`oo000`00o`00oooo
0?ooo`0K0?ooo`00LP3oool00`00o`00l?o`0?3ol01B0?3ol003003o003o
ool0oooo09L0oooo00<00?l00?3ol03`oo00]`3`oo000`00o`00oooo0?oo
o`0K0?ooo`00LP3oool00`00o`00l?o`0?3ol01B0?3ol003003o003oool0
oooo09L0oooo00<00?l00?3ol03`oo00^03`oo000`00o`00oooo0?ooo`0J
0?ooo`00L@3oool00`00o`00l?o`0?3ol01D0?3ol003003o003oool0oooo
09H0oooo00<00?l00?3ol03`oo00^03`oo000`00o`00oooo0?ooo`0J0?oo
o`00L@3oool00`00o`00l?o`0?3ol01D0?3ol003003o003oool0oooo09H0
oooo00<00?l00?3ol03`oo00^@3`oo000`00o`00oooo0?ooo`0I0?ooo`00
L@3oool00`00o`00l?o`0?3ol01E0?3ol003003o003oool0oooo07@0oooo
0P0000000`3oool000000000000L0?ooo`03003o003`oo00l?o`0;T0l?o`
00<00?l00?ooo`3oool06@3oool00740oooo00<00?l00?3ol03`oo00E@3`
oo000`00o`00oooo0?ooo`1e0?ooo`030000003oool0000001d0oooo00<0
0?l00?3ol03`oo00^P3`oo000`00o`00oooo0?ooo`0H0?ooo`00K03oool5
00000003003o003`oo00l?o`05H0l?o`00<00?l0000000000000K@000008
0?ooo`030000003oool0oooo01`0oooo00<00?l00?3ol03`oo00^P3`oo00
0`00o`00oooo0?ooo`0H0?ooo`00L@3oool00`00o`00l?o`0?3ol01F0?3o
l003003o003oool0oooo07<0oooo0P0000000`3oool000000000000K0?oo
o`03003o003`oo00l?o`0;`0l?o`00<00?l00?ooo`3oool05`3oool00740
oooo00<00?l00?3ol03`oo00E`3`oo000`00o`00oooo0?ooo`2B0?ooo`03
003o003`oo00l?o`0;`0l?o`00<00?l00?ooo`3oool05`3oool00700oooo
00<00?l00?3ol03`oo00F03`oo000`00o`00oooo0?ooo`2B0?ooo`03003o
003`oo00l?o`0;`0l?o`00<00?l00?ooo`3oool05`3oool00700oooo00<0
0?l00?3ol03`oo00F@3`oo000`00o`00oooo0?ooo`2A0?ooo`03003o003`
oo00l?o`0;`0l?o`00<00?l00?ooo`3oool05`3oool00700oooo00<00?l0
0?3ol03`oo00F@3`oo000`00o`00oooo0?ooo`2A0?ooo`03003o003`oo00
l?o`0;d0l?o`00<00?l00?ooo`3oool05P3oool00700oooo00<00?l00?3o
l03`oo00FP3`oo000`00o`00oooo0?ooo`2@0?ooo`03003o003`oo00l?o`
0;d0l?o`00<00?l00?ooo`3oool05P3oool00700oooo00<00?l00?3ol03`
oo00F`3`oo000`00o`00oooo0?ooo`2?0?ooo`03003o003`oo00l?o`0;d0
l?o`00<00?l00?ooo`3oool05P3oool00700oooo00<00?l00?3ol03`oo00
F`3`oo000`00o`00oooo0?ooo`2?0?ooo`03003o003`oo00l?o`0;h0l?o`
00<00?l00?ooo`3oool05@3oool00700oooo00<00?l00?3ol03`oo00G03`
oo000`00o`00oooo0?ooo`2>0?ooo`03003o003`oo00l?o`0;h0l?o`00<0
0?l00?ooo`3oool05@3oool00740oooo00<00?l00?3ol03`oo00G03`oo00
0`00o`00oooo0?ooo`2=0?ooo`03003o003`oo00l?o`0;h0l?o`00<00?l0
0?ooo`3oool05@3oool00740oooo00<00?l00?3ol03`oo00G03`oo000`00
o`00oooo0?ooo`2=0?ooo`03003o003`oo00l?o`0;h0l?o`00<00?l00?oo
o`3oool05@3oool00740oooo00<00?l00?3ol03`oo00G@3`oo000`00o`00
oooo0?ooo`2<0?ooo`03003o003`oo00l?o`0;h0l?o`00<00?l00?ooo`3o
ool05@3oool00740oooo00<00?l00?3ol03`oo00GP3`oo000`00o`00oooo
0?ooo`2:0?ooo`03003o003`oo00l?o`0;l0l?o`00<00?l00?ooo`3oool0
5@3oool00740oooo00<00?l00?3ol03`oo00GP3`oo000`3oool00?l00?oo
o`2:0?ooo`03003o003`oo00l?o`0;l0l?o`00<00?l00?ooo`3oool05@3o
ool00740oooo00<00?l00?3ol03`oo00G`3`oo000`00o`00oooo0?ooo`29
0?ooo`03003o003`oo00l?o`0;l0l?o`00<00?l00?ooo`3oool05@3oool0
0740oooo00<00?l00?3ol03`oo00H03`oo000`00o`00oooo0?ooo`280?oo
o`03003o003`oo00l?o`0<00l?o`00<00?l00?ooo`3oool0503oool00740
oooo00<0l?o`003o003`oo00H@3`oo03003o08L0oooo00<00?l00?3ol03`
oo00@@3`oo040000og/0l?o`00<00?l00?ooo`3oool0503oool00780oooo
00<00?l00?3ol03`oo00H`3`oo04003o08<0oooo00<00?l00?3ol03`oo00
?`3`oo020000o`@0/>3V0P000?mi0?3ol003003o003oool0oooo01@0oooo
001b0?ooo`03003o003`oo00l?o`06L0l?o`7000o`1W0?ooo`03003o003`
oo00l?o`03h0l?o`00<0003o0;3PiP2`h>H01P2`h>H00`000?l0l?o`0?3o
l01f0?3ol003003o003oool0oooo01@0oooo001b0?ooo`03003o003`oo00
l?o`08<0l?o`1@00o`1R0?ooo`03003o003`oo00l?o`03d0l?o`00<0003o
0;3PiP2`h>H0202`h>H20000ogH0l?o`00<00?l00?ooo`3oool0503oool0
07<0oooo00<00?l00?3ol03`oo00Q`3`oo04003o05h0oooo00<00?l00?3o
l03`oo00?@3`oo000`000?l0/>3V0;3PiP0:0;3PiP030000o`3`oo00l?o`
07<0l?o`00<00?l00?ooo`3oool0503oool007<0oooo00<00?l00?3ol03`
oo00R`3`oo04003o05X0oooo00<00?l00?3ol03`oo00?03`oo000`000?l0
/>3V0;3PiP0<0;3PiP030000o`3`oo00l?o`0780l?o`00<00?l00?ooo`3o
ool0503oool007<0oooo00<00?l00?3ol03`oo00S`3`oo02003o05P0oooo
00<00?l00?3ol03`oo00?03`oo000`000?l0/>3V0;3PiP0=0;3PiP030000
o`3`oo00l?o`0740l?o`00<00?l00?ooo`3oool0503oool007<0oooo00<0
0?l00?3ol03`oo00T@3`oo02003o05H0oooo00<00?l00?3ol03`oo00>`3`
oo000`000?l0/>3V0;3PiP0?0;3PiP030000o`3`oo00l?o`01@0l?o`1P00
0?mF0?3ol003003o003oool0oooo01@0oooo001d0?ooo`03003o003`oo00
l?o`0980l?o`00<00?l00?ooo`3oool0D`3oool00`00o`00l?o`0?3ol00k
0?3ol0030000o`2`h>H0/>3V0100/>3V00<0003o0?3ol03`oo004@3`oo02
0000o`H0/>3V0`000?mB0?3ol003003o003oool0oooo01D0oooo001d0?oo
o`03003o003`oo00l?o`09<0l?o`0P00o`1C0?ooo`03003o003`oo00l?o`
03X0l?o`00<0003o0;3PiP2`h>H04P2`h>H00`000?l0l?o`0?3ol00>0?3o
l080003o2`2`h>H20000oe00l?o`00<00?l00?ooo`3oool05@3oool007@0
oooo00<00?l00?3ol03`oo00U@3`oo02003o0540oooo00<00?l00?3ol03`
oo00>P3`oo000`000?l0/>3V0;3PiP0C0;3PiP030000o`3`oo00l?o`00`0
l?o`00<0003o0;3PiP2`h>H03@2`h>H20000odh0l?o`00<00?l00?ooo`3o
ool05@3oool007@0oooo00<00?l00?3ol03`oo00U`3`oo02003o04l0oooo
00<00?l00?3ol03`oo00>@3`oo000`000?l0/>3V0;3PiP0E0;3PiP030000
o`3`oo00l?o`00T0l?o`0P000?lB0;3PiP80003oC03`oo000`00o`00oooo
0?ooo`0E0?ooo`00M@3oool00`00o`00l?o`0?3ol0170?3ol0D0003oC03`
oo02003o04d0oooo00<00?l00?3ol03`oo00>@3`oo000`000?l0/>3V0;3P
iP0F0;3PiP030000o`3`oo00l?o`00H0l?o`0P000?lF0;3PiP80003oBP3`
oo000`00o`00oooo0?ooo`0E0?ooo`00M@3oool00`00o`00l?o`0?3ol015
0?3ol080003o1@2`h>H20000od`0l?o`00<00?l00?ooo`3oool0BP3oool0
0`00o`00l?o`0?3ol00i0?3ol0030000o`2`h>H0/>3V01L0/>3V00<0003o
0?3ol03`oo000`3`oo020000oaX0/>3V0P000?m80?3ol003003o003oool0
oooo01D0oooo001f0?ooo`03003o003`oo00l?o`0480l?o`0P000?l90;3P
iP80003oB`3`oo02003o04X0oooo00<00?l00?3ol03`oo00>@3`oo000`00
0?l0/>3V0;3PiP0H0;3PiPD0003o7P2`h>H20000odH0l?o`00<00?l00?oo
o`3oool05@3oool007H0oooo00<00?l00?3ol03`oo00@03`oo020000o`d0
/>3V00<0003o0?3ol03`oo00B@3`oo000`3oool00?l00?ooo`180?ooo`03
003o003`oo00l?o`03T0l?o`00<0003o0;3PiP2`h>H0?@2`h>H00`000?l0
l?o`0?3ol0130?3ol003003o003oool0oooo01D0oooo001f0?ooo`03003o
003`oo00l?o`03d0l?o`0`000?l?0;3PiP030000o`3`oo00l?o`04X0l?o`
00<0oooo003o003oool0A`3oool00`00o`00l?o`0?3ol00h0?3ol0030000
o`2`h>H0/>3V03l0/>3V00<0003o0?3ol03`oo00@@3`oo000`00o`00oooo
0?ooo`0F0?ooo`00M`3oool00`00o`00l?o`0?3ol00j0?3ol080003o4`2`
h>H00`000?l0l?o`0?3ol01;0?3ol003003o003oool0oooo04D0oooo00<0
0?l00?3ol03`oo00>03`oo000`000?l0/>3V0;3PiP100;3PiP80003o@@3`
oo000`00o`00oooo0?ooo`0F0?ooo`00M`3oool00`00o`00l?o`0?3ol00i
0?3ol0030000o`2`h>H0/>3V01<0/>3V00<0003o0?3ol03`oo00C03`oo00
0`00o`00oooo0?ooo`140?ooo`03003o003`oo00l?o`03P0l?o`00<0003o
0;3PiP2`h>H0@@2`h>H00`000?l0l?o`0?3ol00o0?3ol003003o003oool0
oooo01H0oooo001h0?ooo`03003o003`oo00l?o`03H0l?o`0P000?lG0;3P
iP030000o`3`oo00l?o`04`0l?o`00<00?l00?ooo`3oool0@`3oool00`00
o`00l?o`0?3ol00g0?3ol0030000o`2`h>H0/>3V04<0/>3V00<0003o0?3o
l03`oo00?P3`oo000`00o`00oooo0?ooo`0F0?ooo`00N03oool00`00o`00
l?o`0?3ol00d0?3ol080003o6@2`h>H00`000?l0l?o`0?3ol01=0?3ol003
003o003oool0oooo0480oooo00<00?l00?3ol03`oo00=`3`oo000`000?l0
/>3V0;3PiP130;3PiP030000o`3`oo00l?o`03h0l?o`00<00?l00?ooo`3o
ool05P3oool007P0oooo00<00?l00?3ol03`oo00<`3`oo000`000?l0/>3V
0;3PiP0J0;3PiP030000o`3`oo00l?o`04d0l?o`00<00?l00?ooo`3oool0
@@3oool00`00o`00l?o`0?3ol00f0?3ol0030000o`2`h>H0/>3V04D0/>3V
00<0003o0?3ol03`oo00?@3`oo000`00o`00oooo0?ooo`0F0?ooo`00N@3o
ool00`00o`00l?o`0?3ol00b0?3ol0030000o`2`h>H0/>3V01X0/>3V00<0
003o0?3ol03`oo00CP3`oo000`00o`00oooo0?ooo`100?ooo`03003o003`
oo00l?o`03H0l?o`00<0003o0;3PiP2`h>H0A@2`h>H00`000?l0l?o`0?3o
l00m0?3ol003003o003oool0oooo01H0oooo001i0?ooo`03003o003`oo00
l?o`0340l?o`00<0003o0;3PiP2`h>H0702`h>H00`000?l0l?o`0?3ol01>
0?3ol003003o003oool0oooo03l0oooo00<00?l00?3ol03`oo00=P3`oo00
0`000?l0/>3V0;3PiP150;3PiP030000o`3`oo00l?o`03d0l?o`00<00?l0
0?ooo`3oool05P3oool007X0oooo00<00?l00?3ol03`oo00;`3`oo000`00
0?l0/>3V0;3PiP0M0;3PiP030000o`3`oo00l?o`04l0l?o`00<00?l00?oo
o`3oool0?P3oool00`00o`00l?o`0?3ol00f0?3ol0030000o`2`h>H0/>3V
04D0/>3V00<0003o0?3ol03`oo00?03`oo000`00o`00oooo0?ooo`0G0?oo
o`00NP3oool00`00o`00l?o`0?3ol00_0?3ol0030000o`2`h>H0/>3V01h0
/>3V00<0003o0?3ol03`oo00C`3`oo02003o03h0oooo00<00?l00?3ol03`
oo00=P3`oo000`000?l0/>3V0;3PiP150;3PiP030000o`3`oo00l?o`03`0
l?o`00<00?l00?ooo`3oool05`3oool007/0oooo00<00?l00?3ol03`oo00
;P3`oo000`000?l0/>3V0;3PiP0O0;3PiP030000o`3`oo00l?o`04l0l?o`
00<0oooo003o003oool0?03oool00`00o`00l?o`0?3ol00f0?3ol0030000
o`2`h>H0/>3V04D0/>3V00<0003o0?3ol03`oo00?03`oo000`00o`00oooo
0?ooo`0G0?ooo`00N`3oool00`00o`00l?o`0?3ol00^0?3ol0030000o`2`
h>H0/>3V01l0/>3V00<0003o0?3ol03`oo00D@3`oo000`00o`00oooo0?oo
o`0j0?ooo`03003o003`oo00l?o`03H0l?o`00<0003o0;3PiP2`h>H0A@2`
h>H00`000?l0l?o`0?3ol00l0?3ol003003o003oool0oooo01L0oooo001l
0?ooo`03003o003`oo00l?o`02`0l?o`00<0003o0;3PiP2`h>H08@2`h>H0
0`000?l0l?o`0?3ol01A0?3ol003003o003oool0oooo03T0oooo00<00?l0
0?3ol03`oo00=P3`oo000`000?l0/>3V0;3PiP150;3PiP030000o`3`oo00
l?o`03`0l?o`00<00?l00?ooo`3oool05`3oool007`0oooo00<00?l00?3o
l03`oo00;03`oo000`000?l0/>3V0;3PiP0Q0;3PiP030000o`3`oo00l?o`
0580l?o`00<00?l00?ooo`3oool0>03oool00`00o`00l?o`0?3ol00g0?3o
l0030000o`2`h>H0/>3V04@0/>3V00<0003o0?3ol03`oo00?03`oo000`00
o`00oooo0?ooo`0G0?ooo`00O@3oool00`00o`00l?o`0?3ol00[0?3ol003
0000o`2`h>H0/>3V0280/>3V00<0003o0?3ol03`oo00DP3`oo000`00o`00
oooo0?ooo`0g0?ooo`03003o003`oo00l?o`03L0l?o`00<0003o0;3PiP2`
h>H0A02`h>H00`000?l0l?o`0?3ol00k0?3ol003003o003oool0oooo01P0
oooo001m0?ooo`03003o003`oo00l?o`02/0l?o`00<0003o0;3PiP2`h>H0
8P2`h>H00`000?l0l?o`0?3ol01C0?3ol003003o003oool0oooo03H0oooo
00<00?l00?3ol03`oo00=`3`oo000`000?l0/>3V0;3PiP140;3PiP030000
o`3`oo00l?o`03/0l?o`00<00?l00?ooo`3oool0603oool007h0oooo00<0
0?l00?3ol03`oo00:P3`oo000`000?l0/>3V0;3PiP0R0;3PiP030000o`3`
oo00l?o`05@0l?o`00<00?l00?ooo`3oool0=P3oool00`00o`00l?o`0?3o
l00f0?3ol0030000o`2`h>H0/>3V04@0/>3V00<0003o0?3ol03`oo00>`3`
oo000`00o`00oooo0?ooo`0H0?ooo`00O`3oool00`00o`00l?o`0?3ol00Y
0?3ol0030000o`2`h>H0/>3V02<0/>3V00<0003o0?3ol03`oo00E03`oo00
0`00o`00oooo0?ooo`0e0?ooo`03003o003`oo00l?o`03L0l?o`00<0003o
0;3PiP2`h>H0@`2`h>H00`000?l0l?o`0?3ol00k0?3ol003003o003oool0
oooo01P0oooo001o0?ooo`03003o003`oo00l?o`02X0l?o`00<0003o0;3P
iP2`h>H08`2`h>H00`000?l0l?o`0?3ol01D0?3ol003003o003oool0oooo
03D0oooo00<00?l00?3ol03`oo00=P3`oo000`000?l0/>3V0;3PiP120;3P
iP030000o`3`oo00l?o`03`0l?o`00<00?l00?ooo`3oool0603oool00800
oooo00<00?l00?3ol03`oo00:@3`oo000`000?l0/>3V0;3PiP0T0;3PiP<0
003oE03`oo000`00o`00oooo0?ooo`0d0?ooo`03003o003`oo00l?o`03L0
l?o`00<0003o0;3PiP2`h>H0@@2`h>H00`000?l0l?o`0?3ol00l0?3ol003
003o003oool0oooo01P0oooo00200?ooo`03003o003oool0l?o`02T0l?o`
00<0003o0;3PiP2`h>H09`2`h>H=0000odP0l?o`0P00o`0d0?ooo`03003o
003`oo00l?o`03P0l?o`00<0003o0;3PiP2`h>H0@02`h>H00`000?l0l?o`
0?3ol00k0?3ol003003o003oool0oooo01T0oooo00210?ooo`03003o003`
oo00l?o`02P0l?o`00<0003o0;3PiP2`h>H0=02`h>H30000odL0l?o`00<0
0?l00?ooo`3oool0<P3oool00`00o`00l?o`0?3ol00h0?3ol0030000o`2`
h>H0/>3V03l0/>3V00<0003o0?3ol03`oo00>`3`oo000`00o`00oooo0?oo
o`0I0?ooo`00PP3oool00`00o`00l?o`0?3ol00X0?3ol0030000o`2`h>H0
/>3V03H0/>3V10000?m40?3ol003003o003oool0oooo0340oooo00<00?l0
0?3ol03`oo00>03`oo000`000?l0/>3V0;3PiP0o0;3PiP030000o`3`oo00
l?o`03/0l?o`00<00?l00?ooo`3oool06@3oool008<0oooo00<00?l00?3o
l03`oo009`3`oo000`000?l0/>3V0;3PiP0j0;3PiP030000o`3`oo00l?o`
0480l?o`00<00?l00?ooo`3oool0<@3oool00`00o`00l?o`0?3ol00h0?3o
l0030000o`2`h>H0/>3V03h0/>3V00<0003o0?3ol03`oo00>`3`oo000`00
o`00oooo0?ooo`0I0?ooo`00Q03oool00`00o`00l?o`0?3ol00V0?3ol003
0000o`2`h>H0/>3V03/0/>3V00<0003o0?3ol03`oo00@P3`oo000`00o`00
oooo0?ooo`0a0?ooo`03003o003`oo00l?o`03P0l?o`00<0003o0;3PiP2`
h>H0?@2`h>H00`000?l0l?o`0?3ol00k0?3ol003003o003oool0oooo01T0
oooo00240?ooo`03003o003`oo00l?o`02H0l?o`00<0003o0;3PiP2`h>H0
?02`h>H20000od80l?o`00<00?l00?ooo`3oool0<@3oool00`00o`00l?o`
0?3ol00h0?3ol0030000o`2`h>H0/>3V03`0/>3V00<0003o0?3ol03`oo00
?03`oo000`00o`00oooo0?ooo`0I0?ooo`00Q@3oool00`00o`00l?o`0?3o
l00V0?3ol0030000o`2`h>H0/>3V03d0/>3V00<0003o0?3ol03`oo00@03`
oo000`00o`00oooo0?ooo`0a0?ooo`03003o003`oo00l?o`03P0l?o`00<0
003o0;3PiP2`h>H0>`2`h>H00`000?l0l?o`0?3ol00k0?3ol003003o003o
ool0oooo01X0oooo00260?ooo`03003o003`oo00l?o`02D0l?o`00<0003o
0;3PiP2`h>H0?P2`h>H00`000?l0l?o`0?3ol00o0?3ol003003o003oool0
oooo0380oooo00<00?l00?3ol03`oo00>03`oo000`000?l0/>3V0;3PiP0j
0;3PiP030000o`3`oo00l?o`03/0l?o`00<00?l00?ooo`3oool06P3oool0
08L0oooo00<00?l00?3ol03`oo009@3`oo000`000?l0/>3V0;3PiP0n0;3P
iP030000o`3`oo00l?o`03l0l?o`00<00?l00?ooo`3oool0<P3oool00`00
o`00l?o`0?3ol00h0?3ol0030000o`2`h>H0/>3V03T0/>3V00<0003o0?3o
l03`oo00>`3`oo000`00o`00oooo0?ooo`0J0?ooo`00R03oool00`00o`00
l?o`0?3ol00T0?3ol0030000o`2`h>H0/>3V03h0/>3V00<0003o0?3ol03`
oo00?`3`oo000`00o`00oooo0?ooo`0c0?ooo`03003o003`oo00l?o`03P0
l?o`00<0003o0;3PiP2`h>H0>02`h>H00`000?l0l?o`0?3ol00k0?3ol003
003o003oool0oooo01X0oooo00280?ooo`030?3ol000o`00l?o`02D0l?o`
00<0003o0;3PiP2`h>H0?P2`h>H00`000?l0l?o`0?3ol00o0?3ol003003o
003oool0oooo03<0oooo00<00?l00?3ol03`oo00>03`oo000`000?l0/>3V
0;3PiP0g0;3PiP030000o`3`oo00l?o`03/0l?o`00<00?l00?ooo`3oool0
6P3oool008T0oooo00<00?l00?3ol03`oo00903`oo000`000?l0/>3V0;3P
iP0o0;3PiP80003o?`3`oo000`00o`00oooo0?ooo`0d0?ooo`03003o003`
oo00l?o`03P0l?o`00<0003o0;3PiP2`h>H0=P2`h>H00`000?l0l?o`0?3o
l00j0?3ol003003o003oool0oooo01/0oooo002:0?ooo`03003o003`oo00
l?o`02@0l?o`00<0003o0;3PiP2`h>H0@02`h>H00`000?l0l?o`0?3ol00l
0?3ol003003o003oool0oooo03D0oooo00<00?l00?3ol03`oo00>03`oo02
0000ocH0/>3V00<0003o0?3ol03`oo00>P3`oo000`00o`00oooo0?ooo`0K
0?ooo`00RP3oool00`0000000?l00?3ol00U0?3ol0030000o`2`h>H0/>3V
0400/>3V00<0003o0?3ol03`oo00?03`oo000`00o`00oooo0?ooo`0e0?oo
o`03003o003`oo00l?o`03T0l?o`0P000?ld0;3PiP030000o`3`oo00l?o`
03X0l?o`00<00?l00?ooo`3oool06`3oool008X0oooo00<000000?ooo`00
o`009@3`oo000`000?l0/>3V0;3PiP110;3PiP80003o?03`oo000`00o`00
oooo0?ooo`0f0?ooo`03003o003`oo00l?o`03X0l?o`0P000?lb0;3PiP03
0000o`3`oo00l?o`03X0l?o`00<00?l00?ooo`3oool06`3oool008X0oooo
00@000000?ooo`3oool00?l09@3`oo000`000?l0/>3V0;3PiP110;3PiP03
0000o`3`oo00l?o`03X0l?o`00<00?l00?ooo`3oool0=P3oool00`000000
0?l0003o000l0?3ol0030000o`2`h>H0/>3V02l0/>3V00<0003o0?3ol03`
oo00>@3`oo000`00o`00oooo0?ooo`0L0?ooo`00RP3oool01@000000oooo
0?ooo`3`oo000?l002D0l?o`00<0003o0;3PiP2`h>H0@@2`h>H00`000?l0
l?o`0?3ol00i0?3ol003003o003oool0oooo03H0oooo00<000000?ooo`3o
ool00P00o`0k0?3ol0030000o`2`h>H0/>3V02d0/>3V00<0003o0?3ol03`
oo00>P3`oo000`00o`00oooo0?ooo`0L0?ooo`00RP3oool01@000000oooo
0?ooo`3oool00?l002D0l?o`00<0003o0;3PiP2`h>H0@@2`h>H00`000?l0
l?o`0?3ol00i0?3ol003003o003oool0oooo03H0oooo00<000000?ooo`3o
ool00P3oool2003o03X0l?o`00<0003o0;3PiP2`h>H0;02`h>H00`000?l0
l?o`0?3ol00j0?3ol003003o003oool0oooo01`0oooo002:0?ooo`030000
003oool0oooo0080oooo00<00?l00?3ol03`oo008`3`oo000`000?l0/>3V
0;3PiP110;3PiP030000o`3`oo00l?o`03P0l?o`00<00?l00?ooo`3oool0
=P3oool00`000000oooo0?ooo`040?ooo`800?l0>03`oo000`000?l0/>3V
0;3PiP0/0;3PiP030000o`3`oo00l?o`03X0l?o`00<00?l00?ooo`3oool0
703oool008X0oooo00<000000?ooo`3oool00`3oool00`00o`00l?o`0?3o
l00S0?3ol0030000o`2`h>H0/>3V0400/>3V00<0003o0?3ol03`oo00>03`
oo000`00o`00oooo0?ooo`0f0?ooo`030000003oool0oooo00H0oooo0`00
o`0f0?3ol0030000o`2`h>H0/>3V02/0/>3V00<0003o0?3ol03`oo00>P3`
oo000`00o`00oooo0?ooo`0L0?ooo`00RP3oool00`000000oooo0?ooo`04
0?ooo`03003o003`oo00l?o`02<0l?o`00<0003o0;3PiP2`h>H0?`2`h>H0
0`000?l0l?o`0?3ol00h0?3ol003003o003oool0oooo03H0oooo00<00000
0?ooo`3oool02@3oool4003o0380l?o`00<0003o0;3PiP2`h>H0302`h>H5
000001X0/>3V00<0003o0?3ol03`oo00>@3`oo000`00o`00oooo0?ooo`0M
0?ooo`00RP3oool00`000000oooo0?ooo`050?ooo`03003o003`oo00l?o`
0280l?o`00<0003o0;3PiP2`h>H0?`2`h>H00`000?l0l?o`0?3ol00h0?3o
l003003o003oool0oooo03H0oooo00<000000?ooo`3oool03@3oool3003o
0300l?o`00<0003o0;3PiP2`h>H0302`h>H01@000000/>3V0;3PiP2`h>H0
000001P0/>3V00<0003o0?3ol03`oo00>P3`oo000`00o`00oooo0?ooo`0M
0?ooo`00RP3oool00`000000oooo0?ooo`060?ooo`03003o003`oo00l?o`
0280l?o`00<0003o0;3PiP2`h>H0?P2`h>H00`000?l0l?o`0?3ol00g0?3o
l003003o003oool0oooo03L0oooo00<000000?ooo`3oool0403oool3003o
02d0l?o`00<0003o0;3PiP2`h>H0302`h>H01@000000/>3V0;3PiP2`h>H0
000001P0/>3V00<0003o0?3ol03`oo00>P3`oo000`00o`00oooo0?ooo`0M
0?ooo`00RP3oool00`000000oooo0?ooo`070?ooo`03003o003`oo00l?o`
0280l?o`0P000?ln0;3PiP030000o`3`oo00l?o`03L0l?o`00<00?l00?oo
o`3oool0=`3oool00`000000oooo0?ooo`0C0?ooo`<00?l0:P3`oo000`00
0?l0/>3V0;3PiP0<0;3PiP050000002`h>H0/>3V0;3PiP000000602`h>H0
0`000?l0l?o`0?3ol00j0?3ol003003o003oool0oooo01d0oooo002:0?oo
o`030000003oool0oooo00L0oooo00<00?l00?3ol03`oo008`3`oo000`00
0?l0/>3V0;3PiP0l0;3PiP030000o`3`oo00l?o`03L0l?o`00<00?l00?oo
o`3oool0=`3oool00`000000oooo0?ooo`0F0?ooo`800?l0:03`oo000`00
0?l0/>3V0;3PiP0<0;3PiP@000006@2`h>H00`000?l0l?o`0?3ol00j0?3o
l003003o003oool0oooo01d0oooo002:0?ooo`030000003oool0oooo00P0
oooo00<00?l00?3ol03`oo008`3`oo000`000?l0/>3V0;3PiP0j0;3PiP03
0000o`3`oo00l?o`03P0l?o`00<00?l00?ooo`3oool0=`3oool00`000000
oooo0?ooo`0H0?ooo`<00?l09@3`oo000`000?l0/>3V0;3PiP0<0;3PiP05
0000002`h>H0/>3V0;3PiP000000602`h>H00`000?l0l?o`0?3ol00i0?3o
l003003o003oool0oooo01h0oooo002:0?ooo`030000003oool0oooo00T0
oooo00<00?l00?3ol03`oo008`3`oo000`000?l0/>3V0;3PiP0i0;3PiP03
0000o`3`oo00l?o`03P0l?o`00<00?l00?ooo`3oool0=`3oool00`000000
oooo0?ooo`0K0?ooo`<00?l08P3`oo000`000?l0/>3V0;3PiP0<0;3PiP05
0000002`h>H0/>3V0;3PiP000000602`h>H00`000?l0l?o`0?3ol00i0?3o
l003003o003oool0oooo01h0oooo002:0?ooo`030000003oool0oooo00X0
oooo00<00?l00?3ol03`oo008P3`oo000`000?l0/>3V0;3PiP0@0;3PiP<0
000000@0/>3V00000000000000008@2`h>H00`000?l0l?o`0?3ol00h0?3o
l003003o003oool0oooo03P0oooo00<000000?ooo`3oool07P3oool2003o
0240l?o`00<0003o0;3PiP2`h>H02P2`h>H5000001T0/>3V00<0003o0?3o
l03`oo00>@3`oo000`00o`00oooo0?ooo`0N0?ooo`00RP3oool00`000000
oooo0?ooo`0;0?ooo`03003o003`oo00l?o`0280l?o`00<0003o0;3PiP2`
h>H0402`h>H01@000000/>3V0;3PiP2`h>H000000280/>3V00<0003o0?3o
l03`oo00>03`oo000`00o`00oooo0?ooo`0h0?ooo`030000003oool0oooo
0200oooo0`00o`0N0?3ol0030000o`2`h>H0/>3V02P0/>3V00<0003o0?3o
l03`oo00>@3`oo000`00o`00oooo0?ooo`0N0?ooo`00RP3oool00`000000
oooo0?ooo`0;0?ooo`03003o003`oo00l?o`0280l?o`00<0003o0;3PiP2`
h>H0402`h>H500000240/>3V00<0003o0?3ol03`oo00>03`oo000`00o`00
oooo0?ooo`0i0?ooo`030000003oool0oooo02<0oooo0`00o`0J0?3ol003
0000o`2`h>H0/>3V02P0/>3V00<0003o0?3ol03`oo00>@3`oo000`00o`00
oooo0?ooo`0O0?ooo`00RP3oool00`000000oooo0?ooo`0<0?ooo`03003o
003`oo00l?o`0240l?o`00<0003o0;3PiP2`h>H04@2`h>H00`000000/>3V
0000000R0;3PiP030000o`3`oo00l?o`03P0l?o`00<00?l00?ooo`3oool0
>@3oool00`000000oooo0?ooo`0V0?ooo`800?l0603`oo000`000?l0/>3V
0;3PiP0X0;3PiP030000o`3`oo00l?o`03T0l?o`00<00?l00?ooo`3oool0
7`3oool008X0oooo00<000000?ooo`3oool03@3oool00`00o`00l?o`0?3o
l00P0?3ol0030000o`2`h>H0/>3V0140/>3V00<000000;3PiP0000008P2`
h>H00`000?l0l?o`0?3ol00h0?3ol003003o003oool0oooo03T0oooo00<0
00000?ooo`3oool0:03oool00`00o`00l?o`0?3ol00E0?3ol0030000o`2`
h>H0/>3V02P0/>3V00<0003o0?3ol03`oo00>@3`oo000`00o`00oooo0?oo
o`0O0?ooo`00RP3oool00`000000oooo0?ooo`0=0?ooo`030?3ol000o`00
l?o`0200l?o`00<0003o0;3PiP2`h>H04@2`h>H00`000000/>3V0000000Q
0;3PiP030000o`3`oo00l?o`03P0l?o`00<00?l00?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0Y0?ooo`03003o003`oo00l?o`01@0l?o`00<0003o
0;3PiP2`h>H0:02`h>H00`000?l0l?o`0?3ol00i0?3ol003003o003oool0
oooo01l0oooo002:0?ooo`030000003oool0oooo00h0oooo00<00?l00?3o
l03`oo007`3`oo000`000?l0/>3V0;3PiP0B0;3PiP030000002`h>H0/>3V
0200/>3V00<0003o0?3ol03`oo00>03`oo000`00o`00oooo0?ooo`0j0?oo
o`030000003oool0oooo02X0oooo00<00?l00?3ol03`oo004`3`oo000`00
0?l0/>3V0;3PiP0W0;3PiP030000o`3`oo00l?o`03T0l?o`00<00?l00?oo
o`3oool0803oool008X0oooo00<000000?ooo`3oool03P3oool00`00o`00
l?o`0?3ol00N0?3ol0030000o`2`h>H0/>3V0180/>3V0P00000R0;3PiP03
0000o`3`oo00l?o`03L0l?o`00<00?l00?ooo`3oool0>`3oool00`000000
oooo0?ooo`0[0?ooo`03003o003`oo00l?o`0180l?o`00<0003o0;3PiP2`
h>H09`2`h>H00`000?l0l?o`0?3ol00i0?3ol003003o003oool0oooo0200
oooo002:0?ooo`030000003oool0oooo00h0oooo00<00?l00?3ol03`oo00
7P3`oo000`000?l0/>3V0;3PiP0e0;3PiP030000o`3`oo00l?o`03P0l?o`
00<00?l00?ooo`3oool0>`3oool00`000000oooo0?ooo`0/0?ooo`03003o
003`oo00l?o`0140l?o`00<0003o0;3PiP2`h>H09`2`h>H00`000?l0l?o`
0?3ol00i0?3ol003003o003oool0oooo0200oooo002:0?ooo`030000003o
ool0oooo00l0oooo00<00?l00?3ol03`oo007@3`oo000`000?l0/>3V0;3P
iP0e0;3PiP030000o`3`oo00l?o`03P0l?o`00<00?l00?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0]0?ooo`03003o003`oo00l?o`0100l?o`00<0
003o0;3PiP2`h>H09`2`h>H00`000?l0l?o`0?3ol00i0?3ol003003o003o
ool0oooo0200oooo002:0?ooo`030000003oool0oooo00l0oooo00<00?l0
0?3ol03`oo007@3`oo000`000?l0/>3V0;3PiP0d0;3PiP030000o`3`oo00
l?o`03P0l?o`00<00?l00?ooo`3oool0?03oool00`000000oooo0?ooo`0]
0?ooo`03003o003`oo00l?o`0100l?o`00<0003o0;3PiP2`h>H09P2`h>H0
0`000?l0l?o`0?3ol00i0?3ol003003o003oool0oooo0240oooo002:0?oo
o`030000003oool0oooo00l0oooo00<00?l00?3ol03`oo00703`oo000`00
0?l0/>3V0;3PiP0e0;3PiP030000o`3`oo00l?o`03P0l?o`00<00?l00?oo
o`3oool0?03oool00`000000oooo0?ooo`0]0?ooo`03003o003`oo00l?o`
0100l?o`00<0003o0;3PiP2`h>H09P2`h>H00`000?l0l?o`0?3ol00i0?3o
l003003o003oool0oooo0240oooo002:0?ooo`030000003oool0oooo00l0
oooo00<00?l00?3ol03`oo00703`oo000`000?l0/>3V0;3PiP0e0;3PiP03
0000o`3`oo00l?o`03L0l?o`00<00?l00?3ol03oool0?@3oool00`000000
oooo0?ooo`0^0?ooo`03003o003`oo00l?o`00l0l?o`00<0003o0;3PiP2`
h>H09P2`h>H00`000?l0l?o`0?3ol00i0?3ol003003o003oool0oooo0240
oooo002:0?ooo`030000003oool0oooo00l0oooo00<00?l00?3ol03`oo00
703`oo000`000?l0/>3V0;3PiP0d0;3PiP030000o`3`oo00l?o`03P0l?o`
00<00?l00?ooo`3oool0?@3oool00`000000oooo0?ooo`0^0?ooo`03003o
003`oo00l?o`00l0l?o`00<0003o0;3PiP2`h>H09@2`h>H00`000?l0l?o`
0?3ol00j0?3ol003003o003oool0oooo0240oooo002:0?ooo`030000003o
ool0oooo00l0oooo00<00?l00?3ol03`oo00703`oo000`000?l0/>3V0;3P
iP0d0;3PiP030000o`3`oo00l?o`03L0l?o`00<00?l00?3ol03oool0?P3o
ool00`000000oooo0?ooo`0^0?ooo`03003o003`oo00l?o`00h0l?o`00<0
003o0;3PiP2`h>H09P2`h>H00`000?l0l?o`0?3ol00i0?3ol003003o003o
ool0oooo0280oooo002:0?ooo`030000003oool0oooo00l0oooo00<00?l0
0?3ol03`oo00703`oo000`000?l0/>3V0;3PiP0d0;3PiP030000o`3`oo00
l?o`03L0l?o`00<00?l00?ooo`3oool0?P3oool00`000000oooo0?ooo`0^
0?ooo`03003o003`oo00l?o`00h0l?o`00<0003o0;3PiP2`h>H09@2`h>H0
0`000?l0l?o`0?3ol00j0?3ol003003o003oool0oooo0280oooo002:0?oo
o`030000003oool0oooo00l0oooo00<00?l00?3ol03`oo006`3`oo000`00
0?l0/>3V0;3PiP0d0;3PiP030000o`3`oo00l?o`03P0l?o`00<00?l00?oo
o`3oool0?P3oool00`000000oooo0?ooo`0_0?ooo`03003o003`oo00l?o`
00d0l?o`00<0003o0;3PiP2`h>H09@2`h>H00`000?l0l?o`0?3ol00j0?3o
l003003o003oool0oooo0280oooo002:0?ooo`030000003oool0oooo00l0
oooo00<00?l00?3ol03`oo006`3`oo000`000?l0/>3V0;3PiP0d0;3PiP03
0000o`3`oo00l?o`03L0l?o`00<00?l00?ooo`3oool0?`3oool00`000000
oooo0?ooo`0_0?ooo`03003o003`oo00l?o`00d0l?o`00<0003o0;3PiP2`
h>H0902`h>H00`000?l0l?o`0?3ol00k0?3ol003003o003oool0oooo0280
oooo002:0?ooo`030000003oool0oooo00l0oooo00<00?l00?3ol03`oo00
6P3`oo000`000?l0/>3V0;3PiP0d0;3PiP030000o`3`oo00l?o`03P0l?o`
00<00?l00?ooo`3oool0?`3oool00`000000oooo0?ooo`0_0?ooo`03003o
003`oo00l?o`00d0l?o`00<0003o0;3PiP2`h>H0902`h>H00`000?l0l?o`
0?3ol00j0?3ol003003o003oool0oooo02<0oooo002:0?ooo`030000003o
ool0oooo00l0oooo00<00?l00?3ol03`oo006P3`oo000`000?l0/>3V0;3P
iP0d0;3PiP030000o`3`oo00l?o`03L0l?o`00<00?l00?ooo`3oool0@03o
ool00`000000oooo0?ooo`0_0?ooo`03003o003`oo00l?o`00d0l?o`00<0
003o0;3PiP2`h>H08`2`h>H00`000?l0l?o`0?3ol00k0?3ol003003o003o
ool0oooo02<0oooo002:0?ooo`030000003oool0oooo00l0oooo00<00?l0
0?3ol03`oo006@3`oo000`000?l0/>3V0;3PiP0d0;3PiP030000o`3`oo00
l?o`03P0l?o`00<00?l00?ooo`3oool0@03oool00`000000oooo0?ooo`0_
0?ooo`03003o003`oo00l?o`00d0l?o`00<0003o0;3PiP2`h>H08`2`h>H0
0`000?l0l?o`0?3ol00k0?3ol003003o003oool0oooo02<0oooo002:0?oo
o`030000003oool0oooo00l0oooo00<00?l00?3ol03`oo006@3`oo000`00
0?l0/>3V0;3PiP0d0;3PiP030000o`3`oo00l?o`03L0l?o`00<00?l00?oo
o`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`03003o003`oo00l?o`
00d0l?o`00<0003o0;3PiP2`h>H08`2`h>H00`000?l0l?o`0?3ol00k0?3o
l003003o003oool0oooo02<0oooo002:0?ooo`030000003oool0oooo00l0
oooo00<00?l00?3ol03`oo006@3`oo000`000?l0/>3V0;3PiP0d0;3PiP03
0000o`3`oo00l?o`03L0l?o`00<00?l00?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`03003o003`oo00l?o`00d0l?o`00<0003o0;3PiP2`
h>H08P2`h>H00`000?l0l?o`0?3ol00k0?3ol003003o003oool0oooo02@0
oooo002:0?ooo`030000003oool0oooo00l0oooo00<00?l00?3ol03`oo00
603`oo000`000?l0/>3V0;3PiP0d0;3PiP030000o`3`oo00l?o`03L0l?o`
00<00?l00?ooo`3oool0@P3oool00`000000oooo0?ooo`0_0?ooo`03003o
003`oo00l?o`00h0l?o`00<0003o0;3PiP2`h>H08@2`h>H00`000?l0l?o`
0?3ol00k0?3ol003003o003oool0oooo02@0oooo002:0?ooo`030000003o
ool0oooo00l0oooo00<00?l00?3ol03`oo00603`oo000`000?l0/>3V0;3P
iP0d0;3PiP030000o`3`oo00l?o`03L0l?o`00<00?l00?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0_0?ooo`03003o003`oo00l?o`00h0l?o`00<0
003o0;3PiP2`h>H0802`h>H00`000?l0l?o`0?3ol00l0?3ol003003o003o
ool0oooo02@0oooo002:0?ooo`030000003oool0oooo00l0oooo00<00?l0
0?3ol03`oo005`3`oo000`000?l0/>3V0;3PiP0d0;3PiP030000o`3`oo00
l?o`03P0l?o`00<00?l00?ooo`3oool0@P3oool00`000000oooo0?ooo`0_
0?ooo`03003o003`oo00l?o`00l0l?o`00<0003o0;3PiP2`h>H07P2`h>H0
0`000?l0l?o`0?3ol00m0?3ol003003o003oool0oooo02@0oooo002:0?oo
o`030000003oool0oooo00h0oooo00<0l?o`003o003`oo00603`oo000`00
0?l0/>3V0;3PiP0d0;3PiP030000o`3`oo00l?o`03L0l?o`00<00?l00?oo
o`3oool0@`3oool00`000000oooo0?ooo`0_0?ooo`03003o003`oo00l?o`
00l0l?o`00<0003o0;3PiP2`h>H07P2`h>H00`000?l0l?o`0?3ol00l0?3o
l003003o003oool0oooo02D0oooo002:0?ooo`030000003oool0oooo00h0
oooo00<00?l00?3ol03`oo005`3`oo000`000?l0/>3V0;3PiP0e0;3PiP03
0000o`3`oo00l?o`03L0l?o`00<00?l00?ooo`3oool0@`3oool00`000000
oooo0?ooo`0_0?ooo`03003o003`oo00l?o`0100l?o`00<0003o0;3PiP2`
h>H0702`h>H00`000?l0l?o`0?3ol00m0?3ol003003o003oool0oooo02D0
oooo002:0?ooo`030000003oool0oooo00h0oooo00<00?l00?3ol03`oo00
5`3`oo000`000?l0/>3V0;3PiP0d0;3PiP030000o`3`oo00l?o`03L0l?o`
00<00?l00?ooo`3oool0A03oool00`000000oooo0?ooo`0_0?ooo`03003o
003`oo00l?o`0140l?o`00<0003o0;3PiP2`h>H06`2`h>H00`000?l0l?o`
0?3ol00m0?3ol003003o003oool0oooo02D0oooo002:0?ooo`030000003o
ool0oooo00h0oooo00<00?l00?3ol03`oo005`3`oo000`000?l0/>3V0;3P
iP0d0;3PiP030000o`3`oo00l?o`03L0l?o`00<00?l00?ooo`3oool0A03o
ool00`000000oooo0?ooo`0_0?ooo`03003o003`oo00l?o`0180l?o`00<0
003o0;3PiP2`h>H06@2`h>H00`000?l0l?o`0?3ol00n0?3ol003003o003o
ool0oooo02D0oooo002:0?ooo`030000003oool0oooo00d0oooo00<00?l0
0?3ol03`oo00603`oo000`000?l0/>3V0;3PiP0c0;3PiP030000o`3`oo00
l?o`03L0l?o`00<00?l00?ooo`3oool0A@3oool00`000000oooo0?ooo`0_
0?ooo`03003o003`oo00l?o`01<0l?o`0P000?lI0;3PiP030000o`3`oo00
l?o`03d0l?o`00<00?l00?ooo`3oool09P3oool008X0oooo00<000000?oo
o`3oool03@3oool00`00o`00l?o`0?3ol00H0?3ol0030000o`2`h>H0/>3V
0380/>3V00<0003o0?3ol03`oo00>03`oo000`00o`00oooo0?ooo`150?oo
o`030000003oool0oooo02l0oooo00<00?l00?3ol03`oo005@3`oo000`00
0?l0/>3V0;3PiP0E0;3PiP030000o`3`oo00l?o`03h0l?o`00<00?l00?oo
o`3oool09P3oool008X0oooo00<000000?ooo`3oool03@3oool00`00o`00
l?o`0?3ol00I0?3ol0030000o`2`h>H0/>3V0300/>3V00<0003o0?3ol03`
oo00>@3`oo000`00o`00oooo0?ooo`150?ooo`030000003oool0oooo02h0
oooo00<00?l00?3ol03`oo005`3`oo000`000?l0/>3V0;3PiP0C0;3PiP03
0000o`3`oo00l?o`03l0l?o`00<00?l00?ooo`3oool09P3oool008X0oooo
00<000000?ooo`3oool03@3oool00`00o`00l?o`0?3ol00I0?3ol0030000
o`2`h>H0/>3V02l0/>3V00<0003o0?3ol03`oo00>@3`oo000`00o`00oooo
0?ooo`160?ooo`030000003oool0oooo02h0oooo00<00?l00?3ol03`oo00
603`oo000`000?l0/>3V0;3PiP0B0;3PiP030000o`3`oo00l?o`03l0l?o`
00<00?l00?ooo`3oool09P3oool008X0oooo00<000000?ooo`3oool03@3o
ool00`00o`00l?o`0?3ol00J0?3ol0030000o`2`h>H0/>3V02d0/>3V00<0
003o0?3ol03`oo00>P3`oo000`00o`00oooo0?ooo`160?ooo`030000003o
ool0oooo02h0oooo00<00?l00?3ol03`oo006@3`oo020000oa40/>3V00<0
003o0?3ol03`oo00?`3`oo000`00o`00oooo0?ooo`0W0?ooo`00RP3oool0
0`000000oooo0?ooo`0<0?ooo`03003o003`oo00l?o`01`0l?o`00<0003o
0;3PiP2`h>H0;02`h>H00`000?l0l?o`0?3ol00i0?3ol003003o003oool0
oooo04L0oooo00<000000?ooo`3oool0;P3oool00`00o`00l?o`0?3ol00K
0?3ol0030000o`2`h>H0/>3V00d0/>3V00<0003o0?3ol03`oo00@03`oo00
0`00o`00oooo0?ooo`0W0?ooo`00RP3oool00`000000oooo0?ooo`0<0?oo
o`03003o003`oo00l?o`01d0l?o`00<0003o0;3PiP2`h>H0:P2`h>H00`00
0?l0l?o`0?3ol00j0?3ol003003o003oool0oooo04L0oooo00<000000?oo
o`3oool0;@3oool00`00o`00l?o`0?3ol00M0?3ol080003o3@2`h>H00`00
0?l0l?o`0?3ol0100?3ol003003o003oool0oooo02L0oooo002:0?ooo`03
0000003oool0oooo00`0oooo00<00?l00?3ol03`oo007P3`oo000`000?l0
/>3V0;3PiP0X0;3PiP030000o`3`oo00l?o`03/0l?o`00<00?l00?ooo`3o
ool0A`3oool00`000000oooo0?ooo`0]0?ooo`03003o003`oo00l?o`01l0
l?o`00<0003o0;3PiP2`h>H0202`h>H20000od<0l?o`00<00?l00?ooo`3o
ool09`3oool008X0oooo00<000000?ooo`3oool0303oool00`00o`00l?o`
0?3ol00O0?3ol0030000o`2`h>H0/>3V02L0/>3V00<0003o0?3ol03`oo00
>P3`oo000`00o`00oooo0?ooo`180?ooo`030000003oool0oooo02d0oooo
00<00?l00?3ol03`oo00803`oo020000o`H0/>3V0P000?m50?3ol003003o
003oool0oooo02L0oooo002:0?ooo`030000003oool0oooo00/0oooo00<0
0?l00?3ol03`oo00803`oo000`000?l0/>3V0;3PiP0V0;3PiP030000o`3`
oo00l?o`03/0l?o`00<00?l00?ooo`3oool0B03oool00`000000oooo0?oo
o`0]0?ooo`03003o003`oo00l?o`0280l?o`1P000?m60?3ol003003o003o
ool0oooo02P0oooo002:0?ooo`030000003oool0oooo00/0oooo00<00?l0
0?3ol03`oo008@3`oo000`000?l0/>3V0;3PiP0T0;3PiP030000o`3`oo00
l?o`03`0l?o`00<00?l00?ooo`3oool0B03oool00`000000oooo0?ooo`0/
0?ooo`03003o003`oo00l?o`06l0l?o`00<00?l00?ooo`3oool0:03oool0
08X0oooo00<000000?ooo`3oool02`3oool00`00o`00l?o`0?3ol00R0?3o
l080003o8`2`h>H00`000?l0l?o`0?3ol00l0?3ol003003o003oool0oooo
04T0oooo00<000000?ooo`3oool0;03oool00`00o`00l?o`0?3ol01_0?3o
l003003o003oool0oooo02P0oooo002:0?ooo`030000003oool0oooo00X0
oooo00<00?l00?3ol03`oo009@3`oo020000ob00/>3V00<0003o0?3ol03`
oo00?@3`oo000`00o`00oooo0?ooo`190?ooo`030000003oool0oooo02`0
oooo00<00?l00?3ol03`oo00K`3`oo000`00o`00oooo0?ooo`0X0?ooo`00
RP3oool00`000000oooo0?ooo`0:0?ooo`03003o003`oo00l?o`02L0l?o`
0P000?lM0;3PiP030000o`3`oo00l?o`03d0l?o`00<00?l00?ooo`3oool0
BP3oool00`000000oooo0?ooo`0/0?ooo`03003o003`oo00l?o`06h0l?o`
00<00?l00?ooo`3oool0:@3oool008X0oooo00<000000?ooo`3oool02@3o
ool00`00o`00l?o`0?3ol00Z0?3ol0030000o`2`h>H0/>3V01T0/>3V00<0
003o0?3ol03`oo00?P3`oo000`00o`00oooo0?ooo`1:0?ooo`030000003o
ool0oooo02/0oooo00<00?l00?3ol03`oo00K`3`oo000`00o`00oooo0?oo
o`0Y0?ooo`00RP3oool00`000000oooo0?ooo`090?ooo`03003o003`oo00
l?o`02/0l?o`0P000?lH0;3PiP030000o`3`oo00l?o`03l0l?o`00<00?l0
0?ooo`3oool0BP3oool00`000000oooo0?ooo`0[0?ooo`03003o003`oo00
l?o`06l0l?o`00<00?l00?ooo`3oool0:@3oool008X0oooo00<000000?oo
o`3oool02@3oool00`00o`00l?o`0?3ol00]0?3ol080003o5@2`h>H00`00
0?l0l?o`0?3ol00o0?3ol003003o003oool0oooo04/0oooo00<000000?oo
o`3oool0:`3oool00`00o`00l?o`0?3ol01_0?3ol003003o003oool0oooo
02T0oooo002:0?ooo`030000003oool0oooo00P0oooo00<00?l00?3ol03`
oo00<03`oo000`000?l0/>3V0;3PiP0A0;3PiP030000o`3`oo00l?o`0400
l?o`00<00?l00?ooo`3oool0B`3oool00`000000oooo0?ooo`0[0?ooo`03
003o003`oo00l?o`06h0l?o`00<00?l00?ooo`3oool0:P3oool008X0oooo
00<000000?ooo`3oool0203oool00`00o`00l?o`0?3ol00a0?3ol080003o
402`h>H00`000?l0l?o`0?3ol0110?3ol003003o003oool0oooo04/0oooo
00<000000?ooo`3oool0:P3oool00`00o`00l?o`0?3ol01_0?3ol003003o
003oool0oooo02X0oooo002:0?ooo`030000003oool0oooo00L0oooo00<0
0?l00?3ol03`oo00=03`oo020000o``0/>3V0P000?m30?3ol003003o003o
ool0oooo04`0oooo00<000000?ooo`3oool0:P3oool00`00o`00l?o`0?3o
l01_0?3ol003003o003oool0oooo02X0oooo002:0?ooo`030000003oool0
oooo00L0oooo00<00?l00?3ol03`oo00=P3`oo040000o`@0/>3V10000?m5
0?3ol003003o003oool0oooo04`0oooo00<000000?ooo`3oool0:@3oool0
0`00o`00l?o`0?3ol01`0?3ol003003o003oool0oooo02X0oooo002:0?oo
o`030000003oool0oooo00H0oooo00<00?l00?3ol03`oo00>`3`oo040000
odP0l?o`00<00?l00?ooo`3oool0C@3oool00`000000oooo0?ooo`0Y0?oo
o`03003o003`oo00l?o`0280l?o`0`0000030?3ol0030000003`oo00l?o`
04@0l?o`00<00?l00?ooo`3oool0:`3oool008X0oooo00<000000?ooo`3o
ool01P3oool00`00o`00l?o`0?3ol0270?3ol003003o003oool0oooo04d0
oooo00<000000?ooo`3oool0:03oool00`00o`00l?o`0?3ol00T0?3ol005
0000003`oo00l?o`0?3ol0000000A`3`oo000`00o`00oooo0?ooo`0[0?oo
o`00RP3oool00`000000oooo0?ooo`060?ooo`03003o003`oo00l?o`08L0
l?o`00<00?l00?ooo`3oool0C@3oool00`000000oooo0?ooo`0X0?ooo`03
003o003`oo00l?o`02@0l?o`00@000000?3ol03`oo000000B03`oo000`00
o`00oooo0?ooo`0[0?ooo`00RP3oool00`000000oooo0?ooo`050?ooo`03
003o003`oo00l?o`08L0l?o`00<00?l00?ooo`3oool0CP3oool00`000000
oooo0?ooo`0X0?ooo`03003o003`oo00l?o`02@0l?o`100000170?3ol003
003o003oool0oooo02`0oooo002:0?ooo`030000003oool0oooo00D0oooo
00<00?l00?3ol03`oo00Q`3`oo000`00o`00oooo0?ooo`1>0?ooo`030000
003oool0oooo02L0oooo00<00?l00?3ol03`oo009@3`oo001@000000l?o`
0?3ol03`oo00000004H0l?o`00<00?l00?ooo`3oool0;03oool008X0oooo
00<000000?ooo`3oool0103oool00`00o`00l?o`0?3ol0280?3ol003003o
003oool0oooo04h0oooo00<000000?ooo`3oool09`3oool00`00o`00l?o`
0?3ol00U0?3ol0050000003`oo00l?o`0?3ol0000000AP3`oo000`00o`00
oooo0?ooo`0/0?ooo`00RP3oool00`000000oooo0?ooo`040?ooo`03003o
003`oo00l?o`08L0l?o`00<00?l00?ooo`3oool0C`3oool00`000000oooo
0?ooo`0W0?ooo`03003o003`oo00l?o`02D0l?o`00D000000?3ol03`oo00
l?o`000000150?3ol003003o003oool0oooo02d0oooo002:0?ooo`030000
003oool0oooo00<0oooo00<00?l00?3ol03`oo00R03`oo000`00o`00oooo
0?ooo`1?0?ooo`030000003oool0oooo02H0oooo00<00?l00?3ol03`oo00
9@3`oo05000004H0l?o`00<00?l00?ooo`3oool0;@3oool008X0oooo00<0
00000?ooo`3oool00`3oool00`00o`00l?o`0?3ol0270?3ol003003o003`
oo00oooo0500oooo00<000000?ooo`3oool09P3oool00`00o`00l?o`0?3o
l01_0?3ol003003o003oool0oooo02h0oooo002:0?ooo`030000003oool0
oooo0080oooo00<00?l00?3ol03`oo00R03`oo000`00o`00oooo0?ooo`1@
0?ooo`030000003oool0oooo02H0oooo00<00?l00?3ol03`oo00K`3`oo00
0`00o`00oooo0?ooo`0^0?ooo`00RP3oool00`000000oooo0?ooo`020?oo
o`03003o003`oo00l?o`08P0l?o`00<00?l00?ooo`3oool0D03oool00`00
0000oooo0?ooo`0V0?ooo`03003o003`oo00l?o`06l0l?o`00<00?l00?oo
o`3oool0;P3oool008X0oooo00D000000?ooo`3oool0oooo003o002:0?3o
l003003o003oool0oooo0540oooo00<000000?ooo`3oool09P3oool00`00
o`00l?o`0?3ol01^0?3ol003003o003oool0oooo02l0oooo002:0?ooo`05
0000003oool0oooo0?ooo`00o`00RP3`oo000`00o`00oooo0?ooo`1A0?oo
o`030000003oool0oooo02H0oooo00<00?l00?3ol03`oo00KP3`oo000`00
o`00oooo0?ooo`0_0?ooo`00RP3oool010000000oooo0?ooo`00o`2;0?3o
l003003o003oool0oooo0540oooo00<000000?ooo`3oool09P3oool00`00
o`00l?o`0?3ol01^0?3ol003003o003oool0oooo02l0oooo002:0?ooo`04
0000003oool0oooo003o08X0l?o`00<00?l00?ooo`3oool0DP3oool00`00
0000oooo0?ooo`0V0?ooo`03003o003`oo00l?o`06d0l?o`00<00?l00?oo
o`3oool0<03oool008X0oooo00<000000?ooo`00o`00R`3`oo000`00o`00
oooo0?ooo`1B0?ooo`030000003oool0oooo02L0oooo00<00?l00?3ol03`
oo00K03`oo000`00o`00oooo0?ooo`0`0?ooo`00RP3oool00`000000oooo
003o002:0?3ol003003o003oool0oooo05<0oooo00<000000?ooo`3oool0
9`3oool00`00o`00l?o`0?3ol01[0?3ol003003o003oool0oooo0340oooo
002:0?ooo`0300000000o`00l?o`08X0l?o`00<00?l00?ooo`3oool0D`3o
ool00`000000oooo0?ooo`0W0?ooo`03003o003`oo00l?o`06/0l?o`00<0
0?l00?ooo`3oool0<@3oool008X0oooo00<00000003o003`oo00R@3`oo00
0`00o`00oooo0?ooo`1D0?ooo`030000003oool0oooo02L0oooo00<00?l0
0?3ol03`oo00J`3`oo000`00o`00oooo0?ooo`0a0?ooo`00RP3oool00`00
00000?l00?3ol00e0?3ol0@00000D03`oo000`00o`00oooo0?ooo`1D0?oo
o`030000003oool0oooo02L0oooo00<00?l00?3ol03`oo00JP3`oo000`00
o`00oooo0?ooo`0b0?ooo`00RP3oool00`00o`00l?o`0?3ol00f0?3ol004
0000003`oo00l?o`000004h0l?o`00<00?l00?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0X0?ooo`03003o003`oo00l?o`06T0l?o`00<00?l00?oo
o`3oool0<P3oool008X0oooo00<00?l00?3ol03`oo00=P3`oo001@000000
l?o`0?3ol03`oo00000004d0l?o`00<00?l00?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0X0?ooo`03003o003`oo00l?o`03X0l?o`0`00000[0?3o
l003003o003oool0oooo03<0oooo00290?ooo`03003o003`oo00l?o`03L0
l?o`00D000000?3ol03`oo00l?o`0000001<0?3ol003003o003oool0oooo
05H0oooo00<000000?ooo`3oool0:03oool00`00o`00l?o`0?3ol00m0?3o
l0030000003`oo00l?o`02P0l?o`00<00?l00?ooo`3oool0<`3oool008T0
oooo00<00?l00?3ol03`oo00=`3`oo001@000000l?o`0?3ol03`oo000000
04`0l?o`00<00?l00?ooo`3oool0EP3oool00`000000oooo0?ooo`0X0?oo
o`03003o003`oo00l?o`02<0l?o`0`0000030?3ol0030000003`oo00l?o`
00P0000000@0l?o`00000000000000000P3`oo04000000<0l?o`1000000S
0?3ol003003o003oool0oooo03<0oooo00290?ooo`03003o003`oo00l?o`
03L0l?o`00D000000?3ol03`oo00l?o`0000001;0?3ol003003o003oool0
oooo05L0oooo00<000000?ooo`3oool0:@3oool00`00o`00l?o`0?3ol00S
0?3ol0050000003`oo00l?o`0?3ol00000000P3`oo001@000000l?o`0?3o
l03`oo0000000080l?o`00D000000?3ol03`oo00l?o`000000020?3ol005
0000003`oo00l?o`0?3ol00000000P3`oo000`000000l?o`0?3ol00T0?3o
l003003o003oool0oooo03@0oooo00290?ooo`03003o003`oo00l?o`03L0
l?o`00@000000?3ol03`oo000000C03`oo000`00o`00oooo0?ooo`1G0?oo
o`030000003oool0oooo02T0oooo00<00?l00?3ol03`oo008`3`oo001000
0000l?o`0?3ol00000030?3ol0050000003`oo00l?o`0?3ol00000000P3`
oo001@000000l?o`0?3ol03`oo0000000080l?o`00D000000?3ol03`oo00
l?o`000000020?3ol0030000003`oo00l?o`02@0l?o`00<00?l00?ooo`3o
ool0=03oool008T0oooo00<00?l00?3ol03`oo00=P3`oo04000004`0l?o`
00<00?l00?ooo`3oool0F03oool00`000000oooo0?ooo`0Z0?ooo`03003o
003`oo00l?o`0280l?o`100000040?3ol0@000000P3`oo001@000000l?o`
0?3ol03`oo0000000080l?o`00D000000?3ol03`oo00l?o`000000020?3o
l0D000008@3`oo000`00o`00oooo0?ooo`0e0?ooo`00R@3oool00`00o`00
l?o`0?3ol0260?3ol003003o003oool0oooo05P0oooo00<000000?ooo`3o
ool0:P3oool00`00o`00l?o`0?3ol00R0?3ol0050000003`oo00l?o`0?3o
l00000000P3`oo001@000000l?o`0?3ol03`oo0000000080l?o`0P000002
0?3ol0040000003`oo00l?o`00000080l?o`0P0000020?3ol0050000003`
oo00l?o`0?3ol00000008@3`oo000`00o`00oooo0?ooo`0e0?ooo`00R@3o
ool00`00o`00l?o`0?3ol0250?3ol003003o003oool0oooo05T0oooo00<0
00000?ooo`3oool0:`3oool00`00o`00l?o`0?3ol00Q0?3ol0050000003`
oo00l?o`0?3ol00000000`3`oo0300000080l?o`0P0000000`3`oo000000
000000040?3ol080000000<0l?o`0000000000000P3`oo0300000240l?o`
00<00?l00?ooo`3oool0=P3oool008T0oooo00<00?l00?3ol03`oo00Q03`
oo000`00o`00oooo0?ooo`1J0?ooo`030000003oool0oooo02/0oooo00<0
0?l00?3ol03`oo008@3`oo001@000000l?o`0?3ol03`oo00000003`0l?o`
00<00?l00?ooo`3oool0=P3oool008T0oooo00<00?l00?3ol03`oo00P`3`
oo000`00o`00oooo0?ooo`1K0?ooo`030000003oool0oooo02/0oooo00<0
0?l00?3ol03`oo00803`oo05000003`0l?o`00<00?l00?ooo`3oool0=`3o
ool008T0oooo00<00?l00?3ol03`oo00P`3`oo000`00o`00oooo0?ooo`1K
0?ooo`030000003oool0oooo02`0oooo00<00?l00?3ol03`oo00H03`oo00
0`00o`00oooo0?ooo`0g0?ooo`00R@3oool00`00o`00l?o`0?3ol0220?3o
l003003o003oool0oooo05`0oooo00<000000?ooo`3oool0;03oool00`00
o`00l?o`0?3ol01O0?3ol003003o003oool0oooo03P0oooo00290?ooo`03
003o003`oo00l?o`0840l?o`00<00?l00?ooo`3oool0G@3oool00`000000
oooo0?ooo`0/0?ooo`03003o003`oo00l?o`05l0l?o`00<00?l00?ooo`3o
ool0>03oool008X0oooo00<00?l00?3ol03`oo00P03`oo000`00o`00oooo
0?ooo`1M0?ooo`030000003oool0oooo02`0oooo00<00?l00?3ol03`oo00
GP3`oo000`00o`00oooo0?ooo`0i0?ooo`00RP3oool00`00o`00l?o`0?3o
l01o0?3ol003003o003oool0oooo05h0oooo00<000000?ooo`3oool0;@3o
ool00`00o`00l?o`0?3ol01L0?3ol003003o003oool0oooo03X0oooo002:
0?ooo`0300000000o`00l?o`07h0l?o`00<00?l00?ooo`3oool0G`3oool0
0`000000oooo0?ooo`0]0?ooo`03003o003`oo00l?o`05`0l?o`00<00?l0
0?ooo`3oool0>P3oool008X0oooo00<00000003o003`oo00O@3`oo000`3o
ool00?l00?ooo`1P0?ooo`030000003oool0oooo02d0oooo00<00?l00?3o
l03`oo00F`3`oo000`00o`00oooo0?ooo`0k0?ooo`00RP3oool00`000000
oooo003o000e0?3ol0@000001@3`oo0300000080l?o`1`0000020?3ol0D0
000000<0l?o`0000000000000`0000001@3`oo000000000000000000l?o`
00<000007@3`oo000`3oool00?l00?ooo`1Q0?ooo`030000003oool0oooo
02h0oooo00<00?l00?3ol03`oo00FP3`oo000`00o`00oooo0?ooo`0k0?oo
o`00RP3oool00`000000oooo003o000f0?3ol0040000003`oo00l?o`0000
00<0l?o`00D000000?3ol03`oo00l?o`000000020?3ol0050000003`oo00
00000?3ol00000000P3`oo001@000000l?o`0?3ol03`oo00000000@0l?o`
00<000000?3ol03`oo000P3`oo001@000000l?o`0?3ol03`oo00000001d0
l?o`00<0oooo003o003oool0HP3oool00`000000oooo0?ooo`0^0?ooo`03
003o003`oo00l?o`05T0l?o`00<00?l00?ooo`3oool0?03oool008X0oooo
00@000000?ooo`3oool00?l0=@3`oo001@000000l?o`0?3ol03`oo000000
0080l?o`00D000000?3ol03`oo00l?o`000000020?3ol0050000003`oo00
00000?3ol00000000P3`oo001@000000l?o`0?3ol03`oo00000000@0l?o`
00<000000?3ol03`oo000P3`oo001@000000l?o`0?3ol03`oo00000001d0
l?o`00<00?l00?ooo`3oool0HP3oool00`000000oooo0?ooo`0_0?ooo`03
003o003`oo00l?o`05L0l?o`00<00?l00?ooo`3oool0?@3oool008X0oooo
00D000000?ooo`3oool0oooo003o000d0?3ol0050000003`oo00l?o`0?3o
l00000000P3`oo001@000000l?o`0?3ol03`oo0000000080l?o`00D00000
0?3ol0000000l?o`000000030?3ol0@00000103`oo000`000000l?o`0?3o
l0020?3ol0050000003`oo00l?o`0?3ol0000000703`oo000`00o`00oooo
0?ooo`1S0?ooo`030000003oool0oooo02l0oooo00<00?l00?3ol03`oo00
EP3`oo000`00o`00oooo0?ooo`0n0?ooo`00RP3oool00`000000oooo0?oo
o`020?ooo`03003o003`oo00l?o`0340l?o`00D000000?3ol03`oo00l?o`
000000020?3ol0050000003`oo00l?o`0?3ol00000000P3`oo001@000000
l?o`0000003`oo0000000080l?o`00D000000?3ol03`oo00l?o`00000004
0?3ol0030000003`oo00l?o`0080l?o`0P0000020?3ol0030000003`oo00
l?o`01T0l?o`00<0oooo003o003oool0I03oool00`000000oooo0?ooo`0`
0?ooo`03003o003`oo00l?o`05@0l?o`00<00?l00?ooo`3oool0?`3oool0
08X0oooo00<000000?ooo`3oool00P3oool00`3`oo000?l00?3ol00a0?3o
l0050000003`oo00l?o`0?3ol00000000`3`oo0300000080l?o`0`000000
0`3`oo0000000?3ol0030?3ol0<000000`3`oo03000000<0l?o`0P000000
0`3`oo0000000000000K0?3ol0030?ooo`00o`00oooo06D0oooo00<00000
0?ooo`3oool0<03oool00`00o`00l?o`0?3ol01D0?3ol003003o003oool0
oooo03l0oooo002:0?ooo`030000003oool0oooo00<0oooo00<0l?o`003o
003`oo00<03`oo0010000000l?o`0?3ol000000m0?3ol0030?ooo`00o`00
oooo06H0oooo00<000000?ooo`3oool0<@3oool00`00o`00l?o`0?3ol01B
0?3ol003003o003oool0oooo0400oooo002:0?ooo`030000003oool0oooo
00@0oooo00<00?l00?3ol03`oo00;P3`oo04000001/0l?o`00<000000?3o
l03`oo007`3`oo000`3oool00?l00?ooo`1W0?ooo`030000003oool0oooo
0340oooo00<00?l00?3ol03`oo00D@3`oo000`00o`00oooo0?ooo`110?oo
o`00RP3oool00`000000oooo0?ooo`050?ooo`03003o003`oo00l?o`06h0
l?o`00<00?l00?ooo`3oool0I`3oool00`000000oooo0?ooo`0b0?ooo`03
003o003`oo00l?o`04l0l?o`00<00?l00?ooo`3oool0@P3oool008X0oooo
00<000000?ooo`3oool01P3oool00`00o`00l?o`0?3ol01/0?3ol003003o
003oool0oooo06P0oooo00<000000?ooo`3oool0<P3oool00`00o`00l?o`
0?3ol01>0?3ol003003o003oool0oooo04<0oooo002:0?ooo`030000003o
ool0oooo00L0oooo00<00?l00?3ol03`oo00JP3`oo000`00o`00oooo0?oo
o`1Y0?ooo`030000003oool0oooo03<0oooo00<00?l00?3ol03`oo00C03`
oo000`00o`00oooo0?ooo`140?ooo`00RP3oool00`000000oooo0?ooo`08
0?ooo`03003o003`oo00l?o`06T0l?o`00<00?l00?ooo`3oool0J@3oool0
0`000000oooo0?ooo`0c0?ooo`03003o003`oo00l?o`04/0l?o`00<00?l0
0?ooo`3oool0A@3oool008X0oooo00<000000?ooo`3oool02@3oool00`00
o`00l?o`0?3ol01W0?3ol003003o003oool0oooo06X0oooo00<000000?oo
o`3oool0=03oool00`00o`00l?o`0?3ol0190?3ol003003o003oool0oooo
04H0oooo002:0?ooo`030000003oool0oooo00X0oooo0P00o`1V0?3ol003
003o003oool0oooo06/0oooo00<000000?ooo`3oool0=03oool00`00o`00
l?o`0?3ol0180?3ol003003o003oool0oooo04L0oooo002:0?ooo`030000
003oool0oooo00`0oooo00<00?l00?3ol03`oo00HP3`oo000`00o`00oooo
0?ooo`1/0?ooo`030000003oool0oooo03D0oooo00<00?l00?3ol03`oo00
AP3`oo000`00o`00oooo0?ooo`180?ooo`00RP3oool00`000000oooo0?oo
o`0=0?ooo`03003o003`oo00l?o`0600l?o`00<00?l00?ooo`3oool0K@3o
ool00`000000oooo0?ooo`0e0?ooo`03003o003`oo00l?o`04D0l?o`00<0
0?l00?ooo`3oool0B@3oool008X0oooo00<000000?ooo`3oool03P3oool2
003o05l0l?o`00<00?l00?ooo`3oool0KP3oool00`000000oooo0?ooo`0f
0?ooo`03003o003`oo00l?o`04<0l?o`00<00?l00?ooo`3oool0BP3oool0
08X0oooo00<000000?ooo`3oool0403oool00`00o`00l?o`0?3ol01K0?3o
l003003o003oool0oooo06l0oooo00<000000?ooo`3oool0=P3oool00`00
o`00l?o`0?3ol0120?3ol003003o003oool0oooo04/0oooo002:0?ooo`03
0000003oool0oooo0140oooo00<00?l00?3ol03`oo00FP3`oo000`00o`00
oooo0?ooo`1_0?ooo`030000003oool0oooo03L0oooo00<00?l00?3ol03`
oo00@03`oo000`00o`00oooo0?ooo`1<0?ooo`00RP3oool00`000000oooo
0?ooo`0B0?ooo`800?l0F@3`oo000`00o`00oooo0?ooo`1`0?ooo`030000
003oool0oooo03L0oooo00<00?l00?3ol03`oo00?`3`oo000`00o`00oooo
0?ooo`1=0?ooo`00RP3oool00`000000oooo0?ooo`0D0?ooo`03003o003`
oo00l?o`05D0l?o`00<00?l00?ooo`3oool0L@3oool00`000000oooo0?oo
o`0h0?ooo`03003o003`oo00l?o`03h0l?o`00<00?l00?ooo`3oool0C@3o
ool008X0oooo00<000000?ooo`3oool05@3oool2003o05@0l?o`00<00?l0
0?ooo`3oool0LP3oool00`000000oooo0?ooo`0h0?ooo`03003o003`oo00
l?o`03d0l?o`00<00?l00?ooo`3oool0CP3oool008X0oooo00<000000?oo
o`3oool05P3oool00`3`oo000?l00?3ol01A0?3ol003003o003oool0oooo
07<0oooo00<000000?ooo`3oool0>@3oool00`00o`00l?o`0?3ol00k0?3o
l003003o003oool0oooo04l0oooo002:0?ooo`030000003oool0oooo01P0
oooo0P00o`1?0?3ol003003o003oool0oooo07@0oooo00<000000?ooo`3o
ool0>@3oool00`00o`00l?o`0?3ol00j0?3ol003003o003oool0oooo0500
oooo002:0?ooo`030000003oool0oooo01T0oooo00<0l?o`003o003`oo00
C03`oo000`00o`00oooo0?ooo`1e0?ooo`030000003oool0oooo03X0oooo
00<00?l00?3ol03`oo00>03`oo000`00o`00oooo0?ooo`1A0?ooo`00RP3o
ool00`000000oooo0?ooo`0K0?ooo`03003o003`oo00l?o`04X0l?o`00<0
0?l00?ooo`3oool0M@3oool00`000000oooo0?ooo`0j0?ooo`03003o003`
oo00l?o`03L0l?o`00<00?l00?ooo`3oool0DP3oool008X0oooo00<00000
0?ooo`3oool0703oool2003o04T0l?o`00<00?l00?ooo`3oool0MP3oool0
0`000000oooo0?ooo`0k0?ooo`03003o003`oo00l?o`03D0l?o`00<00?l0
0?ooo`3oool0D`3oool008X0oooo00<000000?ooo`3oool07P3oool00`00
o`00l?o`0?3ol0150?3ol003003o003oool0oooo07L0oooo00<000000?oo
o`3oool0>`3oool00`00o`00l?o`0?3ol00d0?3ol003003o003oool0oooo
05@0oooo002:0?ooo`030000003oool0oooo01l0oooo0P00o`140?3ol003
003o003oool0oooo07P0oooo00<000000?ooo`3oool0?03oool00`00o`00
l?o`0?3ol00c0?3ol003003o003oool0oooo05@0oooo002:0?ooo`030000
003oool0oooo0240oooo0P00o`110?3ol003003o003oool0oooo07T0oooo
00<000000?ooo`3oool0?03oool00`00o`00l?o`0?3ol00b0?3ol003003o
003oool0oooo05D0oooo002:0?ooo`030000003oool0oooo02<0oooo0P00
o`0n0?3ol003003o003oool0oooo07X0oooo00<000000?ooo`3oool0?@3o
ool00`00o`00l?o`0?3ol00`0?3ol003003o003oool0oooo05H0oooo002:
0?ooo`030000003oool0oooo02D0oooo00<00?l00?3ol03`oo00>@3`oo02
003o07d0oooo00<000000?ooo`3oool0?P3oool00`00o`00l?o`0?3ol00^
0?3ol003003o003oool0oooo05L0oooo002:0?ooo`030000003oool0oooo
02H0oooo0P00o`0h0?3ol003003o003oool0oooo07d0oooo00<000000?oo
o`3oool0?P3oool00`00o`00l?o`0?3ol00]0?3ol003003o003oool0oooo
05P0oooo002:0?ooo`030000003oool0oooo02P0oooo0P00o`0e0?3ol003
003o003oool0oooo07h0oooo00<000000?ooo`3oool0?`3oool00`00o`00
l?o`0?3ol00[0?3ol003003o003oool0oooo05T0oooo002:0?ooo`030000
003oool0oooo02X0oooo00<00?l00?3ol03`oo00<@3`oo000`00o`00oooo
0?ooo`1o0?ooo`030000003oool0oooo0400oooo00<00?l00?3ol03`oo00
:@3`oo000`00o`00oooo0?ooo`1J0?ooo`00RP3oool00`000000oooo0?oo
o`0[0?ooo`800?l0;`3`oo02003o0880oooo00<000000?ooo`3oool0@03o
ool00`00o`00l?o`0?3ol00W0?3ol0800?l0G@3oool008X0oooo00<00000
0?ooo`3oool0;@3oool2003o02`0l?o`00<00?l00?ooo`3oool0PP3oool0
0`000000oooo0?ooo`110?ooo`03003o003`oo00l?o`02D0l?o`00<00?l0
0?ooo`3oool0G@3oool008X0oooo00<000000?ooo`3oool0;`3oool2003o
02T0l?o`00<00?l00?ooo`3oool0P`3oool00`000000oooo0?ooo`120?oo
o`03003o003`oo00l?o`02<0l?o`00<00?l00?ooo`3oool0GP3oool008X0
oooo00<000000?ooo`3oool0<@3oool00`00o`00l?o`0?3ol00T0?3ol080
0?l0QP3oool00`000000oooo0?ooo`130?ooo`03003o003`oo00l?o`0240
l?o`00<00?l00?ooo`3oool0G`3oool008X0oooo00<000000?ooo`3oool0
<P3oool2003o02<0l?o`00<00?l00?ooo`3oool0QP3oool00`000000oooo
0?ooo`140?ooo`800?l07`3`oo02003o0680oooo002:0?ooo`030000003o
ool0oooo03@0oooo0P00o`0O0?3ol0030?ooo`00o`00oooo08P0oooo00<0
00000?ooo`3oool0AP3oool00`00o`00l?o`0?3ol00K0?3ol003003o003o
ool0oooo0680oooo002:0?ooo`030000003oool0oooo03H0oooo0`00o`0J
0?3ol0030?ooo`00o`000?l008X0oooo00<000000?ooo`3oool0A`3oool0
0`00o`00l?o`0?3ol00H0?3ol0800?l0I@3oool008X0oooo00<000000?oo
o`3oool0>@3oool3003o01D0l?o`00<0oooo003o0000o`00S03oool00`00
0000oooo0?ooo`180?ooo`800?l05P3`oo02003o06L0oooo002:0?ooo`03
0000003oool0oooo03`0oooo0P00o`0A0?3ol0<00?l0SP3oool00`000000
oooo0?ooo`1:0?ooo`800?l04P3`oo02003o06T0oooo002:0?ooo`030000
003oool0oooo03h0oooo4@00o`2A0?ooo`030000003oool0oooo04`0oooo
0P00o`0<0?3ol0@00?l0J`3oool008X0oooo00<000000?ooo`3oool0h03o
ool00`000000oooo0?ooo`1>0?ooo``00?l0K`3oool008X0oooo00<00000
0?ooo`3oool0h03oool00`000000oooo0?ooo`390?ooo`00RP3oool00`00
0000oooo0?ooo`3P0?ooo`030000003oool0oooo0<T0oooo002:0?ooo`03
0000003oool0oooo0>00oooo00<000000?ooo`3oool0b@3oool008X0oooo
00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`390?ooo`00RP3o
ool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo0<T0oooo002:
0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0b@3oool0
0?l0ooooKP3oool00`000000oooo0?ooo`390?ooo`00o`3ooooo0?oooc/0
oooo003o0?ooool0oooo>`3oool00?l0ooooo`3ooolk0?ooo`00o`3ooooo
0?oooc/0oooo003o0?ooool0oooo>`3oool00?l0ooooo`3ooolk0?ooo`00
R03oool200000?l0oooo/03oool008T0oooo00<000000?ooo`3oool0o`3o
oon^0?ooo`00RP3oool00`000000oooo0?ooo`3o0?ooojd0oooo00290?oo
o`030000003oool000000>00oooo0P00003;0?ooo`00R03oool010000000
oooo0?ooo`00003P0?ooo`800000b`3oool008L0oooo0`0000000`3oool0
00000000003N0?ooo`040000003oool0oooo00000<X0oooo003o0?ooof/0
oooo0P0000020?ooo`800000b@3oool00?l0ooooo`3ooolk0?ooo`00o`3o
oooo0?oooc/0oooo003o0?ooool0oooo>`3oool00?l0ooooo`3ooolk0?oo
o`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{569, 293},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\tFigure 2.2",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  " maps ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " onto ",
  StyleBox["B",
    FontFamily->"Courier New"],
  ";  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  " maps ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " into ",
  StyleBox["R",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[TextData[{
  "    The inverse image of a point ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " is the set of all points ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " in",
  " ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " ",
  "such that  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  ".  The inverse image of a point may be one point, several points, or \
nothing at all.  If the last case occurs then the point ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " is not in the range of ",
  StyleBox["f",
    FontFamily->"Courier New"],
  ".  For example, if  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \[ImaginaryI]\ z\)\)]],
  ",  the inverse image of the point ",
  Cell[BoxData[
      \(\(-1\)\)]],
  " is the single point ",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  ", because  ",
  Cell[BoxData[
      \(w = \(f \((\[ImaginaryI])\) = \(\[ImaginaryI]\ \((\[ImaginaryI])\) = \
\(-1\)\)\)\)]],
  ",  and ",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  " is the only point that maps to ",
  Cell[BoxData[
      \(\(-1\)\)]],
  ".  In the case of  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^2\)\)]],
  ",  the inverse image of the point ",
  Cell[BoxData[
      \(\(-1\)\)]],
  " is the set ",
  Cell[BoxData[
      \({\[ImaginaryI], \(-\[ImaginaryI]\)}\)]],
  ".  You will learn in Chapter 5 that, if  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \[ExponentialE]\^z\)\)]],
  ",  the inverse image of the point ",
  StyleBox["0",
    FontFamily->"Courier New"],
  " is the empty set---there is no complex number ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " such that ",
  Cell[BoxData[
      \(\[ExponentialE]\^z = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "    The inverse image of a set of points, S, is the collection of all \
points in the domain that map into S.  If f maps ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " onto ",
  StyleBox["R",
    FontFamily->"Courier New"],
  " it is possible for the inverse image of ",
  StyleBox["R",
    FontFamily->"Courier New"],
  " to be function as well, but the original function must have a special \
property: a function ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is said to be one-to-one if it maps distinct points  ",
  Cell[BoxData[
      \(z\_1 \[NotEqual] z\_2\)]],
  "  onto distinct points  ",
  Cell[BoxData[
      \(f \((z\_1)\) \[NotEqual] f \((z\_2)\)\)]],
  ".  Many times an easy way to prove that a function ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is one-to-one is to suppose  ",
  Cell[BoxData[
      \(f \((z\_1)\) = f \((z\_2)\)\)]],
  ",  and from this assumption deduce that ",
  Cell[BoxData[
      \(z\_1\)]],
  " must equal ",
  Cell[BoxData[
      \(z\_2\)]],
  ".  Thus,  ",
  Cell[BoxData[
      \(f \((z)\) = \[ImaginaryI]\ z\)]],
  "  is one-to-one because if ",
  Cell[BoxData[
      \(f \((z\_1)\) = f \((z\_2)\)\)]],
  ",  then ",
  Cell[BoxData[
      \(\[ImaginaryI]\ z\_1 = \[ImaginaryI]\ z\_2\)]],
  ".  Dividing both sides of the last equation by ",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  " gives  ",
  Cell[BoxData[
      \(z\_1 = z\_2\)]],
  ".  Figure 2.3 illustrates the idea of a one-to-one function: distinct \
points get mapped to distinct points."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006F0000K2000`400?l0
0000o`00003oo`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00
o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?oo
o`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG
0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3o
oonG0?ooo`00o`3ooonG0?ooo`00P03oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo0:@0
oooo00<000000?ooo`3oool0K03oool00800oooo00<000000?ooo`3oool0
Y03oool00`000000oooo0?ooo`1/0?ooo`00P03oool00`000000oooo0?oo
o`2T0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0K03oool00800oooo00<000000?oo
o`3oool0Y03oool00`000000oooo0?ooo`1/0?ooo`00P03oool00`000000
oooo0?ooo`2T0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000
003oool0oooo02<0oooo0`00o`1n0?ooo`030000003oool0oooo06`0oooo
00200?ooo`030000003oool0oooo0280oooo1@00o`1m0?ooo`030000003o
ool0oooo06`0oooo00200?ooo`030000003oool0oooo0240oooo1`00o`1l
0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo
0240oooo1`00o`1l0?ooo`030000003oool0oooo06`0oooo00200?ooo`03
0000003oool0oooo0240oooo1`00o`1l0?ooo`030000003oool0oooo06`0
oooo00200?ooo`030000003oool0oooo0280oooo1@00o`00103oool00?l0
003o0000o`1i0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000
003oool0oooo02<0oooo0`00o`050?ooo`<00?l0MP3oool00`000000oooo
0?ooo`1/0?ooo`00P03oool00`000000oooo0?ooo`0^0?ooo`800?l0M03o
ool00`000000oooo0?ooo`1/0?ooo`00P03oool00`000000oooo0?ooo`0`
0?ooo`<00?l0L@3oool00`000000oooo0?ooo`1/0?ooo`00P03oool00`00
0000oooo0?ooo`0c0?ooo`800?l0K`3oool00`000000oooo0?ooo`1/0?oo
o`00P03oool00`000000oooo0?ooo`0e0?ooo`<00?l0K03oool00`000000
oooo0?ooo`0S0?ooo`<0003oAP3oool00800oooo00<000000?ooo`3oool0
>03oool3003o06T0oooo00<000000?ooo`3oool08P3oool50000odD0oooo
00200?ooo`030000003oool0oooo03/0oooo0P00o`1W0?ooo`030000003o
ool0oooo0240oooo1`000?m40?ooo`00P03oool00`000000oooo0?ooo`0m
0?ooo`<00?l0I03oool00`000000oooo0?ooo`0N0?ooo`X0003oA03oool0
0800oooo00<000000?ooo`3oool0@03oool2003o0680oooo00<000000?oo
o`3oool05@3ooolC0000od@0oooo00200?ooo`030000003oool0oooo0480
oooo0`00o`1O0?ooo`030000003oool0oooo01D0oooo4P000?m50?ooo`00
P03oool00`000000oooo0?ooo`150?ooo`800?l0G@3oool00`000000oooo
0?ooo`0F0?ooo`/0003o0P3oool30000odH0oooo00200?ooo`030000003o
ool0oooo04L0oooo0`00o`1J0?ooo`030000003oool0oooo01H0oooo2@00
0?m=0?ooo`00P03oool00`000000oooo0?ooo`1:0?ooo`<00?l0E`3oool0
0`000000oooo0?ooo`0E0?ooo`T0003oCP3oool00800oooo00<000000?oo
o`3oool0C@3oool2003o05D0oooo00<000000?ooo`3oool04P3oool30000
o`030?ooo`000?l0003o00@0003oD03oool00800oooo00<000000?ooo`3o
ool0C`3oool3003o0580oooo00<000000?ooo`3oool03`3oool30000o`D0
oooo0`000?mB0?ooo`00P03oool00`000000oooo0?ooo`1B0?ooo`800?l0
D03oool00`000000oooo0?ooo`0;0?ooo`@0003o203oool00`000?l0oooo
0?ooo`1B0?ooo`00P03oool00`000000oooo0?ooo`1D0?ooo`<00?l0C@3o
ool00`000000oooo0?ooo`080?ooo`<0003oH@3oool00800oooo00<00000
0?ooo`3oool0E`3oool3003o04X0oooo00<000000?ooo`3oool01@3oool3
0000of@0oooo00200?ooo`030000003oool0oooo05X0oooo0P00o`180?oo
o`030000003oool0oooo0080oooo0`000?mW0?ooo`00P03oool00`000000
oooo0?ooo`1L0?ooo`<00?l0A@3oool00`000000oooo0000o`020000ofX0
oooo00200?ooo`030000003oool0oooo05l0oooo0P00o`120?ooo`<0003o
K@3oool00800oooo00<000000?ooo`3oool0H@3oool3003o03`0oooo0`00
0?l00`3oool000000?ooo`1]0?ooo`00P03oool00`000000oooo0?ooo`1T
0?ooo`<00?l0=P3oool30000o`@0oooo00<000000?ooo`3oool0K03oool0
0800oooo00<000000?ooo`3oool0I`3oool2003o0340oooo0`000?l70?oo
o`030000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo06T0
oooo0`00o`0[0?ooo`<0003o2P3oool00`000000oooo0?ooo`1/0?ooo`00
P03oool00`000000oooo0?ooo`1/0?ooo`800?l09P3oool30000o`d0oooo
00<000000?ooo`3oool0K03oool00800oooo00<000000?ooo`3oool0DP3o
ool200000080oooo0P00000F0?ooo`<00?l0803oool30000oa00oooo00<0
00000?ooo`3oool0=`3oool2000000030?ooo`00000000000300oooo0020
0?ooo`030000003oool0oooo05<0oooo00@000000?ooo`3oool000006P3o
ool2003o01/0oooo0`000?lC0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool00P00000a0?ooo`00K03ooomT000000L0oooo0P00000M
0?ooo`<00?l05@0000030000odP000001`3oool01@000000oooo0?ooo`3o
ool000000340oooo00200?ooo`030000003oool0oooo05@0oooo0P00000P
0?ooo`<00?l03`3oool30000oaT0oooo00<000000?ooo`3oool0=P3oool0
1@000000oooo0?ooo`3oool000000340oooo00200?ooo`030000003oool0
oooo05<0oooo00@000000?ooo`3oool000008P3oool2003o00T0oooo1000
0?lL0?ooo`030000003oool0oooo03H0oooo00D000000?ooo`3oool0oooo
0000000a0?ooo`00P03oool00`000000oooo0?ooo`1B0?ooo`8000000P3o
ool2000002<0oooo0`00o`030?ooo`<0003o803oool00`000000oooo0?oo
o`0e0?ooo`8000000P3oool200000340oooo00200?ooo`030000003oool0
oooo07h0oooo0P00o`000`000?l0oooo0?ooo`0Q0?ooo`030000003oool0
oooo06`0oooo00200?ooo`030000003oool0oooo07/0oooo0`000?l20?oo
o`<00?l08@3oool00`000000oooo0?ooo`1/0?ooo`00P03oool00`000000
oooo0?ooo`1h0?ooo`<0003o203oool3003o01h0oooo00<000000?ooo`3o
ool0K03oool00800oooo00<000000?ooo`3oool0M@3oool30000o`h0oooo
0P00o`0L0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003o
ool0oooo0780oooo0`000?lC0?ooo`<00?l06@3oool00`000000oooo0?oo
o`1/0?ooo`00P03oool00`000000oooo0?ooo`1_0?ooo`<0003o6@3oool2
003o01L0oooo00<000000?ooo`3oool0K03oool00800oooo00<000000?oo
o`3oool0K03oool30000oah0oooo0`00o`0D0?ooo`030000003oool0oooo
06`0oooo00200?ooo`030000003oool0oooo06T0oooo0`000?lT0?ooo`<0
0?l04@3oool00`000000oooo0?ooo`1/0?ooo`00P03oool00`000000oooo
0?ooo`1V0?ooo`<0003o:P3oool2003o00l0oooo00<000000?ooo`3oool0
K03oool00800oooo00<000000?ooo`3oool0H`3oool30000obl0oooo0`00
o`0<0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003oool0
oooo0600oooo0`000?le0?ooo`800?l02P3oool00`000000oooo0?ooo`1/
0?ooo`00P03oool00`000000oooo0?ooo`1M0?ooo`<0003o>P3oool3003o
00L0oooo00<000000?ooo`3oool0K03oool00800oooo00<000000?ooo`3o
ool0FP3oool30000od00oooo0`00o`040?ooo`030000003oool0oooo06`0
oooo00200?ooo`030000003oool0oooo02<0oooo0`3o000`0?ooo`@0003o
AP3oool2003o0080oooo00<000000?ooo`3oool0K03oool00800oooo00<0
00000?ooo`3oool08P3oool50?l002`0oooo0`000?m<0?ooo`<00?l0KP3o
ool00800oooo00<000000?ooo`3oool08@3oool70?l002P0oooo0`000?mA
0?ooo`0300000000o`000?l006`0oooo00200?ooo`030000003oool0oooo
0240oooo2@3o000S0?ooo`<0003oE03oool00`000000oooo0?ooo`03003o
06T0oooo00200?ooo`030000003oool0oooo0240oooo1`3o00020?ooo``0
o`00503oool30000oeL0oooo00<000000?ooo`3oool00`3oool2003o00T0
oooo00<00?l00?ooo`3oool0F`3oool00800oooo00<000000?ooo`3oool0
8P3oool50?l000l0oooo303o00050?ooo`<0003oFP3oool00`000000oooo
0?ooo`050?ooo`<00?l01P3oool3003o05/0oooo00200?ooo`030000003o
ool0oooo02<0oooo0`3o000L0?ooo`80o`000`000?l70?l005H0oooo00<0
00000?ooo`3oool0203oool3003o0080oooo1@00o`1J0?ooo`00P03oool0
0`000000oooo0?ooo`110?ooo`<0003o2P3oool<0?l004X0oooo00<00000
0?ooo`3oool02`3oool9003o05P0oooo00200?ooo`030000003oool0oooo
03h0oooo0`000?lI0?ooo`/0o`009`3oool20?l001H0oooo00<000000?oo
o`3oool0303oool9003o05L0oooo00200?ooo`030000003oool0oooo03/0
oooo0`000?lW0?ooo``0o`006`3oool50?l001<0oooo00<000000?ooo`3o
ool0303oool:003o05H0oooo00200?ooo`030000003oool0oooo03P0oooo
0`000?lf0?ooo``0o`003`3oool70?l000H0oooo0`3o00080?ooo`030000
003oool0oooo00/0oooo3@00o`020?ooo`<00?l0C`3oool00800oooo00<0
00000?ooo`3oool0=@3oool30000odD0oooo303o00030?ooo`X0o`000P3o
ool50?l000L0oooo00<000000?ooo`3oool02`3ooolC003o04h0oooo0020
0?ooo`030000003oool0oooo0380oooo0`000?mD0?oooaD0o`001P3oool0
0`000000oooo0?ooo`0?0?oooa000?l0C@3oool00800oooo00<000000?oo
o`3oool0;`3oool30000oeT0oooo4`3o00060?ooo`030000003oool0oooo
01L0oooo2000o`1=0?ooo`00P03oool00`000000oooo0?ooo`0/0?ooo`<0
003oG03ooolC0?l000H0oooo00<000000?ooo`3oool0603oool7003o04d0
oooo00200?ooo`030000003oool0oooo02P0oooo10000?mO0?ooo`P0o`00
1@3oool50?l000L0oooo00<000000?ooo`3oool06@3oool5003o04h0oooo
00200?ooo`030000003oool0oooo02D0oooo0`000?mS0?ooo`<0o`002`3o
ool30?l000P0oooo00<000000?ooo`3oool06P3oool3003o04l0oooo0020
0?ooo`030000003oool0oooo0280oooo0`000?mo0?ooo`030000003oool0
oooo06`0oooo00200?ooo`030000003oool0oooo01l0oooo0`000?n20?oo
o`030000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo01`0
oooo0`000?n50?ooo`030000003oool0oooo06`0oooo00200?ooo`030000
003oool0oooo0100oooo0`000?l60?ooo`<0003oR03oool00`000000oooo
0?ooo`1/0?ooo`00P03oool00`000000oooo0?ooo`0?0?ooo`D0003o0P3o
ool30000oh/0oooo00<000000?ooo`3oool0K03oool00800oooo00<00000
0?ooo`3oool03P3oool80000ohh0oooo00<000000?ooo`3oool0K03oool0
0800oooo00<000000?ooo`3oool03P3oool70000ohl0oooo00<000000?oo
o`3oool0K03oool00940oooo1`000?on0?ooo`00OP3oool400000100oooo
1@000?oo0?ooo`00P03oool00`000000oooo0?ooo`0@0?ooo`<0003oo`3o
ool10?ooo`00P03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0
oooo06`0oooo00200?ooo`800000Y03oool00`000000oooo0000001]0?oo
o`00O`3oool00`000000oooo0000002T0?ooo`030000003oool0000006d0
oooo001o0?ooo`040000003oool0oooo00000:80oooo00D000000?ooo`3o
ool0oooo0000001/0?ooo`00OP3oool01@000000oooo0?ooo`3oool00000
0:80oooo00D000000?ooo`3oool0oooo0000001/0?ooo`00O@3oool30000
00040?ooo`000000000000000:00oooo0`000000103oool0000000000000
001[0?ooo`00o`3ooonG0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{406, 108},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\tFigure 2.3",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  A function  ",
  StyleBox["w = f(z)",
    FontFamily->"Courier New"],
  "  that is one-to-one. "
}], "Text"],

Cell[TextData[{
  "    The function  ",
  Cell[BoxData[
      \(f \((z)\) = z\^2\)]],
  "  is not one-to-one because ",
  Cell[BoxData[
      \(\(-\[ImaginaryI]\) \[NotEqual] \[ImaginaryI]\)]],
  ",  but  ",
  Cell[BoxData[
      \(f \((\[ImaginaryI])\) = \(f \((\(-\[ImaginaryI]\))\) = \(-1\)\)\)]],
  ".  Figure 2.4 depicts this situation: at least two different points get \
mapped to the same point. "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006F0000K2000`400?l0
0000o`00003oo`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00
o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?oo
o`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG
0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00YP3oool30000ond0oooo
002U0?ooo`D0003ok03oool00:@0oooo1`000?o[0?ooo`00P03oool00`00
0000oooo0?ooo`0Q0?ooo`L0003oO03oool00`000000oooo0?ooo`1/0?oo
o`00P03oool00`000000oooo0?ooo`0Q0?ooo`P0003oN`3oool00`000000
oooo0?ooo`1/0?ooo`00P03oool00`000000oooo0?ooo`0R0?ooo`D0003o
0P3oool30000ogP0oooo00<000000?ooo`3oool0K03oool00800oooo00<0
00000?ooo`3oool08`3oool30000o`H0oooo0`000?me0?ooo`030000003o
ool0oooo06`0oooo00200?ooo`030000003oool0oooo02l0oooo0`000?mb
0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo
0380oooo0`000?m_0?ooo`030000003oool0oooo06`0oooo00200?ooo`03
0000003oool0oooo03D0oooo0`000?m/0?ooo`030000003oool0oooo06`0
oooo00200?ooo`030000003oool0oooo03P0oooo0`000?mY0?ooo`030000
003oool0oooo06`0oooo00200?ooo`030000003oool0oooo03/0oooo0`00
0?mV0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003oool0
oooo03h0oooo0`000?mS0?ooo`030000003oool0oooo06`0oooo00200?oo
o`030000003oool0oooo0440oooo0`000?mP0?ooo`030000003oool0oooo
06`0oooo00200?ooo`030000003oool0oooo04@0oooo0`000?mM0?ooo`03
0000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo04L0oooo
0`000?mJ0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003o
ool0oooo04X0oooo0`000?mG0?ooo`030000003oool0oooo06`0oooo0020
0?ooo`030000003oool0oooo04d0oooo0`000?mD0?ooo`030000003oool0
oooo06`0oooo00200?ooo`030000003oool0oooo0500oooo0`000?mA0?oo
o`030000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo05<0
oooo0`000?m>0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000
003oool0oooo05H0oooo0`000?m;0?ooo`030000003oool0oooo06`0oooo
00200?ooo`030000003oool0oooo05T0oooo0`000?m80?ooo`030000003o
ool0oooo06`0oooo00200?ooo`030000003oool0oooo05`0oooo0P000?m6
0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo
05h0oooo0`000?m30?ooo`030000003oool0oooo06`0oooo00200?ooo`03
0000003oool0oooo0640oooo0`000?m00?ooo`030000003oool0oooo06`0
oooo00200?ooo`030000003oool0oooo06@0oooo0`000?lm0?ooo`030000
003oool0oooo06`0oooo00200?ooo`030000003oool0oooo06L0oooo0`00
0?lj0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003oool0
oooo06X0oooo0`000?lg0?ooo`030000003oool0oooo06`0oooo00200?oo
o`030000003oool0oooo06d0oooo0`000?ld0?ooo`030000003oool0oooo
06`0oooo00200?ooo`030000003oool0oooo0700oooo0`000?la0?ooo`03
0000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo07<0oooo
0`000?l^0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003o
ool0oooo07H0oooo0`000?l[0?ooo`030000003oool0oooo06`0oooo0020
0?ooo`030000003oool0oooo07T0oooo0`000?lX0?ooo`030000003oool0
oooo06`0oooo00200?ooo`030000003oool0oooo07`0oooo0`000?lU0?oo
o`030000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo07l0
oooo0`000?l90?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3o
ool0K03oool00800oooo00<000000?ooo`3oool0PP3oool30000o`H0oooo
0`000?lF0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003o
ool0oooo08D0oooo0`000?l20?ooo`H0003o503oool00`000000oooo0?oo
o`1/0?ooo`00P03oool00`000000oooo0?ooo`280?ooo`T0003o4`3oool0
0`000000oooo0?ooo`1/0?ooo`00P03oool00`000000oooo0?ooo`2:0?oo
o`T0003o4@3oool00`000000oooo0?ooo`1/0?ooo`00P03oool00`000000
oooo0?ooo`2:0?ooo`X0003o403oool00`000000oooo0?ooo`1/0?ooo`00
P03oool00`000000oooo0?ooo`290?ooo`d0003o3P3oool00`000000oooo
0?ooo`1/0?ooo`00P03oool00`000000oooo0?ooo`290?ooo`l0003o00@0
oooo003o0000o`000?l0203oool00`000000oooo0?ooo`1/0?ooo`00P03o
ool00`000000oooo0?ooo`1B0?ooo`8000000P3oool2000003T0oooo1`00
0?l5003o00L0oooo00<000000?ooo`3oool0=`3oool2000000030?ooo`00
000000000300oooo00200?ooo`030000003oool0oooo05<0oooo00@00000
0?ooo`3oool00000@03oool7003o00H0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0200000340oooo001/0?ooof@000001`3oool2
000001d0oooo90000007003o03P000001`3oool01@000000oooo0?ooo`3o
ool000000340oooo00200?ooo`030000003oool0oooo05@0oooo0P00000k
0?ooo`H0o`001`00o`060?ooo`030000003oool0oooo03H0oooo00D00000
0?ooo`3oool0oooo0000000a0?ooo`00P03oool00`000000oooo0?ooo`1C
0?ooo`040000003oool0oooo00000380oooo3`3o0005003o00L0oooo00<0
00000?ooo`3oool0=P3oool01@000000oooo0?ooo`3oool000000340oooo
00200?ooo`030000003oool0oooo0580oooo0P0000020?ooo`800000<@3o
ool=0?l000<0oooo0`00o`080?ooo`030000003oool0oooo03D0oooo0P00
00020?ooo`800000<@3oool00800oooo00<000000?ooo`3oool0RP3oool:
0?l00100oooo00<000000?ooo`3oool0K03oool00800oooo00<000000?oo
o`3oool0RP3oool90?l00140oooo00<000000?ooo`3oool0K03oool00800
oooo00<000000?ooo`3oool0R03oool90?l001<0oooo00<000000?ooo`3o
ool0K03oool00800oooo00<000000?ooo`3oool0Q@3oool30?l00080oooo
1P3o000D0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003o
ool0oooo0880oooo0`3o00060?ooo`<0o`005P3oool00`000000oooo0?oo
o`1/0?ooo`00P03oool00`000000oooo0?ooo`1o0?ooo`<0o`002@3oool0
0`3o0000oooo0?ooo`0F0?ooo`030000003oool0oooo06`0oooo00200?oo
o`030000003oool0oooo07`0oooo0`3o000U0?ooo`030000003oool0oooo
06`0oooo00200?ooo`030000003oool0oooo07T0oooo0`3o000X0?ooo`03
0000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo07H0oooo
0`3o000[0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003o
ool0oooo07<0oooo0`3o000^0?ooo`030000003oool0oooo06`0oooo0020
0?ooo`030000003oool0oooo0700oooo0`3o000a0?ooo`030000003oool0
oooo06`0oooo00200?ooo`030000003oool0oooo06d0oooo0`3o000d0?oo
o`030000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo06X0
oooo0`3o000g0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000
003oool0oooo06L0oooo0`3o000j0?ooo`030000003oool0oooo06`0oooo
00200?ooo`030000003oool0oooo06@0oooo0`3o000m0?ooo`030000003o
ool0oooo06`0oooo00200?ooo`030000003oool0oooo0640oooo0`3o0010
0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo
05l0oooo0P3o00130?ooo`030000003oool0oooo06`0oooo00200?ooo`03
0000003oool0oooo05`0oooo0`3o00150?ooo`030000003oool0oooo06`0
oooo00200?ooo`030000003oool0oooo05T0oooo0`3o00180?ooo`030000
003oool0oooo06`0oooo00200?ooo`030000003oool0oooo05H0oooo0`3o
001;0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003oool0
oooo05<0oooo0`3o001>0?ooo`030000003oool0oooo06`0oooo00200?oo
o`030000003oool0oooo0500oooo0`3o001A0?ooo`030000003oool0oooo
06`0oooo00200?ooo`030000003oool0oooo04d0oooo0`3o001D0?ooo`03
0000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo04X0oooo
0`3o001G0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003o
ool0oooo04L0oooo0`3o001J0?ooo`030000003oool0oooo06`0oooo0020
0?ooo`030000003oool0oooo04@0oooo0`3o001M0?ooo`030000003oool0
oooo06`0oooo00200?ooo`030000003oool0oooo0440oooo0`3o001P0?oo
o`030000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo03h0
oooo0`3o001S0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000
003oool0oooo03/0oooo0`3o001V0?ooo`030000003oool0oooo06`0oooo
00200?ooo`030000003oool0oooo03P0oooo0`3o001Y0?ooo`030000003o
ool0oooo06`0oooo00200?ooo`030000003oool0oooo03D0oooo0`3o001/
0?ooo`030000003oool0oooo06`0oooo00200?ooo`030000003oool0oooo
0380oooo0`3o001_0?ooo`030000003oool0oooo06`0oooo00200?ooo`03
0000003oool0oooo02l0oooo0`3o001b0?ooo`030000003oool0oooo06`0
oooo00200?ooo`030000003oool0oooo02<0oooo0`3o00060?ooo`<0o`00
M@3oool00`000000oooo0?ooo`1/0?ooo`00P03oool00`000000oooo0?oo
o`0R0?ooo`D0o`000P3oool30?l007P0oooo00<000000?ooo`3oool0K03o
ool00800oooo00<000000?ooo`3oool08@3oool80?l007/0oooo00<00000
0?ooo`3oool0K03oool00800oooo00<000000?ooo`3oool08@3oool70?l0
07`0oooo00<000000?ooo`3oool0K03oool00:@0oooo1`3o003[0?ooo`00
OP3oool4000002<0oooo1@3o003/0?ooo`00P03oool00`000000oooo0?oo
o`0S0?ooo`<0o`00k@3oool00800oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`1/0?ooo`00P03oool200000:@0oooo00<000000?oo
o`000000K@3oool007l0oooo00<000000?ooo`000000Y03oool00`000000
oooo0000001]0?ooo`00O`3oool010000000oooo0?ooo`00002R0?ooo`05
0000003oool0oooo0?ooo`000000K03oool007h0oooo00D000000?ooo`3o
ool0oooo0000002R0?ooo`050000003oool0oooo0?ooo`000000K03oool0
07d0oooo0`000000103oool0000000000000002P0?ooo`<0000000@0oooo
0000000000000000J`3oool00?l0ooooU`3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{406, 108},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\tFigure 2.4",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  A function that is not one-to-one."
}], "Text"],

Cell[TextData[{
  "\tIn the exercises we ask you to demonstrate that one-to-one functions \
give rise to inverses that are functions.  Loosely speaking, if  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  maps the set ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " one-to-one and onto the set ",
  StyleBox["B",
    FontFamily->"Courier New"],
  ", then for each ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " in ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " there exists exactly one point ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " in ",
  StyleBox["A",
    FontFamily->"Courier New"],
  "  A such that  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  ".  For any such value of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " we can take the equation  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  and \"solve\" for ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " as a function of ",
  StyleBox["w",
    FontFamily->"Courier New"],
  ".  Doing so produces an inverse function  ",
  Cell[BoxData[
      \(z = g \((w)\)\)]],
  "  where the following equations hold:  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{\(g \((f \((z)\))\)\), "=", 
            RowBox[{
              RowBox[{"z", "   ", 
                StyleBox["for",
                  FontFamily->"Times New Roman"], 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox["all",
                  FontFamily->"Times New Roman"], "  ", "z"}], "\[Element]", 
              "A"}]}], ",", "  ", 
          StyleBox["and",
            FontFamily->"Times New Roman"]}], "\n"}], "\[IndentingNewLine]", 
      RowBox[{\(f \((g \((w)\))\)\), "=", 
        RowBox[{
          RowBox[{"w", "   ", 
            StyleBox["for",
              FontFamily->"Times New Roman"], 
            StyleBox[" ",
              FontFamily->"Times New Roman"], 
            StyleBox["all",
              FontFamily->"Times New Roman"], "  ", "z"}], "\[Element]", 
          "B"}]}]}]],
  "   \n\n\tConversely, if ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  " and ",
  Cell[BoxData[
      \(z = g \((w)\)\)]],
  " are functions that map ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " into ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " into ",
  StyleBox["A",
    FontFamily->"Courier New"],
  ", respectively, and the above hold, then f maps the set ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " one-to-one and onto the set ",
  StyleBox["B",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  "\tFurther, if f is a one-to-one mapping from ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " onto ",
  StyleBox["T",
    FontFamily->"Courier New"],
  " and if ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " is a subset of ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", then f is a one-to-one mapping from ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " onto its image ",
  StyleBox["B",
    FontFamily->"Courier New"],
  ".  We can also show that, if  ",
  Cell[BoxData[
      \(\[Zeta] = f \((z)\)\)]],
  "  is a one-to-one mapping from ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " onto ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " and  ",
  Cell[BoxData[
      \(w = g \((\[Zeta])\)\)]],
  "  is a one-to-one mapping from ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " onto ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ", then the composite mapping  ",
  Cell[BoxData[
      \(w = g \((f \((z)\))\)\)]],
  "  is a one-to-one mapping from ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " onto ",
  StyleBox["S",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe usually indicate the inverse of ",
  Cell[BoxData[
      \(f\)]],
  " by the symbol ",
  Cell[BoxData[
      \(f\^\(-1\)\)]],
  ".  If the domains of ",
  Cell[BoxData[
      \(f\)]],
  " and ",
  Cell[BoxData[
      \(f\^\(-1\)\)]],
  " are ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " respectively, then we write  \n\t\n\t\t\t",
  Cell[BoxData[
      \(\(f\^\(-1\)\) \((f \((z)\))\)\  = \ z\)]],
  "   for all  ",
  Cell[BoxData[
      \(z\  \[Element] \ A\)]],
  ",  and  \n\t\t\n\t\t\t",
  Cell[BoxData[
      \(f \((\(f\^\(-1\)\) \((w)\))\)\  = \ w\)]],
  "   for all  ",
  Cell[BoxData[
      \(w\  \[Element] \ B\)]],
  ".  \n\t\t\nAlso, for  ",
  Cell[BoxData[
      \(z\_0\  \[Element] \ A\)]],
  "  and  ",
  Cell[BoxData[
      \(w\_0\  \[Element] \ B\)]],
  ".     \n\n\t\t\t",
  Cell[BoxData[
      \(w\_0 = f \((z\_0)\)\)]],
  "   iff   ",
  Cell[BoxData[
      \(\(f\^\(-1\)\) \((w\_0)\) = z\_0\)]],
  ",    and \n\n\t\t\t",
  Cell[BoxData[
      \(z\_0 = \(f\^\(-1\)\) \((w\_0)\)\)]],
  "   iff   ",
  Cell[BoxData[
      \(f \((z\_0)\) = w\_0\)]],
  ".   "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 2.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  If  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \[ImaginaryI]\ z\)\)]],
  "  for any complex number z, find  ",
  Cell[BoxData[
      \(\(f\^\(-1\)\) \((w)\)\)]],
  ". \n\nSolution.  We can easily show ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is one-to-one and onto the entire complex plane. We solve for ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ", given  ",
  Cell[BoxData[
      \(w = \(\(f \((z)\)\)\(=\)\(\[ImaginaryI]\)\(\ \)\)\)]],
  ",  to get  ",
  Cell[BoxData[
      \(z = \(w\/\[ImaginaryI] = \(-\[ImaginaryI]\)\ w\)\)]],
  ".  This result implies that ",
  Cell[BoxData[
      \(\(f\^\(-1\)\) \((w)\) = \(-\[ImaginaryI]\)\ w\)]],
  "  for all complex numbers ",
  StyleBox["w",
    FontFamily->"Courier New"],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Once we have specified  ",
  Cell[BoxData[
      \(\(f\^\(-1\)\) \((w)\) = \(-\[ImaginaryI]\)\ w\)]],
  "  for all complex numbers ",
  StyleBox["w",
    FontFamily->"Courier New"],
  ", we note that there is nothing magical about the symbol ",
  StyleBox["w",
    FontFamily->"Courier New"],
  ".  We could just as easily write  ",
  Cell[BoxData[
      \(\(f\^\(-1\)\) \((z)\) = \(-\[ImaginaryI]\)\ z\)]],
  "  for all complex numbers ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[z_] = \[ImaginaryI]\ z;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[w == f[z], z];\)\ \), "\[IndentingNewLine]", 
    \(\(g[w_] = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = f[z] = \>", f[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<z = \!\(f\^\(-1\)\)[w] = \>\"", 
        g[w]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(f\^\(-1\)\)[f[z]] = -\[ImaginaryI](\>\"", 
        f[z], "\<)\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(f\^\(-1\)\)[f[z]] = \>\"", 
        g[f[z]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(f\^\(-1\)\)[w]] = \[ImaginaryI](\>\"", 
        g[w], "\<)\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(f\^\(-1\)\)[w]] = \>\"", 
        f[g[w]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell["\<\
\tWe now show how to find the image B of a specified set A under a given \
mapping u+iv=w=f(z). The set A is usually described with an equation or \
inequality involving x and y. Using inverse functions, we can construct a \
chain of equivalent statements leading to a description of the set B in terms \
of an equation or an inequality involving u and v.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 2.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the function  ",
  Cell[BoxData[
      \(f[z] = \[ImaginaryI]\ z\)]],
  "  maps the line  ",
  Cell[BoxData[
      \(y = x + 1\)]],
  "  in the ",
  StyleBox["xy",
    FontFamily->"Courier New"],
  " plane onto the line  ",
  Cell[BoxData[
      \(v = \(-\ u\) - 1\)]],
  "  in the w plane.  \n\nSolution.  Method 1:  With  ",
  Cell[BoxData[
      \(A = {\((x, y)\) : \ y = x + 1}\)]],
  ",  we want to describe  ",
  Cell[BoxData[
      \(B = f \((A)\)\)]],
  ".  We let  ",
  Cell[BoxData[
      \(z = x + \[ImaginaryI]\ y\  \[Element] \ A\)]],
  "  and get  \n\n\t\t\t",
  Cell[BoxData[{
      \(u + \[ImaginaryI]\ v = \(w = f \((z)\) \[Element] \ B\)\), "\n", 
      \(\(\(\[DoubleLongLeftRightArrow]\)\(\ \)\(f\^\(-1\)\)\) \((w)\) = \(z \
= x + \[ImaginaryI]\ y\  \[Element] \ A\)\), "\n", 
      \(\(\(\[DoubleLongLeftRightArrow]\)\(\ \ \)\(\[ImaginaryI]\)\)\ w\  \
\[Element] \ A\), "\n", 
      \(\(\(\[DoubleLongLeftRightArrow]\)\(\ \ \)\(v\)\) - \[ImaginaryI]\ u\  \
\[Element] \ A\), "\n", 
      \(\(\(\[DoubleLongLeftRightArrow]\)\(\ \ \)\((v, \(-u\))\)\) \[Element] \
\ A\), "\n", 
      \(\(\(\[DoubleLongLeftRightArrow]\)\(\ \ \)\(u\)\)\  = \ v + 1\), 
    "\n", 
      \(\(\(\[DoubleLongLeftRightArrow]\)\(\ \ \)\(v\)\)\  = \ \(-u\) - 
          1\)}]],
  "  \n\nwhere ",
  Cell[BoxData[
      \(\[DoubleLongLeftRightArrow]\)]],
  " is the notation for \"if and only if.\"  Note what this result says:  ",
  Cell[BoxData[
      \(u + \[ImaginaryI]\ v = \(w \[Element] \ 
            B\ \[DoubleLongLeftRightArrow]\ \ v = \(-u\) - 1\)\)]],
  ". The image of ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " under ",
  StyleBox["f",
    FontFamily->"Courier New"],
  ", therefore, is the set  ",
  Cell[BoxData[
      \(B = {\((u, v)\) : \ v = \(-u\) - 1}\)]],
  ".  \n\nMethod 2:  We write  ",
  Cell[BoxData[
      \(u + \[ImaginaryI]\ v = \(w = \(f \((z)\) = \(\[ImaginaryI] \((x + \
\[ImaginaryI]\ y)\) = \(-\ y\) + \[ImaginaryI]\ x\)\)\)\)]],
  "  and note that the transformation can be given by the equations  ",
  Cell[BoxData[
      RowBox[{"u", "=", 
        RowBox[{
          RowBox[{\(-y\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "v"}], "=", "x"}]}]]],
  ".  Because ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " is described by  ",
  Cell[BoxData[
      \(A = {x + \[ImaginaryI]\ \(y : \ y\) = x + 1}\)]],
  ",  we can substitute  ",
  Cell[BoxData[
      RowBox[{"u", "=", 
        RowBox[{
          RowBox[{\(-y\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "v"}], "=", "x"}]}]]],
  "  into the equation  ",
  Cell[BoxData[
      \(y = x + 1\)]],
  "  to obtain  ",
  Cell[BoxData[
      \(\(-u\) = v + 1\)]],
  ",  which we can rewrite as  ",
  Cell[BoxData[
      \(v = \(-u\) - 1\)]],
  ".  If you use this method, be sure to pay careful attention to domains and \
ranges. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(w = \(f[z] = \[ImaginaryI]\ z\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[eq1, eq2, eq3, f, solset, u, v];\)\ \), "\[IndentingNewLine]", 
    \(\(TagSet[x, Im[x], 0];\)\ \), "\n", 
    \(\(TagSet[y, Im[y], 0];\)\ \), "\n", 
    \(\(TagSet[x, Re[x], x];\)\ \), "\n", 
    \(\(TagSet[y, Re[y], y];\)\ \), "\n", 
    \(\(f[z_] := \[ImaginaryI]\ z;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    f[\>", z, "\<] = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[\>", x\  + \ \[ImaginaryI]\ y, "\<] = \>", 
        f[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[\>", x\  + \ \[ImaginaryI]\ y, "\<] = \>", 
        Expand[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Form the line  ",
  Cell[BoxData[
      \(y = x + 1\)]],
  "  and its image."
}], "Text"],

Cell[BoxData[{
    \(\(eq1 = 
        u \[Equal] ComplexExpand[Re[f[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(eq2 = 
        v \[Equal] ComplexExpand[Im[f[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(eq3 = y \[Equal] x\  + \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(sol1 = Solve[eq1, y];\)\ \), "\[IndentingNewLine]", 
    \(\(sol2 = Solve[eq2, x];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u + \[ImaginaryI] v = \>", 
        Expand[f[x + \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u = \>", 
        ComplexExpand[
          Re[f[x + \[ImaginaryI]\ y]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v = \>", 
        ComplexExpand[
          Im[f[x + \[ImaginaryI]\ y]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[sol1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[sol2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(eq4 = 
        Eliminate[{eq1, eq2, eq3}, {x, y}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<In the z-plane.\>"];\)\ \), "\n", 
    \(\(Print[eq3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        ReplaceAll[
          eq3, {sol1\_\(\(\[LeftDoubleBracket]\)\(1, 1\)\(\
\[RightDoubleBracket]\)\), 
            sol2\_\(\(\[LeftDoubleBracket]\)\(1, 1\)\(\[RightDoubleBracket]\)\
\)}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<In the w-plane.\>"];\)\ \), "\n", 
    \(\(Print[eq4];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Plot the mapping  ",
  Cell[BoxData[
      \(w = \(f[z] = \[ImaginaryI]\ z\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ImplicitPlot`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ImplicitPlot[eq3, {x, \(-2\), 2}, {y, \(-2\), 2}, 
        PlotStyle \[Rule] 
          Magenta, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 6, 1], 
            Range[\(-3\), 4, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The line in the z-plane,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eq3];\)\ \), "\[IndentingNewLine]", 
    \(\(ImplicitPlot[eq4, {u, \(-2\), 2}, {v, \(-2\), 2}, 
        PlotStyle \[Rule] 
          Magenta, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 6, 1], 
            Range[\(-3\), 4, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image line in the w-plane,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[eq4];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping w = f[z] = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We see that he transformation  ",
  Cell[BoxData[
      \(w = \(f[z] = \[ImaginaryI]\ z\)\)]],
  "  maps the line  ",
  Cell[BoxData[
      \(y = x + 1\)]],
  "  onto the line  ",
  Cell[BoxData[
      \(v = \(-\ u\) - 1\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\tWe now look at some elementary mappings.  If we let  ",
  Cell[BoxData[
      \(B = a + \[ImaginaryI]b\)]],
  "  denote a fixed complex constant, the transformation  \n\n\t\t\t",
  Cell[BoxData[
      \(w = \(T \((z)\) = \(z + B = 
            x + a + \[ImaginaryI] \((y + b)\)\)\)\)]],
  "  \n\nis a one-to-one mapping of the z-plane onto the w-plane and is \
called a ",
  ButtonBox["translation",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Translation.html"], None},
    ButtonStyle->"Hyperlink"],
  ".  This transformation can be visualized as a rigid translation whereby \
the point  z  is displaced through the vector  ",
  Cell[BoxData[
      \(B = a + \[ImaginaryI]b\)]],
  "  to its new position  ",
  Cell[BoxData[
      \(w = T \((z)\)\)]],
  ".  The inverse mapping is given by  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(z = \(\(T\^\(-1\)\) \((w)\) = \(w - B = 
            u - a + \[ImaginaryI] \((v - b)\)\)\)\)\)\)]],
  "  \n\nand shows that  T  is a one-to-one mapping from the z-plane onto the \
w-plane. The effect of a translation is depicted in Figure 2.5."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009G0000hb000`400?l0
0000o`00003oo`3ooooo0?oooeT0oooo003o0?ooool0ooooF@3oool00?l0
ooooo`3ooomI0?ooo`00o`3ooooo0?oooeT0oooo003o0?ooool0ooooF@3o
ool00?l0ooooo`3ooomI0?ooo`00o`3ooooo0?oooeT0oooo003o0?ooool0
ooooF@3oool00?l0ooooo`3ooomI0?ooo`00o`3ooooo0?oooeT0oooo003o
0?ooool0ooooF@3oool00?l0ooooB`3oool2000000030?ooo`0000000000
0?@0oooo1000000@0?ooo`00OP3oooo6000000L0oooo00<000000?ooo`00
00009`3oooo6000000L0oooo00@000000?ooo`3oool000004@3oool007h0
oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo0<X0oooo00@000000?ooo`3oool000004@3oool007h0
oooo00<000000?ooo`3oool0b@3oool2000000030?ooo`000000000002H0
oooo00<000000?ooo`3oool0b@3oool2000000030?ooo`00000000000140
oooo001n0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool0
g`3oool007h0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?oo
o`3O0?ooo`00OP3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0
oooo0=l0oooo001n0?ooo`030000003oool0oooo0?@0oooo00<000000?oo
o`3oool0g`3oool007h0oooo00<000000?ooo`3oool0m03oool00`000000
oooo0?ooo`3O0?ooo`00OP3oool00`000000oooo0?ooo`3d0?ooo`030000
003oool0oooo0=l0oooo001n0?ooo`030000003oool0oooo0?@0oooo00<0
00000?ooo`3oool0g`3oool007h0oooo00<000000?ooo`3oool0m03oool0
0`000000oooo0?ooo`3O0?ooo`00OP3oool00`000000oooo0?ooo`3d0?oo
o`030000003oool0oooo0=l0oooo001n0?ooo`030000003oool0oooo0?@0
oooo00<000000?ooo`3oool0g`3oool007h0oooo00<000000?ooo`3oool0
m03oool00`000000oooo0?ooo`3O0?ooo`00OP3oool00`000000oooo0?oo
o`3d0?ooo`030000003oool0oooo0=l0oooo001n0?ooo`030000003oool0
oooo0?@0oooo00<000000?ooo`3oool0g`3oool007h0oooo00<000000?oo
o`3oool0SP3oool400000680oooo00<000000?ooo`3oool0RP3oool40000
0540oooo001n0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0500
oooo001n0?ooo`030000003oool0oooo05h0oooo0`00o`090?ooo`D00000
203oool200000080oooo0P0000050?ooo`030000003oool0oooo0080oooo
1`0000020?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
GP3oool3003o00H0oooo1@0000080?ooo`8000000P3oool2000000@0oooo
00<000000?ooo`3oool00P3oool700000080oooo00<000000?ooo`3oool0
D03oool007h0oooo00<000000?ooo`3oool0G@3oool5003o00P0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`D000000P3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`00
0000103oool200000680oooo00<000000?ooo`3oool0G@3oool5003o00D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`D000000P3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`000000103oool200000540oooo001n0?ooo`030000003oool0oooo
0140ooooC`00o`000`3o00000?l00?ooo`080?ooo`030000003oool0oooo
00/0oooo0P0000050?ooo`D00000103oool00`000000oooo000000030?oo
o`030000003oool000000680oooo00<000000?ooo`3oool04@3oool6003o
00@0oooo1P00o`040?ooo`H00?l0103oool5003o00@0oooo1P00o`040?oo
o`H00?l0103oool6003o00@0oooo1P00o`001P3oool00?l0003o0000o`00
o`00003o00H0oooo00<000000?ooo`3oool02`3oool2000000@0oooo1@00
00040?ooo`030000003oool0000000<0oooo00<000000?ooo`000000D@3o
ool007h0oooo00<000000?ooo`3oool04@3oool00`00o`00l?o`0?3ol019
0?3ol0<00?l000<0o`00003o003oool02@3oool00`000000oooo0?ooo`02
0?ooo`D000000`3oool2000000L0oooo00<000000?ooo`3oool0103oool0
0`000000oooo000000030?ooo`040000003oool0oooo00000640oooo00<0
00000?ooo`3oool0G@3oool3003o00030?l00000o`00oooo00H0oooo00<0
00000?ooo`3oool00P3oool5000000<0oooo0P0000060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`0000000`3oool010000000oooo0?oo
o`00001@0?ooo`00OP3oool00`000000oooo0?ooo`0A0?ooo`03003o003`
oo00l?o`04X0l?o`0`00o`000`3o0000oooo0?ooo`060?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`040?ooo`030000003oool000000080oooo00D000000?ooo`3o
ool0oooo0000001Q0?ooo`030000003oool0oooo05h0oooo0`00o`000`3o
0000oooo0?ooo`030?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool000000080oooo00D000000?ooo`3oool0oooo0000001@0?ooo`00OP3o
ool00`000000oooo0?ooo`0A0?ooo`03003o003`oo00l?o`04`0l?o`00<0
0?l00?l0003oool01`3oool5000000P0oooo0P0000020?ooo`8000002P3o
ool5000000050?ooo`00000000000000003oool00`00001P0?ooo`030000
003oool0oooo0600oooo00<00?l00?l0003oool0103oool5000000P0oooo
0P0000020?ooo`8000002@3oool5000000050?ooo`00000000000000003o
ool00`00001?0?ooo`00OP3oool00`000000oooo0?ooo`0A0?ooo`03003o
003`oo00l?o`04`0l?o`00<00?l00?ooo`3o0000T@3oool00`000000oooo
0?ooo`1P0?ooo`03003o003oool0o`0007`0oooo001n0?ooo`030000003o
ool0oooo0140oooo00<00?l00?3ol03`oo00C03`oo000`00o`00oooo0?l0
000W0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool04@3o
ool00`00o`00oooo0?ooo`1<0?ooo`03003o003oool0o`0002<0oooo00<0
00000?ooo`3oool0EP3oool007h0oooo00<000000?ooo`3oool04@3oool0
0`00o`00l?o`0?3ol01<0?3ol004003o003oool0oooo0?l00900oooo00<0
00000?ooo`3oool04@3oool00`00o`00oooo0?ooo`1?0?ooo`030?l0003o
ool0oooo07T0oooo001n0?ooo`030000003oool0oooo0140oooo00<00?l0
0?3ol03`oo00C03`oo001000o`00oooo0?ooo`3o002@0?ooo`030000003o
ool0oooo0140oooo00<00?l00?ooo`3oool0C`3oool00`3o0000oooo0?oo
o`1i0?ooo`00OP3oool00`000000oooo0?ooo`0A0?ooo`03003o003`oo00
l?o`04`0l?o`00D00?l00?ooo`3oool0oooo0?l0002?0?ooo`030000003o
ool0oooo0140oooo00<00?l00?ooo`3oool0D03oool00`3o0000oooo0?oo
o`1h0?ooo`00OP3oool00`000000oooo0?ooo`0A0?ooo`03003o003`oo00
l?o`04`0l?o`00D00?l00?ooo`3oool0oooo0?l0002?0?ooo`030000003o
ool0oooo0140oooo00<00?l00?ooo`3oool0D03oool00`3o0000oooo0?oo
o`1h0?ooo`00OP3oool00`000000oooo0?ooo`0A0?ooo`03003o003`oo00
l?o`04`0l?o`00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`2<
0?ooo`030000003oool0oooo0140oooo00<00?l00?ooo`3oool0C03oool0
0`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo07L0oooo001n0?oo
o`030000003oool0oooo0140oooo00<00?l00?3ol03`oo00C03`oo000`00
o`00oooo0?ooo`020?ooo`030?l0003oool0oooo08`0oooo00<000000?oo
o`3oool0H03oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo
07L0oooo001n0?ooo`030000003oool0oooo0140oooo00<00?l00?3ol03`
oo00C03`oo000`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo08/0
oooo00<000000?ooo`3oool0H03oool00`00o`00oooo0?ooo`030?ooo`03
0?l0003oool0oooo07H0oooo001n0?ooo`030000003oool0oooo0140oooo
00<00?l00?3ol03`oo00C03`oo000`00o`00oooo0?ooo`030?ooo`030?l0
003oool0oooo08/0oooo00<000000?ooo`3oool0H03oool00`00o`00oooo
0?ooo`030?ooo`030?l0003oool0oooo07H0oooo001n0?ooo`030000003o
ool0oooo0140oooo00<00?l00?3ol03`oo00C03`oo000`00o`00oooo0?oo
o`040?ooo`030?l0003oool0oooo08X0oooo00<000000?ooo`3oool0H03o
ool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo07D0oooo001n
0?ooo`030000003oool0oooo0140oooo00<00?l00?3ol03`oo00C03`oo00
0`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo08X0oooo00<00000
0?ooo`3oool04@3oool00`00o`00oooo0?ooo`1<0?ooo`03003o003oool0
oooo00@0oooo00<0o`000?ooo`3oool0M@3oool007h0oooo00<000000?oo
o`3oool04@3oool00`00o`00l?o`0?3ol01<0?3ol003003o003oool0oooo
00D0oooo00<0o`000?ooo`3oool0R@3oool00`000000oooo0?ooo`0A0?oo
o`03003o003oool0oooo05@0oooo00<0o`000?ooo`3oool0M03oool007h0
oooo00<000000?ooo`3oool04@3oool00`00o`00l?o`0?3ol01<0?3ol003
003o003oool0oooo00D0oooo00<0o`000?ooo`3oool0R@3oool00`000000
oooo0?ooo`0A0?ooo`03003o003oool0oooo05@0oooo00<0o`000?ooo`3o
ool0M03oool007h0oooo00<000000?ooo`3oool04@3oool00`00o`00l?o`
0?3ol01<0?3ol003003o003oool0oooo00H0oooo00<0o`000?ooo`3oool0
R03oool00`000000oooo0?ooo`0A0?ooo`03003o003oool0oooo05D0oooo
00<0o`000?ooo`3oool0L`3oool007h0oooo00<000000?ooo`3oool04@3o
ool00`00o`00l?o`0?3ol01<0?3ol003003o003oool0oooo00H0oooo00<0
o`000?ooo`3oool0R03oool00`000000oooo0?ooo`0A0?ooo`03003o003o
ool0oooo05D0oooo00<0o`000?ooo`3oool0L`3oool007h0oooo00<00000
0?ooo`3oool04@3oool00`00o`00l?o`0?3ol01<0?3ol003003o003oool0
oooo00L0oooo00<0o`000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0A
0?ooo`03003o003oool0oooo04`0oooo00<00?l00?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`1b0?ooo`00OP3oool00`000000oooo0?ooo`0A0?oo
o`03003o003`oo00l?o`04`0l?o`00<00?l00?ooo`3oool01`3oool00`3o
0000oooo0?ooo`270?ooo`030000003oool0oooo0600oooo00<00?l00?oo
o`3oool01`3oool00`3o0000oooo0?ooo`1b0?ooo`00OP3oool00`000000
oooo0?ooo`0A0?ooo`03003o003`oo00l?o`04`0l?o`00<00?l00?ooo`3o
ool0203oool00`3o0000oooo0?ooo`260?ooo`030000003oool0oooo0600
oooo00<00?l00?ooo`3oool0203oool00`3o0000oooo0?ooo`1a0?ooo`00
OP3oool00`000000oooo0?ooo`0A0?ooo`03003o003`oo00l?o`04`0l?o`
00<00?l00?ooo`3oool0203oool00`3o0000oooo0?ooo`260?ooo`030000
003oool0oooo0600oooo00<00?l00?ooo`3oool0203oool00`3o0000oooo
0?ooo`1a0?ooo`00OP3oool00`000000oooo0?ooo`0A0?ooo`03003o003`
oo00l?o`04`0l?o`00<00?l00?ooo`3oool02@3oool00`3o0000oooo0?oo
o`250?ooo`030000003oool0oooo0600oooo00<00?l00?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`1`0?ooo`00OP3oool00`000000oooo0?ooo`0A
0?ooo`03003o003`oo00l?o`04`0l?o`00<00?l00?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`250?ooo`030000003oool0oooo0140oooo00<00?l0
0?ooo`3oool0C03oool00`00o`00oooo0?ooo`090?ooo`030?l0003oool0
oooo0700oooo001n0?ooo`030000003oool0oooo0140oooo00<00?l00?3o
l03`oo00C03`oo000`00o`00oooo0?ooo`0:0?ooo`030?l0003oool0oooo
08@0oooo00<000000?ooo`3oool04@3oool00`00o`00oooo0?ooo`1I0?oo
o`030?l0003oool0oooo06l0oooo001n0?ooo`030000003oool0oooo0140
oooo00<00?l00?3ol03`oo00C03`oo000`00o`00oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo08@0oooo00<000000?ooo`3oool04@3oool00`00o`00
oooo0?ooo`1I0?ooo`030?l0003oool0oooo06l0oooo001n0?ooo`030000
003oool0oooo0140oooo00<00?l00?3ol03`oo00C03`oo000`00o`00oooo
0?ooo`0;0?ooo`030?l0003oool0oooo08<0oooo00<000000?ooo`3oool0
4@3oool00`00o`00oooo0?ooo`1J0?ooo`030?l0003oool0oooo06h0oooo
001n0?ooo`030000003oool0oooo0140oooo00<00?l00?3ol03`oo00C03`
oo000`00o`00oooo0?ooo`0;0?ooo`030?l0003oool0oooo08<0oooo00<0
00000?ooo`3oool04@3oool00`00o`00oooo0?ooo`1J0?ooo`030?l0003o
ool0oooo06h0oooo001n0?ooo`030000003oool0oooo0140oooo00<00?l0
0?3ol03`oo00C03`oo000`00o`00oooo0?ooo`0<0?ooo`030?l0003oool0
oooo0880oooo00<000000?ooo`3oool0H03oool00`00o`00oooo0?ooo`0<
0?ooo`030?l0003oool0oooo06d0oooo001n0?ooo`030000003oool0oooo
0140oooo00<00?l00?3ol03`oo00C03`oo000`00o`00oooo0?ooo`0<0?oo
o`030?l0003oool0oooo0880oooo00<000000?ooo`3oool0H03oool00`00
o`00oooo0?ooo`0<0?ooo`030?l0003oool0oooo06d0oooo001n0?ooo`03
0000003oool0oooo0140oooo00<00?l00?3ol03`oo00C03`oo000`00o`00
oooo0?ooo`0=0?ooo`030?l0003oool0oooo0840oooo00<000000?ooo`3o
ool0H03oool00`00o`00oooo0?ooo`0=0?ooo`030?l0003oool0oooo06`0
oooo001n0?ooo`030000003oool0oooo0140oooo00<00?l00?3ol03`oo00
C03`oo000`00o`00oooo0?ooo`0=0?ooo`030?l0003oool0oooo0840oooo
00<000000?ooo`3oool0H03oool00`00o`00oooo0?ooo`0=0?ooo`030?l0
003oool0oooo06`0oooo001n0?ooo`030000003oool0oooo0140oooo00<0
0?l00?3ol03`oo00C03`oo000`00o`00oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo0800oooo00<000000?ooo`3oool04@3oool00`00o`00oooo0?oo
o`1<0?ooo`03003o003oool0oooo00h0oooo00<0o`000?ooo`3oool0J`3o
ool007h0oooo00<000000?ooo`3oool04@3oool00`00o`00l?o`0?3ol01<
0?3ol003003o003oool0oooo00h0oooo00<0o`000?ooo`3oool0P03oool0
0`000000oooo0?ooo`0A0?ooo`03003o003oool0oooo05d0oooo00<0o`00
0?ooo`3oool0J`3oool007h0oooo00<000000?ooo`3oool04@3oool00`00
o`00l?o`0?3ol01<0?3ol003003o003oool0oooo00l0oooo00<0o`000?oo
o`3oool0O`3oool00`000000oooo0?ooo`0A0?ooo`03003o003oool0oooo
05h0oooo00<0o`000?ooo`3oool0JP3oool007h0oooo00<000000?ooo`3o
ool04@3oool00`00o`00l?o`0?3ol01<0?3ol003003o003oool0oooo00l0
oooo00<0o`000?ooo`3oool0O`3oool00`000000oooo0?ooo`0A0?ooo`03
003o003oool0oooo05h0oooo00<0o`000?ooo`3oool0JP3oool007h0oooo
00<000000?ooo`3oool04@3oool00`00o`00l?o`0?3ol01<0?3ol003003o
003oool0oooo0100oooo00<0o`000?ooo`3oool0OP3oool00`000000oooo
0?ooo`0A0?ooo`03003o003oool0oooo05l0oooo00<0o`000?ooo`3oool0
2@3oool5000000`0oooo1@0000030?ooo`030000003oool0oooo0080oooo
2`00000g0?ooo`00OP3oool00`000000oooo0?ooo`0A0?oooe000?l04P3o
ool00`3o0000oooo0?ooo`1n0?ooo`030000003oool0oooo0140oooo00<0
0?l00?ooo`3oool00P3oool6003o00@0oooo1P00o`040?ooo`H00?l00`3o
ool6003o00@0oooo1P00o`040?ooo`H00?l0103oool6003o00@0oooo1P00
o`0B0?ooo`030?l0003oool0oooo00X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`D000000`3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo000000020?ooo`05
0000003oool0oooo0?ooo`000000=P3oool007h0oooo00<000000?ooo`3o
ool0M03oool00`3o0000oooo0?ooo`1m0?ooo`030000003oool0oooo07@0
oooo00<0o`000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool00000
00X0oooo00D000000?ooo`3oool0oooo000000020?ooo`D00000103oool0
0`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000=P3o
ool007h0oooo00<000000?ooo`3oool0M03oool00`3o0000oooo0?ooo`1m
0?ooo`030000003oool0oooo07@0oooo00<0o`000?ooo`3oool02@3oool0
1@000000oooo0?ooo`3oool000000080oooo1@0000040?ooo`@00000103o
ool00`000000oooo0?ooo`040?ooo`030000003oool000000080oooo00D0
00000?ooo`3oool0oooo0000000f0?ooo`00OP3oool00`000000oooo0?oo
o`1e0?ooo`030?l0003oool0oooo07`0oooo00<000000?ooo`3oool0M@3o
ool00`3o0000oooo0?ooo`080?ooo`@000002`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
000000020?ooo`8000000P3oool00`000000oooo0?ooo`0d0?ooo`00OP3o
ool00`000000oooo0?ooo`1e0?ooo`030?l0003oool0oooo07`0oooo00<0
00000?ooo`3oool0M@3oool00`3o0000oooo0?ooo`080?ooo`050000003o
ool0oooo0?ooo`0000002`3oool3000000X0oooo1@0000020?ooo`040000
003oool00000000003L0oooo001n0?ooo`030000003oool0oooo07H0oooo
00<0o`000?ooo`3oool0N`3oool00`000000oooo0?ooo`1f0?ooo`030?l0
003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`03
0000003oool0oooo03P0oooo001n0?ooo`030000003oool0oooo07H0oooo
00<0o`000?ooo`3oool0N`3oool00`000000oooo0?ooo`1f0?ooo`030?l0
003oool0oooo00H0oooo1@00000L0?ooo`030000003oool0oooo00800000
>P3oool007h0oooo00<000000?ooo`3oool0M`3oool00`3o0000oooo0?oo
o`1j0?ooo`030000003oool0oooo07L0oooo00<0o`000?ooo`3oool0I@3o
ool007h0oooo00<000000?ooo`3oool0M`3oool00`3o0000oooo0?ooo`1j
0?ooo`030000003oool0oooo07L0oooo00<0o`000?ooo`3oool0I@3oool0
07h0oooo00<000000?ooo`3oool0N03oool00`3o0000oooo0?ooo`1i0?oo
o`030000003oool0oooo07P0oooo00<0o`000?ooo`3oool0I03oool007h0
oooo00<000000?ooo`3oool0N03oool00`3o0000oooo0?ooo`1i0?ooo`03
0000003oool0oooo07P0oooo00<0o`000?ooo`3oool0I03oool007h0oooo
00<000000?ooo`3oool0N@3oool00`3o0000oooo0?ooo`1h0?ooo`030000
003oool0oooo07T0oooo00<0o`000?ooo`3oool0H`3oool007h0oooo00<0
00000?ooo`3oool0N@3oool00`3o0000oooo0?ooo`1h0?ooo`030000003o
ool0oooo07T0oooo00<0o`000?ooo`3oool0H`3oool007h0oooo00<00000
0?ooo`3oool0NP3oool00`3o0000oooo0?ooo`1g0?ooo`030000003oool0
oooo07X0oooo00<0o`000?ooo`3oool0HP3oool007h0oooo00<000000?oo
o`3oool0NP3oool00`3o0000oooo0?ooo`1g0?ooo`030000003oool0oooo
07X0oooo00<0o`000?ooo`3oool0HP3oool007h0oooo00<000000?ooo`3o
ool0N`3oool00`3o0000oooo0?ooo`1f0?ooo`030000003oool0oooo07/0
oooo00<0o`000?ooo`3oool0H@3oool007h0oooo00<000000?ooo`3oool0
N`3oool00`3o0000oooo0?ooo`1f0?ooo`030000003oool0oooo07/0oooo
00<0o`000?ooo`3oool0H@3oool007h0oooo00<000000?ooo`3oool0O03o
ool00`3o0000oooo0?ooo`1e0?ooo`030000003oool0oooo07`0oooo00<0
o`000?ooo`3oool0H03oool007h0oooo00<000000?ooo`3oool0O03oool0
0`3o0000oooo0?ooo`0:0?ooo`D00000303oool5000000<0oooo00<00000
0?ooo`3oool00P3oool;00000480oooo00<000000?ooo`3oool0O03oool0
0`3o0000oooo0?ooo`1P0?ooo`00OP3oool00`000000oooo0?ooo`1m0?oo
o`030?l0003oool0oooo00X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`D000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo000000020?ooo`050000003o
ool0oooo0?ooo`000000@@3oool00`000000oooo0?ooo`1m0?ooo`030?l0
003oool0oooo05l0oooo001n0?ooo`030000003oool0oooo07d0oooo00<0
o`000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`D00000103oool00`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`000000@@3oool00`00
0000oooo0?ooo`1m0?ooo`030?l0003oool0oooo05l0oooo001n0?ooo`03
0000003oool0oooo07h0oooo00<0o`000?ooo`3oool02@3oool01@000000
oooo0?ooo`3oool000000080oooo1@0000040?ooo`@00000103oool00`00
0000oooo0?ooo`040?ooo`030000003oool000000080oooo00D000000?oo
o`3oool0oooo000000110?ooo`030000003oool0oooo07h0oooo00<0o`00
0?ooo`3oool0GP3oool007h0oooo00<000000?ooo`3oool0OP3oool00`3o
0000oooo0?ooo`090?ooo`@000002`3oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo00000002
0?ooo`8000000P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo07h0oooo00<0o`000?ooo`3oool0GP3oool007h0oooo00<000000?oo
o`3oool0O`3oool00`3o0000oooo0?ooo`080?ooo`050000003oool0oooo
0?ooo`0000002`3oool3000000X0oooo1@0000020?ooo`040000003oool0
000000000480oooo00<000000?ooo`3oool0O`3oool00`3o0000oooo0?oo
o`1M0?ooo`00OP3oool00`000000oooo0?ooo`1o0?ooo`030?l0003oool0
oooo00P0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0O`3oool00`3o0000oooo0?oo
o`1M0?ooo`00OP3oool00`000000oooo0?ooo`200?ooo`030?l0003oool0
oooo00H0oooo1@00000L0?ooo`030000003oool0oooo00800000A@3oool0
0`000000oooo0?ooo`200?ooo`030?l0003oool0oooo05`0oooo001n0?oo
o`030000003oool0oooo0800oooo00<0o`000?ooo`3oool0L@3oool00`00
0000oooo0?ooo`200?ooo`030?l0003oool0oooo05`0oooo001n0?ooo`03
0000003oool0oooo0840oooo00<0o`000?ooo`3oool0L03oool00`000000
oooo0?ooo`210?ooo`030?l0003oool0oooo05/0oooo001n0?ooo`030000
003oool0oooo0840oooo00<0o`000?ooo`3oool0L03oool00`000000oooo
0?ooo`210?ooo`030?l0003oool0oooo05/0oooo001n0?ooo`030000003o
ool0oooo0880oooo00<0o`000?ooo`3oool0K`3oool00`000000oooo0?oo
o`220?ooo`030?l0003oool0oooo05X0oooo001n0?ooo`030000003oool0
oooo0880oooo00<0o`000?ooo`3oool0K`3oool00`000000oooo0?ooo`22
0?ooo`030?l0003oool0oooo05X0oooo001n0?ooo`030000003oool0oooo
08<0oooo00<0o`000?ooo`3oool0KP3oool00`000000oooo0?ooo`230?oo
o`030?l0003oool0oooo05T0oooo001n0?ooo`030000003oool0oooo08<0
oooo00<0o`000?ooo`3oool0KP3oool00`000000oooo0?ooo`230?ooo`03
0?l0003oool0oooo05T0oooo001n0?ooo`030000003oool0oooo08@0oooo
00<0o`000?ooo`3oool0K@3oool00`000000oooo0?ooo`240?ooo`030?l0
003oool0oooo05P0oooo001n0?ooo`030000003oool0oooo08@0oooo00<0
o`000?ooo`3oool0K@3oool00`000000oooo0?ooo`240?ooo`030?l0003o
ool0oooo05P0oooo001n0?ooo`030000003oool0oooo08D0oooo00<0o`00
0?ooo`3oool0K03oool00`000000oooo0?ooo`250?ooo`030?l0003oool0
oooo05L0oooo001n0?ooo`030000003oool0oooo08D0oooo00<0o`000?oo
o`3oool0K03oool00`000000oooo0?ooo`250?ooo`030?l0003oool0oooo
05L0oooo001n0?ooo`030000003oool0oooo08H0oooo00<0o`000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`260?ooo`030?l0003oool0oooo05H0
oooo001n0?ooo`030000003oool0oooo08H0oooo00<0o`000?ooo`3oool0
J`3oool00`000000oooo0?ooo`260?ooo`030?l0003oool0oooo02<0oooo
1000000_0?ooo`00OP3oool00`000000oooo0?ooo`270?ooo`030?l0003o
ool0oooo06X0oooo00<000000?ooo`3oool0Q`3oool00`3o0000oooo0?oo
o`0T0?ooo`030000003oool0oooo02h0oooo001n0?ooo`030000003oool0
oooo08L0oooo00<0o`000?ooo`3oool0JP3oool00`000000oooo0?ooo`27
0?ooo`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo1@00000P
0?ooo`00OP3oool00`000000oooo0?ooo`280?ooo`030?l0003oool0oooo
06T0oooo00<000000?ooo`3oool0R03oool00`3o0000oooo0?ooo`0D0?oo
o`030000003oool0000000<0oooo1@0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000007`3oool0
07h0oooo00<000000?ooo`3oool0R03oool00`3o0000oooo0?ooo`1Y0?oo
o`030000003oool0oooo08P0oooo00<0o`000?ooo`3oool0503oool00`00
0000oooo0000000;0?ooo`030000003oool0000000<0oooo1@0000030?oo
o`050000003oool0oooo0?ooo`0000007`3oool007h0oooo00<000000?oo
o`3oool0R@3oool00`3o0000oooo0?ooo`1X0?ooo`030000003oool0oooo
08T0oooo00<0o`000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0
00000080oooo1@0000030?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000001l0oooo
001n0?ooo`030000003oool0oooo08T0oooo00<0o`000?ooo`3oool0J03o
ool00`000000oooo0?ooo`290?ooo`030?l0003oool0oooo0180oooo00D0
00000?ooo`3oool0oooo000000090?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`8000000P3oool00`000000
oooo0?ooo`0M0?ooo`00OP3oool00`000000oooo0?ooo`2:0?ooo`030?l0
003oool0oooo06L0oooo00<000000?ooo`3oool0RP3oool00`3o0000oooo
0?ooo`0@0?ooo`<0000000@0oooo00000000000000001`3oool300000004
0?ooo`0000000000000000T0oooo00@000000?ooo`0000000000803oool0
07h0oooo00<000000?ooo`3oool0RP3oool00`3o0000oooo0?ooo`1W0?oo
o`030000003oool0oooo08X0oooo00<0o`000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0Q0?ooo`00OP3oool00`000000oooo0?ooo`2;0?ooo`03
0?l0003oool0oooo06H0oooo00<000000?ooo`3oool0R`3oool00`3o0000
oooo0?ooo`0/0?ooo`8000008`3oool007h0oooo00<000000?ooo`3oool0
R`3oool00`3o0000oooo0?ooo`1V0?ooo`030000003oool0oooo08/0oooo
00<0o`000?ooo`3oool0D@3oool007h0oooo00<000000?ooo`3oool0S03o
ool00`3o0000oooo0?ooo`1U0?ooo`030000003oool0oooo08`0oooo00<0
o`000?ooo`3oool0D03oool007h0oooo00<000000?ooo`3oool0S03oool0
0`3o0000oooo0?ooo`1U0?ooo`030000003oool0oooo08`0oooo00<0o`00
0?ooo`3oool0D03oool007h0oooo00<000000?ooo`3oool0S@3oool00`3o
0000oooo0?ooo`1T0?ooo`030000003oool0oooo08d0oooo00<0o`000?oo
o`3oool0C`3oool007h0oooo00<000000?ooo`3oool0S@3oool00`3o0000
oooo0?ooo`1T0?ooo`030000003oool0oooo08d0oooo00<0o`000?ooo`3o
ool0C`3oool007h0oooo00<000000?ooo`3oool0SP3oool00`3o0000oooo
0?ooo`1S0?ooo`030000003oool0oooo08h0oooo00<0o`000?ooo`3oool0
CP3oool007h0oooo00<000000?ooo`3oool0SP3oool00`3o0000oooo0?oo
o`1S0?ooo`030000003oool0oooo08h0oooo00<0o`000?ooo`3oool03P3o
ool2000000030?ooo`000000000000L0oooo0P0000020?ooo`800000103o
ool00`000000oooo0?ooo`040?ooo`D000007P3oool007h0oooo00<00000
0?ooo`3oool0S`3oool00`3o0000oooo0?ooo`1R0?ooo`030000003oool0
oooo08l0oooo00<0o`000?ooo`3oool0303oool00`000000oooo0?ooo`02
00000080oooo1@0000020?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000001l0oooo
001n0?ooo`030000003oool0oooo08l0oooo00<0o`000?ooo`3oool0HP3o
ool00`000000oooo0?ooo`2?0?ooo`030?l0003oool0oooo00`0oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`800000103oool5000000<0oooo
00D000000?ooo`3oool0oooo0000000O0?ooo`00OP3oool00`000000oooo
0?ooo`2@0?ooo`030?l0003oool0oooo0640oooo00<000000?ooo`3oool0
T03oool00`3o0000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`00
00000P3oool5000000<0oooo0P0000060?ooo`030000003oool0oooo00@0
oooo1000000O0?ooo`00OP3oool00`000000oooo0?ooo`2@0?ooo`030?l0
003oool0oooo0640oooo00<000000?ooo`3oool0T03oool00`3o0000oooo
0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000002@3oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo0000000O0?ooo`00OP3oool00`000000oooo0?ooo`2A0?oo
o`030?l0003oool0oooo0600oooo00<000000?ooo`3oool0T@3oool00`3o
0000oooo0?ooo`090?ooo`8000000P3oool2000000P0oooo0P0000020?oo
o`8000002`3oool300000200oooo001n0?ooo`030000003oool0oooo0940
oooo00<0o`000?ooo`3oool0H03oool00`000000oooo0?ooo`2A0?ooo`03
0?l0003oool0oooo04/0oooo001n0?ooo`030000003oool0oooo0980oooo
00<0o`000?ooo`3oool00P3o001M0?ooo`030000003oool0oooo0980oooo
00<0o`000?ooo`3oool00P3o00180?ooo`00OP3oool00`000000oooo0?oo
o`2B0?ooo`D0o`00G@3oool00`000000oooo0?ooo`2B0?ooo`D0o`00B03o
ool007h0oooo00<000000?ooo`3oool0T@3oool60?l005d0oooo00<00000
0?ooo`3oool0T@3oool60?l004P0oooo001n0?ooo`030000003oool0oooo
08l0oooo2@3o001L0?ooo`030000003oool0oooo08l0oooo2@3o00170?oo
o`00OP3oool00`000000oooo0?ooo`2@0?ooo`P0o`00G03oool00`000000
oooo0?ooo`2@0?ooo`P0o`00A`3oool007h0oooo00<000000?ooo`3oool0
T@3oool70?l005`0oooo00<000000?ooo`3oool0T@3oool70?l004L0oooo
001n0?ooo`030000003oool0oooo0940oooo1`3o001L0?ooo`030000003o
ool0oooo0940oooo1`3o00170?ooo`00OP3oool00`000000oooo0?ooo`2B
0?ooo`H0o`00G03oool00`000000oooo0?ooo`2B0?ooo`H0o`001`3oool0
0`000000oooo0000000:0?ooo`D00000103oool00`000000oooo0?ooo`02
0?ooo`D00000803oool007h0oooo00<000000?ooo`3oool0T`3oool60?l0
05/0oooo00<000000?ooo`3oool0T`3oool60?l000D0oooo00D000000?oo
o`000000oooo000000020?ooo`D000000P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000001l0oooo001n0?ooo`030000003oool0oooo09@0oooo1@3o
001K0?ooo`030000003oool0oooo09@0oooo1@3o00050?ooo`050000003o
ool000000?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`D00000
0`3oool01@000000oooo0?ooo`3oool0000001l0oooo001n0?ooo`030000
003oool0oooo09D0oooo103o001K0?ooo`030000003oool0oooo09D0oooo
103o00050?ooo`050000003oool000000?ooo`0000000P3oool5000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`0000007`3oool007h0oooo00<000000?ooo`3o
ool0UP3oool30?l005/0oooo00<000000?ooo`3oool0UP3oool30?l000D0
oooo00D000000?ooo`3oool0oooo000000090?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool00`3oool400000200oooo001n0?oo
o`030000003oool0oooo09H0oooo0`3o001K0?ooo`030000003oool0oooo
09H0oooo0`3o00040?ooo`<0000000@0oooo0000000000000000203oool5
000000X0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`00OP3oool0
0`000000oooo0?ooo`2G0?ooo`<0o`00FP3oool00`000000oooo0?ooo`2G
0?ooo`<0o`008@3oool01@000000oooo0?ooo`3oool0000001l0oooo001n
0?ooo`030000003oool0oooo09P0oooo0P3o001J0?ooo`030000003oool0
oooo09P0oooo0P3o000P0?ooo`D00000803oool007h0oooo00<000000?oo
o`3oool0V@3oool00`3o0000oooo0?ooo`1H0?ooo`030000003oool0oooo
09T0oooo00<0o`000?ooo`3oool0@`3oool007h0oooo00<000000?ooo`3o
ool0L03oool00`000000oooo0000000:0?ooo`D00000103oool010000000
oooo0?ooo`3oool5000000X0oooo0`00o`1H0?ooo`030000003oool0oooo
09T0oooo0`00o`130?ooo`00OP3oool00`000000oooo0?ooo`1_0?ooo`05
0000003oool000000?ooo`0000000P3oool500000080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000080?ooo`D00?l0E`3oool00`000000oooo0?oo
o`2H0?ooo`D00?l0@P3oool007h0oooo00<000000?ooo`3oool0K`3oool0
1@000000oooo0000003oool0000000X0oooo00<000000?ooo`3oool00`3o
ool500000080oooo00D000000?ooo`3oool0oooo000000080?ooo`D00?l0
E`3oool00`000000oooo0?ooo`1<0?oooe400?l0@P3oool007h0oooo00<0
00000?ooo`3oool0K`3oool01@000000oooo0000003oool000000080oooo
1@0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000P0oooo1@00o`1G0?ooo`03
0000003oool0oooo04`0oooo00<00?l00?3ol03`oo00B@3`oo05003o0480
oooo001n0?ooo`030000003oool0oooo06l0oooo00D000000?ooo`3oool0
oooo000000090?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool00P3oool4000000X0oooo0`00o`1H0?ooo`030000003oool0oooo
04`0oooo00<00?l00?3ol03`oo00BP3`oo03003o04<0oooo001n0?ooo`03
0000003oool0oooo06h0oooo0`000000103oool000000000000000080?oo
o`D000002@3oool01@000000oooo0?ooo`3oool0000006@0oooo00<00000
0?ooo`3oool0C03oool00`00o`00l?o`0?3ol01<0?3ol003003o003oool0
oooo0440oooo001n0?ooo`030000003oool0oooo08/0oooo00D000000?oo
o`3oool0oooo0000001T0?ooo`030000003oool0oooo04`0oooo00<00?l0
0?3ol03`oo00C03`oo000`00o`00oooo0?ooo`110?ooo`00OP3oool00`00
0000oooo0?ooo`2:0?ooo`D00000I@3oool00`000000oooo0?ooo`1<0?oo
o`03003o003`oo00l?o`04`0l?o`00<00?l00?ooo`3oool0@@3oool007h0
oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`1<0?ooo`03
003o003`oo00l?o`04`0l?o`00<00?l00?ooo`3oool0@@3oool007h0oooo
00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`1<0?ooo`03003o
003`oo00l?o`04`0l?o`00<00?l00?ooo`3oool0@@3oool007h0oooo00<0
00000?ooo`3oool0m03oool00`000000oooo0?ooo`1<0?ooo`03003o003`
oo00l?o`04`0l?o`00<00?l00?ooo`3oool0@@3oool007h0oooo00<00000
0?ooo`3oool0m03oool00`000000oooo0?ooo`1<0?ooo`03003o003`oo00
l?o`04`0l?o`00<00?l00?ooo`3oool0@@3oool007h0oooo00<000000?oo
o`3oool0m03oool00`000000oooo0?ooo`1<0?ooo`03003o003`oo00l?o`
04`0l?o`00<00?l00?ooo`3oool0@@3oool007h0oooo00<000000?ooo`3o
ool0m03oool00`000000oooo0?ooo`1<0?ooo`03003o003`oo00l?o`04`0
l?o`00<00?l00?ooo`3oool0@@3oool007h0oooo00<000000?ooo`3oool0
m03oool00`000000oooo0?ooo`1<0?ooo`03003o003`oo00l?o`04`0l?o`
00<00?l00?ooo`3oool0@@3oool007h0oooo00<000000?ooo`3oool0m03o
ool00`000000oooo0?ooo`1<0?ooo`03003o003`oo00l?o`04`0l?o`00<0
0?l00?ooo`3oool0@@3oool007h0oooo00<000000?ooo`3oool0m03oool0
0`000000oooo0?ooo`1<0?ooo`03003o003`oo00l?o`04`0l?o`00<00?l0
0?ooo`3oool0@@3oool007h0oooo00<000000?ooo`3oool0m03oool00`00
0000oooo0?ooo`1<0?ooo`03003o003`oo00l?o`04`0l?o`00<00?l00?oo
o`3oool0@@3oool007h0oooo00<000000?ooo`3oool0Y03oool00`000000
oooo0?ooo`0400000180oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`1<0?ooo`03003o003`oo00l?o`04`0l?o`00<00?l00?ooo`3o
ool0@@3oool007h0oooo00<000000?ooo`3oool0X`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`1<0?ooo`03003o003`oo00l?o`04`0l?o`
00<00?l00?ooo`3oool0@@3oool007h0oooo00<000000?ooo`3oool0K`3o
ool00`000000oooo000000090?ooo`8000000P3oool2000000@0oooo00<0
00000?ooo`3oool0103oool5000000<0oooo00<000000?ooo`3oool00P3o
ool700000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`040000003oool0oooo0?ooo`D000001@3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo04`0oooo00<00?l00?3ol03`oo00
C03`oo000`00o`00oooo0?ooo`110?ooo`00OP3oool00`000000oooo0?oo
o`1^0?ooo`050000003oool000000?ooo`0000000P3oool500000080oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?oo
o`030000003oool0000000@0oooo00<000000?ooo`3oool0103oool20000
00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1<
0?ooo`03003o003`oo00l?o`04`0l?o`00<00?l00?ooo`3oool0@@3oool0
07h0oooo00<000000?ooo`3oool0KP3oool01@000000oooo0000003oool0
000000X0oooo0P0000040?ooo`D000000`3oool01@000000oooo0?ooo`3o
ool000000080oooo1@0000040?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000040?ooo`D000000P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`1<0?ooo`03003o003`oo00l?o`04`0l?o`
00<00?l00?ooo`3oool0@@3oool007h0oooo00<000000?ooo`3oool0KP3o
ool01@000000oooo0000003oool000000080oooo1@0000030?ooo`800000
1P3oool00`000000oooo0?ooo`040?ooo`@00000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0C03oool00`00o`00l?o`0?3ol01<0?3o
l003003o003oool0oooo0440oooo001n0?ooo`030000003oool0oooo06h0
oooo00D000000?ooo`3oool0oooo000000090?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0000
00040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000050?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`1<0?ooo`03003o003`oo00l?o`04`0l?o`00<00?l00?ooo`3oool0
@@3oool007h0oooo00<000000?ooo`3oool0K@3oool3000000040?ooo`00
00000000000000L0oooo0P0000020?ooo`8000002`3oool3000000X0oooo
1@0000040?ooo`040000003oool0oooo0?ooo`<0000000@0oooo00000000
000000002@3oool010000000oooo0000000000050?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0C03oool00`00o`00l?o`0?3ol01<
0?3ol003003o003oool0oooo0440oooo001n0?ooo`030000003oool0oooo
0:<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0C03oool00`00
o`00l?o`0?3ol01<0?3ol003003o003oool0oooo0440oooo001n0?ooo`03
0000003oool0oooo09`0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0>0?ooo`8000001P3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo04`0oooo00<00?l00?3ol03`oo00C03`oo000`00o`00
oooo0?ooo`110?ooo`00OP3oool00`000000oooo0?ooo`3d0?ooo`030000
003oool0oooo04`0oooo00<00?l00?3ol03`oo00C03`oo000`00o`00oooo
0?ooo`110?ooo`00OP3oool00`000000oooo0?ooo`3d0?ooo`030000003o
ool0oooo04`0oooo00<00?l00?3ol03`oo00C03`oo000`00o`00oooo0?oo
o`110?ooo`00OP3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0
oooo04`0oooo00<00?l00?3ol03`oo00C03`oo000`00o`00oooo0?ooo`11
0?ooo`00OP3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo
04`0oooo00<00?l00?3ol03`oo00C03`oo000`00o`00oooo0?ooo`110?oo
o`00OP3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo04`0
oooo00<00?l00?3ol03`oo00C03`oo000`00o`00oooo0?ooo`110?ooo`00
OP3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo04`0oooo
00<00?l00?3ol03`oo00C03`oo000`00o`00oooo0?ooo`110?ooo`00OP3o
ool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo04`0oooo00<0
0?l00?3ol03`oo00C03`oo000`00o`00oooo0?ooo`110?ooo`00OP3oool0
0`000000oooo0?ooo`3d0?ooo`030000003oool0oooo04`0oooo00<00?l0
0?3ol03`oo00C03`oo000`00o`00oooo0?ooo`110?ooo`00OP3oool00`00
0000oooo0?ooo`3d0?ooo`030000003oool0oooo04`0oooo00<00?l00?3o
l03`oo00C03`oo000`00o`00oooo0?ooo`110?ooo`00OP3oool00`000000
oooo0?ooo`3d0?ooo`030000003oool0oooo04`0oooo00<00?l00?3ol03`
oo00C03`oo000`00o`00oooo0?ooo`110?ooo`00OP3oool00`000000oooo
0?ooo`3d0?ooo`030000003oool0oooo04`0oooo00<00?l00?3ol03`oo00
C03`oo000`00o`00oooo0?ooo`110?ooo`00OP3oool00`000000oooo0?oo
o`3d0?ooo`030000003oool0oooo04`0oooo00<00?l00?3ol03`oo00C03`
oo000`00o`00oooo0?ooo`110?ooo`00OP3oool00`000000oooo0?ooo`3d
0?ooo`030000003oool0oooo04`0oooo00<00?l00?3ol03`oo00C03`oo00
0`00o`00oooo0?ooo`110?ooo`00OP3oool00`000000oooo0?ooo`3d0?oo
o`030000003oool0oooo04`0ooooD000o`130?ooo`00OP3oool00`000000
oooo0?ooo`3d0?ooo`030000003oool0oooo0=l0oooo001n0?ooo`030000
003oool0oooo0?@0oooo00<000000?ooo`3oool0g`3oool007h0oooo00<0
00000?ooo`3oool0m03oool00`000000oooo0?ooo`3O0?ooo`00OP3oool0
0`000000oooo0?ooo`3d0?ooo`030000003oool0oooo0=l0oooo001n0?oo
o`030000003oool0oooo0?@0oooo00<000000?ooo`3oool0g`3oool007h0
oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`3O0?ooo`00
OP3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo0=l0oooo
001n0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool0g`3o
ool007h0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`3O
0?ooo`00OP3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo
0=l0oooo001n0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3o
ool0g`3oool007h0oooo00<000000?ooo`3oool0m03oool00`000000oooo
0?ooo`3O0?ooo`00OP3oool00`000000oooo0?ooo`3d0?ooo`030000003o
ool0oooo0=l0oooo001n0?ooo`030000003oool0oooo0?@0oooo00<00000
0?ooo`3oool0g`3oool007h0oooo00<000000?ooo`3oool0m03oool00`00
0000oooo0?ooo`3O0?ooo`00OP3oool00`000000oooo0?ooo`3d0?ooo`03
0000003oool0oooo0=l0oooo001n0?ooo`030000003oool0oooo0?@0oooo
00<000000?ooo`3oool0g`3oool007h0oooo00<000000?ooo`3oool0m03o
ool00`000000oooo0?ooo`3O0?ooo`00OP3oool00`000000oooo0?ooo`3d
0?ooo`030000003oool0oooo0=l0oooo001n0?ooo`030000003oool0oooo
0?@0oooo00<000000?ooo`3oool0g`3oool00?l0ooooo`3ooomI0?ooo`00
o`3ooooo0?oooeT0oooo003o0?ooool0ooooF@3oool00?l0ooooo`3ooomI
0?ooo`00o`3ooooo0?oooeT0oooo003o0?ooool0ooooF@3oool00?l0oooo
o`3ooomI0?ooo`00O03oool200000?l0oooofP3oool007d0oooo00<00000
0?ooo`3oool0o`3ooooH0?ooo`00OP3oool00`000000oooo0?ooo`3c0?oo
o`800000h@3oool007d0oooo00<000000?ooo`000000m03oool200000>40
oooo001l0?ooo`040000003oool0oooo00000?<0oooo00@000000?ooo`3o
ool00000h03oool007/0oooo0`0000000`3oool000000000003a0?ooo`80
00000P3oool200000=l0oooo003o0?ooool0ooooF@3oool00?l0ooooo`3o
oomI0?ooo`00o`3ooooo0?oooeT0oooo003o0?ooool0ooooF@3oool00001
\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{599, 227},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["\t\t\t\tFigure 2.5",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  StyleBox["The translation",
    FontWeight->"Plain"],
  "  ",
  Cell[BoxData[
      StyleBox[\(w = \(T \((z)\) = \(z + B = 
              x + a + \[ImaginaryI] \((y + b)\)\)\)\),
        FontWeight->"Plain"]]],
  StyleBox[".",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "\tIf we let  ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  "  be a fixed real number, then for  ",
  Cell[BoxData[
      \(z = r\ \[ExponentialE]\^\[ImaginaryI]\[Theta]\)]],
  ",  the transformation  \n\n\t\t\t",
  Cell[BoxData[
      \(w = \(R \((z)\) = \(z\ \[ExponentialE]\^\[ImaginaryI]\[Alpha] = \(r\ \
\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\) \[ExponentialE]\^\[ImaginaryI]\
\[Alpha] = 
              r\ \[ExponentialE]\^\(\[ImaginaryI] \((\[Theta] + \[Alpha])\)\)\
\)\)\)\)]],
  "  \n\nis a one-to-one mapping of the z-plane onto the w-plane and is \
called a ",
  ButtonBox["rotation",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Rotation.html"], None},
    ButtonStyle->"Hyperlink"],
  ".  It can be visualized as a rigid rotation whereby the point  z  is \
rotated about the origin through an angle  ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  "   to its new position  ",
  Cell[BoxData[
      \(w = R \((z)\)\)]],
  ".  If we use polar coordinates and designate  ",
  Cell[BoxData[
      \(w = \[Rho]\ \[ExponentialE]\^\[ImaginaryI]\[Phi]\)]],
  "  in the w-plane, then the inverse mapping is \n\n\t\t\t",
  Cell[BoxData[
      \(z = \(\(R\^\(-1\)\) \((w)\) = \(w\ \[ExponentialE]\^\(-\[ImaginaryI]\
\[Alpha]\) = \(\[Rho]\ \(\[ExponentialE]\^\[ImaginaryI]\[Phi]\) \
\[ExponentialE]\^\(-\[ImaginaryI]\[Alpha]\) = \[Rho]\ \[ExponentialE]\^\(\
\[ImaginaryI] \((\[Phi] - \[Alpha])\)\)\)\)\)\)]],
  ".  \n\nThis analysis shows that  R  is a one-to-one mapping from the \
z-plane onto the w-plane.  ",
  "The effect of rotation is depicted in Figure 2.6."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000jb000`400?l0
0000o`00003oo`3ooooo0?ooohH0oooo003o0?ooool0ooooQP3oool00?l0
ooooo`3ooon60?ooo`00o`3ooooo0?ooohH0oooo003o0?ooool0ooooQP3o
ool00?l0ooooo`3ooon60?ooo`00o`3ooooo0?ooohH0oooo003o0?ooool0
ooooQP3oool00?l0ooooo`3ooon60?ooo`00o`3ooooo0?ooohH0oooo003o
0?oood`0oooo0P0000000`3oool000000000003o0?ooobD0oooo1000000<
0?ooo`00o`3ooom=0?ooo`030000003oool000000?l0oooo9@3oool01000
0000oooo0?ooo`00000=0?ooo`00C`3ooolX00000003003oo`00o`000?l0
0:800?l04`0000000`00o`0000000000000B000000T0oooo00<000000?oo
o`3oool09P3ooolX000000L00?l01P000007003o00D000001`00o`050000
00L00?l01@000007003o00H000001`00o`05000000L00?l01@000007003o
00D000001`00o`05000000P00?l01@000007003o00D000001`00o`050000
00L00?l01@000006003o00@0000000<00?l0000000000000600000000`00
ool0000000000006000000P0oooo00@000000?ooo`3oool000003@3oool0
07L0oooo00<00?oo0?3ol000o`000`00o`2N0?3ol003003o003oool0oooo
0140oooo00<00?l00?ooo`3oool06@3oool2000000030?ooo`0000000000
04`0oooo0P00o`000`00ool00?l0003o0003003o09h0oooo00<00?l00?oo
o`3oool00P3oool00`00o`00oooo0?ooo`0H0?ooo`03003oo`3oool0oooo
00d0oooo0P0000000`3oool000000000000=0?ooo`00M`3oool00`00o`00
0?oo0?3ol0030?3ol0@00?l0VP3`oo000`00o`00oooo0?ooo`0A0?ooo`03
003o003oool0oooo06T0oooo00D00?l00?3ol03`oo000?l0003oo`040?oo
o`800?l0W03oool00`00o`00oooo0?ooo`020?ooo`03003o003oool0oooo
01P0oooo00<00?oo0?ooo`3oool07`3oool007L0oooo00<00?l0003oo`3`
oo001`3`oo04003o09H0l?o`00<00?l00?ooo`3oool04@3oool00`00o`00
oooo0?ooo`1W0?ooo`800?l00`3`oo000`00o`000?oo003o000<0?ooo`80
0?l0V03oool00`00o`00oooo0?ooo`0H0?ooo`03003oo`3oool0oooo01l0
oooo001g0?ooo`03003o003`oo000?oo00/0l?o`1000o`2B0?3ol003003o
003oool0oooo0140oooo00<00?l00?ooo`3oool0IP3oool00`00o`00l?o`
0?3ol0030?3ol004003o0000ool0l?o`003o00d0oooo1000o`2C0?ooo`03
003o003oool0oooo01T0oooo00<00?oo0?ooo`3oool07`3oool007L0oooo
00<00?l00?3ol000ool03`3`oo04003o08h0l?o`00<00?l00?ooo`3oool0
4@3oool00`00o`00oooo0?ooo`1T0?ooo`800?l0203`oo000`00ool00?l0
0?ooo`0@0?ooo`800?l0T@3oool00`00o`00oooo0?ooo`0I0?ooo`03003o
o`3oool0oooo01l0oooo001g0?ooo`04003o003`oo00l?o`003ooa80l?o`
1000o`2:0?3ol003003o003oool0oooo0140oooo00<00?l00?ooo`3oool0
H`3oool00`00o`00l?o`0?3ol0080?3ol003003oo`3`oo000?l00:<0oooo
00<00?l00?ooo`3oool06@3oool00`00ool0oooo0?ooo`0O0?ooo`00M`3o
ool01000o`00l?o`0?3ol000oolF0?3ol0@00?l0QP3`oo000`00o`00oooo
0?ooo`0A0?ooo`03003o003oool0oooo0640oooo0P00o`0<0?3ol003003o
o`3`oo000?l001L0oooo0P00o`290?ooo`03003o003oool0oooo01T0oooo
00<00?oo0?ooo`3oool07`3oool007L0oooo00<00?l00?3ol03`oo006`3`
oo04003o0880l?o`00<00?l00?ooo`3oool04@3oool00`00o`00oooo0?oo
o`1P0?ooo`03003o003`oo00l?o`00`0l?o`00<00?oo0?3ol000o`006@3o
ool4003o0840oooo00D00?l00?ooo`3oool0oooo003o000K0?ooo`03003o
o`3oool0oooo01l0oooo001g0?ooo`03003o003`oo00l?o`01l0l?o`1000
o`1n0?3ol003003o003oool0oooo0140oooo00<00?l00?ooo`3oool0GP3o
ool2003o00l0l?o`00@00?oo0?3ol03`oo000?l0703oool2003o07l0oooo
00D00?l00?ooo`3oool0oooo003o000K0?ooo`03003oo`3oool0oooo01l0
oooo001g0?ooo`03003o003`oo00l?o`02<0l?o`1000o`1j0?3ol003003o
003oool0oooo0140oooo00<00?l00?ooo`3oool0G@3oool00`00o`00l?o`
0?3ol00<0?3ol005003o003`oo00l?o`0?3ol000ool00P3`oo000`00o`00
oooo0?ooo`2J0?ooo`05003o003oool0oooo0?ooo`00o`006`3oool00`00
ool0oooo0?ooo`0O0?ooo`00M`3oool00`00o`00l?o`0?3ol00W0?3ol0@0
0?l0MP3`oo000`00o`00oooo0?ooo`0A0?ooo`03003o003oool0oooo05`0
oooo00<00?l00?3ol03`oo003@3`oo001@00o`00l?o`0?3ol03`oo000?oo
0080l?o`00<00?l00?ooo`3oool08@3oool4003o07D0oooo00D00?l00?oo
o`3oool0oooo003o000K0?ooo`03003oo`3oool0oooo01l0oooo001g0?oo
o`03003o003`oo00l?o`02/0l?o`1000o`1b0?3ol003003o003oool0oooo
0140oooo00<00?l00?ooo`3oool0FP3oool2003o0100l?o`00D00?l00?3o
l03`oo00l?o`003oo`030?3ol003003o003oool0oooo02@0oooo1000o`1a
0?ooo`05003o003oool0oooo0?ooo`00o`006`3oool00`00ool0oooo0?oo
o`0O0?ooo`00M`3oool00`00o`00l?o`0?3ol00_0?3ol0@00?l0KP3`oo00
0`00o`00oooo0?ooo`0@0?ooo`03003o003oool0oooo05X0oooo00<00?l0
0?3ol03`oo00403`oo000`00o`00l?o`0?3ol0020?3ol005003oo`3`oo00
l?o`0?3ol000o`00VP3oool01@00o`00oooo0?ooo`3oool00?l001/0oooo
00<00?oo0?ooo`3oool07`3oool007L0oooo00<00?l00?3ol03`oo000P3`
oo000`00ool0l?o`0?3ol00^0?3ol0@00?l0JP3`oo000`00o`00oooo0?oo
o`0@0?ooo`03003o003oool0oooo05P0oooo0P00o`0C0?3ol003003o003`
oo00l?o`0080l?o`00D00?oo0?3ol03`oo00l?o`003o000_0?ooo`800?l0
J@3oool01@00o`00oooo0?ooo`3oool00?l001/0oooo00<00?oo0?ooo`3o
ool07`3oool007L0oooo00<00?l00?3ol03`oo000P3`oo000`00ool0l?o`
0?3ol00b0?3ol0@00?l0IP3`oo000`00o`00oooo0?ooo`0@0?ooo`03003o
003oool0oooo05L0oooo00<00?l00?3ol03`oo004`3`oo000`00o`00l?o`
0?3ol0020?3ol003003oo`3`oo00l?o`0080l?o`00<00?l00?ooo`3oool0
;P3oool4003o06T0oooo00<00?l00?ooo`3oool06@3oool00`00ool0oooo
0?ooo`0O0?ooo`00M`3oool00`00o`00l?o`0?3ol0030?3ol003003oo`3`
oo00l?o`03D0l?o`1000o`1R0?3ol003003o003oool0oooo0100oooo00<0
0?l00?ooo`3oool0E@3oool2003o01H0l?o`00<00?l00?3ol03`oo000`3`
oo000`00ool0l?o`0?3ol0020?3ol003003o003oool0oooo0340oooo0P00
o`1W0?ooo`03003o003oool0oooo01P0oooo00<00?oo0?ooo`3oool0803o
ool007L0oooo00<00?l00?3ol03`oo000`3`oo000`00ool0l?o`0?3ol00i
0?3ol0@00?l0GP3`oo000`00o`00oooo0?ooo`0@0?ooo`03003o003oool0
oooo05@0oooo00<00?l00?3ol03`oo00703`oo000`00ool0l?o`0?3ol002
0?3ol003003o003oool0oooo09X0oooo00<00?l00?ooo`3oool0603oool0
0`00ool0oooo0?ooo`0P0?ooo`00M`3oool00`00o`00l?o`0?3ol0040?3o
l003003oo`3`oo00l?o`03`0l?o`1000o`1J0?3ol003003o003oool0oooo
0100oooo00<00?l00?ooo`3oool0DP3oool2003o01l0l?o`00<00?oo0?3o
l03`oo000`3`oo000`00o`00oooo0?ooo`0i0?ooo`800?l0GP3oool00`00
o`00oooo0?ooo`0H0?ooo`03003oo`3oool0oooo0200oooo001g0?ooo`03
003o003`oo00l?o`00@0l?o`00<00?oo0?3ol03`oo00@03`oo04003o05H0
l?o`00<00?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`1A0?ooo`03
003o003`oo00l?o`0200l?o`00<00?oo0?3ol03`oo000`3`oo000`00o`00
oooo0?ooo`0j0?ooo`@00?l0F@3oool00`00o`00oooo0?ooo`0I0?ooo`03
003oo`3oool0oooo0200oooo001g0?ooo`03003o003`oo00l?o`00D0l?o`
00<00?oo0?3ol03`oo00@`3`oo04003o0580l?o`00<00?l00?ooo`3oool0
403oool00`00o`00oooo0?ooo`1?0?ooo`800?l08`3`oo000`00ool0l?o`
0?3ol0030?3ol003003o003oool0oooo03h0oooo0P00o`1D0?ooo`04003o
003oool0oooo003o01/0oooo00<00?oo0?ooo`3oool0803oool007L0oooo
00<00?l00?3ol03`oo001@3`oo000`00ool0l?o`0?3ol0170?3ol0@00?l0
CP3`oo000`00o`00oooo0?ooo`0@0?ooo`03003o003oool0oooo00<0oooo
100000170?ooo`03003o003`oo00l?o`02@0l?o`00<00?oo0?3ol03`oo00
0`3`oo000`00o`00oooo0?ooo`150?ooo`800?l0C03oool01000o`00oooo
0?ooo`00o`050?ooo`@000004P3oool00`00ool0oooo0?ooo`0P0?ooo`00
M`3oool00`00o`00l?o`0?3ol01C0?3ol0@00?l0BP3`oo000`00o`00oooo
0?ooo`0@0?ooo`03003o003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`120?ooo`800?l07`3`oo000`00o`00l?o`
0?3ol0050?3ol003003oo`3`oo00l?o`00@0l?o`00<00?l00?ooo`3oool0
AP3oool4003o04P0oooo00@00?l00?ooo`3oool00?l0103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<00?oo0?ooo`3o
ool0803oool007L0oooo00<00?l00?3ol03`oo00E`3`oo04003o04H0l?o`
00<00?l00?ooo`3oool0403oool00`00o`00oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`00o`00l?o`
0?3ol00O0?3ol003003o003`oo00l?o`00D0l?o`00<00?oo0?3ol03`oo00
103`oo000`00o`00oooo0?ooo`1:0?ooo`800?l0AP3oool01000o`00oooo
0?ooo`00o`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03`3oool00`00ool0oooo0?ooo`0P0?ooo`00M`3oool00`00o`00l?o`
0?3ol01K0?3ol0@00?l0@P3`oo000`00o`00oooo0?ooo`0?0?ooo`03003o
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`110?ooo`03003o003`oo00l?o`01h0l?o`00<00?l00?3ol03`oo00
1P3`oo000`00ool0l?o`0?3ol0040?3ol003003o003oool0oooo0940oooo
00@00?l00?ooo`3oool00?l0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00h0oooo00<00?oo0?ooo`3oool0803oool007L0oooo
00<00?l00?3ol03`oo00G`3`oo04003o03h0l?o`00<00?l00?ooo`3oool0
3`3oool00`00o`00oooo0?ooo`030?ooo`L00000@`3oool00`00o`00l?o`
0?3ol00N0?3ol003003o003`oo00l?o`00H0l?o`00<00?oo0?3ol03`oo00
1@3`oo000`00o`00oooo0?ooo`1@0?ooo`800?l0?P3oool01000o`00oooo
0?ooo`00o`040?ooo`L000003`3oool00`00ool0oooo0?ooo`0Q0?ooo`00
M`3oool00`00o`00l?o`0?3ol01S0?3ol0@00?l0>P3`oo000`00o`00oooo
0?ooo`0?0?ooo`03003o003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`120?ooo`03003o003`oo00l?o`01d0l?o`
00<00?l00?3ol03`oo001P3`oo000`00ool0l?o`0?3ol0050?3ol003003o
003oool0oooo0580oooo1000o`0j0?ooo`04003o003oool0oooo003o00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`03
003oo`3oool0oooo0240oooo001g0?ooo`03003o003`oo00l?o`06L0l?o`
1000o`0f0?3ol003003o003oool0oooo00l0oooo00<00?l00?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04<0oooo
00<00?l00?3ol03`oo00703`oo000`00o`00l?o`0?3ol0070?3ol003003o
o`3`oo00l?o`00D0l?o`00<00?l00?ooo`3oool0E@3oool2003o03X0oooo
00<00?l00?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00d0oooo00<00?oo0?ooo`3oool08@3oool007L0oooo00<0
0?l00?3ol03`oo001`3`oo000`00ool0l?o`0?3ol01Q0?3ol0@00?l0<P3`
oo000`00o`00oooo0?ooo`0?0?ooo`03003o003oool0oooo00D0oooo1000
00160?ooo`03003o003`oo00l?o`01`0l?o`00<00?l00?3ol03`oo001`3`
oo000`00ool0l?o`0?3ol0060?3ol003003o003oool0oooo05`0oooo0P00
o`0b0?ooo`03003o003oool0oooo00D0oooo1000000@0?ooo`03003oo`3o
ool0oooo0240oooo001g0?ooo`03003o003`oo00l?o`00L0l?o`00<00?oo
0?3ol03`oo00I@3`oo04003o02h0l?o`00<00?l00?ooo`3oool03`3oool0
0`00o`00oooo0?ooo`1@0?ooo`03003o003`oo00l?o`01/0l?o`00<00?l0
0?3ol03`oo001`3`oo000`00ool0l?o`0?3ol0060?3ol003003o003oool0
oooo05h0oooo1000o`0^0?ooo`03003o003oool0oooo01T0oooo00<00?oo
0?ooo`3oool08@3oool007L0oooo00<00?l00?3ol03`oo00203`oo000`00
ool0l?o`0?3ol01X0?3ol0@00?l0:P3`oo000`00o`00oooo0?ooo`0>0?oo
o`03003o003oool0oooo0580oooo00<00?l00?3ol03`oo009@3`oo000`00
ool0l?o`0?3ol0060?3ol003003o003oool0oooo0640oooo0P00o`0/0?oo
o`03003o003oool0oooo01T0oooo00<00?oo0?ooo`3oool08@3oool007L0
oooo00<00?l00?3ol03`oo00203`oo000`00ool0l?o`0?3ol01/0?3ol0@0
0?l09P3`oo000`00o`00oooo0?ooo`0>0?ooo`03003o003oool0oooo0580
oooo00<00?l00?3ol03`oo009@3`oo000`00ool0l?o`0?3ol0070?3ol003
003o003oool0oooo08h0oooo00<00?l00?ooo`3oool06@3oool00`00ool0
oooo0?ooo`0Q0?ooo`00M`3oool00`00o`00l?o`0?3ol0090?3ol003003o
o`3`oo00l?o`06l0l?o`1000o`0R0?3ol003003o003oool0oooo00h0oooo
00<00?l00?ooo`3oool0D`3oool00`00o`00l?o`0?3ol00T0?3ol003003o
o`3`oo00l?o`00L0l?o`00<00?l00?ooo`3oool0J@3oool2003o0280oooo
00<00?l00?ooo`3oool06P3oool00`00ool0oooo0?ooo`0Q0?ooo`00M`3o
ool00`00o`00l?o`0?3ol0090?3ol003003oo`3`oo00l?o`07<0l?o`1000
o`0N0?3ol003003o003oool0oooo00h0oooo00<00?l00?ooo`3oool0E03o
ool00`00o`00l?o`0?3ol00T0?3ol003003oo`3`oo00l?o`00L0l?o`00<0
0?l00?ooo`3oool0JP3oool4003o01d0oooo0P00o`0K0?ooo`03003oo`3o
ool0oooo0280oooo001g0?ooo`03003o003`oo00l?o`00X0l?o`00<00?oo
0?3ol03`oo00MP3`oo04003o01X0l?o`00<00?l00?ooo`3oool03P3oool0
0`00o`00oooo0?ooo`1D0?ooo`03003o003`oo00l?o`02@0l?o`00<00?oo
0?3ol03`oo00203`oo000`00o`00oooo0?ooo`1]0?ooo`800?l06`3oool2
003o01/0oooo00<00?oo0?ooo`3oool08P3oool007L0oooo00<00?l00?3o
l03`oo00Q`3`oo04003o01H0l?o`00<00?l00?ooo`3oool03@3oool00`00
o`00oooo0?ooo`1F0?ooo`03003o003`oo00l?o`01L0l?o`00<00?l00?3o
l03`oo002P3`oo000`00ool0l?o`0?3ol0070?3ol003003o003oool0oooo
08X0oooo0P00o`0K0?ooo`03003oo`3oool0oooo0280oooo001g0?ooo`03
003o003`oo00l?o`08/0l?o`1000o`0B0?3ol003003o003oool0oooo00d0
oooo00<00?l00?ooo`3oool0E`3oool00`00o`00l?o`0?3ol00F0?3ol003
003o003`oo00l?o`00X0l?o`00<00?oo0?3ol03`oo00203`oo000`00o`00
oooo0?ooo`1d0?ooo`@00?l04@3oool2003o01/0oooo00<00?oo0?ooo`3o
ool08P3oool007L0oooo00<00?l00?3ol03`oo00S`3`oo04003o00h0l?o`
00<00?l00?ooo`3oool03@3oool00`00o`00oooo0?ooo`1G0?ooo`03003o
003`oo00l?o`01H0l?o`00<00?l00?3ol03`oo002P3`oo000`00ool0l?o`
0?3ol0090?3ol003003o003oool0oooo07L0oooo1000o`0=0?ooo`03003o
003oool0oooo01X0oooo00<00?oo0?ooo`3oool08P3oool007L0oooo00<0
0?l00?3ol03`oo00T`3`oo04003o00P0l?o`0`00o`0?0?ooo`03003o003o
ool0oooo05P0oooo00<00?l00?3ol03`oo005@3`oo000`00o`00l?o`0?3o
l00;0?3ol003003oo`3`oo00l?o`00P0l?o`00<00?l00?ooo`3oool0QP3o
ool3003o01/0oooo00<00?oo0?ooo`3oool08`3oool007L0oooo00<00?l0
0?3ol03`oo00U`3`oo04003o00<0l?o`1@00o`0>0?ooo`03003o003oool0
oooo05T0oooo00<00?l00?3ol03`oo00503`oo000`00o`00l?o`0?3ol00;
0?3ol003003oo`3`oo00l?o`00T0l?o`00<00?l00?ooo`3oool0P03oool2
003o0080oooo1@00o`0J0?ooo`03003oo`3oool0oooo02<0oooo001g0?oo
o`03003o003`oo00l?o`09/0l?o`2@00o`0=0?ooo`03003o003oool0oooo
05T0oooo00<00?l00?3ol03`oo00503`oo02003o00`0l?o`00<00?oo0?3o
l03`oo002P3`oo000`00o`00oooo0?ooo`210?ooo`P00?l06@3oool00`00
ool0oooo0?ooo`0S0?ooo`00M`3oool?003o0003003oo`00o`000?l009D0
0?l0303oool00`00o`00oooo0?ooo`1K0?ooo`03003o003`oo00l?o`01<0
l?o`00<00?l00?3ol03`oo00103`oo07003o00030?3ol000ool0l?o`0080
l?o`1`00o`000`3`oo000?l00?ooo`020?ooo`L00?l01@3oool7003o00D0
oooo2000o`050?ooo`L00?l01@3oool7003o00D0oooo1`00o`050?ooo`P0
0?l01@3oool7003o00D0oooo1`00o`050?ooo`L00?l01@3oool>003o01T0
oooo00<00?oo0?ooo`3oool08`3oool007L0oooo00<000000?ooo`3oool0
303oool00`00ool0oooo0?ooo`2>0?ooo`X00?l02@3oool00`00o`00oooo
0?ooo`1L0?ooo`03003o003`oo00l?o`0240l?o`00<00?oo0?3ol03`oo00
2P3`oo000`00o`00oooo0?ooo`210?ooo`L00?l0603oool00`00ool0oooo
0?ooo`0T0?ooo`00M`3oool00`000000oooo0?ooo`0=0?ooo`03003oo`3o
ool0oooo08h0oooo1@00o`040?ooo`@00?l0103oool00`00o`00oooo0?oo
o`1M0?ooo`03003o003`oo00l?o`0240l?o`00<00?oo0?3ol03`oo002`3`
oo000`00o`00oooo0?ooo`210?ooo`D00?l06@3oool00`00ool0oooo0?oo
o`0T0?ooo`00M`3oool00`000000oooo0?ooo`0=0?ooo`03003oo`3oool0
oooo08l0oooo00<00?l00?l00000o`002@3oool5003o0600oooo00<00?l0
0?3ol03`oo008@3`oo000`00ool0l?o`0?3ol00:0?3ol003003o003oool0
oooo0880oooo00<00?l00?l00000o`006P3oool00`00ool0oooo0?ooo`0T
0?ooo`00M`3oool00`000000oooo0?ooo`0>0?ooo`03003oo`3oool0oooo
08h0oooo00<0o`000?ooo`3oool03@3oool4003o05h0oooo00<00?l00?3o
l03`oo00803`oo000`00ool0l?o`0?3ol00;0?3ol003003o003oool0oooo
0840oooo00<0o`000?ooo`3oool06P3oool00`00ool0oooo0?ooo`0T0?oo
o`00M`3oool00`000000oooo0?ooo`0>0?ooo`03003oo`3oool0oooo08h0
oooo00<0o`000?ooo`3oool04@3oool4003o05/0oooo00<00?l00?3ol03`
oo007`3`oo000`00ool0l?o`0?3ol00<0?3ol003003o003oool0oooo0800
oooo00<0o`000?ooo`3oool06P3oool00`00ool0oooo0?ooo`0T0?ooo`00
M`3oool00`000000oooo0?ooo`0?0?ooo`03003oo`3oool0oooo08d0oooo
00<0o`000?ooo`3oool05@3oool4003o05L0oooo00<00?l00?3ol03`oo00
803`oo000`00ool0l?o`0?3ol00;0?3ol003003o003oool0oooo0800oooo
00<0o`000?ooo`3oool06@3oool00`00ool0oooo0?ooo`0U0?ooo`00M`3o
ool00`000000oooo0?ooo`0?0?ooo`03003oo`3oool0oooo08`0oooo00<0
o`000?ooo`3oool06P3oool4003o05@0oooo00<00?l00?3ol03`oo007`3`
oo000`00ool0l?o`0?3ol00<0?3ol003003o003oool0oooo07h0oooo00<0
o`000?ooo`3oool06P3oool00`00ool0oooo0?ooo`0U0?ooo`00M`3oool0
0`000000oooo0?ooo`2N0?ooo`030?l0003oool0oooo01h0oooo0`00o`1B
0?ooo`03003o003`oo00l?o`01l0l?o`00<00?oo0?3ol03`oo00303`oo00
0`00o`00oooo0?ooo`1m0?ooo`030?l0003oool0oooo01X0oooo00<00?oo
0?ooo`3oool09@3oool007L0oooo00<000000?ooo`3oool0M03oool50000
00T0oooo1@0000020?ooo`D00000403oool00`3o0000oooo0?ooo`1c0?oo
o`03003o003`oo00l?o`01l0l?o`00<00?oo0?3ol03`oo00303`oo000`00
o`00oooo0?ooo`1C0?ooo`D000002@3oool500000080oooo1@00000@0?oo
o`030?l0003oool0oooo01X0oooo00<00?oo0?ooo`3oool09@3oool007L0
oooo00<000000?ooo`3oool0M03oool01@000000oooo0?ooo`3oool00000
0080oooo1@0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000004`3oool00`3o0000oooo0?ooo`1d0?ooo`03003o003`oo00l?o`
01h0l?o`00<00?oo0?3ol03`oo003@3`oo000`00o`00oooo0?ooo`1B0?oo
o`050000003oool0oooo0?ooo`0000000P3oool5000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0000000C0?ooo`030?l0003oool0
oooo01T0oooo00<00?oo0?ooo`3oool09P3oool007L0oooo00<000000?oo
o`3oool0M@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000004P3oool00`3o0000oooo0?ooo`1f0?oo
o`03003o003`oo00l?o`01h0l?o`00<00?oo0?3ol03`oo003@3`oo000`00
o`00oooo0?ooo`1B0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0000000B0?ooo`030?l0003oool0oooo
01X0oooo00<00?oo0?ooo`3oool09P3oool007L0oooo00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`020?ooo`D000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000<000003`3oool00`3o0000
oooo0?ooo`1f0?ooo`03003o003`oo00l?o`01h0l?o`00<00?oo0?3ol03`
oo003@3`oo000`00o`00oooo0?ooo`1C0?ooo`030000003oool0oooo0080
oooo1@0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`00000?0?ooo`030?l0003oool0oooo01X0oooo00<00?oo0?ooo`3o
ool09P3oool007L0oooo00<000000?ooo`3oool0M03oool010000000oooo
0?ooo`00000;0?ooo`8000000`3oool00`000000oooo000000020?ooo`03
0000003oool0oooo00d0oooo00<0o`000?ooo`3oool0M`3oool00`00o`00
l?o`0?3ol00M0?3ol003003oo`3`oo00l?o`00h0l?o`00<00?l00?ooo`3o
ool0D03oool010000000oooo0?ooo`00000;0?ooo`8000000`3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00d0oooo00<0o`000?oo
o`3oool06P3oool00`00ool0oooo0?ooo`0V0?ooo`00M`3oool00`000000
oooo0?ooo`0A0?ooo`03003oo`3oool0oooo0600oooo1@0000090?ooo`80
000000<0oooo0000000000000P3oool4000000<0oooo0`0000020?ooo`80
00001@3oool00`3o0000oooo0?ooo`1i0?ooo`03003o003`oo00l?o`01d0
l?o`00<00?oo0?3ol03`oo003P3`oo000`00o`00oooo0?ooo`1?0?ooo`D0
00002@3oool2000000030?ooo`00000000000080oooo100000030?ooo`<0
00000P3oool2000000D0oooo00<0o`000?ooo`3oool06P3oool00`00ool0
oooo0?ooo`0W0?ooo`00M`3oool00`000000oooo0?ooo`0A0?ooo`03003o
o`3oool0oooo07d0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`030?l0003oool0oooo07T0oooo00<00?l00?3ol03`
oo007@3`oo000`00ool0l?o`0?3ol00>0?3ol003003o003oool0oooo06`0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?oo
o`030?l0003oool0oooo01X0oooo00<00?oo0?ooo`3oool09`3oool007L0
oooo00<000000?ooo`3oool04P3oool00`00ool0oooo0?ooo`1l0?ooo`04
0000003oool0oooo000000<0oooo00@000000?ooo`3oool0o`00O@3oool0
0`00o`00l?o`0?3ol00L0?3ol003003oo`3`oo00l?o`00l0l?o`00<00?l0
0?ooo`3oool0J`3oool010000000oooo0?ooo`0000030?ooo`040000003o
ool0oooo0?l001d0oooo00<00?oo0?ooo`3oool09`3oool007L0oooo00<0
00000?ooo`3oool04P3oool00`00ool0oooo0?ooo`1l0?ooo`030000003o
ool0oooo00D000000P3oool00`3o0000oooo0?ooo`1l0?ooo`03003o003`
oo00l?o`01`0l?o`00<00?oo0?3ol03`oo003`3`oo000`00o`00oooo0?oo
o`1Z0?ooo`030000003oool0oooo00D000000P3oool00`3o0000oooo0?oo
o`0J0?ooo`03003oo`3oool0oooo02P0oooo001g0?ooo`030000003oool0
oooo01<0oooo00<00?oo0?ooo`3oool0NP3oool2000000<0oooo00H00000
0?ooo`3oool000000?ooo`3o001o0?ooo`03003o003`oo00l?o`01`0l?o`
00<00?oo0?3ol03`oo003`3`oo000`00o`00oooo0?ooo`1Y0?ooo`800000
0`3oool01P000000oooo0?ooo`000000oooo0?l001d0oooo00<00?oo0?oo
o`3oool0:03oool007L0oooo00<000000?ooo`3oool04`3oool00`00ool0
oooo0?ooo`200?ooo`8000000P3oool00`3o0000oooo0?ooo`1n0?ooo`03
003o003`oo00l?o`01/0l?o`00<00?oo0?3ol03`oo00403`oo000`00o`00
oooo0?ooo`1^0?ooo`8000000P3oool00`3o0000oooo0?ooo`0J0?ooo`03
003oo`3oool0oooo02T0oooo001g0?ooo`030000003oool0oooo01@0oooo
00<00?oo0?ooo`3oool0NP3oool00`000000oooo0?ooo`060?ooo`030?l0
003oool0oooo07l0oooo00<00?l00?3ol03`oo006`3`oo000`00ool0l?o`
0?3ol00@0?3ol003003o003oool0oooo06P0oooo00<000000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`0J0?ooo`03003oo`3oool0oooo02T0oooo
001g0?ooo`030000003oool0oooo01@0oooo00<00?oo0?ooo`3oool0PP3o
ool00`3o0000oooo0?ooo`200?ooo`03003o003`oo00l?o`01/0l?o`00<0
0?oo0?3ol03`oo00403`oo000`00o`00oooo0?ooo`1`0?ooo`030?l0003o
ool0oooo01/0oooo00<00?oo0?ooo`3oool0:@3oool007L0oooo00<00000
0?ooo`3oool0V@3oool00`3o0000oooo0?ooo`210?ooo`03003o003`oo00
l?o`01/0l?o`00<00?oo0?3ol03`oo00403`oo000`00o`00oooo0?ooo`1_
0?ooo`030?l0003oool0oooo01/0oooo00<00?oo0?ooo`3oool0:@3oool0
07L0oooo00<000000?ooo`3oool0V03oool00`3o0000oooo0?ooo`230?oo
o`03003o003`oo00l?o`01X0l?o`00<00?oo0?3ol03`oo004@3`oo000`00
o`00oooo0?ooo`1]0?ooo`030?l0003oool0oooo01/0oooo00<00?oo0?oo
o`3oool0:P3oool007L0oooo00<000000?ooo`3oool0V03oool00`3o0000
oooo0?ooo`230?ooo`03003o003`oo00l?o`01X0l?o`00<00?oo0?3ol03`
oo004@3`oo000`00o`00oooo0?ooo`1]0?ooo`030?l0003oool0oooo01/0
oooo00<00?oo0?ooo`3oool0:P3oool007L0oooo00<000000?ooo`3oool0
U`3oool00`3o0000oooo0?ooo`250?ooo`03003o003`oo00l?o`01X0l?o`
00<00?oo0?3ol03`oo004@3`oo000`00o`00oooo0?ooo`1[0?ooo`030?l0
003oool0oooo01`0oooo00<00?oo0?ooo`3oool0:P3oool007L0oooo00<0
00000?ooo`3oool0U`3oool00`3o0000oooo0?ooo`260?ooo`03003o003`
oo00l?o`01T0l?o`00<00?oo0?3ol03`oo004P3`oo000`00o`00oooo0?oo
o`1Z0?ooo`030?l0003oool0oooo01/0oooo00<00?oo0?ooo`3oool0:`3o
ool007L0oooo00<000000?ooo`3oool0U`3oool00`3o0000oooo0?ooo`26
0?ooo`03003o003`oo00l?o`01T0l?o`00<00?oo0?3ol03`oo004P3`oo00
0`00o`00oooo0?ooo`1Z0?ooo`030?l0003oool0oooo01/0oooo00<00?oo
0?ooo`3oool0:`3oool007L0oooo00<000000?ooo`3oool05P3oool00`00
ool0oooo0?ooo`1m0?ooo`030?l0003oool0oooo08P0oooo00<00?l00?3o
l03`oo006@3`oo000`00ool0l?o`0?3ol00B0?3ol003003o003oool0oooo
06P0oooo00<0o`000?ooo`3oool06`3oool00`00ool0oooo0?ooo`0/0?oo
o`00M`3oool00`000000oooo0?ooo`0F0?ooo`03003oo`3oool0oooo07d0
oooo00<0o`000?ooo`3oool0R@3oool00`00o`00l?o`0?3ol00H0?3ol003
003oo`3`oo00l?o`01<0l?o`00<00?l00?ooo`3oool0I`3oool00`3o0000
oooo0?ooo`0K0?ooo`03003oo`3oool0oooo02`0oooo001g0?ooo`030000
003oool0oooo01L0oooo00<00?oo0?ooo`3oool0N`3oool00`3o0000oooo
0?ooo`2:0?ooo`03003o003`oo00l?o`01P0l?o`00<00?oo0?3ol03`oo00
503`oo000`00o`00oooo0?ooo`1U0?ooo`030?l0003oool0oooo01`0oooo
00<00?oo0?ooo`3oool0;03oool007L0oooo00<000000?ooo`3oool05`3o
ool00`00ool0oooo0?ooo`1k0?ooo`030?l0003oool0oooo08/0oooo00<0
0?l00?3ol03`oo00603`oo000`00ool0l?o`0?3ol00C0?3ol003003o003o
ool0oooo06D0oooo00<0o`000?ooo`3oool06`3oool00`00ool0oooo0?oo
o`0]0?ooo`00M`3oool00`000000oooo0?ooo`0H0?ooo`03003oo`3oool0
oooo07T0oooo00<0o`000?ooo`3oool0S@3oool00`00o`00l?o`0?3ol00G
0?3ol003003oo`3`oo00l?o`01@0l?o`00<00?l00?ooo`3oool0H`3oool0
0`3o0000oooo0?ooo`0L0?ooo`03003oo`3oool0oooo02d0oooo001g0?oo
o`030000003oool0oooo01P0oooo00<00?oo0?ooo`3oool0N@3oool00`3o
0000oooo0?ooo`2=0?ooo`03003o003`oo00l?o`01L0l?o`00<00?oo0?3o
l03`oo005@3`oo000`00o`00oooo0?ooo`1R0?ooo`030?l0003oool0oooo
01/0oooo00<00?oo0?ooo`3oool0;P3oool007L0oooo00<000000?ooo`3o
ool06@3oool00`00ool0oooo0?ooo`1g0?ooo`030?l0003oool0oooo08h0
oooo00<00000003o003`oo00603`oo000`00ool0l?o`0?3ol00D0?3ol003
003o003oool0oooo0640oooo00<0o`000?ooo`3oool0703oool00`00ool0
oooo0?ooo`0^0?ooo`00M`3oool00`000000oooo0?ooo`0I0?ooo`03003o
o`3oool0oooo07L0oooo00<0o`000?ooo`3oool0SP3oool00`000000oooo
003o000H0?3ol003003oo`3`oo00l?o`01D0l?o`00<00?l00?ooo`3oool0
H03oool00`3o0000oooo0?ooo`0K0?ooo`03003oo`3oool0oooo02l0oooo
001g0?ooo`030000003oool0oooo0980oooo00<0o`000?ooo`3oool0S`3o
ool00`000000oooo003o000I0?3ol003003oo`3`oo00l?o`01D0l?o`00<0
0?l00?ooo`3oool0GP3oool00`3o0000oooo0?ooo`0L0?ooo`03003oo`3o
ool0oooo02l0oooo001g0?ooo`030000003oool0oooo0980oooo00<0o`00
0?ooo`3oool0S`3oool010000000oooo0?ooo`00o`0H0?3ol003003oo`3`
oo00l?o`01D0l?o`00<00?l00?ooo`3oool0GP3oool00`3o0000oooo0?oo
o`0L0?ooo`03003oo`3oool0oooo02l0oooo001g0?ooo`030000003oool0
oooo0980oooo00<0o`000?ooo`3oool0S`3oool01@000000oooo0?ooo`3o
ool00?l001L0l?o`00<00?oo0?3ol03`oo005P3`oo000`00o`00oooo0?oo
o`1M0?ooo`030?l0003oool0oooo01/0oooo00<00?oo0?ooo`3oool0<03o
ool007L0oooo00<000000?ooo`3oool0T@3oool00`3o0000oooo0?ooo`2@
0?ooo`050000003oool0oooo0?ooo`00o`00603`oo000`00ool0l?o`0?3o
l00F0?3ol003003o003oool0oooo05/0oooo00<0o`000?ooo`3oool0703o
ool00`00ool0oooo0?ooo`0`0?ooo`00M`3oool00`000000oooo0?ooo`2A
0?ooo`030?l0003oool0oooo0900oooo00<000000?ooo`3oool00P3oool0
0`00o`00l?o`0?3ol00E0?3ol003003oo`3`oo00l?o`01H0l?o`00<00?l0
0?ooo`3oool0F`3oool00`3o0000oooo0?ooo`0K0?ooo`03003oo`3oool0
oooo0340oooo001g0?ooo`030000003oool0oooo0900oooo00<0o`000?oo
o`3oool0T@3oool00`000000oooo0?ooo`030?ooo`03003o003`oo00l?o`
01@0l?o`00<00?oo0?3ol03`oo005`3`oo000`00o`00oooo0?ooo`1I0?oo
o`030?l0003oool0oooo01`0oooo00<00?oo0?ooo`3oool0<@3oool007L0
oooo00<000000?ooo`3oool06`3oool00`00ool0oooo0?ooo`1b0?ooo`03
0?l0003oool0oooo0940oooo00<000000?ooo`3oool00`3oool00`00o`00
l?o`0?3ol00E0?3ol003003oo`3`oo00l?o`01L0l?o`00<00?l00?ooo`3o
ool0F03oool00`3o0000oooo0?ooo`0K0?ooo`03003oo`3oool0oooo0380
oooo001g0?ooo`030000003oool0oooo01/0oooo00<00?oo0?ooo`3oool0
L@3oool00`3o0000oooo0?ooo`2B0?ooo`030000003oool0oooo00@0oooo
00<00?l00?3ol03`oo00503`oo000`00ool0l?o`0?3ol00G0?3ol003003o
003oool0oooo05L0oooo00<0o`000?ooo`3oool0703oool00`00ool0oooo
0?ooo`0b0?ooo`00M`3oool00`000000oooo0?ooo`0L0?ooo`03003oo`3o
ool0oooo06l0oooo00<0o`000?ooo`3oool0T`3oool00`000000oooo0?oo
o`050?ooo`03003o003`oo00l?o`01<0l?o`00<00?oo0?3ol03`oo00603`
oo000`00o`00oooo0?ooo`1E0?ooo`030?l0003oool0oooo01d0oooo00<0
0?oo0?ooo`3oool0<P3oool007L0oooo00<000000?ooo`3oool0703oool0
0`00ool0oooo0?ooo`1^0?ooo`030?l0003oool0oooo09@0oooo00<00000
0?ooo`3oool01@3oool00`00o`00l?o`0?3ol00D0?3ol003003oo`3`oo00
l?o`01P0l?o`00<00?l00?ooo`3oool0D`3oool00`3o0000oooo0?ooo`0M
0?ooo`03003oo`3oool0oooo03<0oooo001g0?ooo`030000003oool0oooo
01d0oooo00<00?oo0?ooo`3oool0K@3oool00`3o0000oooo0?ooo`2D0?oo
o`030000003oool0oooo00H0oooo00<00?l00?3ol03`oo004`3`oo000`00
ool0l?o`0?3ol00H0?3ol003003o003oool0oooo05<0oooo00<0o`000?oo
o`3oool07@3oool00`00ool0oooo0?ooo`0c0?ooo`00M`3oool00`000000
oooo0?ooo`0M0?ooo`03003oo`3oool0oooo06`0oooo00<0o`000?ooo`3o
ool0U@3oool00`000000oooo0?ooo`070?ooo`03003o003`oo00l?o`0180
l?o`00<00?oo0?3ol03`oo006@3`oo000`00o`00oooo0?ooo`1A0?ooo`03
0?l0003oool0oooo01d0oooo00<00?oo0?ooo`3oool0=03oool007L0oooo
00<000000?ooo`3oool07P3oool00`00ool0oooo0?ooo`1[0?ooo`030?l0
003oool0oooo09D0oooo00<000000?ooo`3oool01`3oool00`00o`00l?o`
0?3ol00C0?3ol003003oo`3`oo00l?o`01T0l?o`00<00?l00?ooo`3oool0
D03oool00`3o0000oooo0?ooo`0L0?ooo`03003oo`3oool0oooo03D0oooo
001g0?ooo`030000003oool0oooo01h0oooo00<00?oo0?ooo`3oool0JP3o
ool00`3o0000oooo0?ooo`2F0?ooo`030000003oool0oooo00P0oooo00<0
0?l00?3ol03`oo004P3`oo000`00ool0l?o`0?3ol00I0?3ol003003o003o
ool0oooo04l0oooo00<0o`000?ooo`3oool07@3oool00`00ool0oooo0?oo
o`0e0?ooo`00M`3oool00`000000oooo0?ooo`2;0?ooo`030?l0003oool0
oooo09H0oooo00<000000?ooo`3oool02@3oool00`00o`00l?o`0?3ol00B
0?3ol003003oo`3`oo00l?o`01T0l?o`00<00?l00?ooo`3oool0CP3oool0
0`3o0000oooo0?ooo`0L0?ooo`03003oo`3oool0oooo03H0oooo001g0?oo
o`030000003oool0oooo08X0oooo00<0o`000?ooo`3oool0U`3oool00`00
0000oooo0?ooo`0:0?ooo`03003o003`oo00l?o`0140l?o`00<00?oo0?3o
l03`oo006P3`oo000`00o`00oooo0?ooo`1<0?ooo`030?l0003oool0oooo
01d0oooo00<00?oo0?ooo`3oool0=P3oool007L0oooo00<000000?ooo`3o
ool0R@3oool00`3o0000oooo0?ooo`2H0?ooo`030000003oool0oooo00X0
oooo00<00?l00?3ol03`oo004@3`oo000`00ool0l?o`0?3ol00J0?3ol003
003o003oool0oooo04/0oooo00<0o`000?ooo`3oool07@3oool00`00ool0
oooo0?ooo`0g0?ooo`00M`3oool00`000000oooo0?ooo`280?ooo`030?l0
003oool0oooo09T0oooo00<000000?ooo`3oool02`3oool00`00o`00l?o`
0?3ol00A0?3ol003003oo`3`oo00l?o`01X0l?o`00<00?l00?ooo`3oool0
B@3oool00`3o0000oooo0?ooo`0M0?ooo`03003oo`3oool0oooo03P0oooo
001g0?ooo`030000003oool0oooo08P0oooo00<0o`000?ooo`3oool0V@3o
ool00`000000oooo0?ooo`0<0?ooo`03003o003`oo00l?o`0100l?o`00<0
0?oo0?3ol03`oo006`3`oo000`00o`00oooo0?ooo`180?ooo`030?l0003o
ool0oooo01d0oooo00<00?oo0?ooo`3oool0>03oool007L0oooo00<00000
0?ooo`3oool0Q`3oool00`3o0000oooo0?ooo`2J0?ooo`030000003oool0
oooo00`0oooo00<00?l00?3ol03`oo00403`oo000`00ool0l?o`0?3ol00K
0?3ol003003o003oool0oooo04L0oooo00<0o`000?ooo`3oool07P3oool0
0`00ool0oooo0?ooo`0h0?ooo`00M`3oool00`000000oooo0?ooo`0P0?oo
o`03003oo`3oool0oooo06<0oooo00<0o`000?ooo`3oool0V`3oool00`00
0000oooo0?ooo`0=0?ooo`03003o003`oo00l?o`0100l?o`00<00?oo0?3o
l03`oo006`3`oo000`00o`00oooo0?ooo`150?ooo`030?l0003oool0oooo
01l0oooo00<00?oo0?ooo`3oool0>03oool007L0oooo00<000000?ooo`3o
ool0803oool00`00ool0oooo0?ooo`1R0?ooo`030?l0003oool0oooo09`0
oooo00<000000?ooo`3oool03P3oool00`00o`00l?o`0?3ol00?0?3ol003
003oo`3`oo00l?o`01`0l?o`00<00?l00?ooo`3oool0@`3oool00`3o0000
oooo0?ooo`0O0?ooo`03003oo`3oool0oooo03T0oooo001g0?ooo`030000
003oool0oooo0240oooo00<00?oo0?ooo`3oool0H@3oool00`3o0000oooo
0?ooo`2L0?ooo`030000003oool0oooo00h0oooo00<00?l00?3ol03`oo00
3`3`oo000`00ool0l?o`0?3ol00L0?3ol003003o003oool0oooo04<0oooo
00<0o`000?ooo`3oool07P3oool00`00ool0oooo0?ooo`0j0?ooo`00M`3o
ool00`000000oooo0?ooo`0Q0?ooo`03003oo`3oool0oooo0600oooo00<0
o`000?ooo`3oool0W@3oool00`000000oooo0?ooo`0?0?ooo`03003o003`
oo00l?o`00l0l?o`00<00?oo0?3ol03`oo00703`oo000`00o`00oooo0?oo
o`110?ooo`030?l0003oool0oooo01l0oooo00<00?oo0?ooo`3oool0>P3o
ool007L0oooo00<000000?ooo`3oool08P3oool00`00ool0oooo0?ooo`1N
0?ooo`030?l0003oool0oooo09h0oooo00<000000?ooo`3oool0403oool0
0`00o`00l?o`0?3ol00>0?3ol003003oo`3`oo00l?o`01d0l?o`00<00?l0
0?ooo`3oool0?`3oool00`3o0000oooo0?ooo`0O0?ooo`03003oo`3oool0
oooo03/0oooo001g0?ooo`030000003oool0oooo0280oooo00<00?oo0?oo
o`3oool0G@3oool00`3o0000oooo0?ooo`2O0?ooo`030000003oool0oooo
0100oooo00<00?l00?3ol03`oo003`3`oo000`00ool0l?o`0?3ol00L0?3o
l003003o003oool0oooo03h0oooo00<0o`000?ooo`3oool0803oool00`00
ool0oooo0?ooo`0k0?ooo`00M`3oool00`000000oooo0?ooo`0S0?ooo`03
003oo`3oool0oooo05`0oooo00<0o`000?ooo`3oool0W`3oool00`000000
oooo0?ooo`0A0?ooo`03003o003`oo00l?o`00h0l?o`00<00?oo0?3ol03`
oo007@3`oo000`00o`00oooo0?ooo`0m0?ooo`030?l0003oool0oooo01l0
oooo00<00?oo0?ooo`3oool0?03oool007L0oooo00<000000?ooo`3oool0
8`3oool00`00ool0oooo0?ooo`1K0?ooo`030?l0003oool0oooo0:00oooo
00<000000?ooo`3oool04P3oool00`00o`00l?o`0?3ol00=0?3ol003003o
o`3`oo00l?o`01h0l?o`00<00?l00?ooo`3oool0>`3oool00`3o0000oooo
0?ooo`0O0?ooo`03003oo`3oool0oooo03d0oooo001g0?ooo`030000003o
ool0oooo0800oooo00<0o`000?ooo`3oool0X@3oool00`000000oooo0?oo
o`0B0?ooo`03003o003`oo00l?o`00h0l?o`00<00?oo0?3ol03`oo007@3`
oo000`00o`00oooo0?ooo`0j0?ooo`030?l0003oool0oooo0200oooo00<0
0?oo0?ooo`3oool0?@3oool007L0oooo00<000000?ooo`3oool0O`3oool0
0`3o0000oooo0?ooo`2R0?ooo`030000003oool0oooo01<0oooo00<00?l0
0?3ol03`oo003@3`oo000`00ool0l?o`0?3ol00N0?3ol003003o003oool0
oooo03P0oooo00<0o`000?ooo`3oool0803oool00`00ool0oooo0?ooo`0n
0?ooo`00M`3oool00`000000oooo0?ooo`1o0?ooo`030?l0003oool0oooo
0:80oooo00<000000?ooo`3oool0503oool00`00o`00l?o`0?3ol00<0?3o
l003003oo`3`oo00l?o`01l0l?o`00<00?l00?ooo`3oool0=`3oool00`3o
0000oooo0?ooo`0O0?ooo`03003oo`3oool0oooo03l0oooo001g0?ooo`03
0000003oool0oooo07h0oooo00<0o`000?ooo`3oool0X`3oool00`000000
oooo0?ooo`0D0?ooo`03003o003`oo00l?o`00d0l?o`00<00?oo0?3ol03`
oo007P3`oo000`00o`00oooo0?ooo`0f0?ooo`030?l0003oool0oooo0200
oooo00<00?oo0?ooo`3oool0?`3oool007L0oooo00<000000?ooo`3oool0
O@3oool00`3o0000oooo0?ooo`2T0?ooo`030000003oool0oooo01D0oooo
00<00?l00?3ol03`oo00303`oo000`00ool0l?o`0?3ol00O0?3ol003003o
003oool0oooo03@0oooo00<0o`000?ooo`3oool0803oool00`00ool0oooo
0?ooo`100?ooo`00M`3oool00`000000oooo0?ooo`1l0?ooo`030?l0003o
ool0oooo0:D0oooo00<000000?ooo`3oool05P3oool00`00o`00l?o`0?3o
l00;0?3ol003003oo`3`oo00l?o`0200l?o`00<00?l00?ooo`3oool0<P3o
ool00`3o0000oooo0?ooo`0P0?ooo`03003oo`3oool0oooo0440oooo001g
0?ooo`030000003oool0oooo02D0oooo00<00?oo0?ooo`3oool0E03oool0
0`3o0000oooo0?ooo`2U0?ooo`030000003oool0oooo01H0oooo00<00?l0
0?3ol03`oo00303`oo000`00ool0l?o`0?3ol00O0?3ol003003o003oool0
oooo0380oooo00<0o`000?ooo`3oool0803oool00`00ool0oooo0?ooo`11
0?ooo`00M`3oool00`000000oooo0?ooo`0U0?ooo`03003oo`3oool0oooo
05<0oooo00<0o`000?ooo`3oool0YP3oool00`000000oooo0?ooo`0G0?oo
o`03003o003`oo00l?o`00/0l?o`00<00?oo0?3ol03`oo00803`oo000`00
o`00oooo0?ooo`0`0?ooo`030?l0003oool0oooo0200oooo00<00?oo0?oo
o`3oool0@P3oool007L0oooo00<000000?ooo`3oool09P3oool00`00ool0
oooo0?ooo`1A0?ooo`030?l0003oool0oooo00P0oooo0P0000020?ooo`03
0000003oool0oooo09P0oooo00<000000?ooo`3oool0603oool00`00o`00
l?o`0?3ol00:0?3ol003003oo`3`oo00l?o`0240l?o`00<00?l00?ooo`3o
ool0;P3oool00`3o0000oooo0?ooo`080?ooo`8000000P3oool00`000000
oooo0?ooo`0A0?ooo`03003oo`3oool0oooo04<0oooo001g0?ooo`030000
003oool0oooo02H0oooo00<00?oo0?ooo`3oool0D03oool00`3o0000oooo
0?ooo`080?ooo`030000003oool0oooo00800000V`3oool00`000000oooo
0?ooo`0H0?ooo`03003o003`oo00l?o`00/0l?o`00<00?oo0?3ol03`oo00
803`oo000`00o`00oooo0?ooo`0]0?ooo`030?l0003oool0oooo00P0oooo
00<000000?ooo`3oool00P00000C0?ooo`03003oo`3oool0oooo04@0oooo
001g0?ooo`030000003oool0oooo02H0oooo00<00?oo0?ooo`3oool0C`3o
ool00`3o0000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000
V`3oool00`000000oooo0?ooo`0I0?ooo`03003o003`oo00l?o`00X0l?o`
00<00?oo0?3ol03`oo008@3`oo000`00o`00oooo0?ooo`0[0?ooo`030?l0
003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`03
003oo`3oool0oooo04D0oooo001g0?ooo`030000003oool0oooo02L0oooo
00<00?oo0?ooo`3oool0C@3oool00`3o0000oooo0?ooo`0:0?ooo`050000
003oool0oooo0?ooo`000000V`3oool00`000000oooo0?ooo`0J0?ooo`03
003o003`oo00l?o`00X0l?o`00<00?oo0?3ol03`oo008@3`oo000`00o`00
oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00X0oooo00D000000?ooo`3o
ool0oooo0000000B0?ooo`03003oo`3oool0oooo04D0oooo001g0?ooo`03
0000003oool0oooo02L0oooo00<00?oo0?ooo`3oool0C03oool00`3o0000
oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`000000V`3oool00`00
0000oooo0?ooo`0J0?ooo`03003o003`oo00l?o`00X0l?o`00<00?oo0?3o
l03`oo008@3`oo000`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo
00/0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`03003oo`3oool0
oooo04H0oooo001g0?ooo`030000003oool0oooo07D0oooo00<0o`000?oo
o`3oool03@3oool3000000030?ooo`000000oooo09T0oooo00<000000?oo
o`3oool06`3oool00`00o`00l?o`0?3ol0090?3ol003003oo`3`oo00l?o`
0280l?o`00<00?l00?ooo`3oool09P3oool00`3o0000oooo0?ooo`0=0?oo
o`<0000000<0oooo0000003oool03`3oool00`00ool0oooo0?ooo`160?oo
o`00M`3oool00`000000oooo0?ooo`1d0?ooo`030?l0003oool0oooo0:d0
oooo00<000000?ooo`3oool0703oool00`00o`00l?o`0?3ol0090?3ol003
003oo`3`oo00l?o`0280l?o`00<00?l00?ooo`3oool0903oool00`3o0000
oooo0?ooo`0R0?ooo`03003oo`3oool0oooo04L0oooo001g0?ooo`030000
003oool0oooo07<0oooo00<0o`000?ooo`3oool0[P3oool00`000000oooo
0?ooo`0L0?ooo`03003o003`oo00l?o`00T0l?o`00<00?oo0?3ol03`oo00
8P3`oo000`00o`00oooo0?ooo`0S0?ooo`030?l0003oool0oooo0280oooo
00<00?oo0?ooo`3oool0B03oool007L0oooo00<000000?ooo`3oool0LP3o
ool00`3o0000oooo0?ooo`2_0?ooo`030000003oool0oooo01d0oooo00<0
0?l00?3ol03`oo00203`oo000`00ool0l?o`0?3ol00S0?3ol003003o003o
ool0oooo0240oooo00<0o`000?ooo`3oool08`3oool00`00ool0oooo0?oo
o`180?ooo`00M`3oool00`000000oooo0?ooo`1a0?ooo`030?l0003oool0
oooo0;00oooo00<000000?ooo`3oool07P3oool00`00o`00l?o`0?3ol008
0?3ol003003oo`3`oo00l?o`02<0l?o`00<00?l00?ooo`3oool07`3oool0
0`3o0000oooo0?ooo`0S0?ooo`03003oo`3oool0oooo04T0oooo001g0?oo
o`030000003oool0oooo0700oooo00<0o`000?ooo`3oool0/@3oool00`00
0000oooo0?ooo`0N0?ooo`03003o003`oo00l?o`00P0l?o`00<00?oo0?3o
l03`oo008`3`oo000`00o`00oooo0?ooo`0N0?ooo`030?l0003oool0oooo
02<0oooo00<00?oo0?ooo`3oool0BP3oool007L0oooo00<000000?ooo`3o
ool0:P3oool00`00ool0oooo0?ooo`120?ooo`030?l0003oool0oooo0;80
oooo00<000000?ooo`3oool07`3oool00`00o`00l?o`0?3ol0070?3ol003
003oo`3`oo00l?o`02@0l?o`00<00?l00?ooo`3oool0703oool00`3o0000
oooo0?ooo`0S0?ooo`03003oo`3oool0oooo04/0oooo001g0?ooo`030000
003oool0oooo02X0oooo00<00?oo0?ooo`3oool0@@3oool00`3o0000oooo
0?ooo`2c0?ooo`030000003oool0oooo0200oooo00<00?l00?3ol03`oo00
1`3`oo000`00ool0l?o`0?3ol00T0?3ol003003o003oool0oooo01X0oooo
00<0o`000?ooo`3oool08`3oool00`00ool0oooo0?ooo`1<0?ooo`00M`3o
ool00`000000oooo0?ooo`0[0?ooo`03003oo`3oool0oooo03l0oooo00<0
o`000?ooo`3oool0]03oool00`000000oooo0?ooo`0P0?ooo`03003o003`
oo00l?o`00L0l?o`00<00?oo0?3ol03`oo00903`oo000`00o`00oooo0?oo
o`0I0?ooo`030?l0003oool0oooo02<0oooo00<00?oo0?ooo`3oool0C@3o
ool007L0oooo00<000000?ooo`3oool0:`3oool00`00ool0oooo0?ooo`0n
0?ooo`030?l0003oool0oooo0;D0oooo00<000000?ooo`3oool08@3oool0
0`00o`00l?o`0?3ol0060?3ol003003oo`3`oo00l?o`02D0l?o`00<00?l0
0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0S0?ooo`03003oo`3oool0
oooo04h0oooo001g0?ooo`030000003oool0oooo02/0oooo00<00?oo0?oo
o`3oool0?03oool20?l00;P0oooo00<000000?ooo`3oool08P3oool00`00
o`00l?o`0?3ol0060?3ol003003oo`3`oo00l?o`02D0l?o`00<00?l00?oo
o`3oool0503oool20?l002D0oooo00<00?oo0?ooo`3oool0C`3oool007L0
oooo00<000000?ooo`3oool0:`3oool00`00ool0oooo0?ooo`0k0?ooo`03
0?l0003oool0oooo0;P0oooo00<000000?ooo`3oool08P3oool00`00o`00
l?o`0?3ol0060?3ol003003oo`3`oo00l?o`02D0l?o`00<00?l00?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`0T0?ooo`03003oo`3oool0oooo0500
oooo001g0?ooo`030000003oool0oooo02`0oooo00<00?oo0?ooo`3oool0
>@3oool00`3o0000oooo0?ooo`2i0?ooo`030000003oool0oooo02<0oooo
00<00?l00?3ol03`oo001P3`oo000`00ool0l?o`0?3ol00U0?3ol003003o
003oool0oooo0140oooo00<0o`000?ooo`3oool0903oool00`00ool0oooo
0?ooo`1A0?ooo`00M`3oool00`000000oooo0?ooo`0/0?ooo`03003oo`3o
ool0oooo03L0oooo0P3o002l0?ooo`030000003oool0oooo02@0oooo00<0
0?l00?3ol03`oo001@3`oo000`00ool0l?o`0?3ol00V0?3ol003003o003o
ool0oooo00h0oooo0P3o000V0?ooo`03003oo`3oool0oooo0580oooo001g
0?ooo`030000003oool0oooo06D0oooo00<0o`000?ooo`3oool0_03oool0
0`000000oooo0?ooo`0T0?ooo`03003o003`oo00l?o`00D0l?o`00<00?oo
0?3ol03`oo009P3`oo000`00o`00oooo0?ooo`0=0?ooo`030?l0003oool0
oooo02H0oooo00<00?oo0?ooo`3oool0DP3oool007L0oooo00<000000?oo
o`3oool0I03oool00`3o0000oooo0?ooo`2m0?ooo`030000003oool0oooo
02D0oooo00<00?l00?3ol03`oo001@3`oo000`00ool0l?o`0?3ol00V0?3o
l003003o003oool0oooo00/0oooo00<0o`000?ooo`3oool09P3oool00`00
ool0oooo0?ooo`1C0?ooo`00M`3oool00`000000oooo0?ooo`1R0?ooo`80
o`00`03oool00`000000oooo0?ooo`0V0?ooo`03003o003`oo00l?o`00@0
l?o`00<00?oo0?3ol03`oo009`3`oo000`00o`00oooo0?ooo`080?ooo`80
o`00:03oool00`00ool0oooo0?ooo`1D0?ooo`00M`3oool00`000000oooo
0?ooo`1Q0?ooo`030?l0003oool0oooo0<00oooo00<000000?ooo`3oool0
9P3oool00`00o`00l?o`0?3ol0040?3ol003003oo`3`oo00l?o`02L0l?o`
00<00?l00?ooo`3oool01`3oool00`3o0000oooo0?ooo`0W0?ooo`03003o
o`3oool0oooo05D0oooo001g0?ooo`030000003oool0oooo0600oooo00<0
o`000?ooo`3oool0`@3oool00`000000oooo0?ooo`0W0?ooo`03003o003`
oo00l?o`00@0l?o`00<00?oo0?3ol03`oo009`3`oo000`00o`00oooo0?oo
o`050?ooo`030?l0003oool0oooo02L0oooo00<00?oo0?ooo`3oool0EP3o
ool007L0oooo00<000000?ooo`3oool0GP3oool20?l00<@0oooo00<00000
0?ooo`3oool0:03oool00`00o`00l?o`0?3ol0030?3ol003003oo`3`oo00
l?o`02D0l?o`0P00o`060?ooo`80o`00:@3oool00`00ool0oooo0?ooo`1G
0?ooo`00M`3oool00`000000oooo0?ooo`0_0?ooo`03003oo`3oool0oooo
02/0oooo00<0o`000?ooo`3oool0a03oool00`000000oooo0?ooo`0Y0?oo
o`03003o003`oo00l?o`0080l?o`00<00?oo0?3ol03`oo00903`oo000`00
o`00oooo0?ooo`050?ooo`030?l0003oool0oooo02P0oooo00<00?oo0?oo
o`3oool0F03oool007L0oooo00<000000?ooo`3oool0;`3oool00`00ool0
oooo0?ooo`0Z0?ooo`030?l0003oool0oooo0<D0oooo00<000000?ooo`3o
ool0:@3oool00`00o`00l?o`0?3ol0030?3ol003003oo`3`oo00l?o`0240
l?o`0P00o`070?ooo`030?l0003oool0oooo02P0oooo00<00?oo0?ooo`3o
ool0F@3oool007L0oooo00<000000?ooo`3oool0<03oool00`00ool0oooo
0?ooo`0W0?ooo`80o`00b03oool00`000000oooo0?ooo`0Z0?ooo`03003o
003`oo00l?o`0080l?o`00<00?oo0?3ol03`oo00803`oo000`00o`00oooo
0?ooo`050?ooo`80o`00:P3oool00`00ool0oooo0?ooo`1J0?ooo`00M`3o
ool00`000000oooo0?ooo`0`0?ooo`03003oo`3oool0oooo02D0oooo0P3o
003:0?ooo`030000003oool0oooo02/0oooo00D00?l00?3ol03`oo00l?o`
003oo`0P0?3ol0800?l01P3oool20?l002/0oooo00<00?oo0?ooo`3oool0
F`3oool007L0oooo00<000000?ooo`3oool0<03oool00`00ool0oooo0?oo
o`0T0?ooo`030?l0003oool0oooo0<X0oooo00<000000?ooo`3oool0:`3o
ool00`00o`00l?o`0?3ol0020?3ol003003oo`3`oo00l?o`01/0l?o`0P00
o`070?ooo`030?l0003oool0oooo02X0oooo00<00?oo0?ooo`3oool0G03o
ool007L0oooo00<000000?ooo`3oool0<03oool00`00ool0oooo0?ooo`0S
0?ooo`030?l0003oool0oooo0</0oooo00<000000?ooo`3oool0;03oool0
1@00o`00l?o`0?3ol03`oo000?oo01`0l?o`00<00?l00?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0Z0?ooo`03003oo`3oool0oooo05d0oooo001g
0?ooo`030000003oool0oooo0340oooo00<00?oo0?ooo`3oool0803oool2
0?l00<h0oooo00<000000?ooo`3oool0;@3oool01@00o`00l?o`0?3ol03`
oo000?oo01T0l?o`0P00o`070?ooo`80o`00;03oool00`00ool0oooo0?oo
o`1N0?ooo`00M`3oool00`000000oooo0?ooo`0a0?ooo`03003oo`3oool0
oooo01h0oooo0P3o003@0?ooo`030000003oool0oooo02d0oooo00D00?l0
0?3ol03`oo00l?o`003oo`0H0?3ol003003o003oool0oooo00D0oooo0P3o
000]0?ooo`03003oo`3oool0oooo05l0oooo001g0?ooo`030000003oool0
oooo0540oooo00<0o`000?ooo`3oool0d03oool00`000000oooo0?ooo`0^
0?ooo`04003o003`oo00l?o`003ooaH0l?o`0P00o`070?ooo`030?l0003o
ool0oooo02`0oooo00<00?oo0?ooo`3oool0H03oool007L0oooo00<00000
0?ooo`3oool0C`3oool20?l00=<0oooo00<000000?ooo`3oool0;`3oool0
1000o`00l?o`0?3ol000oolD0?3ol003003o003oool0oooo00D0oooo0P3o
000^0?ooo`03003oo`3oool0oooo0640oooo001g0?ooo`030000003oool0
oooo04d0oooo0P3o003E0?ooo`030000003oool0oooo02l0oooo00@00?l0
0?3ol03`oo000?oo4P3`oo02003o00H0oooo0P3o000_0?ooo`03003oo`3o
ool0oooo0680oooo001g0?ooo`030000003oool0oooo04/0oooo0P3o003G
0?ooo`030000003oool0oooo0300oooo00<00?l00?3ol000ool04@3`oo00
0`00o`00oooo0?ooo`040?ooo`80o`00<03oool00`00ool0oooo0?ooo`1S
0?ooo`00M`3oool00`000000oooo0?ooo`190?ooo`80o`00f@3oool00`00
0000oooo0?ooo`0a0?ooo`03003o003`oo000?oo00h0l?o`0P00o`050?oo
o`80o`00<03oool2003oofH0oooo001g0?ooo`030000003oool0oooo04L0
oooo0P3o003K0?ooo`030000003oool0oooo0340oooo00<00?l00?3ol000
ool03@3`oo000`00o`00oooo0?ooo`030?ooo`80o`00<@3oool00`00ool0
oooo0?ooo`090?ooo`030000003oool0oooo05X0oooo001g0?ooo`030000
003oool0oooo03@0oooo00<00?oo0?ooo`3oool03@3oool30?l00=d0oooo
00<000000?ooo`3oool0<P3oool00`00o`000?oo0?3ol00:0?3ol0800?l0
0`3oool30?l00340oooo0P00ool<0?ooo`030000003oool0oooo05X0oooo
001g0?ooo`030000003oool0oooo03@0oooo00<00?oo0?ooo`3oool02`3o
ool20?l00>00oooo00<000000?ooo`3oool0<`3oool00`00o`000?oo0?3o
l0070?3ol0800?l00`3oool20?l003<0oooo00<00?oo0?ooo`3oool0303o
ool3000000X0oooo100000050?ooo`030000003oool0oooo00<0oooo0P00
00020?ooo`030000003oool0oooo03X0oooo001g0?ooo`030000003oool0
oooo03D0oooo00<00?oo0?ooo`3oool0203oool20?l00>80oooo00<00000
0?ooo`3oool0<`3oool00`00o`000?oo0?3ol0060?3ol004003o003oool0
oooo0?ooo`80o`00=03oool00`00ool0oooo0?ooo`0<0?ooo`050000003o
ool000000?ooo`0000000P3oool5000000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00800000?@3oool007L0oooo00<000000?ooo`3oool0=@3o
ool00`00ool00?l0003o00060?ooo`80o`00i03oool00`000000oooo0?oo
o`0d0?ooo`04003oo`00o`000?l0003o0080l?o`0P00o`020?ooo`80o`00
=@3oool00`00ool0oooo0?ooo`0=0?ooo`050000003oool000000?ooo`00
0000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
00000P3oool01@000000oooo0?ooo`3oool0000003d0oooo001g0?ooo`03
0000003oool0oooo03@0oooo00<00?l0003oo`00o`000P00o`020?ooo`<0
o`00iP3oool00`000000oooo0?ooo`0d0?ooo`03003o0000ool00?l000<0
0?l000@0oooo0?l0003o0000o`00=P3oool00`00ool0oooo0?ooo`0>0?oo
o`050000003oool000000?ooo`0000000P3oool5000000030?ooo`000000
oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000?@3oool007L0oooo00<000000?ooo`3oool0<`3o
ool2003o0004003oo`00o`000?l0003o0080o`00j@3oool00`000000oooo
0?ooo`0c0?ooo`800?l000@00?oo003o0000o`000?l00P3o000g0?ooo`80
0?oo4@3oool01@000000oooo0000003oool0000000P0oooo1`0000030?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000m
0?ooo`00M`3oool00`000000oooo0?ooo`0c0?ooo`<00?l000@00?oo003o
0000o`000?l0jP3oool00`000000oooo0?ooo`0c0?ooo`<00?l000@00?oo
003o0000o`000?l0=`3oool00`00ool0oooo0?ooo`0B0?ooo`<000002@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0`00
00000`3oool000000?ooo`0k0?ooo`00M`3oool00`000000oooo0?ooo`0c
0?ooo`<00?l000@00?oo003o0000o`000?l0jP3oool00`000000oooo0?oo
o`0c0?ooo`<00?l000@00?oo003o0000o`000?l0=@3oool2003ooaL0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo04P0oooo001g0?ooo`030000003oool0oooo03@0oooo1@00
o`3[0?ooo`030000003oool0oooo03@0oooo0P00o`000`00ool00?l0003o
000e0?ooo`03003oo`3oool0oooo01L0oooo00<000000?ooo`3oool02@3o
ool4000004/0oooo001g0?ooo`030000003oool0oooo03D0oooo0`00o`3/
0?ooo`030000003oool0oooo03D0oooo0P00o`000`00ool0oooo0?ooo`0b
0?ooo`800?ooM@3oool007L0oooo00<000000?ooo`3oool0o`3ooolU0?oo
o`030000003oool0oooo03L0oooo00<00?oo0?ooo`3oool0<@3oool00`00
ool0oooo0?ooo`1e0?ooo`00M`3oool00`000000oooo0?ooo`3o0?ooobD0
oooo00<000000?ooo`3oool0=`3oool00`00ool0oooo0?ooo`0_0?ooo`80
0?ooN03oool007L0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`030000
003oool0oooo03P0oooo00<00?oo0?ooo`3oool0;@3oool00`00ool0oooo
0?ooo`1h0?ooo`00M`3oool00`000000oooo0?ooo`3o0?ooobD0oooo00<0
00000?ooo`3oool0>03oool00`00ool0oooo0?ooo`0[0?ooo`800?ooN`3o
ool007L0oooo00<000000?ooo`3oool0>@3oool00`00ool0oooo0?ooo`06
0?ooo`030000003oool0000000X0oooo1@0000020?ooo`D00000b@3oool0
0`000000oooo0?ooo`0h0?ooo`03003oo`3oool0oooo02X0oooo00<00?oo
0?ooo`3oool0N`3oool007L0oooo00<000000?ooo`3oool0>@3oool00`00
ool0oooo0?ooo`050?ooo`050000003oool000000?ooo`0000000P3oool5
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000003<
0?ooo`030000003oool0oooo03T0oooo00<00?oo0?ooo`3oool09`3oool2
003oogh0oooo001g0?ooo`030000003oool0oooo03X0oooo00<00?oo0?oo
o`3oool0103oool01@000000oooo0000003oool0000000X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0000003<0?ooo`030000003oool0
oooo03T0oooo00<00?oo0?ooo`3oool09@3oool2003ooh00oooo001g0?oo
o`030000003oool0oooo03X0oooo00<00?oo0?ooo`3oool0103oool01@00
0000oooo0000003oool000000080oooo1@0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000000`00000<0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0i
0?ooo`03003oo`3oool0oooo02@0oooo00<00?oo0?ooo`3oool0P03oool0
07L0oooo00<000000?ooo`3oool0>P3oool00`00ool0oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000002P3oool2000000<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2W
0?ooo`030000003oool0oooo03X0oooo00<00?oo0?ooo`3oool08@3oool2
003ooh<0oooo001g0?ooo`030000003oool0oooo03X0oooo00<00?oo0?oo
o`3oool00`3oool3000000040?ooo`0000000000000000P0oooo0P000000
0`3oool00000000000020?ooo`@000000`3oool3000000D0oooo00<00000
0?ooo`3oool00P3oool2000000@0oooo00@000000?ooo`3oool0oooo0P00
00000`3oool000000?ooo`020?ooo`030000003oool0oooo0:H0oooo00<0
00000?ooo`3oool0>P3oool00`00ool0oooo0?ooo`0O0?ooo`800?ooQ@3o
ool007L0oooo00<000000?ooo`3oool0>`3oool00`00ool0oooo0?ooo`0P
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0000000D000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0>`3o
ool00`00ool0oooo0?ooo`0M0?ooo`03003oo`3oool0oooo08D0oooo001g
0?ooo`030000003oool0oooo03/0oooo00<00?oo0?ooo`3oool0803oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0YP3oool01P000000oooo0?ooo`000000oooo
000000/0oooo1@0000020?ooo`D000008@3oool00`00ool0oooo0?ooo`0K
0?ooo`800?ooR03oool007L0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`D000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0YP3oool01`000000oooo0000003oool000000?ooo`00
00000`3oool5000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000T0?ooo`03003oo`3oool0oooo01T0oooo0P00oon:0?ooo`00
M`3oool00`000000oooo0?ooo`1M0?ooo`8000001`3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool200000005
0?ooo`000000oooo0?ooo`000000Z@3oool01`000000oooo0000003oool0
00000?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000l0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?oo
o`3oool00?oo01L0oooo0`00oon<0?ooo`00M`3oool00`000000oooo0?oo
o`1W0?ooo`040000003oool0oooo0?ooo`800000303oool00`000000oooo
0?ooo`2X0?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`D000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00<000002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00@000000?ooo`3oool00?oo5@3oool2003oohl0oooo001g0?oo
o`030000003oool0oooo05h0oooo00<000000?ooo`3oool0``3oool00`00
0000oooo000000030?ooo`030000003oool0oooo00T0oooo0P0000030?oo
o`030000003oool000000080oooo00<000000?ooo`3oool00`0000050?oo
o`030000003oool0oooo0080oooo0P0000040?ooo`040000003oool0oooo
0?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo003oo`0D
0?ooo`03003oo`3oool0oooo08l0oooo001g0?ooo`030000003oool0oooo
0?l0oooo9@3oool4000000040?ooo`0000000000000000T0oooo0P000000
0`3oool00000000000020?ooo`@00000103oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0000
000500000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00oolA0?ooo`800?ooTP3oool007L0oooo00<000000?ooo`3oool0o`3o
oolU0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
003oo`h0oooo0`00oonD0?ooo`00M`3oool00`000000oooo0?ooo`0n0?oo
o`03003oo`3oool0oooo0><0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`D000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00?oo303oool2003ooiL0oooo001g0?ooo`030000003o
ool0oooo03h0oooo00<00?oo0?ooo`3oool0h`3oool00`000000oooo0?oo
o`0L0?ooo`8000001`3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0103oool2000000050?ooo`000000oooo0?ooo`00
0000103oool00`00ool0oooo0?ooo`070?ooo`800?ooV@3oool007L0oooo
00<000000?ooo`3oool0?`3oool00`00ool0oooo0?ooo`3R0?ooo`030000
003oool0oooo02H0oooo00@000000?ooo`3oool0oooo0P00000<0?ooo`03
0000003oool0oooo00<0oooo00<00?oo0?ooo`3oool0103oool3003ooi/0
oooo001g0?ooo`030000003oool0oooo03l0oooo00<00?oo0?ooo`3oool0
hP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo
00<00?oo0?ooo`3oool00P3oool2003ooih0oooo001g0?ooo`030000003o
ool0oooo03l0oooo00<00?oo0?ooo`3oool0hP3oool00`000000oooo0?oo
o`0o0?ooo`@00?ooX03oool007L0oooo00<000000?ooo`3oool0?`3oool0
0`00ool0oooo0?ooo`3R0?ooo`030000003oool0oooo03l0oooo00<00?oo
0?ooo`3oool0X@3oool007L0oooo00<000000?ooo`3oool0@03oool00`00
ool0oooo0?ooo`3Q0?ooo`030000003oool0oooo0400oooo00<00?oo0?oo
o`3oool0X03oool007L0oooo00<000000?ooo`3oool0@03oool00`00ool0
oooo0?ooo`3Q0?ooo`030000003oool0oooo0400oooo00<00?oo0?ooo`3o
ool0X03oool007L0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`030000
003oool0oooo0400oooo00<00?oo0?ooo`3oool0X03oool007L0oooo00<0
00000?ooo`3oool0o`3ooolU0?ooo`030000003oool0oooo0440oooo00<0
0?oo0?ooo`3oool0W`3oool007L0oooo00<000000?ooo`3oool0o`3ooolU
0?ooo`030000003oool0oooo0440oooo00<00?oo0?ooo`3oool0W`3oool0
07L0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`030000003oool0oooo
0><0oooo001g0?ooo`030000003oool0oooo0?l0oooo9@3oool00`000000
oooo0?ooo`3S0?ooo`00M`3oool00`000000oooo0?ooo`3o0?ooobD0oooo
00<000000?ooo`3oool0h`3oool007L0oooo00<000000?ooo`3oool0o`3o
oolU0?ooo`030000003oool0oooo0><0oooo001g0?ooo`030000003oool0
oooo0?l0oooo9@3oool00`000000oooo0?ooo`3S0?ooo`00M`3oool00`00
0000oooo0?ooo`3o0?ooobD0oooo00<000000?ooo`3oool0h`3oool007L0
oooo00<000000?ooo`3oool0o`3ooolU0?ooo`030000003oool0oooo0><0
oooo001g0?ooo`030000003oool0oooo0?l0oooo9@3oool00`000000oooo
0?ooo`3S0?ooo`00M`3oool00`000000oooo0?ooo`3o0?ooobD0oooo00<0
00000?ooo`3oool0h`3oool007L0oooo00<000000?ooo`3oool0o`3ooolU
0?ooo`030000003oool0oooo0><0oooo001g0?ooo`030000003oool0oooo
0?l0oooo9@3oool00`000000oooo0?ooo`3S0?ooo`00M`3oool00`000000
oooo0?ooo`3o0?ooobD0oooo00<000000?ooo`3oool0h`3oool007L0oooo
00<000000?ooo`3oool0o`3ooolU0?ooo`030000003oool0oooo0><0oooo
001g0?ooo`030000003oool0oooo0?l0oooo9@3oool00`000000oooo0?oo
o`3S0?ooo`00o`3ooooo0?ooohH0oooo003o0?ooool0ooooQP3oool00?l0
ooooo`3ooon60?ooo`00o`3ooooo0?ooohH0oooo003o0?ooool0ooooQP3o
ool00?l0ooooo`3ooon60?ooo`00o`3ooooo0?ooohH0oooo003o0?ooool0
ooooQP3oool007D0oooo0P00003o0?ooool0oooo3`3oool007H0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`d0oooo001g0?ooo`030000003oool0
oooo0?l0oooo903oool200000>D0oooo001f0?ooo`030000003oool00000
0?l0oooo9@3oool200000>D0oooo001e0?ooo`040000003oool0oooo0000
0?l0oooo903oool010000000oooo0?ooo`00003T0?ooo`00M03oool30000
00030?ooo`00000000000?l0oooo8P3oool200000080oooo0P00003S0?oo
o`00o`3ooooo0?ooohH0oooo003o0?ooool0ooooQP3oool00?l0ooooo`3o
oon60?ooo`00o`3ooooo0?ooohH0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{644, 235},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\t\t\tFigure 2.6",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The rotation  ",
  Cell[BoxData[
      \(w = \(R \((z)\) = 
          r\ \[ExponentialE]\^\(\[ImaginaryI] \((\[Theta] + \
\[Alpha])\)\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 2.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The ellipse centered at the origin with a horizontal major axis of 4 \
units and vertical minor axis of 2 units can be represented by the parametric \
equation  \n\n\t\t",
  Cell[BoxData[
      \(s \((t)\)\  = \ \(2  cos\ t + \[ImaginaryI]\ sin\ t\  = \ \((2  
              cos\ t, sin\ t)\)\)\)]],
  ",   for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 2  \[Pi]\)]],
  ".  \n\nSuppose we wanted to rotate the ellipse by an angle of ",
  Cell[BoxData[
      \(\[Pi]\/6\)]],
  " radians and shift the center of the ellipse 2 units to the right and 1 \
unit up. Using complex arithmetic, we can easily generate a parametric \
equation ",
  StyleBox["r(t)",
    FontFamily->"Courier New"],
  " that does so:\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(r[t] = 
        s[t]\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/6\) + \((2 + \
\[ImaginaryI])\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \(\(\(=\)\(\((2  
                  cos\ t + \[ImaginaryI]\ sin\ t)\) \((cos\ \[Pi]\/6 + \
\[ImaginaryI]\ sin\ \[Pi]\/6)\) + \((2 + \[ImaginaryI])\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \(\(\(=\)\(\((2\ cos\ t\ cos  \[Pi]\/6\  - 
              sin\ t\ sin  \[Pi]\/6\ )\) + \[ImaginaryI]\ \((2\ cos\ t\ sin  \
\[Pi]\/6 + \ 
                sin\ t\ cos  \[Pi]\/6)\) + \((2 + \[ImaginaryI])\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \(\(=\)\(\((\@3\ cos\ t\  - \(1\/2\) sin\ t\  + 
              2)\) + \[ImaginaryI]\ \((cos\ t\  + \@3\/2\ \ sin\ t\  + 
                1)\)\)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \(\(=\)\((\@3\ cos\ t\  - \(1\/2\) sin\ t\  + 2, \ 
          cos\ t\  + \@3\/2\ \ sin\ t\  + 1)\)\)\)}]],
  "    \nfor  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 2  \[Pi]\)]],
  ".  Figure 2.7 shows parametric plots of these ellipses."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008Y0000^R000`400?l0
0000o`00003oo`3ooooo0?ooob/0oooo003o0?ooool0oooo:`3oool00?l0
ooooo`3oool[0?ooo`00o`3ooooo0?ooob/0oooo003o0?ooool0oooo:`3o
ool00?l0ooooo`3oool[0?ooo`00o`3ooooo0?ooob/0oooo003o0?ooool0
oooo:`3oool009D0oooo1@0000030?ooo`030000003oool0oooo0?l0oooo
RP3oool009L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?ooohX0oooo002G0?ooo`030000003oool0oooo00<0oooo00<0o`3o
000000000000Z`3oool00`000000oooo0?ooo`3K0?ooo`00R`3ooolU0?l0
oi/0oooo00<000000?ooo`3oool0f`3oool007l0oooo303o0?l<0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool;0?l0oi00
oooo00<000000?ooo`3oool0f`3oool007T0oooo1P3o0?lG0?ooo`800000
1@3oool00`000000oooo0?ooo`0K0?ooo`D0o`3oR`3oool00`000000oooo
0?ooo`3K0?ooo`00M@3oool40?l0ob@0oooo00<000000?ooo`3oool0803o
ool40?l0ohL0oooo00<000000?ooo`3oool0f`3oool00740oooo103o0?lX
0?ooo`030000003oool0oooo02@0oooo103o0?n30?ooo`030000003oool0
oooo0=/0oooo001]0?ooo`@0o`3o;03oool00`000000oooo0?ooo`0X0?oo
o`D0o`3oOP3oool00`000000oooo0?ooo`3K0?ooo`00JP3oool30?l0oc00
oooo00<000000?ooo`3oool0;@3oool40?l0ogX0oooo00<000000?ooo`3o
ool0f`3oool006L0oooo0`3o0?lc0?ooo`030000003oool0oooo0340oooo
103o0?mf0?ooo`030000003oool0oooo0=/0oooo001T0?ooo`<0o`3o=P3o
ool00`000000oooo0?ooo`0e0?ooo`@0o`3oLP3oool00`000000oooo0?oo
o`0[0?ooo`l0o`3oX@3oool00640oooo0`3o0?li0?ooo`030000003oool0
oooo03T0oooo0P3o0?m`0?ooo`030000003oool0oooo02<0oooo203o0?l?
0?ooo`H0o`3oV`3oool005l0oooo0P3o0?ll0?ooo`030000003oool0oooo
03/0oooo0`3o0?m]0?ooo`030000003oool0oooo0200oooo0`3o0?lM0?oo
o`H0o`3oU@3oool005`0oooo0`3o0?ln0?ooo`030000003oool0oooo03h0
oooo0P3o0?m[0?ooo`030000003oool0oooo01h0oooo0P3o0?lV0?ooo`D0
o`3oT03oool005X0oooo0P3o0?m10?ooo`030000003oool0oooo0400oooo
0`3o0?mX0?ooo`030000003oool0oooo01/0oooo0`3o0?l]0?ooo`D0o`3o
R`3oool005P0oooo0P3o0?m30?ooo`030000003oool0oooo04<0oooo0P3o
0?mV0?ooo`030000003oool0oooo01P0oooo0`3o0?le0?ooo`<0o`3oR03o
ool005H0oooo0P3o0?m50?ooo`030000003oool0oooo04D0oooo0P3o0?mT
0?ooo`030000003oool0oooo0100oooo0P0000040?ooo`80o`3o103oool2
00000100oooo1@00000?0?ooo`D000000P3oool2000000@0oooo0P000002
0?ooo`80o`3o303oool400000100oooo100000030?ooo`800000103oool2
00000140oooo0P00000B0?ooo`800000103oool2000000@0oooo0P00000B
0?ooo`<000003`3oool005@0oooo0P3o0?m70?ooo`030000003oool0oooo
04L0oooo0P3o0?mR0?ooo`030000003oool0oooo00l0oooo00D000000?oo
o`3oool000000?ooo`020?l0o`D0oooo00@000000?ooo`3oool000004@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`3oool000000`3oool30?l0o`T0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000l0
oooo00@000000?ooo`3oool00000403oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool03P3o
ool00580oooo0P3o0?m90?ooo`030000003oool0oooo04T0oooo0P3o0?mP
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3o0?l:
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo0`3o0?l7
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`D000003`3oool0
0500oooo0P3o0?m;0?ooo`030000003oool0oooo04/0oooo0P3o0?mN0?oo
o`030000003oool0oooo00l0oooo00@000000?ooo`3o0?l000002@3oool2
00000180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`08
0?ooo`8000002P3oool30?l0o`D0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`080?ooo`8000004`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00L0oooo0P00000@0?ooo`040000003oool0
oooo00000100oooo001>0?ooo`80o`3oC@3oool00`000000oooo0?ooo`1=
0?ooo`030?l0o`3oool0oooo05/0oooo00<000000?ooo`3oool03`3oool0
10000000oooo0?l0o`0000090?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00`0oooo0`3o0?l010000000oooo0?ooo`00000@0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool03`3oool010000000
oooo0?ooo`00000@0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0000000@0?ooo`00C03oool20?l0
odl0oooo00<000000?ooo`3oool0CP3oool20?l0oe/0oooo00<000000?oo
o`3oool0403oool00`3o0?l000000?ooo`090?ooo`<00000403oool20000
0180oooo0P00000:0?ooo`<000003`3oool30?l0oa80oooo0P00000:0?oo
o`<00000403oool200000180oooo0P00000:0?ooo`<000004@3oool20000
0100oooo001;0?ooo`030?l0o`3oool0oooo04l0oooo00<000000?ooo`3o
ool0D03oool00`3o0?l0oooo0?ooo`1H0?ooo`030000003oool0oooo00h0
oooo0P3o0?mD0?ooo`<0o`3oM03oool004T0oooo0P3o0?mB0?ooo`030000
003oool0oooo0540oooo00<0o`3o0?ooo`3oool0E`3oool00`000000oooo
0?ooo`0=0?ooo`030?l0o`3oool0oooo05L0oooo0P3o0?mb0?ooo`00A`3o
ool20?l0oe@0oooo00<000000?ooo`3oool0DP3oool20?l0oeL0oooo00<0
00000?ooo`3oool0303oool00`3o0?l0oooo0?ooo`1J0?ooo`80o`3oL03o
ool004H0oooo00<0o`3o0?ooo`3oool0@@3oool2000000@0oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`1D0?ooo`030?l0o`3oool0
oooo05@0oooo00<000000?ooo`3oool0303oool00`3o0?l0oooo0?ooo`1L
0?ooo`80o`3oIP3oool4000000@0oooo00150?ooo`030?l0o`3oool0oooo
0440oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo05D0oooo00<0o`3o0?ooo`3oool0D`3o
ool00`000000oooo0?ooo`0;0?ooo`030?l0o`3oool0oooo05l0oooo0P3o
0?mS0?ooo`040000003oool0oooo000000D0oooo00140?ooo`030?l0o`3o
ool0oooo0480oooo00@000000?ooo`3oool000002`3oool00`000000oooo
0?ooo`020?ooo`<00000EP3oool00`3o0?l0oooo0?ooo`1B0?ooo`h00000
00<0o`3o000000000000H@0000020?l0oeT00000203oool010000000oooo
0?ooo`0000050?ooo`00@`3oool00`3o0?l0oooo0?ooo`0m0?ooo`@00000
0P3oool010000000oooo0?ooo`0000090?ooo`8000001@3oool00`000000
oooo0?ooo`1G0?ooo`80o`3oDP3oool00`000000oooo0?ooo`0:0?ooo`03
0?l0o`3oool0oooo00X0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool02`3oool20?l0o`X0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool01@3oool2000000030?ooo`000000000000D0oooo00120?ooo`030?l0
o`3oool0oooo04@0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo05T0oooo00<0o`3o0?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0:0?ooo`030?l0o`3oool0oooo06H0
oooo0P3o0?mV0?ooo`00@@3oool00`3o0?l0oooo0?ooo`160?ooo`800000
2P3oool3000000@0oooo00<000000?ooo`3oool0FP3oool00`3o0?l0oooo
0?ooo`1>0?ooo`030000003oool0oooo00T0oooo00<0o`3o0?ooo`3oool0
J@3oool20?l0of@0oooo00100?ooo`030?l0o`3oool0oooo05X0oooo00<0
00000?ooo`3oool0F`3oool00`3o0?l0oooo0?ooo`1=0?ooo`030000003o
ool0oooo00P0oooo00<0o`3o0?ooo`3oool0K03oool20?l0of80oooo000o
0?ooo`030?l0o`3oool0oooo05/0oooo00<000000?ooo`3oool0F`3oool0
0`3o0?l0oooo0?ooo`1=0?ooo`030000003oool0oooo00P0oooo00<0o`3o
0?ooo`3oool0KP3oool20?l0of00oooo000n0?ooo`030?l0o`3oool0oooo
05`0oooo00<000000?ooo`3oool0G03oool00`3o0?l0oooo0?ooo`1<0?oo
o`030000003oool0oooo00P0oooo00<0o`3o0?ooo`3oool0L03oool20?l0
oeh0oooo000m0?ooo`030?l0o`3oool0oooo05d0oooo00<000000?ooo`3o
ool0G@3oool00`3o0?l0oooo0?ooo`1;0?ooo`030000003oool0oooo00P0
oooo00<0o`3o0?ooo`3oool0LP3oool20?l0oe`0oooo000m0?ooo`030?l0
o`3oool0oooo05d0oooo00<000000?ooo`3oool0GP3oool00`3o0?l0oooo
0?ooo`1:0?ooo`030000003oool0oooo00P0oooo00<0o`3o0?ooo`3oool0
M03oool00`3o0?l0oooo0?ooo`1I0?ooo`00?03oool00`3o0?l0oooo0?oo
o`1N0?ooo`030000003oool0oooo05h0oooo00<0o`3o0?ooo`3oool0BP3o
ool00`000000oooo0?ooo`080?ooo`030?l0o`3oool0oooo07D0oooo0P3o
0?mI0?ooo`00>`3oool00`3o0?l0oooo0?ooo`1O0?ooo`030000003oool0
oooo05l0oooo00<0o`3o0?ooo`3oool0B@3oool00`000000oooo0?ooo`07
0?ooo`030?l0o`3oool0oooo07P0oooo00<0o`3o0?ooo`3oool0EP3oool0
03X0oooo00<0o`3o0?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?oo
o`030?l0o`3oool0oooo04P0oooo00<000000?ooo`3oool01`3oool00`3o
0?l0oooo0?ooo`1i0?ooo`030?l0o`3oool0oooo05D0oooo000j0?ooo`03
0?l0o`3oool0oooo0600oooo00<000000?ooo`3oool0H03oool00`3o0?l0
oooo0?ooo`180?ooo`030000003oool0oooo00L0oooo00<0o`3o0?ooo`3o
ool0NP3oool20?l0oeD0oooo000i0?ooo`030?l0o`3oool0oooo0640oooo
00<000000?ooo`3oool0H@3oool00`3o0?l0oooo0?ooo`170?ooo`030000
003oool0oooo00L0oooo00<0o`3o0?ooo`3oool0O03oool00`3o0?l0oooo
0?ooo`1B0?ooo`00>03oool00`3o0?l0oooo0?ooo`1R0?ooo`030000003o
ool0oooo0680oooo00<0o`3o0?ooo`3oool0AP3oool00`000000oooo0?oo
o`070?ooo`030?l0o`3oool0oooo07d0oooo0P3o0?mB0?ooo`00=`3oool0
10000000o`3o00000000000@0?ooo`D000000P3oool2000000@0oooo0P00
000@0?ooo`D00000403oool2000000@0oooo0P0000040?ooo`800000403o
ool00`000000oooo0?ooo`0@0?ooo`800000103oool2000000@0oooo0P00
000A0?ooo`D000003`3oool500000080oooo0P0000040?ooo`800000403o
ool00`3o0?l0000000000002000004@0oooo00<000000?ooo`3oool01`3o
ool00`3o0?l0oooo0?ooo`1o0?ooo`030?l0o`3oool0oooo04l0oooo000g
0?ooo`030?l0o`3oool0oooo01<0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`00000A0?ooo`030000003oool0oooo00l0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`00000?0?ooo`03
0000003oool0oooo00l0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`00000B0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool01`3oool010000000oooo0?ooo`00000@0?ooo`030?l0o`3o
ool0oooo04D0oooo00<000000?ooo`3oool01`3oool00`3o0?l0oooo0?oo
o`200?ooo`80o`3oC`3oool003L0oooo00<0o`3o0000003oool04`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03`3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo
00<0o`3o0000003oool0A@3oool00`000000oooo0?ooo`070?ooo`030?l0
o`3oool0oooo0880oooo00<0o`3o0?ooo`3oool0C03oool00340oooo1000
00020?ooo`030?l0o`3oool0000000/0oooo100000040?ooo`030000003o
ool0oooo00P0oooo0P00000:0?ooo`@00000103oool00`000000oooo0?oo
o`090?ooo`@000000P3oool010000000oooo0?ooo`0000090?ooo`800000
403oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000000T0
oooo0P00000C0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0203oool200000140oooo00<0o`3o0?ooo`000000A@3oool00`000000
oooo0?ooo`070?ooo`030?l0o`3oool0oooo08<0oooo00<0o`3o0?ooo`3o
ool0B`3oool003L0oooo00@0o`3o0?ooo`3oool000004P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool03`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00@0o`3o
0?ooo`3oool00000A03oool00`000000oooo0?ooo`080?ooo`030?l0o`3o
ool0oooo08<0oooo0P3o0?m;0?ooo`00=P3oool0103o0?l0oooo00000000
000B0?ooo`8000002P3oool300000100oooo0P00000B0?ooo`8000002P3o
ool3000000l0oooo00<000000?ooo`3oool0403oool2000000X0oooo0`00
000A0?ooo`8000004P3oool2000000X0oooo0`00000A0?ooo`030?l0o`00
0000oooo04@0oooo00<000000?ooo`3oool0203oool00`3o0?l0oooo0?oo
o`250?ooo`030?l0o`3oool0oooo04P0oooo000f0?ooo`030?l0o`3oool0
oooo06@0oooo00<000000?ooo`3oool0I03oool00`3o0?l0oooo0?ooo`14
0?ooo`030000003oool0oooo00P0oooo00<0o`3o0?ooo`3oool0QP3oool2
0?l0odP0oooo000f0?ooo`030?l0o`3oool0oooo06@0oooo00<000000?oo
o`3oool0I03oool00`3o0?l0oooo0?ooo`140?ooo`030000003oool0oooo
00P0oooo00<0o`3o0?ooo`3oool0R03oool00`3o0?l0oooo0?ooo`150?oo
o`00=P3oool00`3o0?l0oooo0?ooo`1T0?ooo`030000003oool0oooo06@0
oooo00<0o`3o0?ooo`3oool0<P3oool2000000@0oooo0P0000040?ooo`80
0000103oool00`000000oooo0?ooo`080?ooo`030?l0o`3oool0oooo08T0
oooo00<0o`3o0?ooo`3oool0A03oool003H0oooo00<0o`3o0?ooo`3oool0
I03oool00`000000oooo0?ooo`1T0?ooo`80o`3o<P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0203oool00`3o0?l0oooo0?ooo`2:0?ooo`030?l0o`3oool0oooo
04<0oooo000f0?ooo`030?l0o`3oool0oooo06@0oooo00<000000?ooo`3o
ool0I@3oool00`3o0?l0oooo0?ooo`090?ooo`80000000<0oooo00000000
00008P3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo
0?ooo`8000002P3oool00`3o0?l0oooo0?ooo`2:0?ooo`030?l0o`3oool0
oooo0480oooo000a0?ooo`D0000000<0o`3o000000000000c00000000`3o
0?l0000000000003000000L0oooo00<000000?ooo`0000008`3oool01000
0000oooo0?ooo`0000090?ooo`800000103oool00`000000oooo0?ooo`09
0?ooo`030?l0o`3oool0oooo08/0oooo0P3o0?m20?ooo`00=P3oool00`3o
0?l0oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo01L0oooo00<0o`3o0?ooo`3oool02`3oool00`00
0000oooo0?ooo`0R0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030?l0o`3oool0
oooo08d0oooo00<0o`3o0?ooo`3oool0?`3oool003H0oooo00<0o`3o0?oo
o`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0G0?ooo`030?l0o`3oool0oooo00T0oooo0P0000000`3o
ool000000000000S0?ooo`8000002P3oool3000000<0oooo00<000000?oo
o`3oool02@3oool00`3o0?l0oooo0?ooo`2>0?ooo`030?l0o`3oool0oooo
03h0oooo000f0?ooo`030?l0o`3oool0oooo06@0oooo00<000000?ooo`3o
ool0I03oool20?l0odD0oooo00<000000?ooo`3oool02P3oool00`3o0?l0
oooo0?ooo`2>0?ooo`030?l0o`3oool0oooo03d0oooo000f0?ooo`030?l0
o`3oool0oooo06@0oooo00<000000?ooo`3oool0I03oool00`3o0?l0oooo
0?ooo`140?ooo`030000003oool0oooo00X0oooo00<0o`3o0?ooo`3oool0
S`3oool00`3o0?l0oooo0?ooo`0l0?ooo`00=P3oool00`3o0?l0oooo0?oo
o`1T0?ooo`030000003oool0oooo06@0oooo00<0o`3o0?ooo`3oool0A03o
ool00`000000oooo0?ooo`0;0?ooo`030?l0o`3oool0oooo08l0oooo00<0
o`3o0?ooo`3oool0>`3oool003H0oooo00<0o`3o0?ooo`3oool0I03oool0
0`000000oooo0?ooo`1T0?ooo`030?l0o`3oool0oooo04@0oooo00<00000
0?ooo`3oool02`3oool00`3o0?l0oooo0?ooo`2@0?ooo`030?l0o`3oool0
oooo03X0oooo000g0?ooo`030?l0o`3oool0oooo06<0oooo00<000000?oo
o`3oool0I03oool00`3o0?l0oooo0?ooo`140?ooo`030000003oool0oooo
00/0oooo00<0o`3o0?ooo`3oool0T@3oool00`3o0?l0oooo0?ooo`0i0?oo
o`00=`3oool00`3o0?l0oooo0?ooo`1S0?ooo`030000003oool0oooo06<0
oooo00<0o`3o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0<0?ooo`03
0?l0o`3oool0oooo0940oooo00<0o`3o0?ooo`3oool0>03oool003P0oooo
00<0o`3o0?ooo`3oool0HP3oool00`000000oooo0?ooo`1S0?ooo`030?l0
o`3oool0oooo04D0oooo00<000000?ooo`3oool0303oool00`3o0?l0oooo
0?ooo`2B0?ooo`80o`3o>03oool003P0oooo00<0o`3o0?ooo`3oool0HP3o
ool00`000000oooo0?ooo`1S0?ooo`030?l0o`3oool0oooo04D0oooo00<0
00000?ooo`3oool03@3oool00`3o0?l0oooo0?ooo`2C0?ooo`030?l0o`3o
ool0oooo03D0oooo000h0?ooo`030?l0o`3oool0oooo0680oooo00<00000
0?ooo`3oool0HP3oool00`3o0?l0oooo0?ooo`160?ooo`030000003oool0
oooo00d0oooo00<0o`3o0?ooo`3oool0U03oool00`3o0?l0oooo0?ooo`0d
0?ooo`00>@3oool00`3o0?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo
0680oooo00<0o`3o0?ooo`3oool0AP3oool00`000000oooo0?ooo`0>0?oo
o`030?l0o`3oool0oooo09@0oooo00<0o`3o0?ooo`3oool0<`3oool003T0
oooo00<0o`3o0?ooo`3oool0H@3oool00`000000oooo0?ooo`1Q0?ooo`03
0?l0o`3oool0oooo04L0oooo00<000000?ooo`3oool03P3oool00`3o0?l0
oooo0?ooo`2E0?ooo`030?l0o`3oool0oooo0380oooo000i0?ooo`030?l0
o`3oool0oooo0640oooo00<000000?ooo`3oool0H03oool00`3o0?l0oooo
0?ooo`180?ooo`030000003oool0oooo00l0oooo00<0o`3o0?ooo`3oool0
U@3oool00`3o0?l0oooo0?ooo`0a0?ooo`00>P3oool00`3o0?l0oooo0?oo
o`1P0?ooo`030000003oool0oooo0600oooo00<0o`3o0?ooo`3oool0B03o
ool00`000000oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo09H0oooo00<0
o`3o0?ooo`3oool0<03oool003X0oooo00<0o`3o0?ooo`3oool0H03oool0
0`000000oooo0?ooo`1O0?ooo`030?l0o`3oool0oooo04T0oooo00<00000
0?ooo`3oool0403oool00`3o0?l0oooo0?ooo`2E0?ooo`030?l0o`3oool0
oooo0300oooo000k0?ooo`030?l0o`3oool0oooo05l0oooo00<000000?oo
o`3oool0G`3oool00`3o0?l0oooo0?ooo`190?ooo`030000003oool0oooo
0100oooo00<0o`3o0?ooo`3oool0UP3oool00`3o0?l0oooo0?ooo`0_0?oo
o`00?03oool00`3o0?l0oooo0?ooo`1N0?ooo`030000003oool0oooo05h0
oooo00<0o`3o0?ooo`3oool0BP3oool00`000000oooo0?ooo`0A0?ooo`03
0?l0o`3oool0oooo09H0oooo00<0o`3o0?ooo`3oool0;P3oool003d0oooo
00<0o`3o0?ooo`3oool0G@3oool00`000000oooo0?ooo`1N0?ooo`030?l0
o`3oool0oooo04X0oooo00<000000?ooo`3oool04P3oool00`3o0?l0oooo
0?ooo`2F0?ooo`030?l0o`3oool0oooo02d0oooo000n0?ooo`030?l0o`3o
ool0oooo05`0oooo00<000000?ooo`3oool0G@3oool00`3o0?l0oooo0?oo
o`1;0?ooo`030000003oool0oooo0180oooo00<0o`3o0?ooo`3oool0U`3o
ool00`3o0?l0oooo0?ooo`0/0?ooo`00?`3oool00`3o0?l0oooo0?ooo`1K
0?ooo`030000003oool0oooo05`0oooo00<0o`3o0?ooo`3oool0C03oool0
0`000000oooo0?ooo`0C0?ooo`030?l0o`3oool0oooo09L0oooo00<0o`3o
0?ooo`3oool0:`3oool003l0oooo00<0o`3o0?ooo`3oool0F`3oool00`00
0000oooo0?ooo`1K0?ooo`030?l0o`3oool0oooo04d0oooo00<000000?oo
o`3oool0503oool00`3o0?l0oooo0?ooo`2F0?ooo`030?l0o`3oool0oooo
02/0oooo00100?ooo`030?l0o`3oool0oooo05X0oooo00<000000?ooo`3o
ool0F@3oool20?l0odT0oooo1@0000020?ooo`030000003oool0oooo01@0
oooo00<0o`3o0?ooo`3oool0U`3oool00`3o0?l0oooo0?ooo`0Z0?ooo`00
@@3oool00`3o0?l0oooo0?ooo`160?ooo`800000103oool2000000@0oooo
0P0000050?ooo`030000003oool0oooo05P0oooo00<0o`3o0?ooo`3oool0
B`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo
00<0o`3o0?ooo`3oool0U`3oool00`3o0?l0oooo0?ooo`0Y0?ooo`00@P3o
ool00`3o0?l0oooo0?ooo`140?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1G0?ooo`03
0?l0o`3oool0oooo04`0oooo00<000000?ooo`3oool00P3oool2000001L0
oooo00<0o`3o0?ooo`3oool0U`3oool00`3o0?l0oooo0?ooo`0X0?ooo`00
@`3oool20?l0od@0oooo00@000000?ooo`3oool000002`3oool00`000000
oooo0?ooo`020?ooo`<00000EP3oool00`3o0?l0oooo0?ooo`1=0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`3o0?l0
oooo0?ooo`2H0?ooo`030?l0o`3oool0oooo02L0oooo00150?ooo`030?l0
o`3oool0oooo0440oooo00@000000?ooo`3oool000002@3oool2000000D0
oooo00<000000?ooo`3oool0E@3oool00`3o0?l0oooo0?ooo`1>0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`3o0?l0
oooo0?ooo`2H0?ooo`030?l0o`3oool0oooo02H0oooo00160?ooo`030?l0
o`3oool0oooo0400oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo05@0oooo00<0o`3o0?ooo`3o
ool0CP3oool2000000@0oooo00<000000?ooo`3oool0603oool00`3o0?l0
oooo0?ooo`2G0?ooo`030?l0o`3oool0oooo02H0oooo00170?ooo`030?l0
o`3oool0oooo0400oooo0P00000:0?ooo`<00000103oool00`000000oooo
0?ooo`1B0?ooo`80o`3oE`3oool00`000000oooo0?ooo`0I0?ooo`030?l0
o`3oool0oooo09L0oooo00<0o`3o0?ooo`3oool09@3oool004P0oooo0P3o
0?mC0?ooo`030000003oool0oooo0540oooo00<0o`3o0?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0J0?ooo`030?l0o`3oool0oooo09L0oooo00<0
o`3o0?ooo`3oool0903oool004X0oooo00<0o`3o0?ooo`3oool0D03oool0
0`000000oooo0?ooo`1@0?ooo`030?l0o`3oool0oooo05P0oooo00<00000
0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`2G0?ooo`030?l0o`3oool0
oooo02<0oooo001;0?ooo`80o`3oD03oool00`000000oooo0?ooo`1?0?oo
o`030?l0o`3oool0oooo05T0oooo00<000000?ooo`3oool06`3oool00`3o
0?l0oooo0?ooo`2G0?ooo`030?l0o`3oool0oooo02<0oooo001=0?ooo`03
0?l0o`3oool0oooo04d0oooo00<000000?ooo`3oool0C@3oool20?l0oe`0
oooo00<000000?ooo`3oool0703oool00`3o0?l0oooo0?ooo`2G0?ooo`03
0?l0o`3oool0oooo0280oooo001>0?ooo`80o`3oC@3oool00`000000oooo
0?ooo`1;0?ooo`80o`3oGP3oool00`000000oooo0?ooo`0M0?ooo`030?l0
o`3oool0oooo09H0oooo00<0o`3o0?ooo`3oool08P3oool00500oooo00<0
o`3o0?ooo`3oool0BP3oool00`000000oooo0?ooo`190?ooo`80o`3oH03o
ool00`000000oooo0?ooo`0N0?ooo`030?l0o`3oool0oooo09H0oooo00<0
o`3o0?ooo`3oool08@3oool00540oooo0P3o0?m:0?ooo`030000003oool0
oooo04L0oooo0P3o0?mR0?ooo`030000003oool0oooo01l0oooo00<0o`3o
0?ooo`3oool0UP3oool00`3o0?l0oooo0?ooo`0P0?ooo`00D`3oool20?l0
odP0oooo00<000000?ooo`3oool0A@3oool20?l0of@0oooo00<000000?oo
o`3oool0803oool00`3o0?l0oooo0?ooo`2E0?ooo`030?l0o`3oool0oooo
0200oooo001E0?ooo`80o`3oAP3oool00`000000oooo0?ooo`120?ooo`<0
o`3oIP3oool00`000000oooo0?ooo`0Q0?ooo`030?l0o`3oool0oooo09D0
oooo00<0o`3o0?ooo`3oool07`3oool005L0oooo0P3o0?m40?ooo`030000
003oool0oooo0400oooo0P3o0?mY0?ooo`030000003oool0oooo0280oooo
00<0o`3o0?ooo`3oool0U03oool00`3o0?l0oooo0?ooo`0O0?ooo`00F@3o
ool30?l0od40oooo00<000000?ooo`3oool0?@3oool30?l0of/0oooo00<0
00000?ooo`3oool08`3oool20?l0oiD0oooo00<0o`3o0?ooo`3oool07P3o
ool005`0oooo0`3o0?ln0?ooo`030000003oool0oooo03X0oooo0`3o0?m^
0?ooo`030000003oool0oooo02D0oooo00<0o`3o0?ooo`3oool0TP3oool0
0`3o0?l0oooo0?ooo`0N0?ooo`00G`3oool20?l0oc`0oooo00<000000?oo
o`3oool0=`3oool30?l0og40oooo00<000000?ooo`3oool09P3oool00`3o
0?l0oooo0?ooo`2B0?ooo`030?l0o`3oool0oooo01d0oooo001Q0?ooo`<0
o`3o>@3oool00`000000oooo0?ooo`0d0?ooo`<0o`3oM03oool00`000000
oooo0?ooo`0W0?ooo`030?l0o`3oool0oooo0940oooo00<0o`3o0?ooo`3o
ool07@3oool006@0oooo0`3o0?lf0?ooo`030000003oool0oooo0340oooo
0`3o0?mg0?ooo`030000003oool0oooo02P0oooo00<0o`3o0?ooo`3oool0
T03oool00`3o0?l0oooo0?ooo`0M0?ooo`00I`3oool40?l0oc80oooo00<0
00000?ooo`3oool0;P3oool30?l0ogX0oooo00<000000?ooo`3oool0:@3o
ool00`3o0?l0oooo0?ooo`2@0?ooo`030?l0o`3oool0oooo01`0oooo001[
0?ooo`@0o`3o;P3oool00`000000oooo0?ooo`0[0?ooo`<0o`3oO@3oool0
0`000000oooo0?ooo`0Z0?ooo`030?l0o`3oool0oooo08l0oooo00<0o`3o
0?ooo`3oool0703oool006l0oooo1P3o0?lX0?ooo`030000003oool0oooo
02H0oooo1@3o0?n00?ooo`030000003oool0oooo02/0oooo00<0o`3o0?oo
o`3oool0S`3oool00`3o0?l0oooo0?ooo`0K0?ooo`00M@3oool50?l0ob<0
oooo00<000000?ooo`3oool08@3oool50?l0og80oooo1@0000020?ooo`80
0000103oool2000000@0oooo00<000000?ooo`3oool0;03oool00`3o0?l0
oooo0?ooo`2>0?ooo`030?l0o`3oool0oooo01/0oooo001j0?ooo`@0o`3o
7`3oool00`000000oooo0?ooo`0N0?ooo`<0o`3oN@3oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0;@3oool20?l0ohh0oooo00<0o`3o0?ooo`3oool06`3oool007h0oooo
1@3o0?lB0?ooo`D000000`3oool00`000000oooo0?ooo`0I0?ooo`D0o`3o
O03oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0?ooo`80
0000<03oool00`3o0?l0oooo0?ooo`2<0?ooo`030?l0o`3oool0oooo01X0
oooo00230?ooo`h0o`3o1P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00X0oooo3`3o0?n10?ooo`030000003oool0oooo00P0oooo
0P0000040?ooo`030000003oool0oooo0300oooo00<0o`3o0?ooo`3oool0
R`3oool00`3o0?l0oooo0?ooo`0J0?ooo`00T@3ooolI0?l0oi00oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0340oooo00<0o`3o0?ooo`3oool0RP3oool00`3o0?l0oooo0?oo
o`0J0?ooo`00U`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo09T0oooo0P00000:0?ooo`<000000`3oool00`000000oooo0?ooo`0b
0?ooo`030?l0o`3oool0oooo08T0oooo00<0o`3o0?ooo`3oool06P3oool0
09L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2[0?oo
o`030000003oool0oooo03<0oooo0P3o0?n:0?ooo`030?l0o`3oool0oooo
01T0oooo002F0?ooo`8000001@3oool00`000000oooo0?ooo`2[0?ooo`03
0000003oool0oooo03D0oooo00<0o`3o0?ooo`3oool0Q`3oool00`3o0?l0
oooo0?ooo`0I0?ooo`00o`3ooom<0?ooo`030000003oool0oooo03H0oooo
0P3o0?n70?ooo`030?l0o`3oool0oooo01T0oooo003o0?oood`0oooo00<0
00000?ooo`3oool0>03oool00`3o0?l0oooo0?ooo`240?ooo`030?l0o`3o
ool0oooo01T0oooo003o0?oood`0oooo00<000000?ooo`3oool0>@3oool2
0?l0oh@0oooo00<0o`3o0?ooo`3oool06@3oool00?l0ooooC03oool00`00
0000oooo0?ooo`0k0?ooo`030?l0o`3oool0oooo0840oooo00<0o`3o0?oo
o`3oool06@3oool00?l0ooooC03oool00`000000oooo0?ooo`0l0?ooo`03
0?l0o`3oool0oooo0800oooo00<0o`3o0?ooo`3oool06@3oool00?l0oooo
C03oool00`000000oooo0?ooo`0m0?ooo`80o`3oP03oool00`3o0?l0oooo
0?ooo`0I0?ooo`00o`3ooom<0?ooo`030000003oool0oooo03l0oooo00<0
o`3o0?ooo`3oool0O@3oool00`3o0?l0oooo0?ooo`0I0?ooo`00V`3oool2
00000:h0oooo00<000000?ooo`3oool0@03oool20?l0ogd0oooo00<0o`3o
0?ooo`3oool06@3oool009`0oooo00<000000?ooo`3oool0[03oool00`00
0000oooo0?ooo`120?ooo`030?l0o`3oool0oooo07X0oooo00<0o`3o0?oo
o`3oool06@3oool009d0oooo00<000000?ooo`3oool0Z`3oool00`000000
oooo0?ooo`130?ooo`80o`3oNP3oool00`3o0?l0oooo0?ooo`0I0?ooo`00
W03oool00`000000oooo0000002/0?ooo`030000003oool0oooo04D0oooo
00<0o`3o0?ooo`3oool0M`3oool00`3o0?l0oooo0?ooo`0I0?ooo`00V`3o
ool010000000oooo0?ooo`00002/0?ooo`030000003oool0oooo04H0oooo
0P3o0?mg0?ooo`030?l0o`3oool0oooo01T0oooo002J0?ooo`<0000000<0
oooo000000000000Z`3oool00`000000oooo0?ooo`180?ooo`030?l0o`3o
ool0oooo07@0oooo00<0o`3o0?ooo`3oool06@3oool00?l0ooooC03oool0
0`000000oooo0?ooo`190?ooo`80o`3oL`3oool00`3o0?l0oooo0?ooo`0J
0?ooo`00o`3ooom<0?ooo`030000003oool0oooo04/0oooo0P3o0?ma0?oo
o`030?l0o`3oool0oooo01X0oooo003o0?oood`0oooo00<000000?ooo`3o
ool0C@3oool20?l0ofl0oooo00<0o`3o0?ooo`3oool06P3oool00?l0oooo
C03oool00`000000oooo0?ooo`1?0?ooo`80o`3oK03oool00`3o0?l0oooo
0?ooo`0K0?ooo`00o`3ooom<0?ooo`030000003oool0oooo0540oooo0P3o
0?mZ0?ooo`030?l0o`3oool0oooo01/0oooo003o0?ooodD0oooo10000003
0?ooo`030000003oool0oooo05<0oooo0P3o0?mX0?ooo`030?l0o`3oool0
oooo01/0oooo003o0?ooodD0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1E0?ooo`80o`3oI@3oool00`3o0?l0oooo0?ooo`0L0?oo
o`00o`3ooom60?ooo`030000003oool0oooo00<0oooo0P00001H0?ooo`80
o`3oH`3oool00`3o0?l0oooo0?ooo`0L0?ooo`00o`3ooom70?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0F@3oool20?l0of00oooo
00<0o`3o0?ooo`3oool07@3oool00?l0ooooA@3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo05/0oooo0P3o0?mM0?ooo`030?l0
o`3oool0oooo01h0oooo003o0?ooodH0oooo0P0000040?ooo`030000003o
ool0oooo05d0oooo0P3o0?mJ0?ooo`030?l0o`3oool0oooo01l0oooo003o
0?oood`0oooo00<000000?ooo`3oool0G`3oool30?l0oeL0oooo00<0o`3o
0?ooo`3oool07`3oool00?l0ooooC03oool00`000000oooo0?ooo`1R0?oo
o`80o`3oE03oool00`3o0?l0oooo0?ooo`0P0?ooo`00o`3ooom<0?ooo`03
0000003oool0oooo06@0oooo0`3o0?m?0?ooo`80o`3o8`3oool00?l0oooo
C03oool00`000000oooo0?ooo`1W0?ooo`<0o`3oB`3oool00`3o0?l0oooo
0?ooo`0S0?ooo`00o`3ooom<0?ooo`030000003oool0oooo06X0oooo0P3o
0?m70?ooo`80o`3o9P3oool00?l0ooooC03oool00`000000oooo0?ooo`1/
0?ooo`<0o`3o@`3oool00`3o0?l0oooo0?ooo`0V0?ooo`00o`3ooom<0?oo
o`030000003oool0oooo06l0oooo103o0?lm0?ooo`80o`3o:@3oool00?l0
ooooC03oool00`000000oooo0?ooo`1c0?ooo`@0o`3o>03oool00`3o0?l0
oooo0?ooo`0Y0?ooo`00o`3ooom<0?ooo`030000003oool0oooo07L0oooo
0`3o0?lc0?ooo`80o`3o;03oool00?l0ooooC03oool00`000000oooo0?oo
o`1j0?ooo`<0o`3o;P3oool20?l0obh0oooo003o0?oood`0oooo00<00000
0?ooo`3oool0O@3oool40?l0obH0oooo103o0?l`0?ooo`00o`3ooom<0?oo
o`030000003oool0oooo0840oooo1P3o0?lK0?ooo`D0o`3o=03oool00?l0
ooooC03oool00`000000oooo0?ooo`270?oooa/0o`3o>@3oool00?l0oooo
C03oool00`000000oooo0?ooo`3K0?ooo`00o`3ooom<0?ooo`030000003o
ool0oooo0=/0oooo003o0?oood`0oooo00<000000?ooo`3oool0f`3oool0
0?l0ooooC03oool00`000000oooo0?ooo`3K0?ooo`00o`3ooom<0?ooo`03
0000003oool0oooo0=/0oooo003o0?oood`0oooo00<000000?ooo`3oool0
f`3oool00?l0oooo>@3oool4000000<0oooo0P0000040?ooo`800000103o
ool00`000000oooo0?ooo`3K0?ooo`00o`3oooli0?ooo`030000003oool0
oooo00T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`3K0?ooo`00o`3ooolj0?ooo`030000003oool0oooo00/0oooo00@00000
0?ooo`3oool0oooo0P00003L0?ooo`00o`3ooolk0?ooo`030000003oool0
oooo00P0oooo0P00003R0?ooo`00o`3oooli0?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool0h@3oool00?l0oooo>P3oool20000
00X0oooo0`00003Q0?ooo`00o`3ooooo0?ooob/0oooo003o0?ooool0oooo
:`3oool00?l0ooooo`3oool[0?ooo`00o`3ooooo0?ooob/0oooo003o0?oo
ool0oooo:`3oool00?l0ooooo`3oool[0?ooo`00o`3ooom;0?ooo`800000
g@3oool00?l0ooooB`3oool200000=d0oooo003o0?ooodX0oooo00@00000
0?ooo`3oool00000g03oool00?l0ooooB@3oool200000080oooo0P00003K
0?ooo`00o`3ooooo0?ooob/0oooo003o0?ooool0oooo:`3oool00?l0oooo
o`3oool[0?ooo`00o`3ooooo0?ooob/0oooo003o0?ooool0oooo:`3oool0
0?l0ooooo`3oool[0?ooo`00o`3ooooo0?ooob/0oooo003o0?ooool0oooo
:`3oool00?l0ooooo`3oool[0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{553, 186},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\tFigure 2.7  (a)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Plot of the original ellipse\t\t\t     ",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Plot of the rotated ellipse\n\t\t\t  ",
  Cell[BoxData[
      \(s \((t)\) = 2  cos\ t + \[ImaginaryI]\ sin\ t\)]],
  "\t\t\t",
  Cell[BoxData[
      \(r \((t)\) = 
        s \((t)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/6\) + \((2 + \
\[ImaginaryI])\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[r, s, t];\)\ \), "\[IndentingNewLine]", 
    \(\(s[t_] = 
        2  Cos[t] + \[ImaginaryI]\ Sin[t];\)\ \), "\[IndentingNewLine]", 
    \(\(r[t_] = 
        s[t]\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/6\) + \((2 + \
\[ImaginaryI])\);\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[{Re[s[t]], Im[s[t]]}, {t, 0, 2  \[Pi]}, 
        PlotStyle \[Rule] Magenta, 
        PlotRange \[Rule] {{\(-2.1\), 2.1}, {\(-1.05\), 1.05}}, 
        AspectRatio \[Rule] 1\/2, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<s[t] = \>", 
        s[t], "\< for 0 \[LessEqual] t \[LessEqual] 2\[Pi].\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(ParametricPlot[{Re[r[t]], Im[r[t]]}, {t, 0, 2  \[Pi]}, 
        PlotStyle \[Rule] Magenta, 
        PlotRange \[Rule] {{0, 4}, {\(-0.5\), 2.5}}, 
        AspectRatio \[Rule] 3\/4, 
        Ticks \[Rule] {Range[0, 4, 1], Range[0, 3, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<r[t] = \>", 
      r[t], "\< for 0 \[LessEqual] t \[LessEqual] 2\[Pi].\>"]\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tIf we let  ",
  Cell[BoxData[
      \(K > 0\)]],
  "  be a fixed positive real number, then the transformation  \n\n\t\t\t",
  Cell[BoxData[
      \(w\  = \ \(S \((z)\)\  = \ \(K\ z\  = \ 
            K\ x + \[ImaginaryI]\ K\ y\)\)\)]],
  "  \n\nis a one-to-one mapping of the z-plane onto the w-plane and is \
called a ",
  StyleBox["magnification",
    FontColor->RGBColor[0, 0, 1]],
  ".  If   ",
  Cell[BoxData[
      \(K > 1\)]],
  ",  it has the effect of stretching the distance between points by the \
factor  K.  If   ",
  Cell[BoxData[
      \(K < 1\)]],
  ",  then it reduces the distance between points by the factor  K.  The \
inverse transformation is given by  \n\n\t\t\t",
  Cell[BoxData[
      \(z\  = \ \(\(S\^\(-1\)\) \((w)\)\  = \ \(\(1\/K\) 
              w\  = \ \(1\/K\) u\  + \ \[ImaginaryI] \( 1\/K\) v\)\)\)]],
  "  \n\nand shows that  S  is a one-to-one mapping from the z-plane onto the \
w-plane.  The effect of magnification is shown in Figure 2.8."
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 2.8",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The magnification  ",
  Cell[BoxData[
      \(w\  = \ \(S \((z)\)\  = \ \(K\ z\  = \ 
            K\ x + \[ImaginaryI]\ K\ y\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tFinally, if we let  ",
  Cell[BoxData[
      \(A = K\ \[ExponentialE]\^\[ImaginaryI]\[Alpha]\)]],
  "  and  ",
  Cell[BoxData[
      \(B = a + \[ImaginaryI]\ b\)]],
  ", where  ",
  Cell[BoxData[
      \(K > 0\)]],
  "  is a positive real number, then the transformation \n\n\t\t\t",
  Cell[BoxData[
      \(w\  = \ \(L \((z)\)\  = \ A\ z + B\)\)]],
  " \n\nis a one-to-one mapping of the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-plane onto the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  "-plane and is called a ",
  StyleBox["linear transformation",
    FontColor->RGBColor[0, 0, 1]],
  ".  It can be considered as the composition of a rotation, a magnification, \
and a translation.  It has the effect of rotating the plane though an angle \
given by  ",
  Cell[BoxData[
      \(\[Alpha] = Arg\ A\)]],
  ",  followed by a magnification by the factor  ",
  Cell[BoxData[
      \(K = \(\(|\)\(A\)\(|\)\)\)]],
  ", followed by a translation by the vector  ",
  Cell[BoxData[
      \(B = a + \[ImaginaryI]b\)]],
  ".  The inverse mapping is given by  ",
  Cell[BoxData[
      \(z = \(\(L\^\(-1\)\) \((w)\) = 1\/A\ w - B\/A\)\)]],
  "  and shows that ",
  StyleBox["L",
    FontFamily->"Courier New"],
  " is a one-to-one mapping from the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-plane onto the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  "-plane."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 2.9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the linear transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \[ImaginaryI]\ z + \[ImaginaryI]\)\)]],
  "  maps the right half plane  ",
  Cell[BoxData[
      \(Re \((z)\) > 1\)]],
  "  onto the upper half plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  Method 1:  Let  ",
  Cell[BoxData[
      \(A = {\((x, y)\) : \ x \[GreaterEqual] 1}\)]],
  ".  To describe  ",
  Cell[BoxData[
      \(B = f \((A)\)\)]],
  ",  we solve  ",
  Cell[BoxData[
      \(w = \[ImaginaryI]\ z + \[ImaginaryI]\)]],
  "  for z to get  ",
  Cell[BoxData[
      \(z\  = \ \(\(w - \[ImaginaryI]\)\/\[ImaginaryI]\  = \ \(\(-\
\[ImaginaryI]\)\ w - 1\  = \ \(f\^\(-1\)\) \((w)\)\)\)\)]],
  ".  We have the following \n\n\t\t\t",
  Cell[BoxData[{
      \(u + iv\  = \ \(w\  = f \((z)\) \[Element] B\)\), "\n", 
      \(\(\(\[DoubleLongLeftRightArrow]\)\(\ \ \ \ \)\(f\^\(-1\)\)\) \((w)\)\ \
 = \ z\  \[Element] A\), "\n", 
      \(\(\(\[DoubleLongLeftRightArrow]\)\(\ \ \)\(-\[ImaginaryI]\)\)\ w - 
          1\  \[Element] A\), "\n", 
      \(\(\(\[DoubleLongLeftRightArrow]\)\(\ \ \)\(v\)\) - 
          1 - \[ImaginaryI]\ u\  \[Element] A\), "\n", 
      \(\(\(\[DoubleLongLeftRightArrow]\)\(\ \ \)\((v - 
              1, \(-u\))\)\)\  \[Element] A\), "\n", 
      \(\(\(\[DoubleLongLeftRightArrow]\)\(\ \ \)\(v\)\) - 1 \[GreaterEqual] 
        1\), "\n", 
      \(\(\(\[DoubleLongLeftRightArrow]\)\(\ \ \)\(v\)\) \[GreaterEqual] 
        2\)}]],
  "  \n\nThus  ",
  Cell[BoxData[
      \(B = {w = u + \(iv : \ v \[GreaterEqual] 2\)}\)]],
  ",  which is the same as saying  ",
  Cell[BoxData[
      \(Im \((w)\) > 2\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Method 2: When we write  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  in Cartesian form as  \n\n\t\t\t",
  Cell[BoxData[
      \(w\  = \ \(u + 
            iv\  = \ \(\[ImaginaryI] \((x + \[ImaginaryI]\ y)\) + \
\[ImaginaryI]\  = \ \(-y\) + \[ImaginaryI] \((x + 1)\)\)\)\)]],
  ",  \n\nwe see that the transformation can be given by the equations  ",
  Cell[BoxData[
      \(u = \(-y\)\)]],
  " and ",
  Cell[BoxData[
      \(v = x + 1\)]],
  ".  Substituting  ",
  Cell[BoxData[
      \(x = v - 1\)]],
  "  in the inequality  ",
  Cell[BoxData[
      \(Re \((z)\) = x \[GreaterEqual] 1\)]],
  "  gives  ",
  Cell[BoxData[
      \(v - 1 \[GreaterEqual] 1\)]],
  ",  or  ",
  Cell[BoxData[
      \(v \[GreaterEqual] 2\)]],
  ",  which is the upper half-plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 2\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Method 3:  The effect of the transformation  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  " is a rotation of the plane through the angle  ",
  Cell[BoxData[
      \(\[Alpha] = \[Pi]\/2\)]],
  " (when z is multiplied by ",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  ") followed by a translation by the vector  ",
  Cell[BoxData[
      \(B = \[ImaginaryI]\)]],
  ".  The first operation yields the set  ",
  Cell[BoxData[
      \(Im \((w)\) \[GreaterEqual] 1\)]],
  ".  The second shifts this set up ",
  StyleBox["1",
    FontFamily->"Courier New"],
  " unit, resulting in the set  ",
  Cell[BoxData[
      \(Im \((w)\) > 2\)]],
  ".  We illustrate this result in Figure 2.9."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000710000Vb000`400?l0
0000o`00003oo`3oooo20?ooo`00o`3oooo20?ooo`00o`3oooo20?ooo`00
o`3oooo20?ooo`00o`3oooo20?ooo`00o`3oooo20?ooo`00o`3oool/0?oo
o`D000006`3oool5000000d0oooo1000000>0?ooo`8000004@3oool30000
00d0oooo0P00000?0?ooo`<000006`3oool00?l0oooo;P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo
00/0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00
000J0?ooo`00O03oool200000:l0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03@3oool5000000l0oooo00<000000?ooo`3oool0303oool0
10000000oooo0?ooo`00000J0?ooo`00N`3oool010000000oooo0?ooo`00
002V0?ooo`@00000103oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0<0?ooo`040000003oool0oooo000000h0oooo0P00000?0?ooo`<00000
6`3oool007d0oooo00@000000?ooo`3oool0oooo0P00000A0?oooed00000
?03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00d0oooo
00@000000?ooo`3oool000003@3oool010000000oooo0?ooo`00000?0?oo
o`030000003oool0000000h0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0J0?ooo`00M@3oool4000000D0oooo00@000000?ooo`3o
ool000004P3oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo
03T0oooo0P00000N0?ooo`800000403oool2000000l0oooo0P00000A0?oo
o`8000003P3oool3000000l0oooo0`00000J0?ooo`00N`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o
/`00ok<01P00ok<00`000000oooo0?ooo`3>0?ooo`00O03oool2000000<0
oooo00<000000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H0
0?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`03
0000003oool0oooo0<h0oooo00210?ooo`030000003oool0oooo0100oooo
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc
00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`3>0?ooo`00P@3o
ool00`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<0
00000?ooo`3oool0^@3oool400000140oooo00210?ooo`030000003oool0
oooo0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`0g
0?ooog`000001@3oool010000000oooo0?ooo`00000B0?ooo`00P@3oool0
0`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000004P3oool00840oooo00<000000?ooo`3oool0403oool0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<0
0`1oOgl00?nc003o/`06003o/`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool0J`3oool2000000030?ooo`00000000000180oooo00210?oo
o`030000003oool0oooo0100ooooG@1oOgm;0?ooo`030000003oool0oooo
0880oooo00210?ooo`030000003oool0oooo0100oooo00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00
ok<01P00ok<00`000000oooo0?ooo`190?ooo`030000003oool0oooo0880
oooo00210?ooo`030000003oool0oooo0100oooo00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`000000oooo0?ooo`190?ooo`030000003oool0oooo0880oooo
00210?ooo`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00
ok<00`000000oooo0?ooo`190?ooo`030000003oool0oooo0880oooo0021
0?ooo`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo0880oooo00210?oo
o`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo0880oooo00210?ooo`03
0000003oool0oooo0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
oooo0?ooo`190?ooo`030000003oool0oooo0880oooo001k0?ooo`@00000
0P3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`220?ooo`00N`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0
Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo0880oooo001l0?ooo`030000003oool0oooo0080oooo0P00000A
0?oooed00000B`3oool00`000000oooo0?ooo`220?ooo`00M@3oool40000
00@0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<0
0?nc00H00?nc00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`22
0?ooo`00N`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0880oooo001l0?ooo`8000000`3oool00`00
0000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`220?ooo`00P@3oool00`000000
oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3o
ool0@03oool5000000@0oooo00<000000?ooo`3oool0PP3oool00840oooo
00<000000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000
003oool0oooo0480oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`220?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00
ok<00?nc00H00?nc00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0880oooo00210?ooo`030000003oool0
oooo0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0PP3oool0
0840oooo00<000000?ooo`3oool0403oool00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o
/`030000003oool0oooo0480oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`220?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`03
07moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0@@3oool2000000H0
oooo00<000000?ooo`3oool0PP3oool00840oooo00<000000?ooo`3oool0
403ooomM07moOd/0oooo00<000000?ooo`3oool0PP3oool00840oooo00<0
00000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0PP3oool00840oooo00<00000
0?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0
oooo04T0oooo00<000000?ooo`3oool0PP3oool00840oooo00<000000?oo
o`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0PP3oool00840oooo00<000000?ooo`3o
ool0403oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0PP3oool00840oooo00<000000?ooo`3oool0
403oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0PP3oool00840oooo00<000000?ooo`3oool0403o
ool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00
ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool0PP3oool007/0oooo1@0000000`3oool000000?ooo`0A
0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07
003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0@03oool4
000000D0oooo00<000000?ooo`3oool0PP3oool007d0oooo00D000000?oo
o`3oool0oooo0000000B0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0880oooo001m0?ooo`040000003oool0oooo0?ooo`8000004@3ooomM
000004<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`22
0?ooo`00M@3oool4000000@0oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07
003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0880oooo001m0?oo
o`050000003oool0oooo0?ooo`0000004P3oool00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06
003o/`030000003oool0oooo0400oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`220?ooo`00O03oool2000000<0oooo00<00000
0?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0
oooo0440oooo0P0000060?ooo`030000003oool0oooo0880oooo00210?oo
o`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
0000oooo0?ooo`0g0?ooo`T0000000<0Ogmo0000000000003P0000000`1o
Ogl000000000000?0000000307moO`000000000000h0000000<0Ogmo0000
000000003`0000000`1oOgl000000000000?0000000307moO`0000000000
00h0000000<0Ogmo0000000000001`00000K0?ooo`00P@3oool00`000000
oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3o
ool0=`3oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H0
0?nc00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01@00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<000000?ooo`3oool06@3oool00840oooo
00<000000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000
003oool0oooo03L0oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00D00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo01T0oooo
00210?ooo`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00
ok<00`000000oooo0?ooo`0g0?ooo`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`05003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?oo
o`0I0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<0
0?nc00H00?nc00<000000?ooo`3oool0=`3oool00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01@00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
0?ooo`3oool06@3oool00840oooo00<000000?ooo`3oool02`3oool50000
05d0Ogmo>@3oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01@00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool06@3oool00840
oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`000008003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o
/`030000003oool0oooo03L0oooo00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00D00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo
01T0oooo00210?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3o
ool000002000ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o
/`00ok<01P00ok<00`000000oooo0?ooo`0g0?ooo`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`05003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
0000oooo0?ooo`0I0?ooo`00P@3oool00`000000oooo0?ooo`0=0?ooo`04
0000003oool0oooo000000P00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o
/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0=`3oool00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01@00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<000000?ooo`3oool06@3oool00840oooo00<000000?ooo`3o
ool03@3oool010000000oooo0?ooo`000008003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo
03L0oooo00<0000007moO`1oOgl03`1oOgl00`000000Ogmo07moO`0>07mo
O`030000001oOgl0Ogmo00l0Ogmo00<0000007moO`1oOgl03P1oOgl00`00
0000Ogmo07moO`0?07moO`030000001oOgl0Ogmo00h0Ogmo00<0000007mo
O`1oOgl03`1oOgl00`000000oooo0?ooo`0I0?ooo`00P@3oool00`000000
oooo0?ooo`0<0?ooo`8000000P3oool00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H0
0?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`03
0000003oool0oooo03L0oooo00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H0
0?nc00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00D00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo01T0
oooo00210?ooo`030000003oool0oooo0100oooo00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`000000oooo0?ooo`0g0?ooo`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`05003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo
0?ooo`0I0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00
ok<00?nc00H00?nc00<000000?ooo`3oool0=`3oool00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01@00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
00000?ooo`3oool06@3oool00840oooo00<000000?ooo`3oool0403oool0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<0
0`1oOgl00?nc003o/`06003o/`030000003oool0oooo0080oooo0P000000
0`3oool000000000000`0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`05003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`0I
0?ooo`00K`3ooon2000000D0oooo00<000000?ooo`000000<@3oool00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01@00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<000000?ooo`3oool06@3oool00840oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H0
0?nc00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0`0?ooo`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00D0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`05003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`000000oooo0?ooo`0I0?ooo`00P@3oool00`000000oooo
0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0
0P3oool2000000030?ooo`00000000000300oooo00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00D00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00D00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
003oool0oooo01T0oooo00210?ooo`030000003oool0oooo0100oooo00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0
Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`0g0?ooo`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00D00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`05003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`000000oooo0?ooo`0I0?ooo`00P@3oool00`000000oooo0?ooo`0@
0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07
003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0=`3oool9
0000000307moO`000000000000h0000000<0Ogmo0000000000003`000000
0`1oOgl000000000000>0000000307moO`000000000000l0000000<0Ogmo
0000000000003`0000000`1oOgl000000000000>0000000307moO`000000
000000L000006`3oool00840oooo00<000000?ooo`3oool0403oool00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1o
Ogl00?nc003o/`06003o/`030000003oool0oooo03L0oooo00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00D00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00D00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`030000003oool0oooo01T0oooo00210?ooo`030000003oool0oooo0100
oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`0g0?ooo`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00D0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`05003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`000000oooo0?ooo`0I0?ooo`00P@3oool00`000000oooo
0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0
=`3oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01@00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<000000?ooo`3oool06@3oool00840oooo00<0
00000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003o
ool0oooo03L0oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00D00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo01T0oooo0021
0?ooo`030000003oool0oooo0100ooooG@1oOgli0?ooo`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`05
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`000000oooo0?ooo`0I0?ooo`00P@3oool00`000000oooo0?ooo`0@0?oo
o`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o
/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0=`3oool00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01@00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<000000?ooo`3oool06@3oool00840oooo00<000000?ooo`3o
ool0403oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo03L0
oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00D00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`030000003oool0oooo01T0oooo00210?ooo`030000
003oool0oooo0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo
0?ooo`0g0?ooo`030000001oOgl0Ogmo00l0Ogmo00<0000007moO`1oOgl0
3P1oOgl00`000000Ogmo07moO`0?07moO`030000001oOgl0Ogmo00h0Ogmo
00<0000007moO`1oOgl03`1oOgl00`000000Ogmo07moO`0>07moO`030000
001oOgl0Ogmo00l0Ogmo00<000000?ooo`3oool06@3oool00840oooo00<0
00000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003o
ool0oooo03L0oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00D00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo01T0oooo0021
0?ooo`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`000000oooo0?ooo`0g0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`05003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`0I
0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc
00H00?nc00<000000?ooo`3oool0=`3oool00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01@00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<000000?oo
o`3oool06@3oool00840oooo00<000000?ooo`3oool0403oool00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl0
0?nc003o/`06003o/`030000003oool0oooo03L0oooo00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00D0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00D0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
0000003oool0oooo01T0oooo001k0?ooo`D0000000<0oooo0000003oool0
4@3oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo03L0oooo
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00D00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`030000003oool0oooo01T0oooo001m0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000
003oool0oooo03L0oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00D00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo01T0oooo
001m0?ooo`040000003oool0oooo0?ooo`8000004@3ooomM000003T0oooo
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00D00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`030000003oool0oooo01T0oooo001m0?ooo`050000003o
ool0oooo0?ooo`0000004P3oool00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000
003oool0oooo03L0oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00D00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo01T0oooo
001m0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc
003o/`06003o/`030000003oool0oooo03L0oooo2@0000000`1oOgl00000
0000000>0000000307moO`000000000000l0000000<0Ogmo000000000000
3P0000000`1oOgl000000000000?0000000307moO`000000000000l00000
00<0Ogmo0000000000003P0000000`1oOgl0000000000007000001/0oooo
001l0?ooo`8000000`3oool00`000000oooo0?ooo`0@0?ooo`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00
ok<00?nc00H00?nc00<000000?ooo`3oool0=`3oool00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01@00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
00000?ooo`3oool06@3oool00840oooo00<000000?ooo`3oool0403oool0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<0
0`1oOgl00?nc003o/`06003o/`030000003oool0oooo03L0oooo00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00D00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`030000003oool0oooo01T0oooo00210?ooo`030000003oool0oooo
0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`0g0?oo
o`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00D00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`05003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`000000oooo0?ooo`0I0?ooo`00P@3oool00`000000
oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3o
ool0=`3oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H0
0?nc00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01@00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<000000?ooo`3oool06@3oool00840oooo
00<000000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000
003oool0oooo03L0oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00D00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo01T0oooo
00210?ooo`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00
ok<00`000000oooo0?ooo`0g0?ooo`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`05003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?oo
o`0I0?ooo`00P@3oool00`000000oooo0?ooo`0@0?oooed0Ogmo>@3oool0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01@00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<000000?ooo`3oool06@3oool00840oooo00<000000?oo
o`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo
03L0oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00D00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`030000003oool0oooo01T0oooo00210?ooo`03
0000003oool0oooo0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
oooo0?ooo`0g0?ooo`030000001oOgl0Ogmo00l0Ogmo00<0000007moO`1o
Ogl03P1oOgl00`000000Ogmo07moO`0?07moO`030000001oOgl0Ogmo00h0
Ogmo00<0000007moO`1oOgl03`1oOgl00`000000Ogmo07moO`0>07moO`03
0000001oOgl0Ogmo00l0Ogmo00<000000?ooo`3oool06@3oool00840oooo
00<000000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000
003oool0oooo03L0oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00D00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo01T0oooo
00210?ooo`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00
ok<00`000000oooo0?ooo`0g0?ooo`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`05003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?oo
o`0I0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<0
0?nc00H00?nc00<000000?ooo`3oool0=`3oool00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01@00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
0?ooo`3oool06@3oool00840oooo00<000000?ooo`3oool0403oool00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1o
Ogl00?nc003o/`06003o/`030000003oool0oooo03L0oooo00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00D00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00D00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`030000003oool0oooo01T0oooo001k0?ooo`@000000P3oool00`000000
oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3o
ool0=`3oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H0
0?nc00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01@00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<000000?ooo`3oool06@3oool007/0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307mo
O`00ok<00?nc00H00?nc00<000000?ooo`3oool0=`3oool00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1@00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<000000?ooo`3oool06@3oool007`0oooo00<000000?ooo`3oool00P3o
ool200000140ooooG@00000i0?ooo`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`05003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?oo
o`0I0?ooo`00O@3oool01@000000oooo0?ooo`3oool000000180oooo00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0
Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`0g0?ooo`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00D00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`05003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`000000oooo0?ooo`0I0?ooo`00N`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00
ok<00`000000oooo0?ooo`0g0?ooo`T0000000<0Ogmo0000000000003P00
00000`1oOgl000000000000?0000000307moO`000000000000h0000000<0
Ogmo0000000000003`0000000`1oOgl000000000000?0000000307moO`00
0000000000h0000000<0Ogmo0000000000001`00000K0?ooo`00O03oool2
000000<0oooo00<000000?ooo`3oool0403oool00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06
003o/`030000003oool0oooo03L0oooo00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00D00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0
oooo01T0oooo00210?ooo`030000003oool0oooo0100oooo00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o
/`00ok<01P00ok<00`000000oooo0?ooo`0g0?ooo`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`05003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
0000oooo0?ooo`0I0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`03
07moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0=`3oool00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01@00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H0
0?nc00<000000?ooo`3oool06@3oool00840oooo00<000000?ooo`3oool0
403oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo03L0oooo
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00D00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`030000003oool0oooo01T0oooo00210?ooo`030000003o
ool0oooo0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?oo
o`0g0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`05003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`0I0?ooo`00P@3oool0
0`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<00000
0?ooo`3oool0=`3oool00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01@00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool06@3oool0
0840oooo00<000000?ooo`3oool0403ooomM07moOcT0oooo00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00D00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00D00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`030000003oool0oooo01T0oooo00210?ooo`030000003oool0oooo0100
oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`0g0?ooo`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00D0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`05003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`000000oooo0?ooo`0I0?ooo`00P@3oool00`000000oooo
0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0
=`3oool00`000000Ogmo07moO`0?07moO`030000001oOgl0Ogmo00h0Ogmo
00<0000007moO`1oOgl03`1oOgl00`000000Ogmo07moO`0>07moO`030000
001oOgl0Ogmo00l0Ogmo00<0000007moO`1oOgl03P1oOgl00`000000Ogmo
07moO`0?07moO`030000003oool0oooo01T0oooo00210?ooo`030000003o
ool0oooo0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?oo
o`0g0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`05003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`0I0?ooo`00P@3oool0
0`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<00000
0?ooo`3oool0=`3oool00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01@00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool06@3oool0
0840oooo00<000000?ooo`3oool0403oool00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o
/`030000003oool0oooo03L0oooo00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00D00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo
01T0oooo00210?ooo`030000003oool0oooo0100oooo00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00
ok<01P00ok<00`000000oooo0?ooo`0g0?ooo`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`05003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
oooo0?ooo`0I0?ooo`00O03oool2000000<0oooo00<000000?ooo`3oool0
403oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo03L0oooo
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00D00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`030000003oool0oooo01T0oooo001k0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0403oool00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc
003o/`06003o/`030000003oool0oooo03L0oooo00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00D00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00D00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
003oool0oooo01T0oooo001m0?ooo`040000003oool0oooo0?ooo`800000
4@3ooomM000003T0oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00D00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo01T0oooo
001n0?ooo`040000003oool0oooo00000180oooo00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`000000oooo0?ooo`0g0?ooo`T0000000<0Ogmo000000000000
3P0000000`1oOgl000000000000?0000000307moO`000000000000h00000
00<0Ogmo0000000000003`0000000`1oOgl000000000000?0000000307mo
O`000000000000h0000000<0Ogmo0000000000001`00000K0?ooo`00N`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc
00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`0g0?ooo`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00D00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`05003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`000000oooo0?ooo`0I0?ooo`00O03oool2000000<0oooo00<0
00000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003o
ool0oooo03L0oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00D00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo01T0oooo0021
0?ooo`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`000000oooo0?ooo`0g0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`05003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`0I
0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc
00H00?nc00<000000?ooo`3oool0=`3oool00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01@00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<000000?oo
o`3oool06@3oool00840oooo00<000000?ooo`3oool0403oool00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl0
0?nc003o/`06003o/`030000003oool0oooo03L0oooo00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00D0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00D0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
0000003oool0oooo01T0oooo00210?ooo`030000003oool0oooo0100oooo
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc
00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`0g0?ooo`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00D00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`05003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`000000oooo0?ooo`0I0?ooo`00P@3oool00`000000oooo0?oo
o`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0=`3o
ool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01@00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<000000?ooo`3oool06@3oool00840oooo00<00000
0?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0
oooo03L0oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00D00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`030000003oool0oooo01T0oooo00210?oo
o`030000003oool0oooo0100ooooG@1oOgli0?ooo`030000001oOgl0Ogmo
00l0Ogmo00<0000007moO`1oOgl03P1oOgl00`000000Ogmo07moO`0?07mo
O`030000001oOgl0Ogmo00h0Ogmo00<0000007moO`1oOgl03`1oOgl00`00
0000Ogmo07moO`0>07moO`030000001oOgl0Ogmo00l0Ogmo00<000000?oo
o`3oool06@3oool00840oooo00<000000?ooo`3oool0403oool00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl0
0?nc003o/`06003o/`030000003oool0oooo03L0oooo00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00D0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00D0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
0000003oool0oooo01T0oooo00210?ooo`030000003oool0oooo0100oooo
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc
00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`0g0?ooo`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00D00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`05003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`000000oooo0?ooo`0I0?ooo`00P@3oool00`000000oooo0?oo
o`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0=`3o
ool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`05003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01@00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<000000?ooo`3oool06@3oool00840oooo00<00000
0?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0
oooo03L0oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00D00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`030000003oool0oooo01T0oooo00210?oo
o`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
0000oooo0?ooo`0g0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`05003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`0I0?oo
o`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H0
0?nc00<000000?ooo`3oool0=`3oool00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01@00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`05003o/`0307moO`00ok<00?nc00H0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01@00ok<00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3o
ool06@3oool007d0oooo0`0000000`3oool000000?ooo`0A0?ooo`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307mo
O`00ok<00?nc00H00?nc00<000000?ooo`3oool0=`3oool00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`05003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1@00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<000000?ooo`3oool06@3oool007h0oooo00@000000?ooo`3oool00000
4P3oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo03L0oooo
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00D00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1@00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00D00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`030000003oool0oooo01T0oooo001k0?ooo`D0000000<0
oooo0000000000004@3ooomM000003T0oooo2@0000000`1oOgl000000000
000>0000000307moO`000000000000l0000000<0Ogmo0000000000003P00
00000`1oOgl000000000000?0000000307moO`000000000000l0000000<0
Ogmo0000000000003P0000000`1oOgl0000000000007000001/0oooo001k
0?ooo`040000003oool0oooo00000?l0oooo@`3oool007`0oooo00<00000
0?ooo`000000o`3ooom30?ooo`00O@3oool200000?l0oooo@`3oool00?l0
oooo`P3oool00?l0oooo`P3oool007l0oooo0P00003o0?oood40oooo0020
0?ooo`030000003oool0oooo0?l0oooo?`3oool00840oooo00<000000?oo
o`3oool0]`3oool2000008@0oooo00200?ooo`030000003oool000000;P0
oooo0P0000240?ooo`00O`3oool010000000oooo0?ooo`00002g0?ooo`04
0000003oool0oooo000008<0oooo001n0?ooo`<0000000<0oooo00000000
0000]@3oool200000080oooo0P0000220?ooo`00o`3oooo20?ooo`00o`3o
ooo20?ooo`00o`3oooo20?ooo`00o`3oooo20?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{449, 155},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\tFigure 2.9",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The linear transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \[ImaginaryI]\ z + \[ImaginaryI]\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(w = \(f[z] = \[ImaginaryI]\ z + \[ImaginaryI]\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[w, x, y, z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[eq1, eq2, f, ineq, u, v, zz];\)\ \), "\n", 
    \(\(TagSet[x, Im[x], 0];\)\ \), "\n", 
    \(\(TagSet[y, Im[y], 0];\)\ \), "\n", 
    \(\(TagSet[x, Re[x], x];\)\ \), "\n", 
    \(\(TagSet[y, Re[y], y];\)\ \), "\n", 
    \(\(f[z_] := \[ImaginaryI]\ z + \[ImaginaryI];\)\ \), "\n", 
    \(\(Print["\<    f[\>", z, "\<] = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[\>", x\  + \ \[ImaginaryI]\ y, "\<] = \>", 
        f[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[\>", x\  + \ \[ImaginaryI]\ y, "\<] = \>", 
        Expand[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Solve for the inverse function.", "Text"],

Cell[BoxData[{
    \(\(solset = 
        Solve[w \[Equal] \[ImaginaryI]\ z + \[ImaginaryI], z];\)\ \), "\n", 
    \(\(Z = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<      w = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<      w = \>", f[x + \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(Print["\<      w = \>", 
        Expand[f[x + \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u + \[ImaginaryI] v = \>", 
        Expand[f[x + \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<u = \>", 
        ComplexExpand[Re[f[x + \[ImaginaryI]\ y]]]];\)\ \), "\n", 
    \(\(Print["\<v = \>", 
        ComplexExpand[Im[f[x + \[ImaginaryI]\ y]]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<z = \>", Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<z = \>", ComplexExpand[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = 
        ReplaceAll[Z\ , 
          w \[Rule] u + \[ImaginaryI]\ v];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<z = \>", Z];\)\ \), "\n", 
    \(\(Print["\<z = \>", Expand[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<x = \>", ComplexExpand[Re[Z]]];\)\ \), "\n", 
    \(\(Print["\<y = \>", 
        ComplexExpand[Im[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To solve for  ",
  Cell[BoxData[
      \(Re[z] > 1\)]],
  ",   we use the following computations."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[Re[z] > 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[x > 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Algebra`InequalitySolve`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ineq = ComplexExpand[Re[Z]] > 1];\)\ \), "\[IndentingNewLine]", 
    \(\(solset = InequalitySolve[ineq, v];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The solution is the upper half plane  ",
  Cell[BoxData[
      \(Im[w] > 2\)]],
  ".  Now use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph the transformation. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Iden[z_] = z;\)\ \), "\n", 
    \(\(f[z_] = \[ImaginaryI]\ z + \[ImaginaryI];\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {1, 5, 0.5}, {\(-6\), 4, 
          0.5}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 6}, {\(-3\), 
              4}}, AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 6, 1], 
            Range[\(-3\), 4, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Magenta, Pink}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The half-plane  Re[z] > 1.\>"];\)\ \), "\n", 
    \(\(CartesianMap[
        f, \ {1, 5, 0.5}, {\(-6\), 4, 
          0.5}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 6}, {\(-1\), 
              6}}, AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 6, 1], 
            Range[\(-1\), 6, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Magenta, Pink}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image half-plane Im[w] > 2,\>"];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the linear transformation  ",
  Cell[BoxData[
      \(w = \(f[z] = \[ImaginaryI]\ z + \[ImaginaryI]\)\)]],
  "  maps the right half plane  ",
  Cell[BoxData[
      \(Re[z] > 1\)]],
  "  onto the upper half plane  ",
  Cell[BoxData[
      \(Im[w] > 2\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\tTranslations and rotations preserve angles.  First, magnifications \
rescale distance by a factor K, so it follows that triangles are mapped onto \
similar triangles, preserving angles.  Then, because a linear transformation \
can be considered to be a composition of a rotation, a magnification, and a \
translation, it follows that linear transformations preserve angles.  \
Consequently, any geometric object is mapped onto an object that is similar \
to the original object; hence linear transformations can be called ",
  StyleBox["similarity mappings",
    FontColor->RGBColor[0, 0, 1]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The usage of the phrase \"",
  StyleBox["linear transformation",
    FontColor->RGBColor[0, 0, 1]],
  "\" in a \"complex analysis course\" is different than that the usage in \
\"linear algebra courses\"."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 2.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the image of the open disk  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(D\_1\), Cell["(-1-\[ImaginaryI])"]}], 
        "=", \({z : \(\(|\)\(z + 
                1 + \[ImaginaryI]\)\(|\)\(\(<\)\(\ \)\(1\)\)\)}\)}]]],
  "  under the linear transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \((3 - 4  \[ImaginaryI])\) z\  + \ 6 + 
            2  \[ImaginaryI]\)\)]],
  "  is the open disk  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(D\_5\), Cell["(-1+3\[ImaginaryI])"]}], 
        "=", \({w : \(\(|\)\(w + 1 - 
                3\ \[ImaginaryI]\)\(|\)\(\(<\)\(\ \)\(5\)\)\)}\)}]]],
  ".  \n\nSolution.  The inverse transformation is  ",
  Cell[BoxData[
      \(z\  = \ \(w - 6 - 2  \[ImaginaryI]\)\/\(3 - 4  \[ImaginaryI]\)\)]],
  ",  so if we designate the range of ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " as ",
  StyleBox["B",
    FontFamily->"Courier New"],
  ", then\n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{"w", "=", 
        RowBox[{\(f \((z)\) \[Element] 
            B \[DoubleLeftRightArrow] \(f\^\(-1\)\) \((w)\)\), "=", 
          RowBox[{"z", "\[Element]", 
            RowBox[{\(D\_1\), Cell["(-1-\[ImaginaryI])"]}]}]}]}], "\n", 
      RowBox[{\(\(\[DoubleLongLeftRightArrow]\)\(\ \ \ \)\(\(w - 6 - 
                2  i\)\/\(3 - 4  i\)\)\), "\[Element]", 
        RowBox[{\(D\_1\), Cell["(-1-\[ImaginaryI])"]}]}], 
    "\n", \(\(\[DoubleLongLeftRightArrow]\)\(\ \ \ \)\(\(|\)\(\(w - 6 - 2  \
i\)\/\(3 - 4  i\) + 1 + i\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)}]],
  "   \n\t\t\t",
  Cell[BoxData[
      \(\(\(\[DoubleLongLeftRightArrow]\)\(\ \ \ \)\(\(|\)\(\(w - 6 - 2  \
i\)\/\(3 - 4  i\) + 1 + i\)\(|\)\)\)\)]],
  Cell[BoxData[
      \(\(\(|\)\(3 - 4  i\)\(|\)\(\(<\)\(\ \)\(1\)\)\(|\)\(3 - 
          4  i\)\(|\)\(\ \)\)\)]],
  "\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[DoubleLongLeftRightArrow]\)\(\ \ \ \)\(\(|\)\(w - 6 - 
            2  i + \((1 + i)\) \((3 - 
                  4  i)\)\)\(|\)\(\(<\)\(\ \)\(5\)\)\)\)\), "\n", 
      \(\(\(\[DoubleLongLeftRightArrow]\)\(\ \ \ \)\(\(|\)\(w + 1 - 
            3  i\)\(|\)\(\(<\)\(\ \)\(5\)\)\)\)\)}]],
  "\n\nHence the disk with center  ",
  Cell[BoxData[Cell["-1-\[ImaginaryI]"]]],
  "  and radius ",
  StyleBox["1",
    FontFamily->"Courier New"],
  " is mapped one-to-one and onto the disk with center  ",
  Cell[BoxData[Cell["-1+3\[ImaginaryI]"]]],
  "  and radius ",
  StyleBox["5",
    FontFamily->"Courier New"],
  " as shown in Figure 2.10."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007@0000Vb000`400?l0
0000o`00003oo`3ooooA0?ooo`00o`3ooooA0?ooo`00o`3ooooA0?ooo`00
o`3ooooA0?ooo`00o`3ooooA0?ooo`00o`3ooooA0?ooo`00o`3ooooA0?oo
o`00o`3ooooA0?ooo`00`@3oool400040;H0oooo0P00101C0?ooo`00`@3o
ool00`001000oooo0?ooo`2f0?ooo`040004003oool0oooo00040580oooo
002^0?ooo`@0Ngek00<000@007]mN`1kOG/00`1kOG/:0?ooo`030004003o
ool0oooo00<0oooo00<000@00?ooo`3oool0/@3oool00`001000oooo0?oo
o`020?ooo`8000@0C@3oool00:X0oooo101kOG/01P00ojd00?ne003o[@00
ojd000@0003o]@<00?n]00@00?ne07]mN`1kOG/0Ngek100010040?ooo`03
0004003oool0oooo0080oooo00<000@00?ooo`3oool0Z@3oool4000400D0
oooo00D000@00?ooo`3oool0oooo0004001>0?ooo`00Z@3oool03P1kOG/0
0?ne003o[@00okD0Ngek003o]@00ojd00?ne003o[@0010000?n]003o]@00
ojd00?ne0P1kOG/01000ojd00?ne07]mN`1kOG/40?ooo`040004003oool0
oooo000400<0oooo00<000@00?ooo`3oool0[`3oool010001000oooo0?oo
o`0010030?ooo`030004003oool0oooo04`0oooo002W0?ooo`0307]mN`00
10000?ne00<00?n]00H00?ne07]mN`00ojd00?n]003o]@001002003o[@05
003o]@00ojd0Ngek003o[@00okD00`00ojd00`001000oooo0?ooo`020?oo
o`8000@0103oool00`001000oooo0?ooo`2`0?ooo`8000@0103oool00`00
1000oooo0?ooo`1<0?ooo`00YP3oool02P1kOG/00?n]0004000010000?ne
003o[@00okD00?n]07]mN`00ojd600040006003o]@1kOG/00?ne003o[@00
okD00?n]0P0010000`1kOG/0oooo0?ooo`070?ooo`030004003oool0oooo
0;H0oooo00<000@00?ooo`3oool0C03oool00:@0oooo00P00?n]07]mN`00
ojd00?ne003o[@0010000?n]003o]@8000@000H0Ngek00040000ojd00?n]
00040000okD2003o[@030004001kOG/000@000800?n]00@00?ne00040000
ojd00?n]0P1kOG/70?ooo`030004003oool0oooo0;H0oooo00<000@00?oo
o`3oool0C03oool00:<0oooo0P1kOG/01@00ojd00?ne003o[@00okD00?n]
008000@000d00?ne003o[@1kOG/00?n]003o]@00ojd000@0003o[@00okD0
0?n]003o]@1kOG/00?ne00<000@000H00?ne003o[@00okD00?n]003o]@1k
OG/60?ooo`030004003oool0oooo0;H0oooo00<000@00?ooo`3oool0C03o
ool00:<0oooo0`1kOG/3003o[@8000@00P00ojd01P00okD00?n]07]mN`00
ojd00?ne000400800?n]00D00?ne07]mN`00ojd00?n]003o]@0300040003
003o]@00ojd00?n]00<0Ngek1@3oool00`001000oooo0?ooo`2f0?ooo`03
0004003oool0oooo04`0oooo002Q0?ooo`0L003o[@1kOG/00?n]003o]@1k
OG/00?ne003o[@0010000?n]003o]@0010000?ne003o[@00okD0Ngek003o
]@00ojd000@007]mN`00okD00?n]07]mN`00ojd00?ne003o[@0010000?n]
003o]@8000@000D00?n]07]mN`00ojd00?ne07]mN`040?ooo`030004003o
ool0oooo0;H0oooo00<000@00?ooo`3oool0C03oool00:40oooo00<00?n]
07]mN`00okD00P00ojd207]mN`<00?n]00<000@0003o[@00ojd0101kOG/0
0`001000Ngek07]mN`0207]mN`05003o]@00ojd000@0003o[@00okD00P00
ojd207]mN`<00?n]00<0Ngek0?ooo`3oool00P3oool00`001000oooo0?oo
o`2_0?ooo`@000@00`3oool00`001000oooo0?ooo`1<0?ooo`00X03oool0
5`00okD0Ngek003o]@00ojd00?ne00040000okD0Ngek003o]@00ojd00?ne
003o[@001000Ngek003o]@1kOG/00?ne003o[@0010000?n]003o]@1kOG/0
0?ne0080Ngek00`000@0003o]@00ojd00?ne003o[@1kOG/000@0003o]@00
ojd00?ne003o[@1kOG/30?ooo`030004003oool0oooo0:l0oooo00<000@0
0?ooo`3oool0103oool00`001000oooo0?ooo`1<0?ooo`00X03oool30004
00800?n]00L000@0003o[@00ojd0Ngek003o]@00ojd0Ngek008000@00P00
ojd00`1kOG/00?ne00040002003o[@0307]mN`00ojd00?n]008000@00P00
ojd207]mN`800?n]00<000@0003o]@00ojd00`0010020?ooo`030004003o
ool0oooo0:80oooo401kOG/010001000Ngek07]mN`3oool2000404d0oooo
002O0?ooo`0307]mN`00okD00?n]00<000@000@00?n]003o]@00ojd00?ne
0P1kOG/01`00ojd00?ne00040000okD00?n]07]mN`00ojd00P0010001P00
okD0Ngek003o]@00ojd000@0003o[@<0Ngek00@00?n]003o]@00ojd00?ne
0`0010001@00okD0Ngek0?ooo`3oool000@009l0oooo1@1kOG/05P00ojd0
0?ne07]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00
ojd00?ne003o[@00okD000@0003o]@00ojd0Ngek0004001kOG]=0?ooo`00
W`3oool01@1kOG/00?n]003o[@00ojd00?ne008000@000<00?n]003o]@00
ojd00P1kOG/01P00okD00?n]003o[@0010000?ne07]mN`@000@000<0Ngek
003o[@0010000`00ojd207]mN`800?n]00D00?ne00040000100000@0003o
]@02003o[@0307]mN`3oool000@009`0oooo0`1kOG/3003o[@05003o]@00
ojd00?n]003o[@1kOG/00`00ojd01@00okD00?n]003o[@00ojd00?ne00<0
0?n]00P00?ne003o[@0010000?n]003o]@00ojd000@0003o[@@0NgekB@3o
ool009h0oooo00L0Ngek003o[@00okD00?n]003o]@0010000?ne008000@0
00@00?n]07]mN`00ojd00?ne0P1kOG/00`00ojd000@00004000207]mN`04
00040000ojd0Ngek003o[@8000@001400?ne07]mN`1kOG/00?n]003o]@1k
OG/00?ne00040000okD00?n]00040000ojd00?ne003o[@00okD0Ngek0004
002J0?ooo`80Ngek02800?n]003o]@00ojd00?ne003o[@00okD00?n]003o
]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD000@0003o]@00ojd00?ne00040000okD0
0?n]003o]@00ojd00?ne101kOG]50?ooo`00WP3oool02@1kOG/00?n]003o
[@00okD00?n]00040000ojd00?ne003o[@020004000A003o]@00ojd00?n]
07]mN`0010000?n]00040000ojd0Ngek00040000ojd0Ngek003o]@001000
0?n]0004001kOG/00P00ojd3000400800?n]00P00?ne00040000ojd00?n]
003o]@00ojd0Ngek000409P0oooo00D0Ngek00040000ojd00?n]003o]@03
003o[@05003o]@00ojd00?n]003o[@00okD00P00ojd00`1kOG/00?ne003o
[@02003o[@05003o]@00ojd00?n]003o[@00okD00P00ojd00`0010000?ne
003o[@02003o[@0500040000ojd00?n]003o[@00okD00`00ojd01000okD0
Ngek07]mN`1kOG]30?ooo`00WP3oool307]mN`08003o[@0010000?n]003o
]@00ojd00?ne07]mN`00okD20004000<003o[@001000Ngek003o]@001000
0?ne07]mN`0010000?n]07]mN`00ojd000@00P1kOG/02`0010000?ne0004
000010000?n]07]mN`00ojd00?ne003o[@0010000?n]00@0Ngek00<000@0
0?ooo`3oool0T`3oool0;`00okD0Ngek07]mN`00ojd000@0003o[@00okD0
0?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@1k
OG/00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o
[@0010000?n]003o]@00ojd00?ne00040000okD00?n]003o]@00ojd00?ne
003o[@00okD0Ngek003o]@00ojd00?ne0080Ngek@@3oool009h0oooo00<0
Ngek003o]@00ojd0101kOG/00`00ojd0Ngek003o]@03003o[@8000@000H0
0?n]07]mN`1kOG/000@007]mN`00100207]mN`040004001kOG/0Ngek003o
[@8000@000H00?ne003o[@00ojd0Ngek003o]@00ojd407]mN`800?n]00<0
Ngek0004003oool0T`3oool207]mN`05003o]@00ojd00?n]00040000okD0
0`00ojd01@00okD00?n]003o[@00ojd00?ne00<00?n]00D00?ne07]mN`00
ojd00?n]003o]@03003o[@06003o]@00ojd00?n]003o[@00okD000@00P00
ojd01@00okD00?n]00040000ojd00?ne00<00?n]00D00?ne003o[@1kOG/0
0?n]003o]@03003o[@80Ngek?`3oool009d0oooo00P0Ngek003o]@00ojd0
0?ne003o[@0010000?n]003o]@@0Ngek00<00?n]003o]@0010000P001000
1`00okD0Ngek07]mN`1kOG/000@007]mN`0010000P1kOG/01P00ojd000@0
0004000010000?n]003o]@@0Ngek00P00?n]003o]@0010000?ne003o[@00
okD0Ngek00040980oooo0P1kOG/0=@00ojd00?ne003o[@00okD00?n]0004
0000ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@00ojd0Ngek003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD0
0?n]003o]@00ojd000@0003o[@00okD00?n]003o]@0010000?ne003o[@00
okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd00?ne003o
[@00okD0Ngek03h0oooo002M0?ooo`0607]mN`00ojd00?n]003o[@00okD0
00@00P00ojd01000okD0Ngek003o[@00ojd407]mN`04003o]@00100000@0
07]mN`8000@00P1kOG/300040003003o[@1kOG/0Ngek0080Ngek00X00?ne
003o[@1kOG/00?n]003o]@00ojd000@0003o[@00okD00?n]0P1kOG^A0?oo
o`0407]mN`00ojd00?n]003o]@<00?n]00D00?ne003o[@0010000?n]003o
]@03003o[@05003o]@00ojd00?n]003o[@00okD00P00ojd00`1kOG/00?ne
003o[@02003o[@05003o]@00ojd00?n]003o[@00okD00P00ojd00`001000
0?ne003o[@02003o[@0500040000ojd00?n]003o[@00okD00`00ojd01@1k
OG/00?n]003o[@00ojd00?ne00<00?n]00<00?ne07]mN`1kOG/0?03oool0
09d0oooo00l0Ngek003o]@00ojd00?ne00040000okD00?n]003o]@00ojd0
Ngek003o[@00okD00?n]00040000ojd0101kOG/00`001000Ngek00040003
000400<0Ngek01000?n]003o]@0010000?ne003o[@00okD0Ngek003o]@00
ojd00?ne00040000okD00?n]003o]@00ojd0NgekS`3oool207]mN`0j003o
]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]
003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/0
0?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00
10000?n]003o]@00ojd00?ne00040000okD00?n]003o]@00ojd00?ne003o
[@1kOG/00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne
003o[@80Ngek>P3oool009d0oooo4`00100207]mNaL000@0SP3oool01@1k
OG/00?n]003o[@00ojd00?ne00<00?n]00H00?ne003o[@00ojd00?n]003o
]@001002003o[@05003o]@00ojd00?n]003o[@00okD00`00ojd00`00okD0
Ngek003o[@0;000400800?n]00D00?ne003o[@0010000?n]003o]@03003o
[@05003o]@1kOG/00?n]003o[@00okD00`00ojd02000okD00?n]003o[@00
ojd00?ne003o[@3oool000@0>@3oool009d0oooo0140Ngek003o]@00ojd0
0?ne00040000okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]00040000
ojd00?ne003o[@0407]mN`030004001kOG/0Ngek00<0Ngek01400?ne003o
[@00okD000@0003o]@00ojd00?ne07]mN`00okD00?n]003o]@0010000?ne
003o[@00okD00?n]07]mN`1a0?ooo`030004003oool0oooo00D0oooo0`00
10090?ooo`8000@01@3oool06000ojd0Ngek003o[@00okD00?n]003o]@00
ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@0010000?n]003o
]@00ojd00?ne003o[@00okD00?n]003o]@<000@000/0Ngek00040000okD0
0?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@070004000F003o]@00
ojd00?ne003o[@00okD0Ngek003o]@00ojd00?ne003o[@00okD00?n]003o
]@00ojd00?ne003o[@00okD00?n]003o]@00ojd000@007]mN`P0oooo0P00
10090?ooo`<000@01`3oool2000401T0oooo002M0?ooo`0407]mN`00ojd0
0?n]003o[@8000@00P00ojd01P00okD0Ngek003o[@00ojd00?ne000400@0
Ngek0P001000101kOG/000@007]mN`1kOG/20004000?003o[@1kOG/0Ngek
07]mN`0010000?n]003o]@00ojd0Ngek003o[@00okD00?n]00040000ojd0
0?ne00800?n]00<0Ngek0?ooo`3oool0K`3oool00`001000oooo0?ooo`05
0?ooo`040004003oool0oooo000400L0oooo00@000@00?ooo`3oool000@0
0`3oool307]mN`800?n]00D00?ne003o[@00ojd00?n]003o]@03003o[@05
003o]@00ojd00?n]003o[@0010000P00ojd500040005003o]@00ojd00?n]
07]mN`00okD00`00ojd02@00okD00?n]003o[@00ojd00?ne003o[@001000
0?n]003o]@03003o[@<000@000H00?n]003o]@00ojd0Ngek003o[@00okD3
003o[@05003o]@00ojd00?n]003o[@00okD00`00ojd00`0010000?n]003o
[@0207]mN`D0oooo00@000@00?ooo`3oool000@02@3oool00`001000oooo
0?ooo`050?ooo`040004003oool0oooo000401P0oooo002M0?ooo`0907]m
N`00okD00?n]003o]@00ojd000@0003o[@00okD00?n]00D0Ngek00@000@0
003o]@00100000@00P1kOG/010001000Ngek07]mN`00100207]mN`8000@0
00<00?n]0004001kOG/0101kOG/02@00okD00?n]003o]@0010000?ne003o
[@00okD0Ngek0004001a0?ooo`030004003oool0oooo00D0oooo00@000@0
0?ooo`3oool000@02P3oool05@001000oooo0?ooo`1kOG/00?ne003o[@00
okD0Ngek003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o
[@00okD00?n]003o]@030004000L003o]@00ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD0
0?n]003o]@0010000?ne003o[@00okD00?n]003o]@0010000?ne003o[@80
00@001D00?ne07]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD000@0003o]@00ojd00?ne003o[@1kOG/0
1P3oool00`001000oooo0?ooo`050?ooo`D000@02@3oool00`001000oooo
0?ooo`0F0?ooo`00WP3oool01@1kOG/00?ne003o[@00ojd000@000@0Ngek
00@00?ne003o[@00ojd00?n]0P001002003o[@0407]mN`001000Ngek0004
0080Ngek00@000@007]mN`00okD00?n]0P0010000`00okD00?n]003o[@05
07]mN`0600040000ojd00?n]003o[@1kOG/000@0J@3oool4000400D0oooo
1@0010020?ooo`<000@00P3oool4000400<0oooo0P0010020?ooo`0307]m
N`00okD00?n]00800?n]00D00?ne07]mN`00ojd00?n]003o]@03003o[@05
003o]@00ojd00?n]003o[@00okD00`0010001@00okD00?n]003o[@00ojd0
0?ne00<00?n]00D00?ne003o[@1kOG/00?n]003o]@03003o[@05003o]@00
ojd00?n]003o[@0010000`00ojd01@00okD00?n]00040000ojd00?ne0080
0?n]00<0Ngek0004000010000P00ojd01@00okD00?n]003o[@00ojd00?ne
00<00?n]0P001002003o[@05003o]@00ojd00?n]003o[@1kOG/01P3oool0
0`001000oooo0?ooo`040?ooo`040004003oool0oooo000400P0oooo0P00
100I0?ooo`00WP3oool507]mN`07003o[@00okD00?n]003o]@1kOG/00?ne
003o[@020004000=003o]@1kOG/0Ngek003o[@001000Ngek00040000ojd0
Ngek00040000okD0Ngek003o]@0300040007003o]@00ojd0Ngek003o[@00
okD00?n]0004000507]mN`030004003oool0oooo06d0oooo00@000@00?oo
o`3oool000@01`3oool00`001000oooo0?ooo`080?ooo`0k0004003oool0
oooo07]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD0Ngek003o]@00
ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]0004
0000ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD0Ngek
003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD0
0?n]003o]@00ojd00?ne00040000okD00?n]003o]@00ojd0Ngek003o[@00
okD00P0010004P00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0003o
[@00okD00?n]003o]@00ojd00?ne003o[@00okD0oooo07]mN`80oooo00@0
00@00?ooo`3oool000@01`3oool00`001000oooo000400080?ooo`030004
003oool0oooo01P0oooo002N0?ooo`0507]mN`00ojd00?n]003o]@001000
0P00ojd00`00okD00?n]07]mN`02000400800?n]0P1kOG/02P00ojd000@0
003o[@1kOG/000@0003o[@1kOG/00?ne00040000ojd207]mN`800?n]0P00
1003003o[@08003o]@0010000?n]003o[@00okD00?n]07]mN`00101_0?oo
o`@000@01`3oool3000400P0oooo0P0010000`1kOG/00?ne003o[@02003o
[@06003o]@00ojd00?n]003o[@00okD0Ngek0P00ojd01P00okD00?n]003o
[@00ojd00?ne000400800?n]00D00?ne003o[@0010000?n]003o]@03003o
[@05003o]@00ojd00?n]003o[@1kOG/00`00ojd02@00okD00?n]003o[@00
ojd00?ne003o[@0010000?n]003o]@03003o[@0500040000ojd00?n]003o
[@1kOG/00`00ojd01@00okD00?n]0004000010000?ne00<00?n]00D00?ne
00040000ojd00?n]003o]@03003o[@05003o]@00ojd00?n]0?ooo`1kOG/0
0P3oool2000400T0oooo0P0010080?ooo`<000@0603oool009h0oooo00P0
Ngek003o[@00okD00?n]003o]@0010000?ne003o[@8000@000D0Ngek003o
[@00okD00?n]07]mN`020004000?003o[@00okD0Ngek00040000ojd0Ngek
003o[@0010000?n]0004001kOG/00?ne003o[@00okD0Ngek008000@000T0
0?ne003o[@0010000?n]003o]@00ojd00?ne07]mN`001000QP3oool04@1k
OG/00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]07]m
N`00ojd00?ne003o[@00okD00?n]008000@003d00?ne003o[@00okD00?n]
003o]@0010000?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD0
Ngek003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne00040000
okD00?n]003o]@00ojd00?ne00040000okD00?n]003o]@1kOG/00?ne003o
[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]003o]@0010000?ne
003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@3oool0
Ngek0340oooo002O0?ooo`0;07]mN`00ojd00?n]003o[@0010000?n]0004
0000ojd00?ne07]mN`00ojd00P1kOG/2003o[@8000@000D0Ngek003o[@00
10000?ne07]mN`03000400800?n]0`1kOG/2003o[@<000@000L00?n]003o
]@00ojd00?n]07]mN`3oool000@008D0oooo00<0Ngek003o]@00ojd00P00
ojd01@00okD00?n]003o[@00ojd00?ne00<00?n]00<0Ngek003o[@00ojd0
0P001003003o[@06003o]@00ojd00?n]003o[@00okD000@00P00ojd02@00
okD00?n]003o[@00ojd00?ne003o[@1kOG/00?n]003o]@03003o[@05003o
]@00ojd00?n]003o[@0010000`00ojd01P00okD00?n]00040000ojd00?ne
07]mN`800?n]00D00?ne003o[@00ojd00?n]003o]@02003o[@8000@000@0
0?n]00040000ojd00?ne0`00ojd01@00okD00?n]003o[@00ojd00?ne0080
0?n]00<0Ngek0?ooo`3oool0;`3oool009l0oooo00@0Ngek003o]@00ojd0
0?ne0P0010001000ojd00?ne003o[@00okD207]mN`06003o[@00okD000@0
00040000ojd0Ngek10001000301kOG/00?ne0004000010000?n]003o]@1k
OG/00?ne003o[@00okD00?n]003o]@8000@000H00?n]003o]@00ojd0Ngek
0?ooo`0010240?ooo`1C07]mN`00okD00?n]003o]@00ojd00?ne003o[@00
okD00?n]003o]@00ojd00?ne003o[@00okD0Ngek003o]@0010000?ne003o
[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]00040000ojd00?ne
003o[@00okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd0
0?ne003o[@00okD00?n]00040000ojd00?ne003o[@00okD00?n]003o]@00
10000?ne003o[@1kOG/00?n]003o]@00ojd00?ne003o[@00okD00?n]003o
]@00ojd00?ne003o[@0010000?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD00?n]003o]@1kOG/07@3oool4000400l0
oooo002O0?ooo`0707]mN`00ojd000@000040000ojd000@0003o]@02003o
[@@0Ngek00L00?n]00040000ojd00?n]07]mN`00okD000@000800?n]00T0
Ngek003o[@00ojd000@0003o]@1kOG/00?n]07]mN`00okD00P00ojd00`00
10000?ne003o[@020004000407]mN`3oool0oooo000408<0oooo00<0Ngek
003o]@00ojd00P00ojd01@00okD00?n]003o[@00ojd00?ne00<00?n]00<0
0?ne003o[@0010000P1kOG/3003o[@05003o]@00ojd00?n]003o[@00okD0
0P00ojd00`0010000?ne003o[@02003o[@06003o]@00ojd00?n]003o[@00
okD0Ngek0P00ojd01P00okD00?n]003o[@00ojd00?ne000400800?n]00D0
0?ne003o[@00ojd00?n]00040002003o[@0307]mN`00okD00?n]00800?n]
00T00?ne003o[@00ojd00?n]003o]@00ojd000@0003o[@0010000`00ojd0
1@00okD00?n]003o[@00ojd00?ne00<00?n]00@00?ne003o[@1kOG/0Ngek
6`3oool010001000oooo0?ooo`00100@0?ooo`00X03oool01`0010000?n]
003o]@00ojd00?ne00040000okD00P1kOG/05000ojd00?ne003o[@001000
0?n]003o]@1kOG/00?ne003o[@0010000?n]003o]@1kOG/00?ne003o[@00
okD000@0003o]@00ojd00?ne0P1kOG/01`00ojd000@0003o[@00okD00?n]
003o]@0010000P3oool00`001000oooo0?ooo`1/0?oooh0000@01@3oool0
10001000oooo0?ooo`00100@0?ooo`00MP3oool300040140oooo0P00100B
0?ooo`<000@000<0Ngek003o[@00okD00P00ojd00`001000Ngek003o[@02
003o[@8000@00`1kOG/2003o[@0400040000okD00?n]003o[@<0Ngek00<0
00@0003o[@00okD00P00ojd00`1kOG/000@0003o[@02003o[@03003o]@1k
OG/0oooo0080oooo00<000@00?ooo`3oool0403oool500040100oooo1000
10130?ooo`030004003oool0oooo00L0oooo00<000@00?ooo`3oool01`3o
ool01@1kOG/00?n]003o[@0010000?ne00<00?n]00T00?ne003o[@00ojd0
0?n]003o]@00ojd000@0003o[@00okD00P00ojd00`1kOG/00?ne003o[@02
003o[@08003o]@00ojd00?n]003o[@00okD00?n]00040000ojd407]mN`05
003o]@00ojd00?n]07]mN`00okD00`00ojd01@00okD00?n]003o[@001000
0?ne00800?n]0P1kOG/01000ojd000@0003o[@1kOG/3003o[@05003o]@00
ojd00?n]003o[@00okD00P00ojd00`0010000?ne003o[@02003o[@05003o
]@0010000?n]003o[@00okD00`00ojd01@00okD00?n]003o[@1kOG/00?ne
00800?n]00<0Ngek0?ooo`3oool01P3oool00`001000oooo0?ooo`080?oo
o`030004003oool0oooo0080oooo0P0010000`3oool000@00004000@0?oo
o`00M`3oool00`001000oooo0?ooo`0?0?ooo`040004003oool0oooo0004
0140oooo00L000@00?ooo`3oool00?n]07]mN`00ojd00?ne0080Ngek0P00
10001P00ojd00?ne00040000okD00?n]003o]@<0Ngek00<000@007]mN`1k
OG/00P1kOG/02000ojd00?ne003o[@0010000?n]003o]@0010000?ne0P1k
OG/00`00ojd00?ne07]mN`040?ooo`030004003oool0oooo0180oooo00<0
00@00?ooo`3oool0403oool00`001000oooo0?ooo`1H0?ooo`0g07]mN`00
okD00?n]003o]@0010000?ne003o[@00okD00?n]003o]@00ojd00?ne003o
[@0010000?n]003o]@00ojd00?ne003o[@00okD0Ngek003o]@00ojd00?ne
003o[@00okD00?n]003o]@00ojd00?ne0004001kOG/00?n]003o]@00ojd0
0?ne003o[@00okD00?n]07]mN`00ojd00?ne003o[@00okD00?n]003o]@00
ojd000@0003o[@00okD00?n]003o]@00ojd0Ngek0004000207]mN`0H003o
]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]
003o]@00ojd00?ne003o[@00okD000@0003o]@00ojd00?ne003o[@00okD0
0?n]0P1kOG/01@00okD00?n]003o]@00ojd0Ngek02d0oooo001d0?ooo`D0
00@04P3oool00`001000oooo0?ooo`0A0?ooo`070004003oool0oooo003o
[@1kOG/00?n]07]mN`03003o[@8000@00P00ojd01P00okD00?n]07]mN`00
ojd00?ne000400800?n]00H00?ne07]mN`00ojd00?n]003o]@001002003o
[@0600040000ojd00?n]07]mN`00okD0Ngek1@3oool00`001000oooo0?oo
o`0B0?ooo`030004003oool0oooo0140oooo00<000@00?ooo`3oool0EP3o
ool0101kOG/00?n]003o[@00okD2003o[@0300040000okD00?n]00800?n]
00D00?ne003o[@0010000?n]003o]@03003o[@05003o]@00ojd00?n]07]m
N`00okD00`00ojd00`00okD00?n]003o[@0207]mN`0400040000ojd00?n]
003o]@<00?n]00D00?ne07]mN`00ojd00?n]003o]@03003o[@05003o]@00
10000?n]003o[@00okD00`00ojd00`001000Ngek003o[@0207]mN`<00?n]
00D00?ne003o[@00ojd000@0003o]@03003o[@06003o]@00ojd00?n]003o
[@00okD000@00P00ojd01@00okD0Ngek07]mN`00ojd00?ne00<00?n]00<0
0?ne003o[@1kOG/0;03oool006h0oooo100010020?ooo`040004003oool0
oooo000400/0oooo100010050?ooo`030004003oool0oooo00T0oooo1000
10040?ooo`030004003oool0oooo0080Ngek01H00?n]003o]@00ojd00?ne
003o[@0010000?n]003o]@00ojd00?ne07]mN`00okD00?n]00040000ojd0
0?ne003o[@1kOG/00?n]003o]@00ojd00?ne0P0010001@00ojd00?ne003o
[@00okD0Ngek00H0oooo00<000@00?ooo`3oool04P3oool00`001000oooo
0?ooo`0B0?ooo`030004003oool0oooo05@0oooo00P00?n]07]mN`00ojd0
0?ne003o[@00okD00?n]003o]@8000@001<00?n]003o]@00ojd00?ne0004
0000okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@1kOG/00?ne
003o[@00okD00?n]0080Ngek01h00?ne003o[@0010000?n]003o]@00ojd0
0?ne003o[@00okD00?n]07]mN`00ojd00?ne003o[@00okD00?n]003o]@00
ojd000@0003o[@00okD00?n]003o]@00ojd00?ne0004001kOG/00?n]003o
]@00ojd207]mN`0M003o]@00ojd00?ne00040000okD00?n]003o]@00ojd0
0?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD0Ngek003o]@00
ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/0:`3oool0
07D0oooo00<000@00?ooo`0010004@3oool010001000oooo0?ooo`00100A
0?ooo`040004003oool0oooo00040080oooo00D00?n]07]mN`00ojd00?ne
003o[@050004000607]mN`00okD00?n]003o[@0010000?ne0`00ojd00`1k
OG/000@000040003000400800?n]00<00?ne07]mN`3oool01P3oool00`00
1000oooo0?ooo`0B0?ooo`030004003oool0oooo0100oooo00@000@00?oo
o`3oool000@0E@3oool00`1kOG/00?n]003o]@03003o[@04003o]@00ojd0
0?n]003o[@8000@000<00?n]00040000okD00`00ojd02@00okD00?n]003o
[@00ojd00?ne003o[@1kOG/00?n]003o]@0207]mN`03003o[@00okD00?n]
00800?n]00D000@0003o[@00ojd00?n]003o]@03003o[@0507]mN`00ojd0
0?n]003o[@00okD00P00ojd00`0010000?ne003o[@02003o[@05003o]@00
ojd000@0003o[@00okD00`00ojd01@00okD0Ngek07]mN`0010000?ne00<0
0?n]00D00?ne003o[@00ojd00?n]003o]@03003o[@05003o]@1kOG/00?n]
003o[@00okD00`00ojd01`00okD00?n]003o[@00ojd00?ne003o[@1kOG/0
:P3oool007H0oooo0P00100B0?ooo`8000@04`3oool2000400D0oooo00T0
Ngek003o[@00okD000@0003o]@00ojd00?ne003o[@1kOG/0200010002@1k
OG/00?ne003o[@00okD00?n]00040000ojd00?ne07]mN`080?ooo`030004
003oool0oooo0140oooo0P00100C0?ooo`8000@0E@3oool06P1kOG/00?n]
003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD0
00@0003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00
okD00?n]0P1kOG/0@P00okD00?n]003o]@00ojd00?ne003o[@00okD000@0
003o]@00ojd00?ne003o[@00okD00?n]003o]@1kOG/00?ne003o[@00okD0
0?n]003o]@00ojd000@0003o[@00okD00?n]003o]@00ojd00?ne00040000
okD00?n]003o]@00ojd00?ne003o[@00okD00?n]00040000ojd00?ne003o
[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@1kOG/00?ne
00040000okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0
0?ne07]mNbX0oooo002W0?ooo`0307]mN`0010000?ne00<00?n]00H00?ne
07]mN`00ojd00?n]003o]@001002003o[@05003o]@00ojd0Ngek003o[@00
okD00`00ojd00`001000Ngek0?ooo`080?ooo`030004003oool0oooo07d0
oooo00<0Ngek003o]@00ojd00P00ojd01@00okD00?n]003o[@00ojd00?ne
00800?n]00<000@0003o]@0010000P00ojd01@00okD00?n]003o[@00ojd0
0?ne00<00?n]00D00?ne07]mN`1kOG/00?n]003o]@03003o[@05003o]@00
ojd00?n]00040000okD00`00ojd01@00okD00?n]07]mN`00ojd00?ne00<0
0?n]00D000@0003o[@00ojd00?n]003o]@02003o[@0307]mN`0010000?n]
00800?n]00T00?ne003o[@00ojd00?n]00040000ojd0Ngek003o[@00okD0
0`00ojd01000okD00?n]003o[@00ojd207]mN`800?n]00D000@0003o[@00
ojd00?n]003o]@03003o[@06003o]@00ojd00?n]003o[@3oool0Ngek:@3o
ool00:P0oooo01<000@007]mN`1kOG/00?n]003o]@1kOG/00?ne003o[@00
okD00?n]00040000ojd00?ne003o[@00okD0Ngek003o]@00ojd00?ne0080
Ngek00<000@00?ooo`3oool0203oool00`001000oooo0?ooo`0/0?ooo`80
00@000<0oooo000400001000B`3oool0H01kOG/00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0003o[@00okD0
00@0003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00
okD00?n]07]mN`00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0003o
[@00okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd00?ne
00040000okD00?n]003o]@00ojd00?ne003o[@1kOG/000@0003o]@00ojd0
0?ne003o[@00okD00?n]003o]@0010000?ne003o[@1kOG/00?n]003o]@00
ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne003o[@00okD00?n]0004
0000ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
07]mNbT0oooo002Z0?ooo`06003o[@1kOG/0Ngek07]mN`00ojd00?ne0P00
ojd00`0010000?ne003o[@02003o[@04003o]@1kOG/0Ngek07]mN`d0oooo
00<000@00?ooo`3oool0;@3oool00`001000oooo0004001<0?ooo`0507]m
N`00ojd00?n]003o[@00okD00`00ojd01@00okD00?n]003o[@00ojd000@0
00<00?n]00D00?ne0004000010000?n]003o]@03003o[@09003o]@1kOG/0
0?n]003o[@00okD00?n]07]mN`00ojd00?ne00<00?n]00D00?ne003o[@00
10000?n]003o]@03003o[@0907]mN`00ojd00?n]003o[@00okD00?n]0004
0000ojd00?ne00<00?n]00D0Ngek003o[@0010000?n]003o]@03003o[@80
00@00P00ojd01@00okD00?n]07]mN`00ojd00?ne00<00?n]00D0Ngek003o
[@00ojd00?n]003o]@02003o[@0300040000okD00?n]00800?n]00D00?ne
003o[@00ojd00?n]003o]@02003o[@0307]mN`3oool0oooo02L0oooo001c
0?ooocX000@01@1kOG/00`001000Ngek07]mN`0407]mNcX000@01P3oool0
0`001000oooo0?ooo`1:0?ooo`0_07]mN`00ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD00?n]00040000ojd00?ne003o[@00okD0
0?n]003o]@00ojd000@0003o[@00okD00?n]003o]@1kOG/00?ne003o[@00
okD00?n]003o]@1kOG/00?ne003o[@00okD00?n]003o]@00ojd00?ne0004
0000okD00?n]003o]@00ojd00?ne07]mN`00okD01@001000;P00okD00?n]
003o]@00ojd00?ne07]mN`00okD000@0003o]@00ojd00?ne003o[@001000
0?n]003o]@00ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne003o[@1k
OG/00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@0010000?ne003o
[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@1kOG/X0?oo
o`00L`3oool00`001000oooo0?ooo`0B0?ooo`030004003oool0oooo0180
oooo00<000@00?ooo`3oool0:03oool00`001000oooo0?ooo`0B0?ooo`03
0004003oool0oooo0180oooo00<000@00?ooo`3oool00P3oool200040003
0?ooo`00100000@004X0oooo00@0Ngek003o[@00ojd00?ne0`00ojd01P00
okD00?n]003o[@00ojd00?ne000400800?n]00X00?ne003o[@00ojd00?n]
003o]@00ojd000@0003o[@00okD0Ngek0P00ojd01P00okD00?n]003o[@00
ojd00?ne07]mN`800?n]00H00?ne003o[@00ojd00?n]003o]@001002003o
[@8000@000<0Ngek0004000010000P00ojd500040005003o]@00ojd0Ngek
003o[@0010000`00ojd01@00okD000@0003o[@00ojd00?ne00<00?n]00D0
0?ne07]mN`00ojd00?n]07]mN`03003o[@09003o]@00ojd00?n]003o[@00
okD00?n]00040000ojd00?ne00<00?n]00D00?ne003o[@00ojd00?n]003o
]@02000402P0oooo00380?ooo`030004003oool0oooo07X0oooo0P1kOG/0
5@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD000@0
003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@020004
000?003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00
okD00?n]003o]@00ojd00?ne00@000@000`00?n]003o]@00ojd0Ngek003o
[@00okD00?n]003o]@0010000?ne003o[@00okD20004000@07]mN`00okD0
00@0003o]@00ojd00?ne00040000okD00?n]003o]@00ojd00?ne003o[@00
okD00?n]003o]@80Ngek01<00?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@0010000?n]003o]@00ojd00?ne003o[@00okD0
0?n]008000@000<00?ne0?ooo`1kOG/09`3oool00<P0oooo00<000@00?oo
o`3oool0NP3oool0101kOG/00?n]07]mN`1kOG/2003o[@09003o]@00ojd0
0?n]003o[@00okD00?n]00040000ojd00?ne00<00?n]00T00?ne003o[@00
ojd00?n]003o]@1kOG/00?n]00040000okD00`00ojd01P00okD00?n]003o
[@00ojd00?ne07]mN`800?n]00D00?ne00040000ojd00?n]00040003003o
[@09003o]@1kOG/00?n]003o[@00okD00?n]00040000ojd00?ne00800?n]
00X0Ngek003o]@00100000@0003o[@00okD00?n]00040000ojd00?ne0`00
ojd00`00okD00?n]003o[@0307]mN`800?n]00D00?ne003o[@00ojd00?n]
003o]@03003o[@05003o]@0010000?n]003o[@00okD010001003003o[@03
003o]@1kOG/0oooo02H0oooo00380?ooo`030004003oool0oooo07X0oooo
00@0Ngek003o]@00ojd00?ne101kOG/0=000ojd00?ne003o[@0010000?n]
003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/0
0?n]003o]@0010000?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00
okD0Ngek003o]@0010000?ne003o[@00okD000@0003o]@00ojd00?ne003o
[@1kOG/00?n]003o]@00ojd00?ne00040000okD00?n]003o]@00ojd0Ngek
003o[@00okD200040009003o[@0010000?n]003o]@00ojd00?ne003o[@00
okD00?n]0080Ngek00l00?ne003o[@00okD0Ngek003o]@00ojd00?ne003o
[@00okD00?n]003o]@00ojd00?ne003o[@00okD00`0010002P00okD00?n]
003o]@00ojd00?ne003o[@00okD00?n]0?ooo`1kOG/V0?ooo`00b03oool0
0`001000oooo0?ooo`1i0?ooo`0307]mN`00okD00?n]00800?n]00@00?ne
003o[@00ojd00?n]0P1kOG/00`0010000?n]003o]@03003o[@09003o]@00
ojd00?n]003o[@00okD00?n]07]mN`00ojd00?ne00800?n]00<000@0003o
]@00ojd00P00ojd01P00okD00?n]003o[@00ojd0Ngek000400800?n]00D0
0?ne003o[@0010000?n]003o]@02003o[@0307]mN`00okD00?n]00800?n]
00D000@0003o[@00ojd00?n]07]mN`03003o[@0500040000ojd000@0003o
[@00okD00`00ojd01@00okD00?n]07]mN`00ojd00?ne00<00?n]00D00?ne
07]mN`00ojd00?n]003o]@03003o[@03003o]@00ojd00?n]00<000@00P00
ojd01@00okD00?n]003o[@00ojd00?ne00<00?n]00<0Ngek0?ooo`3oool0
903oool00<P0oooo00<000@00?ooo`3oool0N@3oool02`1kOG/00?n]003o
]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne0080Ngek01000?n]
003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00okD0
0?n]003o]@00ojd00?ne0P0010007P00ojd00?ne003o[@00okD00?n]0004
0000ojd0Ngek003o[@00okD00?n]003o]@0010000?ne003o[@00okD00?n]
07]mN`00ojd00?ne003o[@0010000?n]003o]@00ojd00?ne07]mN`00okD0
0?n]003o]@8000@001L00?n]0004000010000?ne003o[@00okD00?n]003o
]@1kOG/00?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]
003o]@00ojd00?ne003o[@020004000?003o]@00ojd000@0003o[@00okD0
0?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@3oool0Ngek02D0oooo
00380?ooo`030004003oool0oooo07P0oooo00D0Ngek003o[@00ojd00?n]
003o]@03003o[@06003o]@00ojd00?n]003o[@0010000?n]0P1kOG/01@00
okD00?n]003o[@00ojd00?ne00800?n]00<0Ngek003o]@00ojd00P00ojd0
1000okD00?n]003o[@00ojd2000400800?n]00D000@0003o[@00ojd0Ngek
003o]@03003o[@06003o]@0010000?n]003o[@00okD0Ngek0P00ojd01P00
okD000@0003o[@00ojd00?ne07]mN`800?n]00D00?ne003o[@0010000?n]
003o]@02003o[@0300040000okD00?n]0080Ngek00D00?ne003o[@00ojd0
0?n]003o]@03003o[@0507]mN`00ojd00?n]003o[@00okD00P0010000`00
ojd00?ne003o[@02003o[@0500040000ojd00?n]003o[@00okD00`00ojd0
1000okD00?n]0?ooo`1kOG/U0?ooo`00b03oool00`001000oooo0?ooo`1h
0?ooo`0@07]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o
]@00ojd000@0003o[@00okD00?n]003o]@D0Ngek01<00?ne003o[@1kOG/0
0?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne00040000
okD000@0003o]@00ojd00?ne0080Ngek01X00?n]003o]@00ojd000@0003o
[@00okD00?n]003o]@1kOG/00?ne003o[@0010000?n]003o]@00ojd0Ngek
003o[@00okD00?n]003o]@0010000?ne003o[@00okD00?n]003o]@80Ngek
00d00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o
[@1kOG/00?n]008000@001<00?ne003o[@00okD00?n]003o]@00ojd00?ne
00040000okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0
Ngek02D0oooo00380?ooo`030004003oool0oooo07P0oooo00<0Ngek003o
[@00okD00`00ojd01P00okD00?n]003o[@00ojd00?ne000400800?n]00D0
0?ne003o[@00ojd00?n]003o]@02003o[@80Ngek0`00ojd01@00okD00?n]
003o[@00ojd00?ne00<00?n]0P001002003o[@05003o]@00ojd00?n]003o
[@1kOG/00`00ojd01@0010000?n]003o[@00ojd0Ngek00800?n]00H000@0
003o]@00ojd0Ngek003o[@00okD2003o[@8000@00`00ojd01@00okD0Ngek
003o[@0010000?ne00<00?n]00D00?ne003o[@00ojd00?n]003o]@02003o
[@8000@00`00ojd02@00okD00?n]003o[@00ojd00?ne003o[@0010000?n]
003o]@03003o[@06003o]@00ojd00?n]003o[@00okD0Ngek9@3oool00<P0
oooo00<000@00?ooo`3oool0N03oool05P1kOG/00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD00?n]00040000ojd00?ne003o[@00okD0
0?n]003o]@00ojd00?ne003o[@00okD307]mN`09003o]@00ojd00?ne003o
[@00okD00?n]003o]@00ojd00?ne00<000@002P00?ne003o[@00okD00?n]
003o]@1kOG/00?ne003o[@00okD000@0003o]@00ojd00?ne07]mN`00okD0
0?n]00040000ojd00?ne07]mN`00okD00?n]003o]@0010000?ne00040000
okD00?n]003o]@1kOG/00?ne003o[@0010000?n]003o]@00ojd00?ne003o
[@00okD00?n]100010005`1kOG/00?n]003o]@00ojd00?ne003o[@00okD0
0?n]003o]@00ojd00?ne00040000okD00?n]003o]@00ojd00?ne003o[@00
okD00?n]003o]@00ojd0Ngek02D0oooo00380?ooo`030004003oool0oooo
07L0oooo00<00?n]07]mN`00ojd00P00ojd01@00okD00?n]003o[@00ojd0
0?ne00800?n]00<000@0003o]@00ojd00P00ojd02@00okD00?n]003o[@00
ojd00?ne003o[@1kOG/00?n]003o]@0207]mN`03003o[@00okD00?n]0080
0?n]00D00?ne00040000ojd00?n]003o]@0200040006003o[@00okD00?n]
003o[@1kOG/00?ne0P00ojd00`0010000?ne07]mN`0307]mN`040004001k
OG/00?n]07]mN`800?n]00L000@0003o]@00ojd000@0003o[@00okD0Ngek
00800?n]00D00?ne003o[@0010000?n]003o]@02003o[@8000@00`00ojd0
1@00okD0Ngek003o[@00ojd00?ne00<00?n]00D00?ne003o[@00ojd00?n]
00040003003o[@05003o]@00ojd00?n]003o[@00okD00P00ojd00`1kOG/0
oooo0?ooo`0S0?ooo`00b03oool00`001000oooo0?ooo`1g0?ooo`0L003o
]@1kOG/00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD000@0
003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/0
0?n]003o]@00ojd00?ne003o[@80Ngek01X00?ne003o[@00okD000@0003o
]@00ojd00?ne003o[@00okD00?n]00040000ojd00?ne003o[@00okD0Ngek
003o]@1kOG/000@007]mN`00okD0Ngek003o]@00ojd000@0003o[@80Ngek
00H00?ne003o[@0010000?n]003o]@00100207]mN`08003o]@00ojd00?ne
003o[@00okD000@0003o]@00ojd20004000N003o]@00ojd00?ne003o[@00
okD00?n]003o]@1kOG/00?ne003o[@00okD00?n]003o]@00ojd00?ne003o
[@00okD00?n]00040000ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne
003o[@3oool0Ngek903oool00<P0oooo00<000@00?ooo`3oool0M`3oool0
101kOG/00?n]003o[@00okD3003o[@05003o]@00ojd00?n]003o[@001000
0`00ojd01@00okD00?n]003o[@00ojd00?ne00800?n]00<0Ngek003o]@00
ojd00P00ojd00`00okD00?n]003o[@0407]mN`03003o[@00okD00?n]0080
0?n]00D00?ne003o[@0010000?n]003o]@02003o[@0>07]mN`00okD00?n]
00040000ojd0Ngek003o[@0010000?n]003o]@1kOG/00?n]07]mN`001003
003o[@0500040000ojd00?n]003o[@00okD00`00ojd01@00okD000@00004
0000ojd00?ne00<00?n]00D00?ne003o[@00ojd00?n]07]mN`03003o[@05
003o]@00ojd00?n]003o[@00okD00P00ojd00`0010000?ne003o[@02003o
[@07003o]@00ojd00?n]003o[@00okD00?n]07]mN`0T0?ooo`00b03oool0
0`001000oooo0?ooo`1g0?ooo`0R07]mN`00ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD000@0003o]@00ojd00?ne003o[@00okD0
0?n]003o]@00ojd00?ne003o[@1kOG/00?n]003o]@00ojd00?ne003o[@00
okD00?n]003o]@00ojd00?ne00040080Ngek00H00?ne003o[@00okD00?n]
003o]@00ojd20004000J003o]@1kOG/0Ngek003o[@00okD000@0003o]@1k
OG/00?ne00040000okD00?n]07]mN`00ojd00?ne0004001kOG/00?n]07]m
N`0010000?ne003o[@00okD00?n]003o]@00ojd30004000M003o[@00okD0
0?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@1kOG/00?ne003o[@00
okD00?n]003o]@00ojd00?ne003o[@00okD00?n]00040000ojd00?ne003o
[@00okD00?n]003o]@00ojd0101kOG/T0?ooo`00b03oool00`001000oooo
0?ooo`1g0?ooo`8000@00`00ojd01P00okD00?n]003o[@00ojd00?ne0004
00800?n]00D00?ne003o[@00ojd00?n]003o]@03003o[@0507]mN`00ojd0
0?n]003o[@00okD00`00ojd01@00okD00?n]003o[@0010000?ne00800?n]
0P1kOG/3003o[@0@003o]@00ojd00?n]00040000okD00?n]07]mN`00ojd0
0?ne0004001kOG/00?n]00040000ojd0Ngek003o[@8000@000L00?n]07]m
N`1kOG/00?n]00040000ojd00?ne00800?n]0P001002003o[@0300040000
okD00?n]00800?n]00D00?ne003o[@00ojd00?n]003o]@02003o[@0307]m
N`00okD00?n]00800?n]00H00?ne003o[@00ojd00?n]003o]@00100707]m
N`<00?n]00<0Ngek0?ooo`3oool08P3oool00<P0oooo00<000@00?ooo`3o
ool0M`3oool00`1kOG/00?n]000400080004000K003o[@00okD00?n]003o
]@00ojd00?ne003o[@00okD00?n]003o]@1kOG/00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD00?n]00040000ojd00?ne003o[@00okD0
0?n]0080Ngek01L00?ne003o[@00okD0Ngek003o]@0010000?ne003o[@1k
OG/00?n]0004001kOG/00?ne00040000okD0Ngek00040000ojd00?ne07]m
N`00okD00?n]07]mN`050004000E003o]@00ojd00?ne003o[@00okD000@0
003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/0
0?n]003o]@00ojd00?ne00H0Ngek00/000@0003o]@00ojd00?ne003o[@00
okD00?n]003o]@00ojd00?ne07]mN`0T0?ooo`00b03oool00`001000oooo
0?ooo`1g0?ooo`0407]mN`00ojd00?n]003o]@<00?n]00<00?ne003o[@00
ojd02@0010001@00okD00?n]07]mN`00ojd00?ne00<00?n]00H00?ne003o
[@00ojd00?n]003o]@001002003o[@05003o]@00ojd00?n]003o[@00okD0
0P1kOG/03`00ojd0Ngek003o[@00ojd000@0003o]@00ojd0Ngek003o[@00
1000Ngek0004001kOG/00?ne00040002003o[@0307]mN`00ojd00?n]0080
00@00`00ojd02@00okD00?n]003o[@00ojd00?ne003o[@0010000?n]003o
]@03003o[@03003o]@00ojd00?n]00L0Ngek0P00ojd01@00okD00?n]003o
[@00ojd000@000<00?n]00L00?ne003o[@00ojd00?n]003o]@00ojd0Ngek
02@0oooo00380?ooo`030004003oool0oooo07H0oooo0P1kOG/04P00ojd0
0?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@0010000?n]003o]@00
ojd00?ne003o[@00okD00?n]003o]@T000@000h00?ne003o[@00okD00?n]
00040000ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@@0Ngek
00/00?ne0004000010000?n]07]mN`001000Ngek0004001kOG/000@0003o
]@0207]mN`0A003o[@00100000@007]mN`0010000?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD000@0003o]@00ojd01P1kOG/06000okD0
0?n]07]mN`00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00
okD000@0003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne07]m
Nb@0oooo00380?ooo`030004003oool0oooo07H0oooo00<0Ngek003o[@00
okD00`00ojd01P00okD00?n]003o[@00ojd00?ne000400800?n]00D00?ne
003o[@00ojd00?n]003o]@03003o[@0507]mN`00ojd00?n]003o[@00okD0
0P00ojd7000400800?n]00H00?ne003o[@00ojd00?n]003o]@1kOG/2003o
[@07003o]@1kOG/0Ngek003o[@001000Ngek0004000207]mN`04003o[@00
1000Ngek003o]@8000@000L00?n]003o]@00ojd000@0003o[@00okD00?n]
00T0Ngek00<00?n]003o]@00ojd00P00ojd01@00okD00?n]003o[@1kOG/0
0?ne00<00?n]00T00?ne003o[@00ojd00?n]003o]@00ojd000@0003o[@00
okD00`00ojd01@00okD00?n]003o[@00ojd0Ngek02@0oooo00310?ooo`D0
00@00P3oool00`001000oooo0?ooo`1f0?ooo`0T07]mN`00okD00?n]003o
]@00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD00?n]003o]@1kOG/00?ne003o[@00okD0
0?n]003o]@00ojd00?ne003o[@00okD000@0003o]@00ojd00?ne20001000
1@00ojd00?ne003o[@00okD00?n]0080Ngek00H00?ne07]mN`1kOG/0Ngek
00040000ojd200040003003o]@00ojd0Ngek0080Ngek02/000@007]mN`1k
OG/0Ngek003o[@00okD00?n]003o]@00ojd00?ne003o[@0010000?n]003o
]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD00?n]003o]@0010000?ne003o[@00okD0
0?n]003o]@00ojd00?ne003o[@00okD0Ngek02@0oooo00330?ooo`030004
003oool0oooo0080oooo00<000@00?ooo`3oool0MP3oool01@1kOG/00?n]
003o[@00ojd00?ne00<00?n]00D00?ne003o[@00ojd000@0003o]@03003o
[@09003o]@00ojd00?n]003o[@00okD00?n]07]mN`00ojd00?ne00<00?n]
00D00?ne003o[@00ojd00?n]00040003003o[@05003o]@00ojd00?n]003o
[@00okD00P00ojd00`1kOG/000@000040005000400<0Ngek00<000@007]m
N`1kOG/0101kOG/3003o[@0500040000ojd00?n]003o[@00okD00`00ojd0
1@00okD00?n]003o[@0010000?ne00<00?n]00H00?ne003o[@00ojd00?n]
003o]@1kOG/2003o[@05003o]@00ojd00?n]003o[@00okD00`00ojd01@00
10000?n]003o[@00ojd00?ne00<00?n]00<00?ne003o[@1kOG/0903oool0
0<<0oooo00<000@00?ooo`3oool00P3oool00`001000oooo0?ooo`1f0?oo
o`0a07]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00
ojd000@0003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o
]@1kOG/00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD000@0
003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/0
0?n]003o]@00ojd00?ne003o[@0407]mN`040004001kOG/0Ngek07]mN`@0
00@002h00?ne003o[@00okD000@0003o]@00ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@0010000?n]003o]@00ojd00?ne003o[@00okD0
0?n]003o]@00ojd0Ngek003o[@00okD00?n]003o]@00ojd00?ne003o[@00
okD00?n]003o]@0010000?ne003o[@00okD00?n]003o]@00ojd00?ne003o
[@00okD0Ngek903oool00<<0oooo00<000@00?ooo`3oool00P3oool00`00
1000oooo0?ooo`1f0?ooo`0307]mN`00ojd00?ne00<00?n]00H00?ne003o
[@00ojd00?n]003o]@001002003o[@05003o]@00ojd00?n]003o[@00okD0
0`00ojd01@1kOG/00?n]003o[@00ojd00?ne00<00?n]00D00?ne003o[@00
10000?n]003o]@03003o[@04003o]@00ojd00?n]003o[@L0Ngek10001003
07]mN`03003o[@1kOG/0Ngek00800?n]1`001002003o[@06003o]@00ojd0
0?n]003o[@00okD000@00P00ojd01@00okD00?n]003o[@00ojd00?ne0080
0?n]00<0Ngek003o]@00ojd00P00ojd02@00okD00?n]003o[@00ojd00?ne
003o[@0010000?n]003o]@03003o[@05003o]@00ojd00?n]003o[@1kOG/0
903oool00<<0oooo00<000@00?ooo`3oool00P3oool00`001000oooo0?oo
o`1f0?ooo`0Q07]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@00ojd000@0003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD0
0?n]003o]@1kOG/00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00
okD000@000T0Ngek00D00?n]07]mN`00ojd00?ne003o[@0200040004003o
]@1kOG/0Ngek003o[@80Ngek00@00?ne07]mN`0010000?n]0P1kOG/01`00
okD00?n]003o]@0010000?ne003o[@00okD02@0010007P00okD00?n]003o
]@00ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD000@0003o]@00ojd00?ne003o[@00okD0
0?n]003o]@00ojd00?ne07]mNb@0oooo00320?ooo`8000@0103oool00`00
1000oooo0?ooo`1f0?ooo`0507]mN`00ojd00?n]003o[@00okD00`00ojd0
1@00okD00?n]003o[@0010000?ne00<00?n]00T00?ne003o[@00ojd00?n]
003o]@00ojd0Ngek003o[@00okD00P00ojd607]mN`<00?n]00D00?ne003o
[@00ojd00?n]003o]@02003o[@0B07]mN`00okD000@000040000ojd00?ne
07]mN`00ojd000@007]mN`001000Ngek0004001kOG/00?n]00040000ojd0
0?ne0`1kOG/01@0010000?n]003o[@00ojd00?ne00<00?n]00D00?ne003o
[@0010000?n]003o]@080004000407]mN`00ojd00?n]003o]@<00?n]00D0
0?ne003o[@00ojd00?n]00040003003o[@07003o]@00ojd00?n]003o[@00
okD00?n]07]mN`0T0?ooo`00b03oool00`001000oooo0?ooo`1g0?ooo`0C
07]mN`00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@001000
0?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@0707]mN`0@003o]@00
ojd00?ne003o[@00okD00?n]00040000ojd00?ne003o[@00okD00?n]003o
]@00ojd00?ne003o[@8000@002P00?ne003o[@00okD0Ngek003o]@001000
0?ne07]mN`001000Ngek00040000ojd0Ngek003o[@0010000?n]003o]@00
ojd0Ngek00040000okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o
]@0010000?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
2@0010003@00ojd00?ne00040000okD00?n]003o]@00ojd00?ne003o[@00
okD00?n]003o]@1kOG/0903oool00<P0oooo00<000@00?ooo`3oool0M`3o
ool00`1kOG/00?ne003o[@02003o[@06003o]@00ojd00?n]003o[@00okD0
00@00P00ojd607]mN`800?n]00D0Ngek003o[@00ojd00?n]003o]@03003o
[@05003o]@00ojd00?n]00040000okD00`00ojd00`00okD00?n]003o[@02
00040003003o[@1kOG/00?n]0080Ngek01400?n]00040000okD0Ngek003o
[@001000Ngek003o[@0010000?n]07]mN`00ojd000@0003o[@00okD0Ngek
0004000407]mN`03003o[@00okD00?n]00800?n]00D000@0003o[@00ojd0
0?n]003o]@03003o[@05003o]@00ojd00?n]07]mN`00okD00`00ojd01000
okD00?n]003o[@00ojd9000400<00?n]00<0Ngek0?ooo`3oool08P3oool0
0<P0oooo00<000@00?ooo`3oool0M`3oool01P1kOG/00?n]003o]@00ojd0
0?ne003o[@L0Ngek01T00?n]003o]@00ojd00?ne003o[@00okD00?n]003o
]@1kOG/00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
00040000ojd00?ne003o[@00okD00?n]008000@001@00?ne003o[@00okD0
0?n]07]mN`00ojd00?ne00040000okD00?n]07]mN`00ojd000@007]mN`00
okD000@0003o]@00ojd0Ngek003o[@8000@000H00?ne00040000okD00?n]
003o]@00ojd207]mN`0P003o]@00ojd00?ne00040000okD00?n]003o]@00
ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]003o
]@00ojd00?ne003o[@00okD00?n]00040000ojd00?ne003o[@00okD00?n]
003o]@00ojd4000402@0oooo00380?ooo`030004003oool0oooo07L0oooo
1P1kOG/00`00ojd00?ne003o[@02003o[@0500040000ojd00?n]003o[@00
okD00`00ojd01@00okD00?n]07]mN`00ojd00?ne00<00?n]00H00?ne003o
[@00ojd00?n]003o]@00ojd500040003003o[@00okD00?n]00800?n]00T0
Ngek003o[@1kOG/00?n]00040000ojd0Ngek003o[@0010000P00ojd0201k
OG/00?ne00040000ojd0Ngek003o]@1kOG/00?n]0P001003003o[@03003o
]@00ojd00?n]0080Ngek00@000@0003o[@00ojd00?ne0`00ojd01@00okD0
0?n]003o[@00ojd0Ngek00<00?n]00D00?ne003o[@00ojd00?n]003o]@02
003o[@0300040000okD00?n]00800?n]00L00?ne003o[@00ojd00?n]003o
]@00ojd0Ngek02@0oooo00380?ooo`030004003oool0oooo07L0oooo0200
Ngek003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00
10000?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]07]m
N`00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@8000@002H0
0?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]003o]@00
ojd000@0003o[@00okD0Ngek003o]@0010000?ne003o[@1kOG/00?n]0004
0000ojd00?ne07]mN`00okD00?n]003o]@0010000?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@80Ngek02000?ne003o[@00okD00?n]003o]@00
ojd00?ne003o[@00okD0Ngek003o]@00ojd00?ne003o[@00okD00?n]003o
]@00ojd00?ne003o[@0010000?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne07]mNb@0oooo00380?ooo`030004003oool0oooo07L0
oooo00<0Ngek003o]@00ojd00P00ojd02@00okD00?n]003o[@00ojd00?ne
003o[@0010000?n]003o]@03003o[@06003o]@00ojd00?n]003o[@00okD0
Ngek0P00ojd01@00okD00?n]003o[@00ojd00?ne008000@000<00?n]003o
]@0010000P00ojd00`00okD00?n]003o[@0207]mN`<00?n]00X00?ne0004
001kOG/0Ngek003o]@00ojd000@0003o[@00okD0Ngek0P00ojd01P001000
Ngek003o[@1kOG/00?ne003o[@<000@00`00ojd01@00okD00?n]00040000
ojd00?ne0080Ngek00<00?n]003o]@00ojd00P00ojd01@00okD00?n]07]m
N`00ojd00?ne00<00?n]00D00?ne003o[@00ojd00?n]00040003003o[@05
003o]@00ojd00?n]003o[@00okD00P00ojd00`1kOG/0oooo0?ooo`0S0?oo
o`00b03oool00`001000oooo0?ooo`1g0?ooo`0L07]mN`00ojd00?ne003o
[@00okD00?n]003o]@00ojd00?ne003o[@00okD000@0003o]@00ojd00?ne
003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]003o]@00ojd0
0?ne003o[@8000@000h00?ne003o[@00okD00?n]00040000ojd00?ne003o
[@00okD0Ngek003o]@00ojd00?ne003o[@8000@000<00?ne003o[@1kOG/0
0P1kOG/00`001000Ngek07]mN`0307]mN`0900040000okD00?n]003o]@1k
OG/00?ne00040000okD00?n]008000@000P00?ne003o[@00okD000@0003o
]@00ojd00?ne003o[@@0Ngek01T00?ne003o[@00okD0Ngek003o]@00ojd0
0?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]003o]@00
ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek02D0oooo00380?ooo`03
0004003oool0oooo07L0oooo00@0Ngek003o[@00ojd00?ne0`00ojd01@00
okD00?n]003o[@00ojd000@000<00?n]00D00?ne003o[@00ojd00?n]003o
]@03003o[@0307]mN`00ojd00?n]008000@00`00ojd01@00okD00?n]003o
[@0010000?ne00800?n]00<0Ngek003o]@00ojd00P00ojd01@0010000?n]
003o[@00ojd0Ngek00<00?n]00D000@0003o[@00ojd0Ngek003o]@02003o
[@0600040000okD00?n]003o[@1kOG/000@00`00ojd01@00okD000@0003o
[@0010000?ne00<00?n]00D00?ne003o[@00ojd00?n]003o]@0307]mN`05
003o]@00ojd00?n]003o[@00okD00`00ojd01@00okD00?n]00040000ojd0
0?ne00<00?n]00H00?ne003o[@00ojd00?n]003o]@1kOG/U0?ooo`00b03o
ool00`001000oooo0?ooo`1h0?ooo`0G07]mN`00okD00?n]003o]@00ojd0
0?ne003o[@00okD00?n]003o]@00ojd000@0003o[@00okD00?n]003o]@00
ojd00?ne003o[@00okD00?n]003o]@1kOG/00P001000>000okD00?n]003o
]@00ojd00?ne003o[@00okD00?n]003o]@0010000?ne07]mN`00okD00?n]
003o]@00ojd00?ne00040000okD00?n]003o]@1kOG/00?ne003o[@00okD0
00@0003o]@00ojd0Ngek003o[@00okD00?n]00040000ojd00?ne003o[@1k
OG/000@0003o]@00ojd00?ne003o[@0010000?n]00040000ojd00?ne003o
[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]0P1kOG/05@00okD0
0?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@0010000?ne003o[@00
okD00?n]003o]@00ojd00?ne003o[@00okD00?n]07]mN`0U0?ooo`00b03o
ool00`001000oooo0?ooo`1h0?ooo`0507]mN`00ojd00?n]003o[@00okD0
0`00ojd01@00okD00?n]003o[@0010000?ne00<00?n]00D00?ne003o[@00
ojd00?n]003o]@0200040003003o[@00okD00?n]00800?n]00H00?ne003o
[@00ojd00?n]003o]@00ojd207]mN`06003o]@00ojd00?n]003o[@00okD0
00@00P00ojd02P00okD00?n]07]mN`00ojd00?ne003o[@0010000?n]003o
]@1kOG/2003o[@09003o]@00ojd000@0003o[@00okD00?n]00040000ojd0
0?ne00<00?n]0P001002003o[@05003o]@00ojd00?n]003o[@00okD00`00
ojd00`1kOG/00?n]003o[@0207]mN`<00?n]00D00?ne003o[@00ojd00?n]
00040003003o[@05003o]@00ojd00?n]003o[@00okD00P00ojd00`1kOG/0
oooo0?ooo`0S0?ooo`00b03oool00`001000oooo0?ooo`1h0?ooo`0A07]m
N`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0
003o[@00okD00?n]003o]@00ojd010001000<@00okD00?n]07]mN`00ojd0
0?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]003o]@00
10000?ne003o[@00okD00?n]00040000ojd00?ne003o[@00okD0Ngek003o
]@00ojd00?ne00040000okD00?n]003o]@1kOG/00?ne003o[@00okD000@0
003o]@00ojd00?ne00040000okD00?n]003o]@00ojd000@0003o[@00okD0
0P0010003@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00
okD00?n]003o]@00ojd0101kOG/03`00okD00?n]003o]@0010000?ne003o
[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]07]mN`0U0?ooo`00
b03oool00`001000oooo0?ooo`1i0?ooo`0307]mN`00okD00?n]00800?n]
00T00?ne003o[@00ojd00?n]003o]@00ojd000@0003o[@00okD00P001000
0`00ojd00?ne003o[@02003o[@05003o]@1kOG/00?n]003o[@00okD00`00
ojd01@00okD00?n]07]mN`00ojd00?ne00800?n]00H000@0003o]@00ojd0
00@0003o[@00okD2003o[@0307]mN`00okD00?n]00800?n]00D000@0003o
[@00ojd00?n]07]mN`03003o[@0500040000ojd00?n]003o[@0010000P1k
OG/00`00ojd000@0003o[@02003o[@05003o]@00ojd000@0003o[@00okD0
0`00ojd01@00okD0Ngek003o[@00ojd00?ne00<00?n]00<00?ne003o[@00
ojd00`1kOG/2003o[@05003o]@00ojd00?n]003o[@00okD00`00ojd00`1k
OG/0oooo0?ooo`0T0?ooo`00b03oool00`001000oooo0?ooo`1i0?ooo`0;
07]mN`00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD0
0`0010005`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@1k
OG/00?ne003o[@00okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]003o
]@00ojd00?ne008000@003@00?n]003o]@00ojd00?ne003o[@1kOG/00?n]
003o]@00ojd000@0003o[@00okD00?n]003o]@1kOG/00?ne003o[@00okD0
00@0003o]@00ojd00?ne00040000okD00?n]07]mN`00ojd00?ne003o[@00
okD00?n]003o]@00ojd000@0003o[@00okD00?n]003o]@1kOG/00?ne003o
[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0
0P1kOG/02@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`0V
0?ooo`00b03oool00`001000oooo0?ooo`1i0?ooo`0407]mN`00ojd00?n]
003o]@<00?n]00<00?ne003o[@00ojd00`001002003o[@05003o]@00ojd0
0?n]003o[@00okD00`00ojd01@00okD0Ngek003o[@00ojd00?ne0080Ngek
00<00?n]003o]@00ojd00P00ojd00`00okD00?n]00040002000400<00?n]
00H0Ngek003o[@00ojd00?n]003o]@001002003o[@05003o]@00ojd0Ngek
003o[@00okD00P00ojd01`0010000?ne003o[@0010000?n]0004001kOG/0
0P00ojd03@00okD00?n]003o[@00ojd00?ne003o[@0010000?n]003o]@00
ojd0Ngek003o[@00okD00`00ojd02P00okD00?n]003o[@00ojd00?ne003o
[@0010000?n]003o]@00ojd207]mN`07003o]@00ojd00?n]003o[@00okD0
oooo07]mN`0V0?ooo`00b03oool00`001000oooo0?ooo`1j0?ooo`0707]m
N`00okD00?n]003o]@00ojd00?ne003o[@020004000N003o]@00ojd000@0
003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0
0?ne07]mN`00okD0Ngek003o]@00ojd00?ne003o[@00okD00?n]003o]@00
ojd000@0003o[@00okD00?n]0P0010004`00okD0Ngek003o]@00ojd00?ne
003o[@0010000?n]003o]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd0
00@0003o[@00okD00P0010002`00ojd00?ne07]mN`00okD00?n]003o]@00
ojd00?ne003o[@00okD00?n]008000@001<0Ngek003o[@00okD00?n]003o
]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]
003o]@00ojd00?ne0080Ngek00@00?n]003o]@00ojd0Ngek9`3oool00<40
oooo100010030?ooo`030004003oool0oooo07X0oooo00D0Ngek003o[@00
ojd00?n]003o]@0200040003003o[@00okD00?n]00800?n]00D000@0003o
[@00ojd00?n]003o]@03003o[@04003o]@00ojd00?n]003o[@80Ngek0P00
ojd01@00okD00?n]003o[@00ojd00?ne00800?n]00<000@0003o]@00ojd0
0P00ojd01@00okD0Ngek00040000ojd00?ne00800?n]00<000@0003o]@00
ojd00P00ojd01@1kOG/00?n]003o[@00ojd00?ne00@000@00`00ojd01@1k
OG/00?n]003o[@00ojd00?ne00<00?n]00D00?ne003o[@00ojd000@0003o
]@03003o[@05003o]@00ojd00?n]003o[@00okD00P00ojd00`0010000?ne
003o[@02003o[@04003o]@00ojd00?n]003o[@@0Ngek9`3oool00<40oooo
00<000@00?ooo`3oool0103oool00`001000oooo0?ooo`1j0?ooo`0307]m
N`00100000@0008000@001800?ne003o[@00okD00?n]003o]@00ojd00?ne
00040000okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd3
07]mN`0A003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD000@0003o
]@00ojd00?ne003o[@00okD00?n]07]mN`00ojd00`0010002@00ojd000@0
003o[@00okD00?n]003o]@1kOG/00?ne003o[@020004000Z003o]@001000
0?ne00040000okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]003o]@00
ojd00?ne003o[@00okD0Ngek003o]@0010000?ne003o[@00okD00?n]003o
]@00ojd00?ne003o[@00okD00?n]00040000ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD0Ngek:03oool00<80oooo00<000@00?oo
o`3oool00`3oool00`001000oooo0?ooo`1k0?ooo`0307]mN`00okD00?n]
00800?n]00D00?ne003o[@00ojd00?n]003o]@02003o[@0300040000okD0
0?n]00800?n]00D00?ne003o[@00ojd00?n]07]mN`02003o[@0307]mN`00
okD00?n]00800?n]00D00?ne003o[@00ojd00?n]00040003003o[@05003o
]@00ojd0Ngek003o[@00okD00`00ojd70004000307]mN`0010000?n]0080
0?n]00D00?ne0004000010000?n]003o]@03003o[@0507]mN`00ojd00?n]
003o[@00okD00P00ojd0101kOG/00?ne003o[@00ojd2000400<00?n]00D0
0?ne003o[@00ojd00?n]00040003003o[@05003o]@00ojd00?n]003o[@00
okD00`00ojd00`1kOG/0oooo0?ooo`0V0?ooo`00``3oool00`001000oooo
0?ooo`020?ooo`030004003oool0oooo07/0oooo03X0Ngek003o[@00okD0
0?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0003o[@00
okD00?n]003o]@00ojd00?ne003o[@00okD0Ngek003o]@00ojd00?ne07]m
N`00okD00?n]003o]@00ojd00?ne003o[@0010000?n]003o]@00ojd00?ne
003o[@00okD0Ngek003o]@00ojd00?ne003o[@00okD00?n]00040000ojd0
0?ne003o[@00okD00?n]07]mN`00ojd00?ne003o[@00okD00?n]0P001000
9@00okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]003o]@00ojd00?ne
07]mN`00okD00?n]003o]@00ojd00?ne003o[@0010000?n]003o]@00ojd0
0?ne003o[@0010000?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00
ojd00?ne003o[@1kOG/0:@3oool00<40oooo00@000@00?ooo`3oool000@0
0`3oool00`001000oooo0?ooo`1l0?ooo`0307]mN`00ojd00?ne00<00?n]
00T00?ne003o[@00ojd00?n]003o]@00ojd000@0003o[@00okD00`00ojd2
07]mN`800?n]00<00?ne003o[@00ojd00P1kOG/3003o[@0500040000ojd0
0?n]003o[@00okD00`00ojd02@1kOG/00?n]003o[@00ojd00?ne003o[@00
10000?n]003o]@03003o[@05003o]@1kOG/00?n]003o[@00okD00`00ojd0
1@0010000?n]003o[@00ojd00?ne00<00?n]00D0Ngek003o[@00ojd0Ngek
003o]@03003o[@05003o]@00ojd00?n]003o[@0010000`00ojd01@001000
0?n]003o[@00ojd00?ne00<00?n]00H00?ne003o[@00ojd00?n]003o]@1k
OG/Y0?ooo`00`P3oool2000400@0oooo00<000@00?ooo`3oool0O03oool0
401kOG/00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@0010000?ne003o[@00okD207]mN`1>003o[@00okD00?n]003o]@00
ojd00?ne003o[@00okD00?n]07]mN`00ojd000@0003o[@00okD00?n]003o
]@00ojd00?ne003o[@00okD0Ngek003o]@00ojd00?ne003o[@00okD000@0
003o]@00ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne003o[@00okD0
0?n]003o]@0010000?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00
okD0Ngek003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o
[@0010000?n]003o]@0010000?ne003o[@00okD00?n]003o]@00ojd00?ne
003o[@00okD00?n]003o]@00ojd0Ngek:@3oool00<P0oooo00<000@00?oo
o`3oool0O@3oool0101kOG/00?n]003o[@00okD3003o[@09003o]@00ojd0
0?n]003o[@00okD000@0003o[@1kOG/00?ne00<00?n]00D00?ne003o[@00
ojd00?n]003o]@03003o[@0500040000ojd00?n]003o[@00okD00`00ojd0
1@00okD0Ngek003o[@00ojd00?ne00<00?n]00D000@0003o[@00ojd00?n]
003o]@02003o[@0307]mN`00okD00?n]00800?n]00D00?ne003o[@001000
00@0003o]@03003o[@05003o]@00ojd00?n]07]mN`00okD00`00ojd01@00
okD00?n]003o[@00ojd00?ne00<00?n]0P001002003o[@05003o]@00ojd0
0?n]003o[@00okD00`00ojd00`00okD00?n]07]mN`0Z0?ooo`00b03oool0
0`001000oooo0?ooo`1n0?ooo`0K07]mN`00okD00?n]003o]@00ojd00?ne
003o[@00okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd0
0?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@0010000?n]0080Ngek
01/00?ne003o[@00okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]003o
]@00ojd00?ne00040000okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]
003o]@00ojd00?ne003o[@00okD00P0010001@00ojd00?ne003o[@00okD0
0?n]0080Ngek00l00?ne07]mN`00okD00?n]003o]@00ojd00?ne003o[@00
okD00?n]003o]@00ojd00?ne00040000okD00P0010002`00ojd00?ne003o
[@00okD00?n]003o]@00ojd00?ne003o[@00okD0Ngek02X0oooo00380?oo
o`030004003oool0oooo07h0oooo00D0Ngek003o[@00ojd00?n]003o]@03
003o[@06003o]@00ojd00?n]07]mN`00okD000@00P00ojd01@00okD00?n]
003o[@00ojd00?ne00<00?n]00D000@0003o[@00ojd00?n]003o]@0207]m
N`06003o[@00okD00?n]07]mN`00ojd00?ne0`00ojd01@00okD00?n]0004
0000ojd00?ne00<00?n]00D00?ne07]mN`00ojd00?n]003o]@03003o[@05
00040000ojd000@0003o[@00okD00P1kOG/01P00ojd00?ne003o[@00ojd0
Ngek003o]@<00?n]00d00?ne003o[@00ojd00?n]003o]@00ojd000@0003o
[@00okD00?n]00040000ojd00?ne00<00?n]00@00?ne003o[@00ojd0Ngek
:`3oool00<P0oooo00<000@00?ooo`3oool0O`3oool0201kOG/00?n]003o
]@00ojd00?ne003o[@00okD00?n]0P1kOG/05000okD00?n]003o]@001000
0?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD000@0003o]@00
ojd00?ne003o[@00okD00?n]0P1kOG/06P00okD0Ngek003o]@00ojd00?ne
003o[@00okD00?n]003o]@0010000?ne003o[@00okD00?n]003o]@00ojd0
Ngek003o[@00okD00?n]003o]@00ojd00?ne00040000okD000@00P1kOG/0
7`00okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]003o]@00ojd00?ne
003o[@00okD00?n]003o]@00ojd000@0003o[@00okD00?n]003o]@00ojd0
00@0003o[@00okD00?n]003o]@00ojd00?ne0?ooo`1kOG/0:`3oool00<P0
oooo00<000@00?ooo`3oool0O`3oool00`00ojd0Ngek003o[@02003o[@05
003o]@00ojd0Ngek003o[@00okD00`00ojd01@00okD000@0003o[@00ojd0
0?ne00<00?n]00D00?ne00040000ojd00?n]003o]@03003o[@03003o]@00
ojd00?n]0080Ngek0`00ojd01@00okD00?n]003o[@00ojd000@000<00?n]
00D00?ne003o[@00ojd00?n]07]mN`03003o[@05003o]@00ojd000@007]m
N`0010000`00ojd01P00okD00?n]003o[@00ojd00?ne003o[@80Ngek00D0
0?ne003o[@00ojd00?n]003o]@02003o[@0300040000okD00?n]00800?n]
00D00?ne003o[@0010000?n]003o]@03003o[@0307]mN`3oool0oooo02X0
oooo00380?ooo`030004003oool0oooo0800oooo0240Ngek003o]@00ojd0
0?ne003o[@1kOG/00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00
10000?ne003o[@00okD00?n]003o]@00ojd000@0003o[@00okD00?n]003o
]@00ojd00?ne003o[@00okD00?n]07]mN`00ojd0101kOG/0;P00okD00?n]
003o]@0010000?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00okD0
0?n]003o]@00ojd0Ngek00040000okD000@0003o]@00ojd00?ne003o[@00
okD00?n]003o]@00ojd00?ne003o[@00okD0Ngek003o]@00ojd00?ne003o
[@00okD000@0003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd20004
0003003o]@00ojd0Ngek02d0oooo00380?ooo`030004003oool0oooo0840
oooo00H0Ngek003o]@1kOG/0Ngek003o[@00okD3003o[@06003o]@00ojd0
0?n]003o[@00okD000@00P00ojd01@00okD00?n]00040000ojd00?ne00<0
0?n]00H00?ne003o[@00ojd00?n]003o]@1kOG/2003o[@03003o]@00ojd0
0?n]00<0Ngek00<000@007]mN`1kOG/02P1kOG/01P00ojd000@0003o[@00
ojd000@0003o]@<00?n]00X00?ne003o[@00ojd00?n]003o]@00ojd0Ngek
003o[@00okD00?n]0P0010001@00okD00?n]003o[@00ojd00?ne00<00?n]
00<00?ne003o[@00ojd00P0010000`1kOG/0oooo0?ooo`0[0?ooo`00b03o
ool00`001000oooo0?ooo`210?ooo`15003o]@1kOG/00?ne003o[@00okD0
0?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne00040000
okD00?n]00040000ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o
[@00okD0Ngek003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0
003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD0Ngek003o]@00ojd0
0?ne003o[@00okD000@0003o]@00ojd000@0003o[@00okD00?n]003o]@00
ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek008000@000l00?n]003o
]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@1kOG/0;P3oool00<P0oooo00<000@00?ooo`3oool0PP3oool00`00
ojd0Ngek003o]@03003o[@05003o]@00ojd00?n]003o[@00okD00`00ojd0
1@00okD000@000040000ojd00?ne00<00?n]00T00?ne003o[@00ojd00?n]
003o]@00ojd0Ngek003o[@00okD00`00ojd01@00okD00?n]003o[@001000
0?ne00<00?n]00D00?ne003o[@00ojd00?n]07]mN`03003o[@09003o]@00
ojd000@0003o[@00okD00?n]00040000ojd00?ne00<00?n]00H00?ne003o
[@00ojd00?n]003o]@1kOG/2003o[@05003o]@00ojd00?n]003o[@00okD0
0`00ojd01P00okD00?n]003o[@00ojd00?ne07]mNbl0oooo00380?ooo`03
0004003oool0oooo08<0oooo00h0Ngek003o[@00okD00?n]003o]@00ojd0
0?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@<000@004400?n]003o
]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD00?n]00040000ojd00?ne003o[@00okD0
0?n]003o]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd00?ne00040000
okD00?n]003o]@0010000?ne003o[@00okD00?n]003o]@00ojd00?ne003o
[@00okD000@0003o]@1kOG/00?ne003o[@00okD00?n]003o]@00ojd00?ne
003o[@00okD00?n]003o]@00ojd00?ne07]mN`0`0?ooo`00b03oool00`00
1000oooo0?ooo`240?ooo`0307]mN`00ojd00?ne00<00?n]00D00?ne003o
[@00ojd00?n]003o]@02003o[@0300040000okD00?n]008000@000D00?ne
003o[@00ojd00?n]003o]@02003o[@0307]mN`00okD00?n]00800?n]00H0
0?ne003o[@00ojd00?n]003o]@001002003o[@09003o]@00ojd00?n]003o
[@00okD00?n]07]mN`00ojd00?ne00<00?n]00H000@0003o[@00ojd00?n]
003o]@001002003o[@04003o]@00ojd00?n]003o[@8000@00P00ojd01@00
okD0Ngek003o[@00ojd00?ne00<00?n]00H00?ne003o[@00ojd00?n]003o
]@1kOG/a0?ooo`00b03oool00`001000oooo0?ooo`250?ooo`1>07]mN`00
ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD000@0003o
]@00ojd00?ne003o[@00okD000@0003o]@00ojd00?ne003o[@00okD00?n]
07]mN`00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@001000
0?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek003o[@00
okD00?n]003o]@0010000?ne003o[@00okD00?n]00040000ojd00?ne003o
[@00okD00?n]00040000ojd00?ne003o[@00okD00?n]003o]@1kOG/00?ne
003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD0Ngek<P3oool00<P0
oooo00<000@00?ooo`3oool0QP3oool00`1kOG/00?n]003o]@03003o[@05
003o]@00ojd00?n]00040000okD00`00ojd00`00okD00?n]003o[@020004
00<00?n]00D00?ne07]mN`00ojd00?n]003o]@03003o[@05003o]@00ojd0
0?n]00040000okD00`00ojd01P00okD00?n]003o[@00ojd00?ne07]mN`80
0?n]00D00?ne003o[@0010000?n]003o]@03003o[@0500040000ojd00?n]
003o[@0010000`00ojd01P00okD00?n]003o[@00ojd00?ne07]mN`800?n]
00H00?ne003o[@00ojd00?n]003o]@1kOG/c0?ooo`00b03oool00`001000
oooo0?ooo`260?ooo`0C003o[@1kOG/0Ngek003o]@00ojd00?ne003o[@00
okD000@0003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o
[@020004000Q003o]@1kOG/00?ne003o[@00okD00?n]003o]@00ojd00?ne
003o[@00okD00?n]00040000ojd00?ne003o[@00okD00?n]003o]@00ojd0
0?ne003o[@1kOG/00?n]003o]@00ojd00?ne00040000okD00?n]003o]@00
ojd00?ne00@000@001400?n]003o]@00ojd00?ne003o[@00okD00?n]003o
]@00ojd0Ngek003o[@00okD00?n]003o]@00ojd00?ne07]mN`0d0?ooo`00
b03oool00`001000oooo0?ooo`280?ooo`03003o[@1kOG/00?ne00<00?n]
00D000@0003o[@00ojd00?n]003o]@03003o[@09003o]@00ojd00?n]003o
[@00okD000@007]mN`00ojd00?ne00<00?n]00H00?ne003o[@00ojd00?n]
003o]@001002003o[@05003o]@00ojd00?n]003o[@00okD00P00ojd00`1k
OG/00?ne003o[@02003o[@0500040000ojd00?n]003o[@00okD00`001000
1@00okD00?n]003o[@00ojd00?ne00<00?n]00D00?ne003o[@00ojd00?n]
07]mN`03003o[@03003o]@1kOG/0oooo03@0oooo00320?ooo`8000@0103o
ool00`001000oooo0?ooo`290?ooo`0D003o]@1kOG/00?ne003o[@001000
0?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00
okD00?n]07]mN`00ojd30004000H003o[@00okD00?n]003o]@00ojd00?ne
00040000okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0
Ngek003o[@00okD00?n]003o]@0010000?ne0`0010005000okD00?n]0004
0000ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@00ojd0Ngek003o[@00okD0Ngek=P3oool00<40oooo00@000@00?oo
o`3oool000@00`3oool00`001000oooo0?ooo`2:0?ooo`03003o[@1kOG/0
00@000<00?n]00D00?ne003o[@00ojd00?n]003o]@03003o[@05003o]@00
ojd00?n]07]mN`00okD00`00ojd400040005003o]@00ojd000@0003o[@00
okD00`00ojd01`00okD00?n]003o[@00ojd00?ne07]mN`00ojd01@001000
2@00okD00?n]003o[@00ojd00?ne003o[@0010000?n]003o]@03003o[@05
003o]@00ojd00?n]003o[@00okD00`00ojd207]mNcL0oooo00330?ooo`03
0004003oool0oooo0080oooo00<000@00?ooo`3oool0R`3oool06@00okD0
00@007]mN`00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00
okD00?n]003o]@1kOG/00?ne003o[@00okD00?n]003o]@00ojd00?ne003o
[@00okD03@001000701kOG/000@0003o]@00ojd00?ne00040000okD00?n]
003o]@00ojd00?ne003o[@00okD000@0003o]@00ojd00?ne003o[@00okD0
0?n]003o]@00ojd00?ne003o[@00okD00?n]0?ooo`1kOG/h0?ooo`00a03o
ool01@001000oooo0?ooo`3oool000@008h0oooo0P00ojd01@1kOG/00?n]
003o[@00ojd00?ne00<00?n]00D00?ne003o[@00ojd00?n]07]mN`03003o
[@05003o]@00ojd00?n]003o[@00okD00`00ojd01@0010000?n]003o[@00
ojd00?ne00<00?n]00D00?ne003o[@00ojd00?n]07]mN`03003o[@050004
0000ojd00?n]003o[@00okD00`00ojd01@00okD000@0003o[@00ojd00?ne
00<00?n]00@00?ne003o[@00ojd00?n]0P1kOG/i0?ooo`00`@3oool01000
1000oooo0?ooo`0010030?ooo`030004003oool0oooo08l0oooo0P1kOG/0
=`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne
003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@001000
0?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@1k
OG/00?ne003o[@00okD000@0003o]@00ojd00?ne003o[@00okD00?n]003o
]@00ojd000@0003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00P1k
OG/k0?ooo`00`P3oool2000400@0oooo00<000@00?ooo`3oool0T03oool0
1@00okD0Ngek003o[@00ojd00?ne00<00?n]00D00?ne07]mN`00ojd00?n]
003o]@03003o[@09003o]@00ojd00?n]003o[@00okD00?n]00040000ojd0
0?ne00<00?n]00d00?ne003o[@00ojd00?n]003o]@00ojd0Ngek003o[@00
okD00?n]00040000ojd00?ne00<00?n]00D00?ne003o[@00ojd000@0003o
]@03003o[@04003o]@00ojd0Ngek07]mNcd0oooo00380?ooo`030004003o
ool0oooo0940oooo03D00?ne07]mN`1kOG/00?n]003o]@00ojd00?ne07]m
N`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne
003o[@00okD000@0003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0
0?ne003o[@00okD0Ngek003o]@00ojd00?ne00040000okD00?n]003o]@00
ojd00?ne003o[@00okD00?n]00040000ojd00?ne003o[@00okD00?n]07]m
N`0o0?ooo`00b03oool00`001000oooo0?ooo`2C0?ooo`08003o[@1kOG/0
0?n]003o]@00ojd0Ngek003o[@00okD3003o[@05003o]@00ojd00?n]003o
[@00okD00`00ojd01@0010000?n]003o[@00ojd00?ne00<00?n]00D00?ne
003o[@00ojd00?n]07]mN`03003o[@0500040000ojd00?n]003o[@00okD0
0`00ojd01@00okD000@0003o[@00ojd00?ne0080Ngek@03oool00<P0oooo
00<000@00?ooo`3oool0U@3oool207]mN`0Z003o]@1kOG/00?ne003o[@00
okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne0004
0000okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne
07]mN`00okD00?n]003o]@0010000?ne003o[@00okD00?n]003o]@00ojd0
0?ne003o[@00okD000@00P1kOG]20?ooo`00b03oool00`001000oooo0?oo
o`2G0?ooo`80Ngek0`00ojd01@00okD00?n]003o[@00ojd00?ne00<00?n]
00D00?ne00040000ojd00?n]003o]@03003o[@05003o]@00ojd00?n]003o
[@00okD00P00ojd01P1kOG/00?ne003o[@0010000?n]003o]@<00?n]00<0
0?ne003o[@1kOG/00P1kOG]40?ooo`00b03oool00`001000oooo0?ooo`2I
0?ooo`@0Ngek01h00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00
10000?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o
[@00okD00?n]07]mN`00ojd00?ne00040000okD00?n]003o]@00ojd307]m
NdL0oooo00380?ooo`030004003oool0oooo09d0oooo0`1kOG/2003o[@05
003o]@00ojd00?n]00040000okD00`00ojd01@00okD00?n]003o[@00ojd0
0?ne00<00?n]00D00?ne07]mN`00ojd00?n]0004000407]mNdX0oooo0038
0?ooo`030004003oool0oooo0:00oooo1@1kOG/02`001000Ngek07]mN`00
ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne00H0Ngek00<000@00?oo
o`3oool0C03oool00<P0oooo00<000@00?ooo`3oool0Y`3oool00`00ojd0
Ngek07]mN`0607]mN`80oooo00@000@00?ooo`3oool0oooo0P00101=0?oo
o`00b03oool00`001000oooo0?ooo`2`0?ooo`8000@0103oool00`001000
oooo0?ooo`1<0?ooo`00b03oool00`001000oooo0?ooo`2_0?ooo`040004
003oool0oooo000400<0oooo00<000@00?ooo`3oool0C03oool00<P0oooo
00<000@00?ooo`3oool0/03oool2000400@0oooo00<000@00?ooo`3oool0
C03oool00<P0oooo00<000@00?ooo`3oool0]P3oool00`001000oooo0?oo
o`1<0?ooo`00b03oool00`001000oooo0?ooo`2f0?ooo`030004003oool0
oooo04`0oooo00380?ooo`030004003oool0oooo0;H0oooo00<000@00?oo
o`3oool0C03oool00<P0oooo00<000@00?ooo`3oool0]P3oool00`001000
oooo0?ooo`1<0?ooo`00``3oool300040080oooo00<000@00?ooo`3oool0
[`3oool3000400@0oooo00<000@00?ooo`3oool0C03oool00<@0oooo00D0
00@00?ooo`3oool0oooo0004002c0?ooo`030004003oool0oooo0080oooo
00<000@00?ooo`3oool0C03oool00<40oooo1@0010020?ooo`030004003o
ool0oooo0;00oooo0`0010030?ooo`8000@0C@3oool00<40oooo00@000@0
0?ooo`3oool000@0]@3oool010001000oooo0?ooo`00101B0?ooo`00`P3o
ool00`001000oooo0004002e0?ooo`040004003oool0oooo00040580oooo
00330?ooo`8000@0]P3oool300040580oooo003o0?ooom40oooo003o0?oo
om40oooo00360?ooo`8000@0o`3oool90?ooo`00a`3oool00`001000oooo
0?ooo`3o0?ooo`L0oooo00380?ooo`030004003oool0oooo0;D0oooo0P00
101>0?ooo`00a`3oool00`001000oooo0004002f0?ooo`8000@0CP3oool0
0<H0oooo00@000@00?ooo`3oool000@0]@3oool010001000oooo0?ooo`00
101=0?ooo`00a@3oool3000400030?ooo`00100000@00;<0oooo0P001002
0?ooo`8000@0C03oool00?l0ooood@3oool00?l0ooood@3oool00?l0oooo
d@3oool00?l0ooood@3oool00?l0ooood@3oool00?l0ooood@3oool00001
\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{464, 155},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\tFigure 2.10",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The mapping  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\) = \((3 - 4  \[ImaginaryI])\) z\  + \ 6 + 
            2  \[ImaginaryI]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(w = \(f[z] = \((3 - 4  \[ImaginaryI])\) z\  + \ 6 + 
            2  \[ImaginaryI]\)\)]],
  " .  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[w, x, y, z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, ineq, solset, term];\)\ \), "\n", 
    \(\(f[z_] = \((3 - 4  \[ImaginaryI])\) z + 6 + 
          2  \[ImaginaryI];\)\ \), "\n", 
    \(\(Print["\<    f[\>", z, "\<] = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[\>", x\  + \ \[ImaginaryI]\ y, "\<] = \>", 
        f[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[\>", x\  + \ \[ImaginaryI]\ y, "\<] = \>", 
        ComplexExpand[
          f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Solve for the inverse function, i.e. solve for  z  in terms of  w.  Then \
find ",
  Cell[BoxData[
      \(z + 1 + \[ImaginaryI]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(solset\  = \ Solve[w\  \[Equal] \ f[z], z];\)\ \), "\n", 
    \(\(Z\  = \ 
        Factor[solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(term\  = \ Together[Z + 1 + \[ImaginaryI]];\)\ \), "\n", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<        z = \>", Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[z + 1 + \[ImaginaryI], "\< = \>", 
        Z + 1 + \[ImaginaryI]];\)\ \), "\n", 
    \(\(Print[z + 1 + \[ImaginaryI], "\< = \>", 
        term];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To solve for ",
  Cell[BoxData[
      \(\(\(|\)\(z + 1 + \[ImaginaryI]\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ",  we use the computations."
}], "Text"],

Cell[BoxData[{
    \(\(Print[
        Abs[z + 1 + \[ImaginaryI]]\  < \ 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[
        ineq\  = \ 
          Abs[term[\([1]\)]]\ Abs[term[\([2]\)]]\  < \ 
            1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[Distribute[5\ ineq, \ Less]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Which is the disk  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(D\_5\), Cell["(-1+3 \[ImaginaryI])"]}], 
        "=", \({w : \(\(|\)\(w + 1 - 
                3\ \[ImaginaryI]\)\(|\)\(\(<\)\(\ \)\(5\)\)\)}\)}]]],
  "  in the w-plane.  Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph the transformation. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[Z, W];\)\ \), "\[IndentingNewLine]", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ \((3\  - \ 4  \[ImaginaryI])\) z\  + \ 6\  + \ 
          2  \[ImaginaryI];\)\ \), "\n", 
    \(\(Z[z_]\  = \ Iden[z - 1 - \[ImaginaryI]];\)\ \), "\n", 
    \(\(W[z_]\  = \ f[z - 1 - \[ImaginaryI]];\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Z\ , {0, 1, 0.2}, {0, 
          2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] \
{{\(-6\), 4}, {\(-2\), 8}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-6\), 4, 1], 
            Range[\(-2\), 8, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Cyan, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The open disk |z+1+\[ImaginaryI]| < 1.\>"];\)\ \), "\n", 
    \(\(PolarMap[
        W\ , {0, 1, 0.2}, {0, 
          2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] \
{{\(-6\), 4}, {\(-2\), 8}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-6\), 4, 1], 
            Range[\(-2\), 8, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Cyan, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image is the open disk |w+1-3\[ImaginaryI]| < 5,\>"];\)\ \
\), "\n", 
    \(\(Print["\<under the mapping w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the image of the open disk  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(D\_1\), Cell["(-1-\[ImaginaryI])"]}], 
        "=", \({z : \(\(|\)\(z + 
                1 + \[ImaginaryI]\)\(|\)\(\(<\)\(\ \)\(1\)\)\)}\)}]]],
  "  under the transformation  ",
  Cell[BoxData[
      \(w = \((3 - 4  \[ImaginaryI])\) z\  + \ 6 + 2  \[ImaginaryI]\)]],
  "  is the open disk  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(D\_5\), Cell["(-1+3 \[ImaginaryI])"]}], 
        "=", \({w : \(\(|\)\(w + 1 - 
                3\ \[ImaginaryI]\)\(|\)\(\(<\)\(\ \)\(5\)\)\)}\)}]]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the image of the right half plane  ",
  Cell[BoxData[
      \(Re \((z)\) = x > 1\)]],
  "  under the linear transformation  ",
  Cell[BoxData[
      \(w = \((\(-1\) + \[ImaginaryI])\) z\  - \ 2 + 3  \[ImaginaryI]\)]],
  "  is the half plane  ",
  Cell[BoxData[
      \(v > u + 7\)]],
  ".  \n\nSolution.  The inverse transformation is given by  \n\n\t\t\t",
  Cell[BoxData[
      \(z\  = \ \(\(w + 2 - 3  \[ImaginaryI]\)\/\(\(-1\) + \[ImaginaryI]\)\  \
= \ \(u + 2 + \[ImaginaryI] \((v - 3)\)\)\/\(\(-1\) + \[ImaginaryI]\)\)\)]],
  ",  \n\nwhich we write as  \n\n\t\t\t",
  Cell[BoxData[
      \(x + \[ImaginaryI]\ y\  = \ \(\(-u\) + v - 5\)\/2\  + \ \[ImaginaryI] \
\(\(-u\) - v + 1\)\/2\)]],
  ".  \n\nSubstituting  ",
  Cell[BoxData[
      \(x\  = \ \(\(-u\) + v - 5\)\/2\)]],
  "  into  e  ",
  Cell[BoxData[
      \(Re \((z)\) = x > 1\)]],
  "  gives  ",
  Cell[BoxData[
      \(\(\(-u\) + v - 5\)\/2 > 1\)]],
  ",  which simplifies  ",
  Cell[BoxData[
      \(v > u + 7\)]],
  ".  Figure 2.11 illustrates the mapping."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the function w = f[z].", "Text"],

Cell[BoxData[{
    \(\(Clear[w, x, y, z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, ineq1, ineq2, ineq3];\)\ \), "\n", 
    \(\(TagSet[x, Im[x], 0];\)\ \), "\n", 
    \(\(TagSet[y, Im[y], 0];\)\ \), "\n", 
    \(\(TagSet[x, Re[x], x];\)\ \), "\n", 
    \(\(TagSet[y, Re[y], y];\)\ \), "\n", 
    \(\(f[z_] := \((\(-1\) + \[ImaginaryI])\) z - 2 + 
          3  \[ImaginaryI];\)\ \), "\n", 
    \(\(Print["\<    f[\>", z, "\<] = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[\>", x\  + \ \[ImaginaryI]\ y, "\<] = \>", 
        f[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[\>", x\  + \ \[ImaginaryI]\ y, "\<] = \>", 
        ComplexExpand[
          f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Solve for the inverse function, i.e. solve for  z  in terms of  w.  \
\>", "Text"],

Cell[BoxData[{
    \(\(solset\  = \ 
        Solve[w\  \[Equal] \ \((\(-1\)\  + \ \[ImaginaryI])\) z\  - \ 2\  + \ 
              3  \[ImaginaryI], \ z];\)\ \), "\n", 
    \(\(zz\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Z\  = \ 
        ReplaceAll[zz\ , w \[Rule] u\  + \ \[ImaginaryI]\ v];\)\ \), "\n", 
    \(\(Print["\<w = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<w = \>", f[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(Print["\<w = \>", 
        Expand[f[x + \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<u = \>", 
        ComplexExpand[Re[f[x + \[ImaginaryI]\ y]]]];\)\ \), "\n", 
    \(\(Print["\<v = \>", 
        ComplexExpand[Im[f[x + \[ImaginaryI]\ y]]]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<z = \>", zz];\)\ \), "\n", 
    \(\(Print["\<z = \>", Z];\)\ \), "\n", 
    \(\(Print["\<z = \>", Expand[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<x = \>", ComplexExpand[Re[Z]]];\)\ \), "\n", 
    \(\(Print["\<y = \>", 
        ComplexExpand[Im[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To solve for ",
  Cell[BoxData[
      \(Re[z] > 1\)]],
  " ,  we use the computations."
}], "Text"],

Cell[BoxData[{
    \(\(Print[Re[z]\  > \ 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[x\  > \ 1];\)\ \), "\n", 
    \(\(Print[ineq1\  = \ ComplexExpand[Re[Z]]\  > \ 1];\)\ \), "\n", 
    \(\(Print[ineq2\  = \ MapAll[Together, ineq1]];\)\ \), "\n", 
    \(\(Print[
        ineq3\  = \ 
          Distribute[2\ ineq2, \ Greater]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[
        Distribute[ineq3\  + \ u\  + \ 5, \ 
          Greater]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Or the following commands will also find the solution.", "Text"],

Cell[BoxData[{
    \(\(Print[Re[z]\  > \ 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[x\  > \ 1];\)\ \), "\n", 
    \(\(Print[
        ineq\  = \ 
          ComplexExpand[Re[Z]]\  > \ 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Algebra`InequalitySolve`\>"];\)\), "\[IndentingNewLine]", 
    \(\(solset = InequalitySolve[ineq, v];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Which is the right half plane  ",
  Cell[BoxData[
      \(v > u + 7\)]],
  "  in the w-plane.  Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph the transformation. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ \((\(-1\)\  + \ \[ImaginaryI])\) z\  - \ 2\  + \ 
          3  \[ImaginaryI];\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {1, 5, 0.5}, {\(-6\), 7, 
          0.5}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 6}, {\(-1\), 
              6}}, AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 6, 1], 
            Range[\(-1\), 6, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {DarkGreen, Green}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The right half plane Re[z] > 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(CartesianMap[
        f, \ {1, 5, 0.5}, {\(-6\), 7, 
          0.5}, \[IndentingNewLine]PlotRange \[Rule] {{\(-10\), 2}, {\(-2\), 
              10}}, AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-10\), 2, 2], 
            Range[2, 10, 2]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {DarkGreen, Green}];\)\ \ \), "\n", 
    \(\(Print["\<The image is the half plane v > u + 7,\>"];\)\ \), "\n", 
    \(\(Print["\<under the mapping w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the image of the right half plane  ",
  Cell[BoxData[
      \(Re[z] > 1\)]],
  "  under the linear transformation  ",
  Cell[BoxData[
      \(w = \((\(-1\) + \[ImaginaryI])\) z\  - \ 2 + 3  \[ImaginaryI]\)]],
  "  is the half plane  ",
  Cell[BoxData[
      \(v > u + 7\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007@0000Vb000`400?l0
0000o`00003oo`3ooooA0?ooo`00o`3ooooA0?ooo`00o`3ooooA0?ooo`00
o`3ooooA0?ooo`00o`3ooooA0?ooo`00o`3ooooA0?ooo`00o`3ooooA0?oo
o`00o`3ooooA0?ooo`00N`3oool500000?l0oooo5P3oool4000403L0oooo
001m0?ooo`030000003oool0oooo0?l0oooo5P3oool00`001000oooo0?oo
o`0h0?ooo`00O@3oool010000000oooo0?ooo`3oool200000140ooooG@00
00130?ooo`030004003oool0oooo05l0oooo00<000@00?ooo`3oool00`3o
ool200040380oooo001e0?ooo`@00000103oool01@000000oooo0?ooo`3o
ool000000180oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?oo
o`110?ooo`03003o[@001000oooo05P0oooo100010040?ooo`030004003o
ool0oooo0080oooo00<000@00?ooo`3oool0<@3oool007d0oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<0
00000?ooo`3oool0@@3oool00`00okD00?n]0004001N0?ooo`040004003o
ool0oooo000400<0oooo00<000@00?ooo`3oool0<@3oool007`0oooo0P00
00030?ooo`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00
ok<00`000000oooo0?ooo`110?ooo`04003o[@00okD00?n]000405h0oooo
0P0010040?ooo`030004003oool0oooo0340oooo00210?ooo`030000003o
ool0oooo0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?oo
o`110?ooo`05003o]@00ojd00?ne003o[@001000H`3oool00`001000oooo
0?ooo`0a0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00
ok<00?nc00H00?nc00<000000?ooo`3oool0@@3oool3003o[@03003o]@00
ojd000@00680oooo00<000@00?ooo`3oool0<@3oool00840oooo00<00000
0?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0
oooo0440oooo00L00?ne003o[@00okD00?n]003o]@00ojd0Ngek0640oooo
00<000@00?ooo`3oool0<@3oool00840oooo00<000000?ooo`3oool0403o
ool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00
ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo0440oooo00<0
0?n]003o]@00ojd00P00ojd00`1kOG/00?n]0004001P0?ooo`030004003o
ool0oooo0340oooo00210?ooo`030000003oool0oooo0100oooo00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo
003o/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`09003o]@00ojd0
0?ne003o[@1kOG/00?n]003o]@00ojd000@005l0oooo00<000@00?ooo`3o
ool0<@3oool00840oooo00<000000?ooo`3oool02`3oool5000005d0Ogmo
@`3oool3003o[@0707]mN`00ojd00?n]003o[@00okD00?n]0004001N0?oo
o`030004003oool0oooo0340oooo00210?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`3oool000002000ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`110?oo
o`0;003o]@00ojd0Ngek003o[@00okD00?n]003o]@00ojd00?ne003o[@00
1000G@3oool00`001000oooo0?ooo`0a0?ooo`00P@3oool00`000000oooo
0?ooo`0=0?ooo`040000003oool0oooo000000P00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3o
ool0@@3oool00`00ojd0Ngek003o[@02003o[@07003o]@00ojd00?n]003o
[@00okD00?n]0004001L0?ooo`030004003oool0oooo0340oooo00210?oo
o`030000003oool0oooo00d0oooo00@000000?ooo`3oool000002000ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`000000oooo0?ooo`110?ooo`0;07]mN`00ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD00P00101K0?ooo`030004003oool0oooo
0340oooo00210?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3o
ool000002000ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o
/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`04003o[@1kOG/00?n]
003o]@<00?n]00L00?ne003o[@00ojd000@0003o]@00ojd000@005X0oooo
00<000@00?ooo`3oool0<@3oool00840oooo00<000000?ooo`3oool0303o
ool200000080oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?oo
o`110?ooo`0?003o]@00ojd0Ngek003o[@00okD00?n]003o]@00ojd00?ne
00040000okD00?n]003o]@00ojd000@001@0oooo0`00100G0?ooo`<000@0
4P3oool400040180oooo00<000@00?ooo`3oool04P3oool4000401/0oooo
00210?ooo`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00
ok<00`000000oooo0?ooo`110?ooo`06003o[@00okD00?n]07]mN`00ojd0
0?ne0P00ojd00`0010000?ne003o[@02003o[@03003o]@00ojd000@001<0
oooo00@000@00?ooo`3oool000@05`3oool00`001000oooo0?ooo`0A0?oo
o`030004003oool0oooo01<0oooo00<000@00?ooo`3oool04P3oool00`00
1000oooo0?ooo`0L0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`03
07moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0@@3oool01P00okD0
0?n]003o]@00ojd0Ngek003o[@8000@000T00?ne003o[@00okD00?n]003o
]@00ojd00?ne003o[@0010004P3oool010001000oooo0?ooo`00100D0?oo
o`D000@04`3oool00`001000oooo0?ooo`0B0?ooo`030004003oool0oooo
01<0oooo00<000@00?ooo`3oool06`3oool00840oooo00<000000?ooo`3o
ool0403oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo0080
oooo0P0000000`3oool000000000000j0?ooo`<00?n]00D00?ne003o[@00
10000?n]003o]@03003o[@07003o]@00ojd00?n]003o[@00okD00?n]07]m
N`0;0?ooo`@000@00P3oool3000400l0oooo100010020?ooo`040004003o
ool0oooo000400d0oooo100010040?ooo`030004003oool0oooo0140oooo
00<000@00?ooo`3oool0503oool00`001000oooo0?ooo`0J0?ooo`00K`3o
oon2000000D0oooo00<000000?ooo`000000>`3oool04`00okD00?n]003o
]@00ojd000@0003o[@1kOG/00?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@00ojd0Ngek003o[@0010004@3oool00`001000oooo0?ooo`0E0?oo
o`030004003oool000@001<0oooo00@000@00?ooo`3oool000@04P3oool0
0`001000oooo0?ooo`0B0?ooo`040004003oool0oooo000401/0oooo0021
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<0
0`1oOgl00?nc003o/`06003o/`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0>P3oool02P00ojd00?ne003o[@00ojd000@0003o]@00ojd0
Ngek003o[@00okD3003o[@07003o]@00ojd0Ngek003o[@00okD00?n]0004
000@0?ooo`<000@05P3oool2000401@0oooo0P00100C0?ooo`030004003o
ool0oooo01<0oooo0P00100L0?ooo`00P@3oool00`000000oooo0?ooo`0@
0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07
003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool00P3oool2
000000030?ooo`000000000003X0oooo01D00?ne003o[@00okD000@0003o
]@00ojd00?ne003o[@1kOG/00?n]003o]@00ojd00?ne003o[@1kOG/00?n]
003o]@00ojd00?ne003o[@001000D`3oool00`001000oooo0?ooo`0a0?oo
o`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H0
0?nc00<000000?ooo`3oool0@@3oool2003o[@0300040000okD00?n]0080
0?n]00T00?ne003o[@1kOG/00?n]003o]@00ojd0Ngek003o[@00okD00`00
ojd00`00okD00?n]0004001B0?ooo`030004003oool0oooo01/0oooo1000
100B0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<0
0?nc00H00?nc00<000000?ooo`3oool0@@3oool05`00okD000@0003o]@00
ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek003o[@1kOG/00?n]003o
]@00ojd00?ne003o[@00okD00?n]003o]@00ojd000@00540oooo00<000@0
0?ooo`3oool06P3oool010001000oooo0?ooo`00100C0?ooo`00P@3oool0
0`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<00000
0?ooo`3oool0@@3oool00`0010000?ne003o[@02003o[@09003o]@00ojd0
0?n]003o[@00okD00?n]07]mN`00ojd00?ne00<00?n]00H00?ne003o[@00
ojd00?n]003o]@00ojeY000400D0oooo00@000@00?ooo`3oool000@04`3o
ool00840oooo00<000000?ooo`3oool0403oool00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06
003o/`030000003oool0oooo0440oooo01T000@0003o[@00okD00?n]003o
]@00ojd00?ne003o[@00okD00?n]07]mN`00ojd0Ngek003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD00?n]00040000ojd000@000T0oooo00<0
00@00?ooo`3oool05@3oool00`001000oooo0?ooo`0D0?ooo`030004003o
ool0oooo01@0oooo00<000@00?ooo`3oool0503oool00`001000oooo0?oo
o`020?ooo`8000@000<0oooo0004000010004`3oool00840oooo00<00000
0?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0
oooo0440oooo00@00?n]00040000ojd00?ne0`00ojd02@00okD00?n]07]m
N`00ojd00?ne003o[@1kOG/00?n]003o]@03003o[@07003o]@00ojd000@0
003o[@00okD00?n]0004001>0?ooo`030004003oool0oooo0340oooo0021
0?ooo`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`000000oooo0?ooo`110?ooo`0K003o]@00ojd000@0003o[@00okD00?n]
003o]@00ojd0Ngek003o[@00okD00?n]003o]@00ojd0Ngek003o[@00okD0
0?n]003o]@00ojd000@0003o[@00okD00?n]003o]@00ojd000@004d0oooo
00<000@00?ooo`3oool0<@3oool00840oooo00<000000?ooo`3oool0403o
ool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00
ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo0440oooo00X0
0?n]003o]@00ojd000@0003o[@00okD00?n]07]mN`00ojd00?ne0`00ojd0
2@00okD00?n]07]mN`00ojd00?ne003o[@0010000?n]003o]@03003o[@03
003o]@00ojd000@004`0oooo00<000@00?ooo`3oool0<@3oool00840oooo
00<000000?ooo`3oool0403ooomM07moOd<0oooo00@00?ne003o[@00okD0
0?n]0P0010005`00okD0Ngek003o]@00ojd00?ne003o[@00okD00?n]003o
]@00ojd0Ngek003o[@0010000?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@00ojd000@004/0oooo00<000@00?ooo`3oool0<@3oool00840oooo
00<000000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000
003oool0oooo0440oooo0`00ojd01@00okD00?n]003o[@1kOG/00?ne00<0
0?n]00T00?ne003o[@00ojd00?n]003o]@00ojd000@0003o[@00okD00`00
ojd01`00okD00?n]003o[@00ojd00?ne003o[@1kOG/0BP3oool00`001000
oooo0?ooo`0a0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307mo
O`00ok<00?nc00H00?nc00<000000?ooo`3oool0@@3oool07`00okD00?n]
003o]@00ojd00?ne07]mN`00okD000@0003o]@00ojd00?ne003o[@00okD0
0?n]003o]@00ojd000@0003o[@1kOG/00?n]003o]@00ojd00?ne003o[@00
okD00?n]003o]@00ojd0Ngek003o[@001000B@3oool00`001000oooo0?oo
o`0a0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<0
0?nc00H00?nc00<000000?ooo`3oool0@@3oool01P00ojd00?ne003o[@00
ojd0Ngek003o]@800?n]00<000@0003o]@00ojd00P00ojd02@00okD00?n]
00040000ojd00?ne003o[@1kOG/00?n]003o]@03003o[@07003o]@00ojd0
Ngek003o[@00okD00?n]000400180?ooo`030004003oool0oooo0340oooo
00210?ooo`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00
ok<00`000000oooo0?ooo`110?ooo`0Q003o]@00ojd00?ne07]mN`00okD0
0?n]003o]@00ojd00?ne00040000okD00?n]003o]@00ojd000@0003o[@00
okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]003o]@00ojd0Ngek003o
[@00okD00?n]003o]@00ojd000@004L0oooo00<000@00?ooo`3oool0<@3o
ool00840oooo00<000000?ooo`3oool0403oool00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06
003o/`030000003oool0oooo0440oooo0P00ojd00`1kOG/00?ne003o[@02
003o[@09003o]@00ojd00?n]00040000okD00?n]00040000ojd00?ne00<0
0?n]00T00?ne003o[@1kOG/00?n]003o]@00ojd0Ngek003o[@00okD00`00
ojd00`00okD00?n]000400160?ooo`030004003oool0oooo0340oooo0021
0?ooo`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`000000oooo0?ooo`110?ooo`80Ngek00T00?ne003o[@00okD00?n]003o
]@00ojd00?ne003o[@00okD00P0010005P00ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@1kOG/00?n]07]mN`00ojd00?ne003o[@00okD0
0?n]003o]@00ojd00?ne003o[@0010150?ooo`030004003oool0oooo0340
oooo001k0?ooo`D0000000<0oooo0000003oool04@3oool00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc
003o/`06003o/`030000003oool0oooo0440oooo00<0Ngek003o]@00ojd0
0P00ojd02@00okD00?n]003o[@00ojd00?ne003o[@0010000?n]003o]@03
003o[@09003o]@00ojd00?n]003o[@00okD00?n]07]mN`00ojd00?ne00<0
0?n]00D00?ne003o[@00ojd00?n]003o]@02000404@0oooo00<000@00?oo
o`3oool0<@3oool007d0oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o
/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0@@3oool09@00
okD0Ngek003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0003o
[@0010000?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek
003o[@1kOG/00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@001000
0?ne003o[@001000@`3oool00`001000oooo0?ooo`0a0?ooo`00O@3oool0
10000000oooo0?ooo`3oool200000140ooooG@0000130?ooo`800?n]00<0
Ngek003o]@00ojd00P00ojd02@00okD00?n]00040000ojd00?ne003o[@00
10000?n]003o]@03003o[@09003o]@00ojd0Ngek003o[@00okD00?n]07]m
N`00ojd00?ne00<00?n]00L00?ne003o[@0010000?n]003o]@00ojd000@0
0480oooo00<000@00?ooo`3oool0<@3oool007d0oooo00D000000?ooo`3o
ool0oooo0000000B0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?oo
o`3oool0@@3oool09`00okD00?n]003o]@1kOG/00?ne003o[@00okD00?n]
00040000ojd00?ne003o[@00okD00?n]00040000ojd00?ne003o[@00okD0
0?n]07]mN`00ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne003o[@00
okD00?n]00040000ojd00?ne003o[@00okD00?n]000400110?ooo`030004
003oool0oooo0340oooo001m0?ooo`050000003oool0oooo0?ooo`000000
4P3oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo0440oooo
00X00?n]003o]@00ojd00?n]07]mN`00okD00?n]00040000ojd00?ne0`00
ojd01@00okD00?n]00040000ojd00?ne0080Ngek00<00?n]003o]@00ojd0
0P00ojd02@00okD00?n]07]mN`00ojd00?ne003o[@0010000?n]003o]@03
003o[@03003o]@00ojd000@00400oooo00<000@00?ooo`3oool0<@3oool0
07`0oooo0P0000030?ooo`030000003oool0oooo0100oooo00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o
/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`0Y003o]@00ojd00?ne
003o[@00okD0Ngek00040000ojd00?ne003o[@00okD00?n]003o]@00ojd0
0?ne003o[@001000Ngek003o]@00ojd00?ne003o[@00okD00?n]003o]@00
ojd00?ne003o[@1kOG/00?n]00040000ojd00?ne003o[@00okD00?n]003o
]@00ojd00?ne003o[@001000?`3oool00`001000oooo0?ooo`0a0?ooo`00
P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc
00<000000?ooo`3oool0@@3oool3003o[@05003o]@00ojd000@007]mN`00
okD00`00ojd01P00okD00?n]003o[@00ojd00?ne07]mN`8000@000D00?ne
003o[@00ojd00?n]003o]@03003o[@05003o]@00ojd000@0003o[@00okD0
0`00ojd01`00okD00?n]003o[@00ojd00?ne07]mN`001000?P3oool00`00
1000oooo0?ooo`0a0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`03
07moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0@@3oool06`00okD0
0?n]003o]@00ojd000@0003o[@00okD0Ngek003o]@00ojd00?ne003o[@00
okD00?n]003o]@1kOG/00?ne003o[@00okD000@0003o]@00ojd00?ne003o
[@00okD00?n]003o]@0200040009003o[@1kOG/00?n]003o]@00ojd00?ne
003o[@00okD00?n]0080Ngek00<00?ne0004003oool0?@3oool00`001000
oooo0?ooo`0a0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307mo
O`00ok<00?nc00H00?nc00<000000?ooo`3oool0@@3oool01P00ojd00?ne
003o[@00ojd000@0003o]@800?n]00<0Ngek003o]@00ojd00P00ojd01@00
okD0Ngek003o[@00ojd00?ne00800?n]00<000@0003o]@00ojd00P00ojd0
2@00okD000@0003o[@00ojd00?ne003o[@1kOG/00?n]003o]@03003o[@06
07]mN`00ojd00?n]003o[@00okD000@0?@3oool00`001000oooo0?ooo`0a
0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc
00H00?nc00<000000?ooo`3oool0@@3oool0;000okD00?n]003o]@001000
0?ne003o[@00okD00?n]003o]@1kOG/00?ne003o[@00okD0Ngek003o]@00
ojd00?ne003o[@00okD00?n]003o]@0010000?ne003o[@00okD000@0003o
]@00ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne003o[@1kOG/00?n]
003o]@00ojd00?ne003o[@00okD000@0=@3oool4000400<0oooo00<000@0
0?ooo`3oool0<@3oool00840oooo00<000000?ooo`3oool0403oool00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1o
Ogl00?nc003o/`06003o/`030000003oool0oooo0440oooo00@00?n]0004
000010000?ne0`00ojd01P00okD00?n]003o[@1kOG/00?ne07]mN`800?n]
00D00?ne003o[@00ojd00?n]003o]@02003o[@0300040000okD000@00080
0?n]00T00?ne003o[@00ojd00?n]003o]@00ojd0Ngek003o[@1kOG/00`00
ojd01P00okD00?n]003o[@00ojd00?ne000403@0oooo00<000@00?ooo`3o
ool0103oool00`001000oooo0?ooo`0a0?ooo`00P@3oool00`000000oooo
0?ooo`0@0?oooed0Ogmo@`3oool0;@0010000?n]003o]@00ojd00?ne003o
[@00okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd00?ne
003o[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]003o]@00ojd0
0?ne003o[@00okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]003o]@00
ojd00?ne003o[@00okD00?n]003o]@02000403<0oooo00<000@00?ooo`3o
ool00`3oool200040380oooo00210?ooo`030000003oool0oooo0100oooo
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc
00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`03003o
[@0010000?n]00800?n]00T00?ne003o[@00ojd00?n]003o]@1kOG/00?n]
07]mN`00okD00`00ojd02@00okD00?n]003o[@00ojd00?ne00040000ojd0
00@0003o]@03003o[@09003o]@00ojd00?n]003o[@1kOG/00?n]07]mN`00
ojd00?ne00<00?n]00@00?ne003o[@00ojd00?n]0P00100d0?ooo`030004
003oool0oooo0080oooo00<000@00?ooo`3oool0<@3oool00840oooo00<0
00000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003o
ool0oooo0440oooo02l00?ne003o[@0010000?n]003o]@00ojd00?ne003o
[@00okD0Ngek003o]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd00?ne
003o[@00okD000@0003o]@00ojd00?ne00040000okD00?n]003o]@00ojd0
0?ne003o[@1kOG/00?n]003o]@00ojd0Ngek003o[@00okD00?n]003o]@00
ojd00?ne003o[@0010000?n]003o]@0200040300oooo00@000@00?ooo`3o
ool000@00`3oool00`001000oooo0?ooo`0a0?ooo`00P@3oool00`000000
oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3o
ool0@@3oool3003o[@0600040000ojd00?n]003o[@00okD0Ngek0P00ojd0
1@00okD00?n]003o[@1kOG/00?ne00<00?n]00D00?ne00040000ojd00?n]
003o]@02003o[@0300040000okD00?n]00800?n]00T0Ngek003o[@00ojd0
0?n]003o]@00ojd0Ngek003o[@00okD00`00ojd01`0010000?n]003o[@00
ojd00?ne003o[@001000<03oool2000400@0oooo00<000@00?ooo`3oool0
<@3oool00840oooo00<000000?ooo`3oool0403oool00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o
/`06003o/`030000003oool0oooo0440oooo03<00?ne003o[@00okD00?n]
00040000ojd00?ne07]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD0
Ngek003o]@00ojd00?ne00040000okD00?n]003o]@00ojd00?ne003o[@00
okD000@0003o]@00ojd0Ngek003o[@00okD00?n]003o]@00ojd00?ne003o
[@1kOG/00?n]003o]@00ojd000@0003o[@00okD00?n]003o]@00ojd00?ne
003o[@001000=@3oool00`001000oooo0?ooo`0a0?ooo`00P@3oool00`00
0000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?oo
o`3oool0@@3oool00`00ojd00?ne003o[@02003o[@050004001kOG/00?n]
003o[@00okD00`00ojd01P00okD00?n]003o[@1kOG/00?ne000400800?n]
00D00?ne003o[@00ojd00?n]003o]@02003o[@0300040000okD0Ngek0080
0?n]00T00?ne003o[@00ojd00?n]003o]@00ojd0Ngek003o[@0010000`00
ojd01`00okD00?n]003o[@00ojd00?ne003o[@001000=03oool00`001000
oooo0?ooo`0a0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307mo
O`00ok<00?nc00H00?nc00<000000?ooo`3oool0@@3oool0=@00okD00?n]
003o]@00ojd00?ne07]mN`0010000?n]003o]@00ojd00?ne003o[@00okD0
0?n]003o]@00ojd00?ne00040000okD00?n]003o]@00ojd00?ne003o[@00
okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd00?ne003o
[@00okD00?n]003o]@00ojd000@0003o[@00okD00?n]003o]@00ojd00?ne
003o[@00okD00?n]003o]@00ojd0Ngek03<0oooo00<000@00?ooo`3oool0
<@3oool007/0oooo100000020?ooo`030000003oool0oooo0100oooo00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0
Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`<00?n]00D0
0?ne07]mN`00ojd000@0003o]@03003o[@09003o]@00ojd00?n]003o[@00
okD000@0003o[@1kOG/00?ne00<00?n]00T00?ne003o[@00ojd00?n]003o
]@1kOG/00?n]00040000okD00`00ojd02@00okD00?n]003o[@00ojd000@0
003o[@1kOG/00?n]003o]@03003o[@07003o]@00ojd00?n]003o[@1kOG/0
0?n]0004000b0?ooo`030004003oool0oooo0340oooo001k0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc
003o/`06003o/`030000003oool0oooo0440oooo03L00?ne003o[@00okD0
0?n]07]mN`00ojd00?ne00040000okD00?n]003o]@00ojd00?ne003o[@00
okD000@0003o]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd00?ne003o
[@00okD0Ngek003o]@00ojd00?ne00040000okD00?n]003o]@00ojd00?ne
003o[@0010000?n]003o]@00ojd0Ngek003o[@00okD00?n]003o]@00ojd0
0?ne003o[@1kOG/00?n]003o]@00ojd000@00340oooo00<000@00?ooo`3o
ool0<@3oool007`0oooo00<000000?ooo`3oool00P3oool200000140oooo
G@0000130?ooo`06003o[@00okD00?n]07]mN`00ojd00?ne0P00ojd00`00
10000?ne003o[@02003o[@05003o]@0010000?n]003o[@00okD00P00ojd0
0`1kOG/00?ne003o[@02003o[@05003o]@1kOG/00?n]003o[@00okD00P00
ojd00`0010000?ne003o[@02003o[@0900040000ojd00?n]003o[@00okD0
0?n]07]mN`00ojd00?ne00<00?n]00L0Ngek003o[@00ojd00?n]003o]@00
ojd000@00300oooo00<000@00?ooo`3oool0<@3oool007d0oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<0
00000?ooo`3oool0@@3oool0>@00okD00?n]07]mN`00ojd00?ne003o[@00
okD00?n]003o]@0010000?ne003o[@00okD000@0003o]@00ojd00?ne003o
[@00okD00?n]003o]@1kOG/00?ne003o[@00okD0Ngek003o]@00ojd00?ne
003o[@00okD00?n]003o]@0010000?ne003o[@0010000?n]003o]@00ojd0
0?ne003o[@00okD00?n]07]mN`00ojd00?ne003o[@1kOG/00?n]003o]@00
ojd00?ne003o[@00okD00?n]0004000_0?ooo`030004003oool0oooo0340
oooo001k0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0403oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo0440
oooo00@00?n]07]mN`00ojd00?ne0`00ojd01P00okD00?n]003o[@001000
0?ne000400800?n]00D00?ne003o[@00ojd00?n]003o]@02003o[@0307]m
N`00okD0Ngek00800?n]00D00?ne003o[@00ojd00?n]003o]@02003o[@80
00@00`00ojd02@00okD00?n]003o[@00ojd00?ne003o[@1kOG/00?n]07]m
N`03003o[@07003o]@00ojd00?n]003o[@00okD00?n]0004000^0?ooo`03
0004003oool0oooo0340oooo001l0?ooo`8000000`3oool00`000000oooo
0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0
@@3oool08P1kOG/00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00
ojd00?ne00040000okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o
]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@00ojd20004000G003o]@00ojd00?ne003o[@00okD00?n]003o]@00
ojd00?ne003o[@1kOG/00?n]003o]@00ojd00?ne003o[@00okD00?n]003o
]@00ojd00?ne003o[@001000;@3oool00`001000oooo0?ooo`0a0?ooo`00
P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc
00<000000?ooo`3oool0@@3oool00`00ojd0Ngek003o[@02003o[@09003o
]@00ojd00?n]003o[@00okD000@0003o[@0010000?ne00<00?n]00T00?ne
003o[@00ojd00?n]003o]@1kOG/00?n]07]mN`00okD00`00ojd01@00okD0
0?n]003o[@00ojd000@000800?n]00<000@0003o]@00ojd00P00ojd02@00
okD00?n]003o[@00ojd0Ngek003o[@1kOG/00?n]003o]@03003o[@07003o
]@00ojd00?n]003o[@0010000?n]0004000/0?ooo`030004003oool0oooo
0340oooo00210?ooo`030000003oool0oooo0100oooo00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00
ok<01P00ok<00`000000oooo0?ooo`110?ooo`0m003o]@00ojd0Ngek003o
[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]003o]@0010000?ne
003o[@00okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]003o]@1kOG/0
0?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]00040000
ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]07]m
N`00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0003o[@00okD00?n]
0004000[0?ooo`030004003oool0oooo0340oooo00210?ooo`030000003o
ool0oooo0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?oo
o`110?ooo`<00?n]00H0Ngek003o[@00ojd00?n]003o]@001002003o[@05
003o]@00ojd00?n]00040000okD00`00ojd01@00okD0Ngek003o[@00ojd0
0?ne00800?n]00<0Ngek003o]@00ojd00P00ojd02@00okD000@0003o[@00
ojd00?ne003o[@0010000?n]003o]@03003o[@0907]mN`00ojd00?n]003o
[@00okD00?n]07]mN`00ojd00?ne00<00?n]00H000@0003o[@00ojd00?n]
003o]@00100[0?ooo`030004003oool0oooo0340oooo00210?ooo`030000
003oool0oooo0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo
0?ooo`110?ooo`0n003o]@00ojd00?ne003o[@1kOG/00?n]003o]@001000
0?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]003o]@1k
OG/00?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]003o
]@0010000?ne003o[@00okD00?n]003o]@00ojd000@0003o[@00okD00?n]
07]mN`00ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek003o[@00okD0
0?n]00040000ojd00?ne003o[@00okD00?n]003o]@00100Z0?ooo`030004
003oool0oooo0340oooo00210?ooo`030000003oool0oooo0100oooo00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0
Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`03003o[@00
okD00?n]00800?n]00D0Ngek00040000ojd00?n]003o]@03003o[@06003o
]@00ojd00?n]00040000okD0Ngek0P00ojd01@00okD00?n]003o[@00ojd0
0?ne00800?n]00<0Ngek003o]@0010000P00ojd02@00okD00?n]003o[@00
ojd00?ne003o[@0010000?n]07]mN`03003o[@09003o]@00ojd00?n]003o
[@00okD00?n]07]mN`00ojd000@000<00?n]00H00?ne003o[@00ojd00?n]
003o]@00100Y0?ooo`030004003oool0oooo0340oooo00210?ooo`030000
003oool0oooo0100ooooG@1oOgm30?ooo`10003o]@00ojd00?ne003o[@00
okD000@007]mN`00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o
[@00okD0Ngek003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne
003o[@00okD000@0003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0
0?ne003o[@1kOG/00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00
ojd00?ne003o[@0010000?n]003o]@00ojd00?ne003o[@00okD00?n]003o
]@00ojd00?ne07]mNbP0oooo00<000@00?ooo`3oool0<@3oool00840oooo
00<000000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000
003oool0oooo0440oooo0`00ojd01@00okD000@0003o[@00ojd0Ngek00<0
0?n]00T00?ne003o[@00ojd00?n]003o]@1kOG/00?n]00040000okD00`00
ojd02@00okD00?n]003o[@00ojd00?ne00040000ojd0Ngek003o]@03003o
[@09003o]@00ojd00?n]003o[@1kOG/00?n]00040000ojd00?ne00<00?n]
00T00?ne003o[@00ojd00?n]00040000ojd0Ngek003o[@00okD00`00ojd0
1P00okD00?n]003o[@1kOG/00?ne000402L0oooo00<000@00?ooo`3oool0
<@3oool00840oooo00<000000?ooo`3oool0403oool00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o
/`06003o/`030000003oool0oooo0440oooo02X00?ne003o[@00okD00?n]
00040000ojd00?ne003o[@1kOG/00?n]003o]@00ojd00?ne003o[@00okD0
Ngek003o]@00ojd00?ne00040000okD00?n]003o]@00ojd00?ne003o[@00
okD000@0003o]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd00?ne003o
[@1kOG/00?n]003o]@00ojd20004000F003o]@00ojd00?ne003o[@00okD0
0?n]00040000ojd00?ne003o[@1kOG/00?n]003o]@00ojd00?ne003o[@00
okD0Ngek003o]@00ojd00?ne000402H0oooo00<000@00?ooo`3oool0<@3o
ool00840oooo00<000000?ooo`3oool0403oool00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06
003o/`030000003oool0oooo0440oooo00H00?n]003o]@00ojd000@0003o
[@00okD3003o[@0607]mN`00ojd00?n]003o[@00okD0Ngek0P00ojd01@00
okD00?n]003o[@0010000?ne00<00?n]00D00?ne00040000ojd00?n]003o
]@02003o[@0307]mN`00okD00?n]00800?n]00D0Ngek003o[@00ojd00?n]
003o]@02003o[@0300040000okD00?n]00800?n]00T000@0003o[@00ojd0
0?n]003o]@00ojd0Ngek003o[@00okD00P00ojd00`1kOG/00?ne003o[@02
003o[@03003o]@001000oooo01l0oooo0`0010020?ooo`030004003oool0
oooo0340oooo00210?ooo`030000003oool0oooo0100oooo00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o
/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`0S003o]@00100000@0
003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]003o]@1kOG/0
0?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]003o]@00
10000?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00okD00P1kOG/0
2P00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD20004
000C003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]003o]@1k
OG/00?ne003o[@00okD00?n]003o]@00ojd00?ne0004000P0?ooo`050004
003oool0oooo0?ooo`001000<`3oool00840oooo00<000000?ooo`3oool0
403oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo0440oooo
00@000@0003o[@00ojd00?ne0`00ojd01000okD00?n]003o[@00ojd207]m
N`800?n]00D00?ne003o[@00ojd00?n]003o]@02003o[@0300040000okD0
00@000800?n]00D00?ne003o[@00ojd00?n]003o]@02003o[@0307]mN`00
okD00?n]00800?n]00D00?ne003o[@00ojd00?n]003o]@02003o[@030004
0000okD00?n]00800?n]00T00?ne003o[@00ojd00?n]003o]@00ojd0Ngek
003o[@1kOG/00`00ojd01@00okD00?n]003o[@00ojd00?ne008000@06`3o
ool500040080oooo0P00100b0?ooo`00P@3oool00`000000oooo0?ooo`0@
0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07
003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0@@3oool0
2`00okD000@0003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne
0080Ngek03L00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0
0?ne00040000okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@1k
OG/00?ne07]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o
]@0010000?ne00040000okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@00ojd0Ngek003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD0
0?n]008000@06`3oool010001000oooo0?ooo`0010030?ooo`030004003o
ool0oooo0340oooo00210?ooo`030000003oool0oooo0100oooo00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo
003o/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`03003o[@001000
0?n]00800?n]00@00?ne003o[@00ojd00?n]0P1kOG/2003o[@0507]mN`00
ojd00?n]003o[@00okD00`00ojd200040003003o[@00100000@000<00?n]
00D00?ne003o[@00ojd0Ngek003o]@02003o[@0307]mN`00okD00?n]0080
0?n]00D00?ne003o[@00ojd000@0003o]@02003o[@0300040000okD00?n]
00800?n]00<00?ne003o[@00ojd00P1kOG/01000ojd0Ngek003o[@00okD3
003o[@06003o]@00ojd000@0003o[@00okD000@06`3oool00`001000oooo
000400030?ooo`030004003oool0oooo0340oooo001l0?ooo`8000000`3o
ool00`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<0
00000?ooo`3oool0@@3oool0?000okD00?n]00040000ojd00?ne003o[@00
okD00?n]07]mN`00ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne003o
[@00okD00?n]00040000ojd00?ne003o[@00okD00?n]00040000ojd00?ne
003o[@00okD0Ngek003o]@00ojd00?ne003o[@00okD0Ngek003o]@00ojd0
0?ne003o[@00okD000@0003o]@00ojd00?ne003o[@00okD000@0003o]@00
ojd00?ne003o[@00okD0Ngek003o]@00ojd00?ne003o[@80Ngek00X00?ne
003o[@00okD00?n]00040000ojd00?ne003o[@00okD000@06`3oool20004
00<0oooo00<000@00?ooo`3oool0<@3oool007/0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc
00H00?nc00<000000?ooo`3oool0@@3oool3003o[@0500040000ojd00?n]
003o[@1kOG/00`00ojd01@00okD00?n]003o[@00ojd0Ngek00<00?n]00D0
00@0003o[@00ojd00?n]003o]@03003o[@0500040000ojd00?n]07]mN`00
okD00`00ojd01@00okD00?n]003o[@1kOG/00?ne00800?n]00<000@0003o
]@00ojd00P00ojd01@00okD00?n]003o[@0010000?ne00800?n]00<0Ngek
003o]@00ojd00P00ojd02@00okD00?n]003o[@1kOG/00?ne003o[@001000
0?n]003o]@03003o[@03003o]@00100000@001h0oooo00<000@00?ooo`3o
ool0<@3oool007d0oooo00@000000?ooo`3oool0oooo0P00000A0?oooed0
0000@`3oool0B`00okD00?n]003o]@00ojd000@0003o[@00okD0Ngek003o
]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek003o[@0010000?n]
003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0003o[@1kOG/0
0?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@1kOG/00?ne00040000
okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@0010000?ne07]m
N`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@1kOG/000@0
003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]0004000M0?oo
o`030004003oool0oooo0340oooo001n0?ooo`040000003oool0oooo0000
0180oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`110?oo
o`03003o[@00okD00?n]00800?n]00D000@007]mN`00ojd00?n]003o]@03
003o[@05003o]@00ojd00?n]003o[@0010000`00ojd01@00okD00?n]003o
[@00ojd00?ne00<00?n]00D0Ngek003o[@00ojd00?n]003o]@03003o[@05
003o]@00ojd00?n]00040000okD00`00ojd01@00okD00?n]003o[@00ojd0
0?ne00800?n]00<0Ngek003o]@00ojd00P00ojd02@00okD00?n]003o[@00
ojd00?ne003o[@001000Ngek003o]@03003o[@07003o]@00ojd00?n]003o
[@00okD00?n]07]mN`0L0?ooo`030004003oool0oooo0340oooo001k0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0403oool0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<0
0`1oOgl00?nc003o/`06003o/`030000003oool0oooo0440oooo00H00?ne
003o[@00okD00?n]003o]@1kOG/200040015003o]@00ojd00?ne003o[@00
okD00?n]003o]@00ojd000@0003o[@1kOG/00?n]003o]@00ojd00?ne003o
[@00okD00?n]003o]@00ojd0Ngek003o[@0010000?n]003o]@00ojd00?ne
003o[@00okD00?n]003o]@0010000?ne07]mN`00okD00?n]003o]@00ojd0
0?ne003o[@00okD00?n]003o]@1kOG/00?ne00040000okD00?n]003o]@00
ojd00?ne003o[@00okD00?n]00040000ojd00?ne07]mN`00okD00?n]003o
]@00ojd00?ne003o[@00okD00?n]07]mN`00ojd000@001/0oooo00<000@0
0?ooo`3oool0<@3oool007`0oooo0P0000030?ooo`030000003oool0oooo
0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`110?oo
o`<00?n]00H00?ne07]mN`00ojd00?n]003o]@001002003o[@05003o]@00
ojd00?n]003o[@0010000`00ojd01@1kOG/00?n]003o[@00ojd00?ne00<0
0?n]00D0Ngek003o[@00ojd00?n]00040003003o[@05003o]@00ojd00?n]
00040000okD00P00ojd00`1kOG/00?ne003o[@02003o[@05003o]@00ojd0
0?n]07]mN`00okD00P00ojd00`0010000?ne003o[@02003o[@05003o]@00
ojd000@0003o[@00okD00P00ojd00`1kOG/00?ne003o[@02003o[@07003o
]@00ojd0Ngek003o[@00okD00?n]0004000J0?ooo`030004003oool0oooo
0340oooo00210?ooo`030000003oool0oooo0100oooo00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00
ok<01P00ok<00`000000oooo0?ooo`110?ooo`1?003o]@00ojd00?ne07]m
N`00okD00?n]003o]@00ojd00?ne00040000okD00?n]003o]@00ojd000@0
003o[@00okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]003o]@00ojd0
Ngek003o[@00okD00?n]003o]@0010000?ne003o[@00okD00?n]003o]@00
10000?ne003o[@00okD00?n]003o]@1kOG/00?ne003o[@00okD00?n]003o
]@1kOG/00?ne003o[@00okD00?n]003o]@0010000?ne003o[@00okD00?n]
00040000ojd00?ne003o[@00okD00?n]003o]@1kOG/00?ne003o[@00okD0
0?n]07]mN`00ojd00?ne003o[@00okD00?n]0004000I0?ooo`030004003o
ool0oooo0340oooo00210?ooo`030000003oool0oooo0100oooo00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo
003o/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`03003o[@00okD0
Ngek00800?n]00H00?ne003o[@00ojd00?n]003o]@001002003o[@050004
0000ojd00?n]003o[@00okD00`00ojd01@1kOG/00?n]003o[@00ojd0Ngek
00<00?n]00D00?ne003o[@00ojd000@0003o]@02003o[@0300040000okD0
0?n]00800?n]00D00?ne003o[@00ojd0Ngek003o]@02003o[@0307]mN`00
okD00?n]00800?n]00T00?ne003o[@00ojd000@0003o]@00ojd000@0003o
[@00okD00`00ojd02@00okD00?n]07]mN`00ojd00?ne003o[@1kOG/00?n]
003o]@03003o[@03003o]@00ojd000@001P0oooo00<000@00?ooo`3oool0
<@3oool00840oooo00<000000?ooo`3oool0403oool00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o
/`06003o/`030000003oool0oooo0440oooo00/00?ne07]mN`00okD00?n]
003o]@00ojd00?ne003o[@00okD00?n]003o]@0200040014003o[@00okD0
0?n]003o]@00ojd00?ne003o[@00okD00?n]07]mN`00ojd0Ngek003o[@00
okD00?n]003o]@00ojd00?ne003o[@00okD000@0003o]@0010000?ne003o
[@00okD00?n]003o]@00ojd00?ne003o[@00okD0Ngek003o]@1kOG/00?ne
003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD000@0003o]@001000
0?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]07]mN`00
ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00100G0?ooo`03
0004003oool0oooo0340oooo00210?ooo`030000003oool0oooo0100oooo
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc
00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`0407]m
N`00ojd00?n]003o]@<00?n]00@00?ne003o[@00ojd00?n]0P001002003o
[@05003o]@00ojd00?n]003o[@00okD00`00ojd01@1kOG/00?n]003o[@00
ojd00?ne00<00?n]00D00?ne003o[@00ojd000@0003o]@03003o[@05003o
]@00ojd00?n]003o[@00okD00P00ojd00`1kOG/00?ne003o[@02003o[@05
003o]@00ojd00?n]003o[@00okD00P00ojd00`0010000?ne003o[@02003o
[@09003o]@00ojd00?n]003o[@00okD00?n]07]mN`00ojd00?ne00<00?n]
00L00?ne003o[@00ojd00?n]003o]@00ojd000@001H0oooo00<000@00?oo
o`3oool0<@3oool00840oooo00<000000?ooo`3oool0403oool00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl0
0?nc003o/`06003o/`030000003oool0oooo0440oooo05<00?ne07]mN`00
okD00?n]003o]@00ojd00?ne003o[@00okD00?n]00040000ojd00?ne0004
0000okD00?n]003o]@00ojd00?ne003o[@00okD00?n]07]mN`00ojd0Ngek
003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD000@0003o]@001000
0?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD0Ngek003o]@1k
OG/00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD000@0003o
]@0010000?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]
07]mN`00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@001000
0?n]0004000E0?ooo`030004003oool0oooo0340oooo00210?ooo`030000
003oool0oooo0100ooooG@1oOgm30?ooo`03003o[@00okD0Ngek00800?n]
00D00?ne003o[@00ojd00?n]00040003003o[@0500040000ojd00?n]003o
[@00okD00`00ojd01@1kOG/00?n]003o[@00ojd0Ngek00<00?n]00D00?ne
003o[@00ojd00?n]00040002003o[@0300040000okD00?n]00800?n]00D0
0?ne003o[@00ojd0Ngek003o]@02003o[@0307]mN`00okD00?n]00800?n]
00D00?ne003o[@00ojd000@0003o]@02003o[@0300040000okD00?n]0080
0?n]00T00?ne003o[@1kOG/00?n]003o]@00ojd0Ngek003o[@00okD00`00
ojd01`00okD00?n]00040000ojd00?ne003o[@001000503oool00`001000
oooo0?ooo`0a0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307mo
O`00ok<00?nc00H00?nc00<000000?ooo`3oool0@@3oool0E@00okD00?n]
003o]@1kOG/00?ne003o[@00okD00?n]00040000ojd00?ne003o[@00okD0
0?n]00040000ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne003o[@00
okD00?n]07]mN`00ojd00?ne003o[@00okD00?n]00040000ojd00?ne003o
[@00okD000@0003o]@00ojd00?ne003o[@00okD0Ngek003o]@00ojd00?ne
003o[@00okD0Ngek003o]@00ojd00?ne003o[@00okD000@0003o]@00ojd0
0?ne003o[@00okD000@0003o]@00ojd00?ne003o[@1kOG/00?n]003o]@00
ojd00?ne003o[@1kOG/00?n]003o]@00ojd00?ne003o[@0010000?n]003o
]@00ojd00?ne003o[@0010004`3oool00`001000oooo0?ooo`0a0?ooo`00
P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc
00<000000?ooo`3oool0@@3oool3003o[@05003o]@1kOG/00?n]003o[@00
10000`00ojd01@00okD00?n]003o[@00ojd000@000<00?n]00D0Ngek003o
[@00ojd00?n]003o]@03003o[@0507]mN`00ojd00?n]003o[@0010000`00
ojd01@00okD00?n]003o[@0010000?ne00800?n]00<0Ngek003o]@00ojd0
0P00ojd01@00okD00?n]003o[@1kOG/00?ne00800?n]00<000@0003o]@00
ojd00P00ojd02@00okD00?n]003o[@0010000?ne003o[@1kOG/00?n]003o
]@03003o[@09003o]@00ojd0Ngek003o[@00okD00?n]00040000ojd00?ne
00<00?n]00<00?ne003o[@0010004P3oool00`001000oooo0?ooo`0a0?oo
o`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H0
0?nc00<000000?ooo`3oool0@@3oool0E`00okD00?n]003o]@00ojd00?ne
07]mN`00okD000@0003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0
00@0003o[@1kOG/00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00
ojd0Ngek003o[@0010000?n]003o]@00ojd00?ne003o[@00okD00?n]003o
]@0010000?ne07]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@1kOG/00?ne00040000okD00?n]003o]@00ojd00?ne003o[@00okD0
0?n]003o]@001000Ngek003o[@00okD00?n]003o]@00ojd00?ne003o[@00
okD00?n]07]mN`00ojd000@0003o[@00okD00?n]003o]@00ojd00?ne003o
[@00okD00?n]0004000A0?ooo`030004003oool0oooo0340oooo00210?oo
o`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
0000oooo0?ooo`110?ooo`03003o[@00okD00?n]00800?n]00D00?ne0004
0000ojd00?n]003o]@03003o[@05003o]@00ojd00?n]003o[@1kOG/00`00
ojd01@00okD00?n]003o[@00ojd00?ne00<00?n]00D000@0003o[@00ojd0
0?n]003o]@03003o[@05003o]@00ojd00?n]07]mN`00okD00`00ojd01@00
okD00?n]003o[@00ojd00?ne00800?n]00<000@0003o]@00ojd00P00ojd0
2@00okD00?n]003o[@00ojd00?ne003o[@1kOG/000@0003o]@03003o[@09
003o]@00ojd00?n]003o[@00okD00?n]00040000ojd00?ne00<00?n]00L0
0?ne003o[@00ojd00?n]003o]@00ojd0Ngek0100oooo00<000@00?ooo`3o
ool0<@3oool00840oooo00<000000?ooo`3oool0403oool00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc
003o/`06003o/`030000003oool0oooo0440oooo05T00?ne003o[@00okD0
0?n]003o]@0010000?ne07]mN`00okD00?n]003o]@00ojd00?ne003o[@00
okD00?n]07]mN`00ojd000@0003o[@00okD00?n]003o]@00ojd00?ne003o
[@00okD00?n]00040000ojd0Ngek003o[@00okD00?n]003o]@00ojd00?ne
003o[@00okD0Ngek003o]@0010000?ne003o[@00okD00?n]003o]@00ojd0
0?ne003o[@00okD000@0003o]@1kOG/00?ne003o[@00okD00?n]003o]@00
ojd00?ne003o[@1kOG/00?n]003o]@0010000?ne003o[@00okD00?n]003o
]@00ojd00?ne003o[@0010000?n]07]mN`00ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@1kOG/00?n]0004000?0?ooo`030004003oool0
oooo0340oooo00210?ooo`030000003oool0oooo0100oooo00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o
/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`<00?n]00D00?ne0004
0000ojd00?n]07]mN`03003o[@05003o]@00ojd00?n]003o[@1kOG/00`00
ojd01@0010000?n]003o[@00ojd00?ne00<00?n]00D000@0003o[@00ojd0
0?n]07]mN`03003o[@05003o]@00ojd00?n]07]mN`00okD00P00ojd00`00
10000?ne003o[@02003o[@05003o]@00ojd00?n]00040000okD00P00ojd0
0`1kOG/00?ne003o[@02003o[@05003o]@00ojd0Ngek003o[@00okD00P00
ojd00`0010000?ne003o[@02003o[@09003o]@00ojd000@0003o[@00okD0
0?n]07]mN`00ojd00?ne00<00?n]00L00?ne003o[@1kOG/00?n]003o]@00
ojd000@000h0oooo00<000@00?ooo`3oool0<@3oool007d0oooo0`000000
0`3oool000000?ooo`0A0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo
003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<0
0?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<0
0`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<00000
0?ooo`3oool0@@3oool0F`00okD00?n]003o]@0010000?ne003o[@00okD0
0?n]07]mN`00ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne003o[@00
okD00?n]00040000ojd00?ne003o[@00okD00?n]00040000ojd00?ne003o
[@00okD00?n]07]mN`00ojd00?ne003o[@00okD0Ngek003o]@00ojd00?ne
003o[@00okD000@0003o]@00ojd00?ne003o[@00okD000@0003o]@00ojd0
0?ne003o[@00okD0Ngek003o]@00ojd00?ne003o[@1kOG/00?n]003o]@00
ojd00?ne003o[@00okD000@0003o]@00ojd00?ne003o[@0010000?n]003o
]@00ojd00?ne003o[@1kOG/00?n]003o]@00ojd00?ne003o[@1kOG/00?n]
003o]@00ojd00?ne003o[@0010003@3oool00`001000oooo0?ooo`0a0?oo
o`00OP3oool010000000oooo0?ooo`00000B0?ooo`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc
00H00?nc00<000000?ooo`3oool0@@3oool00`00ojd00?ne00040002003o
[@05003o]@00ojd00?n]003o[@1kOG/00`00ojd01@1kOG/00?n]003o[@00
ojd00?ne00<00?n]00D000@0003o[@00ojd00?n]00040003003o[@05003o
]@00ojd00?n]003o[@1kOG/00P00ojd00`1kOG/00?ne003o[@02003o[@05
003o]@00ojd00?n]00040000okD00P00ojd00`0010000?ne003o[@02003o
[@09003o]@00ojd00?n]07]mN`00okD00?n]07]mN`00ojd00?ne00<00?n]
00T00?ne003o[@00ojd000@0003o]@00ojd000@0003o[@00okD00`00ojd0
2@00okD00?n]07]mN`00ojd00?ne003o[@1kOG/00?n]003o]@03003o[@03
003o]@00ojd000@000D0oooo0`0010040?ooo`030004003oool0oooo0340
oooo001k0?ooo`D0000000<0oooo0000000000004@3ooomM000004<0oooo
02800?ne00040000okD00?n]003o]@00ojd00?ne003o[@00okD00?n]07]m
N`00ojd0Ngek003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
00040000ojd000@0003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD0
0?n]0P1kOG/08@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o
]@0010000?ne00040000okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
003o]@1kOG/00?ne07]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD0
0?n]003o]@020004000F003o[@00okD00?n]003o]@00ojd00?ne003o[@00
okD00?n]07]mN`00ojd0Ngek003o[@00okD00?n]003o]@00ojd00?ne003o
[@00okD00?n]000400@0oooo00@000@00?ooo`3oool000@00`3oool00`00
1000oooo0?ooo`0a0?ooo`00N`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
0000oooo0?ooo`110?ooo`0400040000ojd00?n]003o]@<00?n]00D00?ne
003o[@00ojd00?n]07]mN`03003o[@05003o]@00ojd00?n]003o[@00okD0
0`00ojd01@0010000?n]003o[@00ojd00?ne00<00?n]00<00?ne003o[@00
ojd00P1kOG/3003o[@05003o]@00ojd00?n]003o[@00okD00P00ojd00`00
10000?ne003o[@02003o[@05003o]@00ojd00?n]003o[@00okD00P00ojd0
0`1kOG/00?ne003o[@02003o[@06003o]@00ojd00?n]003o[@00okD00?n]
0P0010001@00okD00?n]003o[@00ojd00?ne00<00?n]00D00?ne003o[@1k
OG/00?n]003o]@03003o[@05003o]@00ojd00?n]003o[@00okD00P001003
0?ooo`040004003oool0oooo000400<0oooo0P00100b0?ooo`00O03oool0
0`000000oooo000000020?ooo`030000003oool0oooo0100oooo00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06
003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<0
0`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo
003o/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`0E003o]@001000
0?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]07]mN`00
ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne008000@004P00?n]0004
0000ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]
07]mN`00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD0
00@0003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00
okD0Ngek003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0003o
[@00okD000@0003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek
003o[@1kOG/00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@001000
0?ne003o[@0010020?ooo`<000@0103oool00`001000oooo0?ooo`0a0?oo
o`00O@3oool200000080oooo00<000000?ooo`3oool0403oool00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl0
0?nc003o/`06003o/`030000003oool0oooo0440oooo00<00?n]003o]@00
10000P00ojd01@00okD00?n]003o[@00ojd0Ngek00<00?n]0P1kOG/2003o
[@05003o]@00ojd00?n]00040000okD00`00ojd2000400800?n]00D00?ne
003o[@00ojd0Ngek003o]@03003o[@0507]mN`00ojd00?n]003o[@00okD0
0P00ojd01P0010000?ne003o[@00ojd000@0003o]@<00?n]00D00?ne003o
[@00ojd0Ngek003o]@02003o[@0307]mN`00okD00?n]00800?n]00D00?ne
003o[@0010000?n]003o]@02003o[@0300040000okD00?n]00800?n]00T0
0?ne003o[@1kOG/00?n]003o]@00ojd0Ngek003o[@00okD00`00ojd01`00
okD000@0003o[@00ojd00?ne003o[@0010000P3oool00`001000oooo0?oo
o`030?ooo`030004003oool0oooo0340oooo00210?ooo`030000003oool0
oooo0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06
003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<0
0`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000
003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<0
0?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`11
0?ooo`0a003o]@00ojd00?ne00040000okD00?n]003o]@00ojd0Ngek003o
[@00okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]003o]@0010000?ne
003o[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]003o]@1kOG/0
0?ne003o[@00okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]003o]@00
10000?ne003o[@00okD00?n]003o]@020004000_003o[@00okD00?n]003o
]@1kOG/00?ne003o[@00okD00?n]003o]@1kOG/00?ne003o[@00okD00?n]
00040000ojd00?ne003o[@00okD00?n]003o]@0010000?ne003o[@00okD0
0?n]07]mN`00ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne003o[@00
okD000@0003o]@00ojd00?ne003o[@00okD00?n]0004003oool00`001003
0?ooo`030004003oool0oooo0340oooo00210?ooo`030000003oool0oooo
0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`110?oo
o`<00?n]00<00?ne00040000ojd00P1kOG/3003o[@09003o]@00ojd00?n]
003o[@00okD0Ngek003o[@0010000?ne00<00?n]00T00?ne003o[@00ojd0
0?n]003o]@0010000?n]07]mN`00okD00`00ojd01@00okD00?n]003o[@00
ojd0Ngek00800?n]00<000@0003o]@00ojd00P00ojd01@00okD00?n]003o
[@00ojd000@000800?n]00<0Ngek003o]@00ojd00P00ojd01@00okD00?n]
003o[@1kOG/00?ne008000@000<00?n]003o]@00ojd00P00ojd01@00okD0
0?n]003o[@0010000?ne0080Ngek00<00?n]003o]@00ojd00P00ojd01000
okD00?n]07]mN`00ojd2000400800?n]00L00?ne003o[@00ojd00?n]003o
]@00ojd000@000H0oooo00<000@00?ooo`3oool0<@3oool00840oooo00<0
00000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003o
ool0oooo0440oooo06<00?ne003o[@00okD00?n]003o]@1kOG/00?ne003o
[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@0010000?ne
003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@1kOG/0
0?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]07]mN`00
10000?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]0004
001kOG/00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD000@0
003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD0
Ngek003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00
10000?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o
[@1kOG/01@3oool00`001000oooo0?ooo`0a0?ooo`00P@3oool00`000000
oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L0
0?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000
0?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3o
ool0@@3oool01`00ojd00?ne003o[@00ojd0Ngek003o]@0010000P00ojd0
1@00okD00?n]003o[@00ojd00?ne00800?n]00<000@0003o]@1kOG/00P00
ojd01@00okD00?n]003o[@00ojd00?ne00800?n]00<0Ngek003o]@001000
0P00ojd01@00okD00?n]003o[@00ojd00?ne00800?n]00<000@007]mN`00
ojd00P00ojd01@00okD00?n]003o[@00ojd00?ne00800?n]00<0Ngek0004
0000ojd00P00ojd02@00okD00?n]003o[@00ojd00?ne00040000ojd0Ngek
003o]@03003o[@09003o]@00ojd00?n]003o[@00okD0Ngek003o[@001000
0?ne00<00?n]00T00?ne003o[@00ojd00?n]00040000ojd0Ngek003o[@00
okD00`00ojd01`00okD00?n]003o[@00ojd0Ngek003o[@001000103oool0
0`001000oooo0?ooo`0a0?ooo`00P@3oool00`000000oooo0?ooo`0@0?oo
o`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o
/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0@@3oool09P00
okD00?n]003o]@00ojd0Ngek003o[@00okD000@0003o]@00ojd00?ne003o
[@00okD00?n]003o]@0010000?ne003o[@00okD0Ngek003o]@00ojd00?ne
003o[@00okD00?n]003o]@1kOG/00?ne003o[@00okD000@0003o]@00ojd0
0?ne003o[@00okD00?n]0P0010002P00okD00?n]07]mN`00ojd00?ne003o
[@00okD00?n]003o]@00ojd207]mN`0a003o]@00ojd000@0003o[@00okD0
0?n]003o]@00ojd00?ne00040000okD00?n]003o]@1kOG/00?ne003o[@00
okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]003o]@0010000?ne003o
[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]07]mN`00ojd00?ne
003o[@00okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]000400030?oo
o`030004003oool0oooo0340oooo00210?ooo`030000003oool0oooo0100
ooooG@1oOgm30?ooo`<00?n]00H0Ngek003o[@00ojd00?n]003o]@001002
003o[@05003o]@00ojd00?n]00040000okD00`00ojd01@00okD0Ngek003o
[@00ojd00?ne00800?n]00<0Ngek003o]@00ojd00P00ojd02@00okD000@0
003o[@00ojd00?ne003o[@0010000?n]003o]@03003o[@0907]mN`00ojd0
0?n]003o[@00okD00?n]07]mN`00ojd00?ne00<00?n]00H000@0003o[@00
ojd00?n]003o]@001002003o[@05003o]@00ojd00?n]07]mN`00okD00`00
ojd01@00okD0Ngek003o[@00ojd00?ne00800?n]00<000@0003o]@00ojd0
0P00ojd02@00okD000@0003o[@00ojd00?ne003o[@1kOG/00?n]003o]@03
003o[@0707]mN`00ojd00?n]003o[@00okD00?n]000400020?ooo`030004
003oool0oooo0340oooo00210?ooo`030000003oool0oooo0100oooo00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0
Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`1Y003o]@00
ojd0Ngek003o[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]003o
]@0010000?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]
003o]@1kOG/00?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD0
0?n]00040000ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek003o[@00
okD00?n]07]mN`00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0003o
[@00okD000@0003o]@00ojd00?ne003o[@00okD00?n]003o]@1kOG/00?ne
003o[@00okD0Ngek003o]@00ojd00?ne003o[@00okD00?n]003o]@001000
0?ne003o[@00okD000@0003o]@00ojd00?ne003o[@00okD00?n]07]mN`00
ojd00?ne003o[@1kOG/00?n]003o]@00ojd00?ne003o[@00okD00?n]0004
003oool000@003<0oooo00210?ooo`030000003oool0oooo0100oooo00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0
Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`03003o[@1k
OG/00?n]00800?n]00T00?ne003o[@00ojd00?n]003o]@0010000?n]0004
0000okD00`00ojd02@00okD00?n]003o[@00ojd00?ne07]mN`00ojd0Ngek
003o]@03003o[@09003o]@00ojd00?n]003o[@00okD000@0003o[@001000
0?ne00<00?n]00T00?ne003o[@00ojd00?n]07]mN`00ojd0Ngek003o[@00
okD00`00ojd01P00okD00?n]003o[@0010000?ne000400800?n]00D00?ne
003o[@00ojd00?n]003o]@02003o[@0307]mN`00okD0Ngek00800?n]00D0
0?ne003o[@00ojd00?n]003o]@02003o[@0300040000okD000@000800?n]
00T00?ne003o[@00ojd00?n]003o]@00ojd0Ngek003o[@1kOG/00`00ojd0
1P00okD00?n]003o[@00ojd00?ne003o[@8000@0<`3oool00840oooo00<0
00000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003o
ool0oooo0440oooo06T0Ngek003o[@00okD00?n]003o]@00ojd00?ne003o
[@00okD00?n]003o]@0010000?ne003o[@00okD00?n]003o]@00ojd00?ne
003o[@00okD00?n]003o]@1kOG/00?ne003o[@00okD00?n]003o]@00ojd0
0?ne003o[@00okD00?n]003o]@0010000?ne003o[@00okD00?n]003o]@00
ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne003o[@00okD00?n]003o
]@00ojd00?ne003o[@00okD000@0003o]@00ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD0Ngek003o]@00ojd00?ne003o[@00okD0
0?n]003o]@00ojd00?ne003o[@00okD000@0003o]@00ojd00?ne003o[@00
okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]003o]@00ojd00?ne003o
[@00okD00?n]003o]@00ojd00?ne003o[@001000<`3oool00840oooo00<0
00000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003o
ool0oooo0440oooo00@00?n]07]mN`00ojd00?ne0`00ojd01P00okD00?n]
003o[@0010000?ne000400800?n]00D00?ne003o[@00ojd00?n]003o]@02
003o[@0307]mN`00okD0Ngek00800?n]00D00?ne003o[@00ojd00?n]003o
]@02003o[@0300040000okD000@000800?n]00T00?ne003o[@00ojd00?n]
003o]@00ojd0Ngek003o[@1kOG/00`00ojd02@00okD00?n]003o[@00ojd0
0?ne00040000ojd000@0003o]@03003o[@09003o]@00ojd00?n]003o[@00
okD0Ngek003o[@1kOG/00?ne00<00?n]00T00?ne003o[@00ojd00?n]003o
]@0010000?n]00040000okD00`00ojd02@00okD00?n]003o[@00ojd0Ngek
003o[@1kOG/00?n]003o]@03003o[@07003o]@00ojd00?n]003o[@001000
0?n]0004000b0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc
00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307mo
O`00ok<00?nc00H00?nc00<000000?ooo`3oool0@@3oool0J`00okD00?n]
07]mN`00ojd00?ne003o[@00okD00?n]003o]@0010000?ne003o[@00okD0
00@0003o]@00ojd00?ne003o[@00okD00?n]003o]@1kOG/00?ne003o[@00
okD0Ngek003o]@00ojd00?ne003o[@00okD00?n]003o]@0010000?ne003o
[@00okD000@0003o]@00ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne
003o[@1kOG/00?n]003o]@00ojd00?ne003o[@00okD00?n]00040000ojd0
0?ne00040000okD00?n]003o]@00ojd00?ne003o[@00okD0Ngek003o]@00
ojd00?ne07]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD000@0003o
]@00ojd00?ne00040000okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]
003o]@00ojd0Ngek003o[@00okD00?n]003o]@00ojd00?ne003o[@001000
0?n]003o]@00ojd000@00340oooo00210?ooo`030000003oool0oooo0100
oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`03
00000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`06
003o[@00okD00?n]07]mN`00ojd00?ne0P00ojd00`0010000?ne003o[@02
003o[@05003o]@0010000?n]003o[@00okD00P00ojd00`1kOG/00?ne003o
[@02003o[@05003o]@1kOG/00?n]003o[@00okD00P00ojd00`0010000?ne
003o[@02003o[@09003o]@0010000?n]003o[@00okD00?n]07]mN`00ojd0
0?ne00<00?n]00T0Ngek003o[@00ojd00?n]003o]@00ojd000@0003o[@00
okD00P00ojd00`0010000?ne003o[@02003o[@05003o]@1kOG/00?n]003o
[@00okD00P00ojd00`1kOG/00?ne003o[@02003o[@05003o]@0010000?n]
003o[@00okD00P00ojd00`0010000?ne003o[@02003o[@0907]mN`00ojd0
0?n]003o[@00okD00?n]07]mN`00ojd00?ne00<00?n]00L000@0003o[@00
ojd00?n]003o]@00ojd000@00300oooo001l0?ooo`8000000`3oool00`00
0000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?oo
o`3oool0@@3oool0K@00okD00?n]003o]@00ojd0Ngek003o[@00okD000@0
003o]@00ojd00?ne003o[@00okD00?n]003o]@0010000?ne003o[@00okD0
Ngek003o]@00ojd00?ne003o[@00okD00?n]003o]@1kOG/00?ne003o[@00
okD000@0003o]@00ojd00?ne003o[@00okD00?n]00040000ojd00?ne003o
[@1kOG/00?n]003o]@00ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne
003o[@0010000?n]003o]@00ojd00?ne003o[@00okD000@0003o]@00ojd0
0?ne07]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD0Ngek003o]@00
ojd00?ne00040000okD00?n]003o]@00ojd00?ne003o[@00okD000@0003o
]@00ojd0Ngek003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]
003o]@00ojd000@0003o[@00okD00?n]003o]@00ojd00?ne003o[@001000
;`3oool007/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc
003o/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0
@@3oool3003o[@05003o]@00ojd0Ngek003o[@0010000`00ojd02@00okD0
0?n]003o[@00ojd00?ne00040000ojd0Ngek003o]@03003o[@09003o]@00
ojd00?n]003o[@00okD0Ngek003o[@0010000?ne00<00?n]00T00?ne003o
[@00ojd00?n]00040000ojd0Ngek003o[@00okD00`00ojd02@00okD00?n]
003o[@00ojd0Ngek003o[@0010000?n]003o]@03003o[@06003o]@00ojd0
0?n]00040000okD0Ngek0P00ojd01@00okD00?n]003o[@00ojd00?ne0080
0?n]00<0Ngek003o]@0010000P00ojd01@00okD00?n]003o[@00ojd00?ne
00800?n]00<000@0003o]@1kOG/00P00ojd02@00okD00?n]003o[@00ojd0
0?ne003o[@1kOG/00?n]00040003003o[@07003o]@00ojd00?n]003o[@00
okD00?n]0004000^0?ooo`00OP3oool00`000000oooo0?ooo`0200000140
ooooG@0000130?ooo`1_003o]@00ojd00?ne003o[@00okD00?n]00040000
ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD0Ngek003o
]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD000@0
003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/0
0?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00
10000?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne07]m
N`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne
00040000okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0
00@007]mN`00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00
ojd000@0003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o
]@00ojd0Ngek02d0oooo001l0?ooo`8000000`3oool00`000000oooo0?oo
o`0@0?ooo`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00L00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`07003o/`0307moO`00ok<00?nc00H00?nc00<000000?ooo`3oool0@@3o
ool00`00ojd00?ne003o[@02003o[@0500040000ojd0Ngek003o[@00okD0
0`00ojd01P00okD00?n]003o[@1kOG/00?ne000400800?n]00D00?ne003o
[@00ojd00?n]003o]@02003o[@0300040000okD0Ngek00800?n]00T00?ne
003o[@00ojd00?n]003o]@00ojd0Ngek003o[@0010000`00ojd02@00okD0
0?n]003o[@00ojd00?ne003o[@0010000?n]07]mN`03003o[@09003o]@00
ojd00?n]003o[@00okD0Ngek003o[@0010000?ne00<00?n]00T00?ne003o
[@00ojd00?n]003o]@0010000?n]07]mN`00okD00`00ojd02@00okD00?n]
003o[@00ojd00?ne07]mN`0010000?n]003o]@03003o[@09003o]@00ojd0
0?n]003o[@0010000?n]07]mN`00ojd00?ne00<00?n]00L00?ne003o[@00
ojd00?n]07]mN`00ojd000@002`0oooo001l0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o
/`030000003oool0oooo0440oooo07400?ne003o[@00okD00?n]00040000
ojd00?ne003o[@1kOG/00?n]003o]@00ojd00?ne003o[@00okD0Ngek003o
]@00ojd00?ne00040000okD00?n]003o]@00ojd00?ne003o[@00okD000@0
003o]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd00?ne003o[@1kOG/0
0?n]003o]@00ojd000@0003o[@00okD00?n]003o]@00ojd00?ne003o[@00
10000?n]003o]@00ojd0Ngek003o[@00okD00?n]003o]@00ojd00?ne07]m
N`00okD00?n]003o]@0010000?ne003o[@00okD00?n]003o]@00ojd00?ne
00040000okD00?n]003o]@1kOG/00?ne003o[@00okD00?n]003o]@00ojd0
0?ne07]mN`00okD00?n]00040000ojd00?ne003o[@00okD00?n]003o]@00
ojd000@0003o[@00okD00?n]07]mN`00ojd00?ne003o[@00okD00?n]003o
]@00ojd0Ngek003o[@00okD00?n]0004000[0?ooo`00O03oool300000080
oooo00<000000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H0
0?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`03
0000003oool0oooo0440oooo0`00ojd01P0010000?n]003o[@00ojd00?ne
07]mN`800?n]00D00?ne003o[@00ojd0Ngek003o]@03003o[@05003o]@00
10000?n]003o[@00okD00P00ojd00`0010000?ne003o[@02003o[@09003o
]@1kOG/00?n]003o[@00okD00?n]07]mN`00ojd00?ne00<00?n]00T000@0
003o[@00ojd00?n]003o]@00ojd000@0003o[@00okD00`00ojd01P1kOG/0
0?n]003o[@00ojd00?ne07]mN`800?n]00D00?ne003o[@00ojd000@0003o
]@03003o[@05003o]@0010000?n]003o[@00okD00P00ojd00`1kOG/00?ne
003o[@02003o[@09003o]@1kOG/00?n]003o[@00okD00?n]00040000ojd0
0?ne00<00?n]00T000@0003o[@00ojd00?n]003o]@00ojd0Ngek003o[@00
okD00`00ojd01`1kOG/00?n]003o[@00ojd00?ne003o[@001000:P3oool0
0840oooo00<000000?ooo`3oool0403oool00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o
/`030000003oool0oooo0440oooo07<00?ne003o[@0010000?n]003o]@00
ojd00?ne003o[@00okD0Ngek003o]@00ojd00?ne07]mN`00okD00?n]003o
]@00ojd00?ne003o[@00okD000@0003o]@00ojd00?ne00040000okD00?n]
003o]@00ojd00?ne003o[@00okD0Ngek003o]@00ojd0Ngek003o[@00okD0
0?n]003o]@00ojd00?ne003o[@0010000?n]003o]@00ojd000@0003o[@00
okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]003o]@1kOG/00?ne003o
[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]003o]@0010000?ne
003o[@00okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]003o]@1kOG/0
0?ne003o[@00okD00?n]003o]@00ojd000@0003o[@00okD00?n]00040000
ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]07]m
N`00ojd00?ne003o[@00okD00?n]003o]@00ojd000@002T0oooo00210?oo
o`030000003oool0oooo0100oooo00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o
/`00ok<01`00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o
/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
0000oooo0?ooo`110?ooo`03003o[@0010000?n]00800?n]00T00?ne003o
[@00ojd00?n]003o]@1kOG/00?n]07]mN`00okD00`00ojd02@00okD00?n]
003o[@00ojd00?ne00040000ojd000@0003o]@03003o[@09003o]@00ojd0
0?n]003o[@00okD0Ngek003o[@1kOG/00?ne00<00?n]00T00?ne003o[@00
ojd00?n]00040000ojd000@0003o[@00okD00`00ojd01000okD00?n]003o
[@00ojd207]mN`800?n]00D00?ne003o[@00ojd00?n]003o]@02003o[@03
00040000okD000@000800?n]00D00?ne003o[@00ojd00?n]003o]@02003o
[@0307]mN`00okD0Ngek00800?n]00T00?ne003o[@00ojd00?n]003o]@00
ojd000@0003o[@0010000`00ojd02@00okD00?n]003o[@00ojd00?ne003o
[@1kOG/00?n]07]mN`03003o[@07003o]@00ojd00?n]003o[@00okD00?n]
0004000X0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00
ok<00?nc00H00?nc00<000000?ooo`3oool0@@3oool0>@0010000?n]003o
]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]
003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD0
0?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00
okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0003o
[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@0207]mN`0Q
003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@001000
0?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@1k
OG/00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]0080
00@001D00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD00?n]
07]mN`00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@00okD0
0P00100W0?ooo`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0
Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00
ok<00?nc00H00?nc00<000000?ooo`3oool0@@3oool01000ojd000@0003o
[@00okD3003o[@06003o]@00ojd00?n]07]mN`00okD0Ngek0P00ojd01@00
okD00?n]003o[@00ojd00?ne00800?n]00<000@0003o]@0010000P00ojd0
1@00okD00?n]003o[@00ojd00?ne00800?n]00<0Ngek003o]@1kOG/00P00
ojd02@00okD00?n]003o[@00ojd00?ne003o[@0010000?n]00040003003o
[@06003o]@00ojd00?n]003o[@00okD0Ngek0P00ojd01@1kOG/00?n]003o
[@00ojd00?ne00<00?n]00D00?ne00040000ojd000@0003o]@03003o[@09
003o]@00ojd00?n]003o[@00okD0Ngek003o[@1kOG/00?ne00<00?n]00D0
0?ne003o[@00ojd00?n]00040002003o[@0300040000okD00?n]00800?n]
00T00?ne003o[@00ojd00?n]07]mN`00ojd0Ngek003o[@00okD00`00ojd0
1`00okD00?n]003o[@0010000?ne003o[@0010009P3oool00840oooo00<0
00000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00
ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003o
ool0oooo0440oooo07L00?ne003o[@0010000?n]003o]@00ojd00?ne003o
[@00okD0Ngek003o]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd00?ne
003o[@00okD000@0003o]@00ojd00?ne00040000okD00?n]003o]@00ojd0
0?ne003o[@00okD0Ngek003o]@00ojd00?ne07]mN`00okD00?n]003o]@00
ojd00?ne003o[@0010000?n]003o]@00ojd000@0003o[@00okD00?n]003o
]@00ojd00?ne003o[@1kOG/00?n]003o]@00ojd0Ngek003o[@00okD00?n]
003o]@00ojd00?ne00040000okD00?n]003o]@0010000?ne003o[@00okD0
0?n]003o]@00ojd00?ne07]mN`00okD00?n]003o]@1kOG/00?ne003o[@00
okD00?n]003o]@00ojd000@0003o[@00okD00?n]003o]@0010000?ne003o
[@00okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]07]mN`00ojd00?ne
003o[@00okD00?n]003o]@00ojd000@0003o[@00okD00?n]0004000U0?oo
o`00P@3oool00`000000oooo0?ooo`0@0?ooo`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00L00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00
ok<01P00ok<00`0000000?nc003o/`07003o/`0307moO`00ok<00?nc00H0
0?nc00<000000?ooo`3oool0@@3oool01P00ojd00?ne003o[@0010000?n]
003o]@800?n]00<0Ngek003o]@00ojd00P00ojd01@00okD0Ngek003o[@00
ojd00?ne00800?n]00<000@0003o]@00ojd00P00ojd01@00okD000@0003o
[@00ojd00?ne00800?n]00<0Ngek003o]@00ojd00P00ojd02@00okD0Ngek
003o[@00ojd00?ne003o[@0010000?n]003o]@03003o[@0900040000ojd0
0?n]003o[@00okD00?n]07]mN`00ojd00?ne00<00?n]00H0Ngek003o[@00
ojd00?n]003o]@001002003o[@05003o]@00ojd00?n]00040000okD00`00
ojd01@00okD0Ngek003o[@00ojd00?ne00800?n]00<0Ngek003o]@00ojd0
0P00ojd01@0010000?n]003o[@00ojd00?ne00800?n]00<000@0003o]@00
ojd00P00ojd02@1kOG/00?n]003o[@00ojd00?ne003o[@1kOG/00?n]003o
]@03003o[@0700040000ojd00?n]003o[@00okD00?n]0004000T0?ooo`00
P@3oool00`000000oooo0?ooo`0@0?oooed0Ogmo@`3oool0:@00okD00?n]
003o]@00ojd000@0003o[@00okD0Ngek003o]@00ojd00?ne003o[@00okD0
0?n]003o]@1kOG/00?ne003o[@00okD000@0003o]@00ojd00?ne003o[@00
okD00?n]003o]@0010000?ne003o[@00okD0Ngek003o]@00ojd00?ne003o
[@00okD00?n]003o]@1kOG/00?ne008000@000X00?n]003o]@00ojd00?ne
003o[@00okD00?n]00040000ojd00?ne0P1kOG/0@P00ojd00?ne003o[@00
okD00?n]003o]@00ojd0Ngek003o[@00okD000@0003o]@00ojd00?ne003o
[@00okD00?n]003o]@0010000?ne003o[@00okD0Ngek003o]@00ojd00?ne
003o[@00okD00?n]003o]@1kOG/00?ne003o[@0010000?n]003o]@00ojd0
0?ne003o[@00okD00?n]003o]@0010000?ne003o[@1kOG/00?n]003o]@00
ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne003o[@0010000?n]003o
]@00ojd00?ne003o[@00okD00?n]000402<0oooo00210?ooo`030000003o
ool0oooo0100oooo00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o
/`06003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00
ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00L00?nc00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?oo
o`110?ooo`<00?n]00D00?ne003o[@001000Ngek003o]@03003o[@09003o
]@00ojd00?n]003o[@00okD0Ngek003o[@0010000?ne00<00?n]00T00?ne
003o[@00ojd00?n]003o]@0010000?n]07]mN`00okD00`00ojd01P00okD0
0?n]003o[@00ojd00?ne000400800?n]00D00?ne003o[@00ojd00?n]003o
]@03003o[@050004001kOG/00?n]003o[@00okD00`00ojd01P00okD00?n]
003o[@00ojd0Ngek000400800?n]00D00?ne003o[@00ojd00?n]003o]@02
003o[@8000@000@0Ngek003o[@00ojd00?ne0`00ojd01P00okD00?n]003o
[@1kOG/00?ne000400800?n]00D00?ne003o[@00ojd00?n]003o]@02003o
[@030004001kOG/00?n]00800?n]00T00?ne003o[@00ojd00?n]003o]@00
ojd0Ngek003o[@0010000`00ojd01`00okD00?n]003o[@00ojd00?ne003o
[@0010008P3oool00840oooo00<000000?ooo`3oool0403oool00`000000
0?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`07003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01P00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01`00ok<00`1oOgl0
0?nc003o/`06003o/`030000003oool0oooo0440oooo07/00?ne003o[@00
okD00?n]003o]@1kOG/000@0003o[@00okD00?n]003o]@00ojd00?ne003o
[@00okD00?n]003o]@0010000?ne003o[@00okD00?n]003o]@00ojd00?ne
003o[@00okD00?n]003o]@1kOG/00?ne003o[@00okD00?n]003o]@00ojd0
0?ne003o[@00okD000@0003o]@1kOG/00?ne003o[@00okD00?n]003o]@00
ojd00?ne003o[@00okD0Ngek00040000ojd00?ne003o[@00okD00?n]003o
]@00ojd00?ne003o[@00okD000@007]mN`00ojd00?ne003o[@00okD00?n]
003o]@00ojd00?ne003o[@00okD0Ngek00040000ojd00?ne003o[@00okD0
0?n]003o]@00ojd00?ne003o[@00okD000@0003o]@00ojd00?ne003o[@00
okD00?n]003o]@00ojd00?ne003o[@1kOG/000@0003o]@00ojd00?ne003o
[@00okD00?n]003o]@00ojd00?ne003o[@0010000?n]003o]@00ojd00?ne
003o[@00okD00?n]003o]@00ojd00?ne07]mN`0010008@3oool00840oooo
00<000000?ooo`3oool0403oool00`0000000?nc003o/`06003o/`0307mo
O`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc
003o/`07003o/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<0
1P00ok<00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc
00<00000003o/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000
003oool0oooo0440oooo00X00?n]003o]@00ojd00?n]07]mN`00okD00?n]
00040000ojd00?ne0`00ojd01P00okD00?n]0004000010000?ne07]mN`80
0?n]00H00?ne003o[@00ojd00?n]003o]@00ojd207]mN`05003o]@001000
0?n]003o[@00okD00`00ojd01P00okD000@0003o[@00ojd00?ne07]mN`80
0?n]00H00?ne003o[@00ojd00?n]003o]@1kOG/2003o[@0500040000ojd0
0?n]003o[@00okD00`00ojd01@00okD000@0003o[@00ojd0Ngek00<00?n]
00@00?ne003o[@00ojd00?n]0P1kOG/2003o[@0500040000ojd00?n]003o
[@00okD00`00ojd01@00okD000@0003o[@1kOG/00?ne00<00?n]00<00?ne
003o[@00ojd00P1kOG/2003o[@0300040000okD00?n]00800?n]00T00?ne
003o[@00ojd00?n]00040000ojd0Ngek003o[@00okD00`00ojd01`00okD0
0?n]07]mN`1kOG/00?ne003o[@001000803oool00840oooo00<000000?oo
o`3oool0403oool00`0000000?nc003o/`06003o/`0307moO`00ok<00?nc
00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`07003o
/`0300000000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01P00ok<00`00
00000?nc003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o
/`00ok<01`00ok<00`1oOgl00?nc003o/`06003o/`030000003oool0oooo
0440oooo01<00?ne003o[@00okD0Ngek003o]@00ojd00?ne003o[@001000
0?n]003o]@00ojd00?ne003o[@0010000?n]003o]@00ojd00?ne0080Ngek
06P00?n]003o]@00ojd00?ne003o[@1kOG/00?n]003o]@00ojd00?ne0004
0000okD00?n]003o]@00ojd00?ne00040000okD00?n]003o]@00ojd00?ne
07]mN`00okD00?n]003o]@00ojd00?ne07]mN`00okD00?n]003o]@00ojd0
00@0003o[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]003o]@00
ojd0Ngek003o[@00okD00?n]003o]@00ojd0Ngek003o[@00okD00?n]003o
]@00ojd000@0003o[@00okD00?n]003o]@00ojd00?ne00040000okD00?n]
003o]@1kOG/00?ne003o[@00okD00?n]003o]@1kOG/00?ne003o[@00okD0
0?n]003o]@0010000?ne003o[@00okD00?n]003o]@00ojd000@0003o[@00
okD00?n]07]mN`00ojd00?ne003o[@00okD00?n]07]mN`00ojd00?ne003o
[@00okD00?n]000401l0oooo00210?ooo`030000003oool0oooo0100oooo
00<00000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`030000
0000ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc
003o/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<0
1P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc
00<0Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`800?n]
00<0Ngek003o]@00ojd00P00ojd02@00okD00?n]00040000ojd00?ne003o
[@0010000?n]003o]@03003o[@09003o]@00ojd0Ngek003o[@00okD00?n]
07]mN`00ojd00?ne00<00?n]00H00?ne00040000ojd00?n]003o]@001002
003o[@06003o]@00ojd00?n]003o[@00okD0Ngek0P00ojd01@00okD0Ngek
003o[@00ojd00?ne00<00?n]0P001002003o[@05003o]@0010000?n]003o
[@00okD00`00ojd01@1kOG/00?n]003o[@00ojd0Ngek00<00?n]00D00?ne
003o[@00ojd00?n]00040003003o[@05003o]@0010000?n]003o[@00okD0
0P00ojd01P1kOG/00?ne003o[@00ojd0Ngek003o]@<00?n]00D00?ne003o
[@00ojd000@0003o]@03003o[@0=00040000ojd00?n]003o[@00okD00?n]
07]mN`00ojd00?ne003o[@1kOG/00?n]003o]@03003o[@03003o]@00ojd0
00@001h0oooo00210?ooo`030000003oool0oooo0100oooo00<00000003o
/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc
00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o
/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1o
Ogl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o
/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`1B003o]@1kOG/00?ne
003o[@00okD00?n]003o]@00ojd00?ne003o[@0010000?n]00040000ojd0
0?ne003o[@00okD00?n]003o]@00ojd00?ne003o[@1kOG/00?n]07]mN`00
ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD000@0003o
]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00okD0Ngek
003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne00040000okD0
00@0003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek003o[@1k
OG/00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0003o
[@8000@001D00?ne003o[@00okD00?n]003o]@00ojd00?ne07]mN`00okD0
Ngek003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd00?ne00040000
okD00P0010005000ojd00?ne003o[@00okD00?n]003o]@00ojd0Ngek003o
[@1kOG/00?n]003o]@00ojd00?ne003o[@00okD00?n]003o]@00ojd000@0
7@3oool007/0oooo0`0000030?ooo`030000003oool0oooo0100oooo00<0
0000003o/`00ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000
ok<00?nc00H00?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o
/`06003o/`0307moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00
ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0
Ogmo003o/`00ok<01P00ok<00`000000oooo0?ooo`110?ooo`0307]mN`00
okD00?n]00800?n]00T00?ne003o[@00ojd00?n]003o]@00ojd000@0003o
[@00okD00`00ojd02@00okD00?n]003o[@00ojd00?ne003o[@1kOG/00?n]
003o]@03003o[@06003o]@00ojd00?n]003o[@00okD000@00P00ojd01@00
okD00?n]003o[@00ojd00?ne00<00?n]00D00?ne07]mN`00ojd00?n]003o
]@03003o[@06003o]@00ojd00?n]003o[@00okD000@00P00ojd01@00okD0
0?n]003o[@00ojd00?ne00<00?n]00D0Ngek003o[@00ojd00?n]003o]@03
003o[@05003o]@00ojd00?n]003o[@0010000`00ojd01@00okD00?n]003o
[@00ojd00?ne00800?n]00<0Ngek003o]@00ojd00P00ojd01@00okD00?n]
003o[@00ojd00?ne00800?n]00<000@0003o]@00ojd00P00ojd02@00okD0
0?n]003o[@00ojd00?ne003o[@1kOG/00?n]003o]@03003o[@07003o]@00
ojd00?n]003o[@00okD00?n]0004000L0?ooo`00N`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0100oooo00<00000003o/`00
ok<01P00ok<00`1oOgl00?nc003o/`06003o/`0300000000ok<00?nc00H0
0?nc00<0Ogmo003o/`00ok<01`00ok<00`0000000?nc003o/`06003o/`03
07moO`00ok<00?nc00H00?nc00<00000003o/`00ok<01P00ok<00`1oOgl0
0?nc003o/`06003o/`0300000000ok<00?nc00L00?nc00<0Ogmo003o/`00
ok<01P00ok<00`000000oooo0?ooo`3M0?ooo`00N`3oool010000000oooo
0?ooo`0000020?ooo`8000004@3ooomM00000=l0oooo001k0?ooo`<00000
o`3ooomC0?ooo`00O03oool00`000000oooo0?ooo`3o0?oooe80oooo001l
0?ooo`<00000o`3ooomB0?ooo`00o`3ooooA0?ooo`00o`3ooooA0?ooo`00
O`3oool200000?l0oooo6`3oool2000403<0oooo00200?ooo`030000003o
ool0oooo0?l0oooo6@3oool2000403<0oooo00210?ooo`030000003oool0
oooo0?l0oooo5`3oool010001000oooo0?ooo`00100b0?ooo`00P03oool0
0`000000oooo0000003o0?oooaL0oooo0P0010020?ooo`8000@0<@3oool0
07l0oooo00@000000?ooo`3oool00000o`3ooom>0?ooo`00OP3oool30000
00030?ooo`00000000000?l0ooooC@3oool00?l0ooood@3oool00?l0oooo
d@3oool00?l0ooood@3oool00?l0ooood@3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{464, 155},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\tFigure 2.11",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The the linear transformation  ",
  Cell[BoxData[
      \(w = \((\(-1\) + \[ImaginaryI])\) z\  - \ 2 + 3  \[ImaginaryI]\)]],
  ".  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Graphics for Complex Functions",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexGraphicsBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Mobius - Bilinear Transformation",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/MobiusTranformationBib.\
html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{994, 632},
WindowMargins->{{5, Automatic}, {Automatic, 2}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 546072, 10312}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 118, 2, 33, "Text"],
Cell[2223, 66, 98, 2, 33, "Text"],
Cell[2324, 70, 594, 9, 90, "Text"],
Cell[2921, 81, 123, 2, 33, "Text"],
Cell[3047, 85, 1344, 50, 71, "Text"],
Cell[4394, 137, 668, 15, 71, "Text"],
Cell[5065, 154, 307, 5, 52, "Text"],
Cell[5375, 161, 1507, 48, 280, "Text"],
Cell[6885, 211, 31450, 518, 241, 31336, 514, "GraphicsData", "Bitmap", "Text",
  
  Evaluatable->False],
Cell[38338, 731, 234, 8, 33, "Text"],
Cell[38575, 741, 255, 10, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[38855, 755, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[39008, 761, 343, 16, 33, "Text",
  Evaluatable->False],
Cell[39354, 779, 535, 11, 210, "Input"],
Cell[39892, 792, 324, 13, 33, "Text",
  Evaluatable->False],
Cell[40219, 807, 695, 13, 210, "Input"],
Cell[40917, 822, 312, 13, 33, "Text",
  Evaluatable->False],
Cell[41232, 837, 1033, 21, 250, "Input"],
Cell[42268, 860, 369, 13, 33, "Text",
  Evaluatable->False],
Cell[42640, 875, 795, 15, 170, "Input"]
}, Closed]],
Cell[43450, 893, 105, 3, 30, "Text"],
Cell[43558, 898, 1869, 45, 297, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[45452, 947, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[45615, 953, 52, 0, 33, "Text"],
Cell[45670, 955, 998, 19, 345, "Input"],
Cell[46671, 976, 50, 0, 33, "Text"],
Cell[46724, 978, 1442, 23, 491, "Input"],
Cell[48169, 1003, 238, 8, 33, "Text"],
Cell[48410, 1013, 1290, 24, 340, "Input"],
Cell[49703, 1039, 1443, 28, 377, "Input"]
}, Closed]],
Cell[51161, 1070, 1257, 35, 144, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[52443, 1109, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[52606, 1115, 52, 0, 33, "Text"],
Cell[52661, 1117, 1301, 24, 440, "Input"],
Cell[53965, 1143, 50, 0, 33, "Text"],
Cell[54018, 1145, 1493, 24, 461, "Input"],
Cell[55514, 1171, 238, 8, 33, "Text"],
Cell[55755, 1181, 1541, 29, 360, "Input"]
}, Closed]],
Cell[57311, 1213, 1004, 32, 128, "Text"],
Cell[58318, 1247, 1232, 30, 188, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[59575, 1281, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[59738, 1287, 35, 0, 33, "Text"],
Cell[59776, 1289, 1469, 29, 465, "Input"],
Cell[61248, 1320, 238, 8, 33, "Text"],
Cell[61489, 1330, 1557, 30, 360, "Input"]
}, Closed]],
Cell[63061, 1363, 1163, 35, 163, "Text"],
Cell[64227, 1400, 2420, 58, 449, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[66672, 1462, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[66835, 1468, 35, 0, 33, "Text"],
Cell[66873, 1470, 2022, 40, 417, "Input"]
}, Closed]],
Cell[68910, 1513, 1057, 33, 106, "Text"],
Cell[69970, 1548, 1463, 33, 261, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[71458, 1585, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[71621, 1591, 35, 0, 33, "Text"],
Cell[71659, 1593, 1762, 34, 377, "Input"],
Cell[73424, 1629, 238, 8, 33, "Text"],
Cell[73665, 1639, 1347, 25, 340, "Input"],
Cell[75015, 1666, 1240, 25, 307, "Input"]
}, Closed]],
Cell[76270, 1694, 1401, 43, 201, "Text",
  Evaluatable->False],
Cell[77674, 1739, 2007, 81, 90, "Text"],
Cell[79684, 1822, 52504, 864, 307, 52390, 860, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[132191, 2688, 467, 23, 33, "Text"],
Cell[132661, 2713, 1697, 63, 90, "Text"],
Cell[134361, 2778, 1557, 50, 90, "Text"],
Cell[135921, 2830, 8913, 149, 122, 8799, 145, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[144837, 2981, 219, 8, 33, "Text"],
Cell[145059, 2991, 417, 12, 33, "Text"],
Cell[145479, 3005, 7953, 133, 122, 7839, 129, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[153435, 3140, 158, 5, 33, "Text"],
Cell[153596, 3147, 2660, 92, 183, "Text"],
Cell[156259, 3241, 1154, 47, 52, "Text"],
Cell[157416, 3290, 1178, 50, 223, "Text"],
Cell[158597, 3342, 923, 31, 93, "Text",
  Evaluatable->False],
Cell[159523, 3375, 609, 20, 52, "Text"],

Cell[CellGroupData[{
Cell[160157, 3399, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[160320, 3405, 1095, 20, 275, "Input"]
}, Closed]],
Cell[161430, 3428, 379, 6, 49, "Text"],
Cell[161812, 3436, 3546, 105, 335, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[165383, 3545, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[165546, 3551, 122, 5, 33, "Text"],
Cell[165671, 3558, 794, 15, 230, "Input"],
Cell[166468, 3575, 108, 5, 33, "Text"],
Cell[166579, 3582, 1689, 36, 450, "Input"],
Cell[168271, 3620, 120, 5, 33, "Text"],
Cell[168394, 3627, 1177, 20, 290, "Input"],
Cell[169574, 3649, 264, 11, 33, "Text"]
}, Closed]],
Cell[169853, 3663, 1131, 27, 201, "Text"],
Cell[170987, 3692, 33734, 557, 241, 33598, 552, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[204724, 4251, 403, 15, 33, "Text"],
Cell[205130, 4268, 1604, 39, 204, "Text"],
Cell[206737, 4309, 49913, 821, 249, 49799, 817, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[256653, 5132, 276, 10, 33, "Text"],
Cell[256932, 5144, 2094, 49, 378, "Text",
  Evaluatable->False],
Cell[259029, 5195, 26241, 433, 200, 26127, 429, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[285273, 5630, 506, 16, 52, "Text"],

Cell[CellGroupData[{
Cell[285804, 5650, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[285967, 5656, 1266, 24, 240, "Input"]
}, Closed]],
Cell[287248, 5683, 1012, 26, 204, "Text"],
Cell[288263, 5711, 257, 9, 33, "Text"],
Cell[288523, 5722, 1425, 46, 150, "Text"],
Cell[289951, 5770, 454, 16, 33, "Text",
  Evaluatable->False],
Cell[290408, 5788, 1390, 36, 224, "Text"],
Cell[291801, 5826, 850, 31, 128, "Text"],
Cell[292654, 5859, 711, 23, 55, "Text"],
Cell[293368, 5884, 77432, 1272, 169, 77318, 1268, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[370803, 7158, 241, 8, 33, "Text"],

Cell[CellGroupData[{
Cell[371069, 7170, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[371232, 7176, 138, 5, 33, "Text"],
Cell[371373, 7183, 779, 15, 230, "Input"],
Cell[372155, 7200, 47, 0, 33, "Text"],
Cell[372205, 7202, 1542, 33, 450, "Input"],
Cell[373750, 7237, 177, 7, 33, "Text",
  Evaluatable->False],
Cell[373930, 7246, 517, 10, 170, "Input"],
Cell[374450, 7258, 262, 10, 33, "Text",
  Evaluatable->False],
Cell[374715, 7270, 1323, 24, 290, "Input"],
Cell[376041, 7296, 305, 11, 33, "Text"]
}, Closed]],
Cell[376361, 7310, 632, 11, 68, "Text"],
Cell[376996, 7323, 316, 9, 33, "Text"],
Cell[377315, 7334, 2627, 68, 278, "Text",
  Evaluatable->False],
Cell[379945, 7404, 61894, 1018, 169, 61780, 1014, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[441842, 8424, 269, 9, 33, "Text"],

Cell[CellGroupData[{
Cell[442136, 8437, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[442300, 8443, 175, 6, 33, "Text"],
Cell[442478, 8451, 648, 13, 150, "Input"],
Cell[443129, 8466, 172, 6, 33, "Text"],
Cell[443304, 8474, 703, 15, 210, "Input"],
Cell[444010, 8491, 167, 5, 33, "Text"],
Cell[444180, 8498, 439, 11, 130, "Input"],
Cell[444622, 8511, 414, 13, 33, "Text",
  Evaluatable->False],
Cell[445039, 8526, 1569, 31, 376, "Input"],
Cell[446611, 8559, 621, 17, 52, "Text"]
}, Closed]],
Cell[447247, 8579, 1202, 36, 230, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[448474, 8619, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[448638, 8625, 44, 0, 33, "Text"],
Cell[448685, 8627, 824, 17, 230, "Input"],
Cell[449512, 8646, 92, 2, 33, "Text"],
Cell[449607, 8650, 1323, 29, 390, "Input"],
Cell[450933, 8681, 118, 5, 33, "Text"],
Cell[451054, 8688, 613, 14, 190, "Input"],
Cell[451670, 8704, 70, 0, 33, "Text"],
Cell[451743, 8706, 501, 10, 170, "Input"],
Cell[452247, 8718, 267, 10, 33, "Text",
  Evaluatable->False],
Cell[452517, 8730, 1391, 26, 290, "Input"],
Cell[453911, 8758, 325, 11, 33, "Text"]
}, Closed]],
Cell[454251, 8772, 89510, 1470, 166, 89396, 1466, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[543764, 10244, 256, 8, 33, "Text"],
Cell[544023, 10254, 290, 7, 33, "Text"],
Cell[544316, 10263, 303, 7, 33, "Text"],
Cell[544622, 10272, 306, 7, 33, "Text"],
Cell[544931, 10281, 257, 5, 33, "Text"],
Cell[545191, 10288, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

