(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    469558,      11270]*)
(*NotebookOutlinePosition[    470373,      11300]*)
(*  CellTagsIndexPosition[    470295,      11294]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[{
  StyleBox["2.2  The Mappings ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      StyleBox[\(w = z\^n\),
        FontWeight->"Bold"]],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" and ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      StyleBox[\(w = z\^\(1/n\)\),
        FontWeight->"Bold"]],
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "\n\tIn this section we turn our attention to power functions.  For ",
  Cell[BoxData[
      \(z = r\ \[ExponentialE]\^\[ImaginaryI]\[Theta]\)]],
  ", we can express the function ",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^2\)\)]],
  " in polar coordinates by \n\n\t\t\t",
  Cell[BoxData[
      \(w = \(f \((z)\) = \(z\^2 = \(r\^2\) \[ExponentialE]\^\[ImaginaryI]2\
\[Theta]\)\)\)]],
  ".  \n\nIf we also use polar coordinates for ",
  Cell[BoxData[
      \(w = \[Rho]\ \[ExponentialE]\^\[ImaginaryI]\[Phi]\)]],
  " in the w -plane, we can express this mapping by the system of equations \n\
\n\t\t\t",
  Cell[BoxData[
      \(\[Rho] = \(r\^2\ \ and\ \ \[Phi] = 2  \[Theta]\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t",
  "Because an argument of the product (z)(z) is twice an argument of z, we \
say that f doubles angles at the origin. Points that lie on the ray ",
  " ",
  Cell[BoxData[
      \(r > 0\)]],
  ", ",
  Cell[BoxData[
      \(\[Theta] = \[Alpha]\)]],
  "  are mapped onto points that lie on the ray  ",
  Cell[BoxData[
      \(\[Rho] > 0\)]],
  " , ",
  Cell[BoxData[
      \(\[Phi] = 2  \[Alpha]\)]],
  ".  If we now restrict the domain of ",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^2\)\)]],
  " to the region  \n\n\t\t\t",
  Cell[BoxData[
      \(A = {r\ \(\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\) : \ 
              r > 0\ and\ \(-\[Pi]\)\/2 < \ \[Theta] \[LessEqual] \[Pi]\/2\)}\
\)]],
  ",  \n\nthen the image of A under the mapping ",
  Cell[BoxData[
      \(w = z\^2\)]],
  " can be described by the set  \n\n\t\t\t",
  Cell[BoxData[
      \(B = {\[Rho]\ \(\(\[ExponentialE]\^\[ImaginaryI]\[Phi]\) : \ \[Rho] > 
                0\ and\  - \[Pi] < \ \[Phi] \[LessEqual] \[Pi]\)}\)]],
  ",   \n\nwhich consists of all points in the w-plane except the point w=0."
}], "Text"],

Cell[TextData[{
  "\tThe inverse mapping of f, which we shall denote by g, is then\n\n\t\t\t\
",
  Cell[BoxData[
      \(z = \(g \((w)\) = \(w\^\(1/2\) = \(\[Rho]\^\(1/
                    2\)\) \[ExponentialE]\^\(\[ImaginaryI]\[Phi]/2\)\)\)\)]],
  ", \n\nwhere  ",
  Cell[BoxData[
      \(w \[Element] B\)]],
  ".  That is\n\n\t\t\t",
  Cell[BoxData[
      \(z = \(g \((w)\) = \(w\^\(1/2\) = \(\(|\)\(w\)\( | \^\(1/
                    2\)\)\(\[ExponentialE]\^\(\[ImaginaryI]Arg \((w)\)/
                      2\)\)\)\)\)\)]],
  ", \n\nwhere  ",
  Cell[BoxData[
      \(w \[NotEqual] 0\)]],
  ".  The function g is so important that we call special attention to it \
with a formal definition."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 2.1 (Principal ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Square Root",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/SquareRoot.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[" Function).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]],
  "The function",
  StyleBox[" \n\n\t\t\t",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(z = \(g \((w)\) = \(w\^\(1/2\) = \(\(|\)\(w\)\( | \^\(1/
                    2\)\)\(\[ExponentialE]\^\(\[ImaginaryI]Arg \((w)\)/
                      2\)\)\)\)\)\)]],
  ",    for   ",
  Cell[BoxData[
      \(w \[NotEqual] 0\)]],
  ".  \n\nis called the principal square root function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIt is left as an exercise to show that f and g satisfy equations g(f(z))=z \
and f(g(w))=w, and thus are inverses of each other that map the set A \
one-to-one and onto the set B and the set B one-to-one and onto the set A, \
respectively. Figure 2.12. illustrates this relationship. \
\>", "Text"],

Cell[TextData[{
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.309017 0.309017 [
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 10 6.28125 ]
[.5 .64303 -8 0 ]
[.5 .64303 8 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 .30902 m
.5 -0.30902 L
.75882 -0.28796 L
.5 .30902 L
F
0 .5 .95 r
.5 .30902 m
.75882 -0.28796 L
1 -0.22622 L
.5 .30902 L
F
0 .9 1 r
.5 .30902 m
1 -0.22622 L
1.20711 -0.128 L
.5 .30902 L
F
1 0 0 r
.5 .30902 m
1.20711 -0.128 L
1.36603 0 L
.5 .30902 L
F
.9 .45 .45 r
.5 .30902 m
1.36603 0 L
1.46593 .14906 L
.5 .30902 L
F
1 .75 .75 r
.5 .30902 m
1.46593 .14906 L
1.5 .30902 L
.5 .30902 L
F
0 1 0 r
.5 .30902 m
1.5 .30902 L
1.46593 .46898 L
.5 .30902 L
F
0 .95 0 r
.5 .30902 m
1.46593 .46898 L
1.36603 .61803 L
.5 .30902 L
F
.45 .95 .45 r
.5 .30902 m
1.36603 .61803 L
1.20711 .74603 L
.5 .30902 L
F
1 .5 0 r
.5 .30902 m
1.20711 .74603 L
1 .84425 L
.5 .30902 L
F
1 .6 0 r
.5 .30902 m
1 .84425 L
.75882 .90599 L
.5 .30902 L
F
1 1 0 r
.5 .30902 m
.75882 .90599 L
.5 .92705 L
.5 .30902 L
F
0 0 0 r
.5 Mabswid
0 .30902 m
1 .30902 L
s
.01 w
.5 .30902 m
.5 .61803 L
s
[ .025 .025 ] 0 setdash
.5 .30902 m
.5 0 L
s
0 g
gsave
1 .32447 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47 .63348 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oQP3oool2
00000280003o9`00Oo<f003VoaT0o`0000260?ooo`8000008@000?lW001olcH00>Ko6P3o000008H0
oooo0P00000Q0000obH007oc=@00i_lL0?l00000QP3oool200000200003o9`00Oo<c003Voah0o`00
00270?ooob40003o9P00Oo<c003Voal0o`0000270?ooob00003o9P00Oo<b003Vob40o`0000270?oo
ob00003o9@00Oo<a003Vob<0o`0000270?ooob00003o9000Oo<a003Vob@0o`0000260?ooo`800000
7P000?lT001olc000>Ko9P3o000008H0oooo0P00000N0000ob<007oc<000i_lW0?l00000QP3oool2
000001d0003o8`00Oo<_003VobT0o`0000260?ooo`8000007@000?lR001olbh00>Ko:`3o000008H0
oooo0P00000L0000ob8007oc;P00i_l/0?l00000QP3oool2000001`0003o8@00Oo<]003Vobh0o`00
00260?ooo`80000070000?lP001olbd00>Ko;`3o000008H0oooo0P00000K0000ob0007oc;000i_la
0?l00000QP3oool2000001/0003o7`00Oo<[003Voc<0o`0000270?oooa/0003o7`00Oo<[003Voc@0
o`0000270?oooa/0003o7P00Oo<Z003VocH0o`0000270?oooaX0003o7`00Oo<X003VocP0o`000027
0?oooaX0003o7P00Oo<X003VocT0o`0000260?ooo`8000006@000?lM001olbL00>Ko>`3o000008H0
oooo0P00000H0000oad007oc9`00i_ll0?l00000QP3oool2000001P0003o7000Oo<V003Voch0o`00
00260?ooo`8000005`000?lL001olbD00>Ko@03o000008H0oooo0P00000G0000oa/007oc9@00i_m0
0?l00040iW=c00260?ooo`8000005P000?lK001olb@00>Ko?`3o00040>IcL`00QP3oool2000001H0
003o6P00Oo<T003Vocd0o`001`3VLg<008H0oooo0P00000E0000oaX007oc8`00i_ll0?l000X0iW=c
00270?oooaH0003o6@00Oo<R003Voc/0o`003@3VLg<008L0oooo5P000?lH001olb800>Ko>P3o000?
0>IcL`00Q`3ooolE0000oaP007oc8@00i_li0?l00180iW=c00270?oooaD0003o5`00Oo<P003VocP0
o`005@3VLg<008L0oooo50000?lG001olb000>Ko=P3o000H0>IcL`00QP3oool2000001<0003o5`00
Oo<N003VocD0o`006`3VLg<008H0oooo0P00000B0000oaL007oc7P00i_ld0?l001d0iW=c00260?oo
o`8000004P000?lF001olad00>Ko<`3o000P0>IcL`00QP3oool200000180003o5@00Oo<L003Voc80
o`008`3VLg<008H0oooo0P00000A0000oaD007oc7000i_l`0?l002H0iW=c00260?ooo`8000004@00
0?lD001ola/00>Ko;`3o000Y0>IcL`00QP3oool200000100003o5000Oo<K003Vobh0o`00:`3VLg<0
08H0oooo0P00000@0000oa<007oc6P00i_l]0?l002h0iW=c00270?oooa00003o4`00Oo<I003Vob`0
o`00<@3VLg<008L0oooo40000?lB001olaT00>Ko:P3o000d0>IcL`00Q`3oool@0000oa4007oc6000
i_lY0?l003L0iW=c00270?ooo`l0003o4@00Oo<G003VobT0o`00>@3VLg<008L0oooo3`000?l@001o
laL00>Ko9`3o000l0>IcL`00QP3oool2000000d0003o4000Oo<F003VobH0o`00?`3VLg<008H0oooo
0P00000=0000o`l007oc5P00i_lT0?l00480iW=c00260?ooo`80000030000?l@001ola@00>Ko8`3o
00150>IcL`00QP3oool2000000`0003o3`00Oo<C003Vob<0o`00A`3VLg<008H0oooo0P00000<0000
o`h007oc4`00i_lQ0?l004X0iW=c00260?ooo`8000002`000?l>001ola800>Ko803o001=0>IcL`00
QP3oool2000000/0003o3@00Oo<B003Voah0o`00D03VLg<008H0oooo0P00000:0000o`d007oc4@00
i_lM0?l00540iW=c0P3o_kl008L0oooo2`000?l<001ola000>Ko7@3o001=0>IcL`P0okno00270?oo
o`X0003o3000Oo<@003Voa/0o`00BP3VLg<>0?no_`00Q`3oool:0000o`/007oc3`00i_lJ0?l004L0
iW=c503o_kl008L0oooo2P000?l:001ol`h00>Ko6@3o00140>IcLaX0okno00260?ooo`8000002000
0?l:001ol`h00>Ko5`3o00110>IcLb00okno00260?ooo`80000020000?l9001ol`d00>Ko5`3o000m
0>IcLbH0okno00260?ooo`8000001`000?l9001ol`d00>Ko5@3o000j0>IcLb`0okno00260?ooo`80
00001`000?l8001ol``00>Ko503o000g0>IcLc80okno00260?ooo`8000001P000?l8001ol`/00>Ko
4`3o000d0>IcLcP0okno00260?ooo`8000001P000?l8001ol`X00>Ko4@3o000a0>IcLch0okno0026
0?ooo`8000001P000?l7001ol`T00>Ko4@3o000]0>IcLd@0okno00260?ooo`8000001@000?l7001o
l`T00>Ko3`3o000Z0>IcLdX0okno00260?ooo`8000001@000?l6001ol`P00>Ko3P3o000W0>IcLe00
okno00270?ooo`D0003o1P00Oo<7003Vo`d0o`00903VLg=F0?no_`00Q`3oool50000o`D007oc1`00
i_l;0?l00240iW=cG03o_kl008L0oooo10000?l5001ol`H00>Ko2`3o000M0>IcLf80okno00270?oo
o`@0003o1000Oo<5003Vo`X0o`006P3VLg=X0?no_`00QP3oool2000000<0003o0`00Oo<5003Vo`P0
o`005`3VLg=^0?no_`00QP3oool200000080003o0`00Oo<4003Vo`L0o`00503VLg=d0?no_`00QP3o
ool200000080003o0P00Oo<4003Vo`D0o`004@3VLg=j0?no_`00QP3oool2000000030000o`00Oo<0
07oc00<00>Ko1@3o000=0>IcLh00okno00260?ooo`80000000@0003o001ol`00i_l00>Ko103o000:
0>IcLhH0okno00260?ooo`80000000<007oc003Vo`00i_l00P3o00070>IcLh`0okno00260?ooo`80
000000<00>Ko0?l0003VLg<00`3VLg>B0?no_`001`3ooooo000000800000603o_kl008H0oooo0P00
00000`3oO`00Lo=c003c0003003c09800?l000260?ooo`80000000<0oiT00?mo003oO`000P1clg<7
003c07`00?l00P000002003o008000002P00o`0008H0oooo0P000000103oo`00oiT00?mo003oO`04
07?cL`X00?<0M`00o`00100000000?l0003o0000000;003o0000QP3oool2000000030?oo003oV@00
oiT000<0ogl01@1clg<=003c07800?l00P00000<003o0000QP3oool200000080ool00P3oV@040?mo
00D0Lo=c4@00l`1/003o008000003000o`0008H0oooo0P0000020?oo00<0oiT0103oO`0707?cLaD0
0?<0I000o`00100000000?l0003o0000000;003o0000QP3oool2000000<0ool00`3oV@050?mo00P0
Lo=c6000l`1M003o008000000P00o`02000000X00?l000260?ooo`8000000`3oo`040?nI00H0ogl0
2@1clg<K003c06L00?l000260?ooo`8000000`3oo`050?nI00H0ogl02`1clg<N003c06400?l00026
0?ooo`800000103oo`050?nI00L0ogl02`1clg<R003c05/00?l000260?ooo`800000103oo`060?nI
00L0ogl03@1clg<U003c05D00?l000260?ooo`8000001@3oo`060?nI00P0ogl03P1clg<Y003c04h0
0?l000260?ooo`8000001@3oo`070?nI00T0ogl03`1clg</003c04P00?l000260?ooo`8000001P3o
o`070?nI00T0ogl04@1clg<_003c04800?l000260?ooo`8000001P3oo`080?nI00X0ogl04@1clg<c
003c03`00?l000260?ooo`8000001P3oo`090?nI00/0ogl04P1clg<f003c03H00?l000260?ooo`80
00001`3oo`080?nI00`0ogl0501clg<i003c03000?l000260?ooo`8000001`3oo`090?nI00d0ogl0
5@1clg<m003c02T00?l000260?ooo`800000203oo`090?nI00d0ogl05`1clg=0003c02<00?l00026
0?ooo`800000203oo`0:0?nI00h0ogl05`1clg=4003c01d00?l000260?ooo`8000002@3oo`0:0?nI
00l0ogl0601clg=7003c01L00?l000260?ooo`8000002@3oo`0;0?nI00l0ogl06P1clg=:003c0140
0?l000260?ooo`8000002@3oo`0<0?nI0100ogl06`1clg=>003c00X00?l000260?ooo`8000002P3o
o`0<0?nI0140ogl0701clg=A003c00@00?l000260?ooo`8000002P3oo`0=0?nI0140ogl07@1clg=C
003c0000QP3oool2000000/0ool03@3oV@0B0?mo01h0Lo=cD000l`0008H0oooo0P00000;0?oo00h0
oiT04`3oO`0O07?cLdd00?<000260?ooo`800000303oo`0>0?nI01<0ogl08@1clg=:003c0000QP3o
ool2000000`0ool03`3oV@0D0?mo0280Lo=cA`00l`0008H0oooo0P00000=0?oo00l0oiT0503oO`0S
07?cLdD00?<000260?ooo`8000003@3oo`0@0?nI01D0ogl0901clg=2003c0000QP3oool2000000d0
ool04@3oV@0F0?mo02D0Lo=c?`00l`0008H0oooo0P00000>0?oo0140oiT05P3oO`0W07?cLc`00?<0
00260?ooo`8000003P3oo`0A0?nI01P0ogl0:01clg<i003c0000QP3oool2000000l0ool04@3oV@0I
0?mo02P0Lo=c=`00l`0008H0oooo0P00000?0?oo0180oiT06@3oO`0Z07?cLc@00?<000260?ooo`80
0000403oo`0B0?nI01X0ogl0:`1clg<a003c0000QP3oool200000100ool04`3oV@0J0?mo02d0Lo=c
;P00l`0008H0oooo0P00000@0?oo01@0oiT06`3oO`0^07?cLb/00?<000260?ooo`8000004@3oo`0D
0?nI01`0ogl0;P1clg<Y003c0000QP3oool200000140ool05@3oV@0L0?mo0300Lo=c9P00l`0008H0
oooo0P00000B0?oo01D0oiT07@3oO`0a07?cLb<00?<000260?ooo`8000004P3oo`0F0?nI01h0ogl0
<P1clg<P003c0000QP3oool2000001<0ool05P3oV@0N0?mo03@0Lo=c7@00l`0008H0oooo0P00000C
0?oo01L0oiT07`3oO`0d07?cLa/00?<000260?ooo`8000004`3oo`0H0?nI0200ogl0=@1clg<H003c
0000QP3oool2000001@0ool0603oV@0P0?mo03L0Lo=c5@00l`0008H0oooo0P00000D0?oo01T0oiT0
8@3oO`0h07?cLa800?<000260?ooo`8000005@3oo`0I0?nI0240ogl0>P1clg<?003c0000QP3oool2
000001D0ool06P3oV@0R0?mo03X0Lo=c3@00l`0008H0oooo0P00000F0?oo01T0oiT0903oO`0k07?c
L`X00?<000260?ooo`8000005P3oo`0J0?nI02@0ogl0?@1clg<7003c0000QP3oool2000001L0ool0
6P3oV@0U0?mo03h0Lo=c1000l`0008H0oooo0P00000G0?oo01/0oiT09P3oO`0o07?cL`400?<00026
0?ooo`8000005`3oo`0L0?nI02H0ogl0?`1clg<008H0oooo0P00000H0?oo01`0oiT09`3oO`0m07?c
L`00QP3oool2000001P0ool07@3oV@0W0?mo03`0Lo=c00260?ooo`8000006@3oo`0M0?nI02P0ogl0
>P1clg<008H0oooo0P00000I0?oo01h0oiT0:@3oO`0h07?cL`00QP3oool2000001X0ool07P3oV@0Y
0?mo03L0Lo=c00260?ooo`8000006P3oo`0O0?nI02X0ogl0=@1clg<008H0oooo0P00000J0?oo0200
oiT0:`3oO`0c07?cL`00QP3oool2000001/0ool0803oV@0[0?mo0380Lo=c00260?ooo`8000006`3o
o`0Q0?nI02`0ogl0<01clg<008H0oooo0P00000L0?oo0240oiT0;03oO`0_07?cL`00QP3oool20000
01`0ool08P3oV@0]0?mo02d0Lo=c00260?ooo`8000007@3oo`0R0?nI02h0ogl0:`1clg<008H0oooo
0P00000M0?oo0280oiT0;`3oO`0Z07?cL`00QP3oool2000001d0ool08`3oV@0`0?mo02P0Lo=c0026
0?ooo`8000007P3oo`0S0?nI0340ogl09P1clg<008H0oooo0P00000N0?oo02@0oiT0<@3oO`0U07?c
L`00QP3oool2000001l0ool0903oV@0b0?mo02<0Lo=c00260?ooo`8000007`3oo`0U0?nI03<0ogl0
8@1clg<008H0oooo0P00000P0?oo02D0oiT0<`3oO`0P07?cL`00QP3oool200000200ool09P3oV@0d
0?mo01h0Lo=c00260?ooo`800000803oo`0W0?nI03@0ogl07@1clg<008H0oooo0P00000Q0?oo02L0
oiT0=@3oO`0K07?cL`00QP3oool200000240ool0:03oV@0f0?mo01T0Lo=c00260?ooo`8000008P3o
o`0X0?nI03H0ogl0601clg<008H0oooo0P00000R0?oo02T0oiT0=`3oO`0F07?cL`00Q`3ooolT0?oo
02T0oiT0>03oO`0D07?cL`00Q`3ooolT0?oo02X0oiT0>03oO`0C07?cL`00Q`3ooolU0?oo02X0oiT0
>@3oO`0A07?cL`00Q`3ooolU0?oo02/0oiT0>@3oO`0@07?cL`00Q`3oool20?oo00@000007`3oo`0[
0?nI03/0ogl03P1clg<008L0oooo103oo`000`000000ool00?oo000O0?oo02/0oiT0?03oO`0<07?c
L`00Q`3oool40?oo00030000003oo`00ool001l0ool0;03oV@0l0?mo00/0Lo=c00270?ooo`@0ool0
0P00000Q0?oo02`0oiT0?@3oO`0907?cL`00Q`3oool30?oo00030000003oo`0000000240ool0;@3o
V@0n0?mo00L0Lo=c00270?ooo`<0ool000@000000?oo003oo`0000008@3oo`0]0?nI03h0ogl01P1c
lg<008L0oooo0P3oo`001@000000ool00?oo003oo`0000000240ool0;P3oV@0o0?mo00@0Lo=c0027
0?ooo`050?oo0000000000000000003oo`000`00000P0?oo02l0oiT0@03oO`0207?cL`00Q`3ooolY
0?oo02l0oiT0@03oO`0107?cL`00Q`3ooolY0?oo0300oiT0@03oO`0008L0oooo:P3oo`0`0?nI03l0
ogl000270?ooobX0ool0<@3oV@0n0?mo0000Q`3oool[0?oo0340oiT0?@3oO`000001\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1, -1, 0, 0}}],
  StyleBox["       ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.309017 0.309017 [
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 10 6.28125 ]
[.5 .64303 -8 0 ]
[.5 .64303 8 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 .30902 m
-0.5 .30902 L
-0.36603 0 L
.5 .30902 L
F
0 .5 .95 r
.5 .30902 m
-0.36603 0 L
0 -0.22622 L
.5 .30902 L
F
0 .9 1 r
.5 .30902 m
0 -0.22622 L
.5 -0.30902 L
.5 .30902 L
F
1 0 0 r
.5 .30902 m
.5 -0.30902 L
1 -0.22622 L
.5 .30902 L
F
.9 .45 .45 r
.5 .30902 m
1 -0.22622 L
1.36603 0 L
.5 .30902 L
F
1 .75 .75 r
.5 .30902 m
1.36603 0 L
1.5 .30902 L
.5 .30902 L
F
0 1 0 r
.5 .30902 m
1.5 .30902 L
1.36603 .61803 L
.5 .30902 L
F
0 .95 0 r
.5 .30902 m
1.36603 .61803 L
1 .84425 L
.5 .30902 L
F
.45 .95 .45 r
.5 .30902 m
1 .84425 L
.5 .92705 L
.5 .30902 L
F
1 .5 0 r
.5 .30902 m
.5 .92705 L
0 .84425 L
.5 .30902 L
F
1 .6 0 r
.5 .30902 m
0 .84425 L
-0.36603 .61803 L
.5 .30902 L
F
1 1 0 r
.5 .30902 m
-0.36603 .61803 L
-0.5 .30902 L
.5 .30902 L
F
0 0 0 r
.5 Mabswid
0 .30902 m
1 .30902 L
s
.5 .30902 m
.5 .61803 L
s
.5 .30902 m
.5 0 L
s
0 g
gsave
1 .32447 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47 .63348 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003o?P00Oo=9
003Vo`030000003o0000o`0004L0o`00C`3VLg<003l007ocB000i_l00`000000o`000?l000160?l0
0500iW=c0010001oldL00>Ko00<000000?l0003o0000A@3o001A0>IcL`00@000Oo=7003Vo`030000
003o0000o`0004D0o`00D@3VLg<0044007ocAP00i_l00`000000o`000?l000140?l00580iW=c0012
001oldD00>Ko00<000000?l0003o0000@`3o001C0>IcL`00@`00Oo=4003Vo`030000003o0000o`00
0480o`00E03VLg<004@007oc@`00i_l00`000000o`000?l000110?l005D0iW=c0015001old800>Ko
00<000000?l0003o0000@03o001F0>IcL`00AP00Oo=1003Vo`030000003o0000o`0003l0o`00E`3V
Lg<004L007oc@000i_l00`000000o`000?l0000n0?l005P0iW=c0018001olcl00>Ko00<000000?l0
003o0000?@3o001I0>IcL`00B@00Oo<n003Vo`030000003o0000o`0003`0o`00FP3VLg<004X007oc
?@00i_l00`000000o`000?l0000k0?l005/0iW=c001;001olc`00>Ko00<000000?l0003o0000>P3o
001L0>IcL`00C000Oo<k003Vo`030000003o0000o`0003T0o`00G@3VLg<004d007oc>P00i_l00`00
0000o`000?l0000h0?l005h0iW=c001>001olcT00>Ko00<000000?l0003o0000=`3o001O0>IcL`00
C`00Oo<h003Vo`030000003o0000o`0003H0o`00H03VLg<004l007oc>000i_l00`000000o`000?l0
000f0?l00600iW=c001@001olcL00>Ko00<000000?l0003o0000=@3o001Q0>IcL`00D@00Oo<f003V
o`030000003o0000o`0003@0o`00HP3VLg<0058007oc=@00i_l00`000000o`000?l0000c0?l006<0
iW=c001C001olc@00>Ko00<000000?l0003o0000<P3o001T0>IcL`00E000Oo<c003Vo`030000003o
0000o`000340o`00I@3VLg<005D007oc<P00i_l00`000000o`000?l0000`0?l006D0iW=c0@3o_kl0
05H007oc<@00i_l00`000000o`000?l0000_0?l006<0iW=c103o_kl005L007oc<000i_l00`000000
o`000?l0000^0?l00640iW=c1`3o_kl005P007oc;`00i_l00`000000o`000?l0000]0?l005l0iW=c
2P3o_kl005T007oc;P00i_l00`000000o`000?l0000/0?l005d0iW=c3@3o_kl005X007oc;@00i_l0
0`000000o`000?l0000[0?l005`0iW=c3`3o_kl000030000o`00Oo<007oc05P007oc;000i_l00`00
0000o`000?l0000Z0?l005X0iW=c4P3o_kl000<0003oF@00Oo<[003Vo`030000003o0000o`0002T0
o`00F03VLg<E0?no_`001P000?mG001olbX00>Ko00<000000?l0003o0000:03o001F0>IcLaP0okno
00090000oe@007oc:P00i_l00`000000o`000?l0000X0?l005<0iW=c6`3o_kl000`0003oDP00Oo<Y
003Vo`030000003o0000o`0002L0o`00DP3VLg<M0?no_`003`000?m@001olbP00>Ko00<000000?l0
003o00009P3o001@0>IcLb00okno000A0000odl007oc9`00i_l00`000000o`000?l0000U0?l004h0
iW=c8`3o_kl001@0003oC@00Oo<V003Vo`030000003o0000o`0002@0o`00C03VLg<V0?no_`005`00
0?m;001olbD00>Ko00<000000?l0003o00008`3o001:0>IcLbT0okno000J0000odT007oc9000i_l0
0`000000o`000?l0000R0?l004T0iW=c:`3o_kl001d0003oA`00Oo<S003Vo`030000003o0000o`00
0240o`00A`3VLg<^0?no_`0080000?m5001olb800>Ko00<000000?l0003o0000803o00150>IcLc40
okno000R0000od@007oc8@00i_l00`000000o`000?l0000O0?l004<0iW=c=03o_kl002D0003o@P00
Oo<P003Vo`030000003o0000o`0001h0o`00@@3VLg<g0?no_`00:0000?m0001olal00>Ko00<00000
0?l0003o00007@3o00100>IcLcT0okno000[0000och007oc7P00i_l00`000000o`000?l0000L0?l0
03h0iW=c?03o_kl002h0003o?000Oo<M003Vo`030000003o0000o`0001/0o`00?03VLg<o0?no_`00
<0000?lk001ola`00>Ko00<000000?l0003o00006P3o000j0>IcLd80okno000c0000ocP007oc7000
i_l00`000000o`000?l0000J0?l003L0iW=cA@3o_kl003H0003o=P00Oo<K003Vo`030000003o0000
o`0001T0o`00=P3VLg=70?no_`00>@000?ld001olaX00>Ko00<000000?l0003o0000603o000d0>Ic
LdX0okno000l0000oc8007oc6@00i_l00`000000o`000?l0000G0?l00380iW=cC@3o_kl003h0003o
<@00Oo<H003Vo`030000003o0000o`0001H0o`00<03VLg=@0?no_`00@@000?l_001olaL00>Ko00<0
00000?l0003o00005@3o000^0>IcLe<0okno00140000obd007oc5P00i_l00`000000o`000?l0000D
0?l002d0iW=cE@3o_kl004L0003o:`00Oo<E003Vo`030000003o0000o`0001<0o`00:`3VLg=H0?no
_`00BP000?lY001ola@00>Ko00<000000?l0003o00004P3o000Y0>IcLe/0okno001<0000obP007oc
4`00i_l00`000000o`000?l0000A0?l002L0iW=cGP3o_kl004l0003o9P00Oo<B003Vo`030000003o
0000o`000100o`009@3VLg=Q0?no_`00DP000?lT001ola400>Ko00<000000?l0003o00003`3o000T
0>IcLf<0okno001E0000ob8007oc4000i_l00`000000o`000?l0000>0?l00280iW=cIP3o_kl005P0
003o8000Oo<?003Vo`030000003o0000o`0000d0o`00803VLg=Y0?no_`00F`000?lN001ol`h00>Ko
00<000000?l0003o0000303o000N0>IcLf`0okno001M0000oa`007oc3P00i_l00`000000o`000?l0
000<0?l001/0iW=cK`3o_kl00600003o6P00Oo<=003Vo`030000003o0000o`0000/0o`006P3VLg=a
0?no_`00H`000?lH001ol``00>Ko00<000000?l0003o00002P3o000H0>IcLg@0okno001V0000oaH0
07oc2`00i_l00`000000o`000?l000090?l001H0iW=cM`3o_kl006T0003o5000Oo<:003Vo`030000
003o0000o`0000P0o`00503VLg=j0?no_`00J`000?lC001ol`T00>Ko00<000000?l0003o00001`3o
000B0>IcLgd0okno001^0000oa4007oc2000i_l00`000000o`000?l000060?l00140iW=cO`3o_kl0
0740003o3`00Oo<7003Vo`030000003o0000o`0000D0o`003`3VLg>20?no_`00M0000?l=001ol`H0
0>Ko00<000000?l0003o0000103o000=0>IcLhD0okno001g0000o`/007oc1@00i_l00`000000o`00
0?l000030?l000/0iW=cR03o_kl007T0003o2P00Oo<4003Vo`030000003o0000o`000080o`002@3V
Lg>;0?no_`00O0000?l8001ol`<00>Ko00@000000?l0003o0000o`00203VLg>=0?no_`00O`000?l6
001ol`800>Ko00<000000?l0003o00001P3VLg>@0?no_`00PP000?l4001ol`03003Vo`000000o`00
00@0iW=cT`3o_kl008D0003o0P00Oo<00`000000iW=c0>IcL`2F0?no_`001`000?oo000000800000
603o_kl008D0ool00P3oV@000`0000000?<0003c002F003o0000PP3oo`040?nI00030?mo00000000
Lo=c00@00?<0Q@00o`0200000003003o00000000000000T00?l0001o0?oo00H0oiT00P3oO`000`00
0000Lo=c07?cL`06003c08400?l000<00000003o0000o`000P00000:003o0000O03oo`080?nI00<0
ogl000@0000007?cL`1clg<0Lo=c2000l`1n003o000500000000o`000?l0003o000000002P00o`00
07T0ool02P3oV@040?mo00030000001clg<0Lo=c0080Lo=c2@00l`1l003o000500000000o`000?l0
003o000000002P00o`0007L0ool02`3oV@050?mo00030000001clg<0Lo=c00<0Lo=c2`00l`1i003o
000500000000o`000?l0003o000000002P00o`0007@0ool03@3oV@060?mo00030000001clg<0Lo=c
00@0Lo=c3@00l`1e003o008000000P00o`02000000X00?l0001a0?oo00l0oiT01`3oO`000`000000
Lo=c07?cL`0507?cL`l00?<0PP00o`0006h0ool04@3oV@080?mo00030000001clg<0Lo=c00H0Lo=c
4@00l`1o003o0000J`3oo`0C0?nI00T0ogl000<0000007?cL`1clg<01`1clg<B003c07d00?l0001Y
0?oo01@0oiT02P3oO`000`000000Lo=c07?cL`0807?cLa@00?<0NP00o`0006H0ool05P3oV@0;0?mo
00030000001clg<0Lo=c00T0Lo=c5P00l`1g003o0000H`3oo`0H0?nI00`0ogl000<0000007?cL`1c
lg<02P1clg<H003c07@00?l0001P0?oo01X0oiT03@3oO`000`000000Lo=c07?cL`0;07?cLaX00?<0
L@00o`0005d0ool0703oV@0>0?mo00030000001clg<0Lo=c00`0Lo=c6`00l`1_003o0000F`3oo`0M
0?nI00l0ogl000<0000007?cL`1clg<03@1clg<M003c06`00?l0001H0?oo01l0oiT0403oO`000`00
0000Lo=c07?cL`0=07?cLb000?<0J@00o`0005D0ool08P3oV@0@0?mo00030000001clg<0Lo=c00h0
Lo=c8P00l`1V003o0000DP3oo`0T0?nI0140ogl000<0000007?cL`1clg<03`1clg<T003c06<00?l0
001?0?oo02H0oiT04P3oO`000`000000Lo=c07?cL`0@07?cLbD00?<0H@00o`0004`0ool0:03oV@0C
0?mo00030000001clg<0Lo=c0140Lo=c9`00l`1N003o0000BP3oo`0Y0?nI01@0ogl000<0000007?c
L`1clg<04P1clg<Y003c05/00?l000170?oo02/0oiT05@3oO`000`000000Lo=c07?cL`0C07?cLb/0
0?<0F000o`0004@0ool0;@3oV@0F0?mo00030000001clg<0Lo=c01@0Lo=c;@00l`1E003o0000@@3o
o`0_0?nI01L0ogl000<0000007?cL`1clg<05@1clg<^003c05<00?l0000n0?oo0340oiT0603oO`00
0`000000Lo=c07?cL`0F07?cLc000?<0D000o`0003`0ool0<P3oV@0I0?mo00030000001clg<0Lo=c
01L0Lo=c<P00l`1=003o0000>@3oo`0d0?nI01X0ogl000<0000007?cL`1clg<0601clg<d003c04X0
0?l0000f0?oo03H0oiT06`3oO`000`000000Lo=c07?cL`0I07?cLcH00?<0A`00o`0003<0ool0>03o
V@0L0?mo00030000001clg<0Lo=c01X0Lo=c=`00l`15003o0000<03oo`0j0?nI01d0ogl000<00000
07?cL`1clg<06`1clg<i003c04800?l0000^0?oo03/0oiT07P3oO`000`000000Lo=c07?cL`0L07?c
Lc/00?<0?`00o`0002/0ool0?@3oV@0O0?mo00030000001clg<0Lo=c01d0Lo=c?@00l`0l003o0000
:03oo`0o0?nI0200ogl000<0000007?cL`1clg<07@1clg=0003c03T00?l0000U0?oo0480oiT0803o
O`000`000000Lo=c07?cL`0N07?cLd400?<0=`00o`000280ool0A03oV@0Q0?mo00030000001clg<0
Lo=c01l0Lo=c@`00l`0d003o0000803oo`150?nI0280ogl000<0000007?cL`1clg<0801clg=5003c
03400?l0000M0?oo04L0oiT08`3oO`000`000000Lo=c07?cL`0Q07?cLdL00?<0;P00o`0001X0ool0
B@3oV@0T0?mo00030000001clg<0Lo=c0280Lo=cB@00l`0[003o00005`3oo`1;0?nI02D0ogl000<0
000007?cL`1clg<08`1clg=:003c02T00?l0000D0?oo04d0oiT09P3oO`000`000000Lo=c07?cL`0T
07?cLd`00?<09P00o`000140ool0C`3oV@0W0?mo00030000001clg<0Lo=c02D0Lo=cCP00l`0S003o
00003`3oo`1@0?nI02P0ogl000<0000007?cL`1clg<09P1clg=@003c02000?l0000<0?oo0580oiT0
:@3oO`000`000000Lo=c07?cL`0W07?cLe800?<07@00o`0000T0ool0E03oV@0Z0?mo00030000001c
lg<0Lo=c02P0Lo=cD`00l`0K003o00001P3oo`1F0?nI02/0ogl000<0000007?cL`1clg<0:@1clg=E
003c01P00?l000030?oo05P0oiT0;03oO`000`000000Lo=c07?cL`0Z07?cLeL00?<05@00o`000003
0?oo003oV@00oiT005L0oiT0;@3oO`000`000000Lo=c07?cL`0[07?cLeT00?<04P00o`0005T0oiT0
;P3oO`000`000000Lo=c07?cL`0/07?cLe/00?<03`00o`0005P0oiT0;`3oO`000`000000Lo=c07?c
L`0]07?cLe`00?<03@00o`0005L0oiT0<03oO`000`000000Lo=c07?cL`0]07?cLel00?<02P00o`00
05L0oiT0<03oO`000`000000Lo=c07?cL`0^07?cLf400?<01`00o`0005H0oiT0<@3oO`000`000000
Lo=c07?cL`0_07?cLf<00?<01000o`0005D0oiT0<P3oO`000`000000Lo=c07?cL`0`07?cLfD00?<0
0@00o`0005@0oiT0<`3oO`000`000000Lo=c07?cL`0a07?cLfD00?<0001C0?nI03@0ogl000<00000
07?cL`1clg<0<P1clg=T003c0000DP3oV@0e0?mo00030000001clg<0Lo=c03<0Lo=cH`00l`000540
oiT0=P3oO`000`000000Lo=c07?cL`0d07?cLf800?<0001@0?nI03L0ogl000<0000007?cL`1clg<0
=@1clg=Q003c0000C`3oV@0h0?mo00030000001clg<0Lo=c03H0Lo=cH000l`0004h0oiT0>@3oO`00
0`000000Lo=c07?cL`0g07?cLel00?<0001=0?nI03X0ogl000<0000007?cL`1clg<0>01clg=N003c
0000C03oV@0k0?mo00030000001clg<0Lo=c03T0Lo=cG@00l`0004/0oiT0?03oO`000`000000Lo=c
07?cL`0j07?cLe`00?<0001:0?nI03d0ogl000<0000007?cL`1clg<0>`1clg=K003c0000B@3oV@0n
0?mo00030000001clg<0Lo=c03`0Lo=cFP00l`0004P0oiT0?`3oO`000`000000Lo=c07?cL`0m07?c
LeT00?<000170?nI0400ogl000<0000007?cL`1clg<0?@1clg=I003c0000A`3oV@100?mo00030000
001clg<0Lo=c03h0Lo=cF000l`0004H0oiT0@@3oO`000`000000Lo=c07?cL`0o07?cLeL00?<00015
0?nI0480ogl000<0000007?cL`1clg<0@01clg=F003c0000A03oV@130?mo00030000001clg<0Lo=c
0440Lo=cE@00l`0004<0oiT0A03oO`000`000000Lo=c07?cL`1207?cLe@00?<000120?nI04D0ogl0
00<0000007?cL`1clg<0@`1clg=C003c0000@@3oV@160?mo00030000001clg<0Lo=c04@0Lo=cDP00
l`000400oiT0A`3oO`000`000000Lo=c07?cL`1507?cLe400?<0000o0?nI04P0ogl000<0000007?c
L`1clg<0AP1clg=@003c0000?P3oV@190?mo00030000001clg<0Lo=c04L0Lo=cC`00l`0003d0oiT0
BP3oO`000`000000Lo=c07?cL`1807?cLdh00?<0000l0?nI04/0ogl0C01clg==003c0000>`3oV@1<
0?mo04d0Lo=cC000l`0003X0oiT0C@3oO`1>07?cLd/00?<0000i0?nI04h0ogl0C`1clg=:003c0000
>03oV@1?0?mo0500Lo=cB@00l`0003L0oiT0D03oO`1@07?cLdT00?<0000g0?nI0500ogl0D@1clg=8
003c0000=P3oV@1A0?mo00@0Lo=c00<0000007?cL`1clg<0B`1clg=7003c0000=@3oV@1B0?mo00<0
Lo=c00<0000007?cL`000000C@1clg=6003c0000=03oV@1C0?mo00<0Lo=c00<0000007?cL`000000
CP1clg=5003c0000<`3oV@1D0?mo0080Lo=c00D0000007?cL`1clg<0Lo=c0000001>07?cLd@00?<0
000b0?nI05D0ogl00P1clg<01@000000Lo=c07?cL`1clg<0000004l0Lo=c@`00l`000340oiT0EP3o
O`001@1clg<00000000000000000Lo=c00<00000C`1clg=2003c0000<03oV@1G0?mo05P0Lo=c@@00
l`0002l0oiT0F03oO`1I07?cLd000?<0000^0?nI05T0ogl0FP1clg<o003c0000;@3oV@1J0?mo05/0
Lo=c?P00l`0002`0oiT0F`3oO`1L07?cLcd00?<00000\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1, -1, 0, 0}}],
  StyleBox["  \n\t\tFigure 2.12",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The mapping   ",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^2\)\)]],
  "   (and  ",
  Cell[BoxData[
      \(z = \(g \((w)\) = w\^\(1/2\)\)\)]],
  ").  "
}], "Text"],

Cell[TextData[{
  "\tWhat are the images of rectangles under the mapping ",
  Cell[BoxData[
      \(w = z\^2\)]],
  "?  To find out, we make use of the Cartesian form  \n\n\t\t\t",
  Cell[BoxData[
      \(w = \(u + \[ImaginaryI]\ v = \(f \((z)\) = z\^2\)\)\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\(x\^2 - 
            y\^2 + \[ImaginaryI]\ 2\ x\ y\)\(=\)\(\ \)\)\)\)\)]],
  Cell[BoxData[
      \(\((x\^2 - y\^2, 2\ x\ y)\) = \((u, v)\)\)]],
  "\n\nand the resulting system of equations  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(u = x\^2 - y\^2\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["  ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"v", "=", 
        RowBox[{"2", " ", "x", " ", 
          RowBox[{"y", " ", 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "   "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 2.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^2\)\)]],
  ",  usually maps vertical and horizontal lines onto parabolas and use this \
fact to find the image of the rectangle ",
  Cell[BoxData[
      \(R = {\((x, y)\) : \ 0 < x < a, 0 < y < b}\)]],
  ".  ",
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Find the image of the vertical line  ",
  Cell[BoxData[
      \(x = a\)]],
  ".  ",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Find the image of the horizontal line  ",
  Cell[BoxData[
      \(y = b\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  Using the above equations, we determine that the vertical line  \
",
  Cell[BoxData[
      \(x = a\)]],
  "  is mapped onto the set of points given by the equations  ",
  Cell[BoxData[
      \(u = a\^2 - y\^2\)]],
  "  and  ",
  Cell[BoxData[
      \(v = 2\ a\ y\)]],
  ".  If  ",
  Cell[BoxData[
      \(a\  \[NotEqual] 0\)]],
  ",  then  ",
  Cell[BoxData[
      \(y = v\/\(2\ a\)\)]],
  "  and  \n\n\t\t\t",
  Cell[BoxData[
      \(u\  = \ a\^2\  - \ v\^2\/\(4\ a\^2\)\)]],
  ",  \n\nthis equation represents a parabola with vertex at  ",
  Cell[BoxData[
      \(\((a\^2, 0)\)\)]],
  ",  oriented horizontally, and opening to the left.  If  ",
  Cell[BoxData[
      \(a\  > 0\)]],
  ",  the set  ",
  Cell[BoxData[
      \({\((u, v)\) : \ u = a\^2 - y\^2, v = 2  a\ y}\)]],
  "  has  ",
  Cell[BoxData[
      \(v > 0\)]],
  "  precisely when  ",
  Cell[BoxData[
      \(y > 0\)]],
  ",  so the part of the line  ",
  Cell[BoxData[
      \(x = a\)]],
  "  lying above the x axis is mapped to the top half of the parabola.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe horizontal line  ",
  Cell[BoxData[
      \(y = b\)]],
  "  is mapped onto the parabola given by the equations  ",
  Cell[BoxData[
      \(u = x\^2 - b\^2\)]],
  "  and   ",
  Cell[BoxData[
      \(v = 2\ \ x\ b\)]],
  ".  If  ",
  Cell[BoxData[
      \(b\  \[NotEqual] 0\)]],
  ",  then as before we get  \n\n\t\t\t",
  Cell[BoxData[
      \(v\  = \ \(-\ b\^2\)\  + \ v\^2\/\(4\ b\^2\)\)]],
  ",   \n\nthis equation represents a parabola with vertex at  ",
  Cell[BoxData[
      \(\(-\ b\^2\)\)]],
  ",  oriented horizontally and opening to the right.  If  ",
  Cell[BoxData[
      \(b\  > 0\)]],
  ",  the part of the line  ",
  Cell[BoxData[
      \(y = b\)]],
  "  to the right of the y axis is mapped to the top half of the parabola \
because the set  ",
  Cell[BoxData[
      \({\((u, v)\) : \ u = x\^2 - b\^2, v = 2  b\ x}\)]],
  "  has  ",
  Cell[BoxData[
      \(v > 0\)]],
  " precisely when  ",
  Cell[BoxData[
      \(x > 0\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tQuadrant I is mapped onto quadrants I and II by  ",
  Cell[BoxData[
      \(w = z\^2\)]],
  ",  so the rectangle  ",
  Cell[BoxData[
      \(R = {\((x, y)\) : \ 0 < x < a, 0 < y < b}\)]],
  "  is mapped onto the region bounded by the top halves of the parabolas \
given by ",
  Cell[BoxData[
      \(u = a\^2 - v\^2\/\(4\ a\^2\)\)]],
  " and ",
  Cell[BoxData[
      \(v = \(-\ b\^2\) + v\^2\/\(4\ b\^2\)\)]],
  " and the ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " axis. The vertices  ",
  Cell[BoxData[
      RowBox[{
      "0", ",", \(a\^2\), ",", \(a\^2 + 2\ \[ImaginaryI]\ a\ b - b\^2\), ",", 
        " ", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "-", \(b\^2\)}]}]]],
  "  of the rectangle are mapped onto the four points ",
  Cell[BoxData[
      RowBox[{
      "0", ",", \(a\^2\), ",", \(a\^2 - b\^2 + 2\ \[ImaginaryI]\ a\ b\), ",", 
        " ", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "-", \(b\^2\)}]}]]],
  ",  respectively, as indicated in Figure 2.13."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tFinally, we can easily verify that the vertical line  ",
  Cell[BoxData[
      \({\((0, y)\) : \ \(-\[Infinity]\) < y < \[Infinity]}\)]],
  "  is mapped to the set ",
  Cell[BoxData[
      \({\((\(-\ y\^2\), 0)\) : \ \(-\[Infinity]\) < y < \[Infinity]}\)]],
  ".  This is simply the set of non-positive real numbers.  Similarly, the \
horizontal line  ",
  Cell[BoxData[
      \({\((x, 0)\) : \ \(-\[Infinity]\) < x < \[Infinity]}\)]],
  "  is mapped to the set ",
  Cell[BoxData[
      \({\((x\^2, 0)\) : \ \(-\[Infinity]\) < x < \[Infinity]}\)]],
  ", which is the set of non-negative real numbers."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 3.14286 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0714286 1.42857 0.142857 1.42857 [
[.42857 .13036 -11.0938 -20.125 ]
[.42857 .13036 11.0938 0 ]
[.78571 .13036 -11.0938 -20.125 ]
[.78571 .13036 11.0938 0 ]
[1.025 .14286 0 -6.28125 ]
[1.025 .14286 10 6.28125 ]
[.05893 1.57143 -16 -6.28125 ]
[.05893 1.57143 0 6.28125 ]
[.05893 3 -16 -6.28125 ]
[.05893 3 0 6.28125 ]
[.07143 3.16786 -5 0 ]
[.07143 3.16786 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 3.14286 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.42857 .14286 m
.42857 .14911 L
s
gsave
.42857 .13036 -72.0938 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.063 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.063 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
81.188 17.063 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.78571 .14286 m
.78571 .14911 L
s
gsave
.78571 .13036 -72.0938 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.063 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.063 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
81.188 17.063 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .14286 m
1 .14286 L
s
gsave
1.025 .14286 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.07143 1.57143 m
.07768 1.57143 L
s
gsave
.05893 1.57143 -77 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.07143 3 m
.07768 3 L
s
gsave
.05893 3 -77 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.07143 0 m
.07143 3.14286 L
s
gsave
.07143 3.16786 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 3.14286 L
0 3.14286 L
closepath
clip
newpath
.5 .165 .165 r
.5 Mabswid
.07143 .14286 m
.07143 .25876 L
.07143 .38517 L
.07143 .50388 L
.07143 .61805 L
.07143 .73958 L
.07143 .85656 L
.07143 .98089 L
.07143 1.10068 L
.07143 1.21593 L
.07143 1.33853 L
.07143 1.45658 L
.07143 1.57008 L
.07143 1.69095 L
.07143 1.80726 L
.07143 1.93093 L
.07143 2.05006 L
.07143 2.16464 L
.07143 2.28658 L
.07143 2.40396 L
.07143 2.52871 L
.07143 2.64891 L
.07143 2.76456 L
.07143 2.88757 L
.07143 3 L
s
1 0 1 r
.25 .14286 m
.25 .25876 L
.25 .38517 L
.25 .50388 L
.25 .61805 L
.25 .73958 L
.25 .85656 L
.25 .98089 L
.25 1.10068 L
.25 1.21593 L
.25 1.33853 L
.25 1.45658 L
.25 1.57008 L
.25 1.69095 L
.25 1.80726 L
.25 1.93093 L
.25 2.05006 L
.25 2.16464 L
.25 2.28658 L
.25 2.40396 L
.25 2.52871 L
.25 2.64891 L
.25 2.76456 L
.25 2.88757 L
.25 3 L
s
.5 .165 .165 r
.42857 .14286 m
.42857 .25876 L
.42857 .38517 L
.42857 .50388 L
.42857 .61805 L
.42857 .73958 L
.42857 .85656 L
.42857 .98089 L
.42857 1.10068 L
.42857 1.21593 L
.42857 1.33853 L
.42857 1.45658 L
.42857 1.57008 L
.42857 1.69095 L
.42857 1.80726 L
.42857 1.93093 L
.42857 2.05006 L
.42857 2.16464 L
.42857 2.28658 L
.42857 2.40396 L
.42857 2.52871 L
.42857 2.64891 L
.42857 2.76456 L
.42857 2.88757 L
.42857 3 L
s
1 0 1 r
.60714 .14286 m
.60714 .25876 L
.60714 .38517 L
.60714 .50388 L
.60714 .61805 L
.60714 .73958 L
.60714 .85656 L
.60714 .98089 L
.60714 1.10068 L
.60714 1.21593 L
.60714 1.33853 L
.60714 1.45658 L
.60714 1.57008 L
.60714 1.69095 L
.60714 1.80726 L
.60714 1.93093 L
.60714 2.05006 L
.60714 2.16464 L
.60714 2.28658 L
.60714 2.40396 L
.60714 2.52871 L
.60714 2.64891 L
.60714 2.76456 L
.60714 2.88757 L
.60714 3 L
s
.5 .165 .165 r
.78571 .14286 m
.78571 .25876 L
.78571 .38517 L
.78571 .50388 L
.78571 .61805 L
.78571 .73958 L
.78571 .85656 L
.78571 .98089 L
.78571 1.10068 L
.78571 1.21593 L
.78571 1.33853 L
.78571 1.45658 L
.78571 1.57008 L
.78571 1.69095 L
.78571 1.80726 L
.78571 1.93093 L
.78571 2.05006 L
.78571 2.16464 L
.78571 2.28658 L
.78571 2.40396 L
.78571 2.52871 L
.78571 2.64891 L
.78571 2.76456 L
.78571 2.88757 L
.78571 3 L
s
.07143 .14286 m
.1004 .14286 L
.13201 .14286 L
.16169 .14286 L
.19023 .14286 L
.22061 .14286 L
.24985 .14286 L
.28094 .14286 L
.31089 .14286 L
.3397 .14286 L
.37035 .14286 L
.39986 .14286 L
.42824 .14286 L
.45845 .14286 L
.48753 .14286 L
.51845 .14286 L
.54823 .14286 L
.57687 .14286 L
.60736 .14286 L
.63671 .14286 L
.66789 .14286 L
.69794 .14286 L
.72686 .14286 L
.75761 .14286 L
.78571 .14286 L
s
1 0 1 r
.07143 .28571 m
.1004 .28571 L
.13201 .28571 L
.16169 .28571 L
.19023 .28571 L
.22061 .28571 L
.24985 .28571 L
.28094 .28571 L
.31089 .28571 L
.3397 .28571 L
.37035 .28571 L
.39986 .28571 L
.42824 .28571 L
.45845 .28571 L
.48753 .28571 L
.51845 .28571 L
.54823 .28571 L
.57687 .28571 L
.60736 .28571 L
.63671 .28571 L
.66789 .28571 L
.69794 .28571 L
.72686 .28571 L
.75761 .28571 L
.78571 .28571 L
s
.5 .165 .165 r
.07143 .42857 m
.1004 .42857 L
.13201 .42857 L
.16169 .42857 L
.19023 .42857 L
.22061 .42857 L
.24985 .42857 L
.28094 .42857 L
.31089 .42857 L
.3397 .42857 L
.37035 .42857 L
.39986 .42857 L
.42824 .42857 L
.45845 .42857 L
.48753 .42857 L
.51845 .42857 L
.54823 .42857 L
.57687 .42857 L
.60736 .42857 L
.63671 .42857 L
.66789 .42857 L
.69794 .42857 L
.72686 .42857 L
.75761 .42857 L
.78571 .42857 L
s
1 0 1 r
.07143 .57143 m
.1004 .57143 L
.13201 .57143 L
.16169 .57143 L
.19023 .57143 L
.22061 .57143 L
.24985 .57143 L
.28094 .57143 L
.31089 .57143 L
.3397 .57143 L
.37035 .57143 L
.39986 .57143 L
.42824 .57143 L
.45845 .57143 L
.48753 .57143 L
.51845 .57143 L
.54823 .57143 L
.57687 .57143 L
.60736 .57143 L
.63671 .57143 L
.66789 .57143 L
.69794 .57143 L
.72686 .57143 L
.75761 .57143 L
.78571 .57143 L
s
.5 .165 .165 r
.07143 .71429 m
.1004 .71429 L
.13201 .71429 L
.16169 .71429 L
.19023 .71429 L
.22061 .71429 L
.24985 .71429 L
.28094 .71429 L
.31089 .71429 L
.3397 .71429 L
.37035 .71429 L
.39986 .71429 L
.42824 .71429 L
.45845 .71429 L
.48753 .71429 L
.51845 .71429 L
.54823 .71429 L
.57687 .71429 L
.60736 .71429 L
.63671 .71429 L
.66789 .71429 L
.69794 .71429 L
.72686 .71429 L
.75761 .71429 L
.78571 .71429 L
s
1 0 1 r
.07143 .85714 m
.1004 .85714 L
.13201 .85714 L
.16169 .85714 L
.19023 .85714 L
.22061 .85714 L
.24985 .85714 L
.28094 .85714 L
.31089 .85714 L
.3397 .85714 L
.37035 .85714 L
.39986 .85714 L
.42824 .85714 L
.45845 .85714 L
.48753 .85714 L
.51845 .85714 L
.54823 .85714 L
.57687 .85714 L
.60736 .85714 L
.63671 .85714 L
.66789 .85714 L
.69794 .85714 L
.72686 .85714 L
.75761 .85714 L
.78571 .85714 L
s
.5 .165 .165 r
.07143 1 m
.1004 1 L
.13201 1 L
.16169 1 L
.19023 1 L
.22061 1 L
.24985 1 L
.28094 1 L
.31089 1 L
.3397 1 L
.37035 1 L
.39986 1 L
.42824 1 L
.45845 1 L
.48753 1 L
.51845 1 L
.54823 1 L
.57687 1 L
.60736 1 L
.63671 1 L
.66789 1 L
.69794 1 L
.72686 1 L
.75761 1 L
.78571 1 L
s
1 0 1 r
.07143 1.14286 m
.1004 1.14286 L
.13201 1.14286 L
.16169 1.14286 L
.19023 1.14286 L
.22061 1.14286 L
.24985 1.14286 L
.28094 1.14286 L
.31089 1.14286 L
.3397 1.14286 L
.37035 1.14286 L
.39986 1.14286 L
.42824 1.14286 L
.45845 1.14286 L
.48753 1.14286 L
.51845 1.14286 L
.54823 1.14286 L
.57687 1.14286 L
.60736 1.14286 L
.63671 1.14286 L
.66789 1.14286 L
.69794 1.14286 L
.72686 1.14286 L
.75761 1.14286 L
.78571 1.14286 L
s
.5 .165 .165 r
.07143 1.28571 m
.1004 1.28571 L
.13201 1.28571 L
.16169 1.28571 L
.19023 1.28571 L
.22061 1.28571 L
.24985 1.28571 L
.28094 1.28571 L
.31089 1.28571 L
.3397 1.28571 L
.37035 1.28571 L
.39986 1.28571 L
.42824 1.28571 L
.45845 1.28571 L
.48753 1.28571 L
.51845 1.28571 L
.54823 1.28571 L
.57687 1.28571 L
.60736 1.28571 L
.63671 1.28571 L
.66789 1.28571 L
.69794 1.28571 L
.72686 1.28571 L
.75761 1.28571 L
.78571 1.28571 L
s
1 0 1 r
.07143 1.42857 m
.1004 1.42857 L
.13201 1.42857 L
.16169 1.42857 L
.19023 1.42857 L
.22061 1.42857 L
.24985 1.42857 L
.28094 1.42857 L
.31089 1.42857 L
.3397 1.42857 L
.37035 1.42857 L
.39986 1.42857 L
.42824 1.42857 L
.45845 1.42857 L
.48753 1.42857 L
.51845 1.42857 L
.54823 1.42857 L
.57687 1.42857 L
.60736 1.42857 L
.63671 1.42857 L
.66789 1.42857 L
.69794 1.42857 L
.72686 1.42857 L
.75761 1.42857 L
.78571 1.42857 L
s
.5 .165 .165 r
.07143 1.57143 m
.1004 1.57143 L
.13201 1.57143 L
.16169 1.57143 L
.19023 1.57143 L
.22061 1.57143 L
.24985 1.57143 L
.28094 1.57143 L
.31089 1.57143 L
.3397 1.57143 L
.37035 1.57143 L
.39986 1.57143 L
.42824 1.57143 L
.45845 1.57143 L
.48753 1.57143 L
.51845 1.57143 L
.54823 1.57143 L
.57687 1.57143 L
.60736 1.57143 L
.63671 1.57143 L
.66789 1.57143 L
.69794 1.57143 L
.72686 1.57143 L
.75761 1.57143 L
.78571 1.57143 L
s
1 0 1 r
.07143 1.71429 m
.1004 1.71429 L
.13201 1.71429 L
.16169 1.71429 L
.19023 1.71429 L
.22061 1.71429 L
.24985 1.71429 L
.28094 1.71429 L
.31089 1.71429 L
.3397 1.71429 L
.37035 1.71429 L
.39986 1.71429 L
.42824 1.71429 L
.45845 1.71429 L
.48753 1.71429 L
.51845 1.71429 L
.54823 1.71429 L
.57687 1.71429 L
.60736 1.71429 L
.63671 1.71429 L
.66789 1.71429 L
.69794 1.71429 L
.72686 1.71429 L
.75761 1.71429 L
.78571 1.71429 L
s
.5 .165 .165 r
.07143 1.85714 m
.1004 1.85714 L
.13201 1.85714 L
.16169 1.85714 L
.19023 1.85714 L
.22061 1.85714 L
.24985 1.85714 L
.28094 1.85714 L
.31089 1.85714 L
.3397 1.85714 L
.37035 1.85714 L
.39986 1.85714 L
.42824 1.85714 L
.45845 1.85714 L
.48753 1.85714 L
.51845 1.85714 L
.54823 1.85714 L
.57687 1.85714 L
.60736 1.85714 L
.63671 1.85714 L
.66789 1.85714 L
.69794 1.85714 L
.72686 1.85714 L
.75761 1.85714 L
.78571 1.85714 L
s
1 0 1 r
.07143 2 m
.1004 2 L
.13201 2 L
.16169 2 L
.19023 2 L
.22061 2 L
.24985 2 L
.28094 2 L
.31089 2 L
.3397 2 L
.37035 2 L
.39986 2 L
.42824 2 L
.45845 2 L
.48753 2 L
.51845 2 L
.54823 2 L
.57687 2 L
.60736 2 L
.63671 2 L
.66789 2 L
.69794 2 L
.72686 2 L
.75761 2 L
.78571 2 L
s
.5 .165 .165 r
.07143 2.14286 m
.1004 2.14286 L
.13201 2.14286 L
.16169 2.14286 L
.19023 2.14286 L
.22061 2.14286 L
.24985 2.14286 L
.28094 2.14286 L
.31089 2.14286 L
.3397 2.14286 L
.37035 2.14286 L
.39986 2.14286 L
.42824 2.14286 L
.45845 2.14286 L
.48753 2.14286 L
.51845 2.14286 L
.54823 2.14286 L
.57687 2.14286 L
.60736 2.14286 L
.63671 2.14286 L
.66789 2.14286 L
.69794 2.14286 L
.72686 2.14286 L
.75761 2.14286 L
.78571 2.14286 L
s
1 0 1 r
.07143 2.28571 m
.1004 2.28571 L
.13201 2.28571 L
.16169 2.28571 L
.19023 2.28571 L
.22061 2.28571 L
.24985 2.28571 L
.28094 2.28571 L
.31089 2.28571 L
.3397 2.28571 L
.37035 2.28571 L
.39986 2.28571 L
.42824 2.28571 L
.45845 2.28571 L
.48753 2.28571 L
.51845 2.28571 L
.54823 2.28571 L
.57687 2.28571 L
.60736 2.28571 L
.63671 2.28571 L
.66789 2.28571 L
.69794 2.28571 L
.72686 2.28571 L
.75761 2.28571 L
.78571 2.28571 L
s
.5 .165 .165 r
.07143 2.42857 m
.1004 2.42857 L
.13201 2.42857 L
.16169 2.42857 L
.19023 2.42857 L
.22061 2.42857 L
.24985 2.42857 L
.28094 2.42857 L
.31089 2.42857 L
.3397 2.42857 L
.37035 2.42857 L
.39986 2.42857 L
.42824 2.42857 L
.45845 2.42857 L
.48753 2.42857 L
.51845 2.42857 L
.54823 2.42857 L
.57687 2.42857 L
.60736 2.42857 L
.63671 2.42857 L
.66789 2.42857 L
.69794 2.42857 L
.72686 2.42857 L
.75761 2.42857 L
.78571 2.42857 L
s
1 0 1 r
.07143 2.57143 m
.1004 2.57143 L
.13201 2.57143 L
.16169 2.57143 L
.19023 2.57143 L
.22061 2.57143 L
.24985 2.57143 L
.28094 2.57143 L
.31089 2.57143 L
.3397 2.57143 L
.37035 2.57143 L
.39986 2.57143 L
.42824 2.57143 L
.45845 2.57143 L
.48753 2.57143 L
.51845 2.57143 L
.54823 2.57143 L
.57687 2.57143 L
.60736 2.57143 L
.63671 2.57143 L
.66789 2.57143 L
.69794 2.57143 L
.72686 2.57143 L
.75761 2.57143 L
.78571 2.57143 L
s
.5 .165 .165 r
.07143 2.71429 m
.1004 2.71429 L
.13201 2.71429 L
.16169 2.71429 L
.19023 2.71429 L
.22061 2.71429 L
.24985 2.71429 L
.28094 2.71429 L
.31089 2.71429 L
.3397 2.71429 L
.37035 2.71429 L
.39986 2.71429 L
.42824 2.71429 L
.45845 2.71429 L
.48753 2.71429 L
.51845 2.71429 L
.54823 2.71429 L
.57687 2.71429 L
.60736 2.71429 L
.63671 2.71429 L
.66789 2.71429 L
.69794 2.71429 L
.72686 2.71429 L
.75761 2.71429 L
.78571 2.71429 L
s
1 0 1 r
.07143 2.85714 m
.1004 2.85714 L
.13201 2.85714 L
.16169 2.85714 L
.19023 2.85714 L
.22061 2.85714 L
.24985 2.85714 L
.28094 2.85714 L
.31089 2.85714 L
.3397 2.85714 L
.37035 2.85714 L
.39986 2.85714 L
.42824 2.85714 L
.45845 2.85714 L
.48753 2.85714 L
.51845 2.85714 L
.54823 2.85714 L
.57687 2.85714 L
.60736 2.85714 L
.63671 2.85714 L
.66789 2.85714 L
.69794 2.85714 L
.72686 2.85714 L
.75761 2.85714 L
.78571 2.85714 L
s
.5 .165 .165 r
.07143 3 m
.1004 3 L
.13201 3 L
.16169 3 L
.19023 3 L
.22061 3 L
.24985 3 L
.28094 3 L
.31089 3 L
.3397 3 L
.37035 3 L
.39986 3 L
.42824 3 L
.45845 3 L
.48753 3 L
.51845 3 L
.54823 3 L
.57687 3 L
.60736 3 L
.63671 3 L
.66789 3 L
.69794 3 L
.72686 3 L
.75761 3 L
.78571 3 L
s
0 1 0 r
.1 w
.78571 .14286 Mdot
1 0 0 r
.78571 3 Mdot
0 0 1 r
.07143 3 Mdot
0 g
gsave
.81429 .21429 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.1 3.1 -61 -10.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
77.375 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.64286 3.1 -61 -10.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.375 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
91.750 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{91.625, 287.875},
    ImageMargins->{{24, 0}, {0, 7}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001K00017b000`400?l00000o`00003oF`3oool0
05/0oooo001K0?ooo`00F`3oool005/0oooo001K0?ooo`00F`3oool005/0oooo001K0?ooo`00F`3o
ool005/0oooo001K0?ooo`00F`3oool005/0oooo001K0?ooo`00F`3oool005/0oooo001K0?ooo`00
F`3oool005/0oooo001K0?ooo`00F`3oool005/0oooo001K0?ooo`00F`3oool005/0oooo001K0?oo
o`009@3oool3000001<0oooo1000000L0?ooo`009P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01d0oooo000S0?ooo`D00000503oool00`000000oooo0?ooo`0L0?ooo`008`3oool0
10000000oooo0?ooo`00000F0?ooo`030000003oool0oooo01/0oooo000T0?ooo`030000003oool0
000001@0oooo00@000000?ooo`3oool00000703oool002D0oooo0P00000E0?ooo`8000007@3oool0
05/0oooo000Q0?ooo`P00000403oool8000001X0oooo001K0?ooo`00F`3oool00100oooo00<00000
0?ooo`3oool0B03oool00100oooo00<000000?ooo`3oool0B03oool00100oooo00<000000?ooo`3o
ool0403oool5000001<0oooo1@00000K0?ooo`00403oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool06`3oool00100oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01/0oooo000@0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0K0?ooo`00403oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06`3oool00100
oooo00<000000?ooo`3oool04@3oool2000001H0oooo0P0000000`3oool00?l0003o000J0?ooo`00
403oool00`000000oooo0?ooo`0[0?ooo`@00?l0403oool2000000030?ooo`000000000000@0oooo
000<0?ooo`@00000;@1o:RX6003o00`00000103oool00`000000oooo000000050?ooo`00403oool0
0`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool0
0`3o0?l0oooo0?ooo`060?ooo`H00?l04@3oool00`000000oooo0?ooo`040?ooo`00403oool00`1o
:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o
0?l0oooo0?ooo`070?ooo`@00?l0403oool2000000030?ooo`000000000000@0oooo000@0?ooo`03
07lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`03
0?l0o`3oool0oooo00P0oooo0P00o`050?ooo`D00000403oool00100oooo00<0ObXZ0?ooo`3oool0
2@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool0
2@3oool00`1o:RX0oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000004@3oool00100oooo
00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo
00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00004@3oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ
:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`030?ooo`@00000
4@3oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3o
ool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000004@3oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?oo
o`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?oo
o`030?ooo`<000004P3oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`09
0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H
0?ooo`00403ooola0?l0oaX0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3o
ool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3o
ool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ
:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403o
ool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3o
ool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0
oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0
oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o
0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o
:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0
oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0
oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo
0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0
ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0
o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403ooola07lZ:QX0oooo000@0?oo
o`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?oo
o`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3o
ool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3o
ool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0
o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ
:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3o
ool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603o
ool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0
oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o
:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o
0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0
oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0
oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo
0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo
0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0
ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@
0?oooc40o`3o6P3oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?oo
o`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?oo
o`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3o
ool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ
:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0
o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3o
ool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3o
ool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0
oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0
oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o
:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100
oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0
oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo
0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo
0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?oooc40ObXZ6P3oool00100oooo00<0ObXZ
0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o
0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?oo
o`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?oo
o`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3o
ool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3o
ool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ
:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403o
ool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3o
ool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0
oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0
oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o
0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o
:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0
oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0
oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo
0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo<@3o
0?lJ0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ
0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?oo
o`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?oo
o`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3o
ool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3o
ool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0
o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ
:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3o
ool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603o
ool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0
oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o
:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o
0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0
oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0
oooo00<0ObXZ0?ooo`3oool0603oool00100oooo<@1o:RXJ0?ooo`00403oool00`1o:RX0oooo0?oo
o`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?oo
o`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o
0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ
0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?oo
o`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?oo
o`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3o
ool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ
:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0
o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3o
ool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3o
ool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0
oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0
oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o
:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100
oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0
oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403ooola0?l0oaX0oooo
000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?oo
o`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ
0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o
0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?oo
o`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?oo
o`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3o
ool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3o
ool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ
:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403o
ool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3o
ool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0
oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0
oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o
0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o
:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0
oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0
oooo000@0?oooc40ObXZ6P3oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?oo
o`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?oo
o`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ
0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?oo
o`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?oo
o`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3o
ool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3o
ool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0
o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ
:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3o
ool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603o
ool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0
oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o
:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o
0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?oooc40o`3o6P3oool00100oooo
00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo
00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?oo
o`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?oo
o`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o
0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ
0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?oo
o`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?oo
o`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3o
ool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ
:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0
o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3o
ool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3o
ool00`1o:RX0oooo0?ooo`0H0?ooo`000`3oool5000000P0oooo00<0ObXZ0?ooo`3oool02@3oool0
0`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool0
0`1o:RX0oooo0?ooo`0H0?ooo`001@3oool00`000000oooo0?ooo`080?ooo`0307lZ:P3oool0oooo
00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo
00T0oooo00<0ObXZ0?ooo`3oool0603oool000D0oooo00<000000?ooo`3oool0203ooola07lZ:QX0
oooo00050?ooo`030000003oool0oooo00P0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo
0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo
0?ooo`0H0?ooo`001@3oool00`000000oooo0?ooo`080?ooo`0307lZ:P3oool0oooo00T0oooo00<0
o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0
ObXZ0?ooo`3oool0603oool000@0oooo0P00000:0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o
0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ
0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?oo
o`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?oo
o`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3o
ool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ
:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0
o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3o
ool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3o
ool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0
oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0
oooo01P0oooo000@0?oooc40o`3o6P3oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0
oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0
oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo
00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo
000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?oo
o`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ
0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o
0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?oo
o`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?oo
o`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3o
ool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3o
ool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ
:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403o
ool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3o
ool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0
oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0
oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo<@1o:RXJ0?ooo`00403oool00`1o:RX0
oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0
oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo
00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo
00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?oo
o`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?oo
o`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ
0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?oo
o`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?oo
o`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3o
ool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3o
ool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0
o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ
:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3o
ool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603o
ool00100oooo<@3o0?lJ0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo
00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo
01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0
oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo
00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo
00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?oo
o`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?oo
o`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o
0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ
0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?oo
o`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?oo
o`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3o
ool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ
:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0
o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3o
ool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3o
ool00`1o:RX0oooo0?ooo`0H0?ooo`00403ooola07lZ:QX0oooo000@0?ooo`0307lZ:P3oool0oooo
00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo
00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0
oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0
oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo
00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo
000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?oo
o`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ
0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o
0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?oo
o`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?oo
o`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3o
ool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3o
ool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ
:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403o
oola0?l0oaX0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool0
0`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool0
0100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo
00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0
oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0
oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo
00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo
00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?oo
o`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?oo
o`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ
0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?oo
o`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?oo
o`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3o
ool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3o
ool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0
o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ
:P3oool0oooo01P0oooo000@0?oooc40ObXZ6P3oool00100oooo00<0ObXZ0?ooo`3oool02@3oool0
0`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool0
0`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo
00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo
01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0
oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo
00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo
00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?oo
o`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?oo
o`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o
0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ
0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?oo
o`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?oo
o`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3o
ool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ
:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0
o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo<@3o0?lJ0?ooo`00403oool0
0`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool0
0`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo
00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo
00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0
oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0
oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo
00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo
000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?oo
o`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ
0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o
0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?oo
o`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?oo
o`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3o
ool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3o
ool0603oool00100oooo<@1o:RXJ0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3o
ool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3o
ool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool0
0`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool0
0100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo
00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0
oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0
oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo
00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo
00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?oo
o`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?oo
o`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ
0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?oo
o`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?oo
o`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3o
ool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3o
ool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403ooola0?l0oaX0oooo000@0?ooo`0307lZ:P3o
ool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3o
ool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo00<0ObXZ0?ooo`3oool02@3oool0
0`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool0
0`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo
00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo
01P0oooo000@0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0
oooo0?ooo`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0603oool00100oooo
00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?ooo`090?ooo`0307lZ:P3oool0oooo00T0oooo
00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`0H0?ooo`00403oool00`1o:RX0oooo0?oo
o`090?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?oo
o`090?ooo`0307lZ:P3oool0oooo01P0oooo000@0?ooo`80003o2P3oool00`3o0?l0oooo0?ooo`09
0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool0203oool20?l001X0oooo00030?oo
o`@00000203oool40000o`T0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`090?oo
o`030?l0o`3oool0oooo00L0oooo103o000I0?ooo`000`3oool00`000000oooo0?ooo`080?ooo`H0
003o:@1o:RX60?l001P0oooo00040?ooo`030000003oool0oooo00L0oooo1P000?lY0?ooo`H0o`00
603oool000D0oooo00<000000?ooo`3oool01`3oool40000ob/0oooo103o000I0?ooo`000`3oool0
10000000oooo0?ooo`0000090?ooo`80003o;@3oool20?l001X0oooo00040?ooo`8000002P3oool0
0`000000oooo0?ooo`180?ooo`00403oool00`000000oooo0?ooo`020?ooo`/000006`3oool50000
00<0oooo00<000000?ooo`3oool00P3oool;000000P0oooo000@0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001T0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000L0oooo000@0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`D00000103oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00001`3oool00100oooo00<000000?ooo`3oool0103oool00`000000oooo000000020?ooo`050000
003oool0oooo0?ooo`0000006P3oool4000000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000001`3oool00100oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000020?ooo`8000000P3oool00`000000oooo0?ooo`0G0?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool00000
0080oooo0P0000020?ooo`030000003oool0oooo00D0oooo000@0?ooo`030000003oool0oooo0080
oooo1@0000020?ooo`040000003oool00000000001/0oooo0`00000:0?ooo`D000000P3oool01000
0000oooo0000000000080?ooo`00703oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
00T0oooo000H0?ooo`030000003oool0oooo00800000;P3oool00`000000oooo0?ooo`02000000/0
oooo001K0?ooo`003P3oool2000004/0oooo000?0?ooo`030000003oool0oooo04T0oooo000@0?oo
o`030000003oool0oooo04P0oooo000?0?ooo`030000003oool0000004T0oooo000>0?ooo`040000
003oool0oooo000004T0oooo000=0?ooo`<0000000<0oooo000000000000B03oool005/0oooo001K
0?ooo`00F`3oool005/0oooo001K0?ooo`00F`3oool005/0oooo001K0?ooo`00F`3oool005/0oooo
001K0?ooo`00F`3oool005/0oooo001K0?ooo`00F`3oool005/0oooo001K0?ooo`00F`3oool005/0
oooo001K0?ooo`00F`3oool005/0oooo001K0?ooo`00F`3oool005/0oooo001K0?ooo`00F`3oool0
05/0oooo001K0?ooo`00F`3oool00001\
\>"],
    ImageRangeCache->{{{0, 90.625}, {286.875, 0}} -> {-0.176181, -0.486165, 
    0.0104643, 0.0104643}}],
  "       ",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.888889 0.222222 0.133333 0.222222 [
[.22222 .12083 -6 -9 ]
[.22222 .12083 6 0 ]
[.44444 .12083 -6 -9 ]
[.44444 .12083 6 0 ]
[.66667 .12083 -6 -9 ]
[.66667 .12083 6 0 ]
[.94444 .12083 -11.0938 -20.125 ]
[.94444 .12083 11.0938 0 ]
[1.025 .13333 0 -6.28125 ]
[1.025 .13333 10 6.28125 ]
[.87639 .35556 -6 -4.5 ]
[.87639 .35556 0 4.5 ]
[.87639 .57778 -6 -4.5 ]
[.87639 .57778 0 4.5 ]
[.88889 .625 -5 0 ]
[.88889 .625 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .6 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22222 .13333 m
.22222 .13958 L
s
[(-3)] .22222 .12083 0 1 Mshowa
.44444 .13333 m
.44444 .13958 L
s
[(-2)] .44444 .12083 0 1 Mshowa
.66667 .13333 m
.66667 .13958 L
s
[(-1)] .66667 .12083 0 1 Mshowa
.94444 .13333 m
.94444 .13958 L
s
gsave
.94444 .12083 -72.0938 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.063 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.063 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
81.188 17.063 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .13333 m
1 .13333 L
s
gsave
1.025 .13333 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.88889 .35556 m
.89514 .35556 L
s
[(1)] .87639 .35556 1 0 Mshowa
.88889 .57778 m
.89514 .57778 L
s
[(2)] .87639 .57778 1 0 Mshowa
.88889 0 m
.88889 .6 L
s
gsave
.88889 .625 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .6 L
0 .6 L
closepath
clip
newpath
.5 .165 .165 r
.5 Mabswid
.88889 .13333 m
.88743 .13333 L
.8825 .13333 L
.8747 .13333 L
.8643 .13333 L
.85012 .13333 L
.83342 .13333 L
.81242 .13333 L
.78899 .13333 L
.76351 .13333 L
.73322 .13333 L
.70096 .13333 L
.66708 .13333 L
.62793 .13333 L
.58724 .13333 L
.54075 .13333 L
.49281 .13333 L
.44379 .13333 L
.38849 .13333 L
.33218 .13333 L
.26906 .13333 L
.20503 .13333 L
.14046 .13333 L
.06858 .13333 L
0 .13333 L
s
1 0 1 r
.89236 .13333 m
.89236 .13347 L
.89236 .1336 L
.89235 .13374 L
.89234 .13388 L
.89232 .13412 L
.89228 .13438 L
.89223 .13467 L
.89217 .13498 L
.89201 .13553 L
.89181 .1361 L
.89158 .13663 L
.8909 .13784 L
.88999 .13908 L
.88896 .14021 L
.88597 .14276 L
.88261 .14497 L
.87814 .14739 L
.86692 .15213 L
.85306 .1567 L
.83505 .16155 L
.81448 .16622 L
.79172 .17072 L
.76432 .1755 L
.73482 .18011 L
.70357 .18454 L
.66719 .18926 L
.62915 .1938 L
.58546 .19862 L
.5402 .20327 L
.49373 .20774 L
.44112 .2125 L
.38738 .21708 L
.33287 .22148 L
.27175 .22618 L
.20994 .23069 L
.14099 .23549 L
.07145 .24011 L
.00347 .24444 L
s
.5 .165 .165 r
.90278 .13333 m
.90278 .13361 L
.90277 .13386 L
.90277 .13415 L
.90276 .13442 L
.90273 .1349 L
.9027 .13543 L
.90265 .13601 L
.90258 .13662 L
.90243 .13772 L
.90223 .13886 L
.902 .13992 L
.90131 .14235 L
.9004 .14482 L
.89937 .14708 L
.89638 .15218 L
.89303 .15661 L
.88855 .16145 L
.87734 .17093 L
.86348 .18006 L
.84546 .18976 L
.8249 .19911 L
.80214 .20811 L
.77474 .21767 L
.74524 .22689 L
.71398 .23575 L
.67761 .24518 L
.63957 .25426 L
.59588 .26391 L
.55062 .27321 L
.50414 .28215 L
.45153 .29167 L
.3978 .30083 L
.34329 .30964 L
.28217 .31902 L
.22036 .32804 L
.15141 .33764 L
.08187 .34689 L
.01389 .35556 L
s
1 0 1 r
.92014 .13333 m
.92014 .13374 L
.92013 .13412 L
.92013 .13455 L
.92012 .13496 L
.92009 .13569 L
.92006 .13647 L
.92001 .13734 L
.91994 .13826 L
.91979 .13992 L
.91959 .14162 L
.91936 .14322 L
.91868 .14686 L
.91776 .15057 L
.91674 .15396 L
.91375 .1616 L
.91039 .16825 L
.90591 .1755 L
.8947 .18973 L
.88084 .20342 L
.86282 .21798 L
.84226 .232 L
.8195 .24549 L
.7921 .25984 L
.7626 .27366 L
.73134 .28695 L
.69497 .3011 L
.65693 .31472 L
.61324 .3292 L
.56798 .34314 L
.5215 .35656 L
.4689 .37083 L
.41516 .38457 L
.36065 .39779 L
.29953 .41186 L
.23772 .4254 L
.16877 .4398 L
.09923 .45367 L
.03125 .46667 L
s
.5 .165 .165 r
.94444 .13333 m
.94444 .13388 L
.94444 .13438 L
.94443 .13496 L
.94442 .1355 L
.9444 .13647 L
.94437 .13752 L
.94432 .13868 L
.94425 .13991 L
.9441 .14211 L
.94389 .14438 L
.94366 .14651 L
.94298 .15136 L
.94207 .15631 L
.94104 .16084 L
.93805 .17103 L
.93469 .17989 L
.93022 .18956 L
.919 .20852 L
.90514 .22679 L
.88713 .24619 L
.86656 .26489 L
.84381 .28288 L
.81641 .30201 L
.7869 .32044 L
.75565 .33816 L
.71927 .35703 L
.68123 .37518 L
.63754 .39448 L
.59228 .41308 L
.54581 .43097 L
.4932 .45 L
.43947 .46832 L
.38496 .48594 L
.32383 .5047 L
.26202 .52275 L
.19308 .54195 L
.12354 .56044 L
.05556 .57778 L
s
.88889 .13333 m
.88898 .13333 L
.88929 .13333 L
.88978 .13333 L
.89043 .13333 L
.89131 .13333 L
.89236 .13333 L
.89367 .13333 L
.89513 .13333 L
.89673 .13333 L
.89862 .13333 L
.90063 .13333 L
.90275 .13333 L
.9052 .13333 L
.90774 .13333 L
.91065 .13333 L
.91364 .13333 L
.91671 .13333 L
.92016 .13333 L
.92368 .13333 L
.92763 .13333 L
.93163 .13333 L
.93567 .13333 L
.94016 .13333 L
.94444 .13333 L
s
1 0 1 r
.88667 .13333 m
.88667 .13336 L
.88667 .13339 L
.88667 .13341 L
.88667 .13344 L
.88667 .13349 L
.88667 .13354 L
.88667 .1336 L
.88668 .13366 L
.88669 .13377 L
.8867 .13389 L
.88672 .13399 L
.88676 .13423 L
.88682 .13448 L
.88688 .13471 L
.88707 .13522 L
.88728 .13566 L
.88756 .13614 L
.88826 .13709 L
.88912 .13801 L
.89025 .13898 L
.89153 .13991 L
.89296 .14081 L
.89467 .14177 L
.89651 .14269 L
.89847 .14357 L
.90074 .14452 L
.90312 .14543 L
.90585 .14639 L
.90868 .14732 L
.91158 .14821 L
.91487 .14917 L
.91823 .15008 L
.92163 .15096 L
.92545 .1519 L
.92932 .1528 L
.93363 .15376 L
.93797 .15469 L
.94222 .15556 L
s
.5 .165 .165 r
.88 .13333 m
.88 .13339 L
.88 .13344 L
.88 .1335 L
.88 .13355 L
.88 .13365 L
.88 .13375 L
.88001 .13387 L
.88001 .13399 L
.88002 .13421 L
.88003 .13444 L
.88005 .13465 L
.88009 .13514 L
.88015 .13563 L
.88021 .13608 L
.8804 .1371 L
.88061 .13799 L
.88089 .13896 L
.88159 .14085 L
.88246 .14268 L
.88358 .14462 L
.88487 .14649 L
.88629 .14829 L
.888 .1502 L
.88985 .15204 L
.8918 .15382 L
.89407 .1557 L
.89645 .15752 L
.89918 .15945 L
.90201 .16131 L
.90491 .1631 L
.9082 .165 L
.91156 .16683 L
.91497 .16859 L
.91879 .17047 L
.92265 .17228 L
.92696 .1742 L
.93131 .17604 L
.93556 .17778 L
s
1 0 1 r
.86889 .13333 m
.86889 .13342 L
.86889 .13349 L
.86889 .13358 L
.86889 .13366 L
.86889 .1338 L
.86889 .13396 L
.8689 .13414 L
.8689 .13432 L
.86891 .13465 L
.86892 .13499 L
.86894 .13531 L
.86898 .13604 L
.86904 .13678 L
.8691 .13746 L
.86929 .13899 L
.8695 .14032 L
.86978 .14177 L
.87048 .14461 L
.87135 .14735 L
.87247 .15026 L
.87376 .15307 L
.87518 .15577 L
.87689 .15864 L
.87874 .1614 L
.88069 .16406 L
.88296 .16689 L
.88534 .16961 L
.88807 .17251 L
.8909 .1753 L
.8938 .17798 L
.89709 .18083 L
.90045 .18358 L
.90386 .18622 L
.90768 .18904 L
.91154 .19175 L
.91585 .19463 L
.9202 .1974 L
.92444 .2 L
s
.5 .165 .165 r
.85333 .13333 m
.85333 .13344 L
.85333 .13354 L
.85333 .13366 L
.85333 .13377 L
.85334 .13396 L
.85334 .13417 L
.85334 .1344 L
.85335 .13465 L
.85335 .13509 L
.85337 .13554 L
.85338 .13597 L
.85342 .13694 L
.85348 .13793 L
.85355 .13883 L
.85373 .14087 L
.85394 .14264 L
.85422 .14458 L
.85492 .14837 L
.85579 .15202 L
.85692 .1559 L
.8582 .15964 L
.85962 .16324 L
.86134 .16707 L
.86318 .17075 L
.86513 .1743 L
.86741 .17807 L
.86978 .1817 L
.87251 .18556 L
.87534 .18928 L
.87825 .19286 L
.88154 .19667 L
.88489 .20033 L
.8883 .20385 L
.89212 .20761 L
.89598 .21122 L
.90029 .21506 L
.90464 .21876 L
.90889 .22222 L
s
1 0 1 r
.83333 .13333 m
.83333 .13347 L
.83333 .1336 L
.83333 .13374 L
.83333 .13388 L
.83334 .13412 L
.83334 .13438 L
.83334 .13467 L
.83335 .13498 L
.83335 .13553 L
.83337 .1361 L
.83338 .13663 L
.83342 .13784 L
.83348 .13908 L
.83355 .14021 L
.83373 .14276 L
.83394 .14497 L
.83422 .14739 L
.83492 .15213 L
.83579 .1567 L
.83692 .16155 L
.8382 .16622 L
.83962 .17072 L
.84134 .1755 L
.84318 .18011 L
.84513 .18454 L
.84741 .18926 L
.84978 .1938 L
.85251 .19862 L
.85534 .20327 L
.85825 .20774 L
.86154 .2125 L
.86489 .21708 L
.8683 .22148 L
.87212 .22618 L
.87598 .23069 L
.88029 .23549 L
.88464 .24011 L
.88889 .24444 L
s
.5 .165 .165 r
.80889 .13333 m
.80889 .1335 L
.80889 .13365 L
.80889 .13382 L
.80889 .13398 L
.80889 .13427 L
.80889 .13459 L
.8089 .13494 L
.8089 .13531 L
.80891 .13597 L
.80892 .13665 L
.80894 .13729 L
.80898 .13874 L
.80904 .14023 L
.8091 .14158 L
.80929 .14464 L
.8095 .1473 L
.80978 .1502 L
.81048 .15589 L
.81135 .16137 L
.81247 .16719 L
.81376 .1728 L
.81518 .1782 L
.81689 .18394 L
.81874 .18947 L
.82069 .19478 L
.82296 .20044 L
.82534 .20589 L
.82807 .21168 L
.8309 .21726 L
.8338 .22262 L
.83709 .22833 L
.84045 .23383 L
.84386 .23912 L
.84768 .24474 L
.85154 .25016 L
.85585 .25592 L
.8602 .26147 L
.86444 .26667 L
s
1 0 1 r
.78 .13333 m
.78 .13353 L
.78 .1337 L
.78 .1339 L
.78 .13409 L
.78 .13443 L
.78 .1348 L
.78001 .1352 L
.78001 .13563 L
.78002 .13641 L
.78003 .1372 L
.78005 .13795 L
.78009 .13964 L
.78015 .14138 L
.78021 .14296 L
.7804 .14653 L
.78061 .14963 L
.78089 .15301 L
.78159 .15965 L
.78246 .16604 L
.78358 .17283 L
.78487 .17938 L
.78629 .18567 L
.788 .19237 L
.78985 .19882 L
.7918 .20502 L
.79407 .21163 L
.79645 .21798 L
.79918 .22474 L
.80201 .23124 L
.80491 .2375 L
.8082 .24417 L
.81156 .25058 L
.81497 .25675 L
.81879 .26331 L
.82265 .26963 L
.82696 .27635 L
.83131 .28282 L
.83556 .28889 L
s
.5 .165 .165 r
.74667 .13333 m
.74667 .13355 L
.74667 .13375 L
.74667 .13398 L
.74667 .1342 L
.74667 .13459 L
.74667 .13501 L
.74667 .13547 L
.74668 .13596 L
.74669 .13684 L
.7467 .13775 L
.74672 .13861 L
.74676 .14055 L
.74682 .14252 L
.74688 .14433 L
.74707 .14841 L
.74728 .15195 L
.74756 .15582 L
.74826 .16341 L
.74912 .17071 L
.75025 .17848 L
.75153 .18596 L
.75296 .19315 L
.75467 .20081 L
.75651 .20818 L
.75847 .21526 L
.76074 .22281 L
.76312 .23007 L
.76585 .23779 L
.76868 .24523 L
.77158 .25239 L
.77487 .26 L
.77823 .26733 L
.78163 .27438 L
.78545 .28188 L
.78932 .2891 L
.79363 .29678 L
.79797 .30418 L
.80222 .31111 L
s
1 0 1 r
.70889 .13333 m
.70889 .13358 L
.70889 .1338 L
.70889 .13406 L
.70889 .13431 L
.70889 .13475 L
.70889 .13522 L
.7089 .13574 L
.7089 .13629 L
.70891 .13728 L
.70892 .13831 L
.70894 .13926 L
.70898 .14145 L
.70904 .14367 L
.7091 .14571 L
.70929 .1503 L
.7095 .15428 L
.70978 .15863 L
.71048 .16717 L
.71135 .17539 L
.71247 .18412 L
.71376 .19253 L
.71518 .20063 L
.71689 .20924 L
.71874 .21753 L
.72069 .22551 L
.72296 .23399 L
.72534 .24217 L
.72807 .25085 L
.7309 .25922 L
.7338 .26727 L
.73709 .27583 L
.74045 .28408 L
.74386 .29201 L
.74768 .30045 L
.75154 .30857 L
.75585 .31721 L
.7602 .32553 L
.76444 .33333 L
s
.5 .165 .165 r
.66667 .13333 m
.66667 .13361 L
.66667 .13386 L
.66667 .13415 L
.66667 .13442 L
.66667 .1349 L
.66667 .13543 L
.66667 .13601 L
.66668 .13662 L
.66669 .13772 L
.6667 .13886 L
.66672 .13992 L
.66676 .14235 L
.66682 .14482 L
.66688 .14708 L
.66707 .15218 L
.66728 .15661 L
.66756 .16145 L
.66826 .17093 L
.66912 .18006 L
.67025 .18976 L
.67153 .19911 L
.67296 .20811 L
.67467 .21767 L
.67651 .22689 L
.67847 .23575 L
.68074 .24518 L
.68312 .25426 L
.68585 .26391 L
.68868 .27321 L
.69158 .28215 L
.69487 .29167 L
.69823 .30083 L
.70163 .30964 L
.70545 .31902 L
.70932 .32804 L
.71363 .33764 L
.71797 .34689 L
.72222 .35556 L
s
1 0 1 r
.62 .13333 m
.62 .13364 L
.62 .13391 L
.62 .13423 L
.62 .13453 L
.62 .13506 L
.62 .13564 L
.62001 .13627 L
.62001 .13695 L
.62002 .13816 L
.62003 .13941 L
.62005 .14058 L
.62009 .14325 L
.62015 .14597 L
.62021 .14846 L
.6204 .15406 L
.62061 .15894 L
.62089 .16426 L
.62159 .17469 L
.62246 .18473 L
.62358 .1954 L
.62487 .20569 L
.62629 .21558 L
.628 .22611 L
.62985 .23624 L
.6318 .24599 L
.63407 .25636 L
.63645 .26635 L
.63918 .27697 L
.64201 .28719 L
.64491 .29703 L
.6482 .3075 L
.65156 .31758 L
.65497 .32727 L
.65879 .33759 L
.66265 .34752 L
.66696 .35807 L
.67131 .36824 L
.67556 .37778 L
s
.5 .165 .165 r
.56889 .13333 m
.56889 .13366 L
.56889 .13396 L
.56889 .13431 L
.56889 .13463 L
.56889 .13522 L
.56889 .13585 L
.5689 .13654 L
.5689 .13728 L
.56891 .1386 L
.56892 .13996 L
.56894 .14124 L
.56898 .14415 L
.56904 .14712 L
.5691 .14983 L
.56929 .15595 L
.5695 .16126 L
.56978 .16707 L
.57048 .17845 L
.57135 .1894 L
.57247 .20105 L
.57376 .21227 L
.57518 .22306 L
.57689 .23454 L
.57874 .2456 L
.58069 .25623 L
.58296 .26755 L
.58534 .27844 L
.58807 .29002 L
.5909 .30118 L
.5938 .31191 L
.59709 .32333 L
.60045 .33433 L
.60386 .3449 L
.60768 .35615 L
.61154 .36699 L
.61585 .37851 L
.6202 .3896 L
.62444 .4 L
s
1 0 1 r
.51333 .13333 m
.51333 .13369 L
.51333 .13401 L
.51333 .13439 L
.51333 .13474 L
.51334 .13537 L
.51334 .13606 L
.51334 .13681 L
.51335 .13761 L
.51335 .13904 L
.51337 .14052 L
.51338 .1419 L
.51342 .14505 L
.51348 .14827 L
.51355 .15121 L
.51373 .15783 L
.51394 .16359 L
.51422 .16988 L
.51492 .18221 L
.51579 .19408 L
.51692 .20669 L
.5182 .21884 L
.51962 .23054 L
.52134 .24298 L
.52318 .25495 L
.52513 .26647 L
.52741 .27873 L
.52978 .29054 L
.53251 .30308 L
.53534 .31517 L
.53825 .32679 L
.54154 .33917 L
.54489 .35108 L
.5483 .36253 L
.55212 .37472 L
.55598 .38646 L
.56029 .39894 L
.56464 .41096 L
.56889 .42222 L
s
.5 .165 .165 r
.45333 .13333 m
.45333 .13372 L
.45333 .13407 L
.45333 .13447 L
.45333 .13485 L
.45334 .13553 L
.45334 .13627 L
.45334 .13708 L
.45335 .13794 L
.45335 .13948 L
.45337 .14107 L
.45338 .14256 L
.45342 .14595 L
.45348 .14942 L
.45355 .15259 L
.45373 .15972 L
.45394 .16592 L
.45422 .17269 L
.45492 .18597 L
.45579 .19875 L
.45692 .21233 L
.4582 .22542 L
.45962 .23801 L
.46134 .25141 L
.46318 .26431 L
.46513 .27671 L
.46741 .28992 L
.46978 .30263 L
.47251 .31614 L
.47534 .32916 L
.47825 .34168 L
.48154 .355 L
.48489 .36783 L
.4883 .38016 L
.49212 .39329 L
.49598 .40593 L
.50029 .41937 L
.50464 .43231 L
.50889 .44444 L
s
1 0 1 r
.38889 .13333 m
.38889 .13374 L
.38889 .13412 L
.38889 .13455 L
.38889 .13496 L
.38889 .13569 L
.38889 .13647 L
.3889 .13734 L
.3889 .13826 L
.38891 .13992 L
.38892 .14162 L
.38894 .14322 L
.38898 .14686 L
.38904 .15057 L
.3891 .15396 L
.38929 .1616 L
.3895 .16825 L
.38978 .1755 L
.39048 .18973 L
.39135 .20342 L
.39247 .21798 L
.39376 .232 L
.39518 .24549 L
.39689 .25984 L
.39874 .27366 L
.40069 .28695 L
.40296 .3011 L
.40534 .31472 L
.40807 .3292 L
.4109 .34314 L
.4138 .35656 L
.41709 .37083 L
.42045 .38457 L
.42386 .39779 L
.42768 .41186 L
.43154 .4254 L
.43585 .4398 L
.4402 .45367 L
.44444 .46667 L
s
.5 .165 .165 r
.32 .13333 m
.32 .13377 L
.32 .13417 L
.32 .13463 L
.32 .13507 L
.32 .13584 L
.32 .13668 L
.32001 .13761 L
.32001 .13859 L
.32002 .14035 L
.32003 .14217 L
.32005 .14388 L
.32009 .14776 L
.32015 .15171 L
.32021 .15534 L
.3204 .16349 L
.32061 .17058 L
.32089 .17831 L
.32159 .19349 L
.32246 .20809 L
.32358 .22362 L
.32487 .23858 L
.32629 .25297 L
.328 .26828 L
.32985 .28302 L
.3318 .2972 L
.33407 .31229 L
.33645 .32681 L
.33918 .34225 L
.34201 .35713 L
.34491 .37144 L
.3482 .38666 L
.35156 .40132 L
.35497 .41542 L
.35879 .43043 L
.36265 .44487 L
.36696 .46023 L
.37131 .47502 L
.37556 .48889 L
s
1 0 1 r
.24667 .13333 m
.24667 .1338 L
.24667 .13422 L
.24667 .13471 L
.24667 .13518 L
.24667 .136 L
.24667 .13689 L
.24667 .13788 L
.24668 .13892 L
.24669 .14079 L
.2467 .14273 L
.24672 .14454 L
.24676 .14866 L
.24682 .15286 L
.24688 .15671 L
.24707 .16537 L
.24728 .1729 L
.24756 .18112 L
.24826 .19725 L
.24912 .21277 L
.25025 .22926 L
.25153 .24515 L
.25296 .26045 L
.25467 .27671 L
.25651 .29237 L
.25847 .30744 L
.26074 .32347 L
.26312 .33891 L
.26585 .35531 L
.26868 .37112 L
.27158 .38632 L
.27487 .4025 L
.27823 .41807 L
.28163 .43305 L
.28545 .449 L
.28932 .46434 L
.29363 .48066 L
.29797 .49638 L
.30222 .51111 L
s
.5 .165 .165 r
.16889 .13333 m
.16889 .13383 L
.16889 .13428 L
.16889 .13479 L
.16889 .13529 L
.16889 .13616 L
.16889 .1371 L
.1689 .13815 L
.1689 .13925 L
.16891 .14123 L
.16892 .14328 L
.16894 .1452 L
.16898 .14956 L
.16904 .15401 L
.1691 .15809 L
.16929 .16726 L
.1695 .17523 L
.16978 .18393 L
.17048 .20101 L
.17135 .21744 L
.17247 .2349 L
.17376 .25173 L
.17518 .26792 L
.17689 .28515 L
.17874 .30173 L
.18069 .31768 L
.18296 .33466 L
.18534 .351 L
.18807 .36837 L
.1909 .3851 L
.1938 .4012 L
.19709 .41833 L
.20045 .43482 L
.20386 .45068 L
.20768 .46756 L
.21154 .48381 L
.21585 .50109 L
.2202 .51773 L
.22444 .53333 L
s
1 0 1 r
.08667 .13333 m
.08667 .13385 L
.08667 .13433 L
.08667 .13488 L
.08667 .13539 L
.08667 .13631 L
.08667 .13731 L
.08667 .13841 L
.08668 .13958 L
.08669 .14167 L
.0867 .14383 L
.08672 .14585 L
.08676 .15046 L
.08682 .15516 L
.08688 .15946 L
.08707 .16914 L
.08728 .17756 L
.08756 .18675 L
.08826 .20477 L
.08912 .22211 L
.09025 .24055 L
.09153 .25831 L
.09296 .2754 L
.09467 .29358 L
.09651 .31109 L
.09847 .32792 L
.10074 .34584 L
.10312 .36309 L
.10585 .38143 L
.10868 .39909 L
.11158 .41608 L
.11487 .43416 L
.11823 .45157 L
.12163 .46831 L
.12545 .48613 L
.12932 .50328 L
.13363 .52152 L
.13797 .53909 L
.14222 .55556 L
s
.5 .165 .165 r
0 .13333 m
0 .13388 L
0 .13438 L
0 .13496 L
0 .1355 L
0 .13647 L
0 .13752 L
1e-005 .13868 L
1e-005 .13991 L
2e-005 .14211 L
3e-005 .14438 L
5e-005 .14651 L
9e-005 .15136 L
.00015 .15631 L
.00021 .16084 L
.0004 .17103 L
.00061 .17989 L
.00089 .18956 L
.00159 .20852 L
.00246 .22679 L
.00358 .24619 L
.00487 .26489 L
.00629 .28288 L
.008 .30201 L
.00985 .32044 L
.0118 .33816 L
.01407 .35703 L
.01645 .37518 L
.01918 .39448 L
.02201 .41308 L
.02491 .43097 L
.0282 .45 L
.03156 .46832 L
.03497 .48594 L
.03879 .5047 L
.04265 .52275 L
.04696 .54195 L
.05131 .56044 L
.05556 .57778 L
s
0 1 0 r
.02 w
.94444 .13333 Mdot
1 0 0 r
.05556 .57778 Mdot
0 0 1 r
0 .13333 Mdot
0 g
gsave
.94444 .16667 -61 -11.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
-0.04444 .1 -61 -11.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.375 14.938 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
84.563 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
90.188 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
0 .6 -61 -11.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
83.000 14.938 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
90.188 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
95.813 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
103.000 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2ab) show
131.750 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{379.563, 227.75},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005k0000hb000`400?l00000o`00003oo`3ooolj
0?ooo`030000003oool0oooo03l0oooo003o0?ooocX0oooo00<000000?ooo`3oool0?`3oool00?l0
oooo>P3oool00`000000oooo0?ooo`0o0?ooo`00o`3ooolj0?ooo`030000003oool0oooo03l0oooo
003o0?ooocX0oooo00<000000?ooo`3oool0?`3oool00?l0oooo>P3oool00`000000oooo0?ooo`0o
0?ooo`00o`3ooolj0?ooo`030000003oool0oooo03l0oooo003o0?ooocX0oooo00<000000?ooo`3o
ool0?`3oool00?l0oooo>P3oool00`000000oooo0?ooo`0o0?ooo`00o`3ooolj0?ooo`030000003o
ool0oooo03l0oooo003o0?ooocX0oooo00<000000?ooo`3oool0?`3oool00?l0oooo>P3oool00`00
0000oooo0?ooo`0o0?ooo`00o`3ooolj0?ooo`030000003oool0oooo03l0oooo003o0?ooocX0oooo
00<000000?ooo`3oool0?`3oool00?l0oooo>P3oool00`000000oooo0?ooo`0o0?ooo`00o`3ooolj
0?ooo`030000003oool0oooo03l0oooo003o0?ooocX0oooo00<000000?ooo`3oool0?`3oool00?l0
oooo>P3oool00`000000oooo0?ooo`0o0?ooo`00o`3ooolj0?ooo`030000003oool0oooo03l0oooo
003o0?ooocX0oooo00<000000?ooo`3oool0?`3oool00?l0oooo>P3oool00`000000oooo0?ooo`0o
0?ooo`00o`3ooolj0?ooo`030000003oool0oooo03l0oooo003o0?ooocX0oooo00<000000?ooo`3o
ool0?`3oool00?l0oooo>P3oool00`000000oooo0?ooo`0=0?ooo`<00000;`3oool00?l0oooo>P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02h0oooo003o0?ooocX0oooo00<00000
0?ooo`3oool02`3oool5000002l0oooo003o0?ooocX0oooo00<000000?ooo`3oool02`3oool01000
0000oooo0?ooo`00000`0?ooo`00o`3ooolj0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`000000<03oool00?l0oooo>P3oool00`000000oooo0?ooo`0=0?ooo`800000<03oool00?l0oooo
>P3oool00`000000oooo0?ooo`0o0?ooo`00o`3ooolj0?ooo`030000003oool0oooo00P0oooo1000
00000`3oool0000000000002000002h0oooo00090?ooo`D00000o`3oool/0?ooo`030000003oool0
oooo03l0oooo000:0?ooo`050000003oool0oooo0?ooo`000000o`3oool[0?ooo`030000003oool0
oooo03l0oooo00030?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
04@0oooo0P0000190?ooo`@00000B@3oool5000004H0oooo00<000000?ooo`3oool0?`3oool000/0
oooo00D000000?ooo`3oool0oooo000000150?ooo`040000003oool0oooo000004P0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo03l0oooo000;0?oo
o`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00/0oooo1@00000_0?oo
o`002`3oool010000000oooo0000000000030?ooo`<00000>P3oool4000000D0oooo00<000000?oo
o`3oool0@03oool4000000@0oooo00<000000?ooo`3oool0@P3oool4000000@0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02l0oooo000;0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0@03oool010000000oooo0?ooo`0000180?oo
o`040000003oool0oooo000004/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo02l0oooo000:0?ooo`8000001`3oool00`000000oooo0?ooo`100?oo
o`800000BP3oool2000004/0oooo0P0000180?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0;`3oool001<0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0;`3oool00180oooo00<000000?ooo`000000o`3ooolU0?ooo`030000
003oool0oooo00`0oooo0P00000a0?ooo`004`3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<0
00000?ooo`3oool0?`3oool00?l0oooo>P3oool00`000000oooo0?ooo`0o0?ooo`001`3oool20000
ool0oooo<@3oool00`000000oooo0?ooo`0?0?ooo`800?l0;P3oool000H0oooo10000?oo0?oooc00
oooo00<000000?ooo`3oool03P3oool4003o01d0oooo1000000<0?ooo`001@3oool60000oa/0ObXZ
00<0o`3o07lZ:P1o:RX0=01o:RX00`3o0?l0ObXZ07lZ:P0]07lZ:P030?l0o`1o:RX0ObXZ02P0ObXZ
00<0o`3o07lZ:P1o:RX08P1o:RX00`3o0?l0ObXZ07lZ:P0K07lZ:P030?l0o`1o:RX0ObXZ01D0ObXZ
00<0o`3o07lZ:P1o:RX0401o:RX00`3o0?l0ObXZ07lZ:P0907lZ:P030?l0o`1o:RX0ObXZ00<0ObXZ
00<0o`3o07lZ:P1o:RX03P1o:RX6003o014000002P3oool010000000oooo0?ooo`00000=0?ooo`00
1@3oool60000oa/0oooo00<0o`3o0?ooo`3oool06@3oool00`1o:RX0oooo0?ooo`0?0?ooo`030000
003oool0oooo00H0oooo00<0o`3o0?ooo`3oool05P3oool00`1o:RX0oooo0?ooo`0D0?ooo`030?l0
o`3oool0oooo0100oooo00D000000?ooo`3oool0oooo07lZ:P0C0?ooo`030?l0o`3oool0oooo0100
oooo00<0ObXZ0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0=0?ooo`0307lZ:P3oool0oooo00/0
oooo00<0o`3o0?ooo`3oool02P3oool00`1o:RX0oooo0?ooo`080?ooo`030?l0o`3oool0oooo00L0
oooo00<0ObXZ0?ooo`3oool01P3oool00`3o0?l0oooo0?ooo`040?ooo`0307lZ:P3oool0oooo0080
oooo00T0o`3o0?ooo`3oool0oooo07lZ:P3oool0o`3o0000003o0?l00P3oool207lZ:P@0oooo00<0
o`3o0?ooo`3oool00`3oool6003o01/0oooo00@000000?ooo`3oool000003@3oool000H0oooo1000
0?lL0?ooo`030?l0o`3oool0oooo01T0oooo00<0ObXZ0?ooo`3oool03`3oool00`000000oooo0?oo
o`060?ooo`030?l0o`3oool0oooo01H0oooo00<0ObXZ0?ooo`3oool0503oool00`3o0?l0oooo0?oo
o`0@0?ooo`050000003oool0oooo0?ooo`1o:RX04`3oool00`3o0?l0oooo0?ooo`0@0?ooo`0307lZ
:P3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03@3oool00`1o:RX0oooo0?ooo`0;0?ooo`030?l0
o`3oool0oooo00X0oooo00<0ObXZ0?ooo`3oool0203oool00`3o0?l0oooo0?ooo`070?ooo`0307lZ
:P3oool0oooo00H0oooo00<0o`3o0?ooo`3oool0103oool00`1o:RX0oooo0?ooo`020?ooo`050?l0
o`3oool0oooo0?ooo`1o:RX00P3oool20?l0o`80oooo00<0ObXZ0?ooo`3oool00`3oool00`3o0?l0
oooo0?ooo`040?ooo`@00?l06`3oool2000000030?ooo`000000000000d0oooo00070?ooo`80003o
7@3oool00`3o0?l0oooo0?ooo`0I0?ooo`0307lZ:P3oool0oooo00l0oooo00<000000?ooo`3oool0
1P3oool00`3o0?l0oooo0?ooo`0F0?ooo`0307lZ:P3oool0oooo01@0oooo00<0o`3o0?ooo`3oool0
403oool01@000000oooo0?ooo`3oool0ObXZ01<0oooo00<0o`3o0?ooo`3oool0403oool00`1o:RX0
oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00d0oooo00<0ObXZ0?ooo`3oool02`3oool00`3o0?l0
oooo0?ooo`0:0?ooo`0307lZ:P3oool0oooo00P0oooo0P3o0?l80?ooo`0307lZ:P3oool0oooo00H0
oooo00<0o`3o0?ooo`3oool0103oool00`1o:RX0oooo0?ooo`020?ooo`050?l0o`3oool0oooo0?oo
o`1o:RX00P3oool30?l0o`030?ooo`1o:RX0oooo00@0oooo00<0o`3o0?ooo`3oool01@3oool2003o
02h0oooo00080?ooo`0307lZ:P3oool0oooo01/0oooo00<0o`3o0?ooo`3oool06@3oool00`1o:RX0
oooo0?ooo`0H0?ooo`030?l0o`3oool0oooo01H0oooo00<0ObXZ0?ooo`3oool0503oool00`3o0?l0
oooo0?ooo`0D0?ooo`0307lZ:P3oool0oooo0140oooo00<0o`3o0?ooo`3oool0403oool00`1o:RX0
oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00d0oooo00<0ObXZ0?ooo`3oool02`3oool00`3o0?l0
oooo0?ooo`0:0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool01P3oool00`1o:RX0
oooo0?ooo`060?ooo`030?l0o`3oool0oooo00@0oooo00<0ObXZ0?ooo`3oool00P3oool00`3o0?l0
oooo0?ooo`020?ooo`0407lZ:P3o0?l000000?ooo`<0o`3o1@3oool00`3o0?l0oooo0?ooo`060?oo
o`0307lZ:P3oool0oooo02`0oooo00080?ooo`0307lZ:P3oool0oooo01/0oooo00<0o`3o0?ooo`3o
ool06@3oool00`1o:RX0oooo0?ooo`0H0?ooo`030?l0o`3oool0oooo01H0oooo00<0ObXZ0?ooo`3o
ool0503oool00`3o0?l0oooo0?ooo`0D0?ooo`0307lZ:P3oool0oooo0140oooo00<0o`3o0?ooo`3o
ool0403oool00`1o:RX0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00d0oooo00<0ObXZ0?ooo`3o
ool02`3oool00`3o0?l0oooo0?ooo`0:0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3o
ool01`3oool00`1o:RX0oooo0?ooo`050?ooo`030?l0o`3oool0oooo00@0oooo00<0ObXZ0?ooo`3o
ool00`3oool01`3o0?l0oooo0?l0o`3o0?l0ObXZ0?ooo`0000000P3oool00`1o:RX0oooo0?l0o`02
0?l0o`80oooo00<0o`3o0?ooo`3oool01P3oool00`1o:RX0oooo0?ooo`0/0?ooo`00203oool00`1o
:RX0oooo0?ooo`0K0?ooo`030?l0o`3oool0oooo01T0oooo00<0ObXZ0?ooo`3oool0603oool00`3o
0?l0oooo0?ooo`0F0?ooo`0307lZ:P3oool0oooo01@0oooo00<0o`3o0?ooo`3oool0503oool00`1o
:RX0oooo0?ooo`0A0?ooo`030?l0o`3oool0oooo0100oooo00<0ObXZ0?ooo`3oool03`3oool00`3o
0?l0oooo0?ooo`0=0?ooo`0307lZ:P3oool0oooo00/0oooo00<0o`3o0?ooo`3oool02P3oool00`1o
:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00L0oooo00<0ObXZ0?ooo`3oool01@3oool00`3o
0?l0oooo0?ooo`040?ooo`0307lZ:P3oool0oooo00<0oooo0P3o0?l30?ooo`0407lZ:P000000oooo
07lZ:PD0oooo103o0?l60?ooo`0307lZ:P3oool0oooo02d0oooo00080?ooo`0307lZ:P3oool0oooo
01/0oooo00<0o`3o0?ooo`3oool06@3oool00`1o:RX0oooo0?ooo`0H0?ooo`030?l0o`3oool0oooo
01H0oooo00<0ObXZ0?ooo`3oool0503oool00`3o0?l0oooo0?ooo`0D0?ooo`0307lZ:P3oool0oooo
0140oooo00<0o`3o0?ooo`3oool0403oool00`1o:RX0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo
00d0oooo00<0ObXZ0?ooo`3oool02`3oool00`3o0?l0oooo0?ooo`0:0?ooo`0307lZ:P3oool0oooo
00T0oooo00<0o`3o0?ooo`3oool01`3oool00`1o:RX0oooo0?ooo`050?ooo`030?l0o`3oool0oooo
00@0oooo00<0ObXZ0?ooo`3o0?l00`3o0?l00`3oool0o`3o0?ooo`030?ooo`<0ObXZ1P3oool00`3o
0?l0oooo0?ooo`040?l0o`80oooo00<0ObXZ0?ooo`3oool0;@3oool000P0oooo00<0ObXZ0?ooo`3o
ool06`3oool00`3o0?l0oooo0?ooo`0I0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o0?ooo`3o
ool05P3oool00`1o:RX0oooo0?ooo`0D0?ooo`030?l0o`3oool0oooo01@0oooo00<0ObXZ0?ooo`3o
ool04@3oool00`3o0?l0oooo0?ooo`0@0?ooo`0307lZ:P3oool0oooo00l0oooo00<0o`3o0?ooo`3o
ool03@3oool00`1o:RX0oooo0?ooo`0;0?ooo`030?l0o`3oool0oooo00X0oooo00<0ObXZ0?ooo`3o
ool02@3oool00`3o0?l0oooo0?ooo`070?ooo`0307lZ:P3oool0oooo00H0oooo00@0o`3o0?ooo`3o
ool0oooo0`3o0?l00`1o:RX0oooo0?ooo`030?ooo`030?l0o`3oool0oooo0080oooo00<0000007lZ
:P1o:RX01P3oool00`3o0?l0oooo0?ooo`040?ooo`<0o`3o;`3oool000P0oooo00<0ObXZ0?ooo`3o
ool06`3oool00`3o0?l0oooo0?ooo`0I0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o0?ooo`3o
ool05P3oool00`1o:RX0oooo0?ooo`0D0?ooo`030?l0o`3oool0oooo01@0oooo00<0ObXZ0?ooo`3o
ool04@3oool00`3o0?l0oooo0?ooo`0@0?ooo`0307lZ:P3oool0oooo00l0oooo00<0o`3o0?ooo`3o
ool03@3oool00`1o:RX0oooo0?ooo`0;0?ooo`030?l0o`3oool0oooo00X0oooo00<0ObXZ0?ooo`3o
ool02@3oool00`3o0?l0oooo0?ooo`070?ooo`0307lZ:P3oool0oooo00H0oooo103o0?l30?ooo`03
07lZ:P3oool0oooo00@0oooo00H0o`3o0?ooo`3oool0oooo07lZ:P3oool207lZ:P@0oooo00<0o`3o
0?ooo`3oool01`3oool0101o:RX0oooo0?ooo`3oool5000002L0oooo00080?ooo`0307lZ:P3oool0
oooo01/0oooo00<0o`3o0?ooo`3oool06@3oool00`1o:RX0oooo0?ooo`0H0?ooo`030?l0o`3oool0
oooo01H0oooo00<0ObXZ0?ooo`3oool05@3oool00`3o0?l0oooo0?ooo`0C0?ooo`0307lZ:P3oool0
oooo0140oooo00<0o`3o0?ooo`3oool0403oool00`1o:RX0oooo0?ooo`0?0?ooo`030?l0o`3oool0
oooo00d0oooo00<0ObXZ0?ooo`3oool02`3oool00`3o0?l0oooo0?ooo`0;0?ooo`0307lZ:P3oool0
oooo00P0oooo00<0o`3o0?ooo`3oool01`3oool00`1o:RX0oooo0?ooo`040?ooo`<0o`3o1P3oool0
0`1o:RX0oooo0?ooo`040?ooo`050?l0o`3oool0oooo0?ooo`1o:RX00`3oool01@1o:RX0oooo0?oo
o`3oool0o`3o00T0oooo00D0ObXZ0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02H0
oooo00080?ooo`0307lZ:P3oool0oooo01/0oooo00<0o`3o0?ooo`3oool06@3oool00`1o:RX0oooo
0?ooo`0H0?ooo`030?l0o`3oool0oooo01H0oooo00<0ObXZ0?ooo`3oool05@3oool00`3o0?l0oooo
0?ooo`0C0?ooo`0307lZ:P3oool0oooo0140oooo00<0o`3o0?ooo`3oool0403oool00`1o:RX0oooo
0?ooo`0?0?ooo`030?l0o`3oool0oooo00d0oooo00<0ObXZ0?ooo`3oool0303oool00`3o0?l0oooo
0?ooo`0:0?ooo`0307lZ:P3oool0oooo00P0oooo00<0o`3o0?ooo`3oool01`3oool00`1o:RX0oooo
0?ooo`040?l0o`80oooo00<0o`3o0?ooo`3oool01@3oool00`1o:RX0oooo0?ooo`040?ooo`040?l0
o`3oool0ObXZ000000@0oooo0P1o:RX00`3o0?l0oooo0?ooo`080?ooo`0507lZ:P3oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0V0?ooo`00203oool00`1o:RX0oooo0?ooo`0K0?ooo`03
0?l0o`3oool0oooo01T0oooo00<0ObXZ0?ooo`3oool0603oool00`3o0?l0oooo0?ooo`0F0?ooo`03
07lZ:P3oool0oooo01D0oooo00<0o`3o0?ooo`3oool04`3oool00`1o:RX0oooo0?ooo`0A0?ooo`03
0?l0o`3oool0oooo0100oooo00<0ObXZ0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0=0?ooo`03
07lZ:P3oool0oooo00`0oooo00<0o`3o0?ooo`3oool02P3oool00`1o:RX0oooo0?ooo`080?ooo`03
0?l0o`3oool0oooo00D0oooo0`3o0?l00`1o:RX0o`3o0?ooo`050?ooo`030?l0o`3oool0oooo00D0
oooo00<0ObXZ0?ooo`3oool0103oool0101o:RX0o`3o0?ooo`0000060?ooo`80ObXZ203oool00`1o
:RX0oooo0?ooo`030?ooo`@000009`3oool000P0oooo00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0
oooo0?ooo`0I0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o0?ooo`3oool05P3oool00`1o:RX0
oooo0?ooo`0E0?ooo`030?l0o`3oool0oooo01<0oooo00<0ObXZ0?ooo`3oool04@3oool00`3o0?l0
oooo0?ooo`0@0?ooo`0307lZ:P3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03@3oool00`1o:RX0
oooo0?ooo`0<0?ooo`030?l0o`3oool0oooo00X0oooo00<0ObXZ0?ooo`3oool0203oool80?l0o`<0
oooo00<0ObXZ0?ooo`3oool01P3oool00`3o0?l0oooo0?ooo`050?ooo`0307lZ:P3oool0oooo0080
oooo00D0ObXZ0?ooo`3oool0o`3o000000060?ooo`040?l0o`3oool0ObXZ07lZ:PH0oooo00<0ObXZ
0?ooo`3oool01P3oool00`000000oooo0?ooo`0U0?ooo`00203oool00`1o:RX0oooo0?ooo`0K0?oo
o`030?l0o`3oool0oooo01T0oooo00<0ObXZ0?ooo`3oool0603oool00`3o0?l0oooo0?ooo`0F0?oo
o`0307lZ:P3oool0oooo01D0oooo00<0o`3o0?ooo`3oool04`3oool00`1o:RX0oooo0?ooo`0A0?oo
o`030?l0o`3oool0oooo0100oooo00<0ObXZ0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0=0?oo
o`0307lZ:P3oool0oooo00`0oooo00<0o`3o0?ooo`3oool02P3oool00`1o:RX0oooo0?ooo`050?oo
o`D0o`3o2@3oool00`1o:RX0oooo0?ooo`060?ooo`030?l0o`3oool0oooo00H0oooo00@0ObXZ0?oo
o`1o:RX0ObXZ0`3oool00`3o0?l000000?ooo`040?ooo`030?l0o`3oool0oooo0080oooo0`1o:RX2
0?ooo`0307lZ:P3oool0oooo00D0oooo0`0000020?ooo`<000008P3oool000P0oooo00<0ObXZ0?oo
o`3oool06`3oool00`3o0?l0oooo0?ooo`0I0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o0?oo
o`3oool05P3oool00`1o:RX0oooo0?ooo`0E0?ooo`030?l0o`3oool0oooo01<0oooo00<0ObXZ0?oo
o`3oool04@3oool00`3o0?l0oooo0?ooo`0A0?ooo`0307lZ:P3oool0oooo00h0oooo00<0o`3o0?oo
o`3oool03@3oool00`1o:RX0oooo0?ooo`0<0?ooo`030?l0o`3oool0oooo00X0oooo00<0ObXZ0?l0
o`3o0?l01@3o0?l40?ooo`030?l0o`3oool0oooo00L0oooo00<0ObXZ0?ooo`3oool01P3oool00`3o
0?l0oooo0?ooo`060?ooo`80ObXZ1P3oool00`3o0?l0oooo0?ooo`030?ooo`030?l0o`3oool0oooo
00D0oooo00<0ObXZ0?ooo`1o:RX0303oool00`000000oooo0?ooo`0R0?ooo`00203oool00`1o:RX0
oooo0?ooo`0K0?ooo`030?l0o`3oool0oooo01T0oooo00<0ObXZ0?ooo`3oool0603oool00`3o0?l0
oooo0?ooo`0F0?ooo`0307lZ:P3oool0oooo01D0oooo00<0o`3o0?ooo`3oool04`3oool00`1o:RX0
oooo0?ooo`0B0?ooo`030?l0o`3oool0oooo0100oooo00<0ObXZ0?ooo`3oool03P3oool00`3o0?l0
oooo0?ooo`0=0?ooo`0307lZ:P3oool0oooo00`0oooo00<0o`3o0?ooo`3oool00`3oool70?l0o`03
07lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool0203oool00`1o:RX0oooo0?ooo`060?ooo`03
0?l0o`3oool0oooo00@0oooo0P1o:RX70?ooo`030000003o0?l0oooo0080oooo00<0o`3o0?ooo`3o
ool01`3oool207lZ:Pd0oooo00<000000?ooo`3oool08@3oool000P0oooo00<0ObXZ0?ooo`3oool0
6`3oool00`3o0?l0oooo0?ooo`0I0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o0?ooo`3oool0
5P3oool00`1o:RX0oooo0?ooo`0E0?ooo`030?l0o`3oool0oooo01<0oooo00<0ObXZ0?ooo`3oool0
4P3oool00`3o0?l0oooo0?ooo`0@0?ooo`0307lZ:P3oool0oooo00h0oooo00<0o`3o0?ooo`3oool0
3@3oool00`1o:RX0oooo0?ooo`0<0?ooo`H0o`3o1`3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0
o`3oool0oooo00P0oooo00<0ObXZ0?ooo`3oool01P3oool00`3o0?l0oooo0?ooo`020?ooo`80ObXZ
0P3oool00`1o:RX0oooo0?ooo`040?ooo`030000003oool0o`3o0080o`3o2P3oool00`1o:RX0oooo
0?ooo`0<0?ooo`030000003oool0oooo0240oooo00080?ooo`0307lZ:P3oool0oooo01/0oooo00<0
o`3o0?ooo`3oool06@3oool00`1o:RX0oooo0?ooo`0H0?ooo`030?l0o`3oool0oooo01H0oooo00<0
ObXZ0?ooo`3oool05@3oool00`3o0?l0oooo0?ooo`0C0?ooo`0307lZ:P3oool0oooo0180oooo00<0
o`3o0?ooo`3oool0403oool00`1o:RX0oooo0?ooo`0>0?ooo`030?l0o`3oool0oooo00d0oooo00<0
ObXZ0?ooo`3oool01`3oool60?l0o`d0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo0?oo
o`070?ooo`0307lZ:P3oool0oooo00L0oooo00@0o`3o0?ooo`3oool0ObXZ1@3oool00`1o:RX0oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`3o0?l02@3oool00`1o:RX0oooo0?ooo`0<0?ooo`03
0000003oool000000280oooo00080?ooo`0307lZ:P3oool0oooo01/0oooo00<0o`3o0?ooo`3oool0
6@3oool00`1o:RX0oooo0?ooo`0H0?ooo`030?l0o`3oool0oooo01H0oooo00<0ObXZ0?ooo`3oool0
5@3oool00`3o0?l0oooo0?ooo`0C0?ooo`0307lZ:P3oool0oooo0180oooo00<0o`3o0?ooo`3oool0
403oool00`1o:RX0oooo0?ooo`0>0?ooo`030?l0o`3oool0oooo00h0oooo00<0ObXZ0?ooo`3oool0
1P3o0?l50?ooo`030?l0o`3oool0oooo00/0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0oooo
0?ooo`070?ooo`0307lZ:P3oool0oooo00L0oooo00<0o`3o07lZ:P1o:RX01P3oool00`1o:RX0oooo
0?ooo`030?ooo`060000003oool0oooo0?l0o`3oool0o`3o203oool00`1o:RX0oooo0?ooo`0=0?oo
o`030000003oool0oooo0240oooo00080?ooo`0307lZ:P3oool0oooo01/0oooo00<0o`3o0?ooo`3o
ool06@3oool00`1o:RX0oooo0?ooo`0H0?ooo`030?l0o`3oool0oooo01H0oooo00<0ObXZ0?ooo`3o
ool05@3oool00`3o0?l0oooo0?ooo`0C0?ooo`0307lZ:P3oool0oooo0180oooo00<0o`3o0?ooo`3o
ool0403oool00`1o:RX0oooo0?ooo`0>0?ooo`030?l0o`3oool0oooo00L0oooo1`3o0?l00`1o:RX0
o`3o0?l0o`0<0?ooo`030?l0o`3oool0oooo00X0oooo00<0ObXZ0?ooo`3oool02@3oool00`3o0?l0
oooo0?ooo`080?ooo`0307lZ:P3oool0oooo00D0oooo0P1o:RX00`3o0?l0oooo0?ooo`060?ooo`03
07lZ:P3oool0oooo0080oooo00<000000?ooo`3o0?l00`3oool30?l0o`D0oooo00<0ObXZ0?ooo`3o
ool0<@3oool000P0oooo00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0I0?ooo`0307lZ
:P3oool0oooo01P0oooo00<0o`3o0?ooo`3oool05P3oool00`1o:RX0oooo0?ooo`0E0?ooo`030?l0
o`3oool0oooo01<0oooo00<0ObXZ0?ooo`3oool04P3oool00`3o0?l0oooo0?ooo`0@0?ooo`0307lZ
:P3oool0oooo00h0oooo2P3o0?l70?ooo`0307lZ:P3oool0oooo00`0oooo00<0o`3o0?ooo`3oool0
2P3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo00P0oooo00<0ObXZ0?ooo`3oool0
0`3oool207lZ:P80oooo00<0o`3o0?ooo`3oool01`3oool01P1o:RX0oooo0?ooo`3oool000000?l0
o`L0oooo00D0o`3o0?ooo`3oool0oooo07lZ:P0d0?ooo`00203oool00`1o:RX0oooo0?ooo`0K0?oo
o`030?l0o`3oool0oooo01X0oooo00<0ObXZ0?ooo`3oool05`3oool00`3o0?l0oooo0?ooo`0F0?oo
o`0307lZ:P3oool0oooo01D0oooo00<0o`3o0?ooo`3oool04`3oool00`1o:RX0oooo0?ooo`0B0?oo
o`030?l0o`3oool0oooo0100oooo00<0ObXZ0?ooo`3oool01P3oool80?l0o`030?ooo`3o0?l0oooo
00h0oooo00<0ObXZ0?ooo`3oool0303oool00`3o0?l0oooo0?ooo`0:0?ooo`0307lZ:P3oool0oooo
00T0oooo00<0o`3o0?ooo`3oool0203oool0101o:RX0oooo0?ooo`3oool207lZ:P@0oooo00<0o`3o
0?ooo`3oool0203oool0101o:RX0oooo0?l0o`3o0?l90?ooo`80o`3o00<0oooo07lZ:P3oool0<`3o
ool000P0oooo00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0J0?ooo`0307lZ:P3oool0
oooo01L0oooo00<0o`3o0?ooo`3oool05P3oool00`1o:RX0oooo0?ooo`0E0?ooo`030?l0o`3oool0
oooo01<0oooo00<0ObXZ0?ooo`3oool04P3oool00`3o0?l0oooo0?ooo`0>0?ooo`80o`3o00<0ObXZ
0?l0o`3o0?l01P3o0?l90?ooo`030?l0o`3oool0oooo00d0oooo00<0ObXZ0?ooo`3oool0303oool0
0`3o0?l0oooo0?ooo`0;0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool0203oool3
07lZ:PL0oooo00<0o`3o0?ooo`3oool0203oool00`1o:RX0oooo0000000;0?ooo`030?l0o`3oool0
oooo03<0oooo00090?ooo`0307lZ:P3oool0oooo01X0oooo00<0o`3o0?ooo`3oool06P3oool00`1o
:RX0oooo0?ooo`0G0?ooo`030?l0o`3oool0oooo01L0oooo00<0ObXZ0?ooo`3oool0503oool00`3o
0?l0oooo0?ooo`0C0?ooo`0307lZ:P3oool0oooo0180oooo00<0o`3o0?ooo`3oool00P3oool<0?l0
o`80oooo00<0ObXZ0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0=0?ooo`0307lZ:P3oool0oooo
00`0oooo00<0o`3o0?ooo`3oool02`3oool00`1o:RX0oooo0?ooo`090?ooo`030?l0o`3oool0oooo
00H0oooo0`1o:RX:0?ooo`030?l0o`3oool0oooo00H0oooo00@0o`3o0?ooo`1o:RX000002P3oool0
0`1o:RX0oooo0?ooo`0d0?ooo`002@3oool00`1o:RX0oooo0?ooo`0J0?ooo`030?l0o`3oool0oooo
01X0oooo00<0ObXZ0?ooo`3oool05`3oool00`3o0?l0oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo
01@0oooo00<0o`3o0?ooo`3oool04`3oool00`1o:RX0oooo0?ooo`0?0?ooo`P0o`3o3P3oool00`1o
:RX0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00h0oooo00<0ObXZ0?ooo`3oool02`3oool00`3o
0?l0oooo0?ooo`0;0?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?ooo`3oool00`3oool307lZ
:P<0oooo00<0ObXZ0?ooo`3oool01`3oool00`3o0?l0oooo0?ooo`050?ooo`050?l0o`3oool0oooo
0?ooo`1o:RX02P3oool00`1o:RX0oooo0?ooo`0d0?ooo`002@3oool00`1o:RX0oooo0?ooo`0J0?oo
o`030?l0o`3oool0oooo01X0oooo00<0ObXZ0?ooo`3oool0603oool00`3o0?l0oooo0?ooo`0F0?oo
o`0307lZ:P3oool0oooo01@0oooo00<0o`3o0?ooo`3oool0503oool00`1o:RX0oooo0?ooo`050?oo
o`T0o`3o0`3oool00`3o0?l0oooo0?ooo`0A0?ooo`0307lZ:P3oool0oooo00h0oooo00<0o`3o0?oo
o`3oool03P3oool00`1o:RX0oooo0?ooo`0<0?ooo`030?l0o`3oool0oooo00X0oooo00<0ObXZ0?oo
o`3oool02@3oool00`3o0?l0oooo0?ooo`0307lZ:PH0oooo00<0ObXZ0?ooo`3oool0203oool00`3o
0?l0oooo0?ooo`030?ooo`030?l0o`3oool0oooo0080oooo00<0000007lZ:P3oool01`3oool00`1o
:RX0oooo0?ooo`0e0?ooo`002@3oool00`1o:RX0oooo0?ooo`0J0?ooo`030?l0o`3oool0oooo01X0
oooo00<0ObXZ0?ooo`3oool0603oool00`3o0?l0oooo0?ooo`0F0?ooo`0307lZ:P3oool0oooo01D0
oooo00<0o`3o0?ooo`3oool04P3oool00`3o0?l0ObXZ0?l0o`060?l0o``0oooo00<0o`3o0?ooo`3o
ool04@3oool00`1o:RX0oooo0?ooo`0>0?ooo`030?l0o`3oool0oooo00h0oooo00<0ObXZ0?ooo`3o
ool0303oool00`3o0?l0oooo0?ooo`0:0?ooo`0307lZ:P3oool0oooo00T0oooo00<0ObXZ0?l0o`1o
:RX02P3oool00`1o:RX0oooo0?ooo`070?ooo`040?l0o`3oool0oooo0?ooo`80o`3o1@3oool00`00
0000oooo07lZ:P060?ooo`0307lZ:P3oool0oooo03H0oooo00090?ooo`0307lZ:P3oool0oooo01X0
oooo00<0o`3o0?ooo`3oool06P3oool00`1o:RX0oooo0?ooo`0H0?ooo`030?l0o`3oool0oooo01H0
oooo00<0ObXZ0?ooo`3oool05@3oool00`3o0?l0oooo0?ooo`050?ooo`d0o`3o00<0oooo07lZ:P3o
ool04P3oool00`3o0?l0oooo0?ooo`0A0?ooo`0307lZ:P3oool0oooo00l0oooo00<0o`3o0?ooo`3o
ool03@3oool00`1o:RX0oooo0?ooo`0<0?ooo`030?l0o`3oool0oooo00/0oooo00<0ObXZ0?ooo`3o
ool01@3oool307lZ:P030?ooo`3o0?l0oooo00X0oooo00<0ObXZ0?ooo`3oool0203oool00`3o0?l0
oooo0?l0o`070?ooo`030000003oool0oooo0080ObXZ0`3oool00`1o:RX0oooo0?ooo`0g0?ooo`00
2@3oool00`1o:RX0oooo0?ooo`0K0?ooo`030?l0o`3oool0oooo01T0oooo00<0ObXZ0?ooo`3oool0
603oool00`3o0?l0oooo0?ooo`0F0?ooo`0307lZ:P3oool0oooo00l0oooo3P3o0?l>0?ooo`0307lZ
:P3oool0oooo0180oooo00<0o`3o0?ooo`3oool0403oool00`1o:RX0oooo0?ooo`0?0?ooo`030?l0
o`3oool0oooo00d0oooo00<0ObXZ0?ooo`3oool0303oool00`3o0?l0oooo0?ooo`0;0?ooo`0307lZ
:P3oool0oooo0080oooo0`1o:RX50?ooo`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0
203oool20?l0o`L0oooo00D000000?ooo`3oool0oooo07lZ:P020?ooo`0307lZ:P3oool0oooo03P0
oooo00090?ooo`0307lZ:P3oool0oooo01/0oooo00<0o`3o0?ooo`3oool06@3oool00`1o:RX0oooo
0?ooo`0H0?ooo`030?l0o`3oool0oooo01H0oooo00<0ObXZ0?ooo`3oool01@3oool:0?l0o`H0oooo
00<0o`3o0?ooo`3oool04`3oool00`1o:RX0oooo0?ooo`0B0?ooo`030?l0o`3oool0oooo0100oooo
00<0ObXZ0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0=0?ooo`0307lZ:P3oool0oooo00`0oooo
00<0o`3o0?ooo`3oool02`3oool00`1o:RX0oooo0?ooo`0207lZ:PP0oooo00<0o`3o0?ooo`3oool0
2@3oool00`1o:RX0oooo0?ooo`060?ooo`80o`3o00<0oooo0?l0o`3oool01P3oool00`000000oooo
0?ooo`020?ooo`0307lZ:P3oool0ObXZ03X0oooo00090?ooo`0307lZ:P3oool0oooo01/0oooo00<0
o`3o0?ooo`3oool06@3oool00`1o:RX0oooo0?ooo`0H0?ooo`030?l0o`3oool0oooo00l0oooo1`3o
0?l00`1o:RX0o`3o0?l0o`050?l0oa00oooo00<0o`3o0?ooo`3oool04`3oool00`1o:RX0oooo0?oo
o`0B0?ooo`030?l0o`3oool0oooo0100oooo00<0ObXZ0?ooo`3oool03`3oool00`3o0?l0oooo0?oo
o`0=0?ooo`0307lZ:P3oool0oooo00d0oooo00<0o`3o0?ooo`3oool02P3oool307lZ:P/0oooo00<0
o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`040?ooo`030?l0o`3oool0oooo0080oooo00<0
o`3o0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`80ObXZ>P3oool000T0oooo00<0ObXZ
0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0I0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o
0?ooo`3o0?l03`3o0?l70?ooo`0307lZ:P3oool0oooo01D0oooo00<0o`3o0?ooo`3oool04`3oool0
0`1o:RX0oooo0?ooo`0B0?ooo`030?l0o`3oool0oooo0100oooo00<0ObXZ0?ooo`3oool03`3oool0
0`3o0?l0oooo0?ooo`0>0?ooo`0307lZ:P3oool0oooo00`0oooo00<0o`3o0?ooo`3oool0203oool2
07lZ:P030?ooo`1o:RX0oooo00/0oooo00<0o`3o0?ooo`3oool02@3oool00`1o:RX0oooo0?ooo`03
0?ooo`030?l0o`3oool0oooo00@0oooo00<0o`3o0?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`0307lZ:P3oool0oooo03X0oooo00090?ooo`0307lZ:P3oool0oooo01/0oooo00<0o`3o0?oo
o`3oool06@3oool00`1o:RX0oooo0?ooo`0@0?ooo`X0o`3o5`3oool00`1o:RX0oooo0?ooo`0E0?oo
o`030?l0o`3oool0oooo01<0oooo00<0ObXZ0?ooo`3oool04P3oool00`3o0?l0oooo0?ooo`0@0?oo
o`0307lZ:P3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03P3oool00`1o:RX0oooo0?ooo`0<0?oo
o`030?l0o`3oool0oooo00D0oooo0`1o:RX40?ooo`0307lZ:P3oool0oooo00T0oooo00<0o`3o0?oo
o`3oool02P3oool00`1o:RX0oooo0?ooo`020?l0o`L0oooo00<0o`3o0?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool0ObXZ03d0oooo00090?ooo`0307lZ:P3oool0oooo01/0oooo00<0o`3o0?oo
o`3oool06@3oool00`1o:RX0oooo0?l0o`0@0?l0o`P0oooo00<0o`3o0?ooo`3oool05P3oool00`1o
:RX0oooo0?ooo`0E0?ooo`030?l0o`3oool0oooo01<0oooo00<0ObXZ0?ooo`3oool04P3oool00`3o
0?l0oooo0?ooo`0A0?ooo`0307lZ:P3oool0oooo00h0oooo00<0o`3o0?ooo`3oool03P3oool00`1o
:RX0oooo0?ooo`0=0?ooo`030?l0o`3oool0oooo00@0ObXZ1`3oool00`1o:RX0oooo0?ooo`0:0?oo
o`030?l0o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3o0?l02P3oool00`3o0?l0oooo0?ooo`020?oo
o`040000003oool0oooo07lZ:Sh0oooo00090?ooo`0307lZ:P3oool0oooo01/0oooo00<0o`3o0?oo
o`3oool02@3oool@0?l0o`0307lZ:P3o0?l0oooo01P0oooo00<0o`3o0?ooo`3oool05P3oool00`1o
:RX0oooo0?ooo`0E0?ooo`030?l0o`3oool0oooo01@0oooo00<0ObXZ0?ooo`3oool04@3oool00`3o
0?l0oooo0?ooo`0A0?ooo`0307lZ:P3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03P3oool00`1o
:RX0oooo0?ooo`0;0?ooo`0407lZ:P3o0?l0ObXZ07lZ:P/0oooo00<0ObXZ0?ooo`3oool02P3oool0
0`3o0?l0oooo0?ooo`090?ooo`030?l0o`1o:RX0oooo00/0oooo0P3o0?l20?ooo`030000003oool0
ObXZ03l0oooo00090?ooo`0307lZ:P3oool0oooo01/0oooo303o0?l@0?ooo`0307lZ:P3oool0oooo
01P0oooo00<0o`3o0?ooo`3oool05P3oool00`1o:RX0oooo0?ooo`0E0?ooo`030?l0o`3oool0oooo
01@0oooo00<0ObXZ0?ooo`3oool04@3oool00`3o0?l0oooo0?ooo`0A0?ooo`0307lZ:P3oool0oooo
00l0oooo00<0o`3o0?ooo`3oool03P3oool00`1o:RX0oooo0?ooo`070?ooo`@0ObXZ00<0oooo0?l0
o`3oool03@3oool00`1o:RX0oooo0?ooo`0:0?ooo`030?l0o`3oool0oooo00L0oooo00<0o`3o0?oo
o`1o:RX03@3oool01P3o0?l0oooo0?ooo`000000oooo07lZ:Sl0oooo00090?ooo`0307lZ:P3oool0
oooo0100oooo303o0?lK0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o0?ooo`3oool05P3oool0
0`1o:RX0oooo0?ooo`0F0?ooo`030?l0o`3oool0oooo01<0oooo00<0ObXZ0?ooo`3oool04P3oool0
0`3o0?l0oooo0?ooo`0@0?ooo`0307lZ:P3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03P3oool0
0`1o:RX0oooo0?ooo`030?ooo`@0ObXZ1P3oool00`3o0?l0oooo0?ooo`0;0?ooo`0307lZ:P3oool0
oooo00X0oooo00<0o`3o0?ooo`3oool01@3oool20?l0o`<0oooo00<0ObXZ0?ooo`3oool02`3oool0
103o0?l0oooo0000001o:RY00?ooo`002@3oool00`1o:RX0oooo0?ooo`040?ooo``0o`3o2`3oool0
0`3o0?l0oooo0?ooo`0I0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o0?ooo`3oool05P3oool0
0`1o:RX0oooo0?ooo`0F0?ooo`030?l0o`3oool0oooo01<0oooo00<0ObXZ0?ooo`3oool04P3oool0
0`3o0?l0oooo0?ooo`0@0?ooo`0307lZ:P3oool0oooo0100oooo00<0o`3o0?ooo`3oool03@3oool0
0`1o:RX0oooo07lZ:P0307lZ:PX0oooo00<0o`3o0?ooo`3oool0303oool00`1o:RX0oooo0?ooo`0:
0?ooo`030?l0o`3oool0oooo0080oooo0P3o0?l60?ooo`0307lZ:P3oool0oooo00/0oooo00<0o`3o
07lZ:P3oool0@03oool000T0oooo00<0ObXZ0?l0o`3o0?l0103o0?lG0?ooo`030?l0o`3oool0oooo
01X0oooo00<0ObXZ0?ooo`3oool05`3oool00`3o0?l0oooo0?ooo`0F0?ooo`0307lZ:P3oool0oooo
01H0oooo00<0o`3o0?ooo`3oool04`3oool00`1o:RX0oooo0?ooo`0B0?ooo`030?l0o`3oool0oooo
0100oooo00<0ObXZ0?ooo`3oool0403oool00`3o0?l0oooo0?ooo`0:0?ooo`D0ObXZ3P3oool00`3o
0?l0oooo0?ooo`0<0?ooo`0307lZ:P3oool0oooo00X0oooo00D0o`3o0?ooo`3oool0oooo0?l0o`09
0?ooo`0307lZ:P3oool0oooo00X0oooo00<0ObXZ0?l0o`3oool0@03oool000T0oooo00<0ObXZ0?oo
o`3oool06`3oool00`3o0?l0oooo0?ooo`0J0?ooo`0307lZ:P3oool0oooo01L0oooo00<0o`3o0?oo
o`3oool05`3oool00`1o:RX0oooo0?ooo`0E0?ooo`030?l0o`3oool0oooo01<0oooo00<0ObXZ0?oo
o`3oool04P3oool00`3o0?l0oooo0?ooo`0@0?ooo`0307lZ:P3oool0oooo0100oooo00<0o`3o0?oo
o`3oool01P3oool407lZ:P<0oooo00<0ObXZ0?ooo`3oool03P3oool00`3o0?l0oooo0?ooo`0;0?oo
o`0307lZ:P3oool0oooo00/0oooo0`3o0?l;0?ooo`0307lZ:P3oool0oooo00P0oooo00<0ObXZ0?oo
o`000000@@3oool000T0oooo00<0ObXZ0?ooo`3oool0703oool00`3o0?l0oooo0?ooo`0I0?ooo`03
07lZ:P3oool0oooo01L0oooo00<0o`3o0?ooo`3oool05`3oool00`1o:RX0oooo0?ooo`0E0?ooo`03
0?l0o`3oool0oooo01<0oooo00<0ObXZ0?ooo`3oool04P3oool00`3o0?l0oooo0?ooo`0@0?ooo`03
07lZ:P3oool0oooo0100oooo00<0o`3o0?ooo`3oool00P3oool407lZ:PP0oooo00<0ObXZ0?ooo`3o
ool03@3oool00`3o0?l0oooo0?ooo`0<0?ooo`0307lZ:P3oool0oooo00T0oooo0P3o0?l=0?ooo`03
07lZ:P3oool0oooo00L0oooo00@0ObXZ0?ooo`3oool00000@@3oool000T0oooo00<0ObXZ0?ooo`3o
ool0703oool00`3o0?l0oooo0?ooo`0I0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o0?ooo`3o
ool05P3oool00`1o:RX0oooo0?ooo`0E0?ooo`030?l0o`3oool0oooo01<0oooo00<0ObXZ0?ooo`3o
ool04P3oool00`3o0?l0oooo0?ooo`0A0?ooo`0307lZ:P3oool0oooo00l0oooo00<0o`3o07lZ:P1o
:RX00P1o:RX<0?ooo`0307lZ:P3oool0oooo00d0oooo00<0o`3o0?ooo`3oool0303oool00`1o:RX0
oooo0?ooo`070?ooo`80o`3o00<0oooo0?l0o`3oool03@3oool00`1o:RX0oooo0?ooo`050?ooo`05
07lZ:P3oool0oooo0?ooo`000000@@3oool000X0oooo00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0
oooo0?ooo`0I0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o0?ooo`3oool05P3oool00`1o:RX0
oooo0?ooo`0E0?ooo`030?l0o`3oool0oooo01<0oooo00<0ObXZ0?ooo`3oool04P3oool00`3o0?l0
oooo0?ooo`0A0?ooo`0307lZ:P3oool0oooo00X0oooo1@1o:RX00`3o0?l0oooo0?ooo`0>0?ooo`03
07lZ:P3oool0oooo00h0oooo00<0o`3o0?ooo`3oool0303oool00`1o:RX0oooo0?ooo`040?ooo`80
o`3o103oool00`3o0?l0oooo0?ooo`0<0?ooo`0307lZ:P3oool0oooo00<0oooo00<0ObXZ0?ooo`3o
ool00P3oool00`000000oooo0?ooo`0o0?ooo`002P3oool00`1o:RX0oooo0?ooo`0K0?ooo`030?l0
o`3oool0oooo01T0oooo00<0ObXZ0?ooo`3oool0603oool00`3o0?l0oooo0?ooo`0F0?ooo`0307lZ
:P3oool0oooo01D0oooo00<0o`3o0?ooo`3oool0503oool00`1o:RX0oooo0?ooo`0A0?ooo`030?l0
o`3oool0oooo0140oooo00<0ObXZ0?ooo`3oool01@3oool507lZ:PD0oooo00<0o`3o0?ooo`3oool0
3`3oool00`1o:RX0oooo0?ooo`0=0?ooo`030?l0o`3oool0oooo00`0oooo00<0ObXZ0?ooo`3oool0
0P3oool20?l0o`L0oooo00<0o`3o0?ooo`3oool0303oool01@1o:RX0oooo0?ooo`3oool0ObXZ00D0
oooo00<000000?ooo`3oool0?`3oool000X0oooo00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo
0?ooo`0I0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o0?ooo`3oool05`3oool00`1o:RX0oooo
0?ooo`0D0?ooo`030?l0o`3oool0oooo01@0oooo00<0ObXZ0?ooo`3oool04P3oool00`3o0?l0oooo
0?ooo`0A0?ooo`0307lZ:P3oool0ObXZ00@0ObXZ2`3oool00`3o0?l0oooo0?ooo`0>0?ooo`0307lZ
:P3oool0oooo00d0oooo00<0o`3o0?ooo`3oool0303oool00`1o:RX0oooo0?ooo`020?l0o`X0oooo
00<0o`3o0?ooo`3oool02`3oool0101o:RX0oooo0?ooo`1o:RX60?ooo`030000003oool0oooo03l0
oooo000:0?ooo`0307lZ:P3oool0oooo01/0oooo00<0o`3o0?ooo`3oool06@3oool00`1o:RX0oooo
0?ooo`0H0?ooo`030?l0o`3oool0oooo01L0oooo00<0ObXZ0?ooo`3oool0503oool00`3o0?l0oooo
0?ooo`0D0?ooo`0307lZ:P3oool0oooo0180oooo00<0o`3o0?ooo`3oool03P3oool507lZ:Q00oooo
00<0o`3o0?ooo`3oool03P3oool00`1o:RX0oooo0?ooo`0>0?ooo`030?l0o`3oool0oooo00`0oooo
00<0ObXZ0?l0o`3oool02`3oool00`3o0?l0oooo0?ooo`0<0?ooo`80ObXZ1`3oool00`000000oooo
0?ooo`0o0?ooo`002P3oool00`1o:RX0oooo0?ooo`0K0?ooo`030?l0o`3oool0oooo01T0oooo00<0
ObXZ0?ooo`3oool0603oool00`3o0?l0oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo01D0oooo00<0
o`3o0?ooo`3oool04`3oool00`1o:RX0oooo0?ooo`0B0?ooo`030?l0o`3oool0oooo00T0oooo1@1o
:RX30?ooo`0307lZ:P3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool00`1o:RX0oooo0?oo
o`0=0?ooo`030?l0o`3oool0oooo00X0oooo0P3o0?l00`1o:RX0oooo0?ooo`0<0?ooo`030?l0o`3o
ool0oooo00/0oooo00<0ObXZ0?ooo`3oool01P3oool00`000000oooo0?ooo`0o0?ooo`002P3oool0
0`1o:RX0oooo0?ooo`0K0?ooo`030?l0o`3oool0oooo01T0oooo00<0ObXZ0?ooo`3oool0603oool0
0`3o0?l0oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo01D0oooo00<0o`3o0?ooo`3oool0503oool0
0`1o:RX0oooo0?ooo`0A0?ooo`030?l0o`3oool0oooo00@0oooo1@1o:RX80?ooo`0307lZ:P3oool0
oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool00`1o:RX0oooo0?ooo`0>0?ooo`030?l0o`3oool0
oooo00L0oooo0P3o0?l30?ooo`0307lZ:P3oool0oooo00`0oooo00<0o`3o0?ooo`3oool0203oool2
07lZ:PT0oooo00<000000?ooo`3oool0?`3oool000X0oooo00<0ObXZ0?ooo`3oool06`3oool00`3o
0?l0oooo0?ooo`0I0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o0?ooo`3oool05`3oool00`1o
:RX0oooo0?ooo`0E0?ooo`030?l0o`3oool0oooo01@0oooo00<0ObXZ0?ooo`3oool04P3oool00`3o
0?l0ObXZ07lZ:P0307lZ:Ph0oooo00<0ObXZ0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0>0?oo
o`0307lZ:P3oool0oooo00h0oooo00<0o`3o0?ooo`3oool0103oool30?l0o`D0oooo00<0ObXZ0?oo
o`3oool03@3oool00`3o0?l0oooo0?ooo`060?ooo`0307lZ:P3oool0oooo00T0oooo00<000000?oo
o`3oool0?`3oool000X0oooo00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0J0?ooo`03
07lZ:P3oool0oooo01L0oooo00<0o`3o0?ooo`3oool05`3oool00`1o:RX0oooo0?ooo`0E0?ooo`03
0?l0o`3oool0oooo01@0oooo00<0ObXZ0?ooo`3oool03@3oool507lZ:P030?l0o`3oool0oooo0140
oooo00<0ObXZ0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`0307lZ:P3oool0oooo00d0
oooo00<0o`3o0?ooo`3oool00P3oool20?l0o`P0oooo00<0ObXZ0?ooo`3oool03@3oool00`3o0?l0
oooo0?ooo`050?ooo`0307lZ:P3oool0oooo00X0oooo00<000000?ooo`3oool0?`3oool000X0oooo
00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0J0?ooo`0307lZ:P3oool0oooo01L0oooo
00<0o`3o0?ooo`3oool05`3oool00`1o:RX0oooo0?ooo`0E0?ooo`030?l0o`3oool0oooo01@0oooo
00<0ObXZ0?ooo`3oool0203oool507lZ:PD0oooo00<0o`3o0?ooo`3oool04@3oool00`1o:RX0oooo
0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo00<0ObXZ0?ooo`3oool03P3oool40?l0o`/0oooo
00<0ObXZ0?ooo`3oool03@3oool00`3o0?l0oooo0?ooo`020?ooo`80ObXZ3@3oool00`000000oooo
0?ooo`0o0?ooo`002P3oool00`1o:RX0oooo0?ooo`0K0?ooo`030?l0o`3oool0oooo01X0oooo00<0
ObXZ0?ooo`3oool05`3oool00`3o0?l0oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo01D0oooo00<0
o`3o0?ooo`3oool0503oool00`1o:RX0oooo0?ooo`040?ooo`@0ObXZ2P3oool00`3o0?l0oooo0?oo
o`0A0?ooo`0307lZ:P3oool0oooo0100oooo00<0o`3o0?ooo`3oool03P3oool00`1o:RX0oooo0?oo
o`0=0?ooo`80o`3o3`3oool00`1o:RX0oooo0?ooo`0<0?ooo`050?l0o`3oool0oooo0?ooo`1o:RX0
3`3oool00`000000oooo0?ooo`0o0?ooo`002P3oool00`1o:RX0oooo0?ooo`0L0?ooo`030?l0o`3o
ool0oooo01T0oooo00<0ObXZ0?ooo`3oool0603oool00`3o0?l0oooo0?ooo`0F0?ooo`0307lZ:P3o
ool0oooo01D0oooo00<0o`3o0?ooo`3oool0503oool00`1o:RX0oooo07lZ:P0407lZ:Pl0oooo00<0
o`3o0?ooo`3oool04@3oool00`1o:RX0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00h0oooo00<0
ObXZ0?ooo`3oool02P3oool30?l0o`030?ooo`3o0?l0oooo00h0oooo00<0ObXZ0?ooo`3oool0303o
ool0103o0?l0oooo07lZ:P1o:RX@0?ooo`030000003oool0oooo03l0oooo000:0?ooo`0307lZ:P3o
ool0oooo01`0oooo00<0o`3o0?ooo`3oool06@3oool00`1o:RX0oooo0?ooo`0H0?ooo`030?l0o`3o
ool0oooo01H0oooo00<0ObXZ0?ooo`3oool05@3oool00`3o0?l0oooo0?ooo`0B0?ooo`@0ObXZ503o
ool00`3o0?l0oooo0?ooo`0A0?ooo`0307lZ:P3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3o
ool00`1o:RX0oooo0?ooo`070?ooo`80o`3o1@3oool00`3o0?l0oooo0?ooo`0=0?ooo`0307lZ:P3o
ool0oooo00`0oooo00<0o`3o0?ooo`3oool0403oool00`000000oooo0?ooo`0o0?ooo`002P3oool0
0`1o:RX0oooo0?ooo`0L0?ooo`030?l0o`3oool0oooo01T0oooo00<0ObXZ0?ooo`3oool0603oool0
0`3o0?l0oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo01@0oooo00<0o`3o0?ooo`3oool0303oool6
07lZ:P80oooo00<0ObXZ0?ooo`3oool04`3oool00`3o0?l0oooo0?ooo`0A0?ooo`0307lZ:P3oool0
oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool00`1o:RX0oooo0?ooo`040?ooo`<0o`3o1`3oool0
0`3o0?l0oooo0?ooo`0=0?ooo`0307lZ:P3oool0oooo00X0oooo0P1o:RXC0?ooo`030000003oool0
oooo03l0oooo000;0?ooo`0307lZ:P3oool0oooo01/0oooo00<0o`3o0?ooo`3oool06@3oool00`1o
:RX0oooo0?ooo`0H0?ooo`030?l0o`3oool0oooo01L0oooo00<0ObXZ0?ooo`3oool05@3oool00`3o
0?l0oooo0?ooo`050?ooo`H0ObXZ203oool00`1o:RX0oooo0?ooo`0C0?ooo`030?l0o`3oool0oooo
0140oooo00<0ObXZ0?ooo`3oool0403oool00`3o0?l0oooo0?ooo`0>0?ooo`0407lZ:P3oool0oooo
0?ooo`<0o`3o2P3oool00`3o0?l0oooo0?ooo`0>0?ooo`0307lZ:P3oool0oooo00P0oooo00<0ObXZ
0?ooo`3oool04`3oool00`000000oooo0?ooo`0o0?ooo`002`3oool00`1o:RX0oooo0?ooo`0K0?oo
o`030?l0o`3oool0oooo01T0oooo00<0ObXZ0?ooo`3oool0603oool00`3o0?l0oooo0?ooo`0G0?oo
o`0307lZ:P3oool0oooo01D0oooo00<0o`3o0?ooo`1o:RX01@1o:RX?0?ooo`0307lZ:P3oool0oooo
01<0oooo00<0o`3o0?ooo`3oool04@3oool00`1o:RX0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo
00l0oooo00<0ObXZ0?l0o`3o0?l03P3oool00`3o0?l0oooo0?ooo`0>0?ooo`0307lZ:P3oool0oooo
00D0oooo0P1o:RXF0?ooo`030000003oool0oooo03l0oooo000;0?ooo`0307lZ:P3oool0oooo01/0
oooo00<0o`3o0?ooo`3oool06@3oool00`1o:RX0oooo0?ooo`0I0?ooo`030?l0o`3oool0oooo01H0
oooo00<0ObXZ0?ooo`3oool04@3oool407lZ:P030?l0o`1o:RX0oooo01@0oooo00<0ObXZ0?ooo`3o
ool04`3oool00`3o0?l0oooo0?ooo`0A0?ooo`0307lZ:P3oool0oooo00l0oooo00<0o`3o0?ooo`3o
ool03@3oool20?l0o`0307lZ:P3oool0oooo00h0oooo00<0o`3o0?ooo`3oool03P3oool00`1o:RX0
oooo0?ooo`040?ooo`0307lZ:P3oool0oooo01H0oooo00<000000?ooo`3oool0?`3oool000/0oooo
00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0I0?ooo`0307lZ:P3oool0oooo01T0oooo
00<0o`3o0?ooo`3oool05P3oool00`1o:RX0oooo0?ooo`0;0?ooo`H0ObXZ103oool00`3o0?l0oooo
0?ooo`0D0?ooo`0307lZ:P3oool0oooo01<0oooo00<0o`3o0?ooo`3oool04@3oool00`1o:RX0oooo
0?ooo`0@0?ooo`030?l0o`3oool0oooo00X0oooo0P3o0?l30?ooo`0307lZ:P3oool0oooo00h0oooo
00<0o`3o0?ooo`3oool03P3oool0101o:RX0oooo0?ooo`3oool207lZ:QT0oooo00<000000?ooo`3o
ool0?`3oool000/0oooo00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0I0?ooo`0307lZ
:P3oool0oooo01T0oooo00<0o`3o0?ooo`3oool05`3oool00`1o:RX0oooo0?ooo`040?ooo`H0ObXZ
2P3oool00`3o0?l0oooo0?ooo`0D0?ooo`0307lZ:P3oool0oooo01<0oooo00<0o`3o0?ooo`3oool0
4@3oool00`1o:RX0oooo0?ooo`0@0?ooo`030?l0o`3oool0oooo00L0oooo0`3o0?l50?ooo`0307lZ
:P3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03@3oool0101o:RX0oooo0?ooo`1o:RXK0?ooo`03
0000003oool0oooo03l0oooo000;0?ooo`0307lZ:P3oool0oooo01/0oooo00<0o`3o0?ooo`3oool0
6@3oool00`1o:RX0oooo0?ooo`0I0?ooo`030?l0o`3oool0oooo01L0oooo1`1o:RXA0?ooo`030?l0
o`3oool0oooo01@0oooo00<0ObXZ0?ooo`3oool04P3oool00`3o0?l0oooo0?ooo`0B0?ooo`0307lZ
:P3oool0oooo00l0oooo00<0o`3o0?ooo`3oool0103oool30?l0o`T0oooo00<0ObXZ0?ooo`3oool0
3P3oool00`3o0?l0oooo0?ooo`0>0?ooo`80ObXZ703oool00`000000oooo0?ooo`0o0?ooo`00303o
ool00`1o:RX0oooo0?ooo`0J0?ooo`030?l0o`3oool0oooo01X0oooo00<0ObXZ0?ooo`3oool0603o
ool00`3o0?l0oooo0?ooo`0@0?ooo`P0ObXZ5`3oool00`3o0?l0oooo0?ooo`0D0?ooo`0307lZ:P3o
ool0oooo01<0oooo00<0o`3o0?ooo`3oool04@3oool00`1o:RX0oooo0?ooo`0?0?ooo`030?l0o`3o
ool0oooo0080oooo0P3o0?l<0?ooo`0307lZ:P3oool0oooo00l0oooo00<0o`3o0?ooo`3oool0303o
ool207lZ:Qd0oooo00<000000?ooo`3oool0?`3oool000`0oooo00<0ObXZ0?ooo`3oool06P3oool0
0`3o0?l0oooo0?ooo`0J0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o0?ooo`3oool02@3oool7
07lZ:PL0oooo00<0ObXZ0?ooo`3oool05@3oool00`3o0?l0oooo0?ooo`0D0?ooo`0307lZ:P3oool0
oooo01<0oooo00<0o`3o0?ooo`3oool04@3oool00`1o:RX0oooo0?ooo`0@0?ooo`@0o`3o3`3oool0
0`1o:RX0oooo0?ooo`0>0?ooo`030?l0o`3oool0oooo00/0oooo00<0ObXZ0?ooo`3oool07@3oool0
0`000000oooo0?ooo`0o0?ooo`00303oool00`1o:RX0oooo0?ooo`0J0?ooo`030?l0o`3oool0oooo
01X0oooo00<0ObXZ0?ooo`3oool06@3oool0103o0?l0oooo0?ooo`3oool707lZ:Ph0oooo00<0ObXZ
0?ooo`3oool05@3oool00`3o0?l0oooo0?ooo`0D0?ooo`0307lZ:P3oool0oooo01<0oooo00<0o`3o
0?ooo`3oool04@3oool00`1o:RX0oooo0?ooo`0>0?ooo`<0o`3o4P3oool00`1o:RX0oooo0?ooo`0?
0?ooo`030?l0o`3oool0oooo00P0oooo0P1o:RXP0?ooo`030000003oool0oooo03l0oooo000<0?oo
o`0307lZ:P3oool0oooo01/0oooo00<0o`3o0?ooo`3oool06@3oool00`1o:RX0oooo0?ooo`0F0?oo
o`<0ObXZ00@0o`3o07lZ:P1o:RX0ObXZ5@3oool00`1o:RX0oooo0?ooo`0E0?ooo`030?l0o`3oool0
oooo01@0oooo00<0ObXZ0?ooo`3oool04`3oool00`3o0?l0oooo0?ooo`0B0?ooo`0307lZ:P3oool0
oooo00X0oooo0`3o0?l30?ooo`030?l0o`3oool0oooo00l0oooo00<0ObXZ0?ooo`3oool03`3oool0
0`3o0?l0oooo0?ooo`070?ooo`0307lZ:P3oool0oooo0200oooo00<000000?ooo`3oool0?`3oool0
00`0oooo00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0I0?ooo`0307lZ:P3oool0oooo
00l0oooo1`1o:RX30?ooo`030?l0o`3oool0oooo01H0oooo00<0ObXZ0?ooo`3oool05P3oool00`3o
0?l0oooo0?ooo`0D0?ooo`0307lZ:P3oool0oooo01<0oooo00<0o`3o0?ooo`3oool04@3oool00`1o
:RX0oooo0?ooo`070?ooo`<0o`3o1P3oool00`3o0?l0oooo0?ooo`0@0?ooo`0307lZ:P3oool0oooo
00l0oooo00<0o`3o0?ooo`3oool0103oool207lZ:R<0oooo00<000000?ooo`3oool0?`3oool000`0
oooo00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0J0?ooo`0307lZ:P3oool0oooo00L0
oooo1`1o:RX:0?ooo`030?l0o`3oool0oooo01H0oooo00<0ObXZ0?ooo`3oool05P3oool00`3o0?l0
oooo0?ooo`0D0?ooo`0307lZ:P3oool0oooo01<0oooo00<0o`3o0?ooo`3oool04@3oool00`1o:RX0
oooo0?ooo`040?ooo`<0o`3o2P3oool00`3o0?l0oooo0?ooo`0?0?ooo`0307lZ:P3oool0oooo00l0
oooo00<0o`3o0?ooo`3oool00P3oool207lZ:RD0oooo00<000000?ooo`3oool0?`3oool000`0oooo
00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0J0?ooo`0307lZ:P3oool0ObXZ00L0ObXZ
4@3oool00`3o0?l0oooo0?ooo`0F0?ooo`0307lZ:P3oool0oooo01H0oooo00<0o`3o0?ooo`3oool0
503oool00`1o:RX0oooo0?ooo`0C0?ooo`030?l0o`3oool0oooo0180oooo00<0ObXZ0?ooo`3oool0
0`3o0?l=0?ooo`030?l0o`3oool0oooo0100oooo00<0ObXZ0?ooo`3oool03`3oool0103o0?l0oooo
07lZ:P1o:RXW0?ooo`030000003oool0oooo03l0oooo000<0?ooo`0307lZ:P3oool0oooo01/0oooo
00<0o`3o0?ooo`3oool0503oool807lZ:QT0oooo00<0o`3o0?ooo`3oool05P3oool00`1o:RX0oooo
0?ooo`0F0?ooo`030?l0o`3oool0oooo01@0oooo00<0ObXZ0?ooo`3oool04`3oool00`3o0?l0oooo
0?ooo`0A0?ooo`040?l0o`1o:RX0o`3o0?l0oa40oooo00<0o`3o0?ooo`3oool03`3oool00`1o:RX0
oooo0?ooo`0?0?ooo`030?l0o`1o:RX0oooo02P0oooo00<000000?ooo`3oool0?`3oool000`0oooo
00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0=0?ooo`L0ObXZ1P3oool00`1o:RX0oooo
0?ooo`0H0?ooo`030?l0o`3oool0oooo01L0oooo00<0ObXZ0?ooo`3oool05@3oool00`3o0?l0oooo
0?ooo`0D0?ooo`0307lZ:P3oool0oooo01@0oooo00<0o`3o0?ooo`3oool0303oool40?l0o`030?oo
o`1o:RX0oooo0180oooo00<0o`3o0?ooo`3oool0403oool00`1o:RX0oooo0?ooo`0<0?ooo`80ObXZ
:`3oool00`000000oooo0?ooo`0o0?ooo`00303oool00`1o:RX0oooo0?ooo`0L0?ooo`030?l0o`3o
ool0oooo00H0oooo1P1o:RX=0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o0?ooo`3oool05`3o
ool00`1o:RX0oooo0?ooo`0F0?ooo`030?l0o`3oool0oooo01@0oooo00<0ObXZ0?ooo`3oool04`3o
ool00`3o0?l0oooo0?ooo`080?ooo`@0o`3o1@3oool00`1o:RX0oooo0?ooo`0A0?ooo`030?l0o`3o
ool0oooo0100oooo00<0ObXZ0?ooo`3oool02`3oool00`1o:RX0oooo0?ooo`0[0?ooo`030000003o
ool0oooo03l0oooo000<0?ooo`0307lZ:P3oool0oooo01`0oooo00<0o`3o0?ooo`3oool01P1o:RXC
0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o0?ooo`3oool05`3oool00`1o:RX0oooo0?ooo`0F
0?ooo`030?l0o`3oool0oooo01@0oooo00<0ObXZ0?ooo`3oool04`3oool00`3o0?l0oooo0?ooo`05
0?ooo`<0o`3o2P3oool00`1o:RX0oooo0?ooo`0@0?ooo`030?l0o`3oool0oooo0100oooo00<0ObXZ
0?ooo`3oool02@3oool207lZ:Rh0oooo00<000000?ooo`3oool0?`3oool000`0oooo00<0ObXZ0?oo
o`3oool06@3oool307lZ:P030?l0o`1o:RX0ObXZ01X0oooo00<0ObXZ0?ooo`3oool05`3oool00`3o
0?l0oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo01H0oooo00<0o`3o0?ooo`3oool0503oool00`1o
:RX0oooo0?ooo`0C0?ooo`030?l0o`3oool0oooo0080oooo0`3o0?l=0?ooo`0307lZ:P3oool0oooo
0140oooo00<0o`3o0?ooo`3oool0403oool00`1o:RX0oooo0?ooo`060?ooo`80ObXZ<03oool00`00
0000oooo0?ooo`0o0?ooo`00303oool00`1o:RX0oooo0?ooo`0B0?ooo`L0ObXZ0`3oool00`3o0?l0
oooo0?ooo`0J0?ooo`0307lZ:P3oool0oooo01L0oooo00<0o`3o0?ooo`3oool05`3oool00`1o:RX0
oooo0?ooo`0F0?ooo`030?l0o`3oool0oooo01@0oooo00<0ObXZ0?ooo`3oool0503oool40?l0oa00
oooo00<0ObXZ0?ooo`3oool04@3oool00`3o0?l0oooo0?ooo`0@0?ooo`0307lZ:P3oool0oooo00@0
oooo0P1o:RXb0?ooo`030000003oool0oooo03l0oooo000=0?ooo`0307lZ:P3oool0oooo00T0oooo
201o:RX:0?ooo`030?l0o`3oool0oooo01X0oooo00<0ObXZ0?ooo`3oool0603oool00`3o0?l0oooo
0?ooo`0G0?ooo`0307lZ:P3oool0oooo01H0oooo00<0o`3o0?ooo`3oool0503oool00`1o:RX0oooo
0?ooo`0@0?ooo`@0o`3o4`3oool00`1o:RX0oooo0?ooo`0B0?ooo`030?l0o`3oool0oooo0100oooo
00@0ObXZ0?ooo`3oool0oooo0P1o:RXZ0?ooo`D000001@3oool00`000000oooo0?ooo`0o0?ooo`00
3@3oool0101o:RX0oooo0?ooo`3oool807lZ:Q80oooo00<0o`3o0?ooo`3oool06P3oool00`1o:RX0
oooo0?ooo`0H0?ooo`030?l0o`3oool0oooo01L0oooo00<0ObXZ0?ooo`3oool05P3oool00`3o0?l0
oooo0?ooo`0D0?ooo`0307lZ:P3oool0oooo00d0oooo0`3o0?l30?ooo`030?l0o`3oool0oooo0180
oooo00<0ObXZ0?ooo`3oool04@3oool00`3o0?l0oooo0?ooo`0@0?ooo`0407lZ:P3oool0ObXZ07lZ
:Rh0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0o0?ooo`003@3oool407lZ:QX0
oooo00<0o`3o0?ooo`3oool06P3oool00`1o:RX0oooo0?ooo`0H0?ooo`030?l0o`3oool0oooo01L0
oooo00<0ObXZ0?ooo`3oool05P3oool00`3o0?l0oooo0?ooo`0D0?ooo`0307lZ:P3oool0oooo00X0
oooo0`3o0?l60?ooo`030?l0o`3oool0oooo0180oooo00<0ObXZ0?ooo`3oool04P3oool00`3o0?l0
oooo0?ooo`0>0?ooo`<0ObXZ<03oool00`000000oooo0?ooo`050?ooo`<00000?`3oool000d0oooo
00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0J0?ooo`0307lZ:P3oool0oooo01P0oooo
00<0o`3o0?ooo`3oool05`3oool00`1o:RX0oooo0?ooo`0F0?ooo`030?l0o`3oool0oooo01@0oooo
00<0ObXZ0?ooo`3oool01P3oool40?l0o`X0oooo00<0o`3o0?ooo`3oool04@3oool00`1o:RX0oooo
0?ooo`0B0?ooo`030?l0o`3oool0oooo00`0oooo0P1o:RXc0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0?`3oool000d0oooo00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?oo
o`0K0?ooo`0307lZ:P3oool0oooo01L0oooo00<0o`3o0?ooo`3oool05`3oool00`1o:RX0oooo0?oo
o`0F0?ooo`030?l0o`3oool0oooo01D0oooo00<0ObXZ0?ooo`3oool00P3oool30?l0o`h0oooo00<0
o`3o0?ooo`3oool04P3oool00`1o:RX0oooo0?ooo`0A0?ooo`030?l0o`3oool0oooo00X0oooo0P1o
:RXe0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0?`3oool000d0oooo00<0ObXZ
0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0K0?ooo`0307lZ:P3oool0oooo01P0oooo00<0o`3o
0?ooo`3oool05`3oool00`1o:RX0oooo0?ooo`0F0?ooo`030?l0o`3oool0oooo01@0oooo00<0ObXZ
0?l0o`3o0?l00P3o0?lA0?ooo`030?l0o`3oool0oooo0180oooo00<0ObXZ0?ooo`3oool04P3oool0
0`3o0?l0oooo0?ooo`070?ooo`80ObXZ=P3oool2000000L0oooo00<000000?ooo`3oool0?`3oool0
00h0oooo00<0ObXZ0?ooo`3oool06P3oool00`3o0?l0oooo0?ooo`0K0?ooo`0307lZ:P3oool0oooo
01P0oooo00<0o`3o0?ooo`3oool05`3oool00`1o:RX0oooo0?ooo`0F0?ooo`030?l0o`3oool0oooo
0140oooo0`3o0?l00`1o:RX0oooo0?ooo`0C0?ooo`030?l0o`3oool0oooo01<0oooo00<0ObXZ0?oo
o`3oool04@3oool00`3o0?l0oooo0?ooo`050?ooo`80ObXZ@@3oool00`000000oooo0?ooo`0o0?oo
o`003P3oool00`1o:RX0oooo0?ooo`0J0?ooo`030?l0o`3oool0oooo01/0oooo00<0ObXZ0?ooo`3o
ool0603oool00`3o0?l0oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo01H0oooo00<0o`3o0?ooo`3o
ool03P3oool30?l0o`<0oooo00<0ObXZ0?ooo`3oool0503oool00`3o0?l0oooo0?ooo`0B0?ooo`03
07lZ:P3oool0oooo0180oooo00<0o`3o0?ooo`3oool00P3oool207lZ:T<0oooo00<000000?ooo`3o
ool0?`3oool000h0oooo00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0J0?ooo`0307lZ
:P3oool0oooo01P0oooo00<0o`3o0?ooo`3oool05`3oool00`1o:RX0oooo0?ooo`0F0?ooo`030?l0
o`3oool0oooo00X0oooo103o0?l60?ooo`0307lZ:P3oool0oooo01@0oooo00<0o`3o0?ooo`3oool0
4`3oool00`1o:RX0oooo0?ooo`0A0?ooo`030?l0o`3oool0ObXZ0080ObXZA@3oool00`000000oooo
0?ooo`0o0?ooo`003P3oool00`1o:RX0oooo0?ooo`0K0?ooo`030?l0o`3oool0oooo01X0oooo00<0
ObXZ0?ooo`3oool0603oool00`3o0?l0oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo01H0oooo00<0
o`3o0?ooo`3oool01P3oool40?l0o`/0oooo00<0ObXZ0?ooo`3oool04`3oool00`3o0?l0oooo0?oo
o`0C0?ooo`0307lZ:P3oool0oooo0140oooo00<0ObXZ0?l0o`3oool0A`3oool00`000000oooo0?oo
o`0o0?ooo`003P3oool00`1o:RX0oooo0?ooo`0K0?ooo`030?l0o`3oool0oooo01/0oooo00<0ObXZ
0?ooo`3oool0603oool00`3o0?l0oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo01H0oooo00@0o`3o
0?ooo`3oool0oooo103o0?l?0?ooo`0307lZ:P3oool0oooo01@0oooo00<0o`3o0?ooo`3oool04P3o
ool00`1o:RX0oooo0?ooo`0?0?ooo`80ObXZBP3oool00`000000oooo0?ooo`0o0?ooo`003P3oool0
0`1o:RX0oooo0?ooo`0K0?ooo`030?l0o`3oool0oooo01/0oooo00<0ObXZ0?ooo`3oool0603oool0
0`3o0?l0oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo01H0oooo103o0?lC0?ooo`0307lZ:P3oool0
oooo01@0oooo00<0o`3o0?ooo`3oool04`3oool00`1o:RX0oooo0?ooo`0<0?ooo`80ObXZC03oool0
0`000000oooo0?ooo`0o0?ooo`003`3oool00`1o:RX0oooo0?ooo`0J0?ooo`030?l0o`3oool0oooo
01/0oooo00<0ObXZ0?ooo`3oool0603oool00`3o0?l0oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo
0180oooo1@3o0?lG0?ooo`0307lZ:P3oool0oooo01@0oooo00<0o`3o0?ooo`3oool04P3oool00`1o
:RX0oooo0?ooo`0:0?ooo`80ObXZCP3oool00`000000oooo0?ooo`0o0?ooo`003`3oool00`1o:RX0
oooo0?ooo`0J0?ooo`030?l0o`3oool0oooo01/0oooo00<0ObXZ0?ooo`3oool0603oool00`3o0?l0
oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo00h0oooo103o0?l40?ooo`030?l0o`3oool0oooo01D0
oooo00<0ObXZ0?ooo`3oool0503oool00`3o0?l0oooo0?ooo`0C0?ooo`0307lZ:P3oool0oooo00L0
oooo0P1o:RY@0?ooo`030000003oool0oooo03l0oooo000?0?ooo`0307lZ:P3oool0oooo01/0oooo
00<0o`3o0?ooo`3oool06P3oool00`1o:RX0oooo0?ooo`0H0?ooo`030?l0o`3oool0oooo01P0oooo
00<0ObXZ0?ooo`3oool0203oool50?l0o`P0oooo00<0o`3o0?ooo`3oool05P3oool00`1o:RX0oooo
0?ooo`0C0?ooo`030?l0o`3oool0oooo01<0oooo00<0ObXZ0?ooo`3oool01@3oool207lZ:U80oooo
00<000000?ooo`3oool0?`3oool000l0oooo00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?oo
o`0K0?ooo`0307lZ:P3oool0oooo01L0oooo00<0o`3o0?ooo`3oool0603oool00`1o:RX0oooo0?oo
o`040?ooo`@0o`3o3P3oool00`3o0?l0oooo0?ooo`0E0?ooo`0307lZ:P3oool0oooo01@0oooo00<0
o`3o0?ooo`3oool04P3oool00`1o:RX0oooo0?ooo`020?ooo`<0ObXZE03oool00`000000oooo0?oo
o`0o0?ooo`003`3oool00`1o:RX0oooo0?ooo`0K0?ooo`030?l0o`3oool0oooo01/0oooo00<0ObXZ
0?ooo`3oool0603oool00`3o0?l0oooo0?ooo`0H0?ooo`0307lZ:P3o0?l0o`3o00<0o`3o4P3oool0
0`3o0?l0oooo0?ooo`0E0?ooo`0307lZ:P3oool0oooo01@0oooo00<0o`3o0?ooo`3oool04`3oool0
101o:RX0oooo07lZ:P1o:RYG0?ooo`030000003oool0oooo03l0oooo000?0?ooo`0307lZ:P3oool0
oooo01/0oooo00<0o`3o0?ooo`3oool06`3oool00`1o:RX0oooo0?ooo`0H0?ooo`030?l0o`3oool0
oooo01D0oooo0`3o0?l00`1o:RX0oooo0?ooo`0E0?ooo`030?l0o`3oool0oooo01D0oooo00<0ObXZ
0?ooo`3oool0503oool00`3o0?l0oooo0?ooo`0B0?ooo`<0ObXZF@3oool00`000000oooo0?ooo`0o
0?ooo`003`3oool00`1o:RX0oooo0?ooo`0K0?ooo`030?l0o`3oool0oooo01/0oooo00<0ObXZ0?oo
o`3oool0603oool00`3o0?l0oooo0?ooo`0A0?ooo`@0o`3o0`3oool00`1o:RX0oooo0?ooo`0F0?oo
o`030?l0o`3oool0oooo01D0oooo00<0ObXZ0?ooo`3oool0503oool00`3o0?l0oooo0?ooo`0>0?oo
o`<0ObXZG03oool00`000000oooo0?ooo`0o0?ooo`00403oool00`1o:RX0oooo0?ooo`0J0?ooo`03
0?l0o`3oool0oooo01/0oooo00<0ObXZ0?ooo`3oool0603oool00`3o0?l0oooo0?ooo`0=0?ooo`@0
o`3o1`3oool00`1o:RX0oooo0?ooo`0F0?ooo`030?l0o`3oool0oooo01D0oooo00<0ObXZ0?ooo`3o
ool0503oool00`3o0?l0oooo0?ooo`0<0?ooo`80ObXZG`3oool00`000000oooo0?ooo`0o0?ooo`00
403oool00`1o:RX0oooo0?ooo`0K0?ooo`030?l0o`3oool0oooo01X0oooo00<0ObXZ0?ooo`3oool0
603oool00`3o0?l0oooo0?ooo`090?ooo`@0o`3o303oool00`1o:RX0oooo0?ooo`0F0?ooo`030?l0
o`3oool0oooo01@0oooo00<0ObXZ0?ooo`3oool05@3oool00`3o0?l0oooo0?ooo`080?ooo`<0ObXZ
H@3oool00`000000oooo0?ooo`0o0?ooo`00403oool00`1o:RX0oooo0?ooo`0K0?ooo`030?l0o`3o
ool0oooo01/0oooo00<0ObXZ0?ooo`3oool0603oool00`3o0?l0oooo0?ooo`030?ooo`D0o`3o403o
ool00`1o:RX0oooo0?ooo`0F0?ooo`030?l0o`3oool0oooo01D0oooo00<0ObXZ0?ooo`3oool0503o
ool00`3o0?l0oooo0?ooo`050?ooo`<0ObXZI03oool00`000000oooo0?ooo`0o0?ooo`00403oool0
0`1o:RX0oooo0?ooo`0K0?ooo`030?l0o`3oool0oooo01/0oooo00<0ObXZ0?ooo`3oool0603oool0
0`3o0?l0oooo0?l0o`030?l0oaD0oooo00<0ObXZ0?ooo`3oool05P3oool00`3o0?l0oooo0?ooo`0E
0?ooo`0307lZ:P3oool0oooo01@0oooo00<0o`3o0?ooo`3oool00`3oool207lZ:VL0oooo00<00000
0?ooo`3oool0?`3oool00100oooo00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0K0?oo
o`0307lZ:P3oool0oooo01H0oooo103o0?lI0?ooo`0307lZ:P3oool0oooo01H0oooo00<0o`3o0?oo
o`3oool05P3oool00`1o:RX0oooo0?ooo`0D0?ooo`030?l0o`3oool0ObXZ0080ObXZJ@3oool00`00
0000oooo0?ooo`0o0?ooo`00403oool00`1o:RX0oooo0?ooo`0L0?ooo`030?l0o`3oool0oooo01X0
oooo00<0ObXZ0?ooo`3oool04P3oool40?l0o`80oooo00<0o`3o0?ooo`3oool0603oool00`1o:RX0
oooo0?ooo`0G0?ooo`030?l0o`3oool0oooo01D0oooo00<0ObXZ0?ooo`3oool04`3oool00`1o:RX0
o`3o07lZ:P1/0?ooo`030000003oool0oooo03l0oooo000A0?ooo`0307lZ:P3oool0oooo01/0oooo
00<0o`3o0?ooo`3oool06P3oool00`1o:RX0oooo0?ooo`0>0?ooo`@0o`3o1`3oool00`3o0?l0oooo
0?ooo`0H0?ooo`0307lZ:P3oool0oooo01H0oooo00<0o`3o0?ooo`3oool05@3oool00`1o:RX0oooo
0?ooo`0A0?ooo`80ObXZK`3oool00`000000oooo0?ooo`0o0?ooo`004@3oool00`1o:RX0oooo0?oo
o`0K0?ooo`030?l0o`3oool0oooo01X0oooo00<0ObXZ0?ooo`3oool02@3oool50?l0o`/0oooo00<0
o`3o0?ooo`3oool0603oool00`1o:RX0oooo0?ooo`0F0?ooo`030?l0o`3oool0oooo01H0oooo00<0
ObXZ0?ooo`3oool03@3oool307lZ:W40oooo00<000000?ooo`3oool0?`3oool00140oooo00<0ObXZ
0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0K0?ooo`0307lZ:P3oool0oooo0080oooo1P3o0?lA
0?ooo`030?l0o`3oool0oooo01L0oooo00<0ObXZ0?ooo`3oool05P3oool00`3o0?l0oooo0?ooo`0F
0?ooo`0307lZ:P3oool0oooo00X0oooo0`1o:RYd0?ooo`030000003oool0oooo03l0oooo000A0?oo
o`0307lZ:P3oool0oooo01`0oooo00<0o`3o0?ooo`3oool06@3oool00`3o0?l0ObXZ0?l0o`030?l0
oaL0oooo00<0o`3o0?ooo`3oool05`3oool00`1o:RX0oooo0?ooo`0G0?ooo`030?l0o`3oool0oooo
01D0oooo00<0ObXZ0?ooo`3oool0203oool207lZ:WL0oooo00<000000?ooo`3oool0?`3oool00140
oooo00<0ObXZ0?ooo`3oool0703oool00`3o0?l0oooo0?ooo`0C0?ooo`H0o`3o00<0oooo07lZ:P3o
ool06P3oool00`3o0?l0oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo01L0oooo00<0o`3o0?ooo`3o
ool05@3oool00`1o:RX0oooo0?ooo`050?ooo`<0ObXZN@3oool00`000000oooo0?ooo`0o0?ooo`00
4@3oool00`1o:RX0oooo0?ooo`0L0?ooo`030?l0o`3oool0oooo00d0oooo1P3o0?l70?ooo`0307lZ
:P3oool0oooo01T0oooo00<0o`3o0?ooo`3oool0603oool00`1o:RX0oooo0?ooo`0G0?ooo`030?l0
o`3oool0oooo01D0oooo00<0ObXZ0?ooo`3oool00P3oool207lZ:W`0oooo00<000000?ooo`3oool0
?`3oool00180oooo00<0ObXZ0?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`080?ooo`D0o`3o3@3o
ool00`1o:RX0oooo0?ooo`0I0?ooo`030?l0o`3oool0oooo01P0oooo00<0ObXZ0?ooo`3oool05`3o
ool00`3o0?l0oooo0?ooo`0E0?ooo`0307lZ:P3oool0ObXZ0080ObXZOP3oool00`000000oooo0?oo
o`0o0?ooo`004P3oool00`1o:RX0oooo0?ooo`0K0?ooo`030?l0o`3oool0oooo00@0oooo103o0?lC
0?ooo`0307lZ:P3oool0oooo01T0oooo00<0o`3o0?ooo`3oool05`3oool00`1o:RX0oooo0?ooo`0G
0?ooo`030?l0o`3oool0oooo01@0oooo0`1o:RZ10?ooo`030000003oool0oooo03l0oooo000B0?oo
o`0307lZ:P3oool0oooo01`0oooo1P3o0?lG0?ooo`0307lZ:P3oool0oooo01T0oooo00<0o`3o0?oo
o`3oool05`3oool00`1o:RX0oooo0?ooo`0H0?ooo`030?l0o`3oool0oooo0140oooo0P1o:RZ40?oo
o`030000003oool0oooo03l0oooo000B0?ooo`0307lZ:P3oool0oooo01P0oooo1@3o0?lL0?ooo`03
07lZ:P3oool0oooo01T0oooo00<0o`3o0?ooo`3oool0603oool00`1o:RX0oooo0?ooo`0G0?ooo`03
0?l0o`3oool0oooo00h0oooo0`1o:RZ60?ooo`030000003oool0oooo03l0oooo000B0?ooo`0307lZ
:P3oool0oooo01<0oooo1@3o0?l40?ooo`030?l0o`3oool0oooo01X0oooo00<0ObXZ0?ooo`3oool0
6@3oool00`3o0?l0oooo0?ooo`0H0?ooo`0307lZ:P3oool0oooo01L0oooo00<0o`3o0?ooo`3oool0
2`3oool307lZ:XT0oooo00<000000?ooo`3oool0?`3oool00180oooo00<0ObXZ0?ooo`3oool03`3o
ool40?l0o`T0oooo00<0o`3o0?ooo`3oool06P3oool00`1o:RX0oooo0?ooo`0I0?ooo`030?l0o`3o
ool0oooo01T0oooo00<0ObXZ0?ooo`3oool05P3oool00`3o0?l0oooo0?ooo`080?ooo`<0ObXZS03o
ool00`000000oooo0?ooo`0o0?ooo`004P3oool00`1o:RX0oooo0?ooo`0:0?ooo`D0o`3o3@3oool0
0`3o0?l0oooo0?ooo`0J0?ooo`0307lZ:P3oool0oooo01X0oooo00<0o`3o0?ooo`3oool0603oool0
0`1o:RX0oooo0?ooo`0F0?ooo`030?l0o`3oool0oooo00D0oooo0`1o:RZ?0?ooo`030000003oool0
oooo03l0oooo000C0?ooo`0307lZ:P3oool0oooo00@0oooo1@3o0?lC0?ooo`030?l0o`3oool0oooo
01X0oooo00<0ObXZ0?ooo`3oool06@3oool00`3o0?l0oooo0?ooo`0H0?ooo`0307lZ:P3oool0oooo
01L0oooo00@0o`3o0?ooo`3oool0oooo0`1o:RZB0?ooo`030000003oool0oooo03l0oooo000C0?oo
o`0307lZ:P3oool0oooo00@0o`3o603oool00`3o0?l0oooo0?ooo`0J0?ooo`0307lZ:P3oool0oooo
01T0oooo00<0o`3o0?ooo`3oool0603oool00`1o:RX0oooo0?ooo`0G0?ooo`040?l0o`1o:RX0ObXZ
07lZ:YD0oooo00<000000?ooo`3oool0?`3oool001<0oooo00<0ObXZ0?l0o`3o0?l0703oool00`3o
0?l0oooo0?ooo`0J0?ooo`0307lZ:P3oool0oooo01T0oooo00<0o`3o0?ooo`3oool0603oool00`1o
:RX0oooo0?ooo`0E0?ooo`80ObXZ00<0o`3o0?ooo`3oool0UP3oool00`000000oooo0?ooo`0o0?oo
o`004`3oool00`1o:RX0oooo0?ooo`0L0?ooo`030?l0o`3oool0oooo01X0oooo00<0ObXZ0?ooo`3o
ool06P3oool00`3o0?l0oooo0?ooo`0H0?ooo`0307lZ:P3oool0oooo0140oooo0`1o:RZK0?ooo`03
0000003oool0oooo03l0oooo000C0?ooo`0307lZ:P3oool0oooo01`0oooo00<0o`3o0?ooo`3oool0
6`3oool00`1o:RX0oooo0?ooo`0I0?ooo`030?l0o`3oool0oooo01P0oooo00<0ObXZ0?ooo`3oool0
3P3oool307lZ:Yh0oooo00<000000?ooo`3oool0?`3oool001<0oooo00<0ObXZ0?ooo`3oool0703o
ool00`3o0?l0oooo0?ooo`0K0?ooo`0307lZ:P3oool0oooo01X0oooo00<0o`3o0?ooo`3oool05`3o
ool00`1o:RX0oooo0?ooo`0:0?ooo`@0ObXZX@3oool00`000000oooo0?ooo`0o0?ooo`00503oool0
0`1o:RX0oooo0?ooo`0L0?ooo`030?l0o`3oool0oooo01X0oooo00<0ObXZ0?ooo`3oool06P3oool0
0`3o0?l0oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo00L0oooo0`1o:RZU0?ooo`030000003oool0
oooo03l0oooo000D0?ooo`0307lZ:P3oool0oooo01`0oooo00<0o`3o0?ooo`3oool06`3oool00`1o
:RX0oooo0?ooo`0I0?ooo`030?l0o`3oool0oooo01P0oooo00<0ObXZ0?ooo`3oool00`3oool307lZ
:ZP0oooo00<000000?ooo`3oool0?`3oool001@0oooo00<0ObXZ0?ooo`3oool0703oool00`3o0?l0
oooo0?ooo`0K0?ooo`0307lZ:P3oool0oooo01T0oooo00<0o`3o0?ooo`3oool0603oool00`1o:RX0
oooo0?ooo`0307lZ:Z/0oooo00<000000?ooo`3oool0?`3oool001@0oooo00<0ObXZ0?ooo`3oool0
703oool00`3o0?l0oooo0?ooo`0K0?ooo`0307lZ:P3oool0oooo01T0oooo00<0o`3o0?ooo`3oool0
603oool307lZ:Zh0oooo00<000000?ooo`3oool0?`3oool001@0oooo00<0ObXZ0?ooo`3oool0703o
ool00`3o0?l0oooo0?ooo`0K0?ooo`0307lZ:P3oool0oooo01X0oooo00<0o`3o0?ooo`3oool0503o
ool307lZ:[40oooo00<000000?ooo`3oool0?`3oool001@0oooo00<0ObXZ0?ooo`3oool0703oool0
0`3o0?l0oooo0?ooo`0L0?ooo`0307lZ:P3oool0oooo01T0oooo00<0o`3o0?ooo`3oool04@3oool3
07lZ:[@0oooo00<000000?ooo`3oool0?`3oool001D0oooo00<0ObXZ0?ooo`3oool0703oool00`3o
0?l0oooo0?ooo`0K0?ooo`0307lZ:P3oool0oooo01T0oooo00<0o`3o0?ooo`3oool03P3oool307lZ
:[L0oooo00<000000?ooo`3oool0?`3oool001D0oooo00<0ObXZ0?ooo`3oool0703oool00`3o0?l0
oooo0?ooo`0K0?ooo`0307lZ:P3oool0oooo01T0oooo00<0o`3o0?ooo`3oool02`3oool307lZ:[X0
oooo00<000000?ooo`3oool0?`3oool001D0oooo00<0ObXZ0?ooo`3oool0703oool00`3o0?l0oooo
0?ooo`0K0?ooo`0307lZ:P3oool0oooo01X0oooo00<0o`3o0?ooo`3oool01`3oool307lZ:[d0oooo
00<000000?ooo`3oool0?`3oool001D0oooo00<0ObXZ0?ooo`3oool0703oool00`3o0?l0oooo0?oo
o`0L0?ooo`0307lZ:P3oool0oooo01T0oooo00<0o`3o0?ooo`3oool0103oool307lZ:/00oooo00<0
00000?ooo`3oool0?`3oool001D0oooo00<0ObXZ0?ooo`3oool07@3oool00`3o0?l0oooo0?ooo`0K
0?ooo`0307lZ:P3oool0oooo01X0oooo00<0o`3o0?ooo`1o:RX00`1o:R[30?ooo`030000003oool0
oooo03l0oooo000F0?ooo`0307lZ:P3oool0oooo01`0oooo00<0o`3o0?ooo`3oool06`3oool00`1o
:RX0oooo0?ooo`0I0?ooo`0307lZ:P3o0?l0ObXZ0<L0oooo00<000000?ooo`3oool0?`3oool001H0
oooo00<0ObXZ0?ooo`3oool0703oool00`3o0?l0oooo0?ooo`0L0?ooo`0307lZ:P3oool0oooo01@0
oooo101o:R[:0?ooo`030000003oool0oooo03l0oooo000F0?ooo`0307lZ:P3oool0oooo01d0oooo
00<0o`3o0?ooo`3oool06`3oool00`1o:RX0oooo0?ooo`0A0?ooo`<0ObXZcP3oool00`000000oooo
0?ooo`0o0?ooo`005`3oool00`1o:RX0oooo0?ooo`0L0?ooo`030?l0o`3oool0oooo01/0oooo00<0
ObXZ0?ooo`3oool03@3oool407lZ:]40oooo00<000000?ooo`3oool0?`3oool001L0oooo00<0ObXZ
0?ooo`3oool0703oool00`3o0?l0oooo0?ooo`0K0?ooo`0307lZ:P3oool0oooo00X0oooo0`1o:R[E
0?ooo`030000003oool0oooo03l0oooo000G0?ooo`0307lZ:P3oool0oooo01`0oooo00<0o`3o0?oo
o`3oool06`3oool00`1o:RX0oooo0?ooo`060?ooo`@0ObXZf03oool00`000000oooo0?ooo`0o0?oo
o`005`3oool00`1o:RX0oooo0?ooo`0L0?ooo`030?l0o`3oool0oooo01`0oooo00@0ObXZ0?ooo`3o
ool0oooo101o:R[L0?ooo`030000003oool0oooo03l0oooo000G0?ooo`0307lZ:P3oool0oooo01d0
oooo00<0o`3o0?ooo`3oool06`3oool407lZ:^00oooo00<000000?ooo`3oool0?`3oool001P0oooo
00<0ObXZ0?ooo`3oool0703oool00`3o0?l0oooo0?ooo`0G0?ooo`D0ObXZh`3oool00`000000oooo
0?ooo`0o0?ooo`00603oool00`1o:RX0oooo0?ooo`0L0?ooo`030?l0o`3oool0oooo01<0oooo101o
:R[X0?ooo`030000003oool0oooo03l0oooo000H0?ooo`0307lZ:P3oool0oooo01`0oooo00<0o`3o
0?ooo`3oool03`3oool407lZ:^`0oooo00<000000?ooo`3oool0?`3oool001P0oooo00<0ObXZ0?oo
o`3oool07@3oool00`3o0?l0oooo0?ooo`0:0?ooo`@0ObXZl03oool00`000000oooo0?ooo`0o0?oo
o`006@3oool00`1o:RX0oooo0?ooo`0L0?ooo`030?l0o`3oool0oooo00L0oooo0`1o:R[d0?ooo`03
0000003oool0oooo03l0oooo000I0?ooo`0307lZ:P3oool0oooo01`0oooo00<0o`3o0?ooo`3oool0
103oool307lZ:_L0oooo00<000000?ooo`3oool0?`3oool001T0oooo00<0ObXZ0?ooo`3oool07@3o
ool00`3o0?l0oooo07lZ:P0307lZ:_X0oooo00<000000?ooo`3oool0?`3oool001T0oooo00<0ObXZ
0?ooo`3oool0703oool00`1o:RX0o`3o07lZ:P3n0?ooo`030000003oool0oooo03l0oooo000J0?oo
o`0307lZ:P3oool0oooo01L0oooo101o:R[o0?ooo`80oooo00<000000?ooo`3oool0?`3oool001X0
oooo00<0ObXZ0?ooo`3oool0503oool307lZ:_l0oooo1P3oool00`000000oooo0?ooo`0o0?ooo`00
6P3oool00`1o:RX0oooo0?ooo`0@0?ooo`@0ObXZo`3oool90?ooo`030000003oool0oooo03l0oooo
000J0?ooo`0307lZ:P3oool0oooo00`0oooo101o:R[o0?ooo`d0oooo00<000000?ooo`3oool0?`3o
ool001X0oooo00<0ObXZ0?ooo`3oool0203oool407lZ:_l0oooo4@3oool00`000000oooo0?ooo`0o
0?ooo`006P3oool20?l000D0oooo101o:R[o0?ooo`/0oooo100000060?ooo`030000003oool0oooo
03l0oooo000I0?ooo`@0o`00101o:R[o0?ooo`l0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0o0?ooo`00603oool60?l00?l0oooo4`3oool00`000000oooo0?ooo`060?ooo`<00000
?`3oool001P0oooo1P3o003o0?oooa@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0o0?ooo`006@3oool40?l00?l0oooo4`3oool010000000oooo0?ooo`0000060?ooo`030000003o
ool0oooo03l0oooo000J0?ooo`80o`00o`3ooolE0?ooo`8000001`3oool00`000000oooo0?ooo`0o
0?ooo`00o`3ooolj0?ooo`030000003oool0oooo03l0oooo000;0?ooo`D000003P3oool5000000/0
oooo00<000000?ooo`3oool00P3oool<000000<0oooo2P00003]0?ooo`030000003oool0oooo03l0
oooo000;0?ooo`040000003oool0oooo00000100oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
k03oool00`000000oooo0?ooo`0o0?ooo`002`3oool010000000oooo0?ooo`0000090?ooo`D00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo1@0000040?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo0000003/0?ooo`030000003oool0oooo03l0oooo000<0?ooo`@0
0000403oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo000000040?ooo`030000003oool0oooo00<0oooo100000020?ooo`050000003oool0oooo
0?ooo`000000o`3oool_0?ooo`003`3oool00`000000oooo0?ooo`03000000/0oooo0P0000020?oo
o`030000003oool00000008000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool00000
00D0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo008000000P3oool0
0`000000oooo0?ooo`3o0?ooobd0oooo000=0?ooo`<000000P3oool00`000000oooo0?ooo`0;0?oo
o`040000003oool0000000000080oooo00<000000?ooo`3oool02P3oool5000000H0oooo00@00000
0?ooo`3oool0oooo0`0000030?ooo`040000003oool0000000000?l0oooo<03oool001<0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0?l0oooo<@3oool001<0oooo00<0
00000?ooo`3oool02@3oool2000000H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`020?ooo`<000002@3oool200000?l0oooo<`3oool00180oooo00<000000?ooo`0000004@3oool0
0`000000oooo0000003o0?oooe<0oooo000C0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0o`3ooomB0?ooo`00o`3oooml0?ooo`00o`3oooml0?ooo`00o`3oooml0?ooo`00o`3oooml
0?ooo`00o`3oooml0?ooo`00o`3oooml0?ooo`00o`3oooli0?ooo`800000@@3oool00?l0oooo>@3o
ool200000440oooo003o0?ooocP0oooo00@000000?ooo`3oool00000@03oool00?l0oooo=`3oool2
00000080oooo0P00000o0?ooo`00o`3oooml0?ooo`00o`3oooml0?ooo`00o`3oooml0?ooo`00o`3o
ooml0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 378.563}, {226.75, 0}} -> {-4, 0, 0, 0}}],
  "  ",
  StyleBox["\nFigure 2.13",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The transformation  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\) = z\^2\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the function w = f[z] and determine the real and imaginary parts.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, eq1, eq2, eq3, eq4, x, y, u, u1, u2, v, U, 
        V];\)\ \), "\n", 
    \(\(f[z_] := z\^2;\)\ \), "\n", 
    \(\(eq1\  = \ 
        u\  \[Equal] \ 
          ComplexExpand[Re[f[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(eq2\  = \ 
        v\  \[Equal] \ 
          ComplexExpand[Im[f[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[x + \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", 
        Expand[f[x + \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u + \[ImaginaryI] v = \>", 
        Expand[f[x + \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[eq1];\)\ \), "\n", 
    \(\(Print[eq2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Find the image of the vertical line  ",
  Cell[BoxData[
      \(x = a\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[eqns\  = \ ReplaceAll[{eq1, eq2}, x \[Rule] a]];\)\ \), "\n", 
    \(\(Print[eq3\  = \ Eliminate[eqns, {y}]];\)\ \), "\n", 
    \(\(Print[solset1\  = \ Solve[eq3, u]];\)\ \), "\n", 
    \(\(u1[v_]\  = \ 
        Expand[solset1\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<u[v] = \>", u1[v]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Hence, the image of the vertical line  ",
  Cell[BoxData[
      \(x = a\)]],
  "  is the parabola  ",
  Cell[BoxData[
      \(u = a\^2 - v\^2\/\(4\ a\^2\)\)]],
  ".  \n\n",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Find the image of the horizontal line  ",
  Cell[BoxData[
      \(y = b\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[eqns\  = \ ReplaceAll[{eq1, eq2}, y \[Rule] b]];\)\ \), "\n", 
    \(\(Print[eq4\  = \ Eliminate[eqns, {x}]];\)\ \), "\n", 
    \(\(Print[solset2\  = \ Solve[eq4, u]];\)\ \), "\n", 
    \(\(u2[v_]\  = \ 
        Expand[solset2\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<u[v] = \>", u2[v]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Hence, the image of the horizontal line  ",
  Cell[BoxData[
      \(y = b\)]],
  "  is the parabola  ",
  Cell[BoxData[
      \(u = \(-b\^2\) + v\^2\/\(4\ b\^2\)\)]],
  ".  \nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a graph of the mapping."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, Iden, z];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^2;\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {0, 0.6, 0.1}, {0, 2, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.05\), 
              0.65}, {\(-0.1\), 2.1}}, 
        AspectRatio \[Rule] 
          2.2\/0.7, \[IndentingNewLine]Ticks \[Rule] {Range[0, 0.6, 0.3], 
            Range[0, 2, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Brown, Pink}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Vertical lines x = a, and horizontal lines y = b.\>"];\)\ \
\), "\n", 
    \(\(CartesianMap[
        f, \ {0, 0.6, 0.1}, {0, 2.0, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-4\), 
              0.5}, {\(-0.2\), 2.4}}, 
        AspectRatio \[Rule] 
          2.6\/4.5, \[IndentingNewLine]Ticks \[Rule] {Range[\(-4\), 0, 1], 
            Range[0, 2, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Brown, Pink}];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<The image parabolas u= \!\(a\^2\)-\!\(v\^2\/\(4\\\ \
a\^2\)\) and u = -\!\(b\^2\)+\!\(v\^2\/\(4\\\ b\^2\)\),\>\""];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, Iden, z];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^2;\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {\(-1.5\), 0.5, 0.1}, {0, 1, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1.5\), 
              0.5}, {\(-0.05\), 1.05}}, 
        AspectRatio \[Rule] 
          1.1\/2.0, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1.5\), 0.5, 
              0.5], Range[0, 1, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Pink}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Vertical lines x = a, and horizontal lines y = b.\>"];\)\ \
\), "\n", 
    \(\(CartesianMap[
        f, \ \ {\(-1.5\), 0.5, 0.1}, {0, 1, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 
              2.3}, {\(-3.2\), 1.0}}, 
        AspectRatio \[Rule] 
          4.2\/3.3, \[IndentingNewLine]Ticks \[Rule] {Range[\(-4\), 4, 1], 
            Range[\(-4\), 2, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Pink}];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<The image parabolas u= \!\(a\^2\)-\!\(v\^2\/\(4\\\ \
a\^2\)\) and u = -\!\(b\^2\)+\!\(v\^2\/\(4\\\ b\^2\)\),\>\""];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Consider the mapping  ",
  Cell[BoxData[
      \(w = z\^2\)],
    AspectRatioFixed->True],
  ".  Find the image of the ray  ",
  Cell[BoxData[
      \(r > 0, \[Theta] = \[Alpha]\)]],
  "  and circle ",
  Cell[BoxData[
      \(r = c\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Find the image of the ray  ",
  Cell[BoxData[
      \(r > 0, \[Theta] = \[Alpha]\)]],
  "  and circle ",
  Cell[BoxData[
      \(r = c\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_] = z\^2;\)\), "\[IndentingNewLine]", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Iden, {0, 3, 
          0.5}, {0, \(\(\ \)\(\[Pi]\)\)\/2, \ \(\(\ \)\(\[Pi]\)\)\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 3}, {0, 3}}, 
        AspectRatio \[Rule] 1\/2, 
        Ticks \[Rule] {Range[\(-9\), 9, 1], Range[0, 9, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Brown, Pink}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>"];\
\)\ \), "\n", 
    \(\(PolarMap[
        f\ , {0, 3, 
          0.5}, {0, \ \(\(\ \)\(\[Pi]\)\)\/2, \ \(\(\ \)\(\[Pi]\)\)\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-9\), 9}, {0, 9}}, 
        AspectRatio \[Rule] 
          1\/2, \[IndentingNewLine]Ticks \[Rule] {{\(-9\), \(-4\), \(-1\), 0, 
              1, 4, 9}, {1, 4, 9}}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Brown, Pink}];\)\ \), "\n", 
    \(\(Print[\*"\"\<The image rays r > 0, \[Theta] = 2\[Alpha], and circles \
r = \!\(c\^2\),\>\""];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_] = z\^2;\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Iden, {0, 3, 
          0.5}, {\(-\ \[Pi]\)\/3, \(\(\ \)\(\[Pi]\)\)\/3, \ \(\(\ \)\(\[Pi]\)\
\)\/12}, \[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 3}}, 
        AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-9\), 9, 1], Range[\(-9\), 9, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Pink}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>"];\
\)\ \), "\n", 
    \(\(PolarMap[
        f\ , {0, 3, 
          0.5}, {\(-\ \[Pi]\)\/3, \(\(\ \)\(\[Pi]\)\)\/3, \ \(\(\ \)\(\[Pi]\)\
\)\/12}, \[IndentingNewLine]PlotRange \[Rule] {{\(-9\), 9}, {\(-9\), 9}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {{\(-9\), \(-4\), \(-1\), 
              0, {1, "\< 1\>"}, {4, "\< 4\>"}, {9, "\< 9\>"}}, {\(-9\), \
\(-4\), 0, 1, 4, 9}}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Pink}];\)\ \), "\n", 
    \(\(Print[\*"\"\<The image rays r > 0, \[Theta] = 2\[Alpha], and circles \
r = \!\(c\^2\),\>\""];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_] = z\^2;\)\), "\[IndentingNewLine]", 
    \(\(g[z_] = z + 1;\)\), "\[IndentingNewLine]", 
    \(\(h[z_] = f[g[z]];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        g, {0, 1, 
          0.1}, {\(-\ \[Pi]\), \ \[Pi], \ \(\(\ \)\(\[Pi]\)\)\/24}, \
\[IndentingNewLine]PlotRange \[Rule] {{0, 2}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[0, 2, 0.5], Range[\(-1\), 1, 1\/2]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The radii, and circles.\>"];\)\ \), "\n", 
    \(\(range = 
        PolarMap[
          h\ , {0, 1, 
            0.1}, {\(-\ \[Pi]\), \ \[Pi], \ \(\(\ \)\(\[Pi]\)\)\/24}, 
          PlotRange \[Rule] {{\(-1\), 4.4}, {\(-2.7\), 2.7}}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 4, 1], 
              Range[\(-2\), 2, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\n", 
    \(\(Print["\<The image curves under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(cardioid = 
        ParametricPlot[{2  Cos[t] \((1 + Cos[t])\), 
            2  Sin[t] \((1 + Cos[t])\)}, {t, \(-\[Pi]\), \[Pi]}, 
          PlotStyle \[Rule] {Thickness[0.009], Red}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[range, cardioid, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<The outer boundary curve is a cardioid.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<(\!\(u\^2\) + \!\(v\^2\) - 2 u\!\(\()\^2\)\) = \
4(\!\(u\^2\) + \!\(v\^2\))\>\""];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<(u,v) = (2 Cos[t](1 + Cos[t]), 2 Sin[t](1 + Cos[t])\>"]\), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tWe can use knowledge of the inverse mapping  ",
  Cell[BoxData[
      \(z = w\^2\)],
    AspectRatioFixed->True],
  " to get further insight into how the mapping ",
  Cell[BoxData[
      \(w = z\^\(1/2\)\)],
    AspectRatioFixed->True],
  " acts on rectangles.  If we let ",
  Cell[BoxData[
      \(z = x + \[ImaginaryI]\ y \[NotEqual] 0\)]],
  ", then  \n\n\t\t\t",
  Cell[BoxData[
      \(z\  = \ \(x + \[ImaginaryI]\ y\  = \ \(w\^2\  = \ 
            u\^2 - v\^2\  + \ \[ImaginaryI]\ 2\ u\ v\)\)\)]],
  ",  \n\nand we note that the point  ",
  Cell[BoxData[
      \(z\  = \ x + \[ImaginaryI]\ y\)]],
  "  in the z plane is related to the point  ",
  Cell[BoxData[
      \(w = \(u + \[ImaginaryI]\ v = z\^\(1/2\)\)\)],
    AspectRatioFixed->True],
  " in the w-plane by the system of equations  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(x = u\^2 - v\^2\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["   ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"y", "=", 
        RowBox[{"2", " ", "u", " ", 
          RowBox[{"v", 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "    "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 2.13.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " The transformation  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ z\^\(1/2\)\)\)],
    AspectRatioFixed->True],
  "  usually maps vertical and horizontal lines onto portions of hyperbolas.  \
\n",
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the image of the vertical line  ",
  Cell[BoxData[
      \(x = a\)]],
  ".   ",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the image of the horizontal line  ",
  Cell[BoxData[
      \(y = b\)]],
  ".  \n\nSolution.  Let  ",
  Cell[BoxData[
      \(a > 0\)]],
  ".  The above equations map the right half-plane given by  ",
  Cell[BoxData[
      \(Re \((z)\) > a\)]],
  "  (i.e.,  ",
  Cell[BoxData[
      \(x > a\)]],
  ")  onto the region in the right half-plane satisfying  ",
  Cell[BoxData[
      \(u\^2 - v\^2 > a\)]],
  "  and lying to the right of the hyperbola  ",
  Cell[BoxData[
      \(u\^2 - v\^2 = a\)]],
  ".  If  ",
  Cell[BoxData[
      \(b > 0\)]],
  ",  the equations  ",
  Cell[BoxData[
      RowBox[{"x", "=", 
        RowBox[{
          RowBox[{\(u\^2\), "-", 
            RowBox[{\(v\^2\), 
              StyleBox["   ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["  ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}]}], "=", \(2\ u\ v\)}]}]]],
  "  map the upper half-plane  ",
  Cell[BoxData[
      \(Im \((z)\) > b\)]],
  "  (i.e.,  ",
  Cell[BoxData[
      \(y > b\)]],
  ")   onto the region in quadrant I satisfying  ",
  Cell[BoxData[
      \(2  u\ v > b\)]],
  "  and lying above the hyperbola  ",
  Cell[BoxData[
      \(2  u\ v = b\)]],
  ". This situation is illustrated in Figure 2.14.  We leave as an exercise \
the investigation of what happens when  ",
  Cell[BoxData[
      RowBox[{"a", "=", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["or",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "b"}], "=", "0"}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.309017 0.309017 [
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 10 6.28125 ]
[.5 .64303 -8 0 ]
[.5 .64303 8 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 .30902 m
-0.5 .30902 L
-0.36603 0 L
.5 .30902 L
F
0 .5 .95 r
.5 .30902 m
-0.36603 0 L
0 -0.22622 L
.5 .30902 L
F
0 .9 1 r
.5 .30902 m
0 -0.22622 L
.5 -0.30902 L
.5 .30902 L
F
1 0 0 r
.5 .30902 m
.5 -0.30902 L
1 -0.22622 L
.5 .30902 L
F
.9 .45 .45 r
.5 .30902 m
1 -0.22622 L
1.36603 0 L
.5 .30902 L
F
1 .75 .75 r
.5 .30902 m
1.36603 0 L
1.5 .30902 L
.5 .30902 L
F
0 1 0 r
.5 .30902 m
1.5 .30902 L
1.36603 .61803 L
.5 .30902 L
F
0 .95 0 r
.5 .30902 m
1.36603 .61803 L
1 .84425 L
.5 .30902 L
F
.45 .95 .45 r
.5 .30902 m
1 .84425 L
.5 .92705 L
.5 .30902 L
F
1 .5 0 r
.5 .30902 m
.5 .92705 L
0 .84425 L
.5 .30902 L
F
1 .6 0 r
.5 .30902 m
0 .84425 L
-0.36603 .61803 L
.5 .30902 L
F
1 1 0 r
.5 .30902 m
-0.36603 .61803 L
-0.5 .30902 L
.5 .30902 L
F
0 0 0 r
.5 Mabswid
0 .30902 m
1 .30902 L
s
.5 .30902 m
.5 .61803 L
s
.5 .30902 m
.5 0 L
s
0 g
gsave
1 .32447 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47 .63348 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003o?P00Oo=9
003Vo`030000003o0000o`0004L0o`00C`3VLg<003l007ocB000i_l00`000000o`000?l000160?l0
0500iW=c0010001oldL00>Ko00<000000?l0003o0000A@3o001A0>IcL`00@000Oo=7003Vo`030000
003o0000o`0004D0o`00D@3VLg<0044007ocAP00i_l00`000000o`000?l000140?l00580iW=c0012
001oldD00>Ko00<000000?l0003o0000@`3o001C0>IcL`00@`00Oo=4003Vo`030000003o0000o`00
0480o`00E03VLg<004@007oc@`00i_l00`000000o`000?l000110?l005D0iW=c0015001old800>Ko
00<000000?l0003o0000@03o001F0>IcL`00AP00Oo=1003Vo`030000003o0000o`0003l0o`00E`3V
Lg<004L007oc@000i_l00`000000o`000?l0000n0?l005P0iW=c0018001olcl00>Ko00<000000?l0
003o0000?@3o001I0>IcL`00B@00Oo<n003Vo`030000003o0000o`0003`0o`00FP3VLg<004X007oc
?@00i_l00`000000o`000?l0000k0?l005/0iW=c001;001olc`00>Ko00<000000?l0003o0000>P3o
001L0>IcL`00C000Oo<k003Vo`030000003o0000o`0003T0o`00G@3VLg<004d007oc>P00i_l00`00
0000o`000?l0000h0?l005h0iW=c001>001olcT00>Ko00<000000?l0003o0000=`3o001O0>IcL`00
C`00Oo<h003Vo`030000003o0000o`0003H0o`00H03VLg<004l007oc>000i_l00`000000o`000?l0
000f0?l00600iW=c001@001olcL00>Ko00<000000?l0003o0000=@3o001Q0>IcL`00D@00Oo<f003V
o`030000003o0000o`0003@0o`00HP3VLg<0058007oc=@00i_l00`000000o`000?l0000c0?l006<0
iW=c001C001olc@00>Ko00<000000?l0003o0000<P3o001T0>IcL`00E000Oo<c003Vo`030000003o
0000o`000340o`00I@3VLg<005D007oc<P00i_l00`000000o`000?l0000`0?l006D0iW=c0@3o_kl0
05H007oc<@00i_l00`000000o`000?l0000_0?l006<0iW=c103o_kl005L007oc<000i_l00`000000
o`000?l0000^0?l00640iW=c1`3o_kl005P007oc;`00i_l00`000000o`000?l0000]0?l005l0iW=c
2P3o_kl005T007oc;P00i_l00`000000o`000?l0000/0?l005d0iW=c3@3o_kl005X007oc;@00i_l0
0`000000o`000?l0000[0?l005`0iW=c3`3o_kl000030000o`00Oo<007oc05P007oc;000i_l00`00
0000o`000?l0000Z0?l005X0iW=c4P3o_kl000<0003oF@00Oo<[003Vo`030000003o0000o`0002T0
o`00F03VLg<E0?no_`001P000?mG001olbX00>Ko00<000000?l0003o0000:03o001F0>IcLaP0okno
00090000oe@007oc:P00i_l00`000000o`000?l0000X0?l005<0iW=c6`3o_kl000`0003oDP00Oo<Y
003Vo`030000003o0000o`0002L0o`00DP3VLg<M0?no_`003`000?m@001olbP00>Ko00<000000?l0
003o00009P3o001@0>IcLb00okno000A0000odl007oc9`00i_l00`000000o`000?l0000U0?l004h0
iW=c8`3o_kl001@0003oC@00Oo<V003Vo`030000003o0000o`0002@0o`00C03VLg<V0?no_`005`00
0?m;001olbD00>Ko00<000000?l0003o00008`3o001:0>IcLbT0okno000J0000odT007oc9000i_l0
0`000000o`000?l0000R0?l004T0iW=c:`3o_kl001d0003oA`00Oo<S003Vo`030000003o0000o`00
0240o`00A`3VLg<^0?no_`0080000?m5001olb800>Ko00<000000?l0003o0000803o00150>IcLc40
okno000R0000od@007oc8@00i_l00`000000o`000?l0000O0?l004<0iW=c=03o_kl002D0003o@P00
Oo<P003Vo`030000003o0000o`0001h0o`00@@3VLg<g0?no_`00:0000?m0001olal00>Ko00<00000
0?l0003o00007@3o00100>IcLcT0okno000[0000och007oc7P00i_l00`000000o`000?l0000L0?l0
03h0iW=c?03o_kl002h0003o?000Oo<M003Vo`030000003o0000o`0001/0o`00?03VLg<o0?no_`00
<0000?lk001ola`00>Ko00<000000?l0003o00006P3o000j0>IcLd80okno000c0000ocP007oc7000
i_l00`000000o`000?l0000J0?l003L0iW=cA@3o_kl003H0003o=P00Oo<K003Vo`030000003o0000
o`0001T0o`00=P3VLg=70?no_`00>@000?ld001olaX00>Ko00<000000?l0003o0000603o000d0>Ic
LdX0okno000l0000oc8007oc6@00i_l00`000000o`000?l0000G0?l00380iW=cC@3o_kl003h0003o
<@00Oo<H003Vo`030000003o0000o`0001H0o`00<03VLg=@0?no_`00@@000?l_001olaL00>Ko00<0
00000?l0003o00005@3o000^0>IcLe<0okno00140000obd007oc5P00i_l00`000000o`000?l0000D
0?l002d0iW=cE@3o_kl004L0003o:`00Oo<E003Vo`030000003o0000o`0001<0o`00:`3VLg=H0?no
_`00BP000?lY001ola@00>Ko00<000000?l0003o00004P3o000Y0>IcLe/0okno001<0000obP007oc
4`00i_l00`000000o`000?l0000A0?l002L0iW=cGP3o_kl004l0003o9P00Oo<B003Vo`030000003o
0000o`000100o`009@3VLg=Q0?no_`00DP000?lT001ola400>Ko00<000000?l0003o00003`3o000T
0>IcLf<0okno001E0000ob8007oc4000i_l00`000000o`000?l0000>0?l00280iW=cIP3o_kl005P0
003o8000Oo<?003Vo`030000003o0000o`0000d0o`00803VLg=Y0?no_`00F`000?lN001ol`h00>Ko
00<000000?l0003o0000303o000N0>IcLf`0okno001M0000oa`007oc3P00i_l00`000000o`000?l0
000<0?l001/0iW=cK`3o_kl00600003o6P00Oo<=003Vo`030000003o0000o`0000/0o`006P3VLg=a
0?no_`00H`000?lH001ol``00>Ko00<000000?l0003o00002P3o000H0>IcLg@0okno001V0000oaH0
07oc2`00i_l00`000000o`000?l000090?l001H0iW=cM`3o_kl006T0003o5000Oo<:003Vo`030000
003o0000o`0000P0o`00503VLg=j0?no_`00J`000?lC001ol`T00>Ko00<000000?l0003o00001`3o
000B0>IcLgd0okno001^0000oa4007oc2000i_l00`000000o`000?l000060?l00140iW=cO`3o_kl0
0740003o3`00Oo<7003Vo`030000003o0000o`0000D0o`003`3VLg>20?no_`00M0000?l=001ol`H0
0>Ko00<000000?l0003o0000103o000=0>IcLhD0okno001g0000o`/007oc1@00i_l00`000000o`00
0?l000030?l000/0iW=cR03o_kl007T0003o2P00Oo<4003Vo`030000003o0000o`000080o`002@3V
Lg>;0?no_`00O0000?l8001ol`<00>Ko00@000000?l0003o0000o`00203VLg>=0?no_`00O`000?l6
001ol`800>Ko00<000000?l0003o00001P3VLg>@0?no_`00PP000?l4001ol`03003Vo`000000o`00
00@0iW=cT`3o_kl008D0003o0P00Oo<00`000000iW=c0>IcL`2F0?no_`001`000?oo000000800000
603o_kl008D0ool00P3oV@000`0000000?<0003c002F003o0000PP3oo`040?nI00030?mo00000000
Lo=c00@00?<0P`00o`02000000800?l00P00000:003o0000O`3oo`060?nI0080ogl000<0000007?c
L`1clg<01P00l`21003o000400000000o`000?l0000000/00?l0001l0?oo00P0oiT00`3oO`001000
0000Lo=c07?cL`1clg<8003c07l00?l00P00000<003o0000N@3oo`0:0?nI00@0ogl000<0000007?c
L`1clg<00P1clg<9003c07d00?l00P00000<003o0000M`3oo`0;0?nI00D0ogl000<0000007?cL`1c
lg<00`1clg<;003c07T00?l000@00000003o0000o`0000002`00o`0007@0ool03@3oV@060?mo0003
0000001clg<0Lo=c00@0Lo=c3@00l`1e003o008000000P00o`02000000X00?l0001a0?oo00l0oiT0
1`3oO`000`000000Lo=c07?cL`0507?cL`l00?<0PP00o`0006h0ool04@3oV@080?mo00030000001c
lg<0Lo=c00H0Lo=c4@00l`1o003o0000J`3oo`0C0?nI00T0ogl000<0000007?cL`1clg<01`1clg<B
003c07d00?l0001Y0?oo01@0oiT02P3oO`000`000000Lo=c07?cL`0807?cLa@00?<0NP00o`0006H0
ool05P3oV@0;0?mo00030000001clg<0Lo=c00T0Lo=c5P00l`1g003o0000H`3oo`0H0?nI00`0ogl0
00<0000007?cL`1clg<02P1clg<H003c07@00?l0001P0?oo01X0oiT03@3oO`000`000000Lo=c07?c
L`0;07?cLaX00?<0L@00o`0005d0ool0703oV@0>0?mo00030000001clg<0Lo=c00`0Lo=c6`00l`1_
003o0000F`3oo`0M0?nI00l0ogl000<0000007?cL`1clg<03@1clg<M003c06`00?l0001H0?oo01l0
oiT0403oO`000`000000Lo=c07?cL`0=07?cLb000?<0J@00o`0005D0ool08P3oV@0@0?mo00030000
001clg<0Lo=c00h0Lo=c8P00l`1V003o0000DP3oo`0T0?nI0140ogl000<0000007?cL`1clg<03`1c
lg<T003c06<00?l0001?0?oo02H0oiT04P3oO`000`000000Lo=c07?cL`0@07?cLbD00?<0H@00o`00
04`0ool0:03oV@0C0?mo00030000001clg<0Lo=c0140Lo=c9`00l`1N003o0000BP3oo`0Y0?nI01@0
ogl000<0000007?cL`1clg<04P1clg<Y003c05/00?l000170?oo02/0oiT05@3oO`000`000000Lo=c
07?cL`0C07?cLb/00?<0F000o`0004@0ool0;@3oV@0F0?mo00030000001clg<0Lo=c01@0Lo=c;@00
l`1E003o0000@@3oo`0_0?nI01L0ogl000<0000007?cL`1clg<05@1clg<^003c05<00?l0000n0?oo
0340oiT0603oO`000`000000Lo=c07?cL`0F07?cLc000?<0D000o`0003`0ool0<P3oV@0I0?mo0003
0000001clg<0Lo=c01L0Lo=c<P00l`1=003o0000>@3oo`0d0?nI01X0ogl000<0000007?cL`1clg<0
601clg<d003c04X00?l0000f0?oo03H0oiT06`3oO`000`000000Lo=c07?cL`0I07?cLcH00?<0A`00
o`0003<0ool0>03oV@0L0?mo00030000001clg<0Lo=c01X0Lo=c=`00l`15003o0000<03oo`0j0?nI
01d0ogl000<0000007?cL`1clg<06`1clg<i003c04800?l0000^0?oo03/0oiT07P3oO`000`000000
Lo=c07?cL`0L07?cLc/00?<0?`00o`0002/0ool0?@3oV@0O0?mo00030000001clg<0Lo=c01d0Lo=c
?@00l`0l003o0000:03oo`0o0?nI0200ogl000<0000007?cL`1clg<07@1clg=0003c03T00?l0000U
0?oo0480oiT0803oO`000`000000Lo=c07?cL`0N07?cLd400?<0=`00o`000280ool0A03oV@0Q0?mo
00030000001clg<0Lo=c01l0Lo=c@`00l`0d003o0000803oo`150?nI0280ogl000<0000007?cL`1c
lg<0801clg=5003c03400?l0000M0?oo04L0oiT08`3oO`000`000000Lo=c07?cL`0Q07?cLdL00?<0
;P00o`0001X0ool0B@3oV@0T0?mo00030000001clg<0Lo=c0280Lo=cB@00l`0[003o00005`3oo`1;
0?nI02D0ogl000<0000007?cL`1clg<08`1clg=:003c02T00?l0000D0?oo04d0oiT09P3oO`000`00
0000Lo=c07?cL`0T07?cLd`00?<09P00o`000140ool0C`3oV@0W0?mo00030000001clg<0Lo=c02D0
Lo=cCP00l`0S003o00003`3oo`1@0?nI02P0ogl000<0000007?cL`1clg<09P1clg=@003c02000?l0
000<0?oo0580oiT0:@3oO`000`000000Lo=c07?cL`0W07?cLe800?<07@00o`0000T0ool0E03oV@0Z
0?mo00030000001clg<0Lo=c02P0Lo=cD`00l`0K003o00001P3oo`1F0?nI02/0ogl000<0000007?c
L`1clg<0:@1clg=E003c01P00?l000030?oo05P0oiT0;03oO`000`000000Lo=c07?cL`0Z07?cLeL0
0?<05@00o`0000030?oo003oV@00oiT005L0oiT0;@3oO`000`000000Lo=c07?cL`0[07?cLeT00?<0
4P00o`0005T0oiT0;P3oO`000`000000Lo=c07?cL`0/07?cLe/00?<03`00o`0005P0oiT0;`3oO`00
0`000000Lo=c07?cL`0]07?cLe`00?<03@00o`0005L0oiT0<03oO`000`000000Lo=c07?cL`0]07?c
Lel00?<02P00o`0005L0oiT0<03oO`000`000000Lo=c07?cL`0^07?cLf400?<01`00o`0005H0oiT0
<@3oO`000`000000Lo=c07?cL`0_07?cLf<00?<01000o`0005D0oiT0<P3oO`000`000000Lo=c07?c
L`0`07?cLfD00?<00@00o`0005@0oiT0<`3oO`000`000000Lo=c07?cL`0a07?cLfD00?<0001C0?nI
03@0ogl000<0000007?cL`1clg<0<P1clg=T003c0000DP3oV@0e0?mo00030000001clg<0Lo=c03<0
Lo=cH`00l`000540oiT0=P3oO`000`000000Lo=c07?cL`0d07?cLf800?<0001@0?nI03L0ogl000<0
000007?cL`1clg<0=@1clg=Q003c0000C`3oV@0h0?mo00030000001clg<0Lo=c03H0Lo=cH000l`00
04h0oiT0>@3oO`000`000000Lo=c07?cL`0g07?cLel00?<0001=0?nI03X0ogl000<0000007?cL`1c
lg<0>01clg=N003c0000C03oV@0k0?mo00030000001clg<0Lo=c03T0Lo=cG@00l`0004/0oiT0?03o
O`000`000000Lo=c07?cL`0j07?cLe`00?<0001:0?nI03d0ogl000<0000007?cL`1clg<0>`1clg=K
003c0000B@3oV@0n0?mo00030000001clg<0Lo=c03`0Lo=cFP00l`0004P0oiT0?`3oO`000`000000
Lo=c07?cL`0m07?cLeT00?<000170?nI0400ogl000<0000007?cL`1clg<0?@1clg=I003c0000A`3o
V@100?mo00030000001clg<0Lo=c03h0Lo=cF000l`0004H0oiT0@@3oO`000`000000Lo=c07?cL`0o
07?cLeL00?<000150?nI0480ogl000<0000007?cL`1clg<0@01clg=F003c0000A03oV@130?mo0003
0000001clg<0Lo=c0440Lo=cE@00l`0004<0oiT0A03oO`000`000000Lo=c07?cL`1207?cLe@00?<0
00120?nI04D0ogl000<0000007?cL`1clg<0@`1clg=C003c0000@@3oV@160?mo00030000001clg<0
Lo=c04@0Lo=cDP00l`000400oiT0A`3oO`000`000000Lo=c07?cL`1507?cLe400?<0000o0?nI04P0
ogl000<0000007?cL`1clg<0AP1clg=@003c0000?P3oV@190?mo00030000001clg<0Lo=c04L0Lo=c
C`00l`0003d0oiT0BP3oO`000`000000Lo=c07?cL`1807?cLdh00?<0000l0?nI04/0ogl0C01clg==
003c0000>`3oV@1<0?mo04d0Lo=cC000l`0003X0oiT0C@3oO`1>07?cLd/00?<0000i0?nI04h0ogl0
C`1clg=:003c0000>03oV@1?0?mo0500Lo=cB@00l`0003L0oiT0D03oO`0207?cL`@00000BP1clg=9
003c0000=`3oV@1@0?mo00@0Lo=c00<0000007?cL`1clg<0BP1clg=8003c0000=P3oV@1A0?mo00@0
Lo=c00<0000007?cL`1clg<0B`1clg=7003c0000=@3oV@1B0?mo00@0Lo=c0P00001=07?cLdH00?<0
000d0?nI05<0ogl00`1clg<00`000000Lo=c0000001>07?cLdD00?<0000c0?nI05@0ogl00`1clg<0
10000000Lo=c07?cL`00001>07?cLd@00?<0000b0?nI05D0ogl00P1clg<01@000000Lo=c07?cL`1c
lg<0000004l0Lo=c@`00l`000340oiT0EP3oO`001@1clg<00000000000000000Lo=c00<00000C`1c
lg=2003c0000<03oV@1G0?mo05P0Lo=c@@00l`0002l0oiT0F03oO`1I07?cLd000?<0000^0?nI05T0
ogl0FP1clg<o003c0000;@3oV@1J0?mo05/0Lo=c?P00l`0002`0oiT0F`3oO`1L07?cLcd00?<00000
\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1, -1, 0, 0}}],
  StyleBox["       ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.309017 0.309017 [
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 10 6.28125 ]
[.5 .64303 -8 0 ]
[.5 .64303 8 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 .30902 m
.5 -0.30902 L
.75882 -0.28796 L
.5 .30902 L
F
0 .5 .95 r
.5 .30902 m
.75882 -0.28796 L
1 -0.22622 L
.5 .30902 L
F
0 .9 1 r
.5 .30902 m
1 -0.22622 L
1.20711 -0.128 L
.5 .30902 L
F
1 0 0 r
.5 .30902 m
1.20711 -0.128 L
1.36603 0 L
.5 .30902 L
F
.9 .45 .45 r
.5 .30902 m
1.36603 0 L
1.46593 .14906 L
.5 .30902 L
F
1 .75 .75 r
.5 .30902 m
1.46593 .14906 L
1.5 .30902 L
.5 .30902 L
F
0 1 0 r
.5 .30902 m
1.5 .30902 L
1.46593 .46898 L
.5 .30902 L
F
0 .95 0 r
.5 .30902 m
1.46593 .46898 L
1.36603 .61803 L
.5 .30902 L
F
.45 .95 .45 r
.5 .30902 m
1.36603 .61803 L
1.20711 .74603 L
.5 .30902 L
F
1 .5 0 r
.5 .30902 m
1.20711 .74603 L
1 .84425 L
.5 .30902 L
F
1 .6 0 r
.5 .30902 m
1 .84425 L
.75882 .90599 L
.5 .30902 L
F
1 1 0 r
.5 .30902 m
.75882 .90599 L
.5 .92705 L
.5 .30902 L
F
0 0 0 r
.5 Mabswid
0 .30902 m
1 .30902 L
s
.01 w
.5 .30902 m
.5 .61803 L
s
[ .025 .025 ] 0 setdash
.5 .30902 m
.5 0 L
s
0 g
gsave
1 .32447 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47 .63348 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oQP3oool2
00000280003o9`00Oo<f003VoaT0o`0000260?ooo`8000008@000?lW001olcH00>Ko6P3o000008H0
oooo0P00000Q0000obH007oc=@00i_lL0?l00000QP3oool200000200003o9`00Oo<c003Voah0o`00
00270?ooob40003o9P00Oo<c003Voal0o`0000270?ooob00003o9P00Oo<b003Vob40o`0000270?oo
ob00003o9@00Oo<a003Vob<0o`0000270?ooob00003o9000Oo<a003Vob@0o`0000260?ooo`800000
7P000?lT001olc000>Ko9P3o000008H0oooo0P00000N0000ob<007oc<000i_lW0?l00000QP3oool2
000001d0003o8`00Oo<_003VobT0o`0000260?ooo`8000007@000?lR001olbh00>Ko:`3o000008H0
oooo0P00000L0000ob8007oc;P00i_l/0?l00000QP3oool2000001`0003o8@00Oo<]003Vobh0o`00
00260?ooo`80000070000?lP001olbd00>Ko;`3o000008H0oooo0P00000K0000ob0007oc;000i_la
0?l00000QP3oool2000001/0003o7`00Oo<[003Voc<0o`0000270?oooa/0003o7`00Oo<[003Voc@0
o`0000270?oooa/0003o7P00Oo<Z003VocH0o`0000270?oooaX0003o7`00Oo<X003VocP0o`000027
0?oooaX0003o7P00Oo<X003VocT0o`0000260?ooo`8000006@000?lM001olbL00>Ko>`3o000008H0
oooo0P00000H0000oad007oc9`00i_ll0?l00000QP3oool2000001P0003o7000Oo<V003Voch0o`00
00260?ooo`8000005`000?lL001olbD00>Ko@03o000008H0oooo0P00000G0000oa/007oc9@00i_m0
0?l00040iW=c00260?ooo`8000005P000?lK001olb@00>Ko?`3o00040>IcL`00QP3oool2000001H0
003o6P00Oo<T003Vocd0o`001`3VLg<008H0oooo0P00000E0000oaX007oc8`00i_ll0?l000X0iW=c
00270?oooaH0003o6@00Oo<R003Voc/0o`003@3VLg<008L0oooo5P000?lH001olb800>Ko>P3o000?
0>IcL`00Q`3ooolE0000oaP007oc8@00i_li0?l00180iW=c00270?oooaD0003o5`00Oo<P003VocP0
o`005@3VLg<008L0oooo50000?lG001olb000>Ko=P3o000H0>IcL`00QP3oool2000001<0003o5`00
Oo<N003VocD0o`006`3VLg<008H0oooo0P00000B0000oaL007oc7P00i_ld0?l001d0iW=c00260?oo
o`8000004P000?lF001olad00>Ko<`3o000P0>IcL`00QP3oool200000180003o5@00Oo<L003Voc80
o`008`3VLg<008H0oooo0P00000A0000oaD007oc7000i_l`0?l002H0iW=c00260?ooo`8000004@00
0?lD001ola/00>Ko;`3o000Y0>IcL`00QP3oool200000100003o5000Oo<K003Vobh0o`00:`3VLg<0
08H0oooo0P00000@0000oa<007oc6P00i_l]0?l002h0iW=c00270?oooa00003o4`00Oo<I003Vob`0
o`00<@3VLg<008L0oooo40000?lB001olaT00>Ko:P3o000d0>IcL`00Q`3oool@0000oa4007oc6000
i_lY0?l003L0iW=c00270?ooo`l0003o4@00Oo<G003VobT0o`00>@3VLg<008L0oooo3`000?l@001o
laL00>Ko9`3o000l0>IcL`00QP3oool2000000d0003o4000Oo<F003VobH0o`00?`3VLg<008H0oooo
0P00000=0000o`l007oc5P00i_lT0?l00480iW=c00260?ooo`80000030000?l@001ola@00>Ko8`3o
00150>IcL`00QP3oool2000000`0003o3`00Oo<C003Vob<0o`00A`3VLg<008H0oooo0P00000<0000
o`h007oc4`00i_lQ0?l004X0iW=c00260?ooo`8000002`000?l>001ola800>Ko803o001=0>IcL`00
QP3oool2000000/0003o3@00Oo<B003Voah0o`00D03VLg<008H0oooo0P00000:0000o`d007oc4@00
i_lM0?l00540iW=c0P3o_kl008L0oooo2`000?l<001ola000>Ko7@3o001=0>IcL`P0okno00270?oo
o`X0003o3000Oo<@003Voa/0o`00BP3VLg<>0?no_`00Q`3oool:0000o`/007oc3`00i_lJ0?l004L0
iW=c503o_kl008L0oooo2P000?l:001ol`h00>Ko6@3o00140>IcLaX0okno00260?ooo`8000002000
0?l:001ol`h00>Ko5`3o00110>IcLb00okno00260?ooo`80000020000?l9001ol`d00>Ko5`3o000m
0>IcLbH0okno00260?ooo`8000001`000?l9001ol`d00>Ko5@3o000j0>IcLb`0okno00260?ooo`80
00001`000?l8001ol``00>Ko503o000g0>IcLc80okno00260?ooo`8000001P000?l8001ol`/00>Ko
4`3o000d0>IcLcP0okno00260?ooo`8000001P000?l8001ol`X00>Ko4@3o000a0>IcLch0okno0026
0?ooo`8000001P000?l7001ol`T00>Ko4@3o000]0>IcLd@0okno00260?ooo`8000001@000?l7001o
l`T00>Ko3`3o000Z0>IcLdX0okno00260?ooo`8000001@000?l6001ol`P00>Ko3P3o000W0>IcLe00
okno00270?ooo`D0003o1P00Oo<7003Vo`d0o`00903VLg=F0?no_`00Q`3oool50000o`D007oc1`00
i_l;0?l00240iW=cG03o_kl008L0oooo10000?l5001ol`H00>Ko2`3o000M0>IcLf80okno00270?oo
o`@0003o1000Oo<5003Vo`X0o`006P3VLg=X0?no_`00QP3oool2000000<0003o0`00Oo<5003Vo`P0
o`005`3VLg=^0?no_`00QP3oool200000080003o0`00Oo<4003Vo`L0o`00503VLg=d0?no_`00QP3o
ool200000080003o0P00Oo<4003Vo`D0o`004@3VLg=j0?no_`00QP3oool2000000030000o`00Oo<0
07oc00<00>Ko1@3o000=0>IcLh00okno00260?ooo`80000000@0003o001ol`00i_l00>Ko103o000:
0>IcLhH0okno00260?ooo`80000000<007oc003Vo`00i_l00P3o00070>IcLh`0okno00260?ooo`80
000000<00>Ko0?l0003VLg<00`3VLg>B0?no_`001`3ooooo000000800000603o_kl008H0oooo0P00
00000`3oO`00Lo=c003c0003003c09800?l000260?ooo`80000000<0oiT00?mo003oO`000P1clg<7
003c07h00?l00P0000000`00o`00000000000009003o0000QP3oool2000000040?oo003oV@00ogl0
0?mo00@0Lo=c2P00l`1g003o000300000000o`000?l0008000002P00o`0008H0oooo0P0000000`3o
o`00oiT00?nI00030?mo00D0Lo=c3@00l`1a003o000500000000o`000?l0003o000000002P00o`00
08H0oooo0P0000020?oo0080oiT0103oO`0507?cLa400?<0J`00o`001@0000000?l0003o0000o`00
000000X00?l000260?ooo`8000000P3oo`030?nI00@0ogl01`1clg<E003c06@00?l000D00000003o
0000o`000?l00000000:003o0000QP3oool2000000<0ool00`3oV@050?mo00P0Lo=c6000l`1M003o
008000000P00o`02000000X00?l000260?ooo`8000000`3oo`040?nI00H0ogl02@1clg<K003c06L0
0?l000260?ooo`8000000`3oo`050?nI00H0ogl02`1clg<N003c06400?l000260?ooo`800000103o
o`050?nI00L0ogl02`1clg<R003c05/00?l000260?ooo`800000103oo`060?nI00L0ogl03@1clg<U
003c05D00?l000260?ooo`8000001@3oo`060?nI00P0ogl03P1clg<Y003c04h00?l000260?ooo`80
00001@3oo`070?nI00T0ogl03`1clg</003c04P00?l000260?ooo`8000001P3oo`070?nI00T0ogl0
4@1clg<_003c04800?l000260?ooo`8000001P3oo`080?nI00X0ogl04@1clg<c003c03`00?l00026
0?ooo`8000001P3oo`090?nI00/0ogl04P1clg<f003c03H00?l000260?ooo`8000001`3oo`080?nI
00`0ogl0501clg<i003c03000?l000260?ooo`8000001`3oo`090?nI00d0ogl05@1clg<m003c02T0
0?l000260?ooo`800000203oo`090?nI00d0ogl05`1clg=0003c02<00?l000260?ooo`800000203o
o`0:0?nI00h0ogl05`1clg=4003c01d00?l000260?ooo`8000002@3oo`0:0?nI00l0ogl0601clg=7
003c01L00?l000260?ooo`8000002@3oo`0;0?nI00l0ogl06P1clg=:003c01400?l000260?ooo`80
00002@3oo`0<0?nI0100ogl06`1clg=>003c00X00?l000260?ooo`8000002P3oo`0<0?nI0140ogl0
701clg=A003c00@00?l000260?ooo`8000002P3oo`0=0?nI0140ogl07@1clg=C003c0000QP3oool2
000000/0ool03@3oV@0B0?mo01h0Lo=cD000l`0008H0oooo0P00000;0?oo00h0oiT04`3oO`0O07?c
Ldd00?<000260?ooo`800000303oo`0>0?nI01<0ogl08@1clg=:003c0000QP3oool2000000`0ool0
3`3oV@0D0?mo0280Lo=cA`00l`0008H0oooo0P00000=0?oo00l0oiT0503oO`0S07?cLdD00?<00026
0?ooo`8000003@3oo`0@0?nI01D0ogl0901clg=2003c0000QP3oool2000000d0ool04@3oV@0F0?mo
02D0Lo=c?`00l`0008H0oooo0P00000>0?oo0140oiT05P3oO`0W07?cLc`00?<000260?ooo`800000
3P3oo`0A0?nI01P0ogl0:01clg<i003c0000QP3oool2000000l0ool04@3oV@0I0?mo02P0Lo=c=`00
l`0008H0oooo0P00000?0?oo0180oiT06@3oO`0Z07?cLc@00?<000260?ooo`800000403oo`0B0?nI
01X0ogl0:`1clg<a003c0000QP3oool200000100ool04`3oV@0J0?mo02d0Lo=c;P00l`0008H0oooo
0P00000@0?oo01@0oiT06`3oO`0^07?cLb/00?<000260?ooo`8000004@3oo`0D0?nI01`0ogl0;P1c
lg<Y003c0000QP3oool200000140ool05@3oV@0L0?mo0300Lo=c9P00l`0008H0oooo0P00000B0?oo
01D0oiT07@3oO`0a07?cLb<00?<000260?ooo`8000004P3oo`0F0?nI01h0ogl0<P1clg<P003c0000
QP3oool2000001<0ool05P3oV@0N0?mo03@0Lo=c7@00l`0008H0oooo0P00000C0?oo01L0oiT07`3o
O`0d07?cLa/00?<000260?ooo`8000004`3oo`0H0?nI0200ogl0=@1clg<H003c0000QP3oool20000
01@0ool0603oV@0P0?mo03L0Lo=c5@00l`0008H0oooo0P00000D0?oo01T0oiT08@3oO`0h07?cLa80
0?<000260?ooo`8000005@3oo`0I0?nI0240ogl0>P1clg<?003c0000QP3oool2000001D0ool06P3o
V@0R0?mo03X0Lo=c3@00l`0008H0oooo0P00000F0?oo01T0oiT0903oO`0k07?cL`X00?<000260?oo
o`8000005P3oo`0J0?nI02@0ogl0?@1clg<7003c0000QP3oool2000001L0ool06P3oV@0U0?mo03h0
Lo=c1000l`0008H0oooo0P00000G0?oo01/0oiT09P3oO`0o07?cL`400?<000260?ooo`8000005`3o
o`0L0?nI02H0ogl0?`1clg<008H0oooo0P00000H0?oo01`0oiT09`3oO`0m07?cL`00QP3oool20000
01P0ool07@3oV@0W0?mo03`0Lo=c00260?ooo`8000006@3oo`0M0?nI02P0ogl0>P1clg<008H0oooo
0P00000I0?oo01h0oiT0:@3oO`0h07?cL`00QP3oool2000001X0ool07P3oV@0Y0?mo03L0Lo=c0026
0?ooo`8000006P3oo`0O0?nI02X0ogl0=@1clg<008H0oooo0P00000J0?oo0200oiT0:`3oO`0c07?c
L`00QP3oool2000001/0ool0803oV@0[0?mo0380Lo=c00260?ooo`8000006`3oo`0Q0?nI02`0ogl0
<01clg<008H0oooo0P00000L0?oo0240oiT0;03oO`0_07?cL`00QP3oool2000001`0ool08P3oV@0]
0?mo02d0Lo=c00260?ooo`8000007@3oo`0R0?nI02h0ogl0:`1clg<008H0oooo0P00000M0?oo0280
oiT0;`3oO`0Z07?cL`00QP3oool2000001d0ool08`3oV@0`0?mo02P0Lo=c00260?ooo`8000007P3o
o`0S0?nI0340ogl09P1clg<008H0oooo0P00000N0?oo02@0oiT0<@3oO`0U07?cL`00QP3oool20000
01l0ool0903oV@0b0?mo02<0Lo=c00260?ooo`8000007`3oo`0U0?nI03<0ogl08@1clg<008H0oooo
0P00000P0?oo02D0oiT0<`3oO`0P07?cL`00QP3oool200000200ool09P3oV@0d0?mo01h0Lo=c0026
0?ooo`800000803oo`0W0?nI03@0ogl07@1clg<008H0oooo0P00000Q0?oo02L0oiT0=@3oO`0K07?c
L`00QP3oool200000240ool0:03oV@0f0?mo01T0Lo=c00260?ooo`8000008P3oo`0X0?nI03H0ogl0
601clg<008H0oooo0P00000R0?oo02T0oiT0=`3oO`0F07?cL`00Q`3ooolT0?oo02T0oiT0>03oO`0D
07?cL`00Q`3ooolT0?oo02X0oiT0>03oO`0C07?cL`00Q`3ooolU0?oo02X0oiT0>@3oO`0A07?cL`00
Q`3ooolU0?oo02/0oiT0>@3oO`0@07?cL`00Q`3ooolU0?oo02/0oiT0>`3oO`0>07?cL`00Q`3ooolV
0?oo02/0oiT0?03oO`0<07?cL`00Q`3oool40?oo00030000003oo`00ool001l0ool0;03oV@0l0?mo
00/0Lo=c00270?ooo`<0ool000<000000?oo000000008@3oo`0/0?nI03d0ogl02@1clg<008L0oooo
0`3oo`000`000000ool00000000Q0?oo02d0oiT0?P3oO`0707?cL`00Q`3oool20?oo00050000003o
o`00ool00?oo000000008@3oo`0]0?nI03h0ogl01P1clg<008L0oooo0P3oo`001@000000ool00?oo
003oo`0000000240ool0;P3oV@0o0?mo00@0Lo=c00270?ooo`050?oo0000000000000000003oo`00
0`00000P0?oo02l0oiT0@03oO`0207?cL`00Q`3ooolY0?oo02l0oiT0@03oO`0107?cL`00Q`3ooolY
0?oo0300oiT0@03oO`0008L0oooo:P3oo`0`0?nI03l0ogl000270?ooobX0ool0<@3oV@0n0?mo0000
Q`3oool[0?oo0340oiT0?@3oO`000001\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1, -1, 0, 0}}],
  StyleBox["  \n\t\t\tFigure 2.14",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The mapping   ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\) = z\^\(1/2\)\)\)],
    AspectRatioFixed->True],
  "   and   (",
  Cell[BoxData[
      \(z\  = \ \(\(f\^\(-1\)\) \((w)\) = w\^2\)\)]],
  ").  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Before we start, make x, y, u and v real variables.", "Text"],

Cell[BoxData[{
    \(\(Remove[u, v, x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, X, Y, U, V, Z];\)\ \), "\n", 
    \(\(TagSet[x, Im[x], 0];\)\ \), "\n", 
    \(\(TagSet[y, Im[y], 0];\)\ \), "\n", 
    \(\(TagSet[u, Im[u[x, y]], 0];\)\ \), "\n", 
    \(\(TagSet[v, Im[v[x, y]], 0];\)\ \), "\n", 
    \(\(TagSet[x, Re[x], x];\)\ \), "\n", 
    \(\(TagSet[y, Re[y], y];\)\ \), "\n", 
    \(\(TagSet[u, Re[u[x, y]], u[x, y]];\)\ \), "\n", 
    \(\(TagSet[v, Re[v[x, y]], v[x, y]];\)\ \)}], "Input"],

Cell[TextData[{
  "The mapping  ",
  Cell[BoxData[
      \(w = z\^\(1/2\)\)]],
  "  can be manipulated as follows.  "
}], "Text"],

Cell[BoxData[{
    \(\(eq0 = \@z \[Equal] w;\)\ \), "\n", 
    \(\(eq1 = z \[Equal] w\^2;\)\ \), "\n", 
    \(\(eq2 = 
        ReplaceAll[
          eq1, {z \[Rule] x + \[ImaginaryI]\ y, 
            w \[Rule] u + \[ImaginaryI]\ v}];\)\ \), "\n", 
    \(\(eq3 = ComplexExpand[eq2];\)\ \), "\n", 
    \(\(eq4 = ComplexExpand[Map[Re, eq3]];\)\ \), "\n", 
    \(\(eq5 = Thread[\(-eq4\), Equal];\)\ \), "\n", 
    \(\(eq6 = Thread[eq5 + eq3, Equal];\)\ \), "\n", 
    \(\(eq7 = ComplexExpand[Map[Im, eq6]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eq0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eq1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eq2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eq3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eq4];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eq7];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Find the image of the vertical line  ",
  Cell[BoxData[
      \(x = a\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<The vertical line is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        eq4\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\) \
\[Equal] a];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Its image is the hyperbola\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[
        eq4\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\) \
\[Equal] a];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Find the image of the horizontal line  ",
  Cell[BoxData[
      \(y = b\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<The horizontal line is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        eq7\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\) \
\[Equal] b];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Its image is the hyperbola\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[
        eq7\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\) \
\[Equal] b];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a graph of the mapping."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, Iden];\)\ \), "\n", 
    \(\(Iden[z_] = z;\)\ \), "\n", 
    \(\(f[z_] = z\^\(1/2\);\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {\(-9\), 9, 1}, {0, 9, 
          1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-9\), 10}, {\(-0.5\), 
              10}}, AspectRatio \[Rule] 
          1\/2, \[IndentingNewLine]Ticks \[Rule] {Range[\(-9\), 9, 3], 
            Range[0, 9, 3]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Cyan, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Vertical lines x = a, and horizontal lines y = b.\>"];\)\ \
\), "\n", 
    \(\(CartesianMap[
        f, \ {\(-9\), 9, 1}, {0, 9, 
          1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.3\), 
              3.3}, {\(-0.3\), 3.3}}, AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[0, 3, 1], Range[0, 3, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Cyan, Blue}];\)\ \), "\n", 
    \(\(Print[\*"\"\<The image hyperbolas \!\(u\^2\)-\!\(v\^2\) = a and 2uv = \
b,\>\""];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tWhat happens to images of regions under the mapping  \n\n\t\t\t",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ \(z\^\(1/2\)\  = \ \(\(\(|\)\(z\)\( | \^\(1/
                      2\)\)\(\[ExponentialE]\^\(\[ImaginaryI]\ Arg \((z)\)/
                        2\)\)\)\  = \ \(r\^\(1/
                      2\)\) \[ExponentialE]\^\(\[ImaginaryI]\[Theta]/2\)\)\)\)\
\)]],
  "   for  ",
  Cell[BoxData[
      \(r\ \[ExponentialE]\^\[ImaginaryI]\[Theta] \[NotEqual] 0\)]],
  ", \n\nwhere  ",
  Cell[BoxData[
      \(\(-\[Pi]\) < \[Theta] \[LessEqual] \[Pi]\)]],
  "?  If we use polar coordinates for  ",
  Cell[BoxData[
      \(w = \[Rho]\ \[ExponentialE]\^\[ImaginaryI]\[Phi]\)]],
  "  in the w plane, we can represent this mapping by the system\n\n\t\t\t",
  Cell[BoxData[
      \(\[Rho] = \(r\^\(1/2\)\ \ and\ \ \[Phi] = \[Theta]\/2\)\)]],
  ".  \n\nThis Equation indicate that the argument of f(z) is half the \
argument of z and that the modulus of f(z) is the square root of the modulus \
of z.  Points that lie on the ray  ",
  Cell[BoxData[
      \(r > 0, \[Theta] = \[Alpha]\)]],
  "  are mapped onto the ray  ",
  Cell[BoxData[
      \(\[Rho] > 0, \[Phi] = \[Alpha]\/2\)]],
  ".  The image of the z plane (with the point z=0 deleted) consists of the \
right half-plane Re(w)>0 together with the positive v axis.  The mapping is \
shown in Figure 2.15."
}], "Text"],

Cell[TextData[{
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .78571 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.285714 0.0714286 0.0714286 0.0714286 [
[.07143 .05893 -6 -9 ]
[.07143 .05893 6 0 ]
[.5 .05893 -3 -9 ]
[.5 .05893 3 0 ]
[.71429 .05893 -3 -9 ]
[.71429 .05893 3 0 ]
[.92857 .05893 -3 -9 ]
[.92857 .05893 3 0 ]
[1.025 .07143 0 -6.28125 ]
[1.025 .07143 10 6.28125 ]
[.27321 .21429 -6 -4.5 ]
[.27321 .21429 0 4.5 ]
[.27321 .35714 -6 -4.5 ]
[.27321 .35714 0 4.5 ]
[.27321 .71429 -6 -4.5 ]
[.27321 .71429 0 4.5 ]
[.28571 .81071 -5 0 ]
[.28571 .81071 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .78571 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07143 .07143 m
.07143 .07768 L
s
[(-3)] .07143 .05893 0 1 Mshowa
.5 .07143 m
.5 .07768 L
s
[(3)] .5 .05893 0 1 Mshowa
.71429 .07143 m
.71429 .07768 L
s
[(6)] .71429 .05893 0 1 Mshowa
.92857 .07143 m
.92857 .07768 L
s
[(9)] .92857 .05893 0 1 Mshowa
0 .07143 m
1 .07143 L
s
gsave
1.025 .07143 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.28571 .21429 m
.29196 .21429 L
s
[(2)] .27321 .21429 1 0 Mshowa
.28571 .35714 m
.29196 .35714 L
s
[(4)] .27321 .35714 1 0 Mshowa
.28571 .71429 m
.29196 .71429 L
s
[(9)] .27321 .71429 1 0 Mshowa
.28571 0 m
.28571 .78571 L
s
gsave
.28571 .81071 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .78571 L
0 .78571 L
closepath
clip
newpath
.5 Mabswid
.28571 .07143 m
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
.28571 .07143 L
s
1 0 0 r
.5 .07143 m
.5 .71429 L
s
.53571 .07143 m
.53571 .71429 L
s
.57143 .07143 m
.57143 .71429 L
s
.60714 .07143 m
.60714 .71429 L
s
.64286 .07143 m
.64286 .71429 L
s
.67857 .07143 m
.67857 .71429 L
s
.71429 .07143 m
.71429 .71429 L
s
.75 .07143 m
.75 .71429 L
s
.78571 .07143 m
.78571 .71429 L
s
.82143 .07143 m
.82143 .71429 L
s
.85714 .07143 m
.85714 .71429 L
s
.89286 .07143 m
.89286 .71429 L
s
.92857 .07143 m
.92857 .71429 L
s
0 0 1 r
0 .35714 m
.92857 .35714 L
s
0 .39286 m
.92857 .39286 L
s
0 .42857 m
.92857 .42857 L
s
0 .46429 m
.92857 .46429 L
s
0 .5 m
.92857 .5 L
s
0 .53571 m
.92857 .53571 L
s
0 .57143 m
.92857 .57143 L
s
0 .60714 m
.92857 .60714 L
s
0 .64286 m
.92857 .64286 L
s
0 .67857 m
.92857 .67857 L
s
0 .71429 m
.92857 .71429 L
s
0 g
0 .07143 m
1 .07143 L
s
.28571 0 m
.28571 .78571 L
s
gsave
.39286 .21429 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.06429 .28571 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{300.75, 236.313},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000k2000`400?l00000o`00003oDP3oool0
0`000000oooo0?ooo`3G0?ooo`00DP3oool00`000000oooo0?ooo`3G0?ooo`00DP3oool00`000000
oooo0?ooo`3G0?ooo`00DP3oool00`000000oooo0?ooo`3G0?ooo`00DP3oool00`000000oooo0?oo
o`3G0?ooo`00DP3oool00`000000oooo0?ooo`3G0?ooo`00DP3oool00`000000oooo0?ooo`3G0?oo
o`00DP3oool00`000000oooo0?ooo`3G0?ooo`006@3oool2000003L0oooo00<000000?ooo`3oool0
=`3oool2000003P0oooo0`00000h0?ooo`<00000:03oool001P0oooo00@000000?ooo`3oool00000
=P3oool00`000000oooo0?ooo`0f0?ooo`040000003oool0oooo000003L0oooo00@000000?ooo`3o
ool00000>@3oool00`000000oooo0?ooo`0V0?ooo`006P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0=P3oool010000000oooo0?ooo`00000h0?oo
o`<000009`3oool00180oooo100000050?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0e0?ooo`<00000>03oool010000000oooo0?ooo`00000W0?oo
o`00603oool010000000oooo0?ooo`00000f0?ooo`030000003oool0oooo03H0oooo00@000000?oo
o`3oool00000>03oool00`000000oooo0?ooo`0g0?ooo`040000003oool0oooo000002L0oooo000I
0?ooo`800000=`3oool00`000000oooo0?ooo`0g0?ooo`800000>@3oool3000003P0oooo0`00000W
0?ooo`00DP3oool00`000000oooo0?ooo`3G0?ooo`00DP3oool00`000000oooo0?ooo`3G0?ooo`00
DP3oool00`000000oooo0?ooo`3G0?ooo`00DP3oool00`000000oooo0?ooo`3G0?ooo`00DP3oool0
0`000000oooo0?ooo`3:0?ooo`80000000<0oooo000000000000203oool00580oooo00<000000?oo
o`3oool0b`3oool00`000000oooo000000090?ooo`00103ooooo000001@000002P3oool00`000000
oooo0?ooo`080?ooo`005`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool06@3oool2000000030?ooo`000000000000P0oooo000G0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool0
0`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo
03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo
001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<00000
0?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3o
ool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0
oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0
oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<0
00000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00
DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003o
ool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo
00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?oo
o`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?oo
o`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000
003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580
oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo
0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001:0?ooo`@00000103oool00`000000oooo0?oo
o`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo02H0oooo001:0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool07@3oool200000080oooo0P00000:0?ooo`D000001P3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V
0?ooo`00B`3oool00`000000oooo0?ooo`040?ooo`<000007P3oool010000000oooo0?ooo`000003
0?ooo`D000000P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3o
ool004`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`8000002`3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool004X0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0O0?ooo`800000103oool5000000<0oooo1000
00070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo02H0oooo001;0?ooo`8000001@3oool00`000000oooo0?ooo`0N
0?ooo`040000003oool0oooo000000X0oooo00D000000?ooo`3oool0oooo000000070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo01d0oooo0P0000020?ooo`8000002P3o
ool3000000P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo
00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?oo
o`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?oo
o`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000
003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580
oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo
0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V
0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo000H0?ooo`@0
0000=P3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo000J0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`006P3o
ool00`000000oooo0?ooo`090?ooo`D000009`3oool00`000000oooo0?ooo`0h0?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo02H0oooo000J0?ooo`8000000`3oool5000000<0oooo00D000000?ooo`3oool0oooo0000
000V0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool001T0oooo00<00000
0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool0>03o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`0V0?ooo`006@3oool010000000oooo0?ooo`0000020?ooo`D000000`3o
ool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`0V0?ooo`00603oool01@000000oooo0?ooo`3oool0000000X0oooo0P0000020?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`005`3o
ool3000000040?ooo`0000000000000000T0oooo00@000000?ooo`00000000009`3oool00`000000
oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`009P3oool2000002X0oooo00<0
00000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00
DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003o
ool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool004`0oooo0`0000030?ooo`030000003oool0
oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool09P3oool004d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo00040?ooodh0003o00<000000000o`00
0?l0[`000?lX0?ooo`00BP3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03P0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool09P3oool004/0oooo00<000000?ooo`000000103oool00`000000oooo
0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001<0?ooo`800000103oool00`000000oooo0?oo
o`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?oo
o`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000
003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo02H0oooo00040?ooodh0003o00<000000000o`000?l0[`000?lX0?ooo`00DP3oool00`000000
oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?oo
o`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3o
ool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3o
ool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00103ooom>0000
o`03000000000?l0003o0:l0003o:03oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo
001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<00000
0?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3o
ool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0
oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool09P3oool000@0ooooCP000?l00`000000003o0000o`2_0000
obP0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo
00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?oo
o`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?oo
o`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000
003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo02H0oooo00040?ooodh0003o00<000000000o`000?l0[`000?lX0?ooo`00DP3oool00`000000
oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?oo
o`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3o
ool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3o
ool000@0ooooCP000?l00`000000003o0000o`2_0000obP0oooo001B0?ooo`030000003oool0oooo
03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo
001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<00000
0?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3o
ool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo00040?ooodh0003o00<00000
0000o`000?l0[`000?lX0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo
00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?oo
o`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?oo
o`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000
003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`0V0?ooo`00103ooom>0000o`03000000000?l0003o0:l0003o:03oool0
0580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000
oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo001B0?oo
o`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3o
ool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3o
ool000@0ooooCP000?l00`000000003o0000o`2_0000obP0oooo001B0?ooo`030000003oool0oooo
03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo
001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo00<00000
0?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?ooo`0h0?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3o
ool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo00040?ooodh0003o00<00000
0000o`000?l0[`000?lX0?ooo`00DP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool09P3oool00580oooo
00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00DP3oool00`000000oooo0?oo
o`0h0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo02H0oooo001B0?ooo`030000003oool0oooo03P0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool09P3oool00580oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?oo
o`00BP3oool3000000D0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0V0?ooo`00
C03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
9P3oool000@0ooooCP000?l00`000000003o0000o`2_0000obP0oooo001:0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0e`3oool004X0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`3G0?ooo`00B`3oool3000000@0oooo00<000000?ooo`3oool0e`3oool0
0580oooo00<000000?ooo`3oool0e`3oool00580oooo00<000000?ooo`3oool0e`3oool00580oooo
00<000000?ooo`3oool0e`3oool00580oooo00<000000?ooo`3oool0e`3oool00580oooo00<00000
0?ooo`3oool0e`3oool00580oooo00<000000?ooo`3oool0e`3oool00580oooo00<000000?ooo`3o
ool0e`3oool00580oooo00<000000?ooo`3oool0e`3oool00580oooo00<000000?ooo`3oool0e`3o
ool00580oooo00<000000?ooo`3oool0e`3oool00580oooo00<000000?ooo`3oool0e`3oool00580
oooo00<000000?ooo`3oool0e`3oool00580oooo00<000000?ooo`3oool0e`3oool00580oooo00<0
00000?ooo`3oool0e`3oool00580oooo00<000000?ooo`3oool0e`3oool00580oooo00<000000?oo
o`3oool0e`3oool00580oooo00<000000?ooo`3oool0e`3oool00?l0oooo;@3oool00?l0oooo;@3o
ool00?l0oooo;@3oool00?l0oooo;@3oool00?l0oooo;@3oool00?l0oooo;@3oool00?l0oooo;@3o
ool00?l0oooo;@3oool00?l0oooo;@3oool00500oooo0P00003J0?ooo`00D@3oool00`000000oooo
0?ooo`3H0?ooo`00DP3oool00`000000oooo0?ooo`3G0?ooo`00D@3oool00`000000oooo0000003H
0?ooo`00D03oool010000000oooo0?ooo`00003H0?ooo`00C`3oool3000000030?ooo`0000000000
0=L0oooo003o0?ooobd0oooo003o0?ooobd0oooo003o0?ooobd0oooo003o0?ooobd0oooo0000\
\>"],
    ImageRangeCache->{{{0, 299.75}, {235.313, 0}} -> {-4, -1, 0, 0}}],
  "     ",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0666667 0.266667 0.0666667 0.266667 [
[.33333 .05417 -3 -9 ]
[.33333 .05417 3 0 ]
[.6 .05417 -3 -9 ]
[.6 .05417 3 0 ]
[.86667 .05417 -3 -9 ]
[.86667 .05417 3 0 ]
[1.025 .06667 0 -6.28125 ]
[1.025 .06667 10 6.28125 ]
[.05417 .33333 -6 -4.5 ]
[.05417 .33333 0 4.5 ]
[.05417 .6 -6 -4.5 ]
[.05417 .6 0 4.5 ]
[.05417 .86667 -6 -4.5 ]
[.05417 .86667 0 4.5 ]
[.06667 1.025 -5 0 ]
[.06667 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.33333 .06667 m
.33333 .07292 L
s
[(1)] .33333 .05417 0 1 Mshowa
.6 .06667 m
.6 .07292 L
s
[(2)] .6 .05417 0 1 Mshowa
.86667 .06667 m
.86667 .07292 L
s
[(3)] .86667 .05417 0 1 Mshowa
0 .06667 m
1 .06667 L
s
gsave
1.025 .06667 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.06667 .33333 m
.07292 .33333 L
s
[(1)] .05417 .33333 1 0 Mshowa
.06667 .6 m
.07292 .6 L
s
[(2)] .05417 .6 1 0 Mshowa
.06667 .86667 m
.07292 .86667 L
s
[(3)] .05417 .86667 1 0 Mshowa
.06667 0 m
.06667 1 L
s
gsave
.06667 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.52855 .06667 m
.52855 .06752 L
.52855 .0683 L
.52855 .0692 L
.52856 .07005 L
.52857 .07156 L
.52859 .0732 L
.52862 .075 L
.52866 .07691 L
.52875 .08034 L
.52887 .08388 L
.529 .08719 L
.5294 .09472 L
.52993 .10238 L
.53052 .10936 L
.53221 .12496 L
.53651 .15282 L
.54197 .17883 L
.54897 .20552 L
.55664 .23018 L
.56557 .25526 L
.57474 .27835 L
.58397 .29962 L
.59407 .32127 L
.60401 .34126 L
.61368 .35973 L
.62404 .37865 L
.63405 .39619 L
.64468 .41417 L
.65488 .4309 L
.66466 .44648 L
.67499 .46256 L
.68487 .47757 L
.69429 .49162 L
.70424 .50617 L
.71372 .51982 L
.72371 .53397 L
.73298 .54692 L
s
.56555 .06667 m
.56555 .06746 L
.56556 .06818 L
.56556 .06901 L
.56556 .0698 L
.56557 .07119 L
.56559 .07271 L
.56561 .07438 L
.56564 .07615 L
.56571 .07933 L
.56581 .08261 L
.56592 .08567 L
.56623 .09265 L
.56665 .09975 L
.56712 .10623 L
.56848 .12075 L
.56998 .13326 L
.57195 .14678 L
.57672 .17281 L
.58234 .19715 L
.58923 .22216 L
.59661 .2454 L
.60426 .26695 L
.61286 .28902 L
.6215 .30947 L
.63006 .32843 L
.63936 .3479 L
.64845 .36597 L
.65821 .38453 L
.66767 .4018 L
.67679 .4179 L
.6865 .4345 L
.69583 .45002 L
.70477 .46453 L
.71425 .47956 L
.72333 .49365 L
.73292 .50825 L
.74208 .52197 L
.75062 .53454 L
s
.6 .06667 m
.6 .06741 L
.6 .06808 L
.6 .06886 L
.60001 .06959 L
.60002 .0709 L
.60003 .07232 L
.60005 .07388 L
.60007 .07554 L
.60013 .07851 L
.60021 .08158 L
.6003 .08445 L
.60055 .09098 L
.6009 .09763 L
.60128 .10371 L
.6024 .11732 L
.60364 .12909 L
.60527 .14183 L
.60925 .16644 L
.61399 .1896 L
.61986 .21355 L
.62622 .23594 L
.63289 .25683 L
.64046 .27833 L
.64815 .29835 L
.65582 .31698 L
.66423 .33619 L
.67252 .35408 L
.68147 .3725 L
.6902 .38969 L
.69866 .40574 L
.70771 .42233 L
.71645 .43785 L
.72486 .45238 L
.73381 .46746 L
.7424 .4816 L
.7515 .49627 L
.76024 .51005 L
.76838 .52269 L
s
.63235 .06667 m
.63235 .06736 L
.63235 .068 L
.63236 .06873 L
.63236 .06943 L
.63237 .07066 L
.63238 .072 L
.63239 .07347 L
.63241 .07503 L
.63246 .07784 L
.63253 .08073 L
.6326 .08343 L
.63282 .0896 L
.63311 .09587 L
.63343 .10161 L
.63437 .11447 L
.63541 .1256 L
.63679 .13767 L
.64017 .16106 L
.64422 .18317 L
.64929 .20613 L
.65483 .22771 L
.66068 .24793 L
.66739 .26884 L
.67425 .28839 L
.68116 .30666 L
.68878 .32556 L
.69633 .34321 L
.70455 .36144 L
.7126 .37849 L
.72045 .39444 L
.72889 .41096 L
.73707 .42644 L
.74496 .44095 L
.7534 .45602 L
.76152 .47018 L
.77016 .48488 L
.77846 .4987 L
.78623 .51138 L
s
.66295 .06667 m
.66295 .06733 L
.66295 .06793 L
.66295 .06863 L
.66296 .06929 L
.66296 .07045 L
.66297 .07172 L
.66299 .07312 L
.663 .0746 L
.66305 .07726 L
.6631 .08001 L
.66316 .08258 L
.66335 .08842 L
.6636 .09438 L
.66387 .09982 L
.66468 .11205 L
.66557 .12263 L
.66676 .13412 L
.66967 .15645 L
.67318 .1776 L
.6776 .19967 L
.68247 .22048 L
.68765 .24006 L
.69363 .26038 L
.69978 .27945 L
.70601 .29733 L
.71293 .31588 L
.71983 .33326 L
.72738 .35125 L
.73482 .36812 L
.7421 .38394 L
.74996 .40034 L
.75761 .41574 L
.76503 .4302 L
.77297 .44523 L
.78065 .45937 L
.78883 .47406 L
.79673 .48789 L
.80412 .50059 L
s
.69206 .06667 m
.69206 .0673 L
.69206 .06787 L
.69206 .06854 L
.69206 .06916 L
.69207 .07028 L
.69207 .07149 L
.69209 .07282 L
.6921 .07424 L
.69214 .07677 L
.69218 .07939 L
.69224 .08184 L
.6924 .08741 L
.69261 .0931 L
.69285 .09829 L
.69355 .10996 L
.69433 .12007 L
.69536 .13106 L
.69791 .15243 L
.70099 .17274 L
.70488 .19399 L
.7092 .21408 L
.71381 .23305 L
.71917 .2528 L
.72471 .27139 L
.73036 .28887 L
.73666 .30705 L
.74298 .32414 L
.74993 .34186 L
.7568 .35852 L
.76356 .37417 L
.77089 .39043 L
.77805 .40571 L
.78501 .42009 L
.79249 .43505 L
.79974 .44914 L
.80749 .4638 L
.81499 .47761 L
.82203 .4903 L
s
.71986 .06667 m
.71986 .06727 L
.71986 .06782 L
.71987 .06846 L
.71987 .06906 L
.71987 .07012 L
.71988 .07128 L
.71989 .07256 L
.7199 .07391 L
.71994 .07634 L
.71998 .07884 L
.72003 .08119 L
.72017 .08653 L
.72035 .09197 L
.72057 .09695 L
.72118 .10813 L
.72186 .11782 L
.72277 .12837 L
.72502 .1489 L
.72775 .16845 L
.73121 .18894 L
.73506 .20838 L
.7392 .22677 L
.74403 .24597 L
.74905 .26409 L
.75418 .28117 L
.75995 .29898 L
.76575 .31575 L
.77215 .33319 L
.77851 .34962 L
.7848 .36507 L
.79163 .38116 L
.79833 .39631 L
.80487 .41058 L
.81191 .42545 L
.81876 .43947 L
.8261 .45407 L
.83322 .46784 L
.83992 .4805 L
s
.74654 .06667 m
.74654 .06725 L
.74654 .06778 L
.74654 .06839 L
.74654 .06896 L
.74654 .06999 L
.74655 .0711 L
.74656 .07233 L
.74657 .07363 L
.7466 .07596 L
.74664 .07837 L
.74668 .08062 L
.7468 .08575 L
.74697 .09098 L
.74716 .09577 L
.7477 .10652 L
.74831 .11584 L
.74912 .12598 L
.75112 .14576 L
.75356 .16462 L
.75666 .18443 L
.76012 .20326 L
.76386 .2211 L
.76823 .23978 L
.7728 .25745 L
.77749 .27414 L
.78277 .29158 L
.78811 .30803 L
.79402 .32518 L
.79993 .34135 L
.80578 .3566 L
.81216 .3725 L
.81844 .3875 L
.82458 .40164 L
.83121 .4164 L
.83768 .43032 L
.84464 .44484 L
.85139 .45855 L
.85777 .47117 L
s
.7722 .06667 m
.7722 .06723 L
.7722 .06774 L
.7722 .06832 L
.7722 .06888 L
.77221 .06987 L
.77221 .07094 L
.77222 .07212 L
.77223 .07338 L
.77226 .07562 L
.77229 .07794 L
.77233 .08011 L
.77244 .08506 L
.77259 .0901 L
.77276 .09471 L
.77325 .10508 L
.77379 .11407 L
.77451 .12386 L
.77631 .14296 L
.7785 .16119 L
.7813 .18037 L
.78444 .19863 L
.78783 .21597 L
.79181 .23415 L
.79598 .25138 L
.80028 .26769 L
.80514 .28476 L
.81007 .3009 L
.81555 .31775 L
.82103 .33367 L
.82648 .3487 L
.83245 .3644 L
.83833 .37923 L
.84411 .39322 L
.85037 .40785 L
.85648 .42167 L
.86306 .43609 L
.86948 .44972 L
.87555 .46228 L
s
.79696 .06667 m
.79696 .06721 L
.79696 .0677 L
.79697 .06827 L
.79697 .0688 L
.79697 .06976 L
.79698 .0708 L
.79698 .07194 L
.79699 .07315 L
.79701 .07532 L
.79704 .07756 L
.79708 .07966 L
.79718 .08444 L
.79731 .08931 L
.79747 .09376 L
.79791 .10378 L
.7984 .11247 L
.79905 .12194 L
.80068 .14042 L
.80266 .15809 L
.8052 .17669 L
.80805 .19443 L
.81115 .21129 L
.81479 .22901 L
.81862 .24582 L
.82257 .26176 L
.82706 .27848 L
.83162 .2943 L
.8367 .31085 L
.84181 .32651 L
.8469 .34132 L
.85249 .35681 L
.85801 .37145 L
.86345 .38529 L
.86935 .39978 L
.87513 .41348 L
.88137 .42779 L
.88746 .44133 L
.89323 .45381 L
s
.82091 .06667 m
.82091 .06719 L
.82091 .06767 L
.82092 .06822 L
.82092 .06874 L
.82092 .06966 L
.82092 .07067 L
.82093 .07177 L
.82094 .07294 L
.82096 .07504 L
.82099 .07721 L
.82102 .07925 L
.82111 .08387 L
.82123 .08859 L
.82137 .0929 L
.82177 .10261 L
.82222 .11103 L
.82281 .1202 L
.82429 .13812 L
.8261 .15527 L
.82842 .17334 L
.83103 .19059 L
.83386 .20701 L
.83721 .22428 L
.84073 .24071 L
.84439 .25629 L
.84854 .27266 L
.85277 .28818 L
.8575 .30443 L
.86227 .31983 L
.86703 .33442 L
.87226 .34968 L
.87746 .36414 L
.88258 .37782 L
.88815 .39216 L
.89362 .40572 L
.89954 .41991 L
.90532 .43335 L
.91082 .44575 L
s
.84413 .06667 m
.84413 .06717 L
.84413 .06764 L
.84413 .06817 L
.84413 .06867 L
.84413 .06957 L
.84414 .07055 L
.84414 .07162 L
.84415 .07276 L
.84417 .07479 L
.84419 .0769 L
.84422 .07887 L
.84431 .08336 L
.84442 .08794 L
.84454 .09212 L
.84491 .10154 L
.84532 .10971 L
.84586 .11862 L
.84721 .13603 L
.84887 .15269 L
.851 .17027 L
.85339 .18706 L
.856 .20308 L
.85909 .21993 L
.86235 .23598 L
.86573 .25123 L
.86959 .26726 L
.87352 .28248 L
.87794 .29844 L
.88239 .31358 L
.88686 .32794 L
.89177 .34299 L
.89666 .35726 L
.90149 .37078 L
.90675 .38495 L
.91193 .39838 L
.91755 .41243 L
.92305 .42576 L
.92828 .43806 L
s
.86667 .06667 m
.86667 .06716 L
.86667 .06761 L
.86667 .06813 L
.86667 .06862 L
.86667 .06949 L
.86668 .07044 L
.86668 .07148 L
.86669 .07258 L
.86671 .07457 L
.86673 .07661 L
.86675 .07853 L
.86683 .08289 L
.86693 .08734 L
.86705 .09141 L
.86738 .10056 L
.86776 .10851 L
.86826 .11717 L
.8695 .1341 L
.87103 .15032 L
.87299 .16744 L
.8752 .18382 L
.87761 .19944 L
.88047 .2159 L
.88349 .23159 L
.88663 .24652 L
.89022 .26223 L
.8939 .27717 L
.89802 .29284 L
.9022 .30773 L
.90638 .32187 L
.91101 .3367 L
.91562 .35077 L
.92018 .36412 L
.92516 .37813 L
.93007 .39141 L
.9354 .40533 L
.94063 .41854 L
.94561 .43074 L
s
0 0 1 r
.21914 1 m
.22652 .95635 L
.23724 .90044 L
.24974 .84355 L
.26629 .77913 L
.28671 .713 L
.31553 .63816 L
.35338 .56271 L
.4023 .4904 L
.46856 .42055 L
.5414 .36625 L
.6208 .32333 L
.69453 .29318 L
.76141 .27138 L
.82808 .25345 L
.88531 .2404 L
s
.23821 1 m
.24577 .96001 L
.25756 .90483 L
.27121 .84889 L
.28914 .78586 L
.31095 .72164 L
.34108 .64973 L
.37944 .57822 L
.42723 .51041 L
.48995 .44467 L
.55818 .39219 L
.63319 .34909 L
.70382 .31778 L
.76861 .29461 L
.83372 .27526 L
.88994 .26101 L
s
.25729 1 m
.26478 .96401 L
.27757 .90961 L
.29228 .85466 L
.31141 .79306 L
.33438 .73074 L
.36548 .66161 L
.40404 .59362 L
.45066 .52964 L
.51034 .46736 L
.57468 .41661 L
.64581 .37363 L
.71353 .3415 L
.77627 .3172 L
.8398 .29661 L
.89496 .2813 L
s
.27636 1 m
.28355 .96834 L
.29725 .91475 L
.31291 .86081 L
.3331 .80065 L
.35702 .74018 L
.38883 .67367 L
.42735 .60884 L
.4728 .54817 L
.52985 .48887 L
.59087 .43972 L
.65856 .39705 L
.72357 .36436 L
.78432 .33916 L
.84627 .31751 L
.90035 .30124 L
s
.29542 1 m
.30206 .97297 L
.3166 .92022 L
.33312 .86731 L
.35421 .80858 L
.37891 .7499 L
.41121 .68584 L
.44954 .62385 L
.49385 .56606 L
.54859 .50934 L
.60672 .46169 L
.67136 .41946 L
.73386 .38642 L
.79269 .36051 L
.85308 .33794 L
.90607 .32082 L
s
.31447 1 m
.3203 .97788 L
.33562 .92598 L
.35289 .8741 L
.37477 .81678 L
.40008 .75984 L
.4327 .69805 L
.47074 .63862 L
.51396 .58336 L
.56663 .52892 L
.62224 .48265 L
.68414 .44095 L
.74432 .40771 L
.80133 .38125 L
.86019 .35791 L
.91208 .34004 L
s
.33351 1 m
.33827 .98304 L
.35429 .932 L
.37224 .88116 L
.39478 .82522 L
.42057 .76993 L
.45338 .71026 L
.49105 .65315 L
.53322 .60012 L
.58406 .54771 L
.63743 .50273 L
.69687 .4616 L
.75491 .4283 L
.81019 .40141 L
.86756 .37743 L
.91837 .35889 L
s
.35252 1 m
.35596 .98844 L
.37262 .93827 L
.39116 .88845 L
.41426 .83385 L
.44043 .78013 L
.47332 .72243 L
.51056 .66742 L
.55175 .6164 L
.60092 .56581 L
.6523 .52202 L
.70952 .48148 L
.76558 .44821 L
.81922 .42102 L
.87515 .3965 L
.92489 .37739 L
s
.37152 1 m
.37338 .99406 L
.39061 .94474 L
.40967 .89593 L
.43323 .84263 L
.45969 .7904 L
.49256 .73454 L
.52935 .68143 L
.56961 .63222 L
.61727 .58327 L
.66686 .54059 L
.72206 .50067 L
.77629 .4675 L
.82838 .44009 L
.88293 .41514 L
.93162 .39552 L
s
.39048 1 m
.39052 .99987 L
.40826 .95141 L
.42778 .90358 L
.45173 .85154 L
.47838 .80072 L
.51118 .74656 L
.5475 .6952 L
.58688 .64763 L
.63315 .60017 L
.68112 .55853 L
.73449 .51922 L
.78703 .48621 L
.83766 .45866 L
.89087 .43335 L
.93854 .4133 L
s
.40962 1 m
.42558 .95824 L
.44549 .91138 L
.46975 .86054 L
.49655 .81106 L
.52921 .75849 L
.56506 .70873 L
.6036 .66265 L
.64861 .61655 L
.69509 .57588 L
.74679 .53717 L
.79775 .50437 L
.84701 .47674 L
.89895 .45115 L
.94561 .43074 L
s
0 g
gsave
.30667 .2 -61 -11.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
70.188 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
83.000 14.938 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
90.813 10.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
96.438 14.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
103.625 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
110.813 14.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16 .54667 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
70.188 12.813 moveto
(uv) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
91.750 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
98.938 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{245, 245},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003e0000mB000`400?l00000o`00003o403oool0
0`000000oooo0?ooo`3R0?ooo`00403oool00`000000oooo0?ooo`3R0?ooo`00403oool00`000000
oooo0?ooo`3R0?ooo`00403oool00`000000oooo0?ooo`3R0?ooo`00403oool00`000000oooo0?oo
o`3R0?ooo`00403oool00`000000oooo0?ooo`0g0?ooo`D00000=`3oool4000003T0oooo0P00000`
0?ooo`00403oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0>@3oool010000000oooo0?ooo`00000_0?ooo`00403oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0^0?oo
o`00403oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0]0?ooo`00403oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03L0oooo00@000000?ooo`3oool00000>03oool010000000oooo0?ooo`00000_0?oo
o`00403oool00`000000oooo0?ooo`0h0?ooo`800000>P3oool2000003X0oooo0P00000`0?ooo`00
403oool00`000000oooo0?ooo`3R0?ooo`00403oool00`000000oooo0?ooo`3R0?ooo`00403oool0
0`000000oooo0?ooo`3R0?ooo`00403oool00`000000oooo0?ooo`3I0?ooo`@000001@3oool00100
oooo00<000000?ooo`3oool0f03oool010000000oooo0?ooo`0000060?ooo`0000<0oooo00000000
0000M@0000000`3o0000000000000005000000030?l000000000000000D0000000<0o`0000000000
00001@0000000`3o0000000000000003000000030?l000000000000000@0000000<0o`0000000000
00000`0000000`3o0000000000000003000000030?l000000000000000<0000000<0o`0000000000
00000`0000000`3o0000000000000002000000030?l00000000000000080000000<0o`0000000000
00000P0000000`3o000000000000000M000000L0oooo00@000000?ooo`3oool000001P3oool00100
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02<0
oooo0P0000000`3oool00000000000060?ooo`00403oool00`000000oooo0?ooo`1U0?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo02h0oooo000@0?ooo`030000003oool0oooo06D0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0;@3o
ool00100oooo00<000000?ooo`3oool0I@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0]0?ooo`00403oool00`00
0000oooo0?ooo`1U0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo02d0oooo000@0?ooo`030000003oool0oooo06D0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool0;@3oool00100oooo00<000000?ooo`3oool0I@3oool00`3o0000oooo
0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0]0?ooo`00403oool00`000000oooo0?ooo`1U0?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02d0oooo000@
0?ooo`030000003oool0oooo06H0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0;@3oool00100oooo00<000000?oo
o`3oool0IP3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0]0?ooo`00403oool00`000000oooo0?ooo`1V0?ooo`03
0?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo02d0oooo000@0?ooo`030000003oool0oooo06H0oooo00<0o`000?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
;@3oool00100oooo00<000000?ooo`3oool0IP3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0]0?ooo`00403oool0
0`000000oooo0?ooo`1V0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02d0oooo000@0?ooo`030000003oool0oooo
06H0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool0;@3oool00100oooo00<000000?ooo`3oool0IP3oool00`3o0000
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0]0?ooo`00403oool00`000000oooo0?ooo`1W0?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02d0oooo
000@0?ooo`030000003oool0oooo06L0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0;@3oool00100oooo00<00000
0?ooo`3oool0I`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0]0?ooo`00403oool00`000000oooo0?ooo`1W0?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo02d0oooo000@0?ooo`030000003oool0oooo06L0oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0;03oool00100oooo00<000000?ooo`3oool0I`3oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0/0?ooo`00403o
ool00`000000oooo0?ooo`1X0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02`0oooo000@0?ooo`030000003oool0
oooo06P0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool0;03oool00100oooo00<000000?ooo`3oool0J03oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`0/0?ooo`00403oool00`000000oooo0?ooo`1X0?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02`0
oooo000@0?ooo`030000003oool0oooo03H0oooo0`0000000`3oool000000000000?0?ooo`030000
003oool0oooo0180oooo1@0000040?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02`0oooo000@0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool00P00000@0?ooo`8000002P3oool5000000<0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02`0oooo000@0?ooo`030000003o
ool0oooo03H0oooo00D000000?ooo`3oool0oooo000000080?ooo`D000000`3oool00`000000oooo
0000000A0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`3o0000oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0[0?ooo`00
403oool00`000000oooo0?ooo`0g0?ooo`050000003oool0oooo0?ooo`0000003`3oool010000000
oooo0?ooo`0000080?ooo`D00000103oool4000000H0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0:`3oool00100
oooo00<000000?ooo`3oool0=`3oool01@000000oooo0?ooo`3oool0000000l0oooo00D000000?oo
o`3oool0oooo0000000?0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0[0?ooo`00403oool00`000000oooo0?ooo`0f0?ooo`8000000P3oool2000000040?ooo`000000
0000000000X0oooo0`0000001@3oool00000000000000000oooo00<000002`3oool3000000L0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool0:P3oool00100oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0:P3oool00100oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool0:P3oool00100oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0:P3oool00100oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0000000B0?ooo`030000003oool0000001H0oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool0:P3oool00100oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool0:P3oool00100oooo00<000000?ooo`3oool0K03o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`3o0000103oool00`3o0000oooo
0?ooo`0Z0?ooo`00403oool00`000000oooo0?ooo`1/0?ooo`030?l0003oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00D0
o`000?ooo`3oool0oooo0?l000030?ooo`<0003o:`3oool00100oooo00<000000?ooo`3oool0K03o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo0?ooo`@0003o0P3oool00`3o0000oooo
0?ooo`0Y0?ooo`00403oool00`000000oooo0?ooo`1]0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo1000
0?l00`3oool0o`000?ooo`030?ooo`030?l0003oool0oooo02T0oooo000@0?ooo`030000003oool0
oooo06d0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo0080oooo00<0o`000000o`000?l00P000?l00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool0:@3oool00100oooo00<000000?ooo`3oool0KP3oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`000?l00`000?l01@3o
0000oooo0?ooo`3oool0o`0000@0oooo00<0o`000?ooo`3oool00P3oool20000obX0oooo000@0?oo
o`030000003oool0oooo06h0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`3oool4
0000o`@0oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`060?l000000?l0003o0000o`3oool0
o`00:P3oool00100oooo00<000000?ooo`3oool0K`3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`@0003o
0P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`000?l0
0`000?l40?ooo`030?l0003oool0oooo02P0oooo000@0?ooo`030000003oool0oooo06l0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`000?l00P000?l00`3oool0o`000?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool00`000?l30?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool09`3o
ool00100oooo00<000000?ooo`3oool0L03oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool30000o`@0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`<0003o00<0oooo0?l0003oool0103oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo02L0oooo000@0?ooo`030000003oool0oooo0700oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`040?l000000?l0003o0000o`80oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0003o00<0003o00D0o`00
0?ooo`3oool0oooo0?l000050?ooo`030?l0003oool0oooo00<0003o:@3oool00100oooo00<00000
0?ooo`3oool0L@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo0?ooo`<0003o1@3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00@0003o103oool00`3o0000oooo0?oo
o`020?ooo`040?l0003oool0oooo0?ooo`@0003o0P3oool00`3o0000oooo0?ooo`0W0?ooo`00403o
ool00`000000oooo0?ooo`1a0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00@0o`000000o`000?l0003o
0`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo10000?l30?ooo`030?l0
003oool0oooo00<0oooo00@0o`000?ooo`3oool0oooo10000?l00`3oool0o`000?ooo`040?ooo`03
0?l0003oool0oooo02H0oooo000@0?ooo`030000003oool0oooo0780oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool0
oooo0`000?l00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00@0o`000000o`00
0?l0003o0P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo10000?l00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool09P3oool00100
oooo00<000000?ooo`3oool0LP3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`3o0000003o0000o`030?ooo`030?l0003oool0oooo00<0
oooo00@0o`000?ooo`3oool0oooo0`000?l50?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`000?l00P000?l00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0V0?ooo`00403oool00`000000oooo0?ooo`1b0?ooo`03
0?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`<0
003o1@3oool00`3o0000oooo0?ooo`040?ooo`030?l000000?l0003o0080oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`020?ooo`80003o0`3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0oooo0P000?lX0?ooo`00403oool00`000000
oooo0?ooo`1c0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0103o0000
oooo0000o`000?l30?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool0oooo0`000?l5
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`000?l00P000?l00`3o0000oooo0?ooo`03
0?ooo`050?l0003oool0oooo0?ooo`3o0000103oool40000o`030?ooo`3o0000oooo02L0oooo000@
0?ooo`030000003oool0oooo07<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`80003o1@3oool00`3o0000oooo0?ooo`030?ooo`040?l000000?l0003o0000o`80oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`<0003o103oool00`3o0000oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`3o000010000?l00`3oool0o`000?ooo`020?ooo`030?l0
003oool0oooo02H0oooo000@0?ooo`030000003oool0oooo07@0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030000o`030?ooo`3o0000oooo00@0oooo00@0o`000?ooo`3oool0oooo
0`000?l00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00H0o`000000o`000?l0
003o0?ooo`3o00050?ooo`030?l0003oool0oooo0080oooo00<0o`000000o`000?l00P000?l00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool09@3oool00100
oooo00<000000?ooo`3oool0M03oool00`3o0000oooo0?ooo`040?ooo`030?l000000?l0003o00@0
oooo00<0o`000?ooo`3oool0103oool00`3o0000003o0000o`030?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool00P3oool20000o`D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`030000o`050?l0003oool0oooo0?ooo`3o0000103oool0103o0000oooo0?ooo`3oool2
0000obL0oooo00080?ooo`D000000`3oool00`000000oooo0?ooo`1d0?ooo`030?l0003oool0oooo
00<0oooo0P000?l00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo0P000?l50?oo
o`030?l0003oool0oooo00@0oooo00H0o`000?ooo`000?l0003o0?ooo`3o00050?ooo`030?l0003o
ool0oooo0080oooo00<0o`000000o`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo0`000?l00`3oool0o`000?ooo`0V0?ooo`002P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo07D0oooo00<0o`000?ooo`3oool00P000?l20?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool00P000?l00`3oool0o`000?ooo`050?ooo`030?l0003oool0
oooo0080oooo0`000?l40?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00`000?l0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`000?l00P000?l0
1@3o0000oooo0?ooo`3oool0o`0002L0oooo000:0?ooo`030000003oool0oooo00<0oooo0P00001f
0?ooo`030?l000000?l0003o00@0oooo00<0o`000?ooo`3oool0103oool30000o`@0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020000o`030?ooo`3o0000oooo00@0oooo00<0o`00
0?ooo`3oool00P3oool30000o`<0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`3o
ool30000o`<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0T0?ooo`002P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo07@0oooo0P000?l00`3o0000oooo0?ooo`04
0?ooo`040?l0003oool0oooo0?ooo`80003o00<0oooo0?l0003oool0103oool00`3o0000oooo0?oo
o`030?ooo`030?l000000?l0003o00@0oooo00<0o`000?ooo`3oool00`3oool01P3o0000003o0000
o`000?l0oooo0?l000@0oooo00<0o`000?ooo`3oool00`3oool30000o`80oooo00<0o`000?ooo`3o
ool00P3oool0103o0000oooo0?ooo`3oool20000obD0oooo000:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0LP3oool20000o`80oooo00<0o`000?ooo`3oool0103oool0103o0000
oooo0000o`000?l40?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`000?l00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P000?l40?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool00P000?l00`3o0000oooo0?ooo`030?ooo`050?l0003oool0oooo
0?ooo`3o00000`000?l00`3oool0o`000?ooo`0T0?ooo`002@3oool2000000D0oooo00<000000?oo
o`3oool0L03oool20000o`@0oooo00<0o`000?ooo`3oool0103oool20000o`H0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000003o0000o`030?ooo`030?l0003oool0oooo00@0oooo00@0o`000?oo
o`000?l0003o0P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo0`000?l2
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`000?l00P000?l40?ooo`030?l0003oool0
oooo02<0oooo000@0?ooo`030000003oool0oooo06h0oooo0P000?l70?ooo`040?l0003oool0oooo
0?ooo`80003o00<0oooo0?l0003oool01P3oool0103o0000oooo0?ooo`3oool20000o`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool30000o`@0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0000o`020000o`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool0oooo
0`000?l30?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool08P3oool00100oooo00<0
00000?ooo`3oool0K03oool20000o`T0oooo00@0o`000?ooo`000?l0003o103oool00`3o0000oooo
0?ooo`040?ooo`040?l0003oool0003o0000o`80oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`020000o`80oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`80
003o103oool00`3o0000oooo0?ooo`020?ooo`060?l000000?l0003o0000o`3oool0o`00103oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0280oooo000@0?ooo`030000003oool0oooo
06X0oooo0P000?l<0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool20000
o`D0oooo00<0o`000?ooo`3oool00`3oool20000o`@0oooo00<0o`000?ooo`3oool00`3oool01P3o
0000003o0000o`000?l0oooo0?l000@0oooo00@0o`000?ooo`3oool0oooo0P000?l00`3o0000oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool20000o`030?l0003oool0oooo0240
oooo000@0?ooo`030000003oool0oooo06P0oooo0P000?l<0?ooo`80003o00<0oooo0?l0003oool0
1@3oool0103o0000oooo0?ooo`3oool20000o`030?ooo`3o0000oooo00@0oooo00<0o`000?ooo`3o
ool00`000?l00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P000?l40?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000000o`000?l00P3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo0`000?l20?ooo`030?l0003oool0oooo0240oooo000@0?ooo`030000
003oool0oooo06L0oooo00<0003o0?ooo`3oool02P3oool20000o`<0oooo00<0o`000?ooo`3oool0
103oool0103o0000oooo0000o`000?l40?ooo`030?l0003oool0oooo00<0oooo0P000?l40?ooo`03
0?l0003oool0oooo00<0oooo00H0o`000?ooo`000?l0003o0?ooo`3o00050?ooo`040?l0003oool0
oooo0?ooo`80003o1@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo0P000?l00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo0240oooo000@0?ooo`030000003oool0oooo06D0oooo0P00
0?l;0?ooo`80003o1P3oool00`3o0000oooo0?ooo`030?ooo`80003o1P3oool0103o0000oooo0?oo
o`3oool20000o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool30000o`@0oooo
00<0o`000?ooo`3oool00P3oool0103o0000oooo0000o`000?l20?ooo`030?l0003oool0oooo0080
oooo00@0o`000?ooo`3oool0oooo0`000?l30?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool0803oool00100oooo00<000000?ooo`3oool0I03oool00`000?l0oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00P000?l00`3oool0o`000?ooo`060?ooo`03
0?l000000?l0003o00<0oooo00<0o`000?ooo`3oool00`3oool01P3o0000oooo0000o`000?l0oooo
0?l000D0oooo00<0o`000?ooo`3oool00P3oool20000o`@0oooo00<0o`000?ooo`3oool00`3oool3
0000o`030?ooo`3o0000oooo00<0oooo00@0o`000?ooo`3oool0oooo0P000?lR0?ooo`00403oool0
0`000000oooo0?ooo`1S0?ooo`030000o`3oool0oooo00T0oooo0P000?l:0?ooo`030?l0003oool0
003o00@0oooo00<0o`000?ooo`3oool00`3oool20000o`D0oooo00<0o`000?ooo`3oool00`3oool2
0000o`@0oooo00<0o`000?ooo`3oool00`3oool01P3o0000003o0000o`000?l0oooo0?l000@0oooo
00@0o`000?ooo`3oool0oooo0P000?l01@3o0000oooo0?ooo`3oool0o`0000D0oooo0`000?l00`3o
ool0o`000?ooo`0Q0?ooo`00403oool00`000000oooo0?ooo`1Q0?ooo`80003o2P3oool20000o``0
oooo0P000?l60?ooo`030?l0003oool0oooo0080003o0P3oool00`3o0000oooo0?ooo`020?ooo`04
0?l0003oool0oooo0?ooo`80003o00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?oo
o`80003o1@3oool00`3o0000oooo0?ooo`020?ooo`<0003o0P3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0003o0080003o00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0O0?oo
o`00403oool00`000000oooo0?ooo`1P0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3o
ool02P3oool20000o`030?ooo`3o0000oooo00D0oooo00<0o`000000o`000?l0103oool00`3o0000
oooo0?ooo`030?ooo`030?l000000?l0003o00<0oooo00<0o`000?ooo`3oool00`3oool0103o0000
oooo0000o`000?l20?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`000?l00P000?l00`3o
0000oooo0?ooo`020?ooo`040?l0003oool0oooo0?ooo`<0003o103oool01@3o0000oooo0?ooo`3o
ool0o`000240oooo000@0?ooo`030000003oool0oooo05l0oooo00<0003o0?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool2
0000o`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool0oooo0P000?l50?ooo`030?l0003o
ool0oooo00<0oooo0P000?l40?ooo`030?l0003oool0oooo0080oooo0P000?l30?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000000o`000?l00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080003o8@3oool00100oooo00<000000?ooo`3oool0G@3oool20000o`X0oooo0P000?l;
0?ooo`80003o1@3oool00`3o0000oooo0?ooo`020000o`<0oooo00<0o`000?ooo`3oool00`3oool0
103o0000oooo0000o`000?l20?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P00
0?l00`3oool0o`000?ooo`040?ooo`060?l000000?l0003o0000o`3oool0o`00103oool0103o0000
oooo0?ooo`3oool20000o`@0oooo00<0o`000?ooo`3oool00P3oool30000o`80oooo00<0o`000?oo
o`3oool07P3oool00100oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?ooo`090?ooo`03
0000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool01P3oool00`3o0000003o0?ooo`040?ooo`03
0?l0003oool0oooo00<0oooo0P000?l40?ooo`030?l0003oool0oooo00@0oooo0P000?l30?ooo`03
0?l0003oool0oooo0080oooo0P000?l40?ooo`030?l0003oool0oooo0080oooo00H0o`000?ooo`00
0?l0003o0?ooo`3o00050?ooo`050?l0003oool0003o0000o`3o0000103oool00`3o0000oooo0?oo
o`0N0?ooo`00403oool00`000000oooo0?ooo`1K0?ooo`030000o`3oool0oooo00T0oooo00<0003o
0?ooo`3oool02@3oool20000o`P0oooo0P000?l70?ooo`030?l0003oool0oooo0080003o00<0oooo
0?l0003oool0103oool0103o0000oooo0?ooo`3oool20000o`030?l0003oool0oooo00<0oooo00@0
o`000?ooo`000?l0003o0P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo0P000?l40?ooo`04
0?l0003oool0oooo0?ooo`<0003o0`3oool01@3o0000oooo0?ooo`3oool0o`000200oooo000@0?oo
o`030000003oool0oooo05T0oooo0P000?l:0?ooo`80003o2P3oool20000o`T0oooo00@0003o0?oo
o`3oool0o`001P3oool00`3o0000003o0000o`040?ooo`030?l0003oool0oooo0080oooo00@0o`00
0?ooo`000?l0003o0`3oool00`3o0000oooo0?ooo`020?ooo`80003o103oool00`3o0000oooo0?oo
o`020?ooo`060?l0003oool0003o0000o`3oool0o`00103oool0103o0000oooo0000o`000?l20?oo
o`050?l0003oool0oooo0?ooo`3o00000`3oool20000oal0oooo000@0?ooo`030000003oool0oooo
05P0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo
00L0oooo0P000?l40?ooo`030?l0003oool0oooo0080oooo0P000?l00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo0080oooo0P000?l50?ooo`030?l0003oool0oooo0080003o00<0oooo0?l0
003oool00`3oool00`3o0000oooo0?ooo`020?ooo`80003o103oool0103o0000oooo0?ooo`3oool2
0000o`@0oooo00D0o`000?ooo`3oool0oooo0?l000030000o`030?ooo`3o0000oooo01h0oooo000@
0?ooo`030000003oool0oooo05L0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`08
0?ooo`80003o2@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080003o0P3oool0
0`3o0000oooo0?ooo`040?ooo`060?l0003oool0003o0000o`3oool0o`001P3oool20000o`<0oooo
00<0o`000?ooo`3oool00`3oool01P3o0000oooo0000o`000?l0oooo0?l000@0oooo00H0o`000?oo
o`000?l0003o0?ooo`3o00040?ooo`030?l0003oool0oooo0080003o00D0o`000?ooo`3oool0oooo
0?l0000O0?ooo`00403oool00`000000oooo0?ooo`1F0?ooo`030000o`3oool0oooo00P0oooo0P00
0?l:0?ooo`030000o`3oool0oooo00L0oooo0P000?l80?ooo`030?l000000?l0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool20000o`@0oooo00@0o`000?ooo`3oool0oooo0P000?l00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P000?l30?ooo`030?l0003oool0oooo0080oooo
0P000?l40?ooo`040?l0003oool0oooo0?ooo`<0003o0P3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo01`0oooo000@0?ooo`030000003oool0oooo05D0oooo00<0003o0?ooo`3oool0
203oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0
203oool00`000?l0o`000?ooo`040?ooo`040?l0003oool0oooo0?ooo`80003o00<0oooo0?l0003o
ool0103oool00`3o0000003o0000o`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool00P000?l00`3oool0o`000?ooo`030?ooo`060?l0003oool0003o0000o`3oool0o`00103oool0
1P3o0000oooo0000o`000?l0oooo0?l000<0oooo00@0o`000?ooo`3oool0oooo0P000?lN0?ooo`00
403oool00`000000oooo0?ooo`1D0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0
203oool20000o`P0oooo0P000?l90?ooo`80003o0P3oool00`3o0000oooo0?ooo`030?ooo`030?l0
00000?l0003o00@0oooo00@0o`000?ooo`3oool0oooo0P000?l50?ooo`030?l0003oool0oooo00<0
oooo0P000?l30?ooo`030?l0003oool0oooo0080oooo0P000?l40?ooo`040?l0003oool0oooo0?oo
o`80003o0`3oool00`3o0000oooo0?ooo`020?ooo`030?l000000?l0003o0200oooo000@0?ooo`03
0000003oool0oooo05<0oooo00<0003o0?ooo`3oool01`3oool20000o`X0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool20000o`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool0003o0P3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080003o00<0o`000?ooo`3oool00`3oool01P3o
0000oooo0000o`000?l0oooo0?l000@0oooo00H0o`000?ooo`000?l0003o0?ooo`3o00040?ooo`03
0?l0003oool0003o0080003o8P3oool00100oooo00<000000?ooo`3oool0DP3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo
0?ooo`070?ooo`80003o1P3oool0103o0000oooo0000o`000?l20?ooo`030?l0003oool0oooo00<0
oooo00<0o`000000o`000?l0103oool00`3o0000oooo0?ooo`020?ooo`030?l000000?l0003o00<0
oooo00<0o`000?ooo`3oool00P3oool20000o`<0oooo00<0o`000?ooo`3oool00P3oool20000o`<0
oooo00<0o`000?ooo`3oool00P3oool20000obD0oooo000@0?ooo`030000003oool0oooo0540oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`80003o203oool20000o`T0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000003o0?ooo`040?ooo`030?l0003oool0oooo0080oooo
00<0003o0?l0003oool0103oool0103o0000oooo0?ooo`3oool20000o`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool00P000?l00`3oool0o`000?ooo`030?ooo`060?l0003oool0003o0000
o`3oool0o`00103oool0103o0000oooo0000o`000?lW0?ooo`00403oool00`000000oooo0?ooo`1@
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool20000o`030?l0003oool0
oooo00@0oooo00H0o`000?ooo`000?l0003o0?ooo`3o00060?ooo`030?l000000?l0003o0080oooo
00<0o`000?ooo`3oool00`3oool20000o`<0oooo00<0o`000?ooo`3oool00P3oool20000o`<0oooo
00<0o`000?ooo`3oool00P3oool20000obT0oooo000@0?ooo`030000003oool0oooo0500oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool01`3oool20000o`P0oooo00@0003o0?ooo`3oool0o`001P3oool20000o`@0oooo
00<0o`000?ooo`3oool00P3oool20000o`D0oooo00<0o`000?ooo`3oool00P000?l00`3o0000oooo
0?ooo`030?ooo`060?l0003oool0003o0000o`3oool0o`00103oool0103o0000oooo0000o`000?l[
0?ooo`00403oool00`000000oooo0?ooo`1?0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool01`3oool20000o`T0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?oo
o`80003o103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0o`0000@0oooo00<0o`000?oo
o`3oool00P000?l20?ooo`030?l0003oool0oooo0080oooo00<0o`000000o`000?l00`3oool00`3o
0000oooo0?ooo`020?ooo`80003o0`3oool00`3o0000oooo0?ooo`020?ooo`80003o;@3oool00100
oooo00<000000?ooo`3oool0CP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool01`3oool20000o`T0oooo00<0003o0?ooo`3oool01@3oool20000o`L0
oooo00@0o`000?ooo`000?l0003o0P3oool00`3o0000oooo0?ooo`030?ooo`80003o103oool0103o
0000oooo0?ooo`3oool20000o`030?l0003oool0oooo00<0oooo00H0o`000?ooo`000?l0003o0?oo
o`3o00040?ooo`040?l0003oool0003o0000obl0oooo000@0?ooo`030000003oool0oooo04d0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo
00<0o`000000o`3oool0103oool00`3o0000oooo0?ooo`020000o`030?ooo`3o0000oooo00@0oooo
00<0o`000000o`000?l00P3oool00`3o0000oooo0?ooo`030?ooo`80003o0`3oool00`3o0000oooo
0?ooo`020?ooo`80003o<@3oool00100oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`070?ooo`80003o1P3oool20000o`T0oooo0P000?l00`3o0000oooo0?ooo`030?ooo`030?l00000
0?l0003o00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0o`000?ooo`030?ooo`030?l0003o
ool0oooo0080003o00<0oooo0?l0003oool00`3oool0103o0000oooo0000o`000?lc0?ooo`00403o
ool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`80003o2@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo00P0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3o0000oooo00@0oooo
00<0o`000?ooo`3oool00P000?l00`3oool0o`000?ooo`040?ooo`80003o0`3oool00`3o0000oooo
0?ooo`020?ooo`80003o=@3oool00100oooo00<000000?ooo`3oool0BP3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080003o0P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0003o00@0oooo00<0o`000?ooo`3oool00P000?l00`3o0000oooo0?ooo`030?ooo`040?l0003o
ool0003o0000ocL0oooo000@0?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0203o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo0P000?l60?ooo`030?l00000
0?l0oooo00<0oooo00<0o`000?ooo`3oool00P3oool20000o`H0oooo0P000?l30?ooo`030?l0003o
ool0oooo0080oooo0P000?li0?ooo`00403oool00`000000oooo0?ooo`180?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo00D0oooo0P000?l00`3o0000oooo0?ooo`030?ooo`060?l0003oool0oooo0000o`3oool0o`00
1@3oool00`000?l0o`000?ooo`030?ooo`030?l0003oool0oooo0080003o>`3oool00100oooo00<0
00000?ooo`3oool0B03oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`80003o1`3oool00`000?l0oooo0?oo
o`060?ooo`80003o1`3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo0P000?l30?ooo`050?l0
003oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`020?ooo`80003o?@3oool00100oooo
00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`000?l0o`000?ooo`040?ooo`030?l000000?l0003o00<0oooo
00H0o`000?ooo`3oool0oooo0000o`3o000n0?ooo`00403oool00`000000oooo0?ooo`160?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool20000o`P0oooo00<0003o0?ooo`3o
ool01@3oool20000o`H0oooo00@0o`000?ooo`000?l0003o0P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00@0oooo00<0o`000000o`000?l0@03oool00100oooo00<000000?ooo`3o
ool0AP3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool00`3oool01P3o0000oooo0?ooo`000?l0oooo0?l000D0oooo00<0003o0?ooo`3oool0@03oool0
0100oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool20000o`H0oooo0P000?l80?ooo`80003o00<0o`000?oo
o`3oool00`3oool00`3o0000003o0000o`030?ooo`030?l0003oool0oooo0080003o@`3oool00100
oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00L0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3o0000oooo00<0oooo00<0o`000?oo
o`000?l0A@3oool00100oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`000?l20?oo
o`040?l0003oool0oooo0?ooo`80003oAP3oool00100oooo00<000000?ooo`3oool0@`3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo0P000?l60?ooo`030?l000000?l0003o
00<0oooo00@0o`000?ooo`3oool0003oB03oool00100oooo00<000000?ooo`3oool0@`3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`040?ooo`80003o203oool00`000?l0oooo0?ooo`060?ooo`030000o`3o0000oooo
00@0oooo0P000?m90?ooo`00403oool00`000000oooo0?ooo`120?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo0P000?l70?ooo`030000o`3oool0oooo00D0oooo0P000?l60?ooo`030000o`3oool0oooo00H0
oooo0P000?l80?ooo`040000o`3oool0oooo0?l000<0oooo00<0003o0?ooo`3oool0B@3oool00100
oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool20000o`<0oooo00@0o`000?ooo`3oool0003oC03oool00100
oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`80003oC@3oool00100oooo
00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
0P000?l80?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0C@3oool00100oooo00<0
00000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`80003o1`3oool00`000?l0oooo0?oo
o`060?ooo`80003o1P3oool00`000?l0oooo0?ooo`1>0?ooo`00403oool00`000000oooo0?ooo`0o
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0C`3oool00100oooo00<000000?oo
o`3oool0?P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0500oooo000@0?ooo`03
0000003oool0oooo01D0oooo1@0000030?ooo`80000000<0oooo0000000000000`3oool00`000000
oooo0?ooo`090?ooo`D000001`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool20000o`H0oooo0P000?mC0?ooo`00403oool00`000000oooo
0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02000000<0
oooo00<000000?ooo`000000103oool500000080oooo00D000000?ooo`3oool0oooo000000060?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool20000o`L0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`1C0?ooo`00403oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool00000
00/0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool0E03oool00100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo1@00
00020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo05D0oooo000@0?ooo`030000003oool0oooo01P0oooo00D000000?ooo`3oool0oooo
000000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0203oool200000080
oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`80003oF03oool000P0oooo
100000040?ooo`030000003oool0oooo01T0oooo00@000000?ooo`00000000000P3oool200000005
0?ooo`00000000000000003oool00`0000090?ooo`040000003oool00000000000D0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo0P000?l6
0?ooo`030000o`3oool0oooo05P0oooo00080?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool05@3oool01@000000oooo0?ooo`3oool0000001P0oooo00<000000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo05T0oooo00090?ooo`030000003oool0oooo
00@0oooo0P00000G0?ooo`<00000603oool2000000L0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`1J0?ooo`002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03T0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1K0?ooo`00203oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo03T0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool20000oeh0
oooo00090?ooo`8000001@3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0GP3oool00100oooo00<000000?ooo`3oool0>03oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo05l0oooo000@0?ooo`030000003oool0oooo03L0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`1P0?ooo`00403oool00`000000oooo0?ooo`0g0?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0H@3oool00100oooo00<000000?ooo`3o
ool0=P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0680oooo000@0?ooo`030000
003oool0oooo03H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1S0?ooo`00403o
ool00`000000oooo0?ooo`0e0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0I03o
ool00100oooo00<000000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo06D0oooo000@0?ooo`030000003oool0oooo03@0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`1V0?ooo`00403oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool0I`3oool00100oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo06P0oooo000@0?ooo`030000003oool0oooo03<0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1Y0?ooo`00403oool00`000000oooo0?ooo`0c
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0JP3oool00100oooo00<000000?oo
o`3oool0<P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo06/0oooo000@0?ooo`03
0000003oool0oooo0380oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1[0?ooo`00
403oool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
K03oool00100oooo00<000000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo06d0oooo000@0?ooo`030000003oool0oooo0340oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`1^0?ooo`00403oool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool0K`3oool00100oooo00<000000?ooo`3oool0<03oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo0700oooo000@0?ooo`030000003oool0oooo0300oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1`0?ooo`00403oool00`000000oooo0?oo
o`0_0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0L@3oool00100oooo00<00000
0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0780oooo000@0?oo
o`030000003oool0oooo02l0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1c0?oo
o`00403oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool0L`3oool00100oooo00<000000?ooo`3oool0;P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo07@0oooo000@0?ooo`030000003oool0oooo02h0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`1e0?ooo`00403oool00`000000oooo0?ooo`0]0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0MP3oool00100oooo00<000000?ooo`3oool0;@3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo07H0oooo000@0?ooo`030000003oool0oooo02d0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1g0?ooo`00403oool00`000000oooo
0?ooo`0/0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0N03oool00100oooo00<0
00000?ooo`3oool0;03oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo07T0oooo000@
0?ooo`030000003oool0oooo02`0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1i
0?ooo`00403oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0NP3oool00100oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo07/0oooo000@0?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`1k0?ooo`00403oool00`000000oooo0?ooo`0Z0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0O03oool00100oooo00<000000?ooo`3oool0:P3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo07`0oooo000@0?ooo`030000003oool0oooo
02X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1m0?ooo`00403oool00`000000
oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0OP3oool00100oooo
00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo07h0oooo
000@0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`1o0?ooo`00403oool00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool0O`3oool00100oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo0800oooo000@0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`200?ooo`00403oool00`000000oooo0?ooo`0X0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0P@3oool00100oooo00<000000?ooo`3oool0:03oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo0880oooo000@0?ooo`030000003oool0oooo02L0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`220?ooo`00403oool00`000000oooo0?ooo`0W
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0P`3oool00100oooo00<000000?oo
o`3oool09`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00D0003o0?oo
o`3oool0oooo0000o`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
1@000?l0oooo0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo08<0oooo000@0?ooo`030000003oool0oooo02L0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`240?ooo`00403oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0Q03oool00100oooo00<000000?ooo`3oool09P3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`05
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo08D0oooo000@0?ooo`030000003oool0oooo02H0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`250?ooo`00403oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0QP3oool000T0oooo0P0000050?ooo`030000003oool0oooo02D0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?oo
o`000?l01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`260?ooo`00203oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`270?ooo`002P3oool00`00
0000oooo0?ooo`030?ooo`8000009P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
08P0oooo000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`050?oo
o`050000o`3oool0oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo08P0oooo00080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0903oool0
0`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo08T0oooo00090?ooo`8000001@3oool00`000000oooo0?ooo`0T
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0R@3oool00100oooo00<000000?oo
o`3oool0903oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool0
1@000?l0oooo0?ooo`3oool0003o00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo08X0oooo000@0?ooo`030000003oool0oooo02@0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l0103o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`2:0?ooo`00403oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0
oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0
003o0?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
R`3oool00100oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo08/0oooo
000@0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`2<0?ooo`00403oool00`000000oooo
0?ooo`0S0?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0S03oool00100oooo00<000000?ooo`3oool08`3oool00`000?l0
oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0
003o00@0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o08l0oooo000@
0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`050000o`3o
ool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`00
0?l0103oool00`000?l0oooo0?ooo`2=0?ooo`00403oool00`000000oooo0?ooo`0R0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?oo
o`000?l0103oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l0T03oool0
0100oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo
0?ooo`000?l0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00D0003o0?ooo`3oool0oooo
0000o`040?ooo`030000o`3oool0oooo08h0oooo000@0?ooo`030000003oool0oooo0280oooo00<0
003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00D0003o0?ooo`3oool0
oooo0000o`050?ooo`050000o`3oool0oooo0?ooo`000?l0103oool01@000?l0oooo0?ooo`3oool0
003o00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`2>0?ooo`00403oool00`00
0000oooo0?ooo`0R0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`00
0?l0T@3oool00100oooo00<000000?ooo`3oool08P3oool01@000?l0oooo0?ooo`3oool0003o00@0
oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00<0003o0?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00D0003o0?ooo`3oool0oooo0000
o`040?ooo`030000o`3oool0oooo08l0oooo000@0?ooo`030000003oool0oooo0240oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l0103o
ool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l0103oool01@000?l0oooo
0?ooo`3oool0003o00@0oooo00D0003o0?ooo`3oool0oooo0000o`2B0?ooo`00403oool00`000000
oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@000?l0
oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0
003o00<0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00<0
003o0?ooo`3oool0T03oool00100oooo00<000000?ooo`3oool08@3oool01@000?l0oooo0?ooo`3o
ool0003o00@0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo
00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00D0003o0?ooo`3o
ool0oooo0000o`040?ooo`030000o`3oool0oooo0900oooo000@0?ooo`030000003oool0oooo0240
oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo0080oooo00D0003o0?oo
o`3oool0oooo0000o`040?ooo`050000o`3oool0oooo0?ooo`000?l0103oool01@000?l0oooo0?oo
o`3oool0003o00@0oooo00D0003o0?ooo`3oool0oooo0000o`2C0?ooo`00403oool00`000000oooo
0?ooo`0Q0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool01@000?l0oooo0?ooo`3oool0003o
00@0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`050000o`3oool0oooo0?ooo`000?l0103o
ool01@000?l0oooo0?ooo`3oool0003o00@0oooo00<0003o0?ooo`3oool0T@3oool00100oooo00<0
00000?ooo`3oool08@3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00D0003o0?ooo`3oool0
oooo0000o`030?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`040?oo
o`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0
oooo0940oooo000@0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool01@000?l0oooo0?ooo`3oool0003o00@0oooo
00D0003o0?ooo`3oool0oooo0000o`2D0?ooo`00403oool00`000000oooo0?ooo`0P0?ooo`030000
o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`050000o`3oool0oooo0?oo
o`000?l00`3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l0103oool0
1@000?l0oooo0?ooo`3oool0003o00@0oooo00<0003o0?ooo`3oool0TP3oool00100oooo00<00000
0?ooo`3oool0803oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l00`3o
ool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`000?l0oooo
0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l0103oool01@000?l0oooo0?ooo`3oool0003o
09D0oooo000@0?ooo`030000003oool0oooo0200oooo00D0003o0?ooo`3oool0oooo0000o`040?oo
o`050000o`3oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`000?l0103oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`2C0?ooo`00403oool00`000000oooo0?ooo`0P0?ooo`050000o`3o
ool0oooo0?ooo`000?l0103oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3o
ool00P3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool0U03oool00100oooo00<000000?oo
o`3oool07`3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l0103oool0
1@000?l0oooo0?ooo`3oool0003o00<0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`050000
o`3oool0oooo0?ooo`000?l0103oool01@000?l0oooo0?ooo`3oool0003o09H0oooo000@0?ooo`03
0000003oool0oooo01l0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o
00<0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`050000o`3oool0oooo0?ooo`000?l00`3o
ool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`000?l0oooo
0?ooo`2E0?ooo`00403oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0080oooo00D0
003o0?ooo`3oool0oooo0000o`030?ooo`050000o`3oool0oooo0?ooo`000?l0103oool01@000?l0
oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0
003o00<0oooo00<0003o0?ooo`3oool0U@3oool00?D0oooo003e0?ooo`00m@3oool00?D0oooo003e
0?ooo`00m@3oool00?D0oooo003e0?ooo`00m@3oool00?D0oooo000?0?ooo`800000i03oool000l0
oooo0P00003T0?ooo`003P3oool010000000oooo0?ooo`00003S0?ooo`003@3oool200000080oooo
0P00003R0?ooo`00m@3oool00?D0oooo003e0?ooo`00m@3oool00001\
\>"],
    ImageRangeCache->{{{0, 244}, {244, 0}} -> {0, 0, 0, 0}}],
  "  ",
  StyleBox["\n\t\tFigure 2.15",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The mapping   ",
  Cell[BoxData[
      \(w\ \  = \(f \((z)\) = \ z\^\(1/2\)\)\)]],
  "    (and  ",
  Cell[BoxData[
      \(z\ \  = \(\(f\^\(-1\)\) \((w)\) = \ w\^2\)\)]],
  ")."
}], "Text"],

Cell[TextData[{
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Consider the mapping  ",
  Cell[BoxData[
      \(w = z\^\(1/2\)\)],
    AspectRatioFixed->True],
  ".  Find the image of the ray  ",
  Cell[BoxData[
      \(r > 0, \[Theta] = \[Alpha]\)]],
  "  and circle ",
  Cell[BoxData[
      \(r = c\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Find the image of the ray  ",
  Cell[BoxData[
      \(r > 0, \[Theta] = \[Alpha]\)]],
  "  and circle ",
  Cell[BoxData[
      \(r = c\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_] = z\^\(1/2\);\)\), "\[IndentingNewLine]", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Iden, {0, 9, 
          0.5}, {0, \ \[Pi], \ \(\(\ \)\(\[Pi]\)\)\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-9\), 9}, {0, 9}}, 
        AspectRatio \[Rule] 1\/2, 
        Ticks \[Rule] {Range[\(-9\), 9, 1], Range[0, 9, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Brown, \ Pink}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>"];\
\)\ \), "\n", 
    \(\(PolarMap[
        f\ , {0, 9, 
          0.5}, {0, \ \[Pi], \ \(\(\ \)\(\[Pi]\)\)\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{0, 3}, {0, 3}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 3, 1], 
            Range[0, 3, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Brown, \ Pink}];\)\ \), "\n", 
    \(\(Print[\*"\"\<The image rays r>0, \[Theta]=\!\(\[Alpha]\/2\), and \
circles r=\!\(\@c\),\>\""];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_] = z\^\(1/2\);\)\), "\[IndentingNewLine]", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Iden, {0, 9, 
          0.5}, {\(\(\ \)\(\(-2\) \[Pi]\)\)\/3, \ \(\(\ \)\(2  \[Pi]\)\)\/3, \
\ \(\(\ \)\(\[Pi]\)\)\/12}, \[IndentingNewLine]PlotRange \[Rule] {{\(-9\), 
              9}, {\(-9\), 9}}, AspectRatio \[Rule] 1\/1, 
        Ticks \[Rule] {Range[\(-9\), 9, 1], Range[\(-9\), 9, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Pink}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>"];\
\)\ \), "\n", 
    \(\(PolarMap[
        f\ , {0, 9, 
          0.5}, {\(\(\ \)\(\(-2\) \[Pi]\)\)\/3, \(\(\ \)\(2  \[Pi]\)\)\/3, \ \
\(\(\ \)\(\[Pi]\)\)\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
              3}, {\(-3\), 3}}, 
        AspectRatio \[Rule] 
          2, \[IndentingNewLine]Ticks \[Rule] {Range[0, 3, 1], 
            Range[\(-3\), 3, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Pink}];\)\ \), "\n", 
    \(\(Print[\*"\"\<The image rays r>0, \[Theta]=\!\(\[Alpha]\/2\), and \
circles r=\!\(\@c\),\>\""];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_] = z\^\(1/2\);\)\), "\[IndentingNewLine]", 
    \(\(g[z_] = z + 1;\)\), "\[IndentingNewLine]", 
    \(\(h[z_] = f[g[z]];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        g, {0, 1, 
          0.1}, {\(-\ \[Pi]\), \ \[Pi], \ \(\(\ \)\(\[Pi]\)\)\/24}, \
\[IndentingNewLine]PlotRange \[Rule] {{0, 2}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[0, 2, 0.5], Range[\(-1\), 1, 1\/2]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\[IndentingNewLine]", 
    \(\(lemniscate = 
        ParametricPlot[{\(\@2\) 
              Cos[t]\/\(1 + \((Sin[t])\)\^2\), \(\@2\) \(Cos[t] Sin[t]\)\/\(1 \
+ \((Sin[t])\)\^2\)}, {t, \(-1.57\), 1.57}, 
          PlotStyle \[Rule] {Thickness[0.009], Red}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The radii, and circles.\>"];\)\ \), "\n", 
    \(\(range = 
        PolarMap[
          h\ , {0, 1, 
            0.1}, {\(-\ \[Pi]\), \ \[Pi], \ \(\(\ \)\(\[Pi]\)\)\/24}, \
\[IndentingNewLine]PlotRange \[Rule] {{0, 1.42}, {\(-0.5\), 0.5}}, 
          AspectRatio \[Rule] \(\(\ \)\(1\)\)\/1.42, \[IndentingNewLine]Ticks \
\[Rule] {Range[0, 0.5, 0.5], Range[\(-1\), 1, 0.5]}, 
          AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Blue, Cyan}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[range, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<The image curves under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[range, lemniscate, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<The outer boundary curve is a lemniscate.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<((u - 1\!\(\()\^2\)\) + \!\(v\^2\))((u + 1\!\(\()\^2\)\) \
+ \!\(v\^2\)) = 1\>\""];\)\ \), "\[IndentingNewLine]", 
    \(Print[\*"\"\<(u,v) = (\!\(\@2\)\!\(Cos[t]\/\(1 + \((Sin[t])\)\^2\)\), \
\!\(\@2\)\!\(\(Cos[t] Sin[t]\)\/\(1 + \((Sin[t])\)\^2\)\))\>\""]\), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tWe can easily extend what we've done to integer powers greater than 2.  \
We begin by letting n be a positive integer, considering the function  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^n\)\)]],
  ",  for  ",
  Cell[BoxData[
      \(z = r\ \[ExponentialE]\^\[ImaginaryI]\[Theta] \[NotEqual] 0\)]],
  ",  and then expressing it in the polar coordinate form\n\n\t\t\t",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ \(z\^n\  = \ \(r\^n\) \[ExponentialE]\^\
\[ImaginaryI]n\[Theta]\)\)\)]],
  ".  \n\nIf we use polar coordinates for ",
  Cell[BoxData[
      \(w = \[Rho]\ \[ExponentialE]\^\[ImaginaryI]\[Phi]\)]],
  " in the w -plane, this mapping can be given by the system of equations  \n\
\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{"\[Rho]", "=", 
          RowBox[{\(r\^n\), 
            StyleBox[
              RowBox[{"  ", 
                StyleBox["  ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]], 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"\[Phi]", "=", 
        RowBox[{"n", " ", 
          RowBox[{"\[Theta]", 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "  "
}], "Text"],

Cell[TextData[{
  "\tThe image of the ray  ",
  Cell[BoxData[
      \(r > 0\)]],
  ", ",
  Cell[BoxData[
      \(\[Theta] = \[Alpha]\)]],
  "  is the ray  ",
  Cell[BoxData[
      \(\[Rho] > 0\)]],
  " , ",
  Cell[BoxData[
      \(\[Phi] = n\ \[Alpha]\)]],
  "  and the angles at the origin are increased by the factor ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ".  The functions  ",
  Cell[BoxData[
      RowBox[{"cos", " ", "n", " ", "\[Theta]", "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "sin", " ", "n", " ", 
        "\[Theta]"}]]],
  "  are periodic with period  ",
  Cell[BoxData[
      \(\(2  \[Pi]\)\/n\)]],
  ",  so ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is in general an ",
  StyleBox["n",
    FontFamily->"Courier New"],
  "-to-one function; that is, ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " points in the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-plane are mapped onto each non-zero point in the w-plane."
}], "Text"],

Cell[TextData[{
  "\t If we now restrict the domain of  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^n\)\)]],
  "  to the region \n\n\t\t\t",
  Cell[BoxData[
      \(E = {r\ \(\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\) : \ 
              r > 0\ and\ \(-\[Pi]\)\/n < \ \[Theta] \[LessEqual] \[Pi]\/n\)}\
\)]],
  ",  \n\nthen the image of ",
  StyleBox["E",
    FontFamily->"Courier New"],
  " under the mapping  ",
  Cell[BoxData[
      \(w = z\^n\)]],
  "  can be described by the set  \n\n\t\t\t",
  Cell[BoxData[
      \(F = {\[Rho]\ \(\(\[ExponentialE]\^\[ImaginaryI]\[Phi]\) : \ \[Rho] > 
                0\ and\  - \[Pi] < \ \[Phi] \[LessEqual] \[Pi]\)}\)]],
  ",   \n\nwhich consists of all points in the w-plane except the point w=0. \
The inverse mapping of f, which we shall denote by g, is then\n\n\t\t\t",
  Cell[BoxData[
      \(z = \(g \((w)\) = \(w\^\(1/n\) = \(\[Rho]\^\(1/
                    n\)\) \[ExponentialE]\^\(\[ImaginaryI]\[Phi]/n\)\)\)\)]],
  ", \n\nwhere ",
  Cell[BoxData[
      \(w \[Element] F\)]],
  ".  That is\n\t\t\t",
  Cell[BoxData[
      \(z = \(g \((w)\) = \(w\^\(1/n\) = \(\(|\)\(w\)\( | \^\(1/
                    n\)\)\(\[ExponentialE]\^\(\[ImaginaryI]Arg \((w)\)/
                      n\)\)\)\)\)\)]],
  ", \n\nwhere ",
  Cell[BoxData[
      \(w \[NotEqual] 0\)]],
  ".  As with the principle square root function, we make an analogous \
definition for  ",
  Cell[BoxData[
      \(n\^th\)]],
  " roots."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 2.2 (Principal ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      StyleBox[\(n\^th\),
        FontWeight->"Bold"]],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" Root Function).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]],
  "The function",
  StyleBox[" \n\n\t\t\t",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(z = \(g \((w)\) = \(w\^\(1/n\) = \(\(|\)\(w\)\( | \^\(1/
                    n\)\)\(\[ExponentialE]\^\(\[ImaginaryI]Arg \((w)\)/
                      n\)\)\)\)\)\)]],
  ", for ",
  Cell[BoxData[
      \(w \[NotEqual] 0\)]],
  "  \n\n",
  "is called the principal  ",
  Cell[BoxData[
      \(n\^th\)]],
  " root function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe leave as an exercise to show that f and g are inverses of each other \
that map the set E one-to-one and onto the set F and the set F one-to-one and \
onto the set E, respectively. Figure 2.16 illustrates this relationship.\
\>", "Text"],

Cell[TextData[{
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.833333 0.416667 0.833333 [
[1.025 .41667 0 -6.28125 ]
[1.025 .41667 10 6.28125 ]
[.16667 .85833 -5 0 ]
[.16667 .85833 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .41667 m
1 .41667 L
s
gsave
1.025 .41667 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.16667 0 m
.16667 .83333 L
s
gsave
.16667 .85833 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .83333 L
0 .83333 L
closepath
clip
newpath
0 .9 1 r
.16667 .41667 m
1.70647 -0.22114 L
1.74488 -0.11907 L
.16667 .41667 L
F
0 .5 .95 r
.16667 .41667 m
1.74488 -0.11907 L
1.77654 -0.0147 L
.16667 .41667 L
F
0 0 1 r
.16667 .41667 m
1.77654 -0.0147 L
1.80131 .09152 L
.16667 .41667 L
F
1 0 0 r
.16667 .41667 m
1.80131 .09152 L
1.81907 .19912 L
.16667 .41667 L
F
.9 .45 .45 r
.16667 .41667 m
1.81907 .19912 L
1.82976 .30766 L
.16667 .41667 L
F
1 .75 .75 r
.16667 .41667 m
1.82976 .30766 L
1.83333 .41667 L
.16667 .41667 L
F
0 1 0 r
.16667 .41667 m
1.83333 .41667 L
1.82976 .52567 L
.16667 .41667 L
F
0 .95 0 r
.16667 .41667 m
1.82976 .52567 L
1.81907 .63421 L
.16667 .41667 L
F
.45 .95 .45 r
.16667 .41667 m
1.81907 .63421 L
1.80131 .74182 L
.16667 .41667 L
F
1 .5 0 r
.16667 .41667 m
1.80131 .74182 L
1.77654 .84803 L
.16667 .41667 L
F
1 .6 0 r
.16667 .41667 m
1.77654 .84803 L
1.74488 .9524 L
.16667 .41667 L
F
1 1 0 r
.16667 .41667 m
1.74488 .9524 L
1.70647 1.05447 L
.16667 .41667 L
F
0 0 0 r
.5 Mabswid
0 .41667 m
1 .41667 L
s
.16667 .41667 m
0 0 rlineto s
.16667 .41667 m
.16667 .83333 L
s
.16667 .41667 m
0 0 rlineto s
.16667 .41667 m
.16667 0 L
s
newpath
.16667 .41667 .79167 -22.5 22.5 arc
s
0 g
gsave
.91667 .56667 -61 -14.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
73.938 10.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
72.313 17.250 moveto
(\\200\\200) show
77.563 17.250 moveto
(\\200) show
79.875 17.250 moveto
(\\200) show
73.938 24.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
84.875 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.91667 .29167 -61 -14.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 17.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
81.125 10.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
79.500 17.250 moveto
(\\200\\200) show
84.750 17.250 moveto
(\\200) show
87.063 17.250 moveto
(\\200) show
81.125 24.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
92.063 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
1 .45833 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.11667 .84167 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{243, 202.438},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003c0000bR000`400?l00000o`00003o9`3oool0
0`000000oooo0?ooo`390?ooo`009`3oool00`000000oooo0?ooo`390?ooo`009`3oool00`000000
oooo0?ooo`390?ooo`009`3oool00`000000oooo0?ooo`390?ooo`009`3oool00`000000oooo0?oo
o`390?ooo`009`3oool00`000000oooo0?ooo`390?ooo`009`3oool00`000000oooo0?ooo`390?oo
o`009`3oool00`000000oooo0?ooo`390?ooo`009`3oool00`000000oooo0?ooo`370?ooo`800>Ko
000W0?ooo`030000003oool0oooo0<D0oooo1000i_l002L0oooo00<000000?ooo`3oool0``3oool6
003Vo`009`3oool00`000000oooo0?ooo`300?ooo`T00>Ko000W0?ooo`030000003oool0oooo0;h0
oooo2`00i_l002L0oooo00<000000?ooo`3oool0^`3oool>003Vo`009`3oool00`000000oooo0?oo
o`2i0?oooa000>Ko000W0?ooo`030000003oool0oooo0;L0oooo4P00i_l002L0oooo00<000000?oo
o`3oool0]03ooolE003Vo`009`3oool00`000000oooo0?ooo`2b0?oooaL00>Ko000W0?ooo`030000
003oool0oooo0:l0oooo6P00i_l002L0oooo00<000000?ooo`3oool0[@3ooolL003Vo`009`3oool0
0`000000oooo0?ooo`2[0?oooah00>Ko000W0?ooo`030000003oool0oooo0:P0oooo8@00i_l002L0
oooo00<000000?ooo`3oool0YP3ooolS003Vo`009`3oool00`000000oooo0?ooo`2S0?ooobH00>Ko
000W0?ooo`030000003oool0oooo0:40oooo9@00i_l3001ol`009`3oool00`000000oooo0?ooo`2N
0?ooo`0300000000i_l00>Ko02800>Ko1P00Oo<002L0oooo00<000000?ooo`3oool0W03oool2003V
o`0300000000i_l00>Ko01l00>Ko2@00Oo<002L0oooo00<000000?ooo`3oool0VP3oool5003Vo`03
00000000i_l00>Ko01/00>Ko3000Oo<002L0oooo00<000000?ooo`3oool0U`3oool8003Vo`030000
0000i_l00>Ko01P00>Ko3`00Oo<002L0oooo00<000000?ooo`3oool0U@3oool;003Vo`0300000000
i_l00>Ko01@00>Ko4P00Oo<002L0oooo00<000000?ooo`3oool0T`3oool=003Vo`0300000000i_l0
0>Ko01400>Ko5@00Oo<002L0oooo00<000000?ooo`3oool0T03ooolA003Vo`0300000000i_l00>Ko
00d00>Ko6000Oo<002L0oooo00<000000?ooo`3oool0SP3ooolC003Vo`0300000000i_l00>Ko00X0
0>Ko6`00Oo<002L0oooo00<000000?ooo`3oool0R`3ooolF003Vo`0300000000i_l00>Ko00L00>Ko
7P00Oo<002L0oooo00<000000?ooo`3oool0R@3ooolH003Vo`0300000000i_l00>Ko00D00>Ko8000
Oo<002L0oooo00<000000?ooo`3oool0Q`3ooolK003Vo`0400000000i_l00>Ko003Vob<007oc000W
0?ooo`030000003oool0oooo08@0oooo7P00i_l00`00000007oc001ol`0T001ol`009`3oool00`00
0000oooo0?ooo`220?oooah00>Ko0`00Oo<00`00000007oc001ol`0S001ol`009`3oool00`000000
oooo0?ooo`1o0?oooah00>Ko1P00Oo<00`00000007oc001ol`0Q001ol`80003o000W0?ooo`030000
003oool0oooo07d0oooo7@00i_l9001ol`0300000000Oo<007oc01h007oc1@000?l002L0oooo00<0
00000?ooo`3oool0N`3ooolL003Vo``007oc00<00000001ol`00Oo<06P00Oo<90000o`009`3oool0
0`000000oooo0?ooo`1h0?oooa`00>Ko4000Oo<00`00000007oc001ol`0E001ol`d0003o000W0?oo
o`030000003oool0oooo07H0oooo6`00i_lC001ol`0300000000Oo<007oc014007oc4@000?l002L0
oooo00<000000?ooo`3oool0L`3ooolK003VoaL007oc00<00000001ol`00Oo<03@00Oo<D0000o`00
9`3oool00`000000oooo0?ooo`1a0?oooaX00>Ko6P00Oo<00`00000007oc001ol`09001olaP0003o
000W0?ooo`030000003oool0oooo06h0oooo6P00i_lM001ol`0300000000Oo<007oc00D007oc7000
0?l002L0oooo00<000000?ooo`3oool0K03ooolI003Vob0007oc00@00000001ol`00Oo<007oc8000
0?l002L0oooo00<000000?ooo`3oool0JP3ooolH003Vob@007oc00<000000000o`000?l080000?l0
02L0oooo00<000000?ooo`3oool0I`3ooolH003Vob<007oc10000?l00`000000003o0000o`0P0000
o`009`3oool00`000000oooo0?ooo`1U0?oooaL00>Ko8P00Oo<80000o`03000000000?l0003o0200
003o000W0?ooo`030000003oool0oooo0680oooo5`00i_lQ001ol``0003o00<000000000o`000?l0
80000?l002L0oooo00<000000?ooo`3oool0H03ooolF003Vob4007oc40000?l00`000000003o0000
o`0O0000o`009`3oool00`000000oooo0?ooo`1N0?oooaD00>Ko8000Oo<D0000o`03000000000?l0
003o01/0003o103o000002L0oooo00<000000?ooo`3oool0F`3ooolF003Voah007oc60000?l00`00
0000003o0000o`0F0000o`T0o`00000W0?ooo`030000003oool0oooo05T0oooo5@00i_lM001ola`0
003o00<000000000o`000?l04@000?l>0?l000009`3oool00`000000oooo0?ooo`1F0?oooaD00>Ko
7@00Oo<O0000o`03000000000?l0003o00`0003o00D0o`0000000000000000000?l00003000000/0
o`00000W0?ooo`030000003oool0oooo05@0oooo5000i_lL001olb@0003o00<000000000o`000?l0
1P000?l70?l000050000003o0000o`000?l000000000303o000002L0oooo00<000000?ooo`3oool0
DP3ooolC003Voa/007oc:0000?l010000000003o0000o`000?l<0?l000050000003o0000o`000?l0
00000000303o000002L0oooo00<000000?ooo`3oool0C`3ooolC003Voa/007oc:P000?l00`3o0000
00000?l0000?0?l000050000003o0000o`000?l0000000002`3o000002L0oooo00<000000?ooo`3o
ool0C@3ooolB003VoaX007oc:@000?l60?l000030000003o0000o`0000h0o`000P0000020?l00003
0000003o0000o`0000T0o`00000W0?ooo`030000003oool0oooo04X0oooo4P00i_lI001olbP0003o
303o00000`000000o`000?l0000<0?l00080000000<0o`00000000000000303o000002L0oooo00<0
00000?ooo`3oool0B03ooolA003VoaP007oc9`000?lA0?l000030000003o0000o`0001d0o`00000W
0?ooo`030000003oool0oooo04H0oooo4000i_lH001olbD0003o5P3o00000`000000o`000?l0000M
0?l000009`3oool00`000000oooo0?ooo`130?oooa000>Ko5`00Oo<T0000oa/0o`0000<000000?l0
003o00007@3o000002L0oooo00<000000?ooo`3oool0@@3oool?003VoaH007oc8`000?lP0?l00003
0000003o0000o`0001d0o`00000W0?ooo`030000003oool0oooo03h0oooo3`00i_lE001olb80003o
9@3o000010000000o`000?l0003o0005000000<0o`002`0000090?l000009`3oool00`000000oooo
0?ooo`0l0?ooo`h00>Ko5@00Oo<P0000ob/0o`0000<000000?l0003o00005P3o00060>IcL`009`3o
ool00`000000oooo0?ooo`0j0?ooo`d00>Ko5000Oo<O0000oc00o`0000<000000?l0003o00003P3o
000>0>IcL`009`3oool00`000000oooo0?ooo`0g0?ooo`d00>Ko4`00Oo<N0000ocD0o`0000<00000
0?l0003o00001P3o000F0>IcL`009`3oool00`000000oooo0?ooo`0e0?ooo``00>Ko4P00Oo<M0000
ocX0o`0000<000000?l0003VLg<0703VLg<002L0oooo00<000000?ooo`3oool0<P3oool<003Voa80
07oc6`000?li0?l000H0iW=c00<000000>IcL`3VLg<02P3VLg<00`000000iW=c0>IcL`030>IcL`03
0000003VLg<0iW=c00T0iW=c000W0?ooo`030000003oool0oooo0300oooo2`00i_lA001olaX0003o
=`3o000=0>IcL`030000003VLg<0iW=c00/0iW=c00D000000>IcL`3VLg<0iW=c0000000<0>IcL`00
9`3oool00`000000oooo0?ooo`0^0?ooo`X00>Ko4000Oo<I0000oc@0o`005P3VLg<00`000000iW=c
0>IcL`0;0>IcL`040000003VLg<0iW=c000000`0iW=c000W0?ooo`030000003oool0oooo02/0oooo
2`00i_l>001olaP0003o<P3o000M0>IcL`030000003VLg<0iW=c00`0iW=c00<000000>IcL`000000
303VLg<002L0oooo00<000000?ooo`3oool0:@3oool:003Vo`h007oc5P000?l_0?l002D0iW=c00<0
00000>IcL`3VLg<0303VLg<00`000000iW=c0000000<0>IcL`009`3oool00`000000oooo0?ooo`0V
0?ooo`X00>Ko3@00Oo<E0000ob`0o`00;@3VLg<00`000000iW=c0>IcL`0:0>IcL`L000002P3VLg<0
02L0oooo00<000000?ooo`3oool0903oool9003Vo``007oc50000?lZ0?l003@0iW=c00<000000>Ic
L`3VLg<06`3VLg<002L0oooo00<000000?ooo`3oool08P3oool8003Vo``007oc4P000?lW0?l003`0
iW=c00<000000>IcL`3VLg<06`3VLg<002L0oooo00<000000?ooo`3oool07`3oool8003Vo`/007oc
4@000?lU0?l004<0iW=c00<000000>IcL`3VLg<06`3VLg<002L0oooo00<000000?ooo`3oool07@3o
ool7003Vo`X007oc40000?lR0?l004/0iW=c00<000000>IcL`3VLg<05P3VLg<50?no_`009`3oool0
0`000000oooo0?ooo`0J0?ooo`L00>Ko2@00Oo<?0000oal0o`00D`3VLg<00`000000iW=c0>IcL`06
0>IcLaD0okno000W0?ooo`030000003oool0oooo01P0oooo1P00i_l9001ol`d0003o7@3o001D0>Ic
L`H0okno00<000000?no_`3o_kl06`3o_kl002L0oooo00<000000?ooo`3oool05P3oool5003Vo`P0
07oc30000?lJ0?l004d0iW=c5@3o_kl00`000000okno0?no_`0K0?no_`009`3oool00`000000oooo
0?ooo`0C0?ooo`D00>Ko1`00Oo<;0000oaP0o`00A@3VLg<T0?no_`030000003o_kl0okno01/0okno
000W0?ooo`030000003oool0oooo0140oooo1000i_l6001ol`X0003o5@3o000m0>IcLc@0okno00<0
00000?no_`3o_kl06`3o_kl002L0oooo00<000000?ooo`3oool03P3oool4003Vo`H007oc20000?lC
0?l003D0iW=c@`3o_kl00`000000okno0?no_`0K0?no_`009`3oool00`000000oooo0?ooo`0<0?oo
o`<00>Ko1@00Oo<70000oa00o`00;P3VLg=B0?no_`030000003o_kl0okno01/0okno000W0?ooo`03
0000003oool0oooo00X0oooo0P00i_l4001ol`H0003o3@3o000W0>IcLf80okno00<000000?no_`3o
_kl06P3o_kl002L0oooo00<000000?ooo`3oool01`3oool2003Vo`<007oc1@000?l;0?l001h0iW=c
LP3o_kl00`000000okno0?no_`0J0?no_`009`3oool00`000000oooo0?ooo`050?ooo`04003Vo`00
Oo<007oc001ol`<0003o203o000G0>IcLh40okno00<000000?no_`3o_kl06P3o_kl002L0oooo00<0
00000?ooo`3oool00P3oool00`00i_l007oc001ol`020000o`H0o`003`3VLg>@0?no_`030000003o
_kl0okno01X0okno000W0?ooo`80000000<0oooo001ol`000?l00`3o00080>IcLil0okno00<00000
0?no_`3o_kl06P3o_kl000<0oooog@00000C0?no_`009`3oool010000000oooo0?ooo`3oV@020?mo
0080Lo=c2000l`2O003o000300000000o`000?l001X00?l0000W0?ooo`030000003oool0oooo0080
oooo00<0ool00?nI003oV@000`3oO`0507?cL`l00?<0T000o`000`0000000?l0003o000J003o0000
9`3oool00`000000oooo0?ooo`050?ooo`040?oo003oV@00oiT00?nI00@0ogl01`1clg<G003c0840
0?l000<00000003o0000o`006P00o`0002L0oooo00<000000?ooo`3oool01`3oool20?oo00<0oiT0
1P3oO`0:07?cLah00?<0LP00o`000`0000000?l0003o000J003o00009`3oool00`000000oooo0?oo
o`0:0?ooo`80ool0103oV@070?mo00`0Lo=c9`00l`1Q003o000300000000o`000?l001/00?l0000W
0?ooo`030000003oool0oooo00`0oooo0`3oo`050?nI00P0ogl03`1clg<^003c05800?l000<00000
003o0000o`006`00o`0002L0oooo00<000000?ooo`3oool03P3oool40?oo00H0oiT02@3oO`0B07?c
LcD00?<0@`00o`000`0000000?l0003o000@003o008000000P00o`02000000D00?l0000W0?ooo`03
0000003oool0oooo0140oooo103oo`060?nI00/0ogl0501clg<m003c03@00?l000<00000003o0000
o`004@00o`00100000000?l0003o00000006003o00009`3oool00`000000oooo0?ooo`0C0?ooo`D0
ool01`3oV@0<0?mo01L0Lo=cA@00l`0T003o000300000000o`000?l001800?l00P000007003o0000
9`3oool00`000000oooo0?ooo`0F0?ooo`D0ool0203oV@0=0?mo01T0Lo=cC@00l`0E003o00030000
0000o`000?l001800?l00P000007003o00009`3oool00`000000oooo0?ooo`0H0?ooo`H0ool02@3o
V@0>0?mo01`0Lo=cE000l`06003o000300000000o`000?l001400?l000@00000003o0000o`000000
1P00o`0002L0oooo00<000000?ooo`3oool06`3oool60?oo00T0oiT0403oO`0N07?cLe<00?<000<0
0000003c0000l`001P00l`0:003o008000000P00o`02000000D00?l0000W0?ooo`030000003oool0
oooo01d0oooo1`3oo`0:0?nI0140ogl08@1clg=;003c000300000000l`000?<001H00?<01@00o`00
02L0oooo00<000000?ooo`3oool07`3oool80?oo00/0oiT04P3oO`0T07?cLd<00?<000<00000003c
0000l`006`00l`0002L0oooo00<000000?ooo`3oool08P3oool80?oo00`0oiT0503oO`0U07?cLc`0
0?<000<00000003c0000l`006`00l`0002L0oooo00<000000?ooo`3oool0903oool90?oo00`0oiT0
5P3oO`0X07?cLc@00?<000<00000003c0000l`006`00l`0002L0oooo00<000000?ooo`3oool09`3o
ool90?oo00d0oiT05`3oO`0Z07?cLbd00?<000<00000003c0000l`006`00l`0002L0oooo00<00000
0?ooo`3oool0:@3oool:0?oo00h0oiT0603oO`0]07?cLbD00?<000<00000003c0000l`006`00l`00
02L0oooo00<000000?ooo`3oool0;03oool:0?oo00h0oiT06P3oO`0`07?cLad00?<000<00000003c
0000l`006`00l`0002L0oooo00<000000?ooo`3oool0;P3oool:0?oo0100oiT06`3oO`0b07?cLaD0
0?<000<00000003c0000l`007000l`0002L0oooo00<000000?ooo`3oool0<03oool;0?oo0140oiT0
703oO`0e07?cL`d00?<000<00000003c0000l`007000l`0002L0oooo00<000000?ooo`3oool0<`3o
ool;0?oo0180oiT07@3oO`0g07?cL`H00?<000<00000003c0000l`007000l`0002L0oooo00<00000
0?ooo`3oool0=@3oool<0?oo0180oiT07`3oO`0h07?cL`030000001clg<00?<001`00?<0000W0?oo
o`030000003oool0oooo03P0oooo303oo`0C0?nI0200ogl0<`1clg<00`000000Lo=c07?cL`0207?c
L`<0000000@0Lo=c00000000000000004`00l`0002L0oooo00<000000?ooo`3oool0>P3oool=0?oo
01@0oiT08@3oO`0^07?cL`030000001clg<0Lo=c00<0Lo=c00D0000007?cL`1clg<0Lo=c00000006
07?cL`h00?<0000W0?ooo`030000003oool0oooo03`0oooo3P3oo`0E0?nI0280ogl0:01clg<00`00
0000Lo=c07?cL`0407?cL`050000001clg<0Lo=c07?cL`0000003P1clg<6003c00009`3oool00`00
0000oooo0?ooo`0o0?ooo`h0ool05@3oV@0T0?mo02<0Lo=c00<0000007?cL`1clg<01@1clg<01@00
0000Lo=c07?cL`1clg<0000001<0Lo=c000W0?ooo`030000003oool0oooo0440oooo3`3oo`0F0?nI
02D0ogl07P1clg<00`000000Lo=c07?cL`0507?cL`8000000P1clg<00`000000Lo=c07?cL`0A07?c
L`009`3oool00`000000oooo0?ooo`140?ooo`l0ool05`3oV@0W0?mo01P0Lo=c00<0000007?cL`1c
lg<0101clg<20000000307?cL`000000000001@0Lo=c000W0?ooo`030000003oool0oooo04H0oooo
403oo`0H0?nI02P0ogl04`1clg<00`000000Lo=c07?cL`0M07?cL`009`3oool00`000000oooo0?oo
o`190?oooa00ool0603oV@0Z0?mo00h0Lo=c00<0000007?cL`1clg<07@1clg<002L0oooo00<00000
0?ooo`3oool0B`3ooolA0?oo01T0oiT0:`3oO`0907?cL`030000001clg<0Lo=c01d0Lo=c000W0?oo
o`030000003oool0oooo04d0oooo4P3oo`0J0?nI02`0ogl00`1clg<00`000000Lo=c07?cL`0307?c
L`X000004@1clg<002L0oooo00<000000?ooo`3oool0D03ooolB0?oo01/0oiT0:`3oO`000`000000
ogl007?cL`0N07?cL`009`3oool00`000000oooo0?ooo`1B0?oooa<0ool06`3oV@0X0?mo00030000
003oO`00ogl000@0ogl06P1clg<002L0oooo00<000000?ooo`3oool0E@3ooolC0?oo01`0oiT0903o
O`000`000000ogl00?mo00090?mo01D0Lo=c000W0?ooo`030000003oool0oooo05L0oooo503oo`0M
0?nI01l0ogl000<000000?mo003oO`003`3oO`0@07?cL`009`3oool00`000000oooo0?ooo`1J0?oo
oa@0ool07@3oV@0L0?mo00030000003oO`00ogl000D0ogl000<000000?mo003oO`000`3oO`000`00
0000ogl00?mo00060?mo00/0Lo=c000W0?ooo`030000003oool0oooo05`0oooo5@3oo`0N0?nI01P0
ogl000<000000?mo003oO`001P3oO`001@000000ogl00?mo003oO`00000000h0ogl01P1clg<002L0
oooo00<000000?ooo`3oool0GP3ooolE0?oo0200oiT0503oO`000`000000ogl00?mo00070?mo0004
0000003oO`00ogl0000001<0ogl00@1clg<002L0oooo00<000000?ooo`3oool0H@3ooolE0?oo0240
oiT03`3oO`000`000000ogl00?mo00090?mo00030000003oO`00000001@0ogl0000W0?ooo`030000
003oool0oooo06<0oooo5P3oo`0Q0?nI00`0ogl000<000000?mo003oO`002@3oO`000`000000ogl0
0000000D0?mo00009`3oool00`000000oooo0?ooo`1V0?oooaH0ool08P3oV@080?mo00030000003o
O`00ogl000L0ogl01`00000B0?mo00009`3oool00`000000oooo0?ooo`1X0?oooaL0ool08`3oV@04
0?mo00030000003oO`00ogl00200ogl0000W0?ooo`030000003oool0oooo06X0oooo603oo`0S0?nI
00030000003oO`00ogl00240ogl0000W0?ooo`030000003oool0oooo06d0oooo603oo`0P0?nI0004
0000003oV@00oiT00?nI0200ogl0000W0?ooo`030000003oool0oooo06l0oooo6@3oo`0M0?nI0003
0000003oV@00oiT000D0oiT0703oO`0002L0oooo00<000000?ooo`3oool0LP3ooolI0?oo01X0oiT0
00<000000?nI003oV@002@3oV@0H0?mo00009`3oool00`000000oooo0?ooo`1d0?oooaX0ool05P3o
V@000`000000oiT00?nI000>0?nI01@0ogl0000W0?ooo`030000003oool0oooo07L0oooo6P3oo`0C
0?nI00030000003oV@00oiT00140oiT04@3oO`0002L0oooo00<000000?ooo`3oool0N@3ooolK0?oo
00l0oiT000<000000?nI003oV@005P3oV@0=0?mo00009`3oool00`000000oooo0?ooo`1k0?oooa`0
ool0303oV@000`000000oiT00?nI000J0?nI00T0ogl0000W0?ooo`030000003oool0oooo07h0oooo
703oo`090?nI00030000003oV@00oiT001h0oiT01@3oO`0002L0oooo00<000000?ooo`3oool0P03o
oolM0?oo00H0oiT000<000000?nI003oV@008@3oV@020?mo00009`3oool00`000000oooo0?ooo`23
0?oooad0ool00P3oV@000`000000oiT00?nI000T0?nI00009`3oool00`000000oooo0?ooo`250?oo
oad0ool000<000000?nI003oV@00903oV@0002L0oooo00<000000?ooo`3oool0R03ooolI0?oo0003
0000003oo`00ool00080ool08`3oV@0002L0oooo00<000000?ooo`3oool0RP3ooolG0?oo00030000
003oo`00ool000D0ool0803oV@0002L0oooo00<000000?ooo`3oool0S03ooolE0?oo00030000003o
o`00ool000L0ool07P3oV@0002L0oooo00<000000?ooo`3oool0S`3ooolB0?oo00030000003oo`00
ool000X0ool06`3oV@0002L0oooo00<000000?ooo`3oool0T@3oool?0?oo00030000003oo`00ool0
00h0ool0603oV@0002L0oooo00<000000?ooo`3oool0U03oool<0?oo00030000003oo`00ool00140
ool05@3oV@0002L0oooo00<000000?ooo`3oool0UP3oool90?oo00030000003oo`00ool001D0ool0
4P3oV@0002L0oooo00<000000?ooo`3oool0V03oool70?oo00030000003oo`00ool001P0ool03`3o
V@0002L0oooo00<000000?ooo`3oool0V`3oool30?oo00030000003oo`00ool001`0ool0303oV@00
02L0oooo00<000000?ooo`3oool0W@3oool00`3oo`0000000?oo000P0?oo00T0oiT0000W0?ooo`03
0000003oool0oooo0:00oooo8`3oo`060?nI00009`3oool00`000000oooo0?ooo`2R0?ooob@0ool0
0`3oV@0002L0oooo00<000000?ooo`3oool0Y@3ooolT0?oo00009`3oool00`000000oooo0?ooo`2W
0?ooob80ool0000W0?ooo`030000003oool0oooo0:T0oooo803oo`0002L0oooo00<000000?ooo`3o
ool0[03ooolM0?oo00009`3oool00`000000oooo0?ooo`2^0?oooa/0ool0000W0?ooo`030000003o
ool0oooo0;40oooo603oo`0002L0oooo00<000000?ooo`3oool0/`3ooolF0?oo00009`3oool00`00
0000oooo0?ooo`2f0?oooa<0ool0000W0?ooo`030000003oool0oooo0;P0oooo4@3oo`0002L0oooo
00<000000?ooo`3oool0^P3oool?0?oo00009`3oool00`000000oooo0?ooo`2m0?ooo``0ool0000W
0?ooo`030000003oool0oooo0;l0oooo2P3oo`0002L0oooo00<000000?ooo`3oool0`P3oool70?oo
00009`3oool00`000000oooo0?ooo`340?ooo`D0ool0000W0?ooo`030000003oool0oooo0<H0oooo
0`3oo`0002L0oooo00<000000?ooo`3oool0b@3oool002L0oooo00<000000?ooo`3oool0b@3oool0
02L0oooo00<000000?ooo`3oool0b@3oool002L0oooo00<000000?ooo`3oool0b@3oool002L0oooo
00<000000?ooo`3oool0b@3oool002L0oooo00<000000?ooo`3oool0b@3oool002L0oooo00<00000
0?ooo`3oool0b@3oool002L0oooo00<000000?ooo`3oool0b@3oool00?<0oooo003c0?ooo`00l`3o
ool00?<0oooo000W0?ooo`@00000b03oool002T0oooo00<000000?ooo`3oool0a`3oool002T0oooo
00<000000?ooo`3oool0a`3oool002T0oooo0P0000380?ooo`00:03oool00`000000oooo00000038
0?ooo`00:03oool010000000oooo0?ooo`0000370?ooo`009`3oool01@000000oooo0?ooo`3oool0
00000<L0oooo000V0?ooo`<0000000@0oooo0000000000000000aP3oool00?<0oooo003c0?ooo`00
l`3oool00?<0oooo003c0?ooo`00l`3oool00001\
\>"],
    ImageRangeCache->{{{0, 242}, {201.438, 0}} -> {0, 0, 0, 0}}],
  StyleBox["       ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.337109 0.280925 [
[1.025 .33711 0 -6.28125 ]
[1.025 .33711 10 6.28125 ]
[.5 .64303 -8 0 ]
[.5 .64303 8 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .33711 m
1 .33711 L
s
gsave
1.025 .33711 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 .9 1 r
.5 .33711 m
-0.5 .33711 L
-0.36603 .05618 L
.5 .33711 L
F
0 .5 .95 r
.5 .33711 m
-0.36603 .05618 L
0 -0.14947 L
.5 .33711 L
F
0 0 1 r
.5 .33711 m
0 -0.14947 L
.5 -0.22474 L
.5 .33711 L
F
1 0 0 r
.5 .33711 m
.5 -0.22474 L
1 -0.14947 L
.5 .33711 L
F
.9 .45 .45 r
.5 .33711 m
1 -0.14947 L
1.36603 .05618 L
.5 .33711 L
F
1 .75 .75 r
.5 .33711 m
1.36603 .05618 L
1.5 .33711 L
.5 .33711 L
F
0 1 0 r
.5 .33711 m
1.5 .33711 L
1.36603 .61803 L
.5 .33711 L
F
0 .95 0 r
.5 .33711 m
1.36603 .61803 L
1 .82369 L
.5 .33711 L
F
.45 .95 .45 r
.5 .33711 m
1 .82369 L
.5 .89896 L
.5 .33711 L
F
1 .5 0 r
.5 .33711 m
.5 .89896 L
0 .82369 L
.5 .33711 L
F
1 .6 0 r
.5 .33711 m
0 .82369 L
-0.36603 .61803 L
.5 .33711 L
F
1 1 0 r
.5 .33711 m
-0.36603 .61803 L
-0.5 .33711 L
.5 .33711 L
F
0 0 0 r
.5 Mabswid
0 .33711 m
1 .33711 L
s
.5 .33711 m
.5 .61803 L
s
.5 .33711 m
.5 .05618 L
s
0 g
gsave
1 .35116 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47 .63208 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{327.625, 202.438},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000570000bR000`400?l00000o`00003o=@00Oo=U
0000ofH0o`00A`3VLg<003H007ocI0000?mU0?l004P0iW=c000g001olf<0003oI03o00190>IcL`00
>000Oo=R0000of<0o`00BP3VLg<003T007ocH@000?mR0?l004/0iW=c000j001olf00003oH@3o001<
0>IcL`00>`00Oo=O0000of00o`00C@3VLg<003`007ocGP000?mO0?l004h0iW=c000m001oled0003o
GP3o001?0>IcL`00?P00Oo=L0000oed0o`00D03VLg<003l007ocF`000?mL0?l00540iW=c0010001o
leX0003oF`3o001B0>IcL`00@@00Oo=I0000oeX0o`00D`3VLg<0048007ocF0000?mI0?l005@0iW=c
0013001oleL0003oF03o001E0>IcL`00A000Oo=F0000oeL0o`00EP3VLg<004D007ocE@000?mF0?l0
05L0iW=c0016001ole@0003o00<000000?l0003o0000DP3o001H0>IcL`00A`00Oo=C0000o`030000
003o0000o`000540o`00F@3VLg<004P007ocDP000?l00`000000o`000?l0001@0?l005X0iW=c0019
001ole40003o00<000000?l0003o0000C`3o001K0>IcL`00BP00Oo=@0000o`030000003o0000o`00
04h0o`00G03VLg<004/007ocC`000?l00`000000o`000?l0001=0?l005d0iW=c001<001oldh0003o
00<000000?l0003o0000C03o001N0>IcL`00C@00Oo==0000o`030000003o0000o`0004/0o`00G`3V
Lg<004h007ocC0000?l00`000000o`000?l0001:0?l00600iW=c001?001old/0003o00<000000?l0
003o0000B@3o001Q0>IcL`00D000Oo=:0000o`030000003o0000o`0004P0o`00HP3VLg<0058007oc
B0000?l00`000000o`000?l000160?l006@0iW=c001C001oldL0003o00<000000?l0003o0000A@3o
001U0>IcL`00E000Oo=60000o`030000003o0000o`0004@0o`00IP3VLg<005D007ocA@000?l00`00
0000o`000?l000130?l006L0iW=c001F001old@0003o00<000000?l0003o0000@P3o001X0>IcL`00
E`00Oo=30000o`030000003o0000o`000440o`00J@3VLg<005P007oc@P000?l00`000000o`000?l0
00100?l006X0iW=c001I001old40003o00<000000?l0003o0000?`3o001[0>IcL`00FP00Oo=00000
o`030000003o0000o`0003h0o`00K03VLg<005/007oc?`000?l00`000000o`000?l0000m0?l006d0
iW=c001L001olch0003o00<000000?l0003o0000?03o001^0>IcL`00G@00Oo<m0000o`030000003o
0000o`0003/0o`00K`3VLg<005h007oc?0000?l00`000000o`000?l0000j0?l00700iW=c001O001o
lc/0003o00<000000?l0003o0000>@3o001a0>IcL`00H000Oo<j0000o`030000003o0000o`0003P0
o`00LP3VLg<0064007oc>@000?l00`000000o`000?l0000g0?l007<0iW=c001R001olcP0003o00<0
00000?l0003o0000=P3o001c0>IcL`40okno001S001olcL0003o00<000000?l0003o0000=@3o001`
0>IcL`D0okno001T001olcH0003o00<000000?l0003o0000=03o001^0>IcL`P0okno001U001olcD0
003o00<000000?l0003o0000<`3o001/0>IcL`/0okno001V001olc@0003o00<000000?l0003o0000
<P3o001Z0>IcL`h0okno001W001olc<0003o00<000000?l0003o0000<@3o001X0>IcLa40okno0003
003VofD007oc<P000?l00`000000o`000?l0000`0?l006H0iW=c503o_kl000H00>KoH`00Oo<a0000
o`030000003o0000o`0002l0o`00I03VLg<G0?no_`002@00i_mQ001olc00003o00<000000?l0003o
0000;P3o001R0>IcLaX0okno000<003Voel007oc;`000?l00`000000o`000?l0000]0?l00600iW=c
7@3o_kl000l00>KoG@00Oo<^0000o`030000003o0000o`0002`0o`00G@3VLg<Q0?no_`004P00i_mK
001olbd0003o00<000000?l0003o0000:`3o001K0>IcLb@0okno000E003VoeT007oc;0000?l00`00
0000o`000?l0000Z0?l005T0iW=c9`3o_kl001P00>KoE`00Oo<[0000o`030000003o0000o`0002T0
o`00E`3VLg<Z0?no_`006`00i_mE001olbX0003o00<000000?l0003o0000:03o001E0>IcLbd0okno
000O003Voe8007oc:@000?l00`000000o`000?l0000W0?l005<0iW=c<03o_kl002800>KoD000Oo<X
0000o`030000003o0000o`0002H0o`00D@3VLg<c0?no_`009@00i_m>001olbL0003o00<000000?l0
003o00009@3o001?0>IcLcH0okno000X003Vod`007oc9P000?l00`000000o`000?l0000T0?l004d0
iW=c>@3o_kl002/00>KoBP00Oo<U0000o`030000003o0000o`0002<0o`00BP3VLg<m0?no_`00;P00
i_m9001olb<0003o00<000000?l0003o00008@3o00190>IcLd00okno000a003VodL007oc8P000?l0
0`000000o`000?l0000P0?l004L0iW=c@`3o_kl003@00>KoA@00Oo<Q0000o`030000003o0000o`00
01l0o`00A@3VLg=60?no_`00=`00i_m3001olb00003o00<000000?l0003o00007P3o00130>IcLdT0
okno000j003Vod4007oc7`000?l00`000000o`000?l0000M0?l00440iW=cC03o_kl003h00>Ko?P00
Oo<N0000o`030000003o0000o`0001`0o`00?`3VLg=?0?no_`00@@00i_ll001olad0003o00<00000
0?l0003o00006`3o000m0>IcLe80okno0014003VocX007oc70000?l00`000000o`000?l0000J0?l0
03/0iW=cE@3o_kl004L00>Ko>000Oo<K0000o`030000003o0000o`0001T0o`00>03VLg=I0?no_`00
BP00i_lf001olaX0003o00<000000?l0003o0000603o000f0>IcLe`0okno001=003Voc@007oc6@00
0?l00`000000o`000?l0000G0?l003@0iW=cG`3o_kl005000>Ko<P00Oo<H0000o`030000003o0000
o`0001H0o`00<P3VLg=R0?no_`00D`00i_l`001olaL0003o00<000000?l0003o00005@3o000`0>Ic
LfD0okno001F003Vobh007oc5P000?l00`000000o`000?l0000D0?l002h0iW=cJ03o_kl005T00>Ko
;000Oo<E0000o`030000003o0000o`0001<0o`00;03VLg=[0?no_`00G@00i_lY001ola@0003o00<0
00000?l0003o00004P3o000Z0>IcLfh0okno001P003VobL007oc4`000?l00`000000o`000?l0000A
0?l002P0iW=cL@3o_kl006<00>Ko9@00Oo<B0000o`030000003o0000o`000100o`009@3VLg=e0?no
_`00IP00i_lS001ola40003o00<000000?l0003o00003`3o000S0>IcLgP0okno001Y003Vob4007oc
40000?l00`000000o`000?l0000>0?l00240iW=cN`3o_kl006`00>Ko7`00Oo<?0000o`030000003o
0000o`0000d0o`007`3VLg=n0?no_`00K`00i_lM001ol`h0003o00<000000?l0003o0000303o000M
0>IcLh40okno001b003Voa/007oc3@000?l00`000000o`000?l0000;0?l001/0iW=cQ03o_kl007D0
0>Ko6@00Oo<<0000o`030000003o0000o`0000X0o`006@3VLg>70?no_`00N000i_lG001ol`/0003o
00<000000?l0003o00002@3o000G0>IcLhX0okno001l003Voa@007oc2P000?l00`000000o`000?l0
00080?l001D0iW=cS@3o_kl007l00>Ko4P00Oo<90000o`030000003o0000o`0000L0o`004P3VLg>A
0?no_`00PP00i_l@001ol`P0003o00<000000?l0003o00001P3o000@0>IcLi@0okno0025003Vo`h0
07oc1`000?l00`000000o`000?l000050?l000h0iW=cU`3o_kl008P00>Ko3000Oo<60000o`030000
003o0000o`0000@0o`00303VLg>J0?no_`00R`00i_l:001ol`D0003o00<000000?l0003o00000`3o
000:0>IcLid0okno002>003Vo`P007oc10000?l00`000000o`000?l000020?l000P0iW=cX03o_kl0
09400>Ko1P00Oo<30000o`040000003o0000o`000?l000H0iW=cX`3o_kl009@00>Ko1000Oo<20000
o`030000003o0000o`0000@0iW=cYP3o_kl009L00>Ko0P00Oo<00`000?l000000?l000020>IcLjT0
okno0007003Vool00000:000000I0?no_`00U`3oo`020?nI00030?mo00000000Lo=c00800?<0Z@00
o`0009@0ool0103oV@020?mo00030000001clg<0Lo=c00@00?<0YP00o`000940ool01P3oV@030?mo
00040000001clg<0Lo=c07?cL`H00?<0U000o`0200000003003o00000000000000X00?l0002>0?oo
00P0oiT0103oO`000`000000Lo=c07?cL`0207?cL`P00?<0T000o`000`0000000?l0003o00020000
00/00?l0002;0?oo00X0oiT01@3oO`000`000000Lo=c07?cL`0307?cL`X00?<0S@00o`001@000000
0?l0003o0000o`00000000/00?l000280?oo00`0oiT01P3oO`000`000000Lo=c07?cL`0407?cL``0
0?<0RP00o`001@0000000?l0003o0000o`00000000/00?l000250?oo00h0oiT01`3oO`000`000000
Lo=c07?cL`0507?cL`h00?<0Q`00o`001@0000000?l0003o0000o`00000000/00?l000220?oo0100
oiT0203oO`000`000000Lo=c07?cL`0607?cLa000?<0P`00o`02000000800?l00P00000;003o0000
O`3oo`0B0?nI00T0ogl000<0000007?cL`1clg<01`1clg<B003c09400?l0001l0?oo01@0oiT02P3o
O`000`000000Lo=c07?cL`0807?cLa@00?<0SP00o`0007T0ool05P3oV@0;0?mo00030000001clg<0
Lo=c00T0Lo=c5P00l`2;003o0000MP3oo`0H0?nI00`0ogl000<0000007?cL`1clg<02P1clg<H003c
08P00?l0001c0?oo01X0oiT03@3oO`000`000000Lo=c07?cL`0;07?cLaX00?<0Q@00o`000700ool0
703oV@0>0?mo00030000001clg<0Lo=c00`0Lo=c7@00l`21003o0000K@3oo`0N0?nI00l0ogl000<0
000007?cL`1clg<03@1clg<O003c07h00?l0001Z0?oo0200oiT0403oO`000`000000Lo=c07?cL`0>
07?cLb400?<0N`00o`0006H0ool08`3oV@0A0?mo00030000001clg<0Lo=c00l0Lo=c8`00l`1h003o
0000H`3oo`0U0?nI0180ogl000<0000007?cL`1clg<0401clg<U003c07D00?l0001P0?oo02L0oiT0
4`3oO`000`000000Lo=c07?cL`0A07?cLbL00?<0LP00o`0005d0ool0:@3oV@0D0?mo00030000001c
lg<0Lo=c0180Lo=c:@00l`1_003o0000FP3oo`0[0?nI01D0ogl000<0000007?cL`1clg<04`1clg<[
003c06`00?l0001G0?oo02d0oiT05P3oO`000`000000Lo=c07?cL`0D07?cLbd00?<0J@00o`0005@0
ool0;`3oV@0G0?mo00030000001clg<0Lo=c01D0Lo=c;`00l`1V003o0000D@3oo`0a0?nI01P0ogl0
00<0000007?cL`1clg<05P1clg<a003c06<00?l0001>0?oo03<0oiT06@3oO`000`000000Lo=c07?c
L`0G07?cLc<00?<0H000o`0004/0ool0=@3oV@0J0?mo00030000001clg<0Lo=c01P0Lo=c=@00l`1M
003o0000B03oo`0g0?nI01/0ogl000<0000007?cL`1clg<06@1clg<g003c05X00?l000150?oo03T0
oiT0703oO`000`000000Lo=c07?cL`0J07?cLcX00?<0EP00o`000480ool0>`3oV@0M0?mo00030000
001clg<0Lo=c01/0Lo=c?000l`1C003o0000?`3oo`0m0?nI01h0ogl000<0000007?cL`1clg<0701c
lg<n003c05000?l0000l0?oo03l0oiT07`3oO`000`000000Lo=c07?cL`0M07?cLd000?<0C@00o`00
03T0ool0@@3oV@0P0?mo00030000001clg<0Lo=c01h0Lo=c@P00l`1:003o0000=P3oo`130?nI0240
ogl000<0000007?cL`1clg<07`1clg=4003c04L00?l0000b0?oo04H0oiT08P3oO`000`000000Lo=c
07?cL`0P07?cLdH00?<0A000o`0002l0ool0B03oV@0S0?mo00030000001clg<0Lo=c0240Lo=cB000
l`11003o0000;03oo`190?nI02D0ogl000<0000007?cL`1clg<08`1clg=9003c03h00?l0000Y0?oo
04/0oiT09P3oO`000`000000Lo=c07?cL`0T07?cLd/00?<0>`00o`0002H0ool0C@3oV@0W0?mo0003
0000001clg<0Lo=c02D0Lo=cC@00l`0h003o00008`3oo`1?0?nI02P0ogl000<0000007?cL`1clg<0
9P1clg=?003c03D00?l0000P0?oo0540oiT0:@3oO`000`000000Lo=c07?cL`0W07?cLe400?<0<P00
o`0001d0ool0D`3oV@0Z0?mo00030000001clg<0Lo=c02P0Lo=cD`00l`0_003o00006P3oo`1E0?nI
02/0ogl000<0000007?cL`1clg<0:@1clg=F003c02/00?l0000G0?oo05L0oiT0;03oO`000`000000
Lo=c07?cL`0Z07?cLeP00?<0:000o`0001@0ool0F@3oV@0]0?mo00030000001clg<0Lo=c02/0Lo=c
FP00l`0U003o00004@3oo`1K0?nI02h0ogl000<0000007?cL`1clg<0;01clg=L003c02800?l0000>
0?oo05d0oiT0;`3oO`000`000000Lo=c07?cL`0]07?cLeh00?<07`00o`0000/0ool0G`3oV@0`0?mo
00030000001clg<0Lo=c02h0Lo=cH000l`0L003o0000203oo`1Q0?nI0340ogl000<0000007?cL`1c
lg<0;`1clg=R003c01T00?l000050?oo06<0oiT0<P3oO`000`000000Lo=c07?cL`0`07?cLf@00?<0
5P00o`0000030?oo003oV@00oiT006@0oiT0<`3oO`000`000000Lo=c07?cL`0a07?cLfH00?<04`00
o`0006H0oiT0=03oO`000`000000Lo=c07?cL`0b07?cLfP00?<04000o`0006D0oiT0=@3oO`000`00
0000Lo=c07?cL`0c07?cLfX00?<03@00o`0006@0oiT0=P3oO`000`000000Lo=c07?cL`0d07?cLf`0
0?<02P00o`0006<0oiT0=`3oO`000`000000Lo=c07?cL`0e07?cLfh00?<01`00o`000680oiT0>03o
O`000`000000Lo=c07?cL`0f07?cLg000?<01000o`000640oiT0>@3oO`000`000000Lo=c07?cL`0g
07?cLg<00?<0001P0?nI03X0ogl000<0000007?cL`1clg<0>01clg=b003c0000G`3oV@0k0?mo0003
0000001clg<0Lo=c03T0Lo=cL@00l`0005h0oiT0?03oO`000`000000Lo=c07?cL`0j07?cLg000?<0
001M0?nI03d0ogl000<0000007?cL`1clg<0>`1clg=_003c0000G03oV@0n0?mo00030000001clg<0
Lo=c03`0Lo=cKP00l`0005/0oiT0?`3oO`000`000000Lo=c07?cL`0m07?cLfd00?<0001J0?nI0400
ogl000<0000007?cL`1clg<0?P1clg=/003c0000F@3oV@110?mo00030000001clg<0Lo=c03l0Lo=c
J`00l`0005P0oiT0@P3oO`000`000000Lo=c07?cL`1007?cLfX00?<0001G0?nI04<0ogl000<00000
07?cL`1clg<0@@1clg=Y003c0000EP3oV@140?mo00030000001clg<0Lo=c0480Lo=cJ000l`0005D0
oiT0A@3oO`000`000000Lo=c07?cL`1307?cLfL00?<0001D0?nI04H0ogl000<0000007?cL`1clg<0
A01clg=V003c0000D`3oV@170?mo00030000001clg<0Lo=c04D0Lo=cI@00l`000580oiT0B03oO`00
0`000000Lo=c07?cL`1607?cLf@00?<0001@0?nI04X0ogl000<0000007?cL`1clg<0B01clg=R003c
0000C`3oV@1;0?mo00030000001clg<0Lo=c04T0Lo=cH@00l`0004h0oiT0C03oO`000`000000Lo=c
07?cL`1:07?cLf000?<0001=0?nI04d0ogl000<0000007?cL`1clg<0B`1clg=O003c0000C03oV@1>
0?mo00030000001clg<0Lo=c04`0Lo=cGP00l`0004/0oiT0C`3oO`000`000000Lo=c07?cL`1=07?c
Led00?<0001:0?nI0500ogl000<0000007?cL`1clg<0CP1clg=L003c0000B@3oV@1A0?mo00030000
001clg<0Lo=c04l0Lo=cF`00l`0004P0oiT0DP3oO`000`000000Lo=c07?cL`1@07?cLeX00?<00017
0?nI05<0ogl000<0000007?cL`1clg<0D@1clg=I003c0000AP3oV@1D0?mo00030000001clg<0Lo=c
0580Lo=cF000l`0004D0oiT0E@3oO`000`000000Lo=c07?cL`1C07?cLeL00?<000140?nI05H0ogl0
E`1clg=F003c0000@`3oV@1G0?mo05P0Lo=cE@00l`000480oiT0F03oO`1I07?cLe@00?<000110?nI
05T0ogl0FP1clg=C003c0000@03oV@1J0?mo05/0Lo=cDP00l`0003l0oiT0F`3oO`1L07?cLe400?<0
000n0?nI05`0ogl0G@1clg=@003c0000?@3oV@1M0?mo00@0Lo=c00<0000007?cL`1clg<0E`1clg=?
003c0000?03oV@1N0?mo00<0Lo=c00<0000007?cL`000000F@1clg=>003c0000>`3oV@1O0?mo00<0
Lo=c00<0000007?cL`000000FP1clg==003c0000>P3oV@1P0?mo0080Lo=c00D0000007?cL`1clg<0
Lo=c0000001J07?cLd`00?<0000i0?nI0640ogl00P1clg<01@000000Lo=c07?cL`1clg<0000005/0
Lo=cB`00l`0003P0oiT0HP3oO`001@1clg<00000000000000000Lo=c00<00000F`1clg=:003c0000
=`3oV@1S0?mo06@0Lo=cB@00l`0003H0oiT0I03oO`1U07?cLdP00?<0000e0?nI06D0ogl0IP1clg=7
003c0000=03oV@1V0?mo06L0Lo=cAP00l`0003<0oiT0I`3oO`1X07?cLdD00?<0000b0?nI06P0ogl0
J@1clg=4003c0000\
\>"],
    ImageRangeCache->{{{0, 326.625}, {201.438, 0}} -> {-1, -1, 0, 0}}],
  StyleBox["  \n\tFigure 2.16",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The mapping   ",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^n\)\)]],
  "   (and  ",
  Cell[BoxData[
      \(z = \(g \((w)\) = w\^\(1/n\)\)\)]],
  ").  "
}], "Text"],

Cell[TextData[{
  StyleBox["Extra Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Explore the mapping  ",
  Cell[BoxData[
      \(w = z\^3\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Find the image of the ray  ",
  Cell[BoxData[
      \(r > 0, \[Theta] = \[Alpha]\)]],
  "  and circle ",
  Cell[BoxData[
      \(r = c\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_] = z\^3;\)\), "\[IndentingNewLine]", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Iden, {0, 3, 
          0.5}, {0, \(\(\ \)\(\[Pi]\)\)\/2, \ \(\(\ \)\(\[Pi]\)\)\/18}, \
\[IndentingNewLine]PlotRange \[Rule] {{0, 3.5}, {0, 3.5}}, 
        AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-9\), 9, 1], Range[0, 9, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Brown, Pink}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>"];\
\)\ \), "\n", 
    \(\(PolarMap[
        f\ , {0, 3, 
          0.5}, {0, \(\(\ \)\(\[Pi]\)\)\/2, \ \(\(\ \)\(\[Pi]\)\)\/18}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-27\), 27}, {\(-27\), 27}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {{\(-27\), \(-8\), 0, 1, 8, 
              27}, {\(-27\), \(-8\), 0, 8, 27}}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Brown, Pink}];\)\ \), "\n", 
    \(\(Print[\*"\"\<The image rays r > 0, \[Theta] = 3\[Alpha], and circles \
r = \!\(c\^3\),\>\""];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_] = z\^3;\)\), "\[IndentingNewLine]", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Iden, {0, 3, 
          0.5}, {\(\(\ \)\(-\[Pi]\)\)\/4, \(\(\ \)\(\[Pi]\)\)\/4, \ \(\(\ \
\)\(\[Pi]\)\)\/24}, \[IndentingNewLine]PlotRange \[Rule] {{0, 4}, {\(-2.5\), 
              2.5}}, AspectRatio \[Rule] 5\/4, 
        Ticks \[Rule] {Range[\(-9\), 9, 1], Range[\(-9\), 9, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>"];\
\)\ \), "\n", 
    \(\(PolarMap[
        f\ , {0, 3, 
          0.5}, {\(\(\ \)\(-\[Pi]\)\)\/4, \(\(\ \)\(\[Pi]\)\)\/4, \ \(\(\ \
\)\(\[Pi]\)\)\/24}, \[IndentingNewLine]PlotRange \[Rule] {{\(-27\), 
              27}, {\(-27\), 27}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {{\(-27\), \(-8\), 0, 
              1, {8, "\< 8\>"}, 27}, {\(-27\), \(-8\), 0, 8, 27}}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\n", 
    \(\(Print[\*"\"\<The image rays r > 0, \[Theta] = 3\[Alpha], and circles \
r = \!\(c\^3\),\>\""];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Find the image of the rectangle ",
  Cell[BoxData[
      \(R = \ {\((x, y)\) : \ 0 < x < 1\/2, 0 < y < 7\/5}\)],
    AspectRatioFixed->True],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, Iden, z];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^3;\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {0, 0.5, 0.1}, {0, 1.4, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.05\), 
              0.55}, {\(-0.05\), 1.5}}, 
        AspectRatio \[Rule] 
          2.2\/0.7, \[IndentingNewLine]Ticks \[Rule] {Range[0, 1\/2, 1\/2], 
            Range[0, 2, 1\/5]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Pink}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The rectangle {(x,y): 0 < x < \!\(1\/2\), 0 < y < \
\!\(7\/5\)}\>\""];\)\ \), "\n", 
    \(\(CartesianMap[
        f, \ {0, 0.5, 0.1}, {0, 1.4, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 
              0.25}, {\(-3\), 0.25}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-3\), 0, 1], 
            Range[\(-4\), 2, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Pink}];\)\ \ \), "\n", 
    \(\(Print["\<The image under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Explore the mapping  ",
  Cell[BoxData[
      \(w = z\^4\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Find the image of the ray  ",
  Cell[BoxData[
      \(r > 0, \[Theta] = \[Alpha]\)]],
  "  and circle ",
  Cell[BoxData[
      \(r = c\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_] = z\^4;\)\), "\[IndentingNewLine]", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Iden, {0, 2, 
          0.5}, {0, \(\(\ \)\(\[Pi]\)\)\/4, \ \(\(\ \)\(\[Pi]\)\)\/24}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 2}, {0, 1.5}}, 
        AspectRatio \[Rule] 1\/2, 
        Ticks \[Rule] {Range[\(-9\), 9, 1], Range[0, 9, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Brown, Pink}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>"];\
\)\ \), "\n", 
    \(\(PolarMap[
        f\ , {0, 2, 
          0.5}, {0, \(\(\ \)\(\[Pi]\)\)\/4, \ \(\(\ \)\(\[Pi]\)\)\/24}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-16\), 16}, {0, 16}}, 
        AspectRatio \[Rule] 
          1\/2, \[IndentingNewLine]Ticks \[Rule] {Range[\(-16\), 16, 4], 
            Range[0, 16, 4]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Brown, Pink}];\)\ \), "\n", 
    \(\(Print[\*"\"\<The image rays r > 0, \[Theta] = 4\[Alpha], and circles \
r = \!\(c\^4\),\>\""];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_] = z\^4;\)\), "\[IndentingNewLine]", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Iden, {0, 2, 
          0.5}, {\(\(\ \)\(-\[Pi]\)\)\/6, \(\(\ \)\(\[Pi]\)\)\/6, \ \(\(\ \
\)\(\[Pi]\)\)\/24}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 
              2}, {\(-1.5\), 1.5}}, AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-1\), 2, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>"];\
\)\ \), "\n", 
    \(\(PolarMap[
        f\ , {0, 2, 
          0.5}, {\(\(\ \)\(-\[Pi]\)\)\/6, \(\(\ \)\(\[Pi]\)\)\/6, \ \(\(\ \
\)\(\[Pi]\)\)\/24}, \[IndentingNewLine]PlotRange \[Rule] {{\(-16\), 
              16}, {\(-16\), 16}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-16\), 16, 4], 
            Range[\(-16\), 16, 4]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\n", 
    \(\(Print[\*"\"\<The image rays r > 0, \[Theta] = 4\[Alpha], and circles \
r = \!\(c\^4\),\>\""];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, Iden, z];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^4;\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, {\(-0.6\), 0.0, 0.05}, {0, 1.1, 
          0.05}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.65\), 
              0.05}, {\(-0.05\), 1.15}}, 
        AspectRatio \[Rule] 
          2.2\/0.7, \[IndentingNewLine]Ticks \[Rule] {Range[\(-0.6\), 0.0, 
              0.6], Range[0, 1, 0.2]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Pink}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The rectangle {(x,y): -\!\(3\/5\) < x < 0, 0 < y < \
\!\(11\/10\)}\>\""];\)\ \), "\n", 
    \(\(CartesianMap[
        f, {\(-0.6\), 0.0, 0.05}, {0, 1.1, 
          0.05}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1.055\), 
              1.5}, {\(-0.2\), 2.3}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-3\), 3, 1], 
            Range[\(-4\), 2, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Pink}];\)\ \ \), "\n", 
    \(\(Print["\<The image under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Explore the mapping  ",
  Cell[BoxData[
      \(w = z\^\(1/3\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[z_] = z\^\(1/3\);\)\), "\[IndentingNewLine]", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Iden, {0, 8, 
          0.5}, {0, \(\(\ \)\(3  \[Pi]\)\)\/4, \ \(\(\ \)\(\[Pi]\)\)\/16}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-6.5\), 8.5}, {0, 9}}, 
        AspectRatio \[Rule] 9\/15, 
        Ticks \[Rule] {Range[\(-9\), 9, 1], Range[0, 8, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>"];\
\)\ \), "\n", 
    \(\(PolarMap[
        f\ , {0, 8, 
          0.5}, {0, \(\(\ \)\(3  \[Pi]\)\)\/4, \ \(\(\ \)\(\[Pi]\)\)\/16}, \
\[IndentingNewLine]PlotRange \[Rule] {{0, 2.2}, {0, 1.5}}, 
        AspectRatio \[Rule] 
          1.5\/2.2, \[IndentingNewLine]Ticks \[Rule] {Range[\(-9\), 9, 1], 
            Range[0, 8, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\n", 
    \(\(Print[\*"\"\<The image rays r > 0, \[Theta] = \!\(1\/3\)\[Alpha], and \
circles r = \!\(c\^\(1/3\)\),\>\""];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, Iden];\)\ \), "\n", 
    \(\(Iden[z_] = z;\)\ \), "\n", 
    \(\(f[z_] = z\^\(1/3\);\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {\(-9\), 9, 1}, {0, 9, 
          1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-9\), 10}, {\(-0.5\), 
              10}}, AspectRatio \[Rule] 
          1\/2, \[IndentingNewLine]Ticks \[Rule] {Range[\(-9\), 9, 3], 
            Range[0, 9, 3]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Brown, Pink}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Vertical lines x = a, and horizontal lines y = b.\>"];\)\ \
\), "\n", 
    \(\(CartesianMap[
        f, \ {\(-9\), 9, 1}, {0, 9, 
          1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.3\), 
              3.3}, {\(-0.3\), 3.3}}, AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[0, 3, 1], Range[0, 3, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Brown, Pink}];\)\ \), "\n", 
    \(\(Print["\<The image curves under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, Iden];\)\ \), "\n", 
    \(\(Iden[z_] = z;\)\ \), "\n", 
    \(\(f[z_] = z\^\(1/3\);\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {0, 8, 1}, {\(-8\), 8, 
          1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 9}, {\(-10\), 
              10}}, AspectRatio \[Rule] 
          2, \[IndentingNewLine]Ticks \[Rule] {Range[\(-8\), 8, 2], 
            Range[\(-8\), 8, 2]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Pink}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Vertical lines x = a, and horizontal lines y = b.\>"];\)\ \
\), "\n", 
    \(\(CartesianMap[
        f, \ {0, 9, 1}, {\(-9\), 9, 
          1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.3\), 
              2.3}, {\(-1.3\), 1.3}}, AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[0, 3, 1], Range[0, 3, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Pink}];\)\ \), "\n", 
    \(\(Print["\<The image curves under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_] = z\^\(1/3\);\)\), "\[IndentingNewLine]", 
    \(\(g[z_] = z + 1;\)\), "\[IndentingNewLine]", 
    \(\(h[z_] = f[g[z]];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        g, {0, 1, 
          0.1}, {\(-\ \[Pi]\), \ \[Pi], \ \(\(\ \)\(\[Pi]\)\)\/24}, \
\[IndentingNewLine]PlotRange \[Rule] {{0, 2}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[0, 2, 0.5], Range[\(-1\), 1, 1\/2]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\[IndentingNewLine]", 
    \(\(lemniscate = 
        ParametricPlot[{\(\@2\) 
              Cos[t]\/\(1 + \((Sin[t])\)\^2\), \(\@2\) \(Cos[t] Sin[t]\)\/\(1 \
+ \((Sin[t])\)\^2\)}, {t, \(-1.57\), 1.57}, 
          PlotStyle \[Rule] {Thickness[0.009], Red}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The radii, and circles.\>"];\)\ \), "\n", 
    \(\(PolarMap[
        h\ , {0, 1, 
          0.1}, {\(-\ \[Pi]\), \ \[Pi], \ \(\(\ \)\(\[Pi]\)\)\/24}, \
\[IndentingNewLine]PlotRange \[Rule] {{0, 1.42}, {\(-0.5\), 0.5}}, 
        AspectRatio \[Rule] \(\(\ \)\(1\)\)\/1.42, \[IndentingNewLine]Ticks \
\[Rule] {Range[0, 0.5, 0.5], Range[\(-1\), 1, 0.5]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The image curves under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Graphics for Complex Functions",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexGraphicsBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1012, 611},
WindowMargins->{{Automatic, 1}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 470174, 11286}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 423, 15, 33, "Text"],
Cell[2528, 79, 722, 19, 166, "Text"],
Cell[3253, 100, 1106, 32, 207, "Text"],
Cell[4362, 134, 706, 19, 185, "Text"],
Cell[5071, 155, 920, 28, 109, "Text",
  Evaluatable->False],
Cell[5994, 185, 310, 5, 52, "Text"],
Cell[6307, 192, 28791, 756, 216, "Text"],
Cell[35101, 950, 1901, 53, 183, "Text"],
Cell[37005, 1005, 787, 28, 52, "Text",
  Evaluatable->False],
Cell[37795, 1035, 1116, 41, 156, "Text",
  Evaluatable->False],
Cell[38914, 1078, 1031, 38, 133, "Text",
  Evaluatable->False],
Cell[39948, 1118, 1589, 48, 76, "Text",
  Evaluatable->False],
Cell[41540, 1168, 682, 17, 52, "Text",
  Evaluatable->False],
Cell[42225, 1187, 135954, 3764, 321, "Text"],

Cell[CellGroupData[{
Cell[178204, 4955, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[178368, 4961, 95, 2, 33, "Text"],
Cell[178466, 4965, 926, 21, 270, "Input"],
Cell[179395, 4988, 239, 10, 33, "Text",
  Evaluatable->False],
Cell[179637, 5000, 508, 10, 150, "Input"],
Cell[180148, 5012, 417, 17, 75, "Text",
  Evaluatable->False],
Cell[180568, 5031, 508, 10, 150, "Input"],
Cell[181079, 5043, 349, 13, 56, "Text",
  Evaluatable->False],
Cell[181431, 5058, 1462, 29, 359, "Input"],
Cell[182896, 5089, 1486, 29, 359, "Input"]
}, Closed]],
Cell[184397, 5121, 414, 17, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[184836, 5142, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[185003, 5148, 226, 10, 33, "Text",
  Evaluatable->False],
Cell[185232, 5160, 1420, 28, 345, "Input"],
Cell[186655, 5190, 1451, 28, 297, "Input"],
Cell[188109, 5220, 2051, 41, 431, "Input"]
}, Closed]],
Cell[190175, 5264, 2222, 64, 180, "Text"],
Cell[192400, 5330, 3143, 100, 128, "Text",
  Evaluatable->False],
Cell[195546, 5432, 28843, 758, 216, "Text"],

Cell[CellGroupData[{
Cell[224414, 6194, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[224578, 6200, 67, 0, 33, "Text"],
Cell[224648, 6202, 510, 10, 210, "Input"],
Cell[225161, 6214, 129, 5, 33, "Text"],
Cell[225293, 6221, 914, 19, 332, "Input"],
Cell[226210, 6242, 239, 10, 33, "Text",
  Evaluatable->False],
Cell[226452, 6254, 511, 11, 132, "Input"],
Cell[226966, 6267, 241, 10, 33, "Text",
  Evaluatable->False],
Cell[227210, 6279, 513, 11, 132, "Input"],
Cell[227726, 6292, 174, 7, 33, "Text",
  Evaluatable->False],
Cell[227903, 6301, 1340, 27, 327, "Input"]
}, Closed]],
Cell[229258, 6331, 1392, 31, 226, "Text"],
Cell[230653, 6364, 169526, 3150, 283, "Text"],
Cell[400182, 9516, 420, 17, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[400627, 9537, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[400794, 9543, 226, 10, 33, "Text",
  Evaluatable->False],
Cell[401023, 9555, 1372, 28, 342, "Input"],
Cell[402398, 9585, 1499, 29, 346, "Input"],
Cell[403900, 9616, 2350, 47, 518, "Input"]
}, Closed]],
Cell[406265, 9666, 1982, 52, 199, "Text"],
Cell[408250, 9720, 1221, 44, 55, "Text"],
Cell[409474, 9766, 1461, 40, 321, "Text"],
Cell[410938, 9808, 850, 30, 109, "Text",
  Evaluatable->False],
Cell[411791, 9840, 252, 4, 52, "Text"],
Cell[412046, 9846, 40062, 989, 241, "Text"],
Cell[452111, 10837, 268, 11, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[452404, 10852, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[452571, 10858, 226, 10, 33, "Text",
  Evaluatable->False],
Cell[452800, 10870, 1441, 29, 317, "Input"],
Cell[454244, 10901, 1529, 30, 331, "Input"],
Cell[455776, 10933, 226, 8, 36, "Text",
  Evaluatable->False],
Cell[456005, 10943, 1341, 27, 333, "Input"]
}, Closed]],
Cell[457361, 10973, 268, 11, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[457654, 10988, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[457821, 10994, 226, 10, 33, "Text",
  Evaluatable->False],
Cell[458050, 11006, 1412, 28, 345, "Input"],
Cell[459465, 11036, 1493, 29, 317, "Input"],
Cell[460961, 11067, 1369, 27, 320, "Input"]
}, Closed]],
Cell[462345, 11097, 274, 11, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[462644, 11112, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[462811, 11118, 1437, 28, 362, "Input"],
Cell[464251, 11148, 1255, 25, 306, "Input"],
Cell[465509, 11175, 1251, 25, 290, "Input"],
Cell[466763, 11202, 1655, 32, 401, "Input"]
}, Closed]],
Cell[468433, 11237, 290, 7, 30, "Text"],
Cell[468726, 11246, 303, 7, 33, "Text"],
Cell[469032, 11255, 257, 5, 33, "Text"],
Cell[469292, 11262, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

