(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    532099,      15463]*)
(*NotebookOutlinePosition[    532914,      15493]*)
(*  CellTagsIndexPosition[    532836,      15487]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["2.4  Branches of Functions",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
\tIn Section 2.3 we defined the principal square root function and \
investigated some of its properties.  We left unanswered some questions \
concerning the choices of square roots. We now look at these questions \
because they are similar to situations involving other elementary \
functions.\
\>", "Text"],

Cell["\<\
    In our definition of a function in Section 2.1, we specified that each \
value of the independent variable in the domain is mapped onto one and only \
one value in the range.  As a result, we often talk about a single-valued \
function, which emphasizes the \"only one\" part of the definition and allows \
us to distinguish such functions from multiple-valued functions, which we now \
introduce.\
\>", "Text"],

Cell[TextData[{
  "\tLet ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  " denote a function whose domain is the set ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " and whose range is the set ",
  StyleBox["R",
    FontFamily->"Courier New"],
  ".  If  w  is a value in the range, then there is an associated inverse \
function ",
  Cell[BoxData[
      \(z = g \((w)\)\)]],
  " that assigns to each value ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " the value (or values) of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " for which the equation ",
  Cell[BoxData[
      \(f \((z)\) = w\)]],
  " holds.  But unless ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " takes on the value  w  at most once in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", then the inverse function ",
  StyleBox["g",
    FontFamily->"Courier New"],
  " is necessarily many valued, and se say that ",
  StyleBox["g",
    FontFamily->"Courier New"],
  " is a ",
  StyleBox[ButtonBox["multivalued function",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/MultivaluedFunction.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ".  For example, the inverse of the function ",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^2\)\)]],
  " is the square root function ",
  Cell[BoxData[
      \(z = \(\(f\^\(-1\)\) \((w)\) = w\^\(1\/2\)\)\)]],
  ".  For each value z other than ",
  Cell[BoxData[
      \(z = 0\)]],
  ", then, the two points ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["-z",
    FontFamily->"Courier New"],
  " are mapped onto the same point ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "; hence ",
  StyleBox["g",
    FontFamily->"Courier New"],
  " is in general a two-valued function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe study of limits, continuity, and derivatives loses all meaning if an \
arbitrary or ambiguous assignment of function values is made.  For this \
reason we did not allow multivalued functions to be considered when we \
defined these concepts.  When working with inverse functions, you have to \
specify carefully one of the many possible inverse values when constructing \
an inverse function, as when you determine implicit functions in calculus.  \
If the values of a function f are determined by an equation that they satisfy \
rather than by an explicit formula, then we say that the function is defined \
implicitly or that",
  " ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " ",
  "is an implicit function. In the theory of complex variables we present a \
similar concept."
}], "Text"],

Cell[TextData[{
  "\tLet ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  " be a multiple-valued function.  A branch of ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is any single-valued function ",
  Cell[BoxData[
      \(f\_0\)]],
  " that is continuous in some domain (except, perhaps, on the boundary).  At \
each point ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " in the domain, assigns one of the values of ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  ".  Associated with the branch of a function is the ",
  StyleBox[ButtonBox["branch cut",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/BranchCut.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tWe now investigate the branches of the ",
  StyleBox[ButtonBox["square root",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/SquareRoot.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 2.20.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  We consider some branches of the two-valued square root function  ",
  Cell[BoxData[
      \(f \((z)\) = \ \ z\^\(1\/2\)\)]],
  ",  (where ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ").  Define the principal square root function as  \n\n",
  StyleBox["(2-28)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(w = \(\(f\_1\) \((z)\)\  = \ \(\(|\)\(z\)\( | \^\(1\/2\)\)\)\)\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\[ExponentialE]\^\(\[ImaginaryI]\ \(Arg \((z)\)\)\/2\)\  = \
\ \(r\^\(1\/2\)\) \[ExponentialE]\^\(\(\ \)\(\[ImaginaryI]  \[Theta]\/2\)\)\)\
\)\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\(r\^\(1\/2\)\) \((\ 
            cos \((\[Theta]\/2)\) + \[ImaginaryI]\ sin \((\[Theta]\/2)\)\ )\)\
\)\)\)\)]],
  ",  \n\nwhere  ",
  Cell[BoxData[
      \(r = \(\(|\)\(z\)\( | \^\(1\/2\)\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Theta] = Arg \((z)\)\)]],
  " so that  ",
  Cell[BoxData[
      \(\(-\[Pi]\) < \[Theta] \[LessEqual] \[Pi]\)]],
  ".  The function ",
  Cell[BoxData[
      \(\(f\_1\) \((z)\)\)]],
  " is a branch of ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  ".  Using the same notation, we can find other branches of the square root \
function.  For example, if we let\n\n",
  StyleBox["(2-29)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(w = \(\(f\_2\) \((z)\) = \ \(\(|\)\(z\)\( | \^\(1\/2\)\)\)\)\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\[ExponentialE]\^\(\[ImaginaryI]\ \(Arg \((z)\) + 2  \
\[Pi]\)\/2\)\  = \ \(r\^\(1\/2\)\) \[ExponentialE]\^\(\(\ \)\(\[ImaginaryI] \
\( \[Theta] + 2  \[Pi]\)\/2\)\)\)\)\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\(r\^\(1/
                2\)\) \((cos \( \[Theta] + 2  \[Pi]\)\/2 + \[ImaginaryI]\ sin \
\( \[Theta] + 2  \[Pi]\)\/2)\)\)\)\)\)]],
  ",    \n\n\tthen\n \t\t\t",
  Cell[BoxData[{
      \(\(\(\(f\_2\) \((z)\)\  = \ \(r\^\(1\/2\)\) \[ExponentialE]\^\(\(\ \
\)\(\[ImaginaryI] \( \[Theta] + 2  \[Pi]\)\/2\)\)\)\(\ \
\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(\(r\^\(1/
                2\)\) \(\[ExponentialE]\^\(\(\ \)\(\[ImaginaryI]  \[Theta]\/2\
\)\)\) \[ExponentialE]\^\(\(\ \)\(\[ImaginaryI]\ \[Pi]\)\)\)\)\(\
\[IndentingNewLine]\)
      \(\ \)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(\(-\ 
            r\^\(1/2\)\) \[ExponentialE]\^\(\(\ \)\(\[ImaginaryI]  \
\[Theta]\/2\)\)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(\(-\ 
            f\_1\) \((z)\)\)\)\)}]],
  "\n\nso ",
  Cell[BoxData[
      RowBox[{\(f\_1\), \((z)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(f\_2\), \((z)\)}]]],
  " can be thought of as \"plus\" and \"minus\" square root functions.  The \
negative real axis is called a branch cut for the functions ",
  Cell[BoxData[
      RowBox[{\(f\_1\), \((z)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(f\_2\), \((z)\)}]]],
  ".  Each point on the branch cut is a point of discontinuity for both \
functions ",
  Cell[BoxData[
      RowBox[{\(f\_1\), \((z)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(f\_2\), \((z)\)}]]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.20.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph the mapping  ",
  Cell[BoxData[
      \(w = \(\(f\_1\) \((z)\) = \(\(z\^\(1/2\)\)\(=\)\(\ \)\)\)\)]],
  Cell[BoxData[
      \(\(r\^\(1/
              2\)\) \((cos \((\[Theta]\/2)\) + \[ImaginaryI]\ sin \((\[Theta]\
\/2)\))\)\)]],
  " where ",
  Cell[BoxData[
      \(\(-\[Pi]\) < \[Theta] < \[Pi]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, Iden];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^\(1/2\);\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(zplane\  = 
        PolarMap[
          Iden, {0, 4, 0.5}, {\(-3.14\), \ 3.14, \ 
            3.14\/12}, \[IndentingNewLine]PlotRange \[Rule] {{\(-4\), 
                4.4}, {\(-4\), 4.4}}, AspectRatio \[Rule] 1, 
          Ticks \[Rule] {Range[\(-4\), 4, 2], Range[\(-4\), 4, 2]}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>"];\
\)\ \), "\n", 
    \(\(wplane\  = \ 
        PolarMap[f\ , {0, 4, 0.5}, {\(-3.14\), \ 3.14, \ 3.14\/12}, 
          PlotRange \[Rule] {{\(-0.2\), 2.2}, {\(-2.2\), 2.2}}, 
          AspectRatio \[Rule] 2, 
          Ticks \[Rule] {Range[0, 2, 1], Range[\(-2\), 2, 1]}, 
          AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The image rays r>0, \[Theta]=\!\(\[Alpha]\/2\), and \
circles r=\!\(\@c\),\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<under the mapping  w = \!\(f\_1\)(z) = \>\"", 
        f[z], "\<.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<w = \!\(f\_1\)(z) = \!\(r\^\(1/2\)\)(cos(\!\(\[Theta]\/2\
\))+\[ImaginaryI] sin(\!\(\[Theta]\/2\))) where \
-\[Pi]<\[Theta]<\[Pi]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

We can compare the above polar mapping with the cartesian coordinate mapping.\
\
\>", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {\(-4\), 4}, {\(-4\), 
          4}, \[IndentingNewLine]PlotRange \[Rule] {{\(-4\), 4.4}, {\(-4\), 
              4.4}}, AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-4\), 4, 2], 
            Range[\(-4\), 4, 2]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Vertical lines x=a, and horizontal lines y=b.\>"];\)\ \), "\n\
", 
    \(\(CartesianMap[
        f, \ {\(-4\), 4}, {\(-4\), 
          4}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.2\), 
              2.2}, {\(-2.2\), 2.2}}, AspectRatio \[Rule] 2, 
        Ticks \[Rule] {Range[0, 2, 1], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\n", 
    \(\(Print[\*"\"\<The image hyperbolas \!\(u\^2\)-\!\(v\^2\) = a and 2uv = \
b,\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<under the mapping  w = \!\(f\_1\)(z) = \>\"", 
        f[z], "\<.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<w = \!\(f\_1\)(z) = \!\(r\^\(1/2\)\)(cos(\!\(\[Theta]\/2\
\))+\[ImaginaryI] sin(\!\(\[Theta]\/2\))) where \
-\[Pi]<\[Theta]<\[Pi]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph the mapping  ",
  Cell[BoxData[
      RowBox[{"w", "=", 
        RowBox[{\(\(f\_2\) \((z)\)\), "=", 
          RowBox[{\(-\ z\^\(1/2\)\), "=", 
            RowBox[{
              RowBox[{
                
                RowBox[{\(r\^\(1/
                        2\)\), \((cos \((\(\[Theta] + 2  \[Pi]\)\/2)\) + \
\[ImaginaryI]\ sin \((\(\[Theta] + 2  \[Pi]\)\/2)\))\), "  ", 
                  StyleBox["where",
                    FontFamily->"Times New Roman"]}], "  ", "-", "\[Pi]"}], 
              "<", "\[Theta]", "<", "\[Pi]", " "}]}]}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, Iden];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_] = \(-\ z\^\(1/2\)\);\)\ \), "\n", 
    \(\(zplane\  = \ 
        PolarMap[
          Iden, {0, 4, 0.5}, {\(-3.14\), \ 3.14, \ 
            3.14\/12}, \[IndentingNewLine]PlotRange \[Rule] {{\(-4\), 
                4.4}, {\(-4\), 4.4}}, AspectRatio \[Rule] 1, 
          Ticks \[Rule] {Range[\(-4\), 4, 2], Range[\(-4\), 4, 2]}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Red, Blue}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The rays r>0, \[Theta]=\[Alpha], and circles r=c.\>"];\)\ \
\), "\n", 
    \(\(wplane\  = \ 
        PolarMap[f\ , {0, 4, 0.5}, {\(-3.14\), \ 3.14, \ 3.14\/12}, 
          PlotRange \[Rule] {{\(-2.2\), 0.2}, {\(-2.2\), 2.2}}, 
          AspectRatio \[Rule] 2, 
          Ticks \[Rule] {Range[\(-2\), 0, 1], Range[\(-2\), 2, 1]}, 
          AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Red, Blue}];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<The image rays r>0, \[Theta] = \!\(\(\[Alpha] + 4  \[Pi]\
\)\/2\), and circles r=\!\(\@c\),\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<under the mapping  w = \!\(f\_2\)(z) = \>\"", 
        f[z], "\<.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<w = \!\(f\_2\)(z) = \!\(r\^\(1/2\)\)(cos(\!\(\(\[Theta] \
+ 4  \[Pi]\)\/2\))+\[ImaginaryI] sin(\!\(\(\[Theta] + 4  \[Pi]\)\/2\))) where \
-\[Pi] < \[Theta] < \[Pi]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

We can compare the above polar mapping with the cartesian coordinate mapping.\
\
\>", "Text"],

Cell[BoxData[{
    \(\(CartesianMap[
        Iden, \ {\(-4\), 4}, {\(-4\), 
          4}, \[IndentingNewLine]PlotRange \[Rule] {{\(-4\), 4.4}, {\(-4\), 
              4.4}}, AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-4\), 4, 2], 
            Range[\(-4\), 4, 2]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Vertical lines x=a, and horizontal lines y=b.\>"];\)\ \), "\n\
", 
    \(\(CartesianMap[
        f, \ {\(-4\), 4}, {\(-4\), 
          4}, \[IndentingNewLine]PlotRange \[Rule] {{\(-2.2\), 
              0.2}, {\(-2.2\), 2.2}}, AspectRatio \[Rule] 2, 
        Ticks \[Rule] {Range[0, 2, 1], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\n", 
    \(\(Print[\*"\"\<The image hyperbolas \!\(u\^2\)-\!\(v\^2\) = a and 2uv = \
b,\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<under the mapping  w = \!\(f\_2\)(z) = \>\"", 
        f[z], "\<.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<w = \!\(f\_2\)(z) = \!\(r\^\(1/2\)\)(cos(\!\(\(\[Theta] \
+ 4  \[Pi]\)\/2\))+\[ImaginaryI] sin(\!\(\(\[Theta] + 4  \[Pi]\)\/2\))) where \
-\[Pi]<\[Theta]<\[Pi]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe have illustrated the two branches of the square root  ",
  Cell[BoxData[
      RowBox[{"w", "=", 
        RowBox[{\(\(f\_1\) \((z)\)\), "=", "  ", 
          RowBox[{
            RowBox[{\(z\^\(1/2\)\), "   ", 
              StyleBox["and",
                FontFamily->"Times New Roman"], "  ", "w"}], 
            "=", \(\(f\_2\) \((z)\) = \(-\ z\^\(1/2\)\)\)}]}]}]]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.21.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the function  ",
  Cell[BoxData[
      \(\(f\_1\) \((z)\) = \ \(r\^\(1\/2\)\) \((cos  \[Theta]\/2 + \
\[ImaginaryI]\ sin  \[Theta]\/2)\)\)]],
  "  is discontinuous along the negative real axis.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  Let  ",
  Cell[BoxData[
      \(z\_0\  = \ \(r\_0\) \[ExponentialE]\^\(\(\ \)\(\[ImaginaryI]\ \[Pi]\)\
\)\)]],
  "  denote a negative real number.  We compute the limit as ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " approaches ",
  Cell[BoxData[
      \(z\_0\)]],
  " through the upper half-plane ",
  Cell[BoxData[
      \({z : Im \((z)\) > 0}\)]],
  " and the limit as ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " approaches ",
  Cell[BoxData[
      \(z\_0\)]],
  " through the lower half-plane ",
  Cell[BoxData[
      \({z : Im \((z)\) < 0}\)]],
  " .  In polar coordinates these limits are given by    \n\n\t\t\t",
  Cell[BoxData[
      \(lim\_\(\((r, \[Theta])\) \[Rule] \((r\_0, \[Pi])\)\)\ \(f\_1\) \((r\ \
\[ExponentialE]\^\(\(\ \)\(\[ImaginaryI]\ \[Theta]\)\))\)\  = \ \
\(lim\_\(\((r, \[Theta])\) \[Rule] \((r\_0, \[Pi])\)\)\ \(r\^\(1\/2\)\) \
\((cos  \[Theta]\/2 + \[ImaginaryI]\ sin  \[Theta]\/2)\)\  = \ \[ImaginaryI]\ \
r\_0\%\(1/2\)\)\)]],
  ",  and  \n\n\t\t\t",
  Cell[BoxData[
      \(lim\_\(\((r, \[Theta])\) \[Rule] \((r\_0, \(-\[Pi]\))\)\)\(f\_1\) \
\((r\ \[ExponentialE]\^\(\(\ \)\(\[ImaginaryI]\ \[Theta]\)\))\)\  = \ \(lim\_\
\(\((r, \[Theta])\) \[Rule] \((r\_0, \(-\[Pi]\))\)\)\(r\^\(1\/2\)\) \((cos  \
\[Theta]\/2 + \[ImaginaryI]\ sin  \[Theta]\/2)\)\  = \ \(-\ \[ImaginaryI]\)\ \
r\_0\%\(1/2\)\)\)]],
  ".  \n\nAs the two limits are distinct, the function ",
  Cell[BoxData[
      \(\(f\_1\) \((z)\)\)]],
  " is discontinuous at ",
  Cell[BoxData[
      \(z\_0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 2.4",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Likewise,  ",
  Cell[BoxData[
      \(\(f\_1\) \((z)\)\)]],
  " is discontinuous at ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  The mappings  ",
  Cell[BoxData[
      \(w = \(f\_1\) \((z)\)\)]],
  ",  ",
  Cell[BoxData[
      \(w = \(f\_2\) \((z)\)\)]],
  ",  and the branch cut are illustrated in Figure 2.18."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(w = \(f[r, \[Theta]] = \(\(z\^\(1/2\)\)\(=\)\(\ \)\)\)\)]],
  Cell[BoxData[
      \(\(r\^\(1/
              2\)\) \((cos \((\[Theta]\/2)\) + \[ImaginaryI]\ sin \((\[Theta]\
\/2)\))\)\)]],
  "  and find the limits as z approaches a point on the negative x-axis."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, r, \[Theta]];\)\ \), "\n", 
    \(\(f[
          r_, \[Theta]_]\  = \ \(r\^\(1/
                2\)\) \((Cos[\[Theta]\/2] + \[ImaginaryI]\ \
Sin[\[Theta]\/2])\);\)\ \), "\n", 
    \(\(lim1\  = 
        PowerExpand[
          Limit[f[r, \[Theta]], \[Theta] \[Rule] \[Pi]]];\)\ \), "\n", 
    \(\(lim2\  = 
        PowerExpand[
          Limit[f[r, \[Theta]], \[Theta] \[Rule] \(-\[Pi]\)]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Let z approach the point z = r \!\(\[ExponentialE]\^\
\[ImaginaryI]\[Pi]\) on negative x-axis.\>\""];\)\ \), "\[IndentingNewLine]", \

    \(\(Print[\*"\"\<  z = r \!\(\[ExponentialE]\^\[ImaginaryI]\[Pi]\)\>\""];\
\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[r, \[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Approach from the upper half-plane\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(\[Theta] \[Rule] \[Pi]\)\)   r \!\(\
\[ExponentialE]\^\[ImaginaryI]\[Pi]\)  = \>\"", 
        r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(\[Theta] \[Rule] \[Pi]\)\) f[r \!\(\
\[ExponentialE]\^\[ImaginaryI]\[Pi]\)] = \>\"", 
        lim1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Approach from the lower half-plane\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(\[Theta] \[Rule] \(-\[Pi]\)\)\)   r \!\(\
\[ExponentialE]\^\[ImaginaryI]\[Pi]\)  = \>\"", 
        r\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]\)];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(\[Theta] \[Rule] \(-\[Pi]\)\)\) f[r \!\(\
\[ExponentialE]\^\[ImaginaryI]\[Pi]\)] = \>\"", 
        lim2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Since the two limits are different,  ",
  Cell[BoxData[
      \(\(f\_1\) \((z)\) = \(\(z\^\(1/2\)\)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \(\(r\^\(1/
              2\)\) \((cos \((\[Theta]\/2)\) + \[ImaginaryI]\ sin \((\[Theta]\
\/2)\))\)\)]],
  "  is discontinuous at all points  ",
  Cell[BoxData[
      \(z = \(-r\) + 0  \[ImaginaryI], \ \ r > 0\)]],
  "  along the negative real axis."
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.941 1 .941 r
0 .5 m
0 0 L
1 0 L
1 1 L
0 1 L
0 .5 L
F
1 1 1 r
0 .5 m
0 .49 L
.5 .49 L
.5 .51 L
0 .51 L
0 .5 L
F
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.25 .5 m
.25 .49957 L
.24999 .49917 L
.24998 .49872 L
.24997 .49829 L
.24995 .4979 L
.24992 .49753 L
.24985 .4967 L
.24976 .49586 L
.24962 .49494 L
.24925 .49308 L
.24875 .49125 L
.24806 .48928 L
.24644 .4857 L
.2411 .4773 L
.23499 .46939 L
.22881 .4611 L
.2263 .45704 L
.22453 .45336 L
.22386 .45152 L
.22358 .45055 L
.22333 .44954 L
.22317 .44865 L
.2231 .44818 L
.22304 .44768 L
.223 .44722 L
.22297 .4468 L
.22296 .44638 L
.22296 .44599 L
.22297 .44554 L
.22299 .44506 L
.22304 .44455 L
.2231 .44408 L
.22325 .44323 L
.22347 .44233 L
.22379 .44134 L
.22421 .44031 L
.22519 .43849 L
.22649 .43667 L
.22795 .43506 L
.23217 .43159 L
.23723 .42858 L
.24298 .42593 L
.25022 .42327 L
.25884 .42073 L
.27606 .41682 L
.31277 .41083 L
.32209 .40932 L
.32996 .40781 L
.33603 .40633 L
Mistroke
.33902 .4054 L
.3414 .40448 L
.34355 .40344 L
.34522 .40237 L
.34661 .40114 L
.3472 .40039 L
.34764 .39967 L
.34778 .39936 L
.34792 .39902 L
.34802 .39872 L
.3481 .39839 L
.34818 .398 L
.34822 .39761 L
.34824 .39723 L
.34823 .39687 L
.3482 .39648 L
.34815 .39612 L
.34808 .3957 L
.34796 .39525 L
.34764 .3943 L
.34723 .39338 L
.34608 .39144 L
.34437 .38919 L
.33998 .38467 L
.32354 .37206 L
.26391 .33707 L
.18407 .2952 L
.14853 .27591 L
.13101 .26559 L
.11732 .25663 L
.10629 .248 L
.10282 .2446 L
.10006 .24117 L
.09902 .23943 L
.09867 .2387 L
.09836 .23791 L
.09815 .23719 L
.09801 .23653 L
.09794 .23585 L
.09794 .23515 L
.09803 .23448 L
.09812 .2341 L
.09823 .23376 L
.09852 .2331 L
.09894 .23243 L
.09944 .23183 L
.1 .23129 L
.10129 .23036 L
.10282 .22956 L
.10451 .22889 L
Mistroke
.10666 .22825 L
.10931 .22768 L
.11076 .22744 L
.11244 .22721 L
.11401 .22703 L
.11577 .22688 L
.1176 .22675 L
.11934 .22667 L
.12115 .22661 L
.12292 .22658 L
.12463 .22657 L
.12657 .22659 L
.12867 .22663 L
.13068 .22669 L
.13262 .22677 L
.13444 .22686 L
.13867 .22712 L
.1489 .22803 L
.15948 .22928 L
.18391 .2331 L
.21286 .23888 L
.26966 .25334 L
.38438 .29425 L
.43223 .3169 L
.47132 .33851 L
.49599 .35309 L
.50452 .35752 L
.50642 .3583 L
.50727 .3586 L
.50799 .35882 L
.5086 .35898 L
.50922 .35911 L
.50953 .35915 L
.5098 .35918 L
.51007 .3592 L
.51036 .35921 L
.5106 .3592 L
.51085 .35918 L
.51125 .35911 L
.51148 .35904 L
.51168 .35896 L
.51185 .35887 L
.51202 .35876 L
.51229 .35852 L
.51241 .35838 L
.51253 .35821 L
.51271 .35787 L
.51283 .3575 L
.51291 .35707 L
.51295 .35661 L
Mistroke
.51294 .35616 L
.5129 .35563 L
.51282 .355 L
.51275 .35466 L
.51267 .35428 L
.51228 .35283 L
.51099 .34946 L
.50883 .345 L
.5027 .33473 L
.4764 .30068 L
.43245 .2556 L
.29253 .14522 L
.09456 .01981 L
Mfstroke
.09456 .01981 m
.06318 0 L
s
1 0 0 r
.25 .5 m
.25 .50043 L
.24999 .50083 L
.24998 .50128 L
.24997 .50171 L
.24995 .5021 L
.24992 .50247 L
.24985 .5033 L
.24976 .50414 L
.24962 .50506 L
.24925 .50692 L
.24875 .50875 L
.24806 .51072 L
.24644 .5143 L
.2411 .5227 L
.23499 .53061 L
.22881 .5389 L
.2263 .54296 L
.22453 .54664 L
.22386 .54848 L
.22358 .54945 L
.22333 .55046 L
.22317 .55135 L
.2231 .55182 L
.22304 .55232 L
.223 .55278 L
.22297 .5532 L
.22296 .55362 L
.22296 .55401 L
.22297 .55446 L
.22299 .55494 L
.22304 .55545 L
.2231 .55592 L
.22325 .55677 L
.22347 .55767 L
.22379 .55866 L
.22421 .55969 L
.22519 .56151 L
.22649 .56333 L
.22795 .56494 L
.23217 .56841 L
.23723 .57142 L
.24298 .57407 L
.25022 .57673 L
.25884 .57927 L
.27606 .58318 L
.31277 .58917 L
.32209 .59068 L
.32996 .59219 L
.33603 .59367 L
Mistroke
.33902 .5946 L
.3414 .59552 L
.34355 .59656 L
.34522 .59763 L
.34661 .59886 L
.3472 .59961 L
.34764 .60033 L
.34778 .60064 L
.34792 .60098 L
.34802 .60128 L
.3481 .60161 L
.34818 .602 L
.34822 .60239 L
.34824 .60277 L
.34823 .60313 L
.3482 .60352 L
.34815 .60388 L
.34808 .6043 L
.34796 .60475 L
.34764 .6057 L
.34723 .60662 L
.34608 .60856 L
.34437 .61081 L
.33998 .61533 L
.32354 .62794 L
.26391 .66293 L
.18407 .7048 L
.14853 .72409 L
.13101 .73441 L
.11732 .74337 L
.10629 .752 L
.10282 .7554 L
.10006 .75883 L
.09902 .76057 L
.09867 .7613 L
.09836 .76209 L
.09815 .76281 L
.09801 .76347 L
.09794 .76415 L
.09794 .76485 L
.09803 .76552 L
.09812 .7659 L
.09823 .76624 L
.09852 .7669 L
.09894 .76757 L
.09944 .76817 L
.1 .76871 L
.10129 .76964 L
.10282 .77044 L
.10451 .77111 L
Mistroke
.10666 .77175 L
.10931 .77232 L
.11076 .77256 L
.11244 .77279 L
.11401 .77297 L
.11577 .77312 L
.1176 .77325 L
.11934 .77333 L
.12115 .77339 L
.12292 .77342 L
.12463 .77343 L
.12657 .77341 L
.12867 .77337 L
.13068 .77331 L
.13262 .77323 L
.13444 .77314 L
.13867 .77288 L
.1489 .77197 L
.15948 .77072 L
.18391 .7669 L
.21286 .76112 L
.26966 .74666 L
.38438 .70575 L
.43223 .6831 L
.47132 .66149 L
.49599 .64691 L
.50452 .64248 L
.50642 .6417 L
.50727 .6414 L
.50799 .64118 L
.5086 .64102 L
.50922 .64089 L
.50953 .64085 L
.5098 .64082 L
.51007 .6408 L
.51036 .64079 L
.5106 .6408 L
.51085 .64082 L
.51125 .64089 L
.51148 .64096 L
.51168 .64104 L
.51185 .64113 L
.51202 .64124 L
.51229 .64148 L
.51241 .64162 L
.51253 .64179 L
.51271 .64213 L
.51283 .6425 L
.51291 .64293 L
.51295 .64339 L
Mistroke
.51294 .64384 L
.5129 .64437 L
.51282 .645 L
.51275 .64534 L
.51267 .64572 L
.51228 .64717 L
.51099 .65054 L
.50883 .655 L
.5027 .66527 L
.4764 .69932 L
.43245 .7444 L
.29253 .85478 L
.09456 .98019 L
Mfstroke
.09456 .98019 m
.06318 1 L
s
0 g
.5 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
0 .51 m
.5 .51 L
s
[ .02 .02 ] 0 setdash
0 .49 m
.5 .49 L
s
0 1 0 r
.03 w
.25 .5 Mdot
0 g
gsave
.98 .525 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5375 .98 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.28 .525 -70.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{199, 199},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000370000ab000`400?l00000o`00003o303oool0
0`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo0640oooo000=0?3ol080003oE03`oo000`00
0000l?o`0?3ol01P0?3ol040oooo000?0?3ol0030000o`3`oo00l?o`0540l?o`00<000000?3ol03`
oo00H03`oo010?ooo`00403`oo020000oe40l?o`00<000000?3ol03`oo00H03`oo010?ooo`004P3`
oo000`000?l0l?o`0?3ol01>0?3ol0030000003`oo00l?o`0600l?o`0@3oool001<0l?o`0P000?m>
0?3ol0030000003`oo00l?o`0600l?o`0@3oool001D0l?o`00<0003o0?3ol03`oo00B`3`oo000`00
0000l?o`0?3ol01P0?3ol040oooo000F0?3ol080003oB`3`oo000`000000l?o`0?3ol01P0?3ol040
oooo000H0?3ol080003oB@3`oo000`000000l?o`0?3ol01P0?3ol040oooo000J0?3ol0030000o`3`
oo00l?o`04H0l?o`00<000000?3ol03`oo00H03`oo010?ooo`006`3`oo020000odH0l?o`00<00000
0?3ol03`oo00H03`oo010?ooo`007@3`oo000`000?l0l?o`0?3ol0130?3ol0030000003`oo00l?o`
0600l?o`0@3oool001h0l?o`0P000?m30?3ol0030000003`oo00l?o`0600l?o`0@3oool00200l?o`
00<0003o0?3ol03`oo00@03`oo000`000000l?o`0?3ol01P0?3ol040oooo000Q0?3ol080003o@03`
oo000`000000l?o`0?3ol01P0?3ol040oooo000S0?3ol0030000o`3`oo00l?o`03d0l?o`00<00000
0?3ol03`oo00H03`oo010?ooo`00903`oo020000ocd0l?o`00<000000?3ol03`oo00H03`oo010?oo
o`009P3`oo020000oc/0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00:03`oo000`000?l0l?o`
0?3ol00h0?3ol0030000003`oo00l?o`0600l?o`0@3oool002T0l?o`0P000?lh0?3ol0030000003`
oo00l?o`0600l?o`0@3oool002/0l?o`00<0003o0?3ol03`oo00=@3`oo000`000000l?o`0?3ol01P
0?3ol040oooo000/0?3ol080003o=@3`oo000`000000l?o`0?3ol01P0?3ol040oooo000^0?3ol003
0000o`3`oo00l?o`0380l?o`00<000000?3ol03`oo00H03`oo010?ooo`00;`3`oo020000oc80l?o`
00<000000?3ol03`oo00H03`oo010?ooo`00<@3`oo000`000?l0l?o`0?3ol00_0?3ol0030000003`
oo00l?o`0600l?o`0@3oool00380l?o`0P000?l_0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
03@0l?o`0P000?l]0?3ol0030000003`oo00l?o`0600l?o`0@3oool003H0l?o`00<0003o0?3ol03`
oo00:P3`oo000`000000l?o`0?3ol01P0?3ol040oooo000g0?3ol080003o:P3`oo000`000000l?o`
0?3ol01P0?3ol040oooo000i0?3ol0030000o`3`oo00l?o`02L0l?o`00<000000?3ol03`oo00H03`
oo010?ooo`00>P3`oo000`000?l0l?o`0?3ol00V0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
03/0l?o`0P000?lV0?3ol0030000003`oo00l?o`0600l?o`0@3oool003d0l?o`00<0003o0?3ol03`
oo008`3`oo000`000000l?o`0?3ol01P0?3ol040oooo000n0?3ol0030000o`3`oo00l?o`0280l?o`
00<000000?3ol03`oo00H03`oo010?ooo`00?`3`oo000`000?l0l?o`0?3ol00Q0?3ol0030000003`
oo00l?o`0600l?o`0@3oool00400l?o`0P000?lQ0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
0480l?o`00<0003o0?3ol03`oo007P3`oo000`000000l?o`0?3ol01P0?3ol040oooo00130?3ol003
0000o`3`oo00l?o`01d0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00A03`oo020000oad0l?o`
00<000000?3ol03`oo00H03`oo010?ooo`00AP3`oo000`000?l0l?o`0?3ol00J0?3ol0030000003`
oo00l?o`0600l?o`0@3oool004L0l?o`00<0003o0?3ol03`oo006@3`oo000`000000l?o`0?3ol01P
0?3ol040oooo00180?3ol0030000o`3`oo00l?o`01P0l?o`00<000000?3ol03`oo00H03`oo010?oo
o`00B@3`oo020000oaP0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00B`3`oo000`000?l0l?o`
0?3ol00E0?3ol0030000003`oo00l?o`0600l?o`0@3oool004`0l?o`00<0003o0?3ol03`oo00503`
oo000`000000l?o`0?3ol01P0?3ol040oooo000F0?3ol0H0003o<@3`oo000`000?l0l?o`0?3ol00C
0?3ol0030000003`oo00l?o`0600l?o`0@3oool001<0l?o`0`000?l60?3ol0H0003o;03`oo020000
oa<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`004`3`oo000`000?l0l?o`0?3ol00<0?3ol0D0
003o:@3`oo000`000?l0l?o`0?3ol00@0?3ol0030000003`oo00l?o`0600l?o`0@3oool001<0l?o`
00<0003o0?3ol03`oo004@3`oo050000obD0l?o`00<0003o0?3ol03`oo003`3`oo000`000000l?o`
0?3ol01P0?3ol040oooo000D0?3ol0030000o`3`oo00l?o`01D0l?o`10000?lR0?3ol080003o3`3`
oo000`000000l?o`0?3ol01P0?3ol040oooo000E0?3ol0030000o`3`oo00l?o`01P0l?o`10000?lP
0?3ol0030000o`3`oo00l?o`00`0l?o`00<000000?3ol03`oo00H03`oo010?ooo`005P3`oo020000
oa`0l?o`0`000?lN0?3ol0030000o`3`oo00l?o`00/0l?o`00<000000?3ol03`oo00H03`oo010?oo
o`00603`oo000`000?l0l?o`0?3ol00L0?3ol0<0003o703`oo000`000?l0l?o`0?3ol00:0?3ol003
0000003`oo00l?o`0600l?o`0@3oool001T0l?o`00<0003o0?3ol03`oo007P3`oo030000oaX0l?o`
00<0003o0?3ol03`oo002@3`oo000`000000l?o`0?3ol01P0?3ol040oooo000J0?3ol080003o8@3`
oo030000oaP0l?o`00<0003o0?3ol03`oo00203`oo000`000000l?o`0?3ol01P0?3ol040oooo000L
0?3ol080003o8P3`oo020000oaL0l?o`00<0003o0?3ol03`oo001`3`oo000`000000l?o`0?3ol01P
0?3ol040oooo000N0?3ol080003o8P3`oo030000oaD0l?o`00<0003o0?3ol03`oo001P3`oo000`00
0000l?o`0?3ol01P0?3ol040oooo000P0?3ol080003o8`3`oo030000oa<0l?o`00<0003o0?3ol03`
oo001@3`oo000`000000l?o`0?3ol01P0?3ol040oooo000R0?3ol080003o903`oo030000oa40l?o`
00<0003o0?3ol03`oo00103`oo000`000000l?o`0?3ol01P0?3ol040oooo000T0?3ol0030000o`3`
oo00l?o`02@0l?o`0`000?l?0?3ol0030000o`3`oo00l?o`00<0l?o`00<000000?3ol03`oo00H03`
oo010?ooo`009@3`oo020000obL0l?o`0P000?l>0?3ol0030000o`3`oo00l?o`0080l?o`00<00000
0?3ol03`oo00H03`oo010?ooo`009`3`oo020000obL0l?o`0P000?l=0?3ol0050000o`3`oo00l?o`
0?3ol0000000HP3`oo010?ooo`00:@3`oo020000obL0l?o`0P000?l;0?3ol0050000o`3`oo00l?o`
0?3ol0000000HP3`oo010?ooo`00:`3`oo020000obL0l?o`0P000?l:0?3ol0040000o`3`oo00l?o`
00000680l?o`0@3oool002d0l?o`0P000?lW0?3ol080003o2@3`oo000`000?l0l?o`0000001R0?3o
l040oooo000_0?3ol080003o9`3`oo000`000?l0l?o`0?3ol0070?3ol0030000o`000000l?o`0640
l?o`0@3oool00340l?o`0P000?lV0?3ol080003o1`3`oo000`000?l000000?3ol01Q0?3ol040oooo
000c0?3ol080003o9P3`oo020000o`H0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00=@3`oo02
0000obH0l?o`0P000?l40?3ol0030000003`oo00l?o`0600l?o`0@3oool003L0l?o`0P000?lV0?3o
l080003o0P3`oo000`000000003o0?3ol01P0?3ol040oooo000i0?3ol0030000o`3`oo00l?o`02D0
l?o`0P000?l00`000000l?o`0000o`1P0?3ol040oooo000j0?3ol080003o9`3`oo000`000000003o
0000o`1P0?3ol040oooo000l0?3ol080003o9@3`oo000`000000003o0000o`1P0?3ol040oooo000n
0?3ol080003o8`3`oo000`000000l?o`0?3ol01P0?3ol040oooo00100?3ol0030000o`3`oo00l?o`
0200l?o`00<000000?3ol03`oo00H03`oo010?ooo`00@@3`oo000`000?l0l?o`0?3ol00O0?3ol003
0000003`oo00l?o`0600l?o`0@3oool00480l?o`00<0003o0?3ol03`oo007P3`oo000`000000l?o`
0?3ol01P0?3ol040oooo00130?3ol0030000o`3`oo00l?o`01d0l?o`00<000000?3ol03`oo00H03`
oo010?ooo`00A03`oo000`000?l0l?o`0?3ol00L0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
04@0l?o`00<0003o0?3ol03`oo00703`oo000`000000l?o`0?3ol01P0?3ol040oooo00140?3ol003
0000o`3`oo00l?o`01`0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00@@3`oo030000oal0l?o`
00<000000?3ol03`oo00H03`oo010?ooo`00>P3`oo070000ob80l?o`00<000000?3ol03`oo00H03`
oo010?ooo`00=@3`oo050000obT0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00<@3`oo040000
obh0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00;P3`oo030000oc80l?o`00<000000?3ol03`
oo00H03`oo010?ooo`00;@3`oo000`000?l0l?o`0?3ol00c0?3ol0030000003`oo00l?o`0600l?o`
0@3oool002`0l?o`0P000?le0?3ol0030000003`oo00l?o`0600l?o`0@3oool002`0l?o`00<0003o
0?3ol03`oo00=03`oo000`000000l?o`0?3ol01P0?3ol040oooo000/0?3ol0030000o`3`oo00l?o`
03@0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00;03`oo000`000?l0l?o`0?3ol00d0?3ol003
0000003`oo00l?o`0600l?o`0@3oool002`0l?o`00<0003o0?3ol03`oo00=03`oo000`000000l?o`
0?3ol01P0?3ol040oooo000]0?3ol0030000o`3`oo00l?o`03<0l?o`00<000000?3ol03`oo00H03`
oo010?ooo`00;P3`oo000`000?l0l?o`0?3ol00b0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
02h0l?o`00<0003o0?3ol03`oo00<P3`oo000`000000l?o`0?3ol01P0?3ol040oooo000_0?3ol003
0000o`3`oo00l?o`0340l?o`00<000000?3ol03`oo00H03`oo010?ooo`00;`3`oo000`000?l0l?o`
0?3ol00a0?3ol0030000003`oo00l?o`0600l?o`0@3oool00300l?o`0P000?la0?3ol0030000003`
oo00l?o`0600l?o`0@3oool000@000000`3`oo05000000<0l?o`1@0000030?3ol0D000000`3`oo05
000000<0l?o`1@0000030?3ol00500000000o`000?l0003o000000000`3`oo05000000<0l?o`1@00
00030?3ol0D000000`3`oo05000000<0l?o`1@0000030?3ol0D00000HP3`oo010?ooo`00;`3oool5
003o02l0ooooI000000002l0oooo1@00o`0_0?ooo`030000003`oo00l?o`0600l?o`0@3oool002l0
00001@00o`0`00000680l?o`0@3oool00300l?o`0`00o`0`0?3ol0030000003`oo00l?o`0600l?o`
0@3oool002l0l?o`00<0o`000?3ol03`oo001P3`oo05000002H0l?o`00<000000?3ol03`oo00F03`
oo0200000080l?o`0P0000020?3ol040oooo000_0?3ol0030?l0003`oo00l?o`00P0l?o`00<00000
0?3ol03`oo009P3`oo000`000000l?o`0?3ol01I0?3ol0040000003`oo00l?o`000000<0l?o`0@3o
ool002h0l?o`00<0o`000?3ol03`oo001@0000040?3ol0030000003`oo00l?o`02H0l?o`00<00000
0?3ol03`oo00FP3`oo02000000@0l?o`0@3oool002h0l?o`00<0o`000?3ol03`oo002@3`oo000`00
0000l?o`0?3ol00V0?3ol0030000003`oo00l?o`05X0l?o`0P0000040?3ol040oooo000]0?3ol003
0?l0003`oo00l?o`00X0l?o`00<000000?3ol03`oo009P3`oo000`000000l?o`0?3ol01I0?3ol004
0000003`oo00l?o`000000<0l?o`0@3oool002`0l?o`00<0o`000?3ol03`oo002`3`oo000`000000
l?o`0?3ol00V0?3ol0030000003`oo00l?o`05P0l?o`0P0000020?3ol08000000P3`oo010?ooo`00
;03`oo000`3o0000l?o`0?3ol00;0?3ol0030000003`oo00l?o`02H0l?o`00<000000?3ol03`oo00
H03`oo010?ooo`00;03`oo000`3o0000l?o`0?3ol00:0?3ol0800000:03`oo000`000000l?o`0?3o
l01P0?3ol040oooo000/0?3ol0030?l0003`oo00l?o`03@0l?o`00<000000?3ol03`oo00H03`oo01
0?ooo`00;03`oo020?l003D0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00;@3`oo000`3o0000
l?o`0?3ol00c0?3ol0030000003`oo00l?o`0600l?o`0@3oool002h0l?o`0`3o000b0?3ol0030000
003`oo00l?o`0600l?o`0@3oool00340l?o`103o000^0?3ol0030000003`oo00l?o`0600l?o`0@3o
ool003D0l?o`1@3o000Y0?3ol0030000003`oo00l?o`0600l?o`0@3oool003X0l?o`1P3o000S0?3o
l0030000003`oo00l?o`0600l?o`0@3oool00400l?o`103o000O0?3ol0030000003`oo00l?o`0600
l?o`0@3oool004@0l?o`00<0o`000?3ol03`oo00703`oo000`000000l?o`0?3ol01P0?3ol040oooo
00140?3ol0030?l0003`oo00l?o`01`0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00A03`oo00
0`3o0000l?o`0?3ol00L0?3ol0030000003`oo00l?o`0600l?o`0@3oool004<0l?o`00<0o`000?3o
l03`oo007@3`oo000`000000l?o`0?3ol01P0?3ol040oooo00120?3ol0030?l0003`oo00l?o`01h0
l?o`00<000000?3ol03`oo00H03`oo010?ooo`00@@3`oo000`3o0000l?o`0?3ol00O0?3ol0030000
003`oo00l?o`0600l?o`0@3oool00400l?o`00<0o`000?3ol03`oo00803`oo000`000000l?o`0?3o
l01P0?3ol040oooo000n0?3ol080o`008`3`oo000`000000l?o`0?3ol01P0?3ol040oooo000l0?3o
l080o`009@3`oo000`000000o`000?l0001P0?3ol040oooo000k0?3ol0030?l0003`oo00l?o`02D0
l?o`00<000000?l0003o0000H03`oo010?ooo`00>@3`oo020?l002H0l?o`0P3o00000`000000l?o`
0?l0001P0?3ol040oooo000g0?3ol080o`009P3`oo020?l00080l?o`00<000000?l0003`oo00H03`
oo010?ooo`00=@3`oo020?l002H0l?o`0P3o00040?3ol0030000003`oo00l?o`0600l?o`0@3oool0
03@0l?o`00<0o`000?3ol03`oo00903`oo020?l000H0l?o`00<000000?3ol03`oo00H03`oo010?oo
o`00<P3`oo020?l002H0l?o`00<0o`000?3ol03`oo001@3`oo000`3o000000000?3ol01Q0?3ol040
oooo000`0?3ol080o`009P3`oo020?l000P0l?o`00<0o`000000003`oo00H@3`oo010?ooo`00;P3`
oo020?l002H0l?o`0P3o00090?3ol0030?l0003`oo0000000680l?o`0@3oool002`0l?o`0P3o000V
0?3ol080o`002P3`oo00103o0000l?o`0?3ol000001R0?3ol040oooo000Z0?3ol080o`009P3`oo02
0?l000/0l?o`00D0o`000?3ol03`oo00l?o`0000001R0?3ol040oooo000X0?3ol080o`009P3`oo02
0?l000d0l?o`00D0o`000?3ol03`oo00l?o`0000001R0?3ol040oooo000V0?3ol080o`009P3`oo02
0?l000h0l?o`00<0o`000?3ol03`oo000P3`oo000`000000l?o`0?3ol01P0?3ol040oooo000T0?3o
l080o`009@3`oo030?l000l0l?o`00<0o`000?3ol03`oo000`3`oo000`000000l?o`0?3ol01P0?3o
l040oooo000R0?3ol080o`00903`oo030?l00140l?o`00<0o`000?3ol03`oo00103`oo000`000000
l?o`0?3ol01P0?3ol040oooo000P0?3ol080o`008`3`oo030?l001<0l?o`00<0o`000?3ol03`oo00
1@3`oo000`000000l?o`0?3ol01P0?3ol040oooo000N0?3ol080o`008P3`oo030?l001D0l?o`00<0
o`000?3ol03`oo001P3`oo000`000000l?o`0?3ol01P0?3ol040oooo000M0?3ol0030?l0003`oo00
l?o`0200l?o`0P3o000G0?3ol0030?l0003`oo00l?o`00L0l?o`00<000000?3ol03`oo00H03`oo01
0?ooo`006`3`oo020?l00200l?o`0`3o000H0?3ol0030?l0003`oo00l?o`00P0l?o`00<000000?3o
l03`oo00H03`oo010?ooo`006@3`oo020?l001l0l?o`0`3o000J0?3ol0030?l0003`oo00l?o`00T0
l?o`00<000000?3ol03`oo00H03`oo010?ooo`00603`oo000`3o0000l?o`0?3ol00L0?3ol0<0o`00
703`oo000`3o0000l?o`0?3ol00:0?3ol0030000003`oo00l?o`0600l?o`0@3oool001L0l?o`00<0
o`000?3ol03`oo006P3`oo030?l001h0l?o`00<0o`000?3ol03`oo002`3`oo000`000000l?o`0?3o
l01P0?3ol040oooo000E0?3ol080o`006@3`oo040?l00200l?o`00<0o`000?3ol03`oo00303`oo00
0`000000l?o`0?3ol01P0?3ol040oooo000D0?3ol0030?l0003`oo00l?o`01D0l?o`103o000R0?3o
l080o`003`3`oo000`000000l?o`0?3ol01P0?3ol040oooo000C0?3ol0030?l0003`oo00l?o`0180
l?o`103o000U0?3ol0030?l0003`oo00l?o`00l0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00
4`3`oo000`3o0000l?o`0?3ol00<0?3ol0H0o`00:03`oo000`3o0000l?o`0?3ol00@0?3ol0030000
003`oo00l?o`0600l?o`0@3oool001<0l?o`0`3o00070?3ol0D0o`00;@3`oo000`3o0000l?o`0?3o
l00A0?3ol0030000003`oo00l?o`0600l?o`0@3oool001H0l?o`1`3o000`0?3ol080o`00503`oo00
0`000000l?o`0?3ol01P0?3ol040oooo001<0?3ol0030?l0003`oo00l?o`01@0l?o`00<000000?3o
l03`oo00H03`oo010?ooo`00B`3`oo000`3o0000l?o`0?3ol00E0?3ol0030000003`oo00l?o`0600
l?o`0@3oool004T0l?o`0P3o000H0?3ol0030000003`oo00l?o`0600l?o`0@3oool004P0l?o`00<0
o`000?3ol03`oo00603`oo000`000000l?o`0?3ol01P0?3ol040oooo00170?3ol0030?l0003`oo00
l?o`01T0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00AP3`oo000`3o0000l?o`0?3ol00J0?3o
l0030000003`oo00l?o`0600l?o`0@3oool004@0l?o`0P3o000M0?3ol0030000003`oo00l?o`0600
l?o`0@3oool004<0l?o`00<0o`000?3ol03`oo007@3`oo000`000000l?o`0?3ol01P0?3ol040oooo
00120?3ol0030?l0003`oo00l?o`01h0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00@@3`oo00
0`3o0000l?o`0?3ol00O0?3ol0030000003`oo00l?o`0600l?o`0@3oool003l0l?o`0P3o000R0?3o
l0030000003`oo00l?o`0600l?o`0@3oool003h0l?o`00<0o`000?3ol03`oo008P3`oo000`000000
l?o`0?3ol01P0?3ol040oooo000m0?3ol0030?l0003`oo00l?o`02<0l?o`00<000000?3ol03`oo00
H03`oo010?ooo`00>`3`oo020?l002H0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00>P3`oo00
0`3o0000l?o`0?3ol00V0?3ol0030000003`oo00l?o`0600l?o`0@3oool003T0l?o`00<0o`000?3o
l03`oo009`3`oo000`000000l?o`0?3ol01P0?3ol040oooo000g0?3ol080o`00:P3`oo000`000000
l?o`0?3ol01P0?3ol040oooo000f0?3ol0030?l0003`oo00l?o`02X0l?o`00<000000?3ol03`oo00
H03`oo010?ooo`00=03`oo020?l002d0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00<P3`oo02
0?l002l0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00<@3`oo000`3o0000l?o`0?3ol00_0?3o
l0030000003`oo00l?o`0600l?o`0@3oool002l0l?o`0P3o000b0?3ol0030000003`oo00l?o`0600
l?o`0@3oool002h0l?o`00<0o`000?3ol03`oo00<P3`oo000`000000l?o`0?3ol01P0?3ol040oooo
000/0?3ol080o`00=@3`oo000`000000l?o`0?3ol01P0?3ol040oooo000[0?3ol0030?l0003`oo00
l?o`03D0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00:@3`oo020?l003P0l?o`00<000000?3o
l03`oo00H03`oo010?ooo`00:03`oo000`3o0000l?o`0?3ol00h0?3ol0030000003`oo00l?o`0600
l?o`0@3oool002H0l?o`0P3o000k0?3ol0030000003`oo00l?o`0600l?o`0@3oool002@0l?o`0P3o
000m0?3ol0030000003`oo00l?o`0600l?o`0@3oool002<0l?o`00<0o`000?3ol03`oo00?@3`oo00
0`000000l?o`0?3ol01P0?3ol040oooo000Q0?3ol080o`00@03`oo000`000000l?o`0?3ol01P0?3o
l040oooo000P0?3ol0030?l0003`oo00l?o`0400l?o`00<000000?3ol03`oo00H03`oo010?ooo`00
7P3`oo020?l004<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`007@3`oo000`3o0000l?o`0?3o
l0130?3ol0030000003`oo00l?o`0600l?o`0@3oool001/0l?o`0P3o00160?3ol0030000003`oo00
l?o`0600l?o`0@3oool001X0l?o`00<0o`000?3ol03`oo00AP3`oo000`000000l?o`0?3ol01P0?3o
l040oooo000H0?3ol080o`00B@3`oo0010000000l?o`0?3ol03`oo04000005/0l?o`0@3oool001H0
l?o`0P3o001;0?3ol0030000003`oo00l?o`00<0l?o`00<000000?3ol03`oo00FP3`oo010?ooo`00
5@3`oo000`3o0000l?o`0?3ol01;0?3ol0030000003`oo00l?o`00<0l?o`00<000000?3ol03`oo00
FP3`oo010?ooo`004`3`oo020?l004h0l?o`00<000000?3ol03`oo000`3`oo02000005/0l?o`0@3o
ool00180l?o`00<0o`000?3ol03`oo00CP3`oo000`000000l?o`0?3ol0020?3ol0030000003`oo00
000005/0l?o`0@3oool00100l?o`0P3o001A0?3ol0030000003`oo00l?o`0080l?o`00@000000?3o
l03`oo000000FP3`oo010?ooo`003P3`oo020?l005<0l?o`00D000000?3ol03`oo00l?o`00000003
0?3ol0030000003`oo00l?o`05P0l?o`0@3oool000`0l?o`0P3o001E0?3ol0030000003`oo00l?o`
00<0000000@0l?o`0000000000000000F@3`oo010?ooo`00\
\>"],
    ImageRangeCache->{{{0, 198}, {198, 0}} -> {-2, -2, 0, 0}}],
  StyleBox["          ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.941 1 .941 r
.5 .5 m
.5 0 L
1 0 L
1 1 L
.5 1 L
.5 .5 L
F
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.5 .75 m
.50031 .75 L
.50059 .75001 L
.50091 .75002 L
.50122 .75004 L
.5015 .75006 L
.50176 .75009 L
.50236 .75017 L
.50295 .75028 L
.50361 .75044 L
.50494 .75087 L
.50623 .75142 L
.50762 .75217 L
.51014 .75387 L
.51581 .75868 L
.51861 .76103 L
.51997 .76204 L
.5212 .76284 L
.52241 .76349 L
.52304 .76377 L
.52371 .76402 L
.52405 .76413 L
.52442 .76423 L
.52477 .7643 L
.52508 .76436 L
.5254 .7644 L
.52575 .76443 L
.52607 .76444 L
.52638 .76443 L
.5267 .76442 L
.52688 .7644 L
.52706 .76438 L
.52741 .76432 L
.52778 .76423 L
.52846 .76402 L
.52908 .76376 L
.53051 .76291 L
.53124 .76235 L
.53202 .76163 L
.53472 .75833 L
.53717 .75424 L
.54267 .74195 L
.54813 .72746 L
.55053 .72124 L
.55317 .71503 L
.55553 .71039 L
.55683 .70832 L
.55807 .70673 L
.55874 .70603 L
.55947 .70542 L
Mistroke
.55979 .7052 L
.56014 .70499 L
.56046 .70484 L
.56075 .70472 L
.56108 .70462 L
.56125 .70458 L
.56143 .70455 L
.56174 .70452 L
.56207 .70452 L
.56237 .70456 L
.56269 .70462 L
.56299 .70472 L
.56326 .70483 L
.56387 .70517 L
.56453 .70568 L
.56522 .70638 L
.56587 .70719 L
.56703 .709 L
.56828 .71147 L
.57113 .71909 L
.57374 .72835 L
.58415 .77938 L
.5894 .80559 L
.59169 .81516 L
.59417 .82352 L
.59555 .8271 L
.59616 .8284 L
.59682 .82962 L
.59741 .83052 L
.59804 .8313 L
.59839 .83164 L
.59871 .83189 L
.59902 .83209 L
.59933 .83223 L
.59964 .83233 L
.59982 .83236 L
.59999 .83237 L
.60033 .83235 L
.60052 .83231 L
.60069 .83225 L
.60099 .83212 L
.60131 .83192 L
.60165 .83165 L
.60196 .83134 L
.60269 .83041 L
.60335 .8293 L
.60483 .82591 L
.6061 .82201 L
.60745 .81691 L
.60986 .80536 L
Mistroke
.61532 .76957 L
.62525 .68881 L
.63035 .6535 L
.63182 .64556 L
.63322 .6392 L
.63459 .63418 L
.63583 .63076 L
.63646 .62948 L
.63679 .62892 L
.63713 .62843 L
.63744 .62806 L
.63777 .62775 L
.63807 .62754 L
.63835 .62741 L
.63852 .62736 L
.6387 .62734 L
.63903 .62736 L
.63935 .62746 L
.63965 .62763 L
.63997 .62789 L
.64032 .62828 L
.64104 .62938 L
.64166 .63068 L
.64224 .63216 L
.64353 .63646 L
.64467 .64137 L
.64587 .64764 L
.64837 .66424 L
.65105 .68666 L
.65587 .73634 L
.6611 .79669 L
.66677 .85766 L
.66943 .88085 L
.67088 .89141 L
.67224 .89972 L
.67349 .90593 L
.67464 .9103 L
.67529 .91221 L
.67591 .91362 L
.67622 .91419 L
.67656 .91468 L
.67675 .91491 L
.67693 .91509 L
.67727 .91533 L
.67759 .91544 L
.67789 .91545 L
.67821 .91535 L
.67839 .91525 L
.67856 .91512 L
.67889 .91478 L
Mistroke
.67925 .91427 L
.67991 .91297 L
.68053 .91134 L
.68117 .90918 L
.68234 .90415 L
.68368 .89656 L
.68494 .88775 L
.68781 .86197 L
.69312 .79684 L
.69798 .72537 L
.70339 .64585 L
.70602 .61154 L
.7084 .58488 L
.7096 .57346 L
.7109 .56278 L
.71202 .55507 L
.71325 .54833 L
.71389 .5456 L
.71456 .54324 L
.71494 .54219 L
.71528 .5414 L
.71563 .54075 L
.71595 .54029 L
.71624 .53999 L
.71656 .5398 L
.71687 .53974 L
.71705 .53977 L
.71722 .53983 L
.71752 .54005 L
.7178 .54036 L
.71811 .54081 L
.71843 .54144 L
.7191 .5432 L
.71974 .54544 L
.72093 .55112 L
.72221 .55936 L
.72361 .57073 L
.72611 .59725 L
.72843 .62791 L
.73877 .80893 L
.74356 .89375 L
.74871 .96516 L
.75 .97824 L
Mfstroke
1 0 0 r
.5 .25 m
.50031 .25 L
.50059 .24999 L
.50091 .24998 L
.50122 .24996 L
.5015 .24994 L
.50176 .24991 L
.50236 .24983 L
.50295 .24972 L
.50361 .24956 L
.50494 .24913 L
.50623 .24858 L
.50762 .24783 L
.51014 .24613 L
.51581 .24132 L
.51861 .23897 L
.51997 .23796 L
.5212 .23716 L
.52241 .23651 L
.52304 .23623 L
.52371 .23598 L
.52405 .23587 L
.52442 .23577 L
.52477 .2357 L
.52508 .23564 L
.5254 .2356 L
.52575 .23557 L
.52607 .23556 L
.52638 .23557 L
.5267 .23558 L
.52688 .2356 L
.52706 .23562 L
.52741 .23568 L
.52778 .23577 L
.52846 .23598 L
.52908 .23624 L
.53051 .23709 L
.53124 .23765 L
.53202 .23837 L
.53472 .24167 L
.53717 .24576 L
.54267 .25805 L
.54813 .27254 L
.55053 .27876 L
.55317 .28497 L
.55553 .28961 L
.55683 .29168 L
.55807 .29327 L
.55874 .29397 L
.55947 .29458 L
Mistroke
.55979 .2948 L
.56014 .29501 L
.56046 .29516 L
.56075 .29528 L
.56108 .29538 L
.56125 .29542 L
.56143 .29545 L
.56174 .29548 L
.56207 .29548 L
.56237 .29544 L
.56269 .29538 L
.56299 .29528 L
.56326 .29517 L
.56387 .29483 L
.56453 .29432 L
.56522 .29362 L
.56587 .29281 L
.56703 .291 L
.56828 .28853 L
.57113 .28091 L
.57374 .27165 L
.58415 .22062 L
.5894 .19441 L
.59169 .18484 L
.59417 .17648 L
.59555 .1729 L
.59616 .1716 L
.59682 .17038 L
.59741 .16948 L
.59804 .1687 L
.59839 .16836 L
.59871 .16811 L
.59902 .16791 L
.59933 .16777 L
.59964 .16767 L
.59982 .16764 L
.59999 .16763 L
.60033 .16765 L
.60052 .16769 L
.60069 .16775 L
.60099 .16788 L
.60131 .16808 L
.60165 .16835 L
.60196 .16866 L
.60269 .16959 L
.60335 .1707 L
.60483 .17409 L
.6061 .17799 L
.60745 .18309 L
.60986 .19464 L
Mistroke
.61532 .23043 L
.62525 .31119 L
.63035 .3465 L
.63182 .35444 L
.63322 .3608 L
.63459 .36582 L
.63583 .36924 L
.63646 .37052 L
.63679 .37108 L
.63713 .37157 L
.63744 .37194 L
.63777 .37225 L
.63807 .37246 L
.63835 .37259 L
.63852 .37264 L
.6387 .37266 L
.63903 .37264 L
.63935 .37254 L
.63965 .37237 L
.63997 .37211 L
.64032 .37172 L
.64104 .37062 L
.64166 .36932 L
.64224 .36784 L
.64353 .36354 L
.64467 .35863 L
.64587 .35236 L
.64837 .33576 L
.65105 .31334 L
.65587 .26366 L
.6611 .20331 L
.66677 .14234 L
.66943 .11915 L
.67088 .10859 L
.67224 .10028 L
.67349 .09407 L
.67464 .0897 L
.67529 .08779 L
.67591 .08638 L
.67622 .08581 L
.67656 .08532 L
.67675 .08509 L
.67693 .08491 L
.67727 .08467 L
.67759 .08456 L
.67789 .08455 L
.67821 .08465 L
.67839 .08475 L
.67856 .08488 L
.67889 .08522 L
Mistroke
.67925 .08573 L
.67991 .08703 L
.68053 .08866 L
.68117 .09082 L
.68234 .09585 L
.68368 .10344 L
.68494 .11225 L
.68781 .13803 L
.69312 .20316 L
.69798 .27463 L
.70339 .35415 L
.70602 .38846 L
.7084 .41512 L
.7096 .42654 L
.7109 .43722 L
.71202 .44493 L
.71325 .45167 L
.71389 .4544 L
.71456 .45676 L
.71494 .45781 L
.71528 .4586 L
.71563 .45925 L
.71595 .45971 L
.71624 .46001 L
.71656 .4602 L
.71687 .46026 L
.71705 .46023 L
.71722 .46017 L
.71752 .45995 L
.7178 .45964 L
.71811 .45919 L
.71843 .45856 L
.7191 .4568 L
.71974 .45456 L
.72093 .44888 L
.72221 .44064 L
.72361 .42927 L
.72611 .40275 L
.72843 .37209 L
.73877 .19107 L
.74356 .10625 L
.74871 .03484 L
.75 .02176 L
Mfstroke
0 g
0 .5 m
1 .5 L
s
.5 .5 m
.5 1 L
s
[ .02 .02 ] 0 setdash
.5 0 m
.5 .5 L
s
0 0 1 r
.03 w
.5 .75 Mdot
1 0 0 r
.5 .25 Mdot
0 g
gsave
.98 .525 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5375 .98 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47 .25 -77.375 -10.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.188 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
91.750 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47 .75 -77.375 -10.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
91.750 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    GeneratedCell->False,
    CellAutoOverwrite->False,
    ImageSize->{199, 199},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000370000ab000`400?l00000o`00003oH`3oool0
0`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000l?o`0?3ol01P0?3ol040oooo001S0?ooo`03
0000003`oo00l?o`0600l?o`0@3oool006<0oooo00<000000?3ol03`oo00H03`oo010?ooo`00H`3o
ool00`000000l?o`0?3ol01P0?3ol040oooo001S0?oooc40l?o`00<0o`000?3ol03`oo00;`3`oo01
0?ooo`00H`3ooola0?3ol0030?l0003`oo00l?o`02l0l?o`0@3oool006<0oooo<@3`oo000`3o0000
l?o`0?3ol00_0?3ol040oooo001S0?ooo`030000003`oo00l?o`02h0l?o`00<0o`000?3ol03`oo00
;`3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00^0?3ol0030?l0003`oo00l?o`02l0l?o`0@3o
ool006<0oooo00<000000?3ol03`oo00;P3`oo000`3o0000l?o`0?3ol00_0?3ol040oooo001S0?oo
o`030000003`oo00l?o`02h0l?o`00<0o`000?3ol03`oo00;`3`oo010?ooo`00H`3oool00`000000
l?o`0?3ol00^0?3ol0030?l0003`oo00l?o`02l0l?o`0@3oool006<0oooo<@3`oo000`3o0000l?o`
0?3ol00_0?3ol040oooo001S0?oooc40l?o`00<0o`000?3ol03`oo00;`3`oo010?ooo`00H`3oool`
0?3ol0030?l0003`oo00l?o`0300l?o`0@3oool006<0oooo00<000000?3ol03`oo00;@3`oo000`3o
0000l?o`0?3ol00`0?3ol040oooo001S0?ooo`030000003`oo00l?o`01l0l?o`0P3o000<0?3ol003
0?l0003`oo00l?o`0300l?o`0@3oool006<0oooo00<000000?3ol03`oo007`3`oo020?l000`0l?o`
00<0o`000?3ol03`oo00<03`oo010?ooo`00H`3oool00`000000l?o`0?3ol00O0?3ol0030?l0003`
oo00o`0000/0l?o`00<0o`000?3ol03`oo00<03`oo010?ooo`00H`3oool00`000000l?o`0?3ol00O
0?3ol0030?l0003`oo00o`0000/0l?o`00<0o`000?3ol03`oo00<03`oo010?ooo`00H`3ooolQ0?3o
l0040?l0003`oo00l?o`0?l000/0l?o`00<0o`000?3ol03`oo00<03`oo010?ooo`00H`3ooolQ0?3o
l0040?l0003`oo00l?o`0?l000/0l?o`00<0o`000?3ol03`oo00<03`oo010?ooo`00H`3ooolQ0?3o
l0040?l0003`oo00l?o`0?l000/0l?o`00<0o`000?3ol03`oo00<03`oo010?ooo`00H`3oool00`00
0000l?o`0?3ol00N0?3ol0040?l0003`oo00l?o`0?l000/0l?o`00<0o`000?3ol03`oo00<03`oo01
0?ooo`00H`3oool00`000000l?o`0?3ol00N0?3ol0040?l0003`oo00l?o`0?l000/0l?o`00<0o`00
0?3ol03`oo00<03`oo010?ooo`00H`3oool00`000000l?o`0?3ol00N0?3ol0050?l0003`oo00l?o`
0?3ol03o00002P3`oo000`3o0000l?o`0?3ol00`0?3ol040oooo001S0?ooo`030000003`oo00l?o`
01h0l?o`00D0o`000?3ol03`oo00l?o`0?l0000:0?3ol0030?l0003`oo00l?o`0300l?o`0@3oool0
06<0oooo00<000000?3ol03`oo007P3`oo001@3o0000l?o`0?3ol03`oo00o`0000X0l?o`00<0o`00
0?3ol03`oo00<03`oo010?ooo`00H`3ooolQ0?3ol0050?l0003`oo00l?o`0?3ol03o00002P3`oo00
0`3o0000l?o`0?3ol00`0?3ol040oooo001S0?ooob40l?o`00D0o`000?3ol03`oo00l?o`0?l00009
0?3ol0030?l0003`oo00l?o`0340l?o`0@3oool006<0oooo8@3`oo001@3o0000l?o`0?3ol03`oo00
o`0000T0l?o`00<0o`000?3ol03`oo00<@3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00M0?3o
l0030?l0003`oo00l?o`0080l?o`00<0o`000?3ol03`oo001`3`oo000`3o0000l?o`0?3ol00a0?3o
l040oooo001S0?ooo`030000003`oo00l?o`0140l?o`00<0o`000?3ol03`oo002@3`oo000`3o0000
l?o`0?3ol0020?3ol0030?l0003`oo00l?o`00L0l?o`00<0o`000?3ol03`oo00<@3`oo010?ooo`00
H`3oool00`000000l?o`0?3ol00@0?3ol080o`002`3`oo000`3o0000l?o`0?3ol0020?3ol0030?l0
003`oo00l?o`00L0l?o`00<0o`000?3ol03`oo00<@3`oo010?ooo`00H`3oool00`000000l?o`0?3o
l00?0?3ol0030?l0003`oo00o`0000/0l?o`00<0o`000?3ol03`oo000`3`oo000`3o0000l?o`0?3o
l0060?3ol0030?l0003`oo00l?o`0340l?o`0@3oool006<0oooo00<000000?3ol03`oo003`3`oo00
103o0000l?o`0?3ol03o000:0?3ol0030?l0003`oo00l?o`00<0l?o`00<0o`000?3ol03`oo001P3`
oo000`3o0000l?o`0?3ol00a0?3ol040oooo001S0?oooa80l?o`00@0o`000?3ol03`oo00o`002P3`
oo000`3o0000l?o`0?3ol0030?3ol0030?l0003`oo00l?o`00H0l?o`00<0o`000?3ol03`oo00<@3`
oo010?ooo`00H`3ooolA0?3ol0050?l0003`oo00l?o`0?3ol03o00002@3`oo000`3o0000l?o`0?3o
l0040?3ol0030?l0003`oo00l?o`00H0l?o`00<0o`000?3ol03`oo00<@3`oo010?ooo`00H`3ooolA
0?3ol0050?l0003`oo00l?o`0?3ol03o00002@3`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`
oo00l?o`00H0l?o`00<0o`000?3ol03`oo00<@3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00>
0?3ol0050?l0003`oo00l?o`0?3ol03o00002@3`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`
oo00l?o`00H0l?o`00<0o`000?3ol03`oo00<@3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00>
0?3ol0050?l0003`oo00l?o`0?3ol03o00002@3`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`
oo00l?o`00H0l?o`00<0o`000?3ol03`oo00<@3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00=
0?3ol0030?l0003`oo00l?o`0080l?o`00<0o`000?3ol03`oo001`3`oo000`3o0000l?o`0?3ol004
0?3ol0030?l0003`oo00l?o`00H0l?o`00<0o`000?3ol03`oo00<@3`oo010?ooo`00H`3oool00`00
0000l?o`0?3ol00=0?3ol0030?l0003`oo00l?o`00<0l?o`00<0o`000?3ol03`oo001P3`oo000`3o
0000l?o`0?3ol0040?3ol0030?l0003`oo00l?o`00H0l?o`00<0o`000?3ol03`oo00<@3`oo010?oo
o`00H`3oool00`000000l?o`0?3ol00=0?3ol0030?l0003`oo00l?o`00<0l?o`00<0o`000?3ol03`
oo001P3`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00l?o`00H0l?o`00<0o`000?3ol03`
oo00<@3`oo010?ooo`00H`3oool@0?3ol0030?l0003`oo00l?o`00<0l?o`00<0o`000?3ol03`oo00
1P3`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00l?o`00H0l?o`00<0o`000?3ol03`oo00
<@3`oo010?ooo`00H`3oool@0?3ol0030?l0003`oo00l?o`00<0l?o`00<0o`000?3ol03`oo001P3`
oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00l?o`00H0l?o`00<0o`000?3ol03`oo00<@3`
oo010?ooo`00H`3oool40?3ol0<0o`00203`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00
l?o`00D0l?o`00<0o`000?3ol03`oo001@3`oo000`3o0000l?o`0?3ol0050?3ol0030?l0003`oo00
l?o`0380l?o`0@3oool005H0oooo1`0000040?ooo`<0o`000P3`oo00103o0000l?o`0?3ol03o0008
0?3ol0030?l0003`oo00l?o`00@0l?o`00<0o`000?3ol03`oo001@3`oo000`3o0000l?o`0?3ol005
0?3ol0030?l0003`oo00l?o`00D0l?o`00<0o`000?3ol03`oo00<P3`oo010?ooo`00F03oool00`00
0000oooo000000050?ooo`H0o`00103`oo000`3o0000l?o`0?3ol0050?3ol0030?l0003`oo00l?o`
00@0l?o`00<0o`000?3ol03`oo001@3`oo000`3o0000l?o`0?3ol0060?3ol0030?l0003`oo00l?o`
00@0l?o`00<0o`000?3ol03`oo00<P3`oo010?ooo`00C`3oool5000000@0oooo00<000000?ooo`00
00001@3oool50?l000D0l?o`00<0o`000?3ol03`oo001@3`oo000`3o0000l?o`0?3ol0040?3ol003
0?l0003`oo00l?o`00D0l?o`00<0o`000?3ol03`oo001P3`oo000`3o0000l?o`0?3ol0040?3ol003
0?l0003`oo00l?o`0380l?o`0@3oool005P0oooo00<000000?ooo`0000001@3oool50?l000H0l?o`
00<0o`000?3ol03`oo00103`oo000`3o0000l?o`0?3ol0050?3ol0030?l0003`oo00l?o`00@0l?o`
00<0o`000?3ol03`oo001P3`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00l?o`0380l?o`
0@3oool005P0oooo00<000000?ooo`0000001P3oool30?l000L0l?o`00<0o`000?3ol03`oo000`3`
oo000`3o0000l?o`0?3ol0060?3ol0030?l0003`oo00l?o`00@0l?o`00<0o`000?3ol03`oo001P3`
oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00l?o`0380l?o`0@3oool005H0oooo1@000008
0?ooo`P0l?o`00<0o`000?3ol03`oo000`3`oo000`3o0000l?o`0?3ol0060?3ol0030?l0003`oo00
l?o`00@0l?o`00<0o`000?3ol03`oo001P3`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00
l?o`0380l?o`0@3oool006<0oooo2@3`oo000`3o0000l?o`0?3ol0020?3ol0030?l0003`oo00l?o`
00H0l?o`00<0o`000?3ol03`oo00103`oo000`3o0000l?o`0?3ol0060?3ol0030?l0003`oo00l?o`
00@0l?o`00<0o`000?3ol03`oo00<P3`oo010?ooo`00F@3oool00`000000oooo0?ooo`070?ooo`T0
l?o`00<0o`000?3ol03`oo000P3`oo000`3o0000l?o`0?3ol0060?3ol0030?l0003`oo00l?o`00@0
l?o`00<0o`000?3ol03`oo001P3`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00l?o`0380
l?o`0@3oool006<0oooo00<000000?3ol03`oo001`3`oo001@3o0000l?o`0?3ol03`oo00o`0000P0
l?o`00<0o`000?3ol03`oo00103`oo000`3o0000l?o`0?3ol0060?3ol0030?l0003`oo00l?o`00@0
l?o`00<0o`000?3ol03`oo00<P3`oo010?ooo`00H`3oool00`000000l?o`0?3ol0070?3ol0040?l0
003`oo00l?o`0?l000T0l?o`00<0o`000?3ol03`oo00103`oo000`3o0000l?o`0?3ol0060?3ol003
0?l0003`oo00l?o`00@0l?o`00<0o`000?3ol03`oo00<P3`oo010?ooo`00H`3oool00`000000l?o`
0?3ol0070?3ol080o`0000<0l?o`0?l0003`oo00203`oo000`3o0000l?o`0?3ol0030?3ol0030?l0
003`oo00l?o`00L0l?o`00<0o`000?3ol03`oo00103`oo000`3o0000l?o`0?3ol00b0?3ol040oooo
001S0?ooo`030000003`oo00l?o`00P0l?o`0P3o000;0?3ol0030?l0003`oo00l?o`0080l?o`00<0
o`000?3ol03`oo001`3`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00l?o`0380l?o`0@3o
ool006<0oooo00<000000?3ol03`oo005@3`oo000`3o0000l?o`0?3ol0020?3ol0030?l0003`oo00
l?o`00L0l?o`00<0o`000?3ol03`oo00103`oo000`3o0000l?o`0?3ol00b0?3ol040oooo001S0?oo
oaP0l?o`00<0o`000?3ol03`oo000P3`oo000`3o0000l?o`0?3ol0070?3ol0030?l0003`oo00l?o`
00@0l?o`00<0o`000?3ol03`oo00<P3`oo010?ooo`00H`3ooolH0?3ol0030?l0003`oo00l?o`0080
l?o`00<0o`000?3ol03`oo001`3`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00l?o`0380
l?o`0@3oool006<0oooo603`oo000`3o0000l?o`0?3ol0020?3ol0030?l0003`oo00l?o`00L0l?o`
00<0o`000?3ol03`oo00103`oo000`3o0000l?o`0?3ol00b0?3ol040oooo001S0?ooo`030000003`
oo00l?o`01D0l?o`00<0o`000?3ol03`oo000P3`oo000`3o0000l?o`0?3ol0080?3ol0030?l0003`
oo00l?o`00<0l?o`00<0o`000?3ol03`oo00<P3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00E
0?3ol0030?l0003`oo00l?o`0080l?o`00<0o`000?3ol03`oo00203`oo000`3o0000l?o`0?3ol002
0?3ol0030?l0003`oo00l?o`03<0l?o`0@3oool006<0oooo00<000000?3ol03`oo005P3`oo001@3o
0000l?o`0?3ol03`oo00o`0000X0l?o`00<0o`000?3ol03`oo000P3`oo000`3o0000l?o`0?3ol00c
0?3ol040oooo001S0?ooo`030000003`oo00l?o`01H0l?o`00D0o`000?3ol03`oo00l?o`0?l0000:
0?3ol0030?l0003`oo00l?o`0080l?o`00<0o`000?3ol03`oo00<`3`oo010?ooo`00H`3oool00`00
0000l?o`0?3ol00F0?3ol0050?l0003`oo00l?o`0?3ol03o00002P3`oo000`3o0000l?o`0?3ol002
0?3ol0030?l0003`oo00l?o`03<0l?o`0@3oool006<0oooo6@3`oo00103o0000l?o`0?3ol03o000;
0?3ol0030?l0003`oo00l?o`0080l?o`00<0o`000?3ol03`oo00<`3`oo010?ooo`00H`3ooolI0?3o
l0040?l0003`oo00l?o`0?l000/0l?o`00<0o`000?3ol03`oo000P3`oo000`3o0000l?o`0?3ol00c
0?3ol040oooo001S0?oooaX0l?o`00<0o`000?3ol03o00002`3`oo000`3o0000l?o`0?3ol0020?3o
l0030?l0003`oo00l?o`03<0l?o`0@3oool006<0oooo00<000000?3ol03`oo005`3`oo000`3o0000
l?o`0?l0000;0?3ol0030?l0003`oo00l?o`0080l?o`00<0o`000?3ol03`oo00<`3`oo010?ooo`00
H`3oool00`000000l?o`0?3ol00G0?3ol0030?l0003`oo00o`0000/0l?o`00<0o`000?3ol03`oo00
0P3`oo000`3o0000l?o`0?3ol00c0?3ol040oooo001S0?ooo`030000003`oo00l?o`01L0l?o`0`3o
000;0?3ol0030?l0003`oo00l?o`0080l?o`00<0o`000?3ol03`oo00<`3`oo010?ooo`00H`3oool0
0`000000l?o`0?3ol00U0?3ol0030?l0003`oo00l?o`0080l?o`00<0o`000?3ol03`oo00<`3`oo01
0?ooo`00H`3oool00`000000l?o`0?3ol00U0?3ol0030?l0003`oo00l?o`0080l?o`00<0o`000?3o
l03`oo00<`3`oo010?ooo`00H`3ooolX0?3ol0050?l0003`oo00l?o`0?3ol03o0000=P3`oo010?oo
o`00H`3ooolX0?3ol0050?l0003`oo00l?o`0?3ol03o0000=P3`oo010?ooo`00H`3ooolX0?3ol005
0?l0003`oo00l?o`0?3ol03o0000=P3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00U0?3ol005
0?l0003`oo00l?o`0?3ol03o0000=P3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00V0?3ol004
0?l0003`oo00l?o`0?l003H0l?o`0@3oool006<0oooo00<000000?3ol03`oo009P3`oo00103o0000
l?o`0?3ol03o000f0?3ol040oooo001S0?ooo`030000003`oo00l?o`02H0l?o`00@0o`000?3ol03`
oo00o`00=P3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00V0?3ol0040?l0003`oo00l?o`0?l0
03H0l?o`0@3oool006<0oooo:@3`oo00103o0000l?o`0?3ol03o000f0?3ol040oooo001S0?ooobT0
l?o`00@0o`000?3ol03`oo00o`00=P3`oo010?ooo`00H`3ooolY0?3ol0030?l0003`oo00o`0003L0
l?o`0@3oool006<0oooo00<000000?3ol03`oo009P3`oo000`3o0000l?o`0?l0000g0?3ol040oooo
001S0?ooo`030000003`oo00l?o`02H0l?o`00<0o`000?3ol03o0000=`3`oo010?ooo`00H`3oool0
0`000000l?o`0?3ol00W0?3ol080o`00=`3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00W0?3o
l080o`00=`3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00W0?3ol080o`00=`3`oo010?ooo`00
H`3ooomS0?3ol040oooo001S0?ooof<0l?o`0@3oool006<0ooooH`3`oo010?ooo`00H`3oool00`00
0000l?o`0?3ol01P0?3ol040oooo001S0?ooo`030000003`oo00l?o`0600l?o`0@3oool006<0oooo
00<000000?3ol03`oo00H03`oo010?ooo`00a`00000006<0oooo00<000000?3ol03`oo00H03`oo01
0?ooo`00H`3oool00`000000l?o`0?3ol01P0?3ol040oooo001S0?ooo`030000003`oo00l?o`0600
l?o`0@3oool006<0oooo00<000000?3ol03`oo00FP3`oo02000000040?3ol000000000000?3ol040
oooo001S0?ooo`030000003`oo00l?o`05T0l?o`00<000000?3ol03`oo000P0000020?3ol040oooo
001S0?ooo`030000003`oo00l?o`05T0l?o`00D000000?3ol03`oo00l?o`000000020?3ol040oooo
001S0?ooo`030000003`oo00l?o`05T0l?o`00D000000?3ol03`oo00l?o`000000020?3ol040oooo
001S0?ooo`030000003`oo00l?o`02L0l?o`0P000?l`0?3ol0050000003`oo00l?o`0?3ol0000000
0P3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00W0?3ol080003o;`3`oo0200000080l?o`0P00
00020?3ol040oooo001S0?ooo`030000003`oo00l?o`02L0l?o`0P000?lg0?3ol040oooo001S0?oo
o`030000003`oo00l?o`02H0l?o`00<0003o0?3ol0000?l0=`3`oo010?ooo`00H`3oool00`000000
l?o`0?3ol00V0?3ol0030000o`3`oo00003o03L0l?o`0@3oool006<0oooo00<000000?3ol03`oo00
9P3`oo000`000?l0l?o`0000o`0g0?3ol040oooo001S0?ooo`030000003`oo00l?o`02H0l?o`00@0
003o0?3ol03`oo00003o=P3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00V0?3ol0040000o`3`
oo00l?o`0000ocH0l?o`0@3oool006<0oooo00<000000?3ol03`oo009P3`oo0010000?l0l?o`0?3o
l0000?lf0?3ol040oooo001S0?ooo`030000003`oo00l?o`02H0l?o`00@0003o0?3ol03`oo00003o
=P3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00V0?3ol0040000o`3`oo00l?o`0000ocH0l?o`
0@3oool006<0oooo00<000000?3ol03`oo009P3`oo0010000?l0l?o`0?3ol0000?lf0?3ol040oooo
001S0?ooo`030000003`oo00l?o`02D0l?o`00D0003o0?3ol03`oo00l?o`0000o`0f0?3ol040oooo
001S0?ooo`030000003`oo00l?o`02D0l?o`00D0003o0?3ol03`oo00l?o`0000o`0f0?3ol040oooo
001S0?ooo`030000003`oo00l?o`02D0l?o`00D0003o0?3ol03`oo00l?o`0000o`0f0?3ol040oooo
001S0?ooo`030000003`oo00l?o`02D0l?o`00D0003o0?3ol03`oo00l?o`0000o`0f0?3ol040oooo
001S0?ooo`030000003`oo00l?o`02D0l?o`00<0003o0?3ol03`oo000P3`oo000`000?l0l?o`0?3o
l00c0?3ol040oooo001S0?ooo`030000003`oo00l?o`01P0l?o`00<0003o0?3ol03`oo002P3`oo00
0`000?l0l?o`0?3ol0020?3ol0030000o`3`oo00l?o`03<0l?o`0@3oool006<0oooo00<000000?3o
l03`oo005`3`oo030000o`/0l?o`00<0003o0?3ol03`oo000P3`oo000`000?l0l?o`0?3ol00c0?3o
l040oooo001S0?ooo`030000003`oo00l?o`01L0l?o`00<0003o0?3ol0000?l02`3`oo000`000?l0
l?o`0?3ol0020?3ol0030000o`3`oo00l?o`03<0l?o`0@3oool006<0oooo00<000000?3ol03`oo00
5`3`oo000`000?l0l?o`0000o`0;0?3ol0030000o`3`oo00l?o`0080l?o`00<0003o0?3ol03`oo00
<`3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00G0?3ol0030000o`3`oo00003o00/0l?o`00<0
003o0?3ol03`oo000P3`oo000`000?l0l?o`0?3ol00c0?3ol040oooo001S0?ooo`030000003`oo00
l?o`01H0l?o`00@0003o0?3ol03`oo00003o2`3`oo000`000?l0l?o`0?3ol0020?3ol0030000o`3`
oo00l?o`03<0l?o`0@3oool006<0oooo00<000000?3ol03`oo005P3`oo0010000?l0l?o`0?3ol000
0?l;0?3ol0030000o`3`oo00l?o`0080l?o`00<0003o0?3ol03`oo00<`3`oo010?ooo`00H`3oool0
0`000000l?o`0?3ol00F0?3ol0050000o`3`oo00l?o`0?3ol0000?l02P3`oo000`000?l0l?o`0?3o
l0020?3ol0030000o`3`oo00l?o`03<0l?o`0@3oool006<0oooo00<000000?3ol03`oo005P3`oo00
1@000?l0l?o`0?3ol03`oo00003o00X0l?o`00<0003o0?3ol03`oo000P3`oo000`000?l0l?o`0?3o
l00c0?3ol040oooo001S0?ooo`030000003`oo00l?o`01H0l?o`00D0003o0?3ol03`oo00l?o`0000
o`0:0?3ol0030000o`3`oo00l?o`0080l?o`00<0003o0?3ol03`oo00<`3`oo010?ooo`00H`3oool0
0`000000l?o`0?3ol00E0?3ol0030000o`3`oo00l?o`0080l?o`00<0003o0?3ol03`oo00203`oo00
0`000?l0l?o`0?3ol0020?3ol0030000o`3`oo00l?o`03<0l?o`0@3oool006<0oooo00<000000?3o
l03`oo005@3`oo000`000?l0l?o`0?3ol0020?3ol0030000o`3`oo00l?o`00P0l?o`00<0003o0?3o
l03`oo000`3`oo000`000?l0l?o`0?3ol00b0?3ol040oooo001S0?ooo`030000003`oo00l?o`01D0
l?o`00<0003o0?3ol03`oo000P3`oo000`000?l0l?o`0?3ol0070?3ol0030000o`3`oo00l?o`00@0
l?o`00<0003o0?3ol03`oo00<P3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00E0?3ol0030000
o`3`oo00l?o`0080l?o`00<0003o0?3ol03`oo001`3`oo000`000?l0l?o`0?3ol0040?3ol0030000
o`3`oo00l?o`0380l?o`0@3oool006<0oooo00<000000?3ol03`oo005@3`oo000`000?l0l?o`0?3o
l0020?3ol0030000o`3`oo00l?o`00L0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3o
l00b0?3ol040oooo001S0?ooo`030000003`oo00l?o`01D0l?o`00<0003o0?3ol03`oo000P3`oo00
0`000?l0l?o`0?3ol0070?3ol0030000o`3`oo00l?o`00@0l?o`00<0003o0?3ol03`oo00<P3`oo01
0?ooo`00H`3oool00`000000l?o`0?3ol0080?3ol080003o2`3`oo000`000?l0l?o`0?3ol0020?3o
l0030000o`3`oo00l?o`00L0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3ol00b0?3o
l040oooo001S0?ooo`030000003`oo00l?o`00L0l?o`0P000?l00`3`oo00003o0?3ol0080?3ol003
0000o`3`oo00l?o`00<0l?o`00<0003o0?3ol03`oo001`3`oo000`000?l0l?o`0?3ol0040?3ol003
0000o`3`oo00l?o`0380l?o`0@3oool006<0oooo00<000000?3ol03`oo001`3`oo0010000?l0l?o`
0?3ol0000?l90?3ol0030000o`3`oo00l?o`00@0l?o`00<0003o0?3ol03`oo001P3`oo000`000?l0
l?o`0?3ol0040?3ol0030000o`3`oo00l?o`0380l?o`0@3oool006<0oooo00<000000?3ol03`oo00
1`3`oo001@000?l0l?o`0?3ol03`oo00003o00P0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0
l?o`0?3ol0060?3ol0030000o`3`oo00l?o`00@0l?o`00<0003o0?3ol03`oo00<P3`oo010?ooo`00
H`3oool00`000000l?o`0?3ol0060?3ol0030000o`3`oo00l?o`0080l?o`00<0003o0?3ol03`oo00
1P3`oo000`000?l0l?o`0?3ol0040?3ol0030000o`3`oo00l?o`00H0l?o`00<0003o0?3ol03`oo00
103`oo000`000?l0l?o`0?3ol00b0?3ol040oooo001S0?ooo`030000003`oo00l?o`00H0l?o`00<0
003o0?3ol03`oo000P3`oo000`000?l0l?o`0?3ol0060?3ol0030000o`3`oo00l?o`00@0l?o`00<0
003o0?3ol03`oo001P3`oo000`000?l0l?o`0?3ol0040?3ol0030000o`3`oo00l?o`0380l?o`0@3o
ool006<0oooo00<000000?3ol03`oo001@3`oo000`000?l0l?o`0?3ol0030?3ol0030000o`3`oo00
l?o`00H0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3ol0060?3ol0030000o`3`oo00
l?o`00@0l?o`00<0003o0?3ol03`oo00<P3`oo010?ooo`00EP3oool7000000@0oooo0`000?l70?3o
l0030000o`3`oo00l?o`00<0l?o`00<0003o0?3ol03`oo001P3`oo000`000?l0l?o`0?3ol0040?3o
l0030000o`3`oo00l?o`00H0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3ol00b0?3o
l040oooo001H0?ooo`030000003oool0000000D0oooo1@000?l60?3ol0030000o`3`oo00l?o`00@0
l?o`00<0003o0?3ol03`oo001@3`oo000`000?l0l?o`0?3ol0040?3ol0030000o`3`oo00l?o`00H0
l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3ol00b0?3ol040oooo001H0?ooo`030000
003oool0000000D0oooo1@000?l50?3ol0030000o`3`oo00l?o`00D0l?o`00<0003o0?3ol03`oo00
103`oo000`000?l0l?o`0?3ol0050?3ol0030000o`3`oo00l?o`00H0l?o`00<0003o0?3ol03`oo00
103`oo000`000?l0l?o`0?3ol00b0?3ol040oooo001H0?ooo`030000003oool0000000D0oooo1P00
0?l40?3ol0030000o`3`oo00l?o`00D0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3o
l0050?3ol0030000o`3`oo00l?o`00H0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3o
l00b0?3ol040oooo001H0?ooo`030000003oool0000000H0oooo0`000?l20?3ol0040000o`3`oo00
l?o`0000o`P0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3ol0050?3ol0030000o`3`
oo00l?o`00D0l?o`00<0003o0?3ol03`oo001@3`oo000`000?l0l?o`0?3ol00b0?3ol040oooo001F
0?ooo`D00000203oool010000000l?o`0?3ol03`oo030000o`P0l?o`00<0003o0?3ol03`oo00103`
oo000`000?l0l?o`0?3ol0050?3ol0030000o`3`oo00l?o`00D0l?o`00<0003o0?3ol03`oo001@3`
oo000`000?l0l?o`0?3ol00b0?3ol040oooo001S0?ooo`030000003`oo00l?o`00d0l?o`00<0003o
0?3ol03`oo000`3`oo000`000?l0l?o`0?3ol0060?3ol0030000o`3`oo00l?o`00@0l?o`00<0003o
0?3ol03`oo001P3`oo000`000?l0l?o`0?3ol00a0?3ol040oooo001I0?ooo`030000003oool0oooo
00L0oooo00<000000?3ol03`oo003@3`oo000`000?l0l?o`0?3ol0030?3ol0030000o`3`oo00l?o`
00H0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3ol0060?3ol0030000o`3`oo00l?o`
0340l?o`0@3oool006<0oooo00<000000?3ol03`oo003@3`oo000`000?l0l?o`0?3ol0030?3ol003
0000o`3`oo00l?o`00H0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3ol0060?3ol003
0000o`3`oo00l?o`0340l?o`0@3oool006<0oooo00<000000?3ol03`oo003@3`oo000`000?l0l?o`
0?3ol0030?3ol0030000o`3`oo00l?o`00H0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`
0?3ol0060?3ol0030000o`3`oo00l?o`0340l?o`0@3oool006<0oooo00<000000?3ol03`oo003@3`
oo000`000?l0l?o`0?3ol0020?3ol0030000o`3`oo00l?o`00L0l?o`00<0003o0?3ol03`oo00103`
oo000`000?l0l?o`0?3ol0060?3ol0030000o`3`oo00l?o`0340l?o`0@3oool006<0oooo00<00000
0?3ol03`oo003P3`oo001@000?l0l?o`0?3ol03`oo00003o00T0l?o`00<0003o0?3ol03`oo00103`
oo000`000?l0l?o`0?3ol0060?3ol0030000o`3`oo00l?o`0340l?o`0@3oool006<0oooo00<00000
0?3ol03`oo003P3`oo001@000?l0l?o`0?3ol03`oo00003o00T0l?o`00<0003o0?3ol03`oo00103`
oo000`000?l0l?o`0?3ol0060?3ol0030000o`3`oo00l?o`0340l?o`0@3oool006<0oooo00<00000
0?3ol03`oo003P3`oo001@000?l0l?o`0?3ol03`oo00003o00T0l?o`00<0003o0?3ol03`oo00103`
oo000`000?l0l?o`0?3ol0060?3ol0030000o`3`oo00l?o`0340l?o`0@3oool006<0oooo00<00000
0?3ol03`oo003P3`oo001@000?l0l?o`0?3ol03`oo00003o00T0l?o`00<0003o0?3ol03`oo00103`
oo000`000?l0l?o`0?3ol0060?3ol0030000o`3`oo00l?o`0340l?o`0@3oool006<0oooo00<00000
0?3ol03`oo003`3`oo0010000?l0l?o`0?3ol0000?l:0?3ol0030000o`3`oo00l?o`00<0l?o`00<0
003o0?3ol03`oo001P3`oo000`000?l0l?o`0?3ol00a0?3ol040oooo001S0?ooo`030000003`oo00
l?o`00l0l?o`00@0003o0?3ol03`oo00003o2P3`oo000`000?l0l?o`0?3ol0030?3ol0030000o`3`
oo00l?o`00H0l?o`00<0003o0?3ol03`oo00<@3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00?
0?3ol0030000o`3`oo00003o00/0l?o`00<0003o0?3ol03`oo000`3`oo000`000?l0l?o`0?3ol006
0?3ol0030000o`3`oo00l?o`0340l?o`0@3oool006<0oooo00<000000?3ol03`oo00403`oo020000
o`/0l?o`00<0003o0?3ol03`oo000P3`oo000`000?l0l?o`0?3ol0070?3ol0030000o`3`oo00l?o`
0340l?o`0@3oool006<0oooo00<000000?3ol03`oo007@3`oo000`000?l0l?o`0?3ol0020?3ol003
0000o`3`oo00l?o`00L0l?o`00<0003o0?3ol03`oo00<@3`oo010?ooo`00H`3oool00`000000l?o`
0?3ol00M0?3ol0030000o`3`oo00l?o`0080l?o`00<0003o0?3ol03`oo001`3`oo000`000?l0l?o`
0?3ol00a0?3ol040oooo001S0?ooo`030000003`oo00l?o`01h0l?o`00D0003o0?3ol03`oo00l?o`
0000o`090?3ol0030000o`3`oo00l?o`0340l?o`0@3oool006<0oooo00<000000?3ol03`oo007P3`
oo001@000?l0l?o`0?3ol03`oo00003o00T0l?o`00<0003o0?3ol03`oo00<@3`oo010?ooo`00H`3o
ool00`000000l?o`0?3ol00N0?3ol0050000o`3`oo00l?o`0?3ol0000?l02P3`oo000`000?l0l?o`
0?3ol00`0?3ol040oooo001S0?ooo`030000003`oo00l?o`01h0l?o`00D0003o0?3ol03`oo00l?o`
0000o`0:0?3ol0030000o`3`oo00l?o`0300l?o`0@3oool006<0oooo00<000000?3ol03`oo007P3`
oo001@000?l0l?o`0?3ol03`oo00003o00X0l?o`00<0003o0?3ol03`oo00<03`oo010?ooo`00H`3o
ool00`000000l?o`0?3ol00N0?3ol0050000o`3`oo00l?o`0?3ol0000?l02P3`oo000`000?l0l?o`
0?3ol00`0?3ol040oooo001S0?ooo`030000003`oo00l?o`01h0l?o`00@0003o0?3ol03`oo00003o
2`3`oo000`000?l0l?o`0?3ol00`0?3ol040oooo001S0?ooo`030000003`oo00l?o`01h0l?o`00@0
003o0?3ol03`oo00003o2`3`oo000`000?l0l?o`0?3ol00`0?3ol040oooo001S0?ooo`030000003`
oo00l?o`01h0l?o`00@0003o0?3ol03`oo00003o2`3`oo000`000?l0l?o`0?3ol00`0?3ol040oooo
001S0?ooo`030000003`oo00l?o`01h0l?o`00@0003o0?3ol03`oo00003o2`3`oo000`000?l0l?o`
0?3ol00`0?3ol040oooo001S0?ooo`030000003`oo00l?o`01h0l?o`00@0003o0?3ol03`oo00003o
2`3`oo000`000?l0l?o`0?3ol00`0?3ol040oooo001S0?ooo`030000003`oo00l?o`01l0l?o`00<0
003o0?3ol0000?l02`3`oo000`000?l0l?o`0?3ol00`0?3ol040oooo001S0?ooo`030000003`oo00
l?o`01l0l?o`00<0003o0?3ol0000?l02`3`oo000`000?l0l?o`0?3ol00`0?3ol040oooo001S0?oo
o`030000003`oo00l?o`01l0l?o`0P000?l<0?3ol0030000o`3`oo00l?o`0300l?o`0@3oool006<0
oooo00<000000?3ol03`oo007`3`oo020000o``0l?o`00<0003o0?3ol03`oo00<03`oo010?ooo`00
H`3oool00`000000l?o`0?3ol00]0?3ol0030000o`3`oo00l?o`0300l?o`0@3oool006<0oooo00<0
00000?3ol03`oo00;@3`oo000`000?l0l?o`0?3ol00`0?3ol040oooo001S0?ooo`030000003`oo00
l?o`02h0l?o`00<0003o0?3ol03`oo00;`3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00^0?3o
l0030000o`3`oo00l?o`02l0l?o`0@3oool006<0oooo00<000000?3ol03`oo00;P3`oo000`000?l0
l?o`0?3ol00_0?3ol040oooo001S0?ooo`030000003`oo00l?o`02h0l?o`00<0003o0?3ol03`oo00
;`3`oo010?ooo`00H`3oool00`000000l?o`0?3ol00^0?3ol0030000o`3`oo00l?o`02l0l?o`0@3o
ool006<0oooo00<000000?3ol03`oo00;P3`oo000`000?l0l?o`0?3ol00_0?3ol040oooo001S0?oo
o`030000003`oo00l?o`02h0l?o`00<0003o0?3ol03`oo00;`3`oo010?ooo`00H`3oool00`000000
l?o`0?3ol00^0?3ol0030000o`3`oo00l?o`02l0l?o`0@3oool006<0oooo00<000000?3ol03`oo00
0`3`oo000`000000l?o`0?3ol00X0?3ol0030000o`3`oo00l?o`02l0l?o`0@3oool006<0oooo00<0
00000?3ol03`oo000P3`oo000`000000l?o`0000000Y0?3ol0030000o`3`oo00l?o`02l0l?o`0@3o
ool006<0oooo00<000000?3ol03`oo000P3`oo000`000000l?o`0000001K0?3ol040oooo001S0?oo
o`050000003`oo00l?o`0?3ol00000000`3`oo000`000000l?o`0?3ol01H0?3ol040oooo001S0?oo
o`050000003`oo00l?o`0?3ol00000000`3`oo000`000000l?o`0?3ol01H0?3ol040oooo001S0?oo
o`030000003`oo00l?o`00<0000000@0l?o`0000000000000000F@3`oo010?ooo`00\
\>"],
    ImageRangeCache->{{{0, 198}, {198, 0}} -> {-2, -2, 0, 0}}],
  StyleBox["   \n\t\t\t\t(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The branch  ",
  Cell[BoxData[
      \(w = \(\(f\_1\) \((z)\) = \@z\)\)]],
  "    (where   ",
  Cell[BoxData[
      \(z = w\^2\)]],
  ").   "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.941 1 .941 r
0 .5 m
0 0 L
1 0 L
1 1 L
0 1 L
0 .5 L
F
1 1 1 r
0 .5 m
0 .49 L
.5 .49 L
.5 .51 L
0 .51 L
0 .5 L
F
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.25 .5 m
.25 .49957 L
.24999 .49917 L
.24998 .49872 L
.24997 .49829 L
.24995 .4979 L
.24992 .49753 L
.24985 .4967 L
.24976 .49586 L
.24962 .49494 L
.24925 .49308 L
.24875 .49125 L
.24806 .48928 L
.24644 .4857 L
.2411 .4773 L
.23499 .46939 L
.22881 .4611 L
.2263 .45704 L
.22453 .45336 L
.22386 .45152 L
.22358 .45055 L
.22333 .44954 L
.22317 .44865 L
.2231 .44818 L
.22304 .44768 L
.223 .44722 L
.22297 .4468 L
.22296 .44638 L
.22296 .44599 L
.22297 .44554 L
.22299 .44506 L
.22304 .44455 L
.2231 .44408 L
.22325 .44323 L
.22347 .44233 L
.22379 .44134 L
.22421 .44031 L
.22519 .43849 L
.22649 .43667 L
.22795 .43506 L
.23217 .43159 L
.23723 .42858 L
.24298 .42593 L
.25022 .42327 L
.25884 .42073 L
.27606 .41682 L
.31277 .41083 L
.32209 .40932 L
.32996 .40781 L
.33603 .40633 L
Mistroke
.33902 .4054 L
.3414 .40448 L
.34355 .40344 L
.34522 .40237 L
.34661 .40114 L
.3472 .40039 L
.34764 .39967 L
.34778 .39936 L
.34792 .39902 L
.34802 .39872 L
.3481 .39839 L
.34818 .398 L
.34822 .39761 L
.34824 .39723 L
.34823 .39687 L
.3482 .39648 L
.34815 .39612 L
.34808 .3957 L
.34796 .39525 L
.34764 .3943 L
.34723 .39338 L
.34608 .39144 L
.34437 .38919 L
.33998 .38467 L
.32354 .37206 L
.26391 .33707 L
.18407 .2952 L
.14853 .27591 L
.13101 .26559 L
.11732 .25663 L
.10629 .248 L
.10282 .2446 L
.10006 .24117 L
.09902 .23943 L
.09867 .2387 L
.09836 .23791 L
.09815 .23719 L
.09801 .23653 L
.09794 .23585 L
.09794 .23515 L
.09803 .23448 L
.09812 .2341 L
.09823 .23376 L
.09852 .2331 L
.09894 .23243 L
.09944 .23183 L
.1 .23129 L
.10129 .23036 L
.10282 .22956 L
.10451 .22889 L
Mistroke
.10666 .22825 L
.10931 .22768 L
.11076 .22744 L
.11244 .22721 L
.11401 .22703 L
.11577 .22688 L
.1176 .22675 L
.11934 .22667 L
.12115 .22661 L
.12292 .22658 L
.12463 .22657 L
.12657 .22659 L
.12867 .22663 L
.13068 .22669 L
.13262 .22677 L
.13444 .22686 L
.13867 .22712 L
.1489 .22803 L
.15948 .22928 L
.18391 .2331 L
.21286 .23888 L
.26966 .25334 L
.38438 .29425 L
.43223 .3169 L
.47132 .33851 L
.49599 .35309 L
.50452 .35752 L
.50642 .3583 L
.50727 .3586 L
.50799 .35882 L
.5086 .35898 L
.50922 .35911 L
.50953 .35915 L
.5098 .35918 L
.51007 .3592 L
.51036 .35921 L
.5106 .3592 L
.51085 .35918 L
.51125 .35911 L
.51148 .35904 L
.51168 .35896 L
.51185 .35887 L
.51202 .35876 L
.51229 .35852 L
.51241 .35838 L
.51253 .35821 L
.51271 .35787 L
.51283 .3575 L
.51291 .35707 L
.51295 .35661 L
Mistroke
.51294 .35616 L
.5129 .35563 L
.51282 .355 L
.51275 .35466 L
.51267 .35428 L
.51228 .35283 L
.51099 .34946 L
.50883 .345 L
.5027 .33473 L
.4764 .30068 L
.43245 .2556 L
.29253 .14522 L
.09456 .01981 L
Mfstroke
.09456 .01981 m
.06318 0 L
s
1 0 0 r
.25 .5 m
.25 .50043 L
.24999 .50083 L
.24998 .50128 L
.24997 .50171 L
.24995 .5021 L
.24992 .50247 L
.24985 .5033 L
.24976 .50414 L
.24962 .50506 L
.24925 .50692 L
.24875 .50875 L
.24806 .51072 L
.24644 .5143 L
.2411 .5227 L
.23499 .53061 L
.22881 .5389 L
.2263 .54296 L
.22453 .54664 L
.22386 .54848 L
.22358 .54945 L
.22333 .55046 L
.22317 .55135 L
.2231 .55182 L
.22304 .55232 L
.223 .55278 L
.22297 .5532 L
.22296 .55362 L
.22296 .55401 L
.22297 .55446 L
.22299 .55494 L
.22304 .55545 L
.2231 .55592 L
.22325 .55677 L
.22347 .55767 L
.22379 .55866 L
.22421 .55969 L
.22519 .56151 L
.22649 .56333 L
.22795 .56494 L
.23217 .56841 L
.23723 .57142 L
.24298 .57407 L
.25022 .57673 L
.25884 .57927 L
.27606 .58318 L
.31277 .58917 L
.32209 .59068 L
.32996 .59219 L
.33603 .59367 L
Mistroke
.33902 .5946 L
.3414 .59552 L
.34355 .59656 L
.34522 .59763 L
.34661 .59886 L
.3472 .59961 L
.34764 .60033 L
.34778 .60064 L
.34792 .60098 L
.34802 .60128 L
.3481 .60161 L
.34818 .602 L
.34822 .60239 L
.34824 .60277 L
.34823 .60313 L
.3482 .60352 L
.34815 .60388 L
.34808 .6043 L
.34796 .60475 L
.34764 .6057 L
.34723 .60662 L
.34608 .60856 L
.34437 .61081 L
.33998 .61533 L
.32354 .62794 L
.26391 .66293 L
.18407 .7048 L
.14853 .72409 L
.13101 .73441 L
.11732 .74337 L
.10629 .752 L
.10282 .7554 L
.10006 .75883 L
.09902 .76057 L
.09867 .7613 L
.09836 .76209 L
.09815 .76281 L
.09801 .76347 L
.09794 .76415 L
.09794 .76485 L
.09803 .76552 L
.09812 .7659 L
.09823 .76624 L
.09852 .7669 L
.09894 .76757 L
.09944 .76817 L
.1 .76871 L
.10129 .76964 L
.10282 .77044 L
.10451 .77111 L
Mistroke
.10666 .77175 L
.10931 .77232 L
.11076 .77256 L
.11244 .77279 L
.11401 .77297 L
.11577 .77312 L
.1176 .77325 L
.11934 .77333 L
.12115 .77339 L
.12292 .77342 L
.12463 .77343 L
.12657 .77341 L
.12867 .77337 L
.13068 .77331 L
.13262 .77323 L
.13444 .77314 L
.13867 .77288 L
.1489 .77197 L
.15948 .77072 L
.18391 .7669 L
.21286 .76112 L
.26966 .74666 L
.38438 .70575 L
.43223 .6831 L
.47132 .66149 L
.49599 .64691 L
.50452 .64248 L
.50642 .6417 L
.50727 .6414 L
.50799 .64118 L
.5086 .64102 L
.50922 .64089 L
.50953 .64085 L
.5098 .64082 L
.51007 .6408 L
.51036 .64079 L
.5106 .6408 L
.51085 .64082 L
.51125 .64089 L
.51148 .64096 L
.51168 .64104 L
.51185 .64113 L
.51202 .64124 L
.51229 .64148 L
.51241 .64162 L
.51253 .64179 L
.51271 .64213 L
.51283 .6425 L
.51291 .64293 L
.51295 .64339 L
Mistroke
.51294 .64384 L
.5129 .64437 L
.51282 .645 L
.51275 .64534 L
.51267 .64572 L
.51228 .64717 L
.51099 .65054 L
.50883 .655 L
.5027 .66527 L
.4764 .69932 L
.43245 .7444 L
.29253 .85478 L
.09456 .98019 L
Mfstroke
.09456 .98019 m
.06318 1 L
s
0 g
.5 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
0 .51 m
.5 .51 L
s
[ .02 .02 ] 0 setdash
0 .49 m
.5 .49 L
s
0 1 0 r
.03 w
.25 .5 Mdot
0 g
gsave
.98 .525 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5375 .98 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.28 .525 -70.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{199, 199},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000370000ab000`400?l00000o`00003o303oool0
0`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo0640oooo000=0?3ol080003oE03`oo000`00
0000l?o`0?3ol01P0?3ol040oooo000?0?3ol0030000o`3`oo00l?o`0540l?o`00<000000?3ol03`
oo00H03`oo010?ooo`00403`oo020000oe40l?o`00<000000?3ol03`oo00H03`oo010?ooo`004P3`
oo000`000?l0l?o`0?3ol01>0?3ol0030000003`oo00l?o`0600l?o`0@3oool001<0l?o`0P000?m>
0?3ol0030000003`oo00l?o`0600l?o`0@3oool001D0l?o`00<0003o0?3ol03`oo00B`3`oo000`00
0000l?o`0?3ol01P0?3ol040oooo000F0?3ol080003oB`3`oo000`000000l?o`0?3ol01P0?3ol040
oooo000H0?3ol080003oB@3`oo000`000000l?o`0?3ol01P0?3ol040oooo000J0?3ol0030000o`3`
oo00l?o`04H0l?o`00<000000?3ol03`oo00H03`oo010?ooo`006`3`oo020000odH0l?o`00<00000
0?3ol03`oo00H03`oo010?ooo`007@3`oo000`000?l0l?o`0?3ol0130?3ol0030000003`oo00l?o`
0600l?o`0@3oool001h0l?o`0P000?m30?3ol0030000003`oo00l?o`0600l?o`0@3oool00200l?o`
00<0003o0?3ol03`oo00@03`oo000`000000l?o`0?3ol01P0?3ol040oooo000Q0?3ol080003o@03`
oo000`000000l?o`0?3ol01P0?3ol040oooo000S0?3ol0030000o`3`oo00l?o`03d0l?o`00<00000
0?3ol03`oo00H03`oo010?ooo`00903`oo020000ocd0l?o`00<000000?3ol03`oo00H03`oo010?oo
o`009P3`oo020000oc/0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00:03`oo000`000?l0l?o`
0?3ol00h0?3ol0030000003`oo00l?o`0600l?o`0@3oool002T0l?o`0P000?lh0?3ol0030000003`
oo00l?o`0600l?o`0@3oool002/0l?o`00<0003o0?3ol03`oo00=@3`oo000`000000l?o`0?3ol01P
0?3ol040oooo000/0?3ol080003o=@3`oo000`000000l?o`0?3ol01P0?3ol040oooo000^0?3ol003
0000o`3`oo00l?o`0380l?o`00<000000?3ol03`oo00H03`oo010?ooo`00;`3`oo020000oc80l?o`
00<000000?3ol03`oo00H03`oo010?ooo`00<@3`oo000`000?l0l?o`0?3ol00_0?3ol0030000003`
oo00l?o`0600l?o`0@3oool00380l?o`0P000?l_0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
03@0l?o`0P000?l]0?3ol0030000003`oo00l?o`0600l?o`0@3oool003H0l?o`00<0003o0?3ol03`
oo00:P3`oo000`000000l?o`0?3ol01P0?3ol040oooo000g0?3ol080003o:P3`oo000`000000l?o`
0?3ol01P0?3ol040oooo000i0?3ol0030000o`3`oo00l?o`02L0l?o`00<000000?3ol03`oo00H03`
oo010?ooo`00>P3`oo000`000?l0l?o`0?3ol00V0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
03/0l?o`0P000?lV0?3ol0030000003`oo00l?o`0600l?o`0@3oool003d0l?o`00<0003o0?3ol03`
oo008`3`oo000`000000l?o`0?3ol01P0?3ol040oooo000n0?3ol0030000o`3`oo00l?o`0280l?o`
00<000000?3ol03`oo00H03`oo010?ooo`00?`3`oo000`000?l0l?o`0?3ol00Q0?3ol0030000003`
oo00l?o`0600l?o`0@3oool00400l?o`0P000?lQ0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
0480l?o`00<0003o0?3ol03`oo007P3`oo000`000000l?o`0?3ol01P0?3ol040oooo00130?3ol003
0000o`3`oo00l?o`01d0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00A03`oo020000oad0l?o`
00<000000?3ol03`oo00H03`oo010?ooo`00AP3`oo000`000?l0l?o`0?3ol00J0?3ol0030000003`
oo00l?o`0600l?o`0@3oool004L0l?o`00<0003o0?3ol03`oo006@3`oo000`000000l?o`0?3ol01P
0?3ol040oooo00180?3ol0030000o`3`oo00l?o`01P0l?o`00<000000?3ol03`oo00H03`oo010?oo
o`00B@3`oo020000oaP0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00B`3`oo000`000?l0l?o`
0?3ol00E0?3ol0030000003`oo00l?o`0600l?o`0@3oool004`0l?o`00<0003o0?3ol03`oo00503`
oo000`000000l?o`0?3ol01P0?3ol040oooo000F0?3ol0H0003o<@3`oo000`000?l0l?o`0?3ol00C
0?3ol0030000003`oo00l?o`0600l?o`0@3oool001<0l?o`0`000?l60?3ol0H0003o;03`oo020000
oa<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`004`3`oo000`000?l0l?o`0?3ol00<0?3ol0D0
003o:@3`oo000`000?l0l?o`0?3ol00@0?3ol0030000003`oo00l?o`0600l?o`0@3oool001<0l?o`
00<0003o0?3ol03`oo004@3`oo050000obD0l?o`00<0003o0?3ol03`oo003`3`oo000`000000l?o`
0?3ol01P0?3ol040oooo000D0?3ol0030000o`3`oo00l?o`01D0l?o`10000?lR0?3ol080003o3`3`
oo000`000000l?o`0?3ol01P0?3ol040oooo000E0?3ol0030000o`3`oo00l?o`01P0l?o`10000?lP
0?3ol0030000o`3`oo00l?o`00`0l?o`00<000000?3ol03`oo00H03`oo010?ooo`005P3`oo020000
oa`0l?o`0`000?lN0?3ol0030000o`3`oo00l?o`00/0l?o`00<000000?3ol03`oo00H03`oo010?oo
o`00603`oo000`000?l0l?o`0?3ol00L0?3ol0<0003o703`oo000`000?l0l?o`0?3ol00:0?3ol003
0000003`oo00l?o`0600l?o`0@3oool001T0l?o`00<0003o0?3ol03`oo007P3`oo030000oaX0l?o`
00<0003o0?3ol03`oo002@3`oo000`000000l?o`0?3ol01P0?3ol040oooo000J0?3ol080003o8@3`
oo030000oaP0l?o`00<0003o0?3ol03`oo00203`oo000`000000l?o`0?3ol01P0?3ol040oooo000L
0?3ol080003o8P3`oo020000oaL0l?o`00<0003o0?3ol03`oo001`3`oo000`000000l?o`0?3ol01P
0?3ol040oooo000N0?3ol080003o8P3`oo030000oaD0l?o`00<0003o0?3ol03`oo001P3`oo000`00
0000l?o`0?3ol01P0?3ol040oooo000P0?3ol080003o8`3`oo030000oa<0l?o`00<0003o0?3ol03`
oo001@3`oo000`000000l?o`0?3ol01P0?3ol040oooo000R0?3ol080003o903`oo030000oa40l?o`
00<0003o0?3ol03`oo00103`oo000`000000l?o`0?3ol01P0?3ol040oooo000T0?3ol0030000o`3`
oo00l?o`02@0l?o`0`000?l?0?3ol0030000o`3`oo00l?o`00<0l?o`00<000000?3ol03`oo00H03`
oo010?ooo`009@3`oo020000obL0l?o`0P000?l>0?3ol0030000o`3`oo00l?o`0080l?o`00<00000
0?3ol03`oo00H03`oo010?ooo`009`3`oo020000obL0l?o`0P000?l=0?3ol0050000o`3`oo00l?o`
0?3ol0000000HP3`oo010?ooo`00:@3`oo020000obL0l?o`0P000?l;0?3ol0050000o`3`oo00l?o`
0?3ol0000000HP3`oo010?ooo`00:`3`oo020000obL0l?o`0P000?l:0?3ol0040000o`3`oo00l?o`
00000680l?o`0@3oool002d0l?o`0P000?lW0?3ol080003o2@3`oo000`000?l0l?o`0000001R0?3o
l040oooo000_0?3ol080003o9`3`oo000`000?l0l?o`0?3ol0070?3ol0030000o`000000l?o`0640
l?o`0@3oool00340l?o`0P000?lV0?3ol080003o1`3`oo000`000?l000000?3ol01Q0?3ol040oooo
000c0?3ol080003o9P3`oo020000o`H0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00=@3`oo02
0000obH0l?o`0P000?l40?3ol0030000003`oo00l?o`0600l?o`0@3oool003L0l?o`0P000?lV0?3o
l080003o0P3`oo000`000000003o0?3ol01P0?3ol040oooo000i0?3ol0030000o`3`oo00l?o`02D0
l?o`0P000?l00`000000l?o`0000o`1P0?3ol040oooo000j0?3ol080003o9`3`oo000`000000003o
0000o`1P0?3ol040oooo000l0?3ol080003o9@3`oo000`000000003o0000o`1P0?3ol040oooo000n
0?3ol080003o8`3`oo000`000000l?o`0?3ol01P0?3ol040oooo00100?3ol0030000o`3`oo00l?o`
0200l?o`00<000000?3ol03`oo00H03`oo010?ooo`00@@3`oo000`000?l0l?o`0?3ol00O0?3ol003
0000003`oo00l?o`0600l?o`0@3oool00480l?o`00<0003o0?3ol03`oo007P3`oo000`000000l?o`
0?3ol01P0?3ol040oooo00130?3ol0030000o`3`oo00l?o`01d0l?o`00<000000?3ol03`oo00H03`
oo010?ooo`00A03`oo000`000?l0l?o`0?3ol00L0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
04@0l?o`00<0003o0?3ol03`oo00703`oo000`000000l?o`0?3ol01P0?3ol040oooo00140?3ol003
0000o`3`oo00l?o`01`0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00@@3`oo030000oal0l?o`
00<000000?3ol03`oo00H03`oo010?ooo`00>P3`oo070000ob80l?o`00<000000?3ol03`oo00H03`
oo010?ooo`00=@3`oo050000obT0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00<@3`oo040000
obh0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00;P3`oo030000oc80l?o`00<000000?3ol03`
oo00H03`oo010?ooo`00;@3`oo000`000?l0l?o`0?3ol00c0?3ol0030000003`oo00l?o`0600l?o`
0@3oool002`0l?o`0P000?le0?3ol0030000003`oo00l?o`0600l?o`0@3oool002`0l?o`00<0003o
0?3ol03`oo00=03`oo000`000000l?o`0?3ol01P0?3ol040oooo000/0?3ol0030000o`3`oo00l?o`
03@0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00;03`oo000`000?l0l?o`0?3ol00d0?3ol003
0000003`oo00l?o`0600l?o`0@3oool002`0l?o`00<0003o0?3ol03`oo00=03`oo000`000000l?o`
0?3ol01P0?3ol040oooo000]0?3ol0030000o`3`oo00l?o`03<0l?o`00<000000?3ol03`oo00H03`
oo010?ooo`00;P3`oo000`000?l0l?o`0?3ol00b0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
02h0l?o`00<0003o0?3ol03`oo00<P3`oo000`000000l?o`0?3ol01P0?3ol040oooo000_0?3ol003
0000o`3`oo00l?o`0340l?o`00<000000?3ol03`oo00H03`oo010?ooo`00;`3`oo000`000?l0l?o`
0?3ol00a0?3ol0030000003`oo00l?o`0600l?o`0@3oool00300l?o`0P000?la0?3ol0030000003`
oo00l?o`0600l?o`0@3oool000@000000`3`oo05000000<0l?o`1@0000030?3ol0D000000`3`oo05
000000<0l?o`1@0000030?3ol00500000000o`000?l0003o000000000`3`oo05000000<0l?o`1@00
00030?3ol0D000000`3`oo05000000<0l?o`1@0000030?3ol0D00000HP3`oo010?ooo`00;`3oool5
003o02l0ooooI000000002l0oooo1@00o`0_0?ooo`030000003`oo00l?o`0600l?o`0@3oool002l0
00001@00o`0`00000680l?o`0@3oool00300l?o`0`00o`0`0?3ol0030000003`oo00l?o`0600l?o`
0@3oool002l0l?o`00<0o`000?3ol03`oo001P3`oo05000002H0l?o`00<000000?3ol03`oo00F03`
oo0200000080l?o`0P0000020?3ol040oooo000_0?3ol0030?l0003`oo00l?o`00P0l?o`00<00000
0?3ol03`oo009P3`oo000`000000l?o`0?3ol01I0?3ol0040000003`oo00l?o`000000<0l?o`0@3o
ool002h0l?o`00<0o`000?3ol03`oo001@0000040?3ol0030000003`oo00l?o`02H0l?o`00<00000
0?3ol03`oo00FP3`oo02000000@0l?o`0@3oool002h0l?o`00<0o`000?3ol03`oo002@3`oo000`00
0000l?o`0?3ol00V0?3ol0030000003`oo00l?o`05X0l?o`0P0000040?3ol040oooo000]0?3ol003
0?l0003`oo00l?o`00X0l?o`00<000000?3ol03`oo009P3`oo000`000000l?o`0?3ol01I0?3ol004
0000003`oo00l?o`000000<0l?o`0@3oool002`0l?o`00<0o`000?3ol03`oo002`3`oo000`000000
l?o`0?3ol00V0?3ol0030000003`oo00l?o`05P0l?o`0P0000020?3ol08000000P3`oo010?ooo`00
;03`oo000`3o0000l?o`0?3ol00;0?3ol0030000003`oo00l?o`02H0l?o`00<000000?3ol03`oo00
H03`oo010?ooo`00;03`oo000`3o0000l?o`0?3ol00:0?3ol0800000:03`oo000`000000l?o`0?3o
l01P0?3ol040oooo000/0?3ol0030?l0003`oo00l?o`03@0l?o`00<000000?3ol03`oo00H03`oo01
0?ooo`00;03`oo020?l003D0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00;@3`oo000`3o0000
l?o`0?3ol00c0?3ol0030000003`oo00l?o`0600l?o`0@3oool002h0l?o`0`3o000b0?3ol0030000
003`oo00l?o`0600l?o`0@3oool00340l?o`103o000^0?3ol0030000003`oo00l?o`0600l?o`0@3o
ool003D0l?o`1@3o000Y0?3ol0030000003`oo00l?o`0600l?o`0@3oool003X0l?o`1P3o000S0?3o
l0030000003`oo00l?o`0600l?o`0@3oool00400l?o`103o000O0?3ol0030000003`oo00l?o`0600
l?o`0@3oool004@0l?o`00<0o`000?3ol03`oo00703`oo000`000000l?o`0?3ol01P0?3ol040oooo
00140?3ol0030?l0003`oo00l?o`01`0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00A03`oo00
0`3o0000l?o`0?3ol00L0?3ol0030000003`oo00l?o`0600l?o`0@3oool004<0l?o`00<0o`000?3o
l03`oo007@3`oo000`000000l?o`0?3ol01P0?3ol040oooo00120?3ol0030?l0003`oo00l?o`01h0
l?o`00<000000?3ol03`oo00H03`oo010?ooo`00@@3`oo000`3o0000l?o`0?3ol00O0?3ol0030000
003`oo00l?o`0600l?o`0@3oool00400l?o`00<0o`000?3ol03`oo00803`oo000`000000l?o`0?3o
l01P0?3ol040oooo000n0?3ol080o`008`3`oo000`000000l?o`0?3ol01P0?3ol040oooo000l0?3o
l080o`009@3`oo000`000000o`000?l0001P0?3ol040oooo000k0?3ol0030?l0003`oo00l?o`02D0
l?o`00<000000?l0003o0000H03`oo010?ooo`00>@3`oo020?l002H0l?o`0P3o00000`000000l?o`
0?l0001P0?3ol040oooo000g0?3ol080o`009P3`oo020?l00080l?o`00<000000?l0003`oo00H03`
oo010?ooo`00=@3`oo020?l002H0l?o`0P3o00040?3ol0030000003`oo00l?o`0600l?o`0@3oool0
03@0l?o`00<0o`000?3ol03`oo00903`oo020?l000H0l?o`00<000000?3ol03`oo00H03`oo010?oo
o`00<P3`oo020?l002H0l?o`00<0o`000?3ol03`oo001@3`oo000`3o000000000?3ol01Q0?3ol040
oooo000`0?3ol080o`009P3`oo020?l000P0l?o`00<0o`000000003`oo00H@3`oo010?ooo`00;P3`
oo020?l002H0l?o`0P3o00090?3ol0030?l0003`oo0000000680l?o`0@3oool002`0l?o`0P3o000V
0?3ol080o`002P3`oo00103o0000l?o`0?3ol000001R0?3ol040oooo000Z0?3ol080o`009P3`oo02
0?l000/0l?o`00D0o`000?3ol03`oo00l?o`0000001R0?3ol040oooo000X0?3ol080o`009P3`oo02
0?l000d0l?o`00D0o`000?3ol03`oo00l?o`0000001R0?3ol040oooo000V0?3ol080o`009P3`oo02
0?l000h0l?o`00<0o`000?3ol03`oo000P3`oo000`000000l?o`0?3ol01P0?3ol040oooo000T0?3o
l080o`009@3`oo030?l000l0l?o`00<0o`000?3ol03`oo000`3`oo000`000000l?o`0?3ol01P0?3o
l040oooo000R0?3ol080o`00903`oo030?l00140l?o`00<0o`000?3ol03`oo00103`oo000`000000
l?o`0?3ol01P0?3ol040oooo000P0?3ol080o`008`3`oo030?l001<0l?o`00<0o`000?3ol03`oo00
1@3`oo000`000000l?o`0?3ol01P0?3ol040oooo000N0?3ol080o`008P3`oo030?l001D0l?o`00<0
o`000?3ol03`oo001P3`oo000`000000l?o`0?3ol01P0?3ol040oooo000M0?3ol0030?l0003`oo00
l?o`0200l?o`0P3o000G0?3ol0030?l0003`oo00l?o`00L0l?o`00<000000?3ol03`oo00H03`oo01
0?ooo`006`3`oo020?l00200l?o`0`3o000H0?3ol0030?l0003`oo00l?o`00P0l?o`00<000000?3o
l03`oo00H03`oo010?ooo`006@3`oo020?l001l0l?o`0`3o000J0?3ol0030?l0003`oo00l?o`00T0
l?o`00<000000?3ol03`oo00H03`oo010?ooo`00603`oo000`3o0000l?o`0?3ol00L0?3ol0<0o`00
703`oo000`3o0000l?o`0?3ol00:0?3ol0030000003`oo00l?o`0600l?o`0@3oool001L0l?o`00<0
o`000?3ol03`oo006P3`oo030?l001h0l?o`00<0o`000?3ol03`oo002`3`oo000`000000l?o`0?3o
l01P0?3ol040oooo000E0?3ol080o`006@3`oo040?l00200l?o`00<0o`000?3ol03`oo00303`oo00
0`000000l?o`0?3ol01P0?3ol040oooo000D0?3ol0030?l0003`oo00l?o`01D0l?o`103o000R0?3o
l080o`003`3`oo000`000000l?o`0?3ol01P0?3ol040oooo000C0?3ol0030?l0003`oo00l?o`0180
l?o`103o000U0?3ol0030?l0003`oo00l?o`00l0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00
4`3`oo000`3o0000l?o`0?3ol00<0?3ol0H0o`00:03`oo000`3o0000l?o`0?3ol00@0?3ol0030000
003`oo00l?o`0600l?o`0@3oool001<0l?o`0`3o00070?3ol0D0o`00;@3`oo000`3o0000l?o`0?3o
l00A0?3ol0030000003`oo00l?o`0600l?o`0@3oool001H0l?o`1`3o000`0?3ol080o`00503`oo00
0`000000l?o`0?3ol01P0?3ol040oooo001<0?3ol0030?l0003`oo00l?o`01@0l?o`00<000000?3o
l03`oo00H03`oo010?ooo`00B`3`oo000`3o0000l?o`0?3ol00E0?3ol0030000003`oo00l?o`0600
l?o`0@3oool004T0l?o`0P3o000H0?3ol0030000003`oo00l?o`0600l?o`0@3oool004P0l?o`00<0
o`000?3ol03`oo00603`oo000`000000l?o`0?3ol01P0?3ol040oooo00170?3ol0030?l0003`oo00
l?o`01T0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00AP3`oo000`3o0000l?o`0?3ol00J0?3o
l0030000003`oo00l?o`0600l?o`0@3oool004@0l?o`0P3o000M0?3ol0030000003`oo00l?o`0600
l?o`0@3oool004<0l?o`00<0o`000?3ol03`oo007@3`oo000`000000l?o`0?3ol01P0?3ol040oooo
00120?3ol0030?l0003`oo00l?o`01h0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00@@3`oo00
0`3o0000l?o`0?3ol00O0?3ol0030000003`oo00l?o`0600l?o`0@3oool003l0l?o`0P3o000R0?3o
l0030000003`oo00l?o`0600l?o`0@3oool003h0l?o`00<0o`000?3ol03`oo008P3`oo000`000000
l?o`0?3ol01P0?3ol040oooo000m0?3ol0030?l0003`oo00l?o`02<0l?o`00<000000?3ol03`oo00
H03`oo010?ooo`00>`3`oo020?l002H0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00>P3`oo00
0`3o0000l?o`0?3ol00V0?3ol0030000003`oo00l?o`0600l?o`0@3oool003T0l?o`00<0o`000?3o
l03`oo009`3`oo000`000000l?o`0?3ol01P0?3ol040oooo000g0?3ol080o`00:P3`oo000`000000
l?o`0?3ol01P0?3ol040oooo000f0?3ol0030?l0003`oo00l?o`02X0l?o`00<000000?3ol03`oo00
H03`oo010?ooo`00=03`oo020?l002d0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00<P3`oo02
0?l002l0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00<@3`oo000`3o0000l?o`0?3ol00_0?3o
l0030000003`oo00l?o`0600l?o`0@3oool002l0l?o`0P3o000b0?3ol0030000003`oo00l?o`0600
l?o`0@3oool002h0l?o`00<0o`000?3ol03`oo00<P3`oo000`000000l?o`0?3ol01P0?3ol040oooo
000/0?3ol080o`00=@3`oo000`000000l?o`0?3ol01P0?3ol040oooo000[0?3ol0030?l0003`oo00
l?o`03D0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00:@3`oo020?l003P0l?o`00<000000?3o
l03`oo00H03`oo010?ooo`00:03`oo000`3o0000l?o`0?3ol00h0?3ol0030000003`oo00l?o`0600
l?o`0@3oool002H0l?o`0P3o000k0?3ol0030000003`oo00l?o`0600l?o`0@3oool002@0l?o`0P3o
000m0?3ol0030000003`oo00l?o`0600l?o`0@3oool002<0l?o`00<0o`000?3ol03`oo00?@3`oo00
0`000000l?o`0?3ol01P0?3ol040oooo000Q0?3ol080o`00@03`oo000`000000l?o`0?3ol01P0?3o
l040oooo000P0?3ol0030?l0003`oo00l?o`0400l?o`00<000000?3ol03`oo00H03`oo010?ooo`00
7P3`oo020?l004<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`007@3`oo000`3o0000l?o`0?3o
l0130?3ol0030000003`oo00l?o`0600l?o`0@3oool001/0l?o`0P3o00160?3ol0030000003`oo00
l?o`0600l?o`0@3oool001X0l?o`00<0o`000?3ol03`oo00AP3`oo000`000000l?o`0?3ol01P0?3o
l040oooo000H0?3ol080o`00B@3`oo0010000000l?o`0?3ol03`oo04000005/0l?o`0@3oool001H0
l?o`0P3o001;0?3ol0030000003`oo00l?o`00<0l?o`00<000000?3ol03`oo00FP3`oo010?ooo`00
5@3`oo000`3o0000l?o`0?3ol01;0?3ol0030000003`oo00l?o`00<0l?o`00<000000?3ol03`oo00
FP3`oo010?ooo`004`3`oo020?l004h0l?o`00<000000?3ol03`oo000`3`oo02000005/0l?o`0@3o
ool00180l?o`00<0o`000?3ol03`oo00CP3`oo000`000000l?o`0?3ol0020?3ol0030000003`oo00
000005/0l?o`0@3oool00100l?o`0P3o001A0?3ol0030000003`oo00l?o`0080l?o`00@000000?3o
l03`oo000000FP3`oo010?ooo`003P3`oo020?l005<0l?o`00D000000?3ol03`oo00l?o`00000003
0?3ol0030000003`oo00l?o`05P0l?o`0@3oool000`0l?o`0P3o001E0?3ol0030000003`oo00l?o`
00<0000000@0l?o`0000000000000000F@3`oo010?ooo`00\
\>"],
    ImageRangeCache->{{{0, 198}, {198, 0}} -> {-2, -2, 0, 0}}],
  StyleBox["          ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.941 1 .941 r
.5 .5 m
.5 0 L
0 0 L
0 1 L
.5 1 L
.5 .5 L
F
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.5 .75 m
.49969 .75 L
.49941 .75001 L
.49909 .75002 L
.49878 .75004 L
.4985 .75006 L
.49824 .75009 L
.49764 .75017 L
.49705 .75028 L
.49639 .75044 L
.49506 .75087 L
.49377 .75142 L
.49238 .75217 L
.48986 .75387 L
.48419 .75868 L
.48139 .76103 L
.48003 .76204 L
.4788 .76284 L
.47759 .76349 L
.47696 .76377 L
.47629 .76402 L
.47595 .76413 L
.47558 .76423 L
.47523 .7643 L
.47492 .76436 L
.4746 .7644 L
.47425 .76443 L
.47393 .76444 L
.47362 .76443 L
.4733 .76442 L
.47312 .7644 L
.47294 .76438 L
.47259 .76432 L
.47222 .76423 L
.47154 .76402 L
.47092 .76376 L
.46949 .76291 L
.46876 .76235 L
.46798 .76163 L
.46528 .75833 L
.46283 .75424 L
.45733 .74195 L
.45187 .72746 L
.44947 .72124 L
.44683 .71503 L
.44447 .71039 L
.44317 .70832 L
.44193 .70673 L
.44126 .70603 L
.44053 .70542 L
Mistroke
.44021 .7052 L
.43986 .70499 L
.43954 .70484 L
.43925 .70472 L
.43892 .70462 L
.43875 .70458 L
.43857 .70455 L
.43826 .70452 L
.43793 .70452 L
.43763 .70456 L
.43731 .70462 L
.43701 .70472 L
.43674 .70483 L
.43613 .70517 L
.43547 .70568 L
.43478 .70638 L
.43413 .70719 L
.43297 .709 L
.43172 .71147 L
.42887 .71909 L
.42626 .72835 L
.41585 .77938 L
.4106 .80559 L
.40831 .81516 L
.40583 .82352 L
.40445 .8271 L
.40384 .8284 L
.40318 .82962 L
.40259 .83052 L
.40196 .8313 L
.40161 .83164 L
.40129 .83189 L
.40098 .83209 L
.40067 .83223 L
.40036 .83233 L
.40018 .83236 L
.40001 .83237 L
.39967 .83235 L
.39948 .83231 L
.39931 .83225 L
.39901 .83212 L
.39869 .83192 L
.39835 .83165 L
.39804 .83134 L
.39731 .83041 L
.39665 .8293 L
.39517 .82591 L
.3939 .82201 L
.39255 .81691 L
.39014 .80536 L
Mistroke
.38468 .76957 L
.37475 .68881 L
.36965 .6535 L
.36818 .64556 L
.36678 .6392 L
.36541 .63418 L
.36417 .63076 L
.36354 .62948 L
.36321 .62892 L
.36287 .62843 L
.36256 .62806 L
.36223 .62775 L
.36193 .62754 L
.36165 .62741 L
.36148 .62736 L
.3613 .62734 L
.36097 .62736 L
.36065 .62746 L
.36035 .62763 L
.36003 .62789 L
.35968 .62828 L
.35896 .62938 L
.35834 .63068 L
.35776 .63216 L
.35647 .63646 L
.35533 .64137 L
.35413 .64764 L
.35163 .66424 L
.34895 .68666 L
.34413 .73634 L
.3389 .79669 L
.33323 .85766 L
.33057 .88085 L
.32912 .89141 L
.32776 .89972 L
.32651 .90593 L
.32536 .9103 L
.32471 .91221 L
.32409 .91362 L
.32378 .91419 L
.32344 .91468 L
.32325 .91491 L
.32307 .91509 L
.32273 .91533 L
.32241 .91544 L
.32211 .91545 L
.32179 .91535 L
.32161 .91525 L
.32144 .91512 L
.32111 .91478 L
Mistroke
.32075 .91427 L
.32009 .91297 L
.31947 .91134 L
.31883 .90918 L
.31766 .90415 L
.31632 .89656 L
.31506 .88775 L
.31219 .86197 L
.30688 .79684 L
.30202 .72537 L
.29661 .64585 L
.29398 .61154 L
.2916 .58488 L
.2904 .57346 L
.2891 .56278 L
.28798 .55507 L
.28675 .54833 L
.28611 .5456 L
.28544 .54324 L
.28506 .54219 L
.28472 .5414 L
.28437 .54075 L
.28405 .54029 L
.28376 .53999 L
.28344 .5398 L
.28313 .53974 L
.28295 .53977 L
.28278 .53983 L
.28248 .54005 L
.2822 .54036 L
.28189 .54081 L
.28157 .54144 L
.2809 .5432 L
.28026 .54544 L
.27907 .55112 L
.27779 .55936 L
.27639 .57073 L
.27389 .59725 L
.27157 .62791 L
.26123 .80893 L
.25644 .89375 L
.25129 .96516 L
.25 .97824 L
Mfstroke
1 0 0 r
.5 .25 m
.49969 .25 L
.49941 .24999 L
.49909 .24998 L
.49878 .24996 L
.4985 .24994 L
.49824 .24991 L
.49764 .24983 L
.49705 .24972 L
.49639 .24956 L
.49506 .24913 L
.49377 .24858 L
.49238 .24783 L
.48986 .24613 L
.48419 .24132 L
.48139 .23897 L
.48003 .23796 L
.4788 .23716 L
.47759 .23651 L
.47696 .23623 L
.47629 .23598 L
.47595 .23587 L
.47558 .23577 L
.47523 .2357 L
.47492 .23564 L
.4746 .2356 L
.47425 .23557 L
.47393 .23556 L
.47362 .23557 L
.4733 .23558 L
.47312 .2356 L
.47294 .23562 L
.47259 .23568 L
.47222 .23577 L
.47154 .23598 L
.47092 .23624 L
.46949 .23709 L
.46876 .23765 L
.46798 .23837 L
.46528 .24167 L
.46283 .24576 L
.45733 .25805 L
.45187 .27254 L
.44947 .27876 L
.44683 .28497 L
.44447 .28961 L
.44317 .29168 L
.44193 .29327 L
.44126 .29397 L
.44053 .29458 L
Mistroke
.44021 .2948 L
.43986 .29501 L
.43954 .29516 L
.43925 .29528 L
.43892 .29538 L
.43875 .29542 L
.43857 .29545 L
.43826 .29548 L
.43793 .29548 L
.43763 .29544 L
.43731 .29538 L
.43701 .29528 L
.43674 .29517 L
.43613 .29483 L
.43547 .29432 L
.43478 .29362 L
.43413 .29281 L
.43297 .291 L
.43172 .28853 L
.42887 .28091 L
.42626 .27165 L
.41585 .22062 L
.4106 .19441 L
.40831 .18484 L
.40583 .17648 L
.40445 .1729 L
.40384 .1716 L
.40318 .17038 L
.40259 .16948 L
.40196 .1687 L
.40161 .16836 L
.40129 .16811 L
.40098 .16791 L
.40067 .16777 L
.40036 .16767 L
.40018 .16764 L
.40001 .16763 L
.39967 .16765 L
.39948 .16769 L
.39931 .16775 L
.39901 .16788 L
.39869 .16808 L
.39835 .16835 L
.39804 .16866 L
.39731 .16959 L
.39665 .1707 L
.39517 .17409 L
.3939 .17799 L
.39255 .18309 L
.39014 .19464 L
Mistroke
.38468 .23043 L
.37475 .31119 L
.36965 .3465 L
.36818 .35444 L
.36678 .3608 L
.36541 .36582 L
.36417 .36924 L
.36354 .37052 L
.36321 .37108 L
.36287 .37157 L
.36256 .37194 L
.36223 .37225 L
.36193 .37246 L
.36165 .37259 L
.36148 .37264 L
.3613 .37266 L
.36097 .37264 L
.36065 .37254 L
.36035 .37237 L
.36003 .37211 L
.35968 .37172 L
.35896 .37062 L
.35834 .36932 L
.35776 .36784 L
.35647 .36354 L
.35533 .35863 L
.35413 .35236 L
.35163 .33576 L
.34895 .31334 L
.34413 .26366 L
.3389 .20331 L
.33323 .14234 L
.33057 .11915 L
.32912 .10859 L
.32776 .10028 L
.32651 .09407 L
.32536 .0897 L
.32471 .08779 L
.32409 .08638 L
.32378 .08581 L
.32344 .08532 L
.32325 .08509 L
.32307 .08491 L
.32273 .08467 L
.32241 .08456 L
.32211 .08455 L
.32179 .08465 L
.32161 .08475 L
.32144 .08488 L
.32111 .08522 L
Mistroke
.32075 .08573 L
.32009 .08703 L
.31947 .08866 L
.31883 .09082 L
.31766 .09585 L
.31632 .10344 L
.31506 .11225 L
.31219 .13803 L
.30688 .20316 L
.30202 .27463 L
.29661 .35415 L
.29398 .38846 L
.2916 .41512 L
.2904 .42654 L
.2891 .43722 L
.28798 .44493 L
.28675 .45167 L
.28611 .4544 L
.28544 .45676 L
.28506 .45781 L
.28472 .4586 L
.28437 .45925 L
.28405 .45971 L
.28376 .46001 L
.28344 .4602 L
.28313 .46026 L
.28295 .46023 L
.28278 .46017 L
.28248 .45995 L
.2822 .45964 L
.28189 .45919 L
.28157 .45856 L
.2809 .4568 L
.28026 .45456 L
.27907 .44888 L
.27779 .44064 L
.27639 .42927 L
.27389 .40275 L
.27157 .37209 L
.26123 .19107 L
.25644 .10625 L
.25129 .03484 L
.25 .02176 L
Mfstroke
0 g
0 .5 m
1 .5 L
s
.5 .5 m
.5 1 L
s
[ .02 .02 ] 0 setdash
.5 0 m
.5 .5 L
s
0 0 1 r
.03 w
.5 .75 Mdot
1 0 0 r
.5 .25 Mdot
0 g
gsave
.98 .525 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5375 .98 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.555 .25 -70.1875 -10.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.188 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
77.375 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.555 .75 -70.1875 -10.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
77.375 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{199, 199},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000370000ab000`400?l00000o`00003oH`3oool0
0`000000oooo0?ooo`1Q0?ooo`00H`3`oo000`000000oooo0?ooo`1Q0?ooo`00H`3`oo000`000000
oooo0?ooo`1Q0?ooo`00H`3`oo000`000000oooo0?ooo`1Q0?ooo`00H`3`oo000`000000oooo0?oo
o`1Q0?ooo`00<@3`oo000`3o0000l?o`0?3ol00_0?3ol6@0oooo000a0?3ol0030?l0003`oo00l?o`
02l0l?o`I03oool00340l?o`00<0o`000?3ol03`oo00;`3`oo1T0?ooo`00<@3`oo000`3o0000l?o`
0?3ol00_0?3ol0030000003oool0oooo0640oooo000a0?3ol0030?l0003`oo00l?o`02l0l?o`00<0
00000?ooo`3oool0H@3oool00340l?o`00<0o`000?3ol03`oo00;`3`oo000`000000oooo0?ooo`1Q
0?ooo`00<@3`oo000`3o0000l?o`0?3ol00_0?3ol0030000003oool0oooo0640oooo000a0?3ol003
0?l0003`oo00l?o`02l0l?o`00<000000?ooo`3oool0H@3oool00340l?o`00<0o`000?3ol03`oo00
;`3`oo1T0?ooo`00<@3`oo000`3o0000l?o`0?3ol00_0?3ol6@0oooo000b0?3ol0030?l0003`oo00
l?o`02h0l?o`I03oool00380l?o`00<0o`000?3ol03`oo00;P3`oo000`000000oooo0?ooo`1Q0?oo
o`00<P3`oo000`3o0000l?o`0?3ol00:0?3ol080o`008P3`oo000`000000oooo0?ooo`1Q0?ooo`00
<P3`oo000`3o0000l?o`0?3ol00:0?3ol080o`008P3`oo000`000000oooo0?ooo`1Q0?ooo`00<P3`
oo000`3o0000l?o`0?3ol0090?3ol0030?l0003`oo00o`000280l?o`00<000000?ooo`3oool0H@3o
ool00380l?o`00<0o`000?3ol03`oo002@3`oo000`3o0000l?o`0?l0000R0?3ol0030000003oool0
oooo0640oooo000b0?3ol0030?l0003`oo00l?o`00T0l?o`00<0o`000?3ol03o00008P3`oo1T0?oo
o`00<P3`oo000`3o0000l?o`0?3ol0090?3ol0040?l0003`oo00l?o`0?l00240l?o`I03oool00380
l?o`00<0o`000?3ol03`oo002@3`oo00103o0000l?o`0?3ol03o000Q0?3ol6@0oooo000b0?3ol003
0?l0003`oo00l?o`00T0l?o`00@0o`000?3ol03`oo00o`008@3`oo000`000000oooo0?ooo`1Q0?oo
o`00<P3`oo000`3o0000l?o`0?3ol0090?3ol0040?l0003`oo00l?o`0?l00240l?o`00<000000?oo
o`3oool0H@3oool00380l?o`00<0o`000?3ol03`oo00203`oo001@3o0000l?o`0?3ol03`oo00o`00
0240l?o`00<000000?ooo`3oool0H@3oool00380l?o`00<0o`000?3ol03`oo00203`oo001@3o0000
l?o`0?3ol03`oo00o`000240l?o`00<000000?ooo`3oool0H@3oool00380l?o`00<0o`000?3ol03`
oo00203`oo001@3o0000l?o`0?3ol03`oo00o`000240l?o`00<000000?ooo`3oool0H@3oool00380
l?o`00<0o`000?3ol03`oo00203`oo001@3o0000l?o`0?3ol03`oo00o`000240l?o`I03oool00380
l?o`00<0o`000?3ol03`oo00203`oo001@3o0000l?o`0?3ol03`oo00o`000240l?o`I03oool003<0
l?o`00<0o`000?3ol03`oo001`3`oo001@3o0000l?o`0?3ol03`oo00o`000240l?o`I03oool003<0
l?o`00<0o`000?3ol03`oo001`3`oo001@3o0000l?o`0?3ol03`oo00o`000240l?o`00<000000?oo
o`3oool0H@3oool003<0l?o`00<0o`000?3ol03`oo001`3`oo000`3o0000l?o`0?3ol0020?3ol003
0?l0003`oo00l?o`00X0l?o`00<0o`000?3ol03`oo004@3`oo000`000000oooo0?ooo`1Q0?ooo`00
<`3`oo000`3o0000l?o`0?3ol0070?3ol0030?l0003`oo00l?o`0080l?o`00<0o`000?3ol03`oo00
2@3`oo020?l001<0l?o`00<000000?ooo`3oool0H@3oool003<0l?o`00<0o`000?3ol03`oo001P3`
oo000`3o0000l?o`0?3ol0030?3ol0030?l0003`oo00l?o`00T0l?o`00<0o`000?3ol03o00004P3`
oo000`000000oooo0?ooo`1Q0?ooo`00<`3`oo000`3o0000l?o`0?3ol0060?3ol0030?l0003`oo00
l?o`00<0l?o`00<0o`000?3ol03`oo00203`oo00103o0000l?o`0?3ol03o000B0?3ol0030000003o
ool0oooo0640oooo000c0?3ol0030?l0003`oo00l?o`00H0l?o`00<0o`000?3ol03`oo000`3`oo00
0`3o0000l?o`0?3ol0080?3ol0040?l0003`oo00l?o`0?l00180l?o`I03oool003<0l?o`00<0o`00
0?3ol03`oo001P3`oo000`3o0000l?o`0?3ol0030?3ol0030?l0003`oo00l?o`00P0l?o`00@0o`00
0?3ol03`oo00o`004P3`oo1T0?ooo`00<`3`oo000`3o0000l?o`0?3ol0060?3ol0030?l0003`oo00
l?o`00@0l?o`00<0o`000?3ol03`oo001`3`oo001@3o0000l?o`0?3ol03`oo00o`000140l?o`I03o
ool003<0l?o`00<0o`000?3ol03`oo001P3`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00
l?o`00L0l?o`00D0o`000?3ol03`oo00l?o`0?l0000A0?3ol0030000003oool0oooo0640oooo000c
0?3ol0030?l0003`oo00l?o`00H0l?o`00<0o`000?3ol03`oo00103`oo000`3o0000l?o`0?3ol007
0?3ol0050?l0003`oo00l?o`0?3ol03o00004@3`oo000`000000oooo0?ooo`1Q0?ooo`00<`3`oo00
0`3o0000l?o`0?3ol0060?3ol0030?l0003`oo00l?o`00@0l?o`00<0o`000?3ol03`oo001`3`oo00
0`3o0000l?o`0?3ol0020?3ol0030?l0003`oo00l?o`00h0l?o`00<000000?ooo`3oool0H@3oool0
03<0l?o`00<0o`000?3ol03`oo001P3`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00l?o`
00H0l?o`00<0o`000?3ol03`oo000`3`oo000`3o0000l?o`0?3ol00>0?3ol0030000003oool0oooo
0640oooo000c0?3ol0030?l0003`oo00l?o`00H0l?o`00<0o`000?3ol03`oo00103`oo000`3o0000
l?o`0?3ol0060?3ol0030?l0003`oo00l?o`00<0l?o`00<0o`000?3ol03`oo003P3`oo000`000000
oooo0?ooo`1Q0?ooo`00<`3`oo000`3o0000l?o`0?3ol0060?3ol0030?l0003`oo00l?o`00@0l?o`
00<0o`000?3ol03`oo001P3`oo000`3o0000l?o`0?3ol0030?3ol0030?l0003`oo00l?o`00h0l?o`
I03oool003<0l?o`00<0o`000?3ol03`oo001P3`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`
oo00l?o`00H0l?o`00<0o`000?3ol03`oo000`3`oo000`3o0000l?o`0?3ol00>0?3ol6@0oooo000c
0?3ol0030?l0003`oo00l?o`00H0l?o`00<0o`000?3ol03`oo00103`oo000`3o0000l?o`0?3ol006
0?3ol0030?l0003`oo00l?o`00@0l?o`00<0o`000?3ol03`oo001P3`oo030?l000@0l?o`I03oool0
03@0l?o`00<0o`000?3ol03`oo00103`oo000`3o0000l?o`0?3ol0060?3ol0030?l0003`oo00l?o`
00D0l?o`00<0o`000?3ol03`oo00103`oo000`3o0000l?o`0?3ol0060?3ol0050?l0003`oo00l?o`
0?l0003`oo000`3o000:0?ooo`L00000DP3oool003@0l?o`00<0o`000?3ol03`oo00103`oo000`3o
0000l?o`0?3ol0060?3ol0030?l0003`oo00l?o`00D0l?o`00<0o`000?3ol03`oo00103`oo000`3o
0000l?o`0?3ol0050?3ol0030?l0003`oo00l?o`0080l?o`1@3o000;0?ooo`030000003oool00000
05@0oooo000d0?3ol0030?l0003`oo00l?o`00@0l?o`00<0o`000?3ol03`oo001P3`oo000`3o0000
l?o`0?3ol0040?3ol0030?l0003`oo00l?o`00D0l?o`00<0o`000?3ol03`oo001@3`oo000`3o0000
l?o`0?3ol0020?3ol0D0o`000P3oool5000000@0oooo00<000000?ooo`000000E03oool003@0l?o`
00<0o`000?3ol03`oo00103`oo000`3o0000l?o`0?3ol0060?3ol0030?l0003`oo00l?o`00@0l?o`
00<0o`000?3ol03`oo001@3`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00l?o`00<0l?o`
1@3o000;0?ooo`030000003oool0000005@0oooo000d0?3ol0030?l0003`oo00l?o`00@0l?o`00<0
o`000?3ol03`oo001P3`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00l?o`00H0l?o`00<0
o`000?3ol03`oo000`3`oo000`3o0000l?o`0?3ol0040?3ol0<0o`00303oool00`000000oooo0000
001D0?ooo`00=03`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00l?o`00H0l?o`00<0o`00
0?3ol03`oo00103`oo000`3o0000l?o`0?3ol0060?3ol0030?l0003`oo00l?o`0080l?o`00<0o`00
0?3ol03`oo001`3`oo0;0?ooo`D00000E03oool003@0l?o`00<0o`000?3ol03`oo00103`oo000`3o
0000l?o`0?3ol0060?3ol0030?l0003`oo00l?o`00@0l?o`00<0o`000?3ol03`oo001P3`oo000`3o
0000l?o`0?3ol0020?3ol0030?l0003`oo00l?o`00L0l?o`I03oool003@0l?o`00<0o`000?3ol03`
oo00103`oo000`3o0000l?o`0?3ol0060?3ol0030?l0003`oo00l?o`00@0l?o`00<0o`000?3ol03`
oo001P3`oo001@3o0000l?o`0?3ol03`oo00o`0000X0l?o`3P3oool00`000000oooo0?ooo`1C0?oo
o`00=03`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00l?o`00H0l?o`00<0o`000?3ol03`
oo00103`oo000`3o0000l?o`0?3ol0060?3ol0050?l0003`oo00l?o`0?3ol03o00002P3`oo000`00
0000oooo0?ooo`1Q0?ooo`00=03`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`oo00l?o`00H0
l?o`00<0o`000?3ol03`oo00103`oo000`3o0000l?o`0?3ol0060?3ol0050?l0003`oo00l?o`0?3o
l03o00002P3`oo000`000000oooo0?ooo`1Q0?ooo`00=03`oo000`3o0000l?o`0?3ol0040?3ol003
0?l0003`oo00l?o`00H0l?o`00<0o`000?3ol03`oo000`3`oo000`3o0000l?o`0?3ol0080?3ol004
0?l0003`oo00o`000?l000X0l?o`00<000000?ooo`3oool0H@3oool003@0l?o`00<0o`000?3ol03`
oo00103`oo000`3o0000l?o`0?3ol0070?3ol0030?l0003`oo00l?o`0080l?o`00<0o`000?3ol03`
oo002@3`oo020?l000/0l?o`00<000000?ooo`3oool0H@3oool003@0l?o`00<0o`000?3ol03`oo00
103`oo000`3o0000l?o`0?3ol0070?3ol0030?l0003`oo00l?o`0080l?o`00<0o`000?3ol03`oo00
5P3`oo000`000000oooo0?ooo`1Q0?ooo`00=03`oo000`3o0000l?o`0?3ol0040?3ol0030?l0003`
oo00l?o`00L0l?o`00<0o`000?3ol03`oo000P3`oo000`3o0000l?o`0?3ol00F0?3ol6@0oooo000d
0?3ol0030?l0003`oo00l?o`00@0l?o`00<0o`000?3ol03`oo001`3`oo000`3o0000l?o`0?3ol002
0?3ol0030?l0003`oo00l?o`01H0l?o`I03oool003@0l?o`00<0o`000?3ol03`oo000`3`oo000`3o
0000l?o`0?3ol0080?3ol0030?l0003`oo00l?o`0080l?o`00<0o`000?3ol03`oo005P3`oo1T0?oo
o`00=03`oo000`3o0000l?o`0?3ol0030?3ol0030?l0003`oo00l?o`00P0l?o`00<0o`000?3ol03`
oo000P3`oo000`3o0000l?o`0?3ol00F0?3ol0030000003oool0oooo0640oooo000d0?3ol0030?l0
003`oo00l?o`00<0l?o`00<0o`000?3ol03`oo00203`oo000`3o0000l?o`0?3ol0020?3ol0030?l0
003`oo00l?o`01H0l?o`00<000000?ooo`3oool0H@3oool003D0l?o`00<0o`000?3ol03`oo000P3`
oo000`3o0000l?o`0?3ol0080?3ol0050?l0003`oo00l?o`0?3ol03o00006@3`oo000`000000oooo
0?ooo`1Q0?ooo`00=@3`oo000`3o0000l?o`0?3ol0020?3ol0030?l0003`oo00l?o`00P0l?o`00D0
o`000?3ol03`oo00l?o`0?l0000I0?3ol0030000003oool0oooo0640oooo000e0?3ol0030?l0003`
oo00l?o`0080l?o`00<0o`000?3ol03`oo00203`oo001@3o0000l?o`0?3ol03`oo00o`0001T0l?o`
00<000000?ooo`3oool0H@3oool003D0l?o`00<0o`000?3ol03`oo000P3`oo000`3o0000l?o`0?3o
l0090?3ol0040?l0003`oo00l?o`0?l001T0l?o`I03oool003D0l?o`00<0o`000?3ol03`oo000P3`
oo000`3o0000l?o`0?3ol0090?3ol0030?l0003`oo00o`0001X0l?o`I03oool003D0l?o`00<0o`00
0?3ol03`oo000P3`oo000`3o0000l?o`0?3ol0090?3ol0030?l0003`oo00o`0001X0l?o`I03oool0
03D0l?o`00<0o`000?3ol03`oo000P3`oo000`3o0000l?o`0?3ol0090?3ol0030?l0003`oo00o`00
01X0l?o`00<000000?ooo`3oool0H@3oool003D0l?o`00<0o`000?3ol03`oo000P3`oo000`3o0000
l?o`0?3ol0090?3ol0030?l0003`oo00o`0001X0l?o`00<000000?ooo`3oool0H@3oool003D0l?o`
00<0o`000?3ol03`oo000P3`oo000`3o0000l?o`0?3ol0090?3ol0<0o`006P3`oo000`000000oooo
0?ooo`1Q0?ooo`00=@3`oo000`3o0000l?o`0?3ol0020?3ol0030?l0003`oo00l?o`02H0l?o`00<0
00000?ooo`3oool0H@3oool003D0l?o`00<0o`000?3ol03`oo000P3`oo000`3o0000l?o`0?3ol00V
0?3ol0030000003oool0oooo0640oooo000e0?3ol0030?l0003`oo00l?o`0080l?o`00<0o`000?3o
l03`oo009P3`oo1T0?ooo`00=P3`oo001@3o0000l?o`0?3ol03`oo00o`0002P0l?o`I03oool003H0
l?o`00D0o`000?3ol03`oo00l?o`0?l0000X0?3ol6@0oooo000f0?3ol0040?l0003`oo00l?o`0?l0
02T0l?o`00<000000?ooo`3oool0H@3oool003H0l?o`00@0o`000?3ol03`oo00o`00:@3`oo000`00
0000oooo0?ooo`1Q0?ooo`00=P3`oo00103o0000l?o`0?3ol03o000Y0?3ol0030000003oool0oooo
0640oooo000f0?3ol0040?l0003`oo00l?o`0?l002T0l?o`00<000000?ooo`3oool0H@3oool003H0
l?o`00@0o`000?3ol03`oo00o`00:@3`oo000`000000oooo0?ooo`1Q0?ooo`00=P3`oo00103o0000
l?o`0?3ol03o000Y0?3ol6@0oooo000f0?3ol0040?l0003`oo00l?o`0?l002T0l?o`I03oool003L0
l?o`00<0o`000?3ol03o0000:@3`oo1T0?ooo`00=`3`oo000`3o0000l?o`0?l0000Y0?3ol0030000
003oool0oooo0640oooo000g0?3ol0030?l0003`oo00o`0002T0l?o`00<000000?ooo`3oool0H@3o
ool003L0l?o`0P3o000Z0?3ol0030000003oool0oooo0640oooo000g0?3ol080o`00:P3`oo000`00
0000oooo0?ooo`1Q0?ooo`00=`3`oo020?l002X0l?o`00<000000?ooo`3oool0H@3oool006<0l?o`
I03oool006<0l?o`I03oool006<0l?o`I03oool006<0l?o`00<000000?ooo`3oool0H@3oool006<0
l?o`00<000000?ooo`3oool0H@3oool006<0l?o`00<000000?ooo`3oool0H@3oool00<L00000001S
0?3ol0030000003oool0oooo0640oooo001S0?3ol0030000003oool0oooo0640oooo001S0?3ol003
0000003oool0oooo0640oooo001S0?3ol0030000003oool0oooo05X0oooo0P0000000`3oool00000
000000020?ooo`00H`3`oo000`000000oooo0?ooo`1I0?ooo`030000003oool0oooo008000000`3o
ool006<0l?o`00<000000?ooo`3oool0F@3oool01@000000oooo0?ooo`3oool0000000<0oooo001S
0?3ol0030000003oool0oooo05T0oooo00D000000?ooo`3oool0oooo000000030?ooo`00=`3`oo02
0000obX0l?o`00<000000?ooo`3oool0F@3oool01@000000oooo0?ooo`3oool0000000<0oooo000g
0?3ol080003o:P3`oo000`000000oooo0?ooo`1H0?ooo`8000000P3oool2000000<0oooo000g0?3o
l080003o:P3`oo000`000000oooo0?ooo`1Q0?ooo`00=`3`oo000`000?l0l?o`0000o`0Y0?3ol003
0000003oool0oooo0640oooo000g0?3ol0030000o`3`oo00003o02T0l?o`00<000000?ooo`3oool0
H@3oool003L0l?o`00<0003o0?3ol0000?l0:@3`oo000`000000oooo0?ooo`1Q0?ooo`00=P3`oo00
10000?l0l?o`0?3ol0000?lY0?3ol0030000003oool0oooo0640oooo000f0?3ol0040000o`3`oo00
l?o`0000obT0l?o`00<000000?ooo`3oool0H@3oool003H0l?o`00@0003o0?3ol03`oo00003o:@3`
oo000`000000oooo0?ooo`1Q0?ooo`00=P3`oo0010000?l0l?o`0?3ol0000?lY0?3ol0030000003o
ool0oooo0640oooo000f0?3ol0040000o`3`oo00l?o`0000obT0l?o`00<000000?ooo`3oool0H@3o
ool003H0l?o`00@0003o0?3ol03`oo00003o:@3`oo000`000000oooo0?ooo`1Q0?ooo`00=P3`oo00
10000?l0l?o`0?3ol0000?lY0?3ol0030000003oool0oooo0640oooo000f0?3ol0050000o`3`oo00
l?o`0?3ol0000?l0:03`oo000`000000oooo0?ooo`1Q0?ooo`00=P3`oo001@000?l0l?o`0?3ol03`
oo00003o02P0l?o`00<000000?ooo`3oool0H@3oool003D0l?o`00<0003o0?3ol03`oo000P3`oo00
0`000?l0l?o`0?3ol00V0?3ol0030000003oool0oooo0640oooo000e0?3ol0030000o`3`oo00l?o`
0080l?o`00<0003o0?3ol03`oo009P3`oo000`000000oooo0?ooo`1Q0?ooo`00=@3`oo000`000?l0
l?o`0?3ol0020?3ol0030000o`3`oo00l?o`00X0l?o`00<0003o0?3ol03`oo006@3`oo000`000000
oooo0?ooo`1Q0?ooo`00=@3`oo000`000?l0l?o`0?3ol0020?3ol0030000o`3`oo00l?o`00T0l?o`
0`000?lJ0?3ol0030000003oool0oooo0640oooo000e0?3ol0030000o`3`oo00l?o`0080l?o`00<0
003o0?3ol03`oo002@3`oo000`000?l0l?o`0000o`0J0?3ol0030000003oool0oooo0640oooo000e
0?3ol0030000o`3`oo00l?o`0080l?o`00<0003o0?3ol03`oo002@3`oo000`000?l0l?o`0000o`0J
0?3ol0030000003oool0oooo0640oooo000e0?3ol0030000o`3`oo00l?o`0080l?o`00<0003o0?3o
l03`oo002@3`oo000`000?l0l?o`0000o`0J0?3ol0030000003oool0oooo0640oooo000e0?3ol003
0000o`3`oo00l?o`0080l?o`00<0003o0?3ol03`oo002@3`oo000`000?l0l?o`0000o`0J0?3ol003
0000003oool0oooo0640oooo000e0?3ol0030000o`3`oo00l?o`0080l?o`00<0003o0?3ol03`oo00
2@3`oo0010000?l0l?o`0?3ol0000?lI0?3ol0030000003oool0oooo0640oooo000e0?3ol0030000
o`3`oo00l?o`0080l?o`00<0003o0?3ol03`oo00203`oo001@000?l0l?o`0?3ol03`oo00003o01T0
l?o`00<000000?ooo`3oool0H@3oool003D0l?o`00<0003o0?3ol03`oo000P3`oo000`000?l0l?o`
0?3ol0080?3ol0050000o`3`oo00l?o`0?3ol0000?l06@3`oo000`000000oooo0?ooo`1Q0?ooo`00
=@3`oo000`000?l0l?o`0?3ol0020?3ol0030000o`3`oo00l?o`00P0l?o`00D0003o0?3ol03`oo00
l?o`0000o`0I0?3ol0030000003oool0oooo0640oooo000d0?3ol0030000o`3`oo00l?o`00<0l?o`
00<0003o0?3ol03`oo00203`oo000`000?l0l?o`0?3ol0020?3ol0030000o`3`oo00l?o`01H0l?o`
00<000000?ooo`3oool0H@3oool003@0l?o`00<0003o0?3ol03`oo000`3`oo000`000?l0l?o`0?3o
l0080?3ol0030000o`3`oo00l?o`0080l?o`00<0003o0?3ol03`oo005P3`oo000`000000oooo0?oo
o`1Q0?ooo`00=03`oo000`000?l0l?o`0?3ol0030?3ol0030000o`3`oo00l?o`00P0l?o`00<0003o
0?3ol03`oo000P3`oo000`000?l0l?o`0?3ol00F0?3ol0030000003oool0oooo0640oooo000d0?3o
l0030000o`3`oo00l?o`00@0l?o`00<0003o0?3ol03`oo001`3`oo000`000?l0l?o`0?3ol0020?3o
l0030000o`3`oo00l?o`01H0l?o`00<000000?ooo`3oool0H@3oool003@0l?o`00<0003o0?3ol03`
oo00103`oo000`000?l0l?o`0?3ol0070?3ol0030000o`3`oo00l?o`0080l?o`00<0003o0?3ol03`
oo005P3`oo000`000000oooo0?ooo`1Q0?ooo`00=03`oo000`000?l0l?o`0?3ol0040?3ol0030000
o`3`oo00l?o`00L0l?o`00<0003o0?3ol03`oo000P3`oo000`000?l0l?o`0?3ol00F0?3ol0030000
003oool0oooo0640oooo000d0?3ol0030000o`3`oo00l?o`00@0l?o`00<0003o0?3ol03`oo001`3`
oo000`000?l0l?o`0?3ol0020?3ol0030000o`3`oo00l?o`00T0l?o`0P000?l;0?3ol0030000003o
ool0oooo0640oooo000d0?3ol0030000o`3`oo00l?o`00@0l?o`00<0003o0?3ol03`oo001P3`oo00
0`000?l0l?o`0?3ol0030?3ol0030000o`3`oo00l?o`00P0l?o`00@0003o0?3ol0000?l0003o2P3`
oo000`000000oooo0?ooo`1Q0?ooo`00=03`oo000`000?l0l?o`0?3ol0040?3ol0030000o`3`oo00
l?o`00H0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3ol0060?3ol0050000o`3`oo00
l?o`0?3ol0000?l02P3`oo000`000000oooo0?ooo`1Q0?ooo`00=03`oo000`000?l0l?o`0?3ol004
0?3ol0030000o`3`oo00l?o`00H0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3ol006
0?3ol0050000o`3`oo00l?o`0?3ol0000?l02P3`oo000`000000oooo0?ooo`1Q0?ooo`00=03`oo00
0`000?l0l?o`0?3ol0040?3ol0030000o`3`oo00l?o`00H0l?o`00<0003o0?3ol03`oo00103`oo00
0`000?l0l?o`0?3ol0060?3ol0050000o`3`oo00l?o`0?3ol0000?l02P3`oo000`000000oooo0?oo
o`1Q0?ooo`00=03`oo000`000?l0l?o`0?3ol0040?3ol0030000o`3`oo00l?o`00H0l?o`00<0003o
0?3ol03`oo00103`oo000`000?l0l?o`0?3ol0060?3ol0030000o`3`oo00l?o`0080l?o`00<0003o
0?3ol03`oo001`3`oo000`000000oooo0?ooo`1Q0?ooo`00=03`oo000`000?l0l?o`0?3ol0040?3o
l0030000o`3`oo00l?o`00H0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3ol0060?3o
l0030000o`3`oo00l?o`0080l?o`00<0003o0?3ol03`oo001`3`oo000`000000oooo0?ooo`1Q0?oo
o`00=03`oo000`000?l0l?o`0?3ol0040?3ol0030000o`3`oo00l?o`00H0l?o`00<0003o0?3ol03`
oo00103`oo000`000?l0l?o`0?3ol0060?3ol0030000o`3`oo00l?o`00<0l?o`00<0003o0?3ol03`
oo00103`oo030000o`X0oooo1`00001B0?ooo`00=03`oo000`000?l0l?o`0?3ol0040?3ol0030000
o`3`oo00l?o`00H0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3ol0050?3ol0030000
o`3`oo00l?o`00@0l?o`00<0003o0?3ol03`oo000`3`oo050000o`/0oooo00<000000?ooo`000000
E03oool003@0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3ol0060?3ol0030000o`3`
oo00l?o`00@0l?o`00<0003o0?3ol03`oo001@3`oo000`000?l0l?o`0?3ol0050?3ol0030000o`3`
oo00l?o`0080l?o`1@000?l;0?ooo`030000003oool0000005@0oooo000d0?3ol0030000o`3`oo00
l?o`00@0l?o`00<0003o0?3ol03`oo001P3`oo000`000?l0l?o`0?3ol0050?3ol0030000o`3`oo00
l?o`00@0l?o`00<0003o0?3ol03`oo001@3`oo000`000?l0l?o`0?3ol0020?3ol0D0003o2`3oool0
0`000000oooo0000001D0?ooo`00=03`oo000`000?l0l?o`0?3ol0040?3ol0030000o`3`oo00l?o`
00H0l?o`00<0003o0?3ol03`oo001@3`oo000`000?l0l?o`0?3ol0040?3ol0030000o`3`oo00l?o`
00H0l?o`00D0003o0?3ol03`oo00003o0?3ol0030000o``0oooo00<000000?ooo`000000E03oool0
03<0l?o`00<0003o0?3ol03`oo001P3`oo000`000?l0l?o`0?3ol0040?3ol0030000o`3`oo00l?o`
00H0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3ol0060?3ol0<0003o103`oo000`00
0000oooo0?ooo`080?ooo`D00000E03oool003<0l?o`00<0003o0?3ol03`oo001P3`oo000`000?l0
l?o`0?3ol0040?3ol0030000o`3`oo00l?o`00H0l?o`00<0003o0?3ol03`oo000`3`oo000`000?l0
l?o`0?3ol00>0?3ol0030000003oool0oooo0640oooo000c0?3ol0030000o`3`oo00l?o`00H0l?o`
00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3ol0060?3ol0030000o`3`oo00l?o`00<0l?o`
00<0003o0?3ol03`oo003P3`oo000`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05<0oooo
000c0?3ol0030000o`3`oo00l?o`00H0l?o`00<0003o0?3ol03`oo00103`oo000`000?l0l?o`0?3o
l0060?3ol0030000o`3`oo00l?o`00<0l?o`00<0003o0?3ol03`oo003P3`oo000`000000oooo0?oo
o`1Q0?ooo`00<`3`oo000`000?l0l?o`0?3ol0060?3ol0030000o`3`oo00l?o`00@0l?o`00<0003o
0?3ol03`oo001P3`oo000`000?l0l?o`0?3ol0030?3ol0030000o`3`oo00l?o`00h0l?o`00<00000
0?ooo`3oool0H@3oool003<0l?o`00<0003o0?3ol03`oo001P3`oo000`000?l0l?o`0?3ol0040?3o
l0030000o`3`oo00l?o`00L0l?o`00<0003o0?3ol03`oo000P3`oo000`000?l0l?o`0?3ol00>0?3o
l0030000003oool0oooo0640oooo000c0?3ol0030000o`3`oo00l?o`00H0l?o`00<0003o0?3ol03`
oo00103`oo000`000?l0l?o`0?3ol0070?3ol0050000o`3`oo00l?o`0?3ol0000?l04@3`oo000`00
0000oooo0?ooo`1Q0?ooo`00<`3`oo000`000?l0l?o`0?3ol0060?3ol0030000o`3`oo00l?o`00@0
l?o`00<0003o0?3ol03`oo001`3`oo001@000?l0l?o`0?3ol03`oo00003o0140l?o`00<000000?oo
o`3oool0H@3oool003<0l?o`00<0003o0?3ol03`oo001P3`oo000`000?l0l?o`0?3ol0040?3ol003
0000o`3`oo00l?o`00L0l?o`00D0003o0?3ol03`oo00l?o`0000o`0A0?3ol0030000003oool0oooo
0640oooo000c0?3ol0030000o`3`oo00l?o`00H0l?o`00<0003o0?3ol03`oo000`3`oo000`000?l0
l?o`0?3ol0080?3ol0040000o`3`oo00l?o`0000oa80l?o`00<000000?ooo`3oool0H@3oool003<0
l?o`00<0003o0?3ol03`oo001P3`oo000`000?l0l?o`0?3ol0030?3ol0030000o`3`oo00l?o`00P0
l?o`00@0003o0?3ol03`oo00003o4P3`oo000`000000oooo0?ooo`1Q0?ooo`00<`3`oo000`000?l0
l?o`0?3ol0060?3ol0030000o`3`oo00l?o`00<0l?o`00<0003o0?3ol03`oo00203`oo0010000?l0
l?o`0?3ol0000?lB0?3ol0030000003oool0oooo0640oooo000c0?3ol0030000o`3`oo00l?o`00H0
l?o`00<0003o0?3ol03`oo000`3`oo000`000?l0l?o`0?3ol0090?3ol0030000o`3`oo00003o0180
l?o`00<000000?ooo`3oool0H@3oool003<0l?o`00<0003o0?3ol03`oo001`3`oo000`000?l0l?o`
0?3ol0020?3ol0030000o`3`oo00l?o`00T0l?o`0P000?lC0?3ol0030000003oool0oooo0640oooo
000c0?3ol0030000o`3`oo00l?o`00L0l?o`00<0003o0?3ol03`oo000P3`oo000`000?l0l?o`0?3o
l00N0?3ol0030000003oool0oooo0640oooo000c0?3ol0030000o`3`oo00l?o`00L0l?o`00D0003o
0?3ol03`oo00l?o`0000o`0Q0?3ol0030000003oool0oooo0640oooo000c0?3ol0030000o`3`oo00
l?o`00L0l?o`00D0003o0?3ol03`oo00l?o`0000o`0Q0?3ol0030000003oool0oooo0640oooo000b
0?3ol0030000o`3`oo00l?o`00P0l?o`00D0003o0?3ol03`oo00l?o`0000o`0Q0?3ol0030000003o
ool0oooo0640oooo000b0?3ol0030000o`3`oo00l?o`00P0l?o`00D0003o0?3ol03`oo00l?o`0000
o`0Q0?3ol0030000003oool0oooo0640oooo000b0?3ol0030000o`3`oo00l?o`00P0l?o`00D0003o
0?3ol03`oo00l?o`0000o`0Q0?3ol0030000003oool0oooo0640oooo000b0?3ol0030000o`3`oo00
l?o`00P0l?o`00D0003o0?3ol03`oo00l?o`0000o`0Q0?3ol0030000003oool0oooo0640oooo000b
0?3ol0030000o`3`oo00l?o`00P0l?o`00D0003o0?3ol03`oo00l?o`0000o`0Q0?3ol0030000003o
ool0oooo0640oooo000b0?3ol0030000o`3`oo00l?o`00T0l?o`00@0003o0?3ol03`oo00003o8@3`
oo000`000000oooo0?ooo`1Q0?ooo`00<P3`oo000`000?l0l?o`0?3ol0090?3ol0040000o`3`oo00
l?o`0000ob40l?o`00<000000?ooo`3oool0H@3oool00380l?o`00<0003o0?3ol03`oo002@3`oo00
10000?l0l?o`0?3ol0000?lQ0?3ol0030000003oool0oooo0640oooo000b0?3ol0030000o`3`oo00
l?o`00T0l?o`00@0003o0?3ol03`oo00003o8@3`oo000`000000oooo0?ooo`1Q0?ooo`00<P3`oo00
0`000?l0l?o`0?3ol0090?3ol0030000o`3`oo00003o0280l?o`00<000000?ooo`3oool0H@3oool0
0380l?o`00<0003o0?3ol03`oo002@3`oo000`000?l0l?o`0000o`0R0?3ol0030000003oool0oooo
0640oooo000b0?3ol0030000o`3`oo00l?o`00T0l?o`00<0003o0?3ol0000?l08P3`oo000`000000
oooo0?ooo`1Q0?ooo`00<P3`oo000`000?l0l?o`0?3ol00:0?3ol080003o8P3`oo000`000000oooo
0?ooo`1Q0?ooo`00<P3`oo000`000?l0l?o`0?3ol00:0?3ol080003o8P3`oo000`000000oooo0?oo
o`1Q0?ooo`00<P3`oo000`000?l0l?o`0?3ol00^0?3ol0030000003oool0oooo0640oooo000b0?3o
l0030000o`3`oo00l?o`02h0l?o`00<000000?ooo`3oool0H@3oool00340l?o`00<0003o0?3ol03`
oo00;`3`oo000`000000oooo0?ooo`1Q0?ooo`00<@3`oo000`000?l0l?o`0?3ol00_0?3ol0030000
003oool0oooo0640oooo000a0?3ol0030000o`3`oo00l?o`02l0l?o`00<000000?ooo`3oool0H@3o
ool00340l?o`00<0003o0?3ol03`oo00;`3`oo000`000000oooo0?ooo`1Q0?ooo`00<@3`oo000`00
0?l0l?o`0?3ol00_0?3ol0030000003oool0oooo0640oooo000a0?3ol0030000o`3`oo00l?o`02l0
l?o`00<000000?ooo`3oool0H@3oool00340l?o`00<0003o0?3ol03`oo00;`3`oo000`000000oooo
0?ooo`1Q0?ooo`00<@3`oo000`000?l0l?o`0?3ol00_0?3ol0030000003oool0oooo0640oooo000a
0?3ol0030000o`3`oo00l?o`02l0l?o`00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1K
0?ooo`00<@3`oo000`000?l0l?o`0?3ol00_0?3ol0030000003oool0oooo0080oooo00<000000?oo
o`000000G03oool006<0l?o`00<000000?ooo`3oool00P3oool00`000000oooo0000001L0?ooo`00
H`3`oo001@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0F@3oool006<0l?o`
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo05T0oooo001S0?3ol0030000
003oool0oooo00<0000000@0oooo0000000000000000FP3oool00001\
\>"],
    ImageRangeCache->{{{0, 198}, {198, 0}} -> {-2, -2, 0, 0}}],
  "  ",
  StyleBox["\n\t\t\t\t(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The branch  ",
  Cell[BoxData[
      \(w = \(\(f\_2\) \((z)\) = \(-\@z\)\)\)]],
  "   (where   ",
  Cell[BoxData[
      \(z = w\^2\)]],
  ").  "
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\tFigure 2.18",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The branches  ",
  Cell[BoxData[
      \(\(f\_1\) \((z)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\(f\_2\) \((z)\)\)]],
  "  of  ",
  Cell[BoxData[
      \(f \((z)\) = z\^\(1\/2\)\)]],
  ".   "
}], "Text"],

Cell[TextData[{
  "\tWe can construct other branches of the square root function by \
specifying that an argument of z given by  ",
  Cell[BoxData[
      \(\[Theta] = arg\ z\)]],
  "  is to lie in the interval  ",
  Cell[BoxData[
      \(\[Alpha] < \[Theta] \[LessEqual] \[Alpha] + 2  \[Pi]\)]],
  ".  The corresponding branch, denoted ",
  Cell[BoxData[
      \(\(f\_\[Alpha]\) \((z)\)\)]],
  ", is  \n\n",
  StyleBox["(2-30)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\(f\_\[Alpha]\) \((z)\) = \ \(r\^\(1\/2\)\) \((cos  \[Theta]\/2 + \
\[ImaginaryI]\ sin  \[Theta]\/2)\)\)]],
  ",\n\nwhere  ",
  Cell[BoxData[
      \(z = 
        r\ \[ExponentialE]\^\(\(\ \)\(\[ImaginaryI]\ \[Theta]\)\) \[NotEqual] 
          0\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Alpha] < \[Theta] \[LessEqual] \[Alpha] + 2  \[Pi]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "    The branch cut for  ",
  Cell[BoxData[
      \(\(f\_\[Alpha]\) \((z)\)\)]],
  "  is the ray  ",
  Cell[BoxData[
      \(r \[GreaterEqual] 0, \[Theta] = \[Alpha]\)]],
  ",  which includes the origin.  The point ",
  Cell[BoxData[
      \(z = 0\)]],
  ", common to all branch cuts for the multivalued square root function, is \
called a branch point.  The mapping ",
  Cell[BoxData[
      \(w = \(f\_\[Alpha]\) \((z)\)\)]],
  " and its branch cut are illustrated in Figure 2.19."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.941 1 .941 r
0 .5 m
0 0 L
1 0 L
1 1 L
0 1 L
0 .5 L
F
1 1 1 r
.85 1.10622 m
.83788 1.11322 L
.48788 .507 L
.51212 .493 L
.86212 1.09922 L
.85 1.10622 L
F
0 g
.5 Mabswid
[ ] 0 setdash
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
.79676 1 m
.51306 .50862 L
s
[ .02 .02 ] 0 setdash
.78059 1 m
.50006 .51411 L
s
0 1 0 r
[ ] 0 setdash
newpath
.5 .5 .35 0 57.7082 arc
s
0 g
gsave
.8375 .6875 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.98 .525 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5375 .98 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{199, 199},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000370000ab000`400?l00000o`00003oH`3oool0
0`000000oooo0?ooo`1Q0?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol003
0000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`
oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
06<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040
oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`
oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`
0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`
0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<00000
0?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol003
0000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`
oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
06<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040
oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`
oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`
0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`
0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<00000
0?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol003
0000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`
oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
06<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040
oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`
oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`
0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`
0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<00000
0?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol003
0000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`
oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
06<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040
oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`
oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`
0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`
0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<00000
0?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol003
0000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`
oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
06<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040
oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`
oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`
0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`
0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<00000
0?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol003
0000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`
oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
06<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040
oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`
oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`
0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`
0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<00000
0?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol003
0000003`oo00l?o`0600l?o`0@3oool006<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`
oo000`000000l?o`0?3ol01P0?3ol040oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool0
06<0l?o`00<000000?3ol03`oo00H03`oo010?ooo`00H`3`oo000`000000l?o`0?3ol01P0?3ol040
oooo001S0?3ol0030000003`oo00l?o`0600l?o`0@3oool00:P0000000<00?l00000000000007000
00000680l?o`00<0oooo0000003oool00P3ooom10?3ol003003o003`oo00l?o`01/0l?o`0@3oool0
0600l?o`0`3oool010000000oooo0000003ooom10?3ol003003o003`oo00l?o`01/0l?o`0@3oool0
0640l?o`0P3oool01@000000oooo0?ooo`000000oooo0400l?o`00<00?l00?3ol03`oo006`3`oo01
0?ooo`00HP3`oo001P3oool000000?ooo`3oool000000?oood00l?o`00<00?l00?3ol03`oo004`3`
oo0200000080l?o`0P0000020?3ol040oooo001R0?3ol0030?ooo`000000oooo0080oooo00<00000
0?ooo`3`oo00?P3`oo000`00o`00l?o`0?3ol00D0?3ol0040000003`oo00l?o`000000<0l?o`0@3o
ool006<0l?o`00D000000?ooo`3oool0oooo000000020?ooocd0l?o`00<00?l00?3ol03`oo005P3`
oo02000000@0l?o`0@3oool006<0l?o`00<000000?ooo`0000000P3oool00`000000oooo0?3ol00l
0?3ol003003o003`oo00l?o`01H0l?o`0P0000040?3ol040oooo001S0?3ol0060000003oool0oooo
0000003oool000000P3oooll0?3ol003003o003`oo00l?o`01D0l?o`00@000000?3ol03`oo000000
0`3`oo010?ooo`00H`3`oo0010000000l?o`0?ooo`0000020?ooo`030000003oool0l?o`03/0l?o`
00<00?l00?3ol03`oo00503`oo0200000080l?o`0P0000020?3ol040oooo001S0?3ol0050000003`
oo00oooo0?ooo`0000000P3oool00`000000oooo0?3ol00j0?3ol003003o003`oo00l?o`01`0l?o`
0@3oool006<0l?o`00<000000?3ol03`oo00103oool00`000000oooo0?3ol00j0?3ol003003o003`
oo00l?o`01`0l?o`0@3oool006<0l?o`00<000000?3ol03`oo001@3oool00`000000oooo0?3ol00i
0?3ol003003o003`oo00l?o`01`0l?o`0@3oool006<0l?o`00@000000?3ol03`oo00l?o`103oool0
0`000000oooo0?ooo`0i0?3ol003003o003`oo00l?o`01`0l?o`0@3oool006<0l?o`00@000000?3o
l03`oo00l?o`0P3oool01@000000oooo0?ooo`000000oooo03T0l?o`00<00?l00?3ol03`oo00703`
oo010?ooo`00H`3`oo000`000000l?o`0?3ol0020?3ol080oooo00D000000?ooo`3oool000000?oo
o`0g0?3ol003003o003`oo00l?o`01d0l?o`0@3oool006<0l?o`00<000000?3ol03`oo000`3`oo00
1P3oool000000?ooo`3oool000000?ooocL0l?o`00<00?l00?3ol03`oo007@3`oo010?ooo`00H`3`
oo000`000000l?o`0?3ol0030?3ol080oooo00D000000?ooo`3oool000000?ooo`0f0?3ol003003o
003`oo00l?o`01d0l?o`0@3oool006<0l?o`00<000000?3ol03`oo00103`oo040?ooo`030000003o
ool0l?o`03D0l?o`00<00?l00?3ol03`oo007@3`oo010?ooo`00H`3`oo000`000000l?o`0?3ol004
0?3ol0D0oooo00<000000?ooo`3`oo00<`3`oo000`00o`00l?o`0?3ol00N0?3ol040oooo001S0?3o
l0030000003`oo00l?o`00D0l?o`103oool00`000000oooo0?ooo`0c0?3ol003003o003`oo00l?o`
01h0l?o`0@3oool006<0l?o`00<000000?3ol03`oo001@3`oo000`3oool000000?ooo`020?ooo`03
0000003oool0l?o`0340l?o`00<00?l00?3ol03`oo007`3`oo010?ooo`00H`3`oo000`000000l?o`
0?3ol0060?3ol0030?ooo`000000oooo0080oooo00<000000?ooo`3`oo00<03`oo000`00o`00l?o`
0?3ol00O0?3ol040oooo001S0?3ol0030000003`oo00l?o`00L0l?o`00H000000?ooo`3oool0oooo
0000003ooola0?3ol003003o003`oo00l?o`01l0l?o`0@3oool006<0l?o`00<000000?3ol03`oo00
1`3`oo000`3oool000000?ooo`020?ooo`030000003oool0l?o`02l0l?o`00<00?l00?3ol03`oo00
7`3`oo010?ooo`00H`3`oo000`000000l?o`0?3ol0080?3ol0@0oooo00<000000?ooo`3`oo00;P3`
oo000`00o`00l?o`0?3ol00P0?3ol040oooo001S0?3ol0030000003`oo00l?o`00P0l?o`1@3oool0
0`000000oooo0?3ol00]0?3ol003003o003`oo00l?o`0200l?o`0@3oool006<0l?o`00<000000?3o
l03`oo002@3`oo001@3oool000000?ooo`3oool000000080oooo;03`oo000`00o`00l?o`0?3ol00Q
0?3ol040oooo001S0?3ol0030000003`oo00l?o`00T0l?o`00<0oooo0000003oool00P3oool00`00
0000oooo0?3ol00[0?3ol003003o003`oo00l?o`0240l?o`0@3oool006<0l?o`00<000000?3ol03`
oo002P3`oo000`3oool000000?ooo`020?ooo`030000003oool0l?o`02T0l?o`00<00?l00?3ol03`
oo008P3`oo010?ooo`00H`3`oo000`000000l?o`0?3ol00;0?3ol0060000003oool0oooo0?ooo`00
0000oooo:P3`oo000`00o`00l?o`0?3ol00R0?3ol040oooo001S0?3ol0030000003`oo00l?o`00/0
l?o`00<0oooo0000003oool00P3oool00`000000oooo0?3ol00W0?3ol003003o003`oo00l?o`02<0
l?o`0@3oool006<0l?o`00<000000?3ol03`oo00303`oo040?ooo`030000003oool0l?o`02L0l?o`
00<00?l00?3ol03`oo008`3`oo010?ooo`00H`3`oo000`000000l?o`0?3ol00<0?3ol0D0oooo00<0
00000?ooo`3`oo009@3`oo000`00o`00l?o`0?3ol00T0?3ol040oooo001S0?3ol0030000003`oo00
l?o`00d0l?o`00D0oooo0000003oool0oooo000000020?ooobD0l?o`00<00?l00?3ol03`oo00903`
oo010?ooo`00H`3`oo000`000000l?o`0?3ol00=0?3ol0030?ooo`000000oooo0080oooo00<00000
0?ooo`3`oo008`3`oo000`00o`00l?o`0?3ol00U0?3ol040oooo001S0?3ol0030000003`oo00l?o`
00h0l?o`00<0oooo0000003oool00P3oool00`000000oooo0?3ol00R0?3ol003003o003`oo00l?o`
0080l?o`0P0000020?3ol0030000003`oo00l?o`01`0l?o`0@3oool006<0l?o`00<000000?3ol03`
oo003`3`oo001P000000oooo0?ooo`3oool000000?ooob80l?o`00<00?l00?3ol03`oo000P3`oo00
0`000000l?o`0?3ol002000001l0l?o`0@3oool006<0l?o`00<000000?3ol03`oo003`3`oo000`3o
ool000000?ooo`020?ooo`030000003oool0l?o`0200l?o`00<00?l00?3ol03`oo000P3`oo001@00
0000l?o`0?3ol03`oo00000001l0l?o`0@3oool006<0l?o`00<000000?3ol03`oo00403`oo040?oo
o`030000003oool0l?o`01l0l?o`00<00?l00?3ol03`oo000`3`oo001@000000l?o`0?3ol03`oo00
000001l0l?o`0@3oool006<0l?o`00<000000?3ol03`oo00403`oo050?ooo`030000003oool0l?o`
01h0l?o`00<00?l00?3ol03`oo000`3`oo001@000000l?o`0?3ol03`oo00000001l0l?o`0@3oool0
06<0l?o`00<000000?3ol03`oo004@3`oo000`3oool000000?ooo`020?ooo`030000003oool0l?o`
01`0l?o`00<00?l00?3ol03`oo001@3`oo03000000030?3ol0000000l?o`01d0l?o`0@3oool006<0
l?o`00<000000?3ol03`oo004@3`oo000`3oool000000?ooo`020?ooo`030000003oool0l?o`01/0
l?o`00<00?l00?3ol03`oo00:@3`oo010?ooo`00H`3`oo000`000000l?o`0?3ol00B0?3ol0030?oo
o`000000oooo0080oooo00<000000?ooo`3`oo006@3`oo000`00o`00l?o`0?3ol00Z0?3ol040oooo
001S0?3ol0030000003`oo00l?o`01<0l?o`00H000000?ooo`3oool0oooo0000003ooolI0?3ol003
003o003`oo00l?o`02/0l?o`0@3oool006<0l?o`00<000000?3ol03`oo004`3`oo000`3oool00000
0?ooo`020?ooo`030000003oool0l?o`01L0l?o`00<00?l00?3ol03`oo00:`3`oo010?ooo`00H`3`
oo000`000000l?o`0?3ol00D0?3ol0@0oooo00<000000?ooo`3oool05@3`oo02003o02h0l?o`0@3o
ool006<0l?o`00<000000?3ol03`oo00503`oo050?ooo`030000003oool0l?o`01<0l?o`00<00?l0
0?3ol03`oo00;P3`oo010?ooo`00H`3`oo000`000000l?o`0?3ol00E0?3ol0030?ooo`000000oooo
0080oooo00<000000?ooo`3`oo004P3`oo000`00o`00l?o`0?3ol00^0?3ol040oooo001S0?3ol003
0000003`oo00l?o`01H0l?o`00H0oooo0000003oool0oooo0000003ooolB0?3ol003003o003`oo00
l?o`02l0l?o`0@3oool006<0l?o`00<000000?3ol03`oo005P3`oo000`3oool000000?ooo`020?oo
o`030000003oool0l?o`00l0l?o`00<00?l00?3ol03`oo00<03`oo010?ooo`00H`3`oo000`000000
l?o`0?3ol00G0?3ol0060?ooo`000000oooo0?ooo`000000oooo3`3`oo000`00o`00l?o`0?3ol00a
0?3ol040oooo001S0?3ol0030000003`oo00l?o`01L0l?o`1@3oool00`000000oooo0?3ol00<0?3o
l003003o003`oo00l?o`0380l?o`0@3oool006<0l?o`00<000000?3ol03`oo00603`oo040?ooo`03
0000003oool0oooo00/0l?o`00<00?l00?3ol03`oo00<`3`oo010?ooo`00H`3`oo000`000000l?o`
0?3ol00H0?3ol0D0oooo00<000000?ooo`3`oo002@3`oo000`00o`00l?o`0?3ol00d0?3ol040oooo
001S0?3ol0030000003`oo00l?o`01T0l?o`00<0oooo0000003oool00P3oool00`000000oooo0?3o
l0060?3ol0800?l0=`3`oo010?ooo`00H`3`oo000`000000l?o`0?3ol00J0?3ol0060?ooo`000000
oooo0?ooo`000000oooo1P3`oo000`00o`00l?o`0?3ol00g0?3ol040oooo001S0?3ol0030000003`
oo00l?o`01X0l?o`00<0oooo0000003oool00P3oool00`000000oooo0?3ol0030?3ol003003o003`
oo00l?o`03P0l?o`0@3oool006<0l?o`00<000000?3ol03`oo006`3`oo001P3oool000000?ooo`3o
ool000000?ooo`80l?o`0P00o`0k0?3ol040oooo001S0?3ol0030000003`oo00l?o`01/0l?o`1@3o
ool00`000000oooo003o000m0?3ol040oooo001S0?3ol0030000003`oo00l?o`01`0l?o`103oool0
0`000000oooo0?ooo`0m0?3ol040oooo001S0?3ol0030000003`oo00l?o`01`0l?o`1@3oool00`00
0000oooo0?3ol00l0?3ol040oooo001S0?3ol0030000003`oo00l?o`01d0l?o`00<0oooo0000003o
ool00P3oool00`000000oooo0?3ol00k0?3ol040oooo001S0?3ol0030000003`oo00l?o`01h0l?o`
00H0oooo0000003oool0oooo0000003oooll0?3ol040oooo001S0?3ol0030000003`oo00l?o`01h0
l?o`00<0oooo0000003oool00P3oool00`000000oooo0?3ol00j0?3ol040oooo001S0?3ol0030000
003`oo00l?o`01l0l?o`00H0oooo0000003oool0oooo0000003ooolk0?3ol040oooo001S0?3ol003
0000003`oo00l?o`01l0l?o`1@3oool00`000000oooo0?3ol00i0?3ol040oooo001S0?3ol0030000
003`oo00l?o`0200l?o`1@3oool00`000000oooo0?3ol00h0?3ol040oooo001S0?3ol0030000003`
oo00l?o`0200l?o`1@3oool00`000000oooo0?3ol00h0?3ol040oooo001S0?3ol0030000003`oo00
l?o`0240l?o`00<0oooo0000003oool00P3oool00`000000oooo0?3ol00g0?3ol040oooo001S0?3o
l0030000003`oo00l?o`0280l?o`00H0oooo0000003oool0oooo0000003ooolh0?3ol040oooo001S
0?3ol0030000003`oo00l?o`0280l?o`00<0oooo0000003oool00P3oool00`000000oooo0?3ol00f
0?3ol040oooo001S0?3ol0030000003`oo00l?o`02<0l?o`00H0oooo0000003oool0oooo0000003o
oolg0?3ol040oooo001S0?3ol0030000003`oo00l?o`02<0l?o`1@3oool00`000000oooo0?3ol00e
0?3ol040oooo001S0?3ol0030000003`oo00l?o`02@0l?o`1@3oool00`000000oooo0?3ol00d0?3o
l040oooo001S0?3ol0030000003`oo00l?o`02@0l?o`0P3oool01@000000oooo0?ooo`000000oooo
03D0l?o`0@3oool006<0l?o`00<000000?3ol03`oo009@3`oo000`3oool000000?ooo`020?ooo`03
0000003oool0l?o`03<0l?o`0@3oool006<0l?o`00<000000?3ol03`oo009P3`oo001P3oool00000
0?ooo`3oool000000?oooc@0l?o`0@3oool006<0l?o`00<000000?3ol03`oo009P3`oo000`3oool0
00000?ooo`020?ooo`030000003oool0l?o`0380l?o`0@3oool006<0l?o`00<000000?3ol03`oo00
9`3`oo001P3oool000000?ooo`3oool000000?oooc<0l?o`0@3oool006<0l?o`00<000000?3ol03`
oo009`3`oo050?ooo`030000003oool0l?o`0340l?o`0@3oool006<0l?o`00<000000?3ol03`oo00
:03`oo050?ooo`030000003oool0l?o`0300l?o`0@3oool006<0l?o`00<000000?3ol03`oo00:03`
oo020?ooo`050000003oool0oooo0000003oool0<@3`oo010?ooo`00H`3`oo000`000000l?o`0?3o
l00Y0?3ol0030?ooo`000000oooo0080oooo00<000000?ooo`3`oo00;`3`oo010?ooo`00H`3`oo00
0`000000l?o`0?3ol00Z0?3ol0060?ooo`000000oooo0?ooo`000000oooo<03`oo010?ooo`00H`3`
oo000`000000l?o`0?3ol00Z0?3ol0030?ooo`000000oooo0080oooo00<000000?ooo`3`oo00;P3`
oo010?ooo`00H`3`oo000`000000l?o`0?3ol00[0?3ol0050?ooo`000000oooo0?ooo`0000000P3o
ool^0?3ol040oooo001S0?3ol0030000003`oo00l?o`02/0l?o`1@3oool00`000000oooo0?3ol00]
0?3ol040oooo001S0?3ol0030000003`oo00l?o`02`0l?o`1@3oool00`000000oooo0?3ol00/0?3o
l040oooo001S0?3ol0030000003`oo00l?o`02d0l?o`00H0oooo0000003oool0oooo0000003oool]
0?3ol040oooo001S0?3ol0030000003`oo00l?o`02d0l?o`00<0oooo0000003oool00P3oool00`00
0000oooo0?3ol00[0?3ol040oooo001S0?3ol0030000003`oo00l?o`02h0l?o`00H0oooo0000003o
ool0oooo0000003oool/0?3ol040oooo001S0?3ol0040000003`oo00l?o`0?3ol0@00000:@3`oo00
0`3oool000000?ooo`020?ooo`030000003oool0l?o`02X0l?o`0@3oool006<0l?o`00<000000?3o
l03`oo000`3`oo000`000000l?o`0?3ol00Y0?3ol0030?ooo`000000oooo0080oooo00<000000?oo
o`3`oo00:@3`oo010?ooo`00H`3`oo000`000000l?o`0?3ol0030?3ol0030000003`oo00l?o`02T0
l?o`1@3oool00`000000oooo0?3ol00Y0?3ol040oooo001S0?3ol0030000003`oo00l?o`00<0l?o`
0P00000[0?3ol0D0oooo00<000000?ooo`3`oo00:03`oo010?ooo`00H`3`oo000`000000l?o`0?3o
l0020?3ol0030000003`oo00000002`0l?o`00H0oooo0000003oool0oooo0000003ooolY0?3ol040
oooo001S0?3ol0030000003`oo00l?o`0080l?o`00@000000?3ol03`oo000000:`3`oo020?ooo`05
0000003oool0oooo0000003oool0:03`oo010?ooo`00H`3`oo001@000000l?o`0?3ol03`oo000000
00<0l?o`00<000000?3ol03`oo00:P3`oo001P3oool000000?ooo`3oool000000?ooobP0l?o`0@3o
ool006<0l?o`00<000000?3ol03`oo000`000000103`oo00000000000000000[0?3ol080oooo00D0
00000?ooo`3oool000000?ooo`0W0?3ol040oooo0000\
\>"],
    ImageRangeCache->{{{0, 198}, {198, 0}} -> {-2, -2, 0, 0}}],
  StyleBox["          ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.941 1 .941 r
.5 .5 m
1.10622 .85 L
.75622 1.45622 L
-0.45622 .75622 L
-0.10622 .15 L
.5 .5 L
F
0 g
.5 Mabswid
[ ] 0 setdash
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
.5 .5 m
0 0 rlineto s
.5 .5 m
0 .21132 L
s
[ .02 .02 ] 0 setdash
1 .78868 m
.5 .5 L
s
0 1 0 r
[ ] 0 setdash
newpath
.5 .5 .35 0 30 arc
s
0 g
gsave
.8875 .6125 -73.7813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.188 12.813 moveto
(\\220) show
77.375 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.563 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.98 .525 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5375 .98 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{199, 199},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000370000ab000`400?l00000o`00003oH`3oool0
0`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000
oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?oo
o`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?oo
o`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3o
ool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`00
0000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo
0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q
0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00
H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool0
0`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000
oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?oo
o`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?oo
o`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3o
ool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`00
0000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo
0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q
0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00
H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool0
0`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000oooo0?ooo`1Q0?ooo`0000<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`1Q0?ooo`0000<0l?o`000000000000H03oool00`000000oooo
0?ooo`1Q0?ooo`000`3`oo02000005h0oooo00<000000?ooo`3oool0H@3oool000D0l?o`0P00001L
0?ooo`030000003oool0oooo0640oooo00070?3ol0030000003oool0oooo05T0oooo00<000000?oo
o`3oool0H@3oool000P0l?o`0P00001I0?ooo`030000003oool0oooo0640oooo000:0?3ol0800000
E`3oool00`000000oooo0?ooo`1Q0?ooo`00303`oo02000005D0oooo00<000000?ooo`3oool0H@3o
ool000h0l?o`00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1Q0?ooo`003`3`oo020000
0580oooo00<000000?ooo`3oool0H@3oool00140l?o`0P00001@0?ooo`030000003oool0oooo0640
oooo000C0?3ol0030000003oool0oooo04d0oooo00<000000?ooo`3oool0H@3oool001@0l?o`0P00
001=0?ooo`030000003oool0oooo0640oooo000F0?3ol0800000B`3oool00`000000oooo0?ooo`1Q
0?ooo`00603`oo02000004T0oooo00<000000?ooo`3oool0H@3oool001X0l?o`00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`1Q0?ooo`006`3`oo02000004H0oooo00<000000?ooo`3oool0
H@3oool001d0l?o`0P0000140?ooo`030000003oool0oooo0640oooo000O0?3ol0800000@P3oool0
0`000000oooo0?ooo`1Q0?ooo`008@3`oo000`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
0640oooo000R0?3ol0800000?`3oool00`000000oooo0?ooo`1Q0?ooo`00903`oo02000003d0oooo
00<000000?ooo`3oool0H@3oool002H0l?o`0P00000k0?ooo`030000003oool0oooo0640oooo000X
0?3ol0030000003oool0oooo03P0oooo00<000000?ooo`3oool0H@3oool002T0l?o`0P00000h0?oo
o`030000003oool0oooo0640oooo000[0?3ol0800000=P3oool00`000000oooo0?ooo`1Q0?ooo`00
;@3`oo02000003@0oooo00<000000?ooo`3oool0H@3oool002l0l?o`00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`1Q0?ooo`00<03`oo0200000340oooo00<000000?ooo`3oool0H@3oool0
0380l?o`0P00000_0?ooo`030000003oool0oooo0640oooo000d0?3ol0030000003oool0oooo02`0
oooo00<000000?ooo`3oool0H@3oool003D0l?o`0P00000/0?ooo`030000003oool0oooo0640oooo
000g0?3ol0800000:P3oool00`000000oooo0?ooo`1Q0?ooo`00>@3`oo02000002P0oooo00<00000
0?ooo`3oool0H@3oool003/0l?o`00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1Q0?oo
o`00?03`oo02000002D0oooo00<000000?ooo`3oool0H@3oool003h0l?o`0P00000S0?ooo`030000
003oool0oooo0640oooo00100?3ol08000008@3oool00`000000oooo0?ooo`1Q0?ooo`00@P3`oo00
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0640oooo00130?3ol08000007P3oool00`00
0000oooo0?ooo`1Q0?ooo`00A@3`oo02000001`0oooo00<000000?ooo`3oool0H@3oool004L0l?o`
0P00000J0?ooo`030000003oool0oooo0640oooo00190?3ol0030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0H@3oool004X0l?o`0P00000G0?ooo`030000003oool0oooo0640oooo001<0?3o
l08000005@3oool00`000000oooo0?ooo`1Q0?ooo`00CP3`oo02000001<0oooo00<000000?ooo`3o
ool0H@3oool00500l?o`00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1Q0?ooo`00D@3`
oo0200000100oooo00<000000?ooo`3oool0H@3oool005<0l?o`0P00000>0?ooo`030000003oool0
oooo0640oooo001E0?3ol0030000003oool0oooo00/0oooo00<000000?ooo`3oool0H@3oool005H0
l?o`0P00000;0?ooo`030000003oool0oooo0640oooo001H0?3ol08000002@3oool00`000000oooo
0?ooo`1Q0?ooo`00FP3`oo02000000L0oooo00<000000?ooo`3oool0H@3oool005`0l?o`00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1Q0?ooo`00G@3`oo02000000@0oooo00<000000?oo
o`3oool0H@3oool005l0l?o`0P0000020?ooo`030000003oool0oooo0640oooo001Q0?3ol0<00000
H`3oool00:P0000000<00?l00000000000007000000006<0l?o`0P0000130?ooo`03003o003oool0
oooo01`0oooo001S0?3ol0040000003`oo0000000?3ol440oooo00<00?l00?ooo`3oool0703oool0
06<0l?o`00<000000?3ol03`oo000`3`oo0o0?ooo`03003o003oool0oooo01`0oooo001S0?3ol003
0000003`oo00l?o`00<0l?o`00<000000?ooo`3oool0?03oool00`00o`00oooo0?ooo`0E0?ooo`80
000000<0oooo0000000000000P3oool006<0l?o`00<000000?3ol03`oo00103`oo02000003`0oooo
00<00?l00?ooo`3oool0503oool00`000000oooo0?ooo`02000000<0oooo001S0?3ol0030000003`
oo00l?o`00H0l?o`00<000000?3ol03oool0>03oool00`00o`00oooo0?ooo`0E0?ooo`050000003o
ool0oooo0?ooo`0000000`3oool006<0l?o`00<000000?3ol03`oo002@3`oo0h0?ooo`03003o003o
ool0oooo01D0oooo00D000000?ooo`3oool0oooo000000030?ooo`00H`3`oo000`000000l?o`0?3o
l00:0?3ol0030000003oool0oooo03@0oooo00<00?l00?ooo`3oool05@3oool01@000000oooo0?oo
o`3oool0000000<0oooo001S0?3ol0030000003`oo00l?o`00/0l?o`0P00000d0?ooo`03003o003o
ool0oooo01@0oooo0P0000020?ooo`8000000`3oool006<0l?o`00<000000?3ol03`oo003@3`oo00
0`000000l?o`0?ooo`0a0?ooo`03003o003oool0oooo01d0oooo001S0?3ol0030000003`oo00l?o`
0100l?o`<@3oool00`00o`00oooo0?ooo`0M0?ooo`00H`3`oo000`000000l?o`0?3ol00A0?3ol003
0000003oool0oooo02d0oooo00<00?l00?ooo`3oool07@3oool006<0l?o`00<000000?3ol03`oo00
4P3`oo02000002`0oooo00<00?l00?ooo`3oool07P3oool006<0l?o`00<000000?3ol03`oo00503`
oo000`000000oooo0?ooo`0Y0?ooo`03003o003oool0oooo01h0oooo001S0?3ol0030000003`oo00
l?o`01L0l?o`:@3oool00`00o`00oooo0?ooo`0N0?ooo`00H`3`oo000`000000l?o`0?3ol00G0?3o
l0030000003`oo00oooo02H0oooo00<00?l00?ooo`3oool07P3oool006<0l?o`00<000000?3ol03`
oo00603`oo02000000030?3ol03oool0oooo0280oooo00<00?l00?ooo`3oool07`3oool006<0l?o`
00<000000?3ol03`oo006P3`oo02000002<0oooo00<00?l00?ooo`3oool07`3oool006<0l?o`00<0
00000?3ol03`oo007P3`oo0Q0?ooo`03003o003oool0oooo01l0oooo001S0?3ol0030000003`oo00
l?o`01h0l?o`00<000000?3ol03oool07P3oool00`00o`00oooo0?ooo`060?ooo`030000003oool0
oooo01H0oooo001S0?3ol0030000003`oo00l?o`01l0l?o`0P00000N0?ooo`8000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo1@00000>0?ooo`00H`3`oo000`000000
l?o`0?3ol00Q0?3ol08000006`3oool00`000000oooo0?ooo`02000000H0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000h0oooo001S0?3ol0030000003`oo00l?o`02D0
l?o`6@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0?0?ooo`00H`3`oo000`000000l?o`0?3ol00U0?3ol0030000003`oo00oooo01D0
oooo00<00?l00000003oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03P3oool006<0l?o`00<000000?3ol03`oo009P3`oo02000001D0oooo
00<00?l00000003oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03@3oool006<0l?o`00<000000?3ol03`oo00:03`oo02000001<0oooo00<0
0?l00?ooo`0000000P0000000`3oool000000?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0303oool006<0l?o`00<000000?3ol03`oo00;03`oo0A0?ooo`03003o003oool0
oooo00X0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00`0oooo001S
0?3ol0030000003`oo00l?o`02`0l?o`00<000000?ooo`3oool03@3oool00`00o`00oooo0?ooo`0<
0?ooo`040000003oool0oooo0?ooo`<000003`3oool006<0l?o`00<000000?3ol03`oo00;@3`oo02
000000d0oooo00<00?l00?ooo`3oool08P3oool006<0l?o`00<000000?3ol03`oo00;`3`oo000`00
0000l?o`0?ooo`090?ooo`03003o003oool0oooo02<0oooo001S0?3ol0030000003`oo00l?o`03<0
l?o`203oool00`00o`00oooo0?ooo`0S0?ooo`00H`3`oo000`000000l?o`0?3ol00c0?3ol0030000
003oool0oooo00@0oooo00<00?l00?ooo`3oool0903oool006<0l?o`00<000000?3ol03`oo00=03`
oo02000000@0oooo00<00?l00?ooo`3oool0903oool006<0l?o`00<000000?3ol03`oo00=P3`oo00
10000000l?o`0?ooo`00o`0W0?ooo`00H`3`oo000`000000l?o`0?3ol00i0?3ol003003o003oool0
oooo02D0oooo001S0?3ol0030000003`oo00l?o`03X0l?o`00<000000?ooo`3oool0903oool006<0
l?o`00<000000?3ol03`oo00>`3`oo02000002@0oooo001S0?3ol0030000003`oo00l?o`03d0l?o`
00<000000?3ol03oool08@3oool006<0l?o`00<000000?3ol03`oo00@03`oo0Q0?ooo`00H`3`oo00
0`000000l?o`0?3ol0110?3ol0030000003oool0oooo01d0oooo001S0?3ol0030000003`oo00l?o`
0480l?o`0P00000M0?ooo`00H`3`oo000`000000l?o`0?3ol0140?3ol0030000003oool0oooo01X0
oooo001S0?3ol0030000003`oo00l?o`04L0l?o`6P3oool006<0l?o`00<000000?3ol03`oo00A`3`
oo000`000000l?o`0?ooo`0G0?ooo`00H`3`oo000`000000l?o`0?3ol0180?3ol080000000<0l?o`
0?ooo`3oool0503oool006<0l?o`00<000000?3ol03`oo00BP3`oo02000001D0oooo001S0?3ol003
0000003`oo00l?o`04h0l?o`4`3oool006<0l?o`00<000000?3ol03`oo00CP3`oo000`000000l?o`
0?ooo`0@0?ooo`00H`3`oo000`000000l?o`0?3ol01?0?3ol0800000403oool006<0l?o`00<00000
0?3ol03`oo00D@3`oo02000000h0oooo001S0?3ol0030000003`oo00l?o`05D0l?o`303oool006<0
l?o`00<000000?3ol03`oo00E@3`oo000`000000l?o`0?ooo`090?ooo`00H`3`oo000`000000l?o`
0?3ol01F0?3ol08000002@3oool006<0l?o`00<000000?3ol03`oo00F03`oo02000000L0oooo001S
0?3ol0030000003`oo00l?o`05`0l?o`1@3oool006<0l?o`00<000000?3ol03`oo00G03`oo000`00
0000oooo0?ooo`020?ooo`00H`3`oo000`000000l?o`0?3ol01M0?3ol08000000P3oool006<0l?o`
00<000000?3ol03`oo00G`3`oo0200000000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo00
0`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000
l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3o
l01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3o
l000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`
oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`00
0000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`
0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q
0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000
H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo00
0`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000
l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3o
l01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3o
l000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`
oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`00
0000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol01Q0?3ol000H`3`oo000`000000l?o`
0?3ol01Q0?3ol000H`3`oo000`000000l?o`0?3ol0030?3ol0030000003`oo00l?o`05/0l?o`001S
0?3ol0030000003`oo00l?o`0080l?o`00<000000?3ol0000000G03`oo0006<0l?o`00<000000?3o
l03`oo000P3`oo000`000000l?o`0000001L0?3ol000H`3`oo001@000000l?o`0?3ol03`oo000000
00<0l?o`00<000000?3ol03`oo00F@3`oo0006<0l?o`00D000000?3ol03`oo00l?o`000000030?3o
l0030000003`oo00l?o`05T0l?o`001S0?3ol0030000003`oo00l?o`00<0000000@0l?o`00000000
00000000FP3`oo000001\
\>"],
    ImageRangeCache->{{{0, 198}, {198, 0}} -> {-2, -2, 0, 0}}],
  StyleBox["   \n\t\t\t\tFigure 2.19",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The branch  ",
  Cell[BoxData[
      \(\(f\_\[Alpha]\) \((z)\)\)]],
  "  of  ",
  Cell[BoxData[
      \(f \((z)\) = z\^\(1\/2\)\)]],
  ".   "
}], "Text"],

Cell[TextData[{
  StyleBox["The Riemann Surface for",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  Cell[BoxData[
      \(w\  = \ z\^\(1\/2\)\)],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "\tA ",
  StyleBox[ButtonBox["Riemann surface",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RiemannSurface.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " is a construct useful for visualizing a multivalued function.  It was \
introduced by ",
  StyleBox[ButtonBox["Georg Friedrich Bernhard Riemann",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Riemann.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " (1826-1866) in 1851.  The idea is ingenious - a geometric construction \
that permits surfaces to be the domain or range of a multivalued function.  \
Riemann surfaces depend on the function being investigated.  We now give a \
nontechnical formulation of the Riemann surface for the multivalued square \
root function. "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["    ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.08151 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0538949 1.17484 5.10117e-017 1.17484 [
[ 0 0 0 0 ]
[ 1 1.08151 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.08151 L
0 1.08151 L
closepath
clip
newpath
.58664 .53899 m .59263 .54434 L .51103 .57603 L .146 .945 0 r
F
.65652 .50304 m .59263 .54434 L .58664 .53899 L .341 .936 0 r
F
.65652 .50304 m .67041 .50595 L .59263 .54434 L F
.51326 .56907 m .51103 .57603 L .42972 .60092 L 0 .941 .041 r
F
.58664 .53899 m .51103 .57603 L .51326 .56907 L .146 .945 0 r
F
.71911 .46176 m .67041 .50595 L .65652 .50304 L .548 .92 0 r
F
.71911 .46176 m .74029 .46137 L .67041 .50595 L F
.58052 .53418 m .58664 .53899 L .51326 .56907 L .145 .953 0 r
F
.64234 .50082 m .58664 .53899 L .58052 .53418 L .341 .946 0 r
F
.64234 .50082 m .65652 .50304 L .58664 .53899 L F
.77069 .41614 m .74029 .46137 L .71911 .46176 L .759 .899 0 r
F
.77069 .41614 m .79822 .41161 L .74029 .46137 L F
.44021 .59314 m .42972 .60092 L .35293 .61926 L 0 .92 .279 r
F
.51326 .56907 m .42972 .60092 L .44021 .59314 L 0 .941 .041 r
F
.69753 .46299 m .65652 .50304 L .64234 .50082 L .551 .93 0 r
F
.69753 .46299 m .71911 .46176 L .65652 .50304 L F
.51554 .56251 m .51326 .56907 L .44021 .59314 L 0 .943 .04 r
F
.58052 .53418 m .51326 .56907 L .51554 .56251 L .145 .953 0 r
F
.74274 .42167 m .71911 .46176 L .69753 .46299 L .765 .908 0 r
F
.74274 .42167 m .77069 .41614 L .71911 .46176 L F
.57426 .53007 m .58052 .53418 L .51554 .56251 L .143 .96 0 r
F
.62785 .49949 m .58052 .53418 L .57426 .53007 L .341 .957 0 r
F
.62785 .49949 m .64234 .50082 L .58052 .53418 L F
.44021 .59314 m .35293 .61926 L .37143 .61141 L 0 .92 .279 r
F
.45092 .58564 m .44021 .59314 L .37143 .61141 L 0 .913 .272 r
F
.51554 .56251 m .44021 .59314 L .45092 .58564 L 0 .943 .04 r
F
.67553 .4653 m .64234 .50082 L .62785 .49949 L .554 .942 0 r
F
.67553 .4653 m .69753 .46299 L .64234 .50082 L F
.51787 .55648 m .51554 .56251 L .45092 .58564 L 0 .942 .039 r
F
.57426 .53007 m .51554 .56251 L .51787 .55648 L .143 .96 0 r
F
.80773 .36774 m .79822 .41161 L .77069 .41614 L .786 .671 0 r
F
.80773 .36774 m .84025 .35826 L .79822 .41161 L F
.37143 .61141 m .35293 .61926 L .285 .63166 L 0 .877 .496 r
F
.71436 .42843 m .69753 .46299 L .67553 .4653 L .773 .919 0 r
F
.71436 .42843 m .74274 .42167 L .69753 .46299 L F
.45092 .58564 m .37143 .61141 L .39028 .60371 L 0 .913 .272 r
F
.46187 .57851 m .45092 .58564 L .39028 .60371 L 0 .899 .261 r
F
.51787 .55648 m .45092 .58564 L .46187 .57851 L 0 .942 .039 r
F
.56784 .52691 m .57426 .53007 L .51787 .55648 L .139 .964 0 r
F
.61302 .49934 m .57426 .53007 L .56784 .52691 L .34 .969 0 r
F
.61302 .49934 m .62785 .49949 L .57426 .53007 L F
.77487 .37831 m .77069 .41614 L .74274 .42167 L .793 .677 0 r
F
.77487 .37831 m .80773 .36774 L .77069 .41614 L F
.65309 .469 m .62785 .49949 L .61302 .49934 L .558 .956 0 r
F
.65309 .469 m .67553 .4653 L .62785 .49949 L F
.52026 .55118 m .51787 .55648 L .46187 .57851 L 0 .934 .038 r
F
.56784 .52691 m .51787 .55648 L .52026 .55118 L .139 .964 0 r
F
.37143 .61141 m .285 .63166 L .31094 .62439 L 0 .877 .496 r
F
.39028 .60371 m .37143 .61141 L .31094 .62439 L 0 .858 .476 r
F
.68551 .43677 m .67553 .4653 L .65309 .469 L .782 .932 0 r
F
.68551 .43677 m .71436 .42843 L .67553 .4653 L F
.74164 .39022 m .74274 .42167 L .71436 .42843 L .802 .683 0 r
F
.74164 .39022 m .77487 .37831 L .74274 .42167 L F
.46187 .57851 m .39028 .60371 L .40949 .59626 L 0 .899 .261 r
F
.47306 .57191 m .46187 .57851 L .40949 .59626 L 0 .871 .245 r
F
.52026 .55118 m .46187 .57851 L .47306 .57191 L 0 .934 .038 r
F
.56127 .52507 m .56784 .52691 L .52026 .55118 L .134 .961 0 r
F
.59785 .50079 m .56784 .52691 L .56127 .52507 L .336 .979 0 r
F
.59785 .50079 m .61302 .49934 L .56784 .52691 L F
.63018 .47457 m .61302 .49934 L .59785 .50079 L .561 .971 0 r
F
.63018 .47457 m .65309 .469 L .61302 .49934 L F
.82707 .31869 m .84025 .35826 L .80773 .36774 L .79 .435 0 r
F
.82707 .31869 m .86275 .30364 L .84025 .35826 L F
.39028 .60371 m .31094 .62439 L .33726 .61719 L 0 .858 .476 r
F
.40949 .59626 m .39028 .60371 L .33726 .61719 L 0 .828 .448 r
F
.52271 .54693 m .52026 .55118 L .47306 .57191 L 0 .909 .035 r
F
.56127 .52507 m .52026 .55118 L .52271 .54693 L .134 .961 0 r
F
.47393 .84602 m .46714 .86728 L .38553 .82008 L 0 .628 .145 r
F
.55106 .88051 m .46714 .86728 L .47393 .84602 L .049 .624 0 r
F
.55106 .88051 m .55311 .90373 L .46714 .86728 L F
.70805 .40383 m .71436 .42843 L .68551 .43677 L .813 .691 0 r
F
.70805 .40383 m .74164 .39022 L .71436 .42843 L F
.31094 .62439 m .285 .63166 L .23043 .63903 L 0 .813 .681 r
F
.65619 .44719 m .65309 .469 L .63018 .47457 L .793 .947 0 r
F
.65619 .44719 m .68551 .43677 L .65309 .469 L F
.7912 .33487 m .80773 .36774 L .77487 .37831 L .798 .438 0 r
F
.7912 .33487 m .82707 .31869 L .80773 .36774 L F
.40079 .80165 m .38553 .82008 L .3127 .7626 L 0 .632 .36 r
F
.47393 .84602 m .38553 .82008 L .40079 .80165 L 0 .628 .145 r
F
.62799 .90487 m .55311 .90373 L .55106 .88051 L .187 .62 0 r
F
.62799 .90487 m .63895 .92924 L .55311 .90373 L F
.47306 .57191 m .40949 .59626 L .42907 .58916 L 0 .871 .245 r
F
.48451 .5661 m .47306 .57191 L .42907 .58916 L 0 .819 .219 r
F
.47242 .57211 m .48451 .5661 L .44904 .58258 L 0 0 0 r
F
.49487 .56094 m .47306 .57191 L .48451 .5661 L 0 .909 .035 r
F
.49622 .56147 m .48451 .5661 L .47242 .57211 L 0 0 0 r
F
.52271 .54693 m .49487 .56094 L .48451 .5661 L 0 .909 .035 r
F
.40949 .59626 m .33726 .61719 L .36397 .61011 L 0 .828 .448 r
F
.42907 .58916 m .40949 .59626 L .36397 .61011 L 0 .779 .406 r
F
.55453 .5252 m .56127 .52507 L .52271 .54693 L .122 .938 0 r
F
.58231 .50457 m .56127 .52507 L .55453 .5252 L .326 .982 0 r
F
.58231 .50457 m .59785 .50079 L .56127 .52507 L F
.75514 .35243 m .77487 .37831 L .74164 .39022 L .807 .441 0 r
F
.75514 .35243 m .7912 .33487 L .77487 .37831 L F
.31094 .62439 m .23043 .63903 L .2628 .63294 L 0 .813 .681 r
F
.33726 .61719 m .31094 .62439 L .2628 .63294 L 0 .781 .641 r
F
.60679 .48281 m .59785 .50079 L .58231 .50457 L .562 .987 0 r
F
.60679 .48281 m .63018 .47457 L .59785 .50079 L F
.48085 .82382 m .47393 .84602 L .40079 .80165 L 0 .621 .144 r
F
.54896 .85617 m .47393 .84602 L .48085 .82382 L .049 .617 0 r
F
.54896 .85617 m .55106 .88051 L .47393 .84602 L F
.67405 .41969 m .68551 .43677 L .65619 .44719 L .826 .701 0 r
F
.67405 .41969 m .70805 .40383 L .68551 .43677 L F
.33574 .74794 m .3127 .7626 L .25301 .69572 L 0 .637 .57 r
F
.40079 .80165 m .3127 .7626 L .33574 .74794 L 0 .632 .36 r
F
.52522 .54424 m .52271 .54693 L .48451 .5661 L 0 .848 .03 r
F
.50704 .55554 m .52522 .54424 L .49622 .56147 L 0 0 0 r
F
.54093 .53448 m .52271 .54693 L .52522 .54424 L .122 .938 0 r
F
.52779 .54416 m .52522 .54424 L .50704 .55554 L 0 0 0 r
F
.55453 .5252 m .54093 .53448 L .52522 .54424 L .122 .938 0 r
F
.41634 .7825 m .40079 .80165 L .33574 .74794 L 0 .626 .357 r
F
.48085 .82382 m .40079 .80165 L .41634 .7825 L 0 .621 .144 r
F
.61683 .87928 m .55106 .88051 L .54896 .85617 L .186 .613 0 r
F
.61683 .87928 m .62799 .90487 L .55106 .88051 L F
.62635 .46058 m .63018 .47457 L .60679 .48281 L .805 .966 0 r
F
.62635 .46058 m .65619 .44719 L .63018 .47457 L F
.70046 .91909 m .63895 .92924 L .62799 .90487 L .311 .617 0 r
F
.70046 .91909 m .72007 .94382 L .63895 .92924 L F
.71886 .37174 m .74164 .39022 L .70805 .40383 L .817 .445 0 r
F
.71886 .37174 m .75514 .35243 L .74164 .39022 L F
.33726 .61719 m .2628 .63294 L .29547 .62684 L 0 .781 .641 r
F
.36397 .61011 m .33726 .61719 L .29547 .62684 L 0 .733 .586 r
F
.42907 .58916 m .36397 .61011 L .39109 .60321 L 0 .779 .406 r
F
.44904 .58258 m .42907 .58916 L .39109 .60321 L 0 0 0 r
F
.48451 .5661 m .42907 .58916 L .44904 .58258 L 0 .819 .219 r
F
.52522 .54424 m .48451 .5661 L .49622 .56147 L 0 .848 .03 r
F
.48791 .80053 m .48085 .82382 L .41634 .7825 L 0 .614 .143 r
F
.54683 .83055 m .48085 .82382 L .48791 .80053 L .048 .609 0 r
F
.54683 .83055 m .54896 .85617 L .48085 .82382 L F
.33574 .74794 m .25301 .69572 L .28274 .68581 L 0 .637 .57 r
F
.35913 .7328 m .33574 .74794 L .28274 .68581 L 0 .631 .567 r
F
.41634 .7825 m .33574 .74794 L .35913 .7328 L 0 .626 .357 r
F
.63963 .4387 m .65619 .44719 L .62635 .46058 L .843 .714 0 r
F
.63963 .4387 m .67405 .41969 L .65619 .44719 L F
.43216 .76252 m .41634 .7825 L .35913 .7328 L 0 .619 .355 r
F
.48791 .80053 m .41634 .7825 L .43216 .76252 L 0 .614 .143 r
F
.82622 .27178 m .86275 .30364 L .82707 .31869 L .79 .211 0 r
F
.82622 .27178 m .86274 .2508 L .86275 .30364 L F
.68236 .39334 m .70805 .40383 L .67405 .41969 L .831 .45 0 r
F
.68236 .39334 m .71886 .37174 L .70805 .40383 L F
.60547 .85227 m .54896 .85617 L .54683 .83055 L .185 .604 0 r
F
.60547 .85227 m .61683 .87928 L .54896 .85617 L F
.68055 .89309 m .62799 .90487 L .61683 .87928 L .309 .608 0 r
F
.68055 .89309 m .70046 .91909 L .62799 .90487 L F
.54761 .52851 m .55453 .5252 L .52522 .54424 L .098 .855 0 r
F
.56639 .5121 m .55453 .5252 L .54761 .52851 L .297 .955 0 r
F
.56639 .5121 m .58231 .50457 L .55453 .5252 L F
.58287 .4953 m .58231 .50457 L .56639 .5121 L .551 .996 0 r
F
.58287 .4953 m .60679 .48281 L .58231 .50457 L F
.36397 .61011 m .29547 .62684 L .32845 .62071 L 0 .733 .586 r
F
.39109 .60321 m .36397 .61011 L .32845 .62071 L 0 0 0 r
F
.78972 .29383 m .82707 .31869 L .7912 .33487 L .797 .212 0 r
F
.78972 .29383 m .82622 .27178 L .82707 .31869 L F
.54761 .52851 m .52522 .54424 L .52779 .54416 L .098 .855 0 r
F
.59596 .47861 m .60679 .48281 L .58287 .4953 L .816 .988 0 r
F
.59596 .47861 m .62635 .46058 L .60679 .48281 L F
.2628 .63294 m .23043 .63903 L .22218 .63985 L 0 .686 .776 r
F
.2628 .63294 m .22218 .63985 L .22488 .63934 L F
.2628 .63294 m .22143 .63992 L .23001 .63831 L F
.2468 .6352 m .21065 .62088 L .2547 .63373 L 0 .642 .778 r
F
.23001 .63831 m .22886 .63728 L .2468 .6352 L F
.22886 .63728 m .21065 .62088 L .2468 .6352 L F
.2468 .6352 m .23001 .63831 L .24585 .63533 L 0 .686 .776 r
F
.2628 .63294 m .23001 .63831 L .2468 .6352 L F
.2628 .63294 m .24725 .63513 L .25498 .63424 L F
.24725 .63513 m .2468 .6352 L .25498 .63424 L F
.31281 .67567 m .28274 .68581 L .25498 .63424 L 0 .637 .773 r
F
.29547 .62684 m .2628 .63294 L .25571 .63412 L 0 .644 .714 r
F
.29547 .62684 m .25571 .63412 L .25877 .63355 L F
.29547 .62684 m .25498 .63424 L .26369 .63261 L F
.28062 .62946 m .24552 .61669 L .28852 .62799 L 0 .637 .773 r
F
.26369 .63261 m .26248 .63155 L .28062 .62946 L F
.26248 .63155 m .24552 .61669 L .28062 .62946 L F
.29547 .62684 m .26369 .63261 L .28062 .62946 L 0 .644 .714 r
F
.29547 .62684 m .28109 .62938 L .28879 .62852 L F
.28109 .62938 m .28062 .62946 L .28879 .62852 L F
.34322 .66528 m .31281 .67567 L .28879 .62852 L 0 .631 .768 r
F
.34322 .66528 m .28879 .62852 L .28923 .62847 L F
.31281 .67567 m .26369 .63261 L .28852 .62799 L 0 .637 .773 r
F
.28928 .62948 m .26833 .63368 L .29003 .63095 L 0 0 0 r
F
.32845 .62071 m .29547 .62684 L .2895 .62834 L F
.29302 .62769 m .2895 .62834 L .28879 .62852 L F
.32845 .62071 m .2895 .62834 L .29302 .62769 L F
.32845 .62071 m .28879 .62852 L .29767 .62687 L F
.32845 .62071 m .31522 .62357 L .32287 .62275 L F
.34322 .66528 m .29829 .62739 L .31509 .62422 L 0 .631 .768 r
F
.34322 .66528 m .31472 .62368 L .32287 .62275 L F
.37399 .65459 m .34322 .66528 L .32287 .62275 L 0 .624 .761 r
F
.37399 .65459 m .32287 .62275 L .32339 .6227 L F
.36175 .61459 m .32845 .62071 L .32356 .6225 L 0 0 0 r
F
.3277 .62174 m .32356 .6225 L .32287 .62275 L F
.36175 .61459 m .32356 .6225 L .3277 .62174 L F
.34975 .61768 m .32287 .62275 L .33195 .62108 L F
.36175 .61459 m .34967 .6177 L .35722 .61694 L F
.37399 .65459 m .33263 .62162 L .34952 .6184 L 0 .624 .761 r
F
.37399 .65459 m .34913 .61784 L .35722 .61694 L F
.4051 .64355 m .37399 .65459 L .35722 .61694 L 0 .615 .754 r
F
.4051 .64355 m .35722 .61694 L .35787 .61687 L F
.39537 .60849 m .36175 .61459 L .35789 .61659 L 0 0 0 r
F
.36287 .61568 m .35789 .61659 L .35722 .61694 L F
.39537 .60849 m .35789 .61659 L .36287 .61568 L F
.38456 .61173 m .35722 .61694 L .36657 .61524 L F
.39537 .60849 m .38445 .61176 L .39184 .61107 L F
.4051 .64355 m .36733 .61579 L .38427 .61253 L 0 .615 .754 r
F
.4051 .64355 m .38387 .61194 L .39184 .61107 L F
.43658 .63206 m .4051 .64355 L .39184 .61107 L 0 .605 .744 r
F
.43658 .63206 m .39184 .61107 L .3927 .61099 L F
.42931 .60244 m .39537 .60849 L .39248 .6106 L 0 0 0 r
F
.39871 .60949 m .39248 .6106 L .39184 .61107 L F
.42931 .60244 m .39248 .6106 L .39871 .60949 L F
.4198 .60569 m .39184 .61107 L .40157 .60933 L F
.42931 .60244 m .41964 .60574 L .42675 .60516 L F
.46359 .5965 m .42931 .60244 L .42675 .60516 L F
.43658 .63206 m .40247 .60991 L .41941 .6066 L 0 .605 .744 r
F
.43658 .63206 m .41898 .60597 L .42675 .60516 L F
.46841 .61992 m .43658 .63206 L .42675 .60516 L 0 .592 .732 r
F
.45563 .59951 m .42675 .60516 L .43711 .60335 L 0 0 0 r
F
.4982 .59083 m .46359 .5965 L .46193 .5992 L 0 .011 .141 r
F
.46841 .61992 m .43825 .60395 L .45506 .60058 L 0 .592 .732 r
F
.46841 .61992 m .45459 .5999 L .46193 .5992 L F
.50061 .60664 m .46841 .61992 L .46193 .5992 L 0 .574 .715 r
F
.49264 .59305 m .46193 .5992 L .4738 .59719 L 0 .011 .141 r
F
.50061 .60664 m .4746 .59748 L .49157 .59429 L 0 .574 .715 r
F
.50061 .60664 m .49111 .59367 L .4974 .5932 L F
.53316 .58713 m .50061 .60664 L .4974 .5932 L 0 .553 .685 r
F
.53316 .58713 m .52524 .58797 L .52312 .58884 L 0 .186 .346 r
F
.52524 .58797 m .4982 .59083 L .4974 .5932 L F
.52524 .58797 m .4974 .5932 L .49501 .6003 L F
.4982 .59083 m .49111 .59367 L .4974 .5932 L 0 .011 .141 r
F
.4982 .59083 m .46193 .5992 L .49264 .59305 L F
.50381 .58101 m .46359 .5965 L .4982 .59083 L 0 0 .069 r
F
.53316 .58713 m .50381 .58101 L .4982 .59083 L 0 .203 .284 r
F
.53316 .58713 m .4974 .5932 L .49633 .58869 L 0 .553 .685 r
F
.53316 .58713 m .52312 .58884 L .49501 .6003 L 0 .186 .346 r
F
.49157 .59429 m .4738 .59719 L .49111 .59367 L 0 .574 .715 r
F
.4746 .59748 m .4738 .59719 L .49157 .59429 L F
.4974 .5932 m .49111 .59367 L .49722 .59242 L F
.50061 .60664 m .46193 .5992 L .4738 .59719 L F
.4974 .5932 m .45695 .60736 L .49501 .6003 L 0 .011 .141 r
F
.49111 .59367 m .45695 .60736 L .4974 .5932 L F
.49111 .59367 m .4738 .59719 L .48855 .5947 L F
.49264 .59305 m .4738 .59719 L .49111 .59367 L F
.47496 .58491 m .42931 .60244 L .46359 .5965 L 0 0 0 r
F
.50381 .58101 m .47496 .58491 L .46359 .5965 L 0 0 .069 r
F
.49722 .59242 m .45975 .59224 L .49633 .58869 L 0 .574 .715 r
F
.4738 .59719 m .45975 .59224 L .49722 .59242 L F
.46359 .5965 m .45459 .5999 L .46193 .5992 L 0 0 0 r
F
.46359 .5965 m .42675 .60516 L .45563 .59951 L F
.4738 .59719 m .46193 .5992 L .45975 .59224 L 0 .574 .715 r
F
.48855 .5947 m .46193 .5992 L .45695 .60736 L 0 .011 .141 r
F
.45506 .60058 m .43711 .60335 L .45459 .5999 L 0 .592 .732 r
F
.43825 .60395 m .43711 .60335 L .45506 .60058 L F
.46193 .5992 m .45459 .5999 L .46171 .5985 L F
.46841 .61992 m .42675 .60516 L .428 .60506 L F
.46841 .61992 m .42651 .60451 L .43608 .6028 L F
.46193 .5992 m .419 .6134 L .45695 .60736 L 0 0 0 r
F
.45459 .5999 m .419 .6134 L .46193 .5992 L F
.45459 .5999 m .43711 .60335 L .45273 .60061 L F
.45563 .59951 m .43711 .60335 L .45459 .5999 L F
.44657 .59037 m .41861 .59657 L .39537 .60849 L F
.44657 .59037 m .39537 .60849 L .42931 .60244 L F
.47496 .58491 m .44657 .59037 L .42931 .60244 L F
.46171 .5985 m .42343 .5961 L .45975 .59224 L 0 .592 .732 r
F
.43711 .60335 m .42343 .5961 L .46171 .5985 L F
.42778 .60498 m .42675 .60516 L .42651 .60451 L F
.428 .60506 m .42675 .60516 L .42778 .60498 L F
.45273 .60061 m .42675 .60516 L .419 .6134 L 0 0 0 r
F
.41941 .6066 m .40157 .60933 L .41898 .60597 L 0 .605 .744 r
F
.40247 .60991 m .40157 .60933 L .41941 .6066 L F
.41964 .60574 m .41898 .60597 L .42675 .60516 L 0 0 0 r
F
.42675 .60516 m .41898 .60597 L .42651 .60451 L 0 .605 .744 r
F
.43658 .63206 m .39258 .61094 L .40157 .60933 L F
.41898 .60597 m .38116 .6189 L .42675 .60516 L 0 0 0 r
F
.41898 .60597 m .40157 .60933 L .41748 .60648 L F
.4198 .60569 m .40157 .60933 L .41898 .60597 L F
.42931 .60244 m .39184 .61107 L .4198 .60569 L F
.44904 .58258 m .39109 .60321 L .41861 .59657 L F
.41861 .59657 m .39109 .60321 L .36175 .61459 L F
.41861 .59657 m .36175 .61459 L .39537 .60849 L F
.42651 .60451 m .38737 .60011 L .42343 .5961 L 0 .605 .744 r
F
.40157 .60933 m .38737 .60011 L .42651 .60451 L F
.40157 .60933 m .39159 .61046 L .40075 .6088 L F
.39258 .61094 m .39159 .61046 L .40157 .60933 L F
.3927 .61099 m .39184 .61107 L .39159 .61046 L F
.41748 .60648 m .39184 .61107 L .38116 .6189 L 0 0 0 r
F
.42675 .60516 m .38116 .6189 L .419 .6134 L F
.43608 .6028 m .42651 .60451 L .42343 .5961 L 0 .592 .732 r
F
.38427 .61253 m .36657 .61524 L .38387 .61194 L 0 .615 .754 r
F
.36733 .61579 m .36657 .61524 L .38427 .61253 L F
.38445 .61176 m .38387 .61194 L .39184 .61107 L 0 0 0 r
F
.39184 .61107 m .38387 .61194 L .39159 .61046 L 0 .615 .754 r
F
.4051 .64355 m .3578 .61683 L .36657 .61524 L F
.38387 .61194 m .34343 .62406 L .39184 .61107 L 0 0 0 r
F
.38387 .61194 m .36657 .61524 L .38257 .61233 L F
.38456 .61173 m .36657 .61524 L .38387 .61194 L F
.39537 .60849 m .35722 .61694 L .38456 .61173 L F
.39109 .60321 m .32845 .62071 L .36175 .61459 L F
.39159 .61046 m .35154 .6042 L .38737 .60011 L 0 .615 .754 r
F
.36657 .61524 m .35154 .6042 L .39159 .61046 L F
.36657 .61524 m .35696 .61636 L .36586 .61472 L F
.3578 .61683 m .35696 .61636 L .36657 .61524 L F
.35787 .61687 m .35722 .61694 L .35696 .61636 L F
.38257 .61233 m .35722 .61694 L .34343 .62406 L 0 0 0 r
F
.39184 .61107 m .34343 .62406 L .38116 .6189 L F
.40075 .6088 m .39159 .61046 L .38737 .60011 L 0 .605 .744 r
F
.34952 .6184 m .33195 .62108 L .34913 .61784 L 0 .624 .761 r
F
.33263 .62162 m .33195 .62108 L .34952 .6184 L F
.34967 .6177 m .34913 .61784 L .35722 .61694 L 0 0 0 r
F
.35722 .61694 m .34913 .61784 L .35696 .61636 L 0 .624 .761 r
F
.37399 .65459 m .32334 .62266 L .33195 .62108 L F
.34913 .61784 m .30582 .62897 L .35722 .61694 L 0 0 0 r
F
.34913 .61784 m .33195 .62108 L .34797 .61813 L F
.34975 .61768 m .33195 .62108 L .34913 .61784 L F
.36175 .61459 m .32287 .62275 L .34975 .61768 L F
.35696 .61636 m .31597 .60834 L .35154 .6042 L 0 .624 .761 r
F
.33195 .62108 m .31597 .60834 L .35696 .61636 L F
.33195 .62108 m .3226 .6222 L .33132 .62058 L F
.32334 .62266 m .3226 .6222 L .33195 .62108 L F
.32339 .6227 m .32287 .62275 L .3226 .6222 L F
.34797 .61813 m .32287 .62275 L .30582 .62897 L 0 0 0 r
F
.35722 .61694 m .30582 .62897 L .34343 .62406 L F
.36586 .61472 m .35696 .61636 L .35154 .6042 L 0 .615 .754 r
F
.31509 .62422 m .29767 .62687 L .31472 .62368 L 0 .631 .768 r
F
.29829 .62739 m .29767 .62687 L .31509 .62422 L F
.31522 .62357 m .31472 .62368 L .32287 .62275 L 0 0 0 r
F
.32287 .62275 m .31472 .62368 L .3226 .6222 L 0 .631 .768 r
F
.34322 .66528 m .28852 .62799 L .29709 .62639 L F
.31472 .62368 m .31365 .62391 L .32287 .62275 L 0 0 0 r
F
.31365 .62391 m .26833 .63368 L .32107 .62311 L F
.31365 .62391 m .32107 .62311 L .32287 .62275 L F
.31472 .62368 m .29767 .62687 L .31365 .62391 L F
.32845 .62071 m .29767 .62687 L .31472 .62368 L F
.3226 .6222 m .28063 .6125 L .31597 .60834 L 0 .631 .768 r
F
.29767 .62687 m .28063 .6125 L .3226 .6222 L F
.28928 .62948 m .29003 .63095 L .30582 .62897 L 0 0 0 r
F
.32287 .62275 m .28928 .62948 L .30582 .62897 L F
.33132 .62058 m .3226 .6222 L .31597 .60834 L 0 .624 .761 r
F
.28923 .62847 m .28879 .62852 L .28919 .62845 L 0 .631 .768 r
F
.31365 .62391 m .28879 .62852 L .26833 .63368 L 0 0 0 r
F
.28919 .62845 m .28879 .62852 L .28852 .62799 L 0 .631 .768 r
F
.25877 .63355 m .25571 .63412 L .25498 .63424 L 0 .644 .714 r
F
.25532 .63418 m .25498 .63424 L .2547 .63373 L 0 .637 .773 r
F
.25498 .63424 m .23001 .63831 L .2547 .63373 L 0 .642 .778 r
F
.28274 .68581 m .23055 .6388 L .25498 .63424 L F
.23055 .6388 m .23001 .63831 L .25498 .63424 L F
.23001 .63831 m .22143 .63992 L .22048 .63825 L F
.23001 .63831 m .22048 .63825 L .22886 .63728 L F
.24585 .63533 m .24217 .63602 L .19371 .64267 L 0 .686 .776 r
F
.22938 .63843 m .22143 .63992 L .19371 .64267 L F
.22488 .63934 m .22218 .63985 L .22143 .63992 L F
.28274 .68581 m .22143 .63992 L .23001 .63831 L 0 .642 .778 r
F
.24159 .6361 m .19371 .64267 L .23096 .63824 L 0 .686 .776 r
F
.25339 .63446 m .19371 .64267 L .25428 .63436 L F
.2468 .6352 m .19371 .64267 L .25498 .63424 L F
.28274 .68581 m .25301 .69572 L .22143 .63992 L 0 .642 .778 r
F
.23096 .63824 m .19371 .64267 L .17903 .64424 L 0 .439 .707 r
F
.23096 .63824 m .17903 .64424 L .21095 .64227 L F
.23096 .63824 m .21095 .64227 L .21899 .64177 L F
.25428 .63436 m .24159 .6361 L .23096 .63824 L 0 .686 .776 r
F
.25498 .63424 m .25339 .63446 L .25428 .63436 L F
.22886 .63728 m .22048 .63825 L .21065 .62088 L 0 .642 .778 r
F
.31281 .67567 m .2547 .63373 L .26315 .63214 L 0 .637 .773 r
F
.27961 .62964 m .25498 .63424 L .23096 .63824 L 0 .644 .714 r
F
.25535 .6342 m .25498 .63424 L .25532 .63418 L 0 .637 .773 r
F
.31281 .67567 m .25498 .63424 L .25535 .6342 L F
.28879 .62852 m .23096 .63824 L .26833 .63368 L 0 .644 .714 r
F
.28062 .62946 m .26369 .63261 L .27961 .62964 L F
.28062 .62946 m .23096 .63824 L .28879 .62852 L F
.28852 .62799 m .24552 .61669 L .28063 .6125 L 0 .637 .773 r
F
.29709 .62639 m .28852 .62799 L .28063 .6125 L 0 .631 .768 r
F
.2547 .63373 m .21065 .62088 L .24552 .61669 L 0 .642 .778 r
F
.26315 .63214 m .2547 .63373 L .24552 .61669 L 0 .637 .773 r
F
.35913 .7328 m .28274 .68581 L .31281 .67567 L 0 .631 .567 r
F
.38289 .71712 m .35913 .7328 L .31281 .67567 L 0 .625 .563 r
F
.43216 .76252 m .35913 .7328 L .38289 .71712 L 0 .619 .355 r
F
.46941 .5768 m .44904 .58258 L .41861 .59657 L 0 0 0 r
F
.49622 .56147 m .44904 .58258 L .46941 .5768 L F
.75324 .31722 m .7912 .33487 L .75514 .35243 L .805 .213 0 r
F
.75324 .31722 m .78972 .29383 L .7912 .33487 L F
.49511 .77596 m .48791 .80053 L .43216 .76252 L 0 .605 .142 r
F
.54465 .8034 m .48791 .80053 L .49511 .77596 L .048 .599 0 r
F
.54465 .8034 m .54683 .83055 L .48791 .80053 L F
.64561 .41819 m .67405 .41969 L .63963 .4387 L .848 .456 0 r
F
.64561 .41819 m .68236 .39334 L .67405 .41969 L F
.44826 .74155 m .43216 .76252 L .38289 .71712 L 0 .611 .352 r
F
.49511 .77596 m .43216 .76252 L .44826 .74155 L 0 .605 .142 r
F
.60474 .46265 m .62635 .46058 L .59596 .47861 L .866 .73 0 r
F
.60474 .46265 m .63963 .4387 L .62635 .46058 L F
.76411 .92334 m .72007 .94382 L .70046 .91909 L .416 .613 0 r
F
.76411 .92334 m .79172 .94765 L .72007 .94382 L F
.50822 .55882 m .49622 .56147 L .46941 .5768 L 0 0 0 r
F
.52779 .54416 m .49622 .56147 L .50822 .55882 L F
.66035 .8656 m .61683 .87928 L .60547 .85227 L .306 .598 0 r
F
.66035 .8656 m .68055 .89309 L .61683 .87928 L F
.71675 .3423 m .75514 .35243 L .71886 .37174 L .815 .215 0 r
F
.71675 .3423 m .75324 .31722 L .75514 .35243 L F
.59391 .82355 m .54683 .83055 L .54465 .8034 L .184 .593 0 r
F
.59391 .82355 m .60547 .85227 L .54683 .83055 L F
.38289 .71712 m .31281 .67567 L .34322 .66528 L 0 .625 .563 r
F
.407 .70079 m .38289 .71712 L .34322 .66528 L 0 .617 .558 r
F
.44826 .74155 m .38289 .71712 L .407 .70079 L 0 .611 .352 r
F
.68024 .36964 m .71886 .37174 L .68236 .39334 L .827 .216 0 r
F
.68024 .36964 m .71675 .3423 L .71886 .37174 L F
.55003 .52701 m .56639 .5121 L .54761 .52851 L 0 0 0 r
F
.55837 .51607 m .56639 .5121 L .55189 .52531 L .478 .935 0 r
F
.55837 .51607 m .58287 .4953 L .56639 .5121 L F
.56495 .50565 m .58287 .4953 L .56108 .51378 L .803 .996 0 r
F
.56495 .50565 m .56108 .51378 L .55837 .51607 L F
.56495 .50565 m .59596 .47861 L .58287 .4953 L F
.56931 .49611 m .59596 .47861 L .56829 .50274 L .893 .751 0 r
F
.56931 .49611 m .56829 .50274 L .56495 .50565 L F
.53316 .58713 m .56837 .49848 L .56495 .50565 L 0 0 0 r
F
.56837 .49848 m .56931 .49611 L .56495 .50565 L F
.53316 .58713 m .56405 .50797 L .55837 .51607 L F
.56405 .50797 m .56495 .50565 L .55837 .51607 L F
.53316 .58713 m .57022 .49023 L .56931 .49611 L .909 .461 0 r
F
.57022 .49023 m .57114 .48784 L .56931 .49611 L F
.55837 .51607 m .55189 .52531 L .55003 .52701 L .478 .935 0 r
F
.60855 .44812 m .63963 .4387 L .60474 .46265 L .872 .464 0 r
F
.60855 .44812 m .64561 .41819 L .63963 .4387 L F
.5405 .53817 m .54761 .52851 L .52779 .54416 L 0 0 0 r
F
.55003 .52701 m .54761 .52851 L .5405 .53817 L F
.7362 .89776 m .70046 .91909 L .68055 .89309 L .411 .604 0 r
F
.7362 .89776 m .76411 .92334 L .70046 .91909 L F
.50244 .7498 m .49511 .77596 L .44826 .74155 L 0 .594 .141 r
F
.54244 .77436 m .49511 .77596 L .50244 .7498 L .048 .587 0 r
F
.54244 .77436 m .54465 .8034 L .49511 .77596 L F
.46466 .71938 m .44826 .74155 L .407 .70079 L 0 .601 .348 r
F
.50244 .7498 m .44826 .74155 L .46466 .71938 L 0 .594 .141 r
F
.46941 .5768 m .41861 .59657 L .44657 .59037 L 0 0 0 r
F
.4902 .5724 m .46941 .5768 L .44657 .59037 L F
.50822 .55882 m .46941 .5768 L .4902 .5724 L F
.53044 .5493 m .52779 .54416 L .50822 .55882 L F
.5405 .53817 m .52779 .54416 L .53044 .5493 L F
.63984 .8363 m .60547 .85227 L .59391 .82355 L .302 .586 0 r
F
.63984 .8363 m .66035 .8656 L .60547 .85227 L F
.64369 .40018 m .68236 .39334 L .64561 .41819 L .843 .218 0 r
F
.64369 .40018 m .68024 .36964 L .68236 .39334 L F
.58214 .79271 m .54465 .8034 L .54244 .77436 L .182 .58 0 r
F
.58214 .79271 m .59391 .82355 L .54465 .8034 L F
.56931 .49611 m .60474 .46265 L .59596 .47861 L .893 .751 0 r
F
.407 .70079 m .34322 .66528 L .37399 .65459 L 0 .617 .558 r
F
.43149 .68368 m .407 .70079 L .37399 .65459 L 0 .608 .552 r
F
.46466 .71938 m .407 .70079 L .43149 .68368 L 0 .601 .348 r
F
.52052 .56022 m .50822 .55882 L .4902 .5724 L 0 0 0 r
F
.53044 .5493 m .50822 .55882 L .52052 .56022 L F
.24552 .61669 m .21065 .62088 L .18936 .54025 L 0 .524 .826 r
F
.70798 .87068 m .68055 .89309 L .66035 .8656 L .406 .592 0 r
F
.70798 .87068 m .7362 .89776 L .68055 .89309 L F
.60706 .43579 m .64561 .41819 L .60855 .44812 L .865 .22 0 r
F
.60706 .43579 m .64369 .40018 L .64561 .41819 L F
.57114 .48784 m .60474 .46265 L .56931 .49611 L .91 .475 0 r
F
.57114 .48784 m .60855 .44812 L .60474 .46265 L F
.48135 .69564 m .46466 .71938 L .43149 .68368 L 0 .589 .343 r
F
.50991 .72157 m .46466 .71938 L .48135 .69564 L 0 .581 .139 r
F
.50991 .72157 m .50244 .7498 L .46466 .71938 L F
.54018 .74281 m .50244 .7498 L .50991 .72157 L .048 .572 0 r
F
.54018 .74281 m .54244 .77436 L .50244 .7498 L F
.24552 .61669 m .18936 .54025 L .22731 .54267 L 0 .524 .826 r
F
.28063 .6125 m .24552 .61669 L .22731 .54267 L 0 .52 .821 r
F
.80386 .23029 m .86274 .2508 L .82622 .27178 L .787 0 0 r
F
.80386 .23029 m .83846 .20347 L .86274 .2508 L F
.76947 .25806 m .82622 .27178 L .78972 .29383 L .793 0 0 r
F
.76947 .25806 m .80386 .23029 L .82622 .27178 L F
.61904 .80473 m .59391 .82355 L .58214 .79271 L .298 .571 0 r
F
.61904 .80473 m .63984 .8363 L .59391 .82355 L F
.73529 .28702 m .78972 .29383 L .75324 .31722 L .8 0 0 r
F
.73529 .28702 m .76947 .25806 L .78972 .29383 L F
.4902 .5724 m .44657 .59037 L .47496 .58491 L 0 0 0 r
F
.43149 .68368 m .37399 .65459 L .4051 .64355 L 0 .608 .552 r
F
.7013 .31753 m .75324 .31722 L .71675 .3423 L .809 0 0 r
F
.7013 .31753 m .73529 .28702 L .75324 .31722 L F
.51144 .57081 m .4902 .5724 L .47496 .58491 L 0 0 .01 r
F
.52052 .56022 m .4902 .5724 L .51144 .57081 L 0 0 0 r
F
.45635 .66556 m .43149 .68368 L .4051 .64355 L 0 .597 .545 r
F
.48135 .69564 m .43149 .68368 L .45635 .66556 L 0 .589 .343 r
F
.57018 .75903 m .54244 .77436 L .54018 .74281 L .18 .563 0 r
F
.57018 .75903 m .58214 .79271 L .54244 .77436 L F
.66748 .35017 m .71675 .3423 L .68024 .36964 L .819 0 0 r
F
.66748 .35017 m .7013 .31753 L .71675 .3423 L F
.28063 .6125 m .22731 .54267 L .26532 .54527 L 0 .52 .821 r
F
.31597 .60834 m .28063 .6125 L .26532 .54527 L 0 .516 .815 r
F
.57028 .48123 m .60855 .44812 L .57114 .48784 L .899 .223 0 r
F
.57028 .48123 m .60706 .43579 L .60855 .44812 L F
.67947 .84176 m .66035 .8656 L .63984 .8363 L .399 .579 0 r
F
.67947 .84176 m .70798 .87068 L .66035 .8656 L F
.63382 .38585 m .68024 .36964 L .64369 .40018 L .833 0 0 r
F
.63382 .38585 m .66748 .35017 L .68024 .36964 L F
.53316 .58713 m .55003 .52701 L .5405 .53817 L .171 .102 0 r
F
.53316 .58713 m .55837 .51607 L .55003 .52701 L .159 0 0 r
F
.81458 .91802 m .79172 .94765 L .76411 .92334 L .448 .544 0 r
F
.81458 .91802 m .84907 .94112 L .79172 .94765 L F
.53316 .58713 m .5405 .53817 L .53044 .5493 L .096 .173 0 r
F
.60027 .42643 m .64369 .40018 L .60706 .43579 L .851 0 0 r
F
.60027 .42643 m .63382 .38585 L .64369 .40018 L F
.31597 .60834 m .26532 .54527 L .30338 .54811 L 0 .516 .815 r
F
.35154 .6042 m .31597 .60834 L .30338 .54811 L 0 .51 .808 r
F
.45635 .66556 m .4051 .64355 L .43658 .63206 L 0 .597 .545 r
F
.53316 .58713 m .53044 .5493 L .52052 .56022 L 0 .209 .017 r
F
.49834 .66963 m .48135 .69564 L .45635 .66556 L 0 .574 .337 r
F
.51753 .69033 m .48135 .69564 L .49834 .66963 L 0 .564 .136 r
F
.51753 .69033 m .50991 .72157 L .48135 .69564 L F
.59795 .77009 m .58214 .79271 L .57018 .75903 L .293 .552 0 r
F
.59795 .77009 m .61904 .80473 L .58214 .79271 L F
.53788 .70761 m .50991 .72157 L .51753 .69033 L .047 .553 0 r
F
.53788 .70761 m .54018 .74281 L .50991 .72157 L F
.56677 .47668 m .60706 .43579 L .57028 .48123 L .878 0 0 r
F
.56677 .47668 m .60027 .42643 L .60706 .43579 L F
.51144 .57081 m .47496 .58491 L .50381 .58101 L 0 0 .01 r
F
.48158 .64596 m .45635 .66556 L .43658 .63206 L 0 .583 .536 r
F
.49834 .66963 m .45635 .66556 L .48158 .64596 L 0 .574 .337 r
F
.53316 .58713 m .52052 .56022 L .51144 .57081 L 0 .221 .116 r
F
.35154 .6042 m .30338 .54811 L .3415 .55125 L 0 .51 .808 r
F
.38737 .60011 m .35154 .6042 L .3415 .55125 L 0 .504 .8 r
F
.7799 .8937 m .76411 .92334 L .7362 .89776 L .44 .534 0 r
F
.7799 .8937 m .81458 .91802 L .76411 .92334 L F
.65068 .8105 m .63984 .8363 L .61904 .80473 L .39 .562 0 r
F
.65068 .8105 m .67947 .84176 L .63984 .8363 L F
.53316 .58713 m .57028 .48123 L .57114 .48784 L .985 .227 0 r
F
.55801 .72117 m .54018 .74281 L .53788 .70761 L .178 .541 0 r
F
.55801 .72117 m .57018 .75903 L .54018 .74281 L F
.48158 .64596 m .43658 .63206 L .46841 .61992 L 0 .583 .536 r
F
.53316 .58713 m .56677 .47668 L .57028 .48123 L .944 0 0 r
F
.53316 .58713 m .51144 .57081 L .50381 .58101 L 0 .216 .205 r
F
.38737 .60011 m .3415 .55125 L .37968 .55478 L 0 .504 .8 r
F
.42343 .5961 m .38737 .60011 L .37968 .55478 L 0 .496 .79 r
F
.58858 .42078 m .63382 .38585 L .60027 .42643 L .834 0 .205 r
F
.56085 .47452 m .60027 .42643 L .56677 .47668 L .854 0 .198 r
F
.56085 .47452 m .58858 .42078 L .60027 .42643 L F
.61651 .37634 m .66748 .35017 L .63382 .38585 L .819 0 .209 r
F
.58858 .42078 m .61651 .37634 L .63382 .38585 L .834 0 .205 r
F
.74504 .86791 m .7362 .89776 L .70798 .87068 L .431 .523 0 r
F
.74504 .86791 m .7799 .8937 L .7362 .89776 L F
.64467 .33651 m .7013 .31753 L .66748 .35017 L .808 0 .212 r
F
.61651 .37634 m .64467 .33651 L .66748 .35017 L .819 0 .209 r
F
.57658 .73088 m .57018 .75903 L .55801 .72117 L .287 .527 0 r
F
.57658 .73088 m .59795 .77009 L .57018 .75903 L F
.51561 .63958 m .49834 .66963 L .48158 .64596 L 0 .553 .328 r
F
.52528 .6537 m .49834 .66963 L .51561 .63958 L 0 .541 .132 r
F
.52528 .6537 m .51753 .69033 L .49834 .66963 L F
.53316 .58713 m .56085 .47452 L .56677 .47668 L .893 0 .175 r
F
.22731 .54267 m .18936 .54025 L .19199 .45687 L 0 .363 .822 r
F
.5072 .62376 m .48158 .64596 L .46841 .61992 L 0 .564 .522 r
F
.51561 .63958 m .48158 .64596 L .5072 .62376 L 0 .553 .328 r
F
.62161 .77603 m .61904 .80473 L .59795 .77009 L .379 .539 0 r
F
.62161 .77603 m .65068 .8105 L .61904 .80473 L F
.42343 .5961 m .37968 .55478 L .41792 .55886 L 0 .496 .79 r
F
.45975 .59224 m .42343 .5961 L .41792 .55886 L 0 .486 .777 r
F
.6731 .29949 m .73529 .28702 L .7013 .31753 L .799 0 .214 r
F
.64467 .33651 m .6731 .29949 L .7013 .31753 L .808 0 .212 r
F
.53553 .66582 m .51753 .69033 L .52528 .6537 L .047 .527 0 r
F
.53553 .66582 m .53788 .70761 L .51753 .69033 L F
.22731 .54267 m .19199 .45687 L .23047 .46655 L 0 .363 .822 r
F
.26532 .54527 m .22731 .54267 L .23047 .46655 L 0 .36 .817 r
F
.26833 .63368 m .23096 .63824 L .21899 .64177 L 0 0 0 r
F
.5072 .62376 m .46841 .61992 L .50061 .60664 L 0 .564 .522 r
F
.26532 .54527 m .23047 .46655 L .26878 .47653 L 0 .36 .817 r
F
.30338 .54811 m .26532 .54527 L .26878 .47653 L 0 .357 .811 r
F
.70183 .26437 m .76947 .25806 L .73529 .28702 L .792 0 .216 r
F
.6731 .29949 m .70183 .26437 L .73529 .28702 L .799 0 .214 r
F
.30338 .54811 m .26878 .47653 L .30695 .48689 L 0 .357 .811 r
F
.3415 .55125 m .30338 .54811 L .30695 .48689 L 0 .354 .804 r
F
.55291 .47502 m .58858 .42078 L .56085 .47452 L .83 0 .392 r
F
.53316 .58713 m .55291 .47502 L .56085 .47452 L .847 0 .352 r
F
.70999 .84029 m .70798 .87068 L .67947 .84176 L .419 .509 0 r
F
.70999 .84029 m .74504 .86791 L .70798 .87068 L F
.54566 .67571 m .53788 .70761 L .53553 .66582 L .176 .511 0 r
F
.54566 .67571 m .55801 .72117 L .53788 .70761 L F
.26833 .63368 m .21899 .64177 L .25881 .63903 L 0 0 0 r
F
.30582 .62897 m .26833 .63368 L .25881 .63903 L F
.3415 .55125 m .30695 .48689 L .34496 .49773 L 0 .354 .804 r
F
.37968 .55478 m .3415 .55125 L .34496 .49773 L 0 .35 .796 r
F
.57279 .41944 m .61651 .37634 L .58858 .42078 L .815 0 .405 r
F
.55291 .47502 m .57279 .41944 L .58858 .42078 L .83 0 .392 r
F
.45975 .59224 m .41792 .55886 L .45624 .5638 L 0 .486 .777 r
F
.49633 .58869 m .45975 .59224 L .45624 .5638 L 0 .472 .759 r
F
.73087 .2306 m .80386 .23029 L .76947 .25806 L .786 0 .217 r
F
.70183 .26437 m .73087 .2306 L .76947 .25806 L .792 0 .216 r
F
.37968 .55478 m .34496 .49773 L .38283 .50922 L 0 .35 .796 r
F
.41792 .55886 m .37968 .55478 L .38283 .50922 L 0 .345 .787 r
F
.30582 .62897 m .25881 .63903 L .29848 .63598 L 0 0 0 r
F
.34343 .62406 m .30582 .62897 L .29848 .63598 L F
.54353 .47836 m .57279 .41944 L .55291 .47502 L .807 0 .582 r
F
.53316 .58713 m .54353 .47836 L .55291 .47502 L .809 0 .528 r
F
.41792 .55886 m .38283 .50922 L .42057 .52165 L 0 .345 .787 r
F
.45624 .5638 m .41792 .55886 L .42057 .52165 L 0 .338 .774 r
F
.34343 .62406 m .29848 .63598 L .33801 .63251 L 0 0 0 r
F
.38116 .6189 m .34343 .62406 L .33801 .63251 L F
.59288 .37262 m .64467 .33651 L .61651 .37634 L .804 0 .413 r
F
.57279 .41944 m .59288 .37262 L .61651 .37634 L .815 0 .405 r
F
.59229 .73673 m .59795 .77009 L .57658 .73088 L .364 .509 0 r
F
.59229 .73673 m .62161 .77603 L .59795 .77009 L F
.55495 .68324 m .55801 .72117 L .54566 .67571 L .28 .49 0 r
F
.55495 .68324 m .57658 .73088 L .55801 .72117 L F
.76023 .19783 m .83846 .20347 L .80386 .23029 L .78 0 .218 r
F
.73087 .2306 m .76023 .19783 L .80386 .23029 L .786 0 .217 r
F
.45624 .5638 m .42057 .52165 L .45818 .53556 L 0 .338 .774 r
F
.49464 .57041 m .45624 .5638 L .45818 .53556 L 0 .328 .756 r
F
.49633 .58869 m .45624 .5638 L .49464 .57041 L 0 .472 .759 r
F
.53316 .58713 m .5072 .62376 L .50061 .60664 L 0 .549 .496 r
F
.53316 .58713 m .51561 .63958 L .5072 .62376 L 0 .539 .308 r
F
.54353 .47836 m .554 .42284 L .57279 .41944 L .807 0 .582 r
F
.53337 .4846 m .554 .42284 L .54353 .47836 L .769 0 .754 r
F
.53316 .58713 m .53337 .4846 L .54353 .47836 L .759 0 .69 r
F
.67479 .81032 m .67947 .84176 L .65068 .8105 L .404 .491 0 r
F
.67479 .81032 m .70999 .84029 L .67947 .84176 L F
.53316 .58713 m .52528 .6537 L .51561 .63958 L 0 .523 .122 r
F
.38116 .6189 m .33801 .63251 L .37738 .6285 L 0 0 0 r
F
.419 .6134 m .38116 .6189 L .37738 .6285 L F
.53316 .58713 m .49633 .58869 L .49464 .57041 L 0 .447 .73 r
F
.554 .42284 m .59288 .37262 L .57279 .41944 L .797 0 .6 r
F
.49464 .57041 m .45818 .53556 L .4957 .55238 L 0 .328 .756 r
F
.53316 .58713 m .49464 .57041 L .4957 .55238 L 0 .304 .725 r
F
.53316 .58713 m .53553 .66582 L .52528 .6537 L .051 .5 0 r
F
.53337 .4846 m .53358 .43116 L .554 .42284 L .769 0 .754 r
F
.52317 .49366 m .53358 .43116 L .53337 .4846 L .553 0 .751 r
F
.53316 .58713 m .52317 .49366 L .53337 .4846 L .54 0 .692 r
F
.419 .6134 m .37738 .6285 L .4166 .62373 L 0 0 0 r
F
.45695 .60736 m .419 .6134 L .4166 .62373 L 0 0 .009 r
F
.4957 .55238 m .4655 .50854 L .49942 .53516 L 0 .18 .753 r
F
.4957 .55238 m .45818 .53556 L .4655 .50854 L F
.53316 .58713 m .4957 .55238 L .49942 .53516 L 0 .164 .717 r
F
.76023 .19783 m .78994 .16579 L .83846 .20347 L .78 0 .218 r
F
.61323 .33007 m .6731 .29949 L .64467 .33651 L .795 0 .418 r
F
.59288 .37262 m .61323 .33007 L .64467 .33651 L .804 0 .413 r
F
.45818 .53556 m .43133 .48592 L .4655 .50854 L 0 .185 .771 r
F
.45818 .53556 m .42057 .52165 L .43133 .48592 L F
.49942 .53516 m .47771 .48373 L .50555 .51931 L 0 .026 .751 r
F
.49942 .53516 m .4655 .50854 L .47771 .48373 L F
.53316 .58713 m .49942 .53516 L .50555 .51931 L 0 .024 .709 r
F
.52317 .49366 m .51305 .44435 L .53358 .43116 L .553 0 .751 r
F
.51366 .50534 m .51305 .44435 L .52317 .49366 L .349 0 .75 r
F
.53316 .58713 m .51366 .50534 L .52317 .49366 L .337 0 .696 r
F
.53316 .58713 m .54566 .67571 L .53553 .66582 L .192 .471 0 r
F
.45695 .60736 m .4166 .62373 L .45565 .61776 L 0 0 .009 r
F
.49501 .6003 m .45695 .60736 L .45565 .61776 L 0 .055 .185 r
F
.50555 .51931 m .49395 .46207 L .51366 .50534 L .155 0 .75 r
F
.50555 .51931 m .47771 .48373 L .49395 .46207 L F
.53316 .58713 m .50555 .51931 L .51366 .50534 L .148 0 .702 r
F
.51366 .50534 m .49395 .46207 L .51305 .44435 L .349 0 .75 r
F
.42057 .52165 m .39688 .46531 L .43133 .48592 L 0 .189 .784 r
F
.42057 .52165 m .38283 .50922 L .39688 .46531 L F
.63945 .77709 m .65068 .8105 L .62161 .77603 L .383 .467 0 r
F
.63945 .77709 m .67479 .81032 L .65068 .8105 L F
.49501 .6003 m .45565 .61776 L .49452 .60949 L 0 .055 .185 r
F
.53316 .58713 m .49501 .6003 L .49452 .60949 L 0 .147 .362 r
F
.53316 .58713 m .56852 .69116 L .56276 .68838 L .303 .266 0 r
F
.53316 .58713 m .57181 .69172 L .56852 .69116 L .063 .093 0 r
F
.57105 .68966 m .57235 .69022 L .57181 .69172 L 0 0 0 r
F
.53316 .58713 m .57235 .69022 L .57105 .68966 L F
.57158 .68818 m .57009 .68692 L .57235 .69022 L .838 .06 0 r
F
.53316 .58713 m .57009 .68692 L .57158 .68818 L F
.56516 .68209 m .56869 .68573 L .57009 .68692 L .592 0 0 r
F
.57009 .68692 m .57358 .69075 L .57235 .69022 L 0 .014 0 r
F
.57358 .69075 m .61221 .73316 L .57235 .69022 L F
.60496 .7252 m .60789 .72619 L .61221 .73316 L F
.57009 .68692 m .60789 .72619 L .60496 .7252 L F
.56869 .68573 m .60789 .72619 L .57009 .68692 L .592 0 0 r
F
.60051 .71858 m .59809 .71717 L .60789 .72619 L F
.56516 .68209 m .59809 .71717 L .60051 .71858 L F
.57181 .69172 m .61085 .73755 L .60401 .73886 L .178 .232 0 r
F
.57235 .69022 m .61085 .73755 L .57181 .69172 L 0 .101 0 r
F
.57235 .69022 m .61221 .73316 L .61085 .73755 L F
.58348 .70667 m .5959 .71589 L .59809 .71717 L .526 0 0 r
F
.59809 .71717 m .61054 .72709 L .60789 .72619 L 0 0 .083 r
F
.62969 .74234 m .63182 .74256 L .64637 .75563 L F
.59809 .71717 m .63182 .74256 L .62969 .74234 L F
.5959 .71589 m .63182 .74256 L .59809 .71717 L .526 0 0 r
F
.61054 .72709 m .64637 .75563 L .60789 .72619 L 0 0 .083 r
F
.60789 .72619 m .64637 .75563 L .65254 .76626 L 0 .039 0 r
F
.60789 .72619 m .65254 .76626 L .61221 .73316 L F
.61507 .73012 m .60979 .72789 L .63182 .74256 L .526 0 0 r
F
.58348 .70667 m .60979 .72789 L .61507 .73012 L F
.56852 .69116 m .60401 .73886 L .59229 .73673 L .316 .378 0 r
F
.57181 .69172 m .60401 .73886 L .56852 .69116 L .178 .232 0 r
F
.58188 .71249 m .60508 .7259 L .60979 .72789 L .484 0 0 r
F
.60979 .72789 m .63372 .74275 L .63182 .74256 L 0 0 .24 r
F
.63817 .74551 m .63682 .74426 L .6663 .76298 L F
.60979 .72789 m .63682 .74426 L .63817 .74551 L F
.60508 .7259 m .63682 .74426 L .60979 .72789 L .484 0 0 r
F
.58188 .71249 m .59917 .72503 L .63682 .74426 L F
.59917 .72503 m .63561 .74314 L .63682 .74426 L .351 0 0 r
F
.63561 .74314 m .66457 .75753 L .63682 .74426 L F
.63372 .74275 m .6663 .76298 L .63182 .74256 L 0 0 .24 r
F
.53316 .58713 m .56516 .68209 L .57009 .68692 L .938 0 .033 r
F
.53316 .58713 m .56276 .68838 L .55495 .68324 L .369 .38 0 r
F
.53316 .58713 m .55791 .67601 L .56516 .68209 L .9 0 .151 r
F
.53316 .58713 m .55495 .68324 L .54566 .67571 L .305 .433 0 r
F
.53316 .58713 m .54885 .66899 L .55791 .67601 L .848 0 .29 r
F
.53316 .58713 m .53865 .66127 L .54885 .66899 L .8 0 .43 r
F
.53316 .58713 m .52808 .6531 L .53865 .66127 L .645 0 .491 r
F
.53316 .58713 m .51791 .64465 L .52808 .6531 L .428 0 .49 r
F
.53316 .58713 m .50889 .63603 L .51791 .64465 L .231 0 .479 r
F
.53316 .58713 m .50168 .6273 L .50889 .63603 L .054 0 .458 r
F
.53316 .58713 m .49678 .61847 L .50168 .6273 L 0 .051 .429 r
F
.53316 .58713 m .49452 .60949 L .49678 .61847 L 0 .107 .394 r
F
.56276 .68838 m .57658 .73088 L .55495 .68324 L .346 .462 0 r
F
.56276 .68838 m .59229 .73673 L .57658 .73088 L F
.554 .42284 m .56461 .37544 L .59288 .37262 L .797 0 .6 r
F
.53358 .43116 m .56461 .37544 L .554 .42284 L .762 0 .777 r
F
.38283 .50922 m .36214 .44592 L .39688 .46531 L 0 .191 .794 r
F
.38283 .50922 m .34496 .49773 L .36214 .44592 L F
.4655 .50854 m .44955 .45314 L .47771 .48373 L 0 .027 .77 r
F
.4655 .50854 m .43133 .48592 L .44955 .45314 L F
.56461 .37544 m .61323 .33007 L .59288 .37262 L .789 0 .612 r
F
.63386 .29005 m .70183 .26437 L .6731 .29949 L .788 0 .423 r
F
.61323 .33007 m .63386 .29005 L .6731 .29949 L .795 0 .418 r
F
.34496 .49773 m .32709 .42736 L .36214 .44592 L 0 .193 .802 r
F
.34496 .49773 m .30695 .48689 L .32709 .42736 L F
.53358 .43116 m .53378 .38516 L .56461 .37544 L .762 0 .777 r
F
.51305 .44435 m .53378 .38516 L .53358 .43116 L .551 0 .773 r
F
.47771 .48373 m .47396 .42468 L .49395 .46207 L .155 0 .769 r
F
.47771 .48373 m .44955 .45314 L .47396 .42468 L F
.60401 .73886 m .62161 .77603 L .59229 .73673 L .356 .433 0 r
F
.60401 .73886 m .63945 .77709 L .62161 .77603 L F
.84767 .90382 m .84907 .94112 L .81458 .91802 L .399 .385 0 r
F
.84767 .90382 m .88731 .92491 L .84907 .94112 L F
.30695 .48689 m .29172 .40938 L .32709 .42736 L 0 .195 .808 r
F
.30695 .48689 m .26878 .47653 L .29172 .40938 L F
.49395 .46207 m .50277 .40173 L .51305 .44435 L .348 0 .77 r
F
.49395 .46207 m .47396 .42468 L .50277 .40173 L F
.51305 .44435 m .50277 .40173 L .53378 .38516 L .551 0 .773 r
F
.43133 .48592 m .42105 .42498 L .44955 .45314 L 0 .027 .783 r
F
.43133 .48592 m .39688 .46531 L .42105 .42498 L F
.49452 .60949 m .45989 .628 L .49678 .61847 L 0 .059 .219 r
F
.49452 .60949 m .45565 .61776 L .45989 .628 L F
.26878 .47653 m .25602 .39184 L .29172 .40938 L 0 .196 .814 r
F
.26878 .47653 m .23047 .46655 L .25602 .39184 L F
.80805 .88157 m .81458 .91802 L .7799 .8937 L .387 .377 0 r
F
.80805 .88157 m .84767 .90382 L .81458 .91802 L F
.56852 .69116 m .59229 .73673 L .56276 .68838 L .316 .378 0 r
F
.65479 .25167 m .73087 .2306 L .70183 .26437 L .782 0 .426 r
F
.63386 .29005 m .65479 .25167 L .70183 .26437 L .788 0 .423 r
F
.56461 .37544 m .57538 .33193 L .61323 .33007 L .789 0 .612 r
F
.53378 .38516 m .57538 .33193 L .56461 .37544 L .756 0 .792 r
F
.57538 .33193 m .63386 .29005 L .61323 .33007 L .782 0 .62 r
F
.23047 .46655 m .21998 .37462 L .25602 .39184 L 0 .198 .819 r
F
.23047 .46655 m .19199 .45687 L .21998 .37462 L F
.76847 .8579 m .7799 .8937 L .74504 .86791 L .373 .368 0 r
F
.76847 .8579 m .80805 .88157 L .7799 .8937 L F
.39688 .46531 m .39218 .39825 L .42105 .42498 L 0 .028 .793 r
F
.39688 .46531 m .36214 .44592 L .39218 .39825 L F
.45565 .61776 m .42257 .63396 L .45989 .628 L 0 .003 .056 r
F
.45565 .61776 m .4166 .62373 L .42257 .63396 L F
.44955 .45314 m .45367 .39009 L .47396 .42468 L .154 0 .783 r
F
.44955 .45314 m .42105 .42498 L .45367 .39009 L F
.72893 .83245 m .74504 .86791 L .70999 .84029 L .355 .356 0 r
F
.72893 .83245 m .76847 .8579 L .74504 .86791 L F
.53378 .38516 m .534 .34266 L .57538 .33193 L .756 0 .792 r
F
.50277 .40173 m .534 .34266 L .53378 .38516 L .548 0 .787 r
F
.49678 .61847 m .46953 .63834 L .50168 .6273 L 0 .032 .243 r
F
.49678 .61847 m .45989 .628 L .46953 .63834 L F
.47396 .42468 m .49233 .36225 L .50277 .40173 L .347 0 .784 r
F
.47396 .42468 m .45367 .39009 L .49233 .36225 L F
.4166 .62373 m .38481 .63806 L .42257 .63396 L 0 0 0 r
F
.4166 .62373 m .37738 .6285 L .38481 .63806 L F
.68946 .80468 m .70999 .84029 L .67479 .81032 L .332 .34 0 r
F
.68946 .80468 m .72893 .83245 L .70999 .84029 L F
.67604 .2144 m .76023 .19783 L .73087 .2306 L .777 0 .429 r
F
.65479 .25167 m .67604 .2144 L .73087 .2306 L .782 0 .426 r
F
.50277 .40173 m .49233 .36225 L .534 .34266 L .548 0 .787 r
F
.36214 .44592 m .36292 .37246 L .39218 .39825 L 0 .028 .8 r
F
.36214 .44592 m .32709 .42736 L .36292 .37246 L F
.65009 .77365 m .67479 .81032 L .63945 .77709 L .3 .319 0 r
F
.65009 .77365 m .68946 .80468 L .67479 .81032 L F
.61085 .73755 m .63945 .77709 L .60401 .73886 L .253 .287 0 r
F
.61085 .73755 m .65009 .77365 L .63945 .77709 L F
.37738 .6285 m .34663 .64096 L .38481 .63806 L 0 0 0 r
F
.37738 .6285 m .33801 .63251 L .34663 .64096 L F
.58634 .29066 m .65479 .25167 L .63386 .29005 L .776 0 .627 r
F
.57538 .33193 m .58634 .29066 L .63386 .29005 L .782 0 .62 r
F
.534 .34266 m .58634 .29066 L .57538 .33193 L .751 0 .803 r
F
.42105 .42498 m .43305 .35711 L .45367 .39009 L .154 0 .793 r
F
.42105 .42498 m .39218 .39825 L .43305 .35711 L F
.33801 .63251 m .30803 .64301 L .34663 .64096 L 0 0 0 r
F
.33801 .63251 m .29848 .63598 L .30803 .64301 L F
.50168 .6273 m .48395 .649 L .50889 .63603 L .054 0 .256 r
F
.50168 .6273 m .46953 .63834 L .48395 .649 L F
.32709 .42736 m .33326 .34729 L .36292 .37246 L 0 .028 .807 r
F
.32709 .42736 m .29172 .40938 L .33326 .34729 L F
.69761 .1779 m .78994 .16579 L .76023 .19783 L .772 0 .431 r
F
.67604 .2144 m .69761 .1779 L .76023 .19783 L .777 0 .429 r
F
.29848 .63598 m .26902 .64441 L .30803 .64301 L 0 0 0 r
F
.29848 .63598 m .25881 .63903 L .26902 .64441 L F
.45989 .628 m .43677 .64459 L .46953 .63834 L 0 .011 .085 r
F
.45989 .628 m .42257 .63396 L .43677 .64459 L F
.45367 .39009 m .48169 .32456 L .49233 .36225 L .346 0 .794 r
F
.45367 .39009 m .43305 .35711 L .48169 .32456 L F
.534 .34266 m .53421 .30215 L .58634 .29066 L .751 0 .803 r
F
.49233 .36225 m .53421 .30215 L .534 .34266 L .545 0 .798 r
F
.49233 .36225 m .48169 .32456 L .53421 .30215 L F
.25881 .63903 m .22958 .64528 L .26902 .64441 L 0 0 0 r
F
.25881 .63903 m .21899 .64177 L .22958 .64528 L F
.50889 .63603 m .50216 .6601 L .51791 .64465 L .23 0 .256 r
F
.50889 .63603 m .48395 .649 L .50216 .6601 L F
.59749 .25079 m .67604 .2144 L .65479 .25167 L .771 0 .632 r
F
.58634 .29066 m .59749 .25079 L .65479 .25167 L .776 0 .627 r
F
.39218 .39825 m .41208 .32512 L .43305 .35711 L .154 0 .801 r
F
.39218 .39825 m .36292 .37246 L .41208 .32512 L F
.61221 .73316 m .65009 .77365 L .61085 .73755 L .106 .15 0 r
F
.29172 .40938 m .30319 .32254 L .33326 .34729 L 0 .028 .813 r
F
.29172 .40938 m .25602 .39184 L .30319 .32254 L F
.69761 .1779 m .71954 .14192 L .78994 .16579 L .772 0 .431 r
F
.21899 .64177 m .18973 .64572 L .22958 .64528 L 0 0 0 r
F
.21899 .64177 m .17903 .64424 L .18973 .64572 L F
.53421 .30215 m .59749 .25079 L .58634 .29066 L .747 0 .811 r
F
.51791 .64465 m .52282 .67162 L .52808 .6531 L .424 0 .242 r
F
.51791 .64465 m .50216 .6601 L .52282 .67162 L F
.65254 .76626 m .68946 .80468 L .65009 .77365 L .185 .177 0 r
F
.61221 .73316 m .65254 .76626 L .65009 .77365 L .106 .15 0 r
F
.42257 .63396 m .40341 .64833 L .43677 .64459 L 0 0 0 r
F
.42257 .63396 m .38481 .63806 L .40341 .64833 L F
.55791 .67601 m .59809 .71717 L .56516 .68209 L .737 0 0 r
F
.25602 .39184 m .27269 .29809 L .30319 .32254 L 0 .029 .817 r
F
.25602 .39184 m .21998 .37462 L .27269 .29809 L F
.43305 .35711 m .47085 .28795 L .48169 .32456 L .344 0 .802 r
F
.43305 .35711 m .41208 .32512 L .47085 .28795 L F
.52808 .6531 m .54435 .68344 L .53865 .66127 L .633 0 .208 r
F
.52808 .6531 m .52282 .67162 L .54435 .68344 L F
.69327 .79429 m .72893 .83245 L .68946 .80468 L .236 .194 0 r
F
.65254 .76626 m .69327 .79429 L .68946 .80468 L .185 .177 0 r
F
.46953 .63834 m .45839 .65604 L .48395 .649 L .05 0 .097 r
F
.46953 .63834 m .43677 .64459 L .45839 .65604 L F
.36292 .37246 m .39076 .29378 L .41208 .32512 L .153 0 .807 r
F
.36292 .37246 m .33326 .34729 L .39076 .29378 L F
.55791 .67601 m .58348 .70667 L .59809 .71717 L .737 0 0 r
F
.54885 .66899 m .58348 .70667 L .55791 .67601 L .777 0 .022 r
F
.53421 .30215 m .53443 .26285 L .59749 .25079 L .747 0 .811 r
F
.48169 .32456 m .53443 .26285 L .53421 .30215 L .542 0 .806 r
F
.60884 .21182 m .69761 .1779 L .67604 .2144 L .767 0 .636 r
F
.59749 .25079 m .60884 .21182 L .67604 .2144 L .771 0 .632 r
F
.53865 .66127 m .56511 .69526 L .54885 .66899 L .769 0 .129 r
F
.53865 .66127 m .54435 .68344 L .56511 .69526 L F
.54885 .66899 m .56511 .69526 L .58348 .70667 L .777 0 .022 r
F
.48169 .32456 m .47085 .28795 L .53443 .26285 L .542 0 .806 r
F
.73438 .81908 m .76847 .8579 L .72893 .83245 L .272 .206 0 r
F
.69327 .79429 m .73438 .81908 L .72893 .83245 L .236 .194 0 r
F
.53443 .26285 m .60884 .21182 L .59749 .25079 L .743 0 .818 r
F
.77583 .84159 m .80805 .88157 L .76847 .8579 L .299 .215 0 r
F
.73438 .81908 m .77583 .84159 L .76847 .8579 L .272 .206 0 r
F
.38481 .63806 m .36945 .65044 L .40341 .64833 L 0 0 0 r
F
.38481 .63806 m .34663 .64096 L .36945 .65044 L F
.81761 .86237 m .84767 .90382 L .80805 .88157 L .32 .222 0 r
F
.77583 .84159 m .81761 .86237 L .80805 .88157 L .299 .215 0 r
F
.8597 .8818 m .88731 .92491 L .84767 .90382 L .337 .228 0 r
F
.81761 .86237 m .8597 .8818 L .84767 .90382 L .32 .222 0 r
F
.33326 .34729 m .36906 .26282 L .39076 .29378 L .153 0 .813 r
F
.33326 .34729 m .30319 .32254 L .36906 .26282 L F
.8597 .8818 m .9021 .90012 L .88731 .92491 L .337 .228 0 r
F
.41208 .32512 m .45981 .252 L .47085 .28795 L .343 0 .809 r
F
.41208 .32512 m .39076 .29378 L .45981 .252 L F
.48395 .649 m .48595 .6686 L .50216 .6601 L .212 0 .09 r
F
.48395 .649 m .45839 .65604 L .48595 .6686 L F
.64637 .75563 m .69327 .79429 L .65254 .76626 L .029 .052 0 r
F
.6204 .17342 m .71954 .14192 L .69761 .1779 L .763 0 .639 r
F
.60884 .21182 m .6204 .17342 L .69761 .1779 L .767 0 .636 r
F
.53443 .26285 m .53466 .2243 L .60884 .21182 L .743 0 .818 r
F
.47085 .28795 m .53466 .2243 L .53443 .26285 L .54 0 .812 r
F
.34663 .64096 m .3349 .65138 L .36945 .65044 L 0 0 0 r
F
.34663 .64096 m .30803 .64301 L .3349 .65138 L F
.43677 .64459 m .43221 .65998 L .45839 .65604 L .044 0 0 r
F
.43677 .64459 m .40341 .64833 L .43221 .65998 L F
.47085 .28795 m .45981 .252 L .53466 .2243 L .54 0 .812 r
F
.53466 .2243 m .6204 .17342 L .60884 .21182 L .739 0 .823 r
F
.30319 .32254 m .34697 .23208 L .36906 .26282 L .153 0 .818 r
F
.30319 .32254 m .27269 .29809 L .34697 .23208 L F
.50216 .6601 m .51738 .68234 L .52282 .67162 L .389 0 .061 r
F
.50216 .6601 m .48595 .6686 L .51738 .68234 L F
.6855 .78004 m .73438 .81908 L .69327 .79429 L .109 .06 0 r
F
.64637 .75563 m .6855 .78004 L .69327 .79429 L .029 .052 0 r
F
.6204 .17342 m .63219 .13535 L .71954 .14192 L .763 0 .639 r
F
.39076 .29378 m .44855 .21643 L .45981 .252 L .342 0 .814 r
F
.39076 .29378 m .36906 .26282 L .44855 .21643 L F
.30803 .64301 m .29973 .6514 L .3349 .65138 L 0 0 0 r
F
.30803 .64301 m .26902 .64441 L .29973 .6514 L F
.56511 .69526 m .60979 .72789 L .58348 .70667 L .634 0 0 r
F
.52282 .67162 m .55024 .6971 L .54435 .68344 L .572 0 .003 r
F
.52282 .67162 m .51738 .68234 L .55024 .6971 L F
.63182 .74256 m .6855 .78004 L .64637 .75563 L 0 0 .099 r
F
.53466 .2243 m .53489 .18618 L .6204 .17342 L .739 0 .823 r
F
.45981 .252 m .53489 .18618 L .53466 .2243 L .538 0 .818 r
F
.56511 .69526 m .58188 .71249 L .60979 .72789 L .634 0 0 r
F
.54435 .68344 m .58188 .71249 L .56511 .69526 L .672 0 0 r
F
.72524 .80125 m .77583 .84159 L .73438 .81908 L .165 .065 0 r
F
.6855 .78004 m .72524 .80125 L .73438 .81908 L .109 .06 0 r
F
.54435 .68344 m .55024 .6971 L .58188 .71249 L .672 0 0 r
F
.45981 .252 m .44855 .21643 L .53489 .18618 L .538 0 .818 r
F
.40341 .64833 m .40541 .66187 L .43221 .65998 L .038 0 0 r
F
.40341 .64833 m .36945 .65044 L .40541 .66187 L F
.45839 .65604 m .46927 .67346 L .48595 .6686 L .188 0 0 r
F
.45839 .65604 m .43221 .65998 L .46927 .67346 L F
.53489 .18618 m .63219 .13535 L .6204 .17342 L .736 0 .828 r
F
.26902 .64441 m .26394 .65069 L .29973 .6514 L 0 0 0 r
F
.26902 .64441 m .22958 .64528 L .26394 .65069 L F
.36906 .26282 m .43706 .18104 L .44855 .21643 L .341 0 .819 r
F
.36906 .26282 m .34697 .23208 L .43706 .18104 L F
.76558 .82021 m .81761 .86237 L .77583 .84159 L .206 .069 0 r
F
.72524 .80125 m .76558 .82021 L .77583 .84159 L .165 .065 0 r
F
.63182 .74256 m .6663 .76298 L .6855 .78004 L 0 0 .099 r
F
.6663 .76298 m .72524 .80125 L .6855 .78004 L 0 0 .107 r
F
.22958 .64528 m .22753 .64934 L .26394 .65069 L 0 0 0 r
F
.22958 .64528 m .18973 .64572 L .22753 .64934 L F
.53489 .18618 m .53512 .14826 L .63219 .13535 L .736 0 .828 r
F
.44855 .21643 m .53512 .14826 L .53489 .18618 L .536 0 .823 r
F
.48595 .6686 m .51179 .68897 L .51738 .68234 L .344 0 0 r
F
.48595 .6686 m .46927 .67346 L .51179 .68897 L F
.44855 .21643 m .43706 .18104 L .53512 .14826 L .536 0 .823 r
F
.80652 .83749 m .8597 .8818 L .81761 .86237 L .237 .072 0 r
F
.76558 .82021 m .80652 .83749 L .81761 .86237 L .206 .069 0 r
F
.36945 .65044 m .37798 .66228 L .40541 .66187 L .031 0 0 r
F
.36945 .65044 m .3349 .65138 L .37798 .66228 L F
.43221 .65998 m .45213 .67593 L .46927 .67346 L .162 0 0 r
F
.43221 .65998 m .40541 .66187 L .45213 .67593 L F
.84804 .85345 m .9021 .90012 L .8597 .8818 L .261 .074 0 r
F
.80652 .83749 m .84804 .85345 L .8597 .8818 L .237 .072 0 r
F
.51738 .68234 m .55631 .70633 L .55024 .6971 L .496 0 0 r
F
.51738 .68234 m .51179 .68897 L .55631 .70633 L F
.70154 .78025 m .76558 .82021 L .72524 .80125 L .034 0 .112 r
F
.6663 .76298 m .70154 .78025 L .72524 .80125 L 0 0 .107 r
F
.55024 .6971 m .59917 .72503 L .58188 .71249 L .557 0 0 r
F
.55024 .6971 m .55631 .70633 L .59917 .72503 L F
.84804 .85345 m .89014 .86834 L .9021 .90012 L .261 .074 0 r
F
.63682 .74426 m .70154 .78025 L .6663 .76298 L 0 0 .282 r
F
.3349 .65138 m .34991 .66153 L .37798 .66228 L .025 0 0 r
F
.3349 .65138 m .29973 .6514 L .34991 .66153 L F
.46927 .67346 m .50601 .69291 L .51179 .68897 L .294 0 0 r
F
.46927 .67346 m .45213 .67593 L .50601 .69291 L F
.73752 .7953 m .80652 .83749 L .76558 .82021 L .092 0 .115 r
F
.70154 .78025 m .73752 .7953 L .76558 .82021 L .034 0 .112 r
F
.40541 .66187 m .43451 .67664 L .45213 .67593 L .136 0 0 r
F
.40541 .66187 m .37798 .66228 L .43451 .67664 L F
.63682 .74426 m .66457 .75753 L .70154 .78025 L 0 0 .282 r
F
.29973 .6514 m .32117 .65981 L .34991 .66153 L .019 0 0 r
F
.29973 .6514 m .26394 .65069 L .32117 .65981 L F
.66457 .75753 m .73752 .7953 L .70154 .78025 L 0 0 .308 r
F
.51179 .68897 m .56258 .71267 L .55631 .70633 L .414 0 0 r
F
.51179 .68897 m .50601 .69291 L .56258 .71267 L F
.55631 .70633 m .56258 .71267 L .61697 .73455 L .443 0 0 r
F
.56258 .71267 m .61036 .73188 L .61697 .73455 L .339 0 0 r
F
.59917 .72503 m .61697 .73455 L .62431 .73753 L .351 0 0 r
F
.55631 .70633 m .61697 .73455 L .59917 .72503 L .443 0 0 r
F
.61036 .73188 m .6353 .74191 L .61697 .73455 L .339 0 0 r
F
.62431 .73753 m .61697 .73455 L .66457 .75753 L .351 0 0 r
F
.77425 .80868 m .84804 .85345 L .80652 .83749 L .137 0 .117 r
F
.73752 .7953 m .77425 .80868 L .80652 .83749 L .092 0 .115 r
F
.26394 .65069 m .29175 .65727 L .32117 .65981 L .013 0 0 r
F
.26394 .65069 m .22753 .64934 L .29175 .65727 L F
.37798 .66228 m .41639 .67596 L .43451 .67664 L .11 0 0 r
F
.37798 .66228 m .34991 .66153 L .41639 .67596 L F
.45213 .67593 m .50006 .69489 L .50601 .69291 L .244 0 0 r
F
.45213 .67593 m .43451 .67664 L .50006 .69489 L F
.81175 .82075 m .89014 .86834 L .84804 .85345 L .172 0 .119 r
F
.77425 .80868 m .81175 .82075 L .84804 .85345 L .137 0 .117 r
F
.66457 .75753 m .69304 .7686 L .73752 .7953 L 0 0 .308 r
F
.61697 .73455 m .69304 .7686 L .66457 .75753 L 0 0 .441 r
F
.69304 .7686 m .77425 .80868 L .73752 .7953 L 0 0 .325 r
F
.50601 .69291 m .56904 .71691 L .56258 .71267 L .335 0 0 r
F
.50601 .69291 m .50006 .69489 L .56904 .71691 L F
.61697 .73455 m .6353 .74191 L .63971 .74473 L 0 0 .441 r
F
.56258 .71267 m .56904 .71691 L .6353 .74191 L .339 0 0 r
F
.56904 .71691 m .6313 .73935 L .6353 .74191 L .249 0 0 r
F
.6313 .73935 m .65418 .74759 L .6353 .74191 L F
.63971 .74473 m .6353 .74191 L .69304 .7686 L 0 0 .441 r
F
.81175 .82075 m .85002 .83174 L .89014 .86834 L .172 0 .119 r
F
.34991 .66153 m .39776 .67414 L .41639 .67596 L .086 0 0 r
F
.34991 .66153 m .32117 .65981 L .39776 .67414 L F
.72226 .77799 m .81175 .82075 L .77425 .80868 L .025 0 .336 r
F
.69304 .7686 m .72226 .77799 L .77425 .80868 L 0 0 .325 r
F
.43451 .67664 m .49393 .69533 L .50006 .69489 L .197 0 0 r
F
.43451 .67664 m .41639 .67596 L .49393 .69533 L F
.6353 .74191 m .72226 .77799 L .69304 .7686 L 0 0 .485 r
F
.32117 .65981 m .3786 .67132 L .39776 .67414 L .064 0 0 r
F
.32117 .65981 m .29175 .65727 L .3786 .67132 L F
.50006 .69489 m .49393 .69533 L .5757 .71951 L .262 0 0 r
F
.52965 .70434 m .5757 .71951 L .56904 .71691 L F
.5339 .7059 m .5757 .71951 L .52965 .70434 L F
.49393 .69533 m .56346 .71528 L .5757 .71951 L .198 0 0 r
F
.56904 .71691 m .5757 .71951 L .58905 .72412 L .249 0 0 r
F
.56346 .71528 m .58258 .72077 L .5757 .71951 L .198 0 0 r
F
.58905 .72412 m .5757 .71951 L .65418 .74759 L .249 0 0 r
F
.49393 .69533 m .48761 .69449 L .54893 .71146 L .198 0 0 r
F
.54476 .70992 m .54893 .71146 L .58258 .72077 L F
.49393 .69533 m .54893 .71146 L .54476 .70992 L F
.50006 .69489 m .5339 .7059 L .52965 .70434 L .262 0 0 r
F
.6353 .74191 m .65418 .74759 L .72226 .77799 L 0 0 .485 r
F
.75224 .78605 m .85002 .83174 L .81175 .82075 L .072 0 .345 r
F
.72226 .77799 m .75224 .78605 L .81175 .82075 L .025 0 .336 r
F
.39776 .67414 m .3786 .67132 L .45602 .68735 L .115 0 0 r
F
.4376 .68126 m .48761 .69449 L .49393 .69533 L .154 0 0 r
F
.4407 .68229 m .48761 .69449 L .4376 .68126 L F
.41639 .67596 m .39776 .67414 L .48761 .69449 L F
.39776 .67414 m .48109 .69254 L .48761 .69449 L .115 0 0 r
F
.45286 .68631 m .45602 .68735 L .48109 .69254 L F
.39776 .67414 m .45602 .68735 L .45286 .68631 L F
.41639 .67596 m .4407 .68229 L .4376 .68126 L .154 0 0 r
F
.65418 .74759 m .75224 .78605 L .72226 .77799 L 0 0 .516 r
F
.75224 .78605 m .783 .79302 L .85002 .83174 L .072 0 .345 r
F
.65418 .74759 m .67362 .75192 L .75224 .78605 L 0 0 .516 r
F
.5757 .71951 m .67362 .75192 L .65418 .74759 L 0 0 .644 r
F
.67362 .75192 m .783 .79302 L .75224 .78605 L 0 0 .538 r
F
.5757 .71951 m .58258 .72077 L .67362 .75192 L 0 0 .644 r
F
.67362 .75192 m .69364 .75512 L .783 .79302 L 0 0 .538 r
F
.58258 .72077 m .69364 .75512 L .67362 .75192 L 0 0 .688 r
F
.48761 .69449 m .58967 .72088 L .58258 .72077 L 0 0 .696 r
F
.48761 .69449 m .48109 .69254 L .58967 .72088 L F
.58258 .72077 m .58967 .72088 L .69364 .75512 L 0 0 .688 r
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{221.938, 239.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M0000kb000`400?l00000o`00003og@3oool0
0=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3o
ool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00
g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?oo
o`00g@3oool00=d0oooo003M0?ooo`00Q03oool70;`0d`X0``2SB03oool007d0oooo3P2l0=<C0<<0
Xcl0oooo001f0?oooaD0_03C4`330:<40<D0KS/0oooo001d0?ooo`80R@3B5@2l0=<B0<<0X`P0a@1^
>03oool00740oooo1@290=8D0;`0da<0``2S2`3506he0?ooo`00KP3oool808T0dQ@0_03C4P330:<?
0<D0KS80oooo001[0?ooo`/0R@3B502l0=<B0<<0Xa80a@1^;`3oool006T0oooo3@290=8D0;`0da40
``2S4P3506h30<L0=bd0oooo001V0?oooa00R@3B4`2l0=<B0<<0Xa40a@1^1@3703L/0?ooo`00H`3o
oolC08T0dPd0_03C1P2m0=8A0<@0XQ40a@1^1`3703L[0?ooo`00H03ooolF08T0dPL0_03C302m0=8A
0<@0XP@0aP1]303506h90<L0=bX0oooo001O0?ooo`80E`3A5@290=8B0;d0dQ40a02R203606d80<D0
KP`0a`0g:03oool005d0oooo101G0=4B08T0dP<0R@3A4P2m0=8A0<@0XP/0aP1]103506h>0<L0=bL0
oooo001K0?ooo`L0E`3A3P290=8608T0dA80_@3B40340:8?0<H0KA00a`0g9P3oool005T0oooo2@1G
0=4;08T0dPT0R@3A4@2m0=8@0<@0XQ00aP1]0P3903L?0<L0=bD0oooo001G0?ooo``0E`3A1`290=8<
08T0dA40_@3B40340:8?0<H0K@@0b@0g3`3703LT0?ooo`00EP3oool=05L0d@@0R@3B3`290=4@0;d0
dQ00a02R3`3606d70<T0=``0a`0g0P39000S0?ooo`00E03oool?05L0dA<0R@3A2`2m0=850;h0d@l0
a@2Q3`3606d90<T0=`T0a`0g1039000S0?ooo`00DP3oool@05L0d@80E`3@4P290=460;d0dPX0_P3A
3`350:430<P0K@`0aP1]2`3903L60<L0=`H0b@008P3oool00500oooo401G0=4405L0d180R@3A402n
0=4>0<D0X@L0b01]203606d=0<T0=`<0a`0g2039000R0?ooo`00CP3ooolA05L0d@D0E`3@40290=42
08X0ca00_P3A3P350:4:0<P0K@@0aP1]3`3903L;0<T00240oooo001<0?oooa40E`3A1`1G0=0=08T0
d@D0RP3?3`2n0=4>0<D0X@h0b01]3`3903L20</000X0b@008@3oool004/0oooo0P0W0=4>05L0d@X0
E`3@2@290=4808X0c`l0_P3A3@350:4?0<P0K@80bP0g303903L30</000/0b@00803oool004X0oooo
100W0=4<05L0d@/0E`3@1P290=4;08X0c`l0_P3A3@350:4>0<P0K@@0bP0g2P3903L50</000X0b@00
803oool004T0oooo1P0W0=4905L0d@d0E`3@0`290=4>08X0c`l0_P3A30350:4>0<P0K@L0bP0g1`39
03L60</000/0b@007`3oool004P0oooo1`0W0=4705L0d@l0E`3@4@2:0<l>0;h0d@`0a@2Q3P3806d9
0<X0=`D0b@0g203;000:0<T001l0oooo00170?ooo`T09`3A1@1G0=4?05L0d080E`3?402:0<l:0;h0
d@@0_`3?30360:040<T0K0T0b01]303:03L20<T0=`T0b`002@3900000`3:=P00oooo0?ooo`0M0?oo
o`00AP3oool;02L0d@80E`3A3`1G0=0405L0ca00RP3?1@2n0=490;l0c``0aP2P203906`40<P0K@h0
bP0g2`3;00060<T000<0bSH07`3oool004@0oooo3@0W0=4?05L0d0L0E`3?3`2:0<l=0;l0c``0aP2P
303906`>0<X0=`80c0002P3;00050<T000@0bSH07`3oool004<0oooo3@0W0=4202L0d0d0E`3@201G
0<l=08X0c`80RP3>3@2o0<l<0<H0X0`0b@1/0P3<03H;0<X0=`@0c0002P3;00020<T000H0bSH07`3o
ool00480oooo3@0W0=4402L0d0X0E`3@2P1G0<l:08X0c`D0RP3>3@2o0<l;0<H0X0`0b@1/103<03H8
0<X0=`H0c0002P3;00080<Xf01l0oooo00110?ooo`d09`3A1P0W0=0705L0d0d0E`3?1P2:0<l808X0
cP`0_`3?30360:0;0<T0K0L0c00f1@3:03L80<`000L0b`000P3<=P080<Xf01l0oooo00100?ooo`d0
9`3A200W0=0505L0d0h0E`3?0`2:0<l;08X0cP`0_`3?2`360:0;0<T0K0T0c00f0`3:03L90<`000D0
b`00103<=P080<Xf01l0oooo000o0?ooo`d09`3A2P0W0=0205L0d100E`3?3P2:0<h<0;l0c`/0aP2P
2P3906`;0<`0=P`0c0000P3;00060<`f00P0bSH07`3oool003h0oooo3@0W0=4;02L0d140E`3?0P1H
0<d=08X0cP/0_`3?2`360:0:0<T0K0/0c00f0P3?000;0<`000P0c3H0203:=P0O0?ooo`00?03oool=
02L0d@`09`3@0P0W0<h>05L0c`@0F03=3@2:0<h60;l0c`D0`03=2`3809h40</0J`D0b@1/2`3<03H4
0<l000T0c00000<0cSH00<`f003<=P001P3<=P080<Xf01l0oooo000l0?ooo`030007d@0W0=409`3A
00T09`3A300W0=0402L0cP`0E`3?1@1H0<d=08X0cP/0`03=2P3809h90</0J`/0c00f1@3?00080<`0
0080cSH0203<=P080<Xf01l0oooo000k0?ooo`<000OA2@0W0=4<02L0d0H09`3>2@1G0<l705P0c@/0
RP3>0P2;0<`;0<00c@X0b02N2@3;06/20<h0=PP0c00f1`3?00050<`000@0cSH0203<=P080<Xf01l0
oooo000j0?ooo`D000OA1`0W0=4<02L0d0L09`3>1`1G0<l:05P0c@P0RP3>102;0<`;0<00c@T0b02N
2@3;06/40<h0=PH0c00f203?00040<`000D0cSH0203<=P060<Xf0080bVl07`3oool003X0oooo1P00
1m4502L0d@`09`3@2@0W0<h505L0c`/0F03=1@2:0<h708/0c0X0`03=2@3809h90</0J`L0cP0f0`3<
03H:0<l00080c0001P3>=P080<`f00<0bSH01@3:K`0O0?ooo`00>@3oool80007d@<09`3A300W0=0;
02L0cP80E`3?3@1H0<d308X0cPT0R`3<2P300<d90<P0WPP0b`1[2@3>03H<0<l000P0cSH0203<=P07
0<Y_0200oooo000h0?ooo`X000OA3@0W0=0<02L0cPl0F03=302;0<`:0<00c@P0b02N2@3;06/80<h0
=P80d@002P3?00000`3@=`00cSH00<hf00060<hf00H0c3H00P3<L0070<Y_0200oooo000h0?ooo`X0
00OA0P001m0:02L0d0`09`3>0P0W0<d=05P0c@80F03;2`2;0<`:0<00c@L0b02N2@3;06/80<h0=P@0
d@001`3?00030=0g00P0cSH0103<=P040<a`00H0bVl08@3oool003L0oooo2P001m440007d0P09`3@
300W0<h402L0c@X0F03=101H0</;08/0c0T0`03=203909`40<d0J@@0b`1[203>03H60=4000D0c`00
103@=`080<hf0080c3H01@3<L0070<Y_0240oooo000f0?ooo`X000OA1`001m0502L0d0`09`3>1@0W
0<d905P0c@D0F03;2`2;0<`40<00c@D0`@3:1`3909`80<d0J@P0cP0f203A00020<l000H0d3L0203>
=P070<a`00L0bVl08@3oool003D0oooo2`001m480007d0<09`3@300W0<h702L0c@H0F03=1`1H0</:
08/0c0X0`@3:1`3909`80<d0J@80d@0e1@3>03H90=4000P0d3L01P3>=P020<i`00L0c7001P3:K`0R
0?ooo`00=@3oool:0007d@X000O@3@0W0<h802L0c@D0F03=2@1H0</808/0c00308`0b@310<X0`@3:
00P0`@3:1P3909`80<d0J@D0d@0e0P3>03H90=4000030=<g003@=`00d3L000H0d3L00`3>=P050<i`
00H0c7001`3:K`0R0?ooo`00=03oool:0007d@/000O@0P001lh:02L0cPX09`3=0P1H0<d;05P0b`H0
R`3<0`2<0<T90<40bPL0b@2L1`3=06T70=40=@T0d@000P3C=`080=0g00L0cW001`3<L0060<Y_02<0
oooo000c0?ooo`/000OA2P001m040007cPP09`3>2`0W0<d=05P0b`@0R`3<1@2<0<T90<40bPH0b@2L
203=06T70=40=@030=D0003A0000d@0000@0d@00103C=`070=0g00030=5a003>L000cW0000D0cW00
1`3<L0060<Y_02<0oooo000c0?ooo`X000OA2`001m050007cPH09`3>300W0<d00`0W0</0F03;05P0
b`0:05P0b`80R`3<1`2<0<T90<40bPH0b@2L1`3=06T70=40=@<0e@00103A00050=<g00D0d3L00`3A
L@070<i`00H0c7001P3:K`0T0?ooo`00<P3oool:0007d@/000O@1`001lh402L0cP`09`3=0`0W0</;
05P0b`T0S03920310<X60<T0W0L0c@1Y1`3A03D50=D00080d@001P3C=`040=0g00<0dG401`3>L007
0<a`00<0bVl00`39Z`0T0?ooo`00<@3oool;0007d@X000O@2@001lh202L0cP`09`3=100W0</:05P0
b`80F038202<0<T80<40bPH0b@2L1`3=06T60=40=@H0e@00203C=`020=0g00D0dG401`3>L0060<a`
00H0bJ/09@3oool00300oooo2`001m4;0007d0X000O>300W0<d602L0b`P0F03;0`1H0<P808`0b@P0
`@3:1@3909`70<d0J@H0d@0e1P3E00000`3G=`00dcL00=<g00060=<g00L0dG401`3>L0030<a`00<0
bjd01@39Z`0V0?ooo`00<03oool2000bd@P000OA2`001m0;0007cP030007c00W0<d09`3=00P09`3=
200W0</505P0b`H0F0381`2<0<T70<40bPH0c02I1P3@06L60=40=@H0e@000P3G=`060=<g0080e7<0
1P3AL@070<i`00H0bjd01@39Z`0W0?ooo`00<03oool4000bd@H000OA2P001m0;0007cP<000O<200W
0<d902L0b`@0F03;1`1H0<P708`0b@@0`@3:0`330<H60<`0V@H0d01W0P3E03@30=40=@H0e@000`3G
=`040=<g00@0e7<01P3AL@050<i`0080cJh01@3;[@050<V[02P0oooo000_0?ooo`L003;A0`001m4;
0007d0X000O>1@001l`602L0c@/09`3;0P1H0</805P0b0L0S0391`330<H50<`0V@H0d01W1@3E03@6
0=D000@0ecL00P3C=`060=Ac00H0dG400P3>L0040<f^00D0bjd01P39Z`0X0?ooo`00;`3oool9000b
d@/000O@2`001lh60007c0@09`3=300W0</;05P0b0@0S0390P2=0<D70<<0aPD0c02I1P3@06L50=D0
=0030=T0003E0000e@000080e@001@3G=`070=Ac00H0dG401P3=[P050<^]00H0bJ/0:@3oool002l0
oooo2@00<]42000bd0P000O@2`001lh80007c0809`3=300W0</202L0b0X0F0380P2<0<T408d0a@L0
``36103<09T60=00I`D0e@0d0`3I00020=D000D0ecL000<0fG@00=Ac003DL`001@3DL`040=5a0080
d;001P3=[P050<^]00D0bJ/0:P3oool002h0oooo2P00<]44000bd0H000O@2P001lh:0007c0`09`3;
100W0<P905P0b0H0S@351P330<H50<`0V@D0d01W1@3E03@40=T000H0ecL00P3IM0070=Ac0080dG40
0`3@/0060<f^00D0bjd01@39Z`0[0?ooo`00;P3oool9000bd@L003;@0`001m0;0007cPX000O<0P00
1l/902L0b`D09`38201H0<P205T0a@D0S@351P330<H50<`0V@D0d01W103E03@40=T000030=dh003G
=`00ecL00080ecL00`3IM0070=Ac00D0d;001P3=[P050<^]00D0bJ/0;03oool002h0oooo2@00<]49
000bd0/000O>2P001l`40007b`L09`3;1`0W0<P605P0b0<0F@351@2=0<D60<<0aP@0c02I1@3@06L4
0=D0=0@0f@000P3M>0030=Lg00@0fG@01@3DL`020=>c00@0d;001`3=[P040<^]00D0bJ/0;@3oool0
02d0oooo2P00<]49000bd080037>20001lh;0007c0H000O;100W0</802L0b0@0F0381@1I0<D508d0
a@H0``36103<09T50=00I`<0e@0d103I00030=dh0080ecL01@3IM0020=Ac00@0dk<01@3@/0060<f^
00@0bjd01@32iP0^0?ooo`00;@3oool9000bd@X003;@1000<Lh60007cPX000O<20001l/202L0b`X0
9`380P1H0<P605T0a@D0S@351P330<H30<`0V@D0d01W0`3E03@40=T000@0gCP01P3IM0060=>c00D0
d;001P3=[P020<^]0080`nP01@32iP0_0?ooo`00;@3oool9000bd@T003;@1`00<Lh30007cPX000O<
2P001l/;02L0b0P0F@351@2=0<D50<<0aP@0cP2D103D06@30=D0=0@0f@00103M>0000`3OMP00fG@0
0=Ud00030=Ud00030=Nf003C/`00dk<000@0dk<0103@/0060<f^00@0`nP01@32iP0`0?ooo`00;03o
ool:000bd@T003;@2@00<Lh;0007c0X000O;00<000K802L0b00W0<P0200W0<P00`0W0<@0F@3505T0
a@0605T0a@@0S@350`330<H20<@0`@@0cP2D103D06@20=X0<P@0f@00103M>0020=mf00<0fG@00P3G
]P060=>c00@0d;001P35j`040<?X00D0`^H0<@3oool002`0oooo2@00<]4:000bd0T0037>0P00<Ld8
0007c0X000O;0`001/P802L0b0<09`341`1I0<D408d0a@D0a031103>09@30=@0I0<0fP0b00<0h000
0=T0003I0000103M>0030=mf00040=Ud003G]P00ekH00=Nf00H0dk<00P3@/0020<S^00H0aN/01033
j0050<;V0380oooo000/0?ooo`T003;A2@00<]0:000acP@0037=1P001l`90007b`D000K81P0W0<P4
02L0a0L0F@350`2=0<D00`2=0<00a0310<@0`@030<@0`@<0cP2D103D06@20=X0<P<0h000103M>003
0=mf00D0ekH01@3C/`040<S^00H0aN/01033j0040<;V03@0oooo000[0?ooo`X003;A2@00<]09000a
cPL0037=0`001l`:0007b`H000K81@0W0<P502L0a0H0F@350P2=0<D208d0`0D0a0310`3>09@30=@0
I0<0fP0b0`3P00030=dh00<0ggH000<0gKX00=Nf003G]P000P3G]P030=>c0080bo801038kP060<G[
00@0`nP01032iP0e0?ooo`00:`3oool9000bd@X003;@2@00<Lh9000ac@X000O;20001/P302L0b0H0
9`341P1I0<D408d0`0D0a0310`3>09@20=@0I0<0fP0b0`3P00000`3V>@00gCP00=dh00030=mf0003
0=fj003G]P00ekH00080ekH01@3;lP040<S^00H0aN/01033j0040<;V03H0oooo000[0?ooo`T003;A
2@00<]0:000acPT0037=0P00<</70007b`X000K800<09`3802L0a00W0<@01P0W0<@405T0a@80F@2o
0`2=0<040<@0`@<0cP2D0`3D06@20=X0<P<0h0000P3V>@030=mf00<0gKX00P3G]P020<kg00@0bo80
1038kP060<G[00@0`nP01032iP0g0?ooo`00:P3oool:000bd@T003;@2@00<Lh:000ac@@0033;1@00
1l/:0006b0T09`340`1I0<D305T0_`<0S@3010340<430<h0U080e01T0`3J03820>000080iST000<0
j7T00=mf003OMP000`3M^P00103G]P00c_L00<kg003>m`040<_b00@0b>h01P35j`040<?X00@0`^H0
>03oool002X0oooo0`00G=86000bd@X003;@2@00<Lh9000ac@L0033;0P001l/;0006b0030006a@0W
0<@09`3400L09`3400<0F@3505T0_`1I0;l00P1I0;l308d0`0@0a0310`3>09@0103D06@0fP0b0=X0
<P3J03820>000080iST00P3XN@00103OMP00gKX00=fj003M^P040<kg00@0bo801038kP060<G[00@0
`nP00`32iP0j0?ooo`00:P3oool6001LdP<003;A2@00<]09000acPX0037=2000<</;0006b0<000K5
200W0<@505T0_`<0S@3010340<420<h0U080e01T0P3J03820>000080iST00P3XN@040=fj00040=3l
003>m`00c_L00<kg00@0bo801038kP050<G[00@0`nP0102<j`0k0?ooo`00:P3oool8001LdPX003;@
2@00<Lh:000ac@P0033;0P00<<P90006b0@000K51P0W0<@202L0_`@0F@2o0`2=0<040<@0`@80cP2D
00D0e01T0=X0<P3J0380fP0b0>0000020>Hi0080j7T000<0i<000=fj003M^P000P3@o0030<kg00@0
bo80102>m00508ga00@0SNh00`2<j`0m0?ooo`00:P3oool8001LdPD005cA1@00<]09000acPT0037=
2@00<</4000`b0H000K81P001/D402L0a0<09`2o1@1I0;l208d0`0@0a0310P3>09@30=X0<P030>00
003V>@00iST00080j7T000<0i<000=fj003@o0000P3@o0030<kg00@0SoP0102>m00408ga00D0SNh0
0`2<j`0n0?ooo`00:P3oool8001LdPT005cA2@00<Lh:000ac@T0033;1@00<<P50006b0L000K50P0W
0<@502L0_`@0F@2o0P2=0<030<@0`@80cP2D00@0f01J0>@0;03T02`0h0000P3V>@020>Qi00030>C0
003@o000d?`00080d?`00P3>m`000`2?o000SoP008oh000208oh00<0S_@01@2=l@0408g^00<0S>/0
@03oool002X0oooo2000G=89001Ld@@005_?1@00<Lh:000ac@P0033;2000<<P20006b0T000K51P0W
0;l405T0_`80S@300P340<4010320;00c`270<l0Q`3H05X20>@0;080iST00P3XN@000`3T`000cOh0
0=3l00020=3l00<0So`0102?n00308kd00@0SO401@2=kP0308c[0440oooo000Z0?ooo`P005cB2@00
G=48001Kc`X0037=2@00<</9000`b0X000K500<000K002L0_`0W0;l0100W0;l305T0_`80S@300`32
0;020<l0Q`040=P0FP3T02`0i00/0?`j0080j7T000D0i<000<gn003@o000d?`008gn000308ol00<0
SoP0102>m00308ga00D0SNh00`2<j`130?ooo`00:P3oool8001LdPT005cA2000Fll3001Jc@L0037=
2@00<</9000`b08002o51`001/D30006`0D09`2o0`1I0;l00`2=0<00RP2a0<80/0020<80/080c`27
00P0f01J0>@0;03a0000o3X00>Qi003T`000cOh00=3l0080SOh00`2?o00308oh00<0S_@0102=l@05
08g^00<0S>/0A03oool002X0oooo2000G=89001Ld@P005_?1P00F/d4000ac@P0033;2P00<<P3000_
a@H000K510001/0502L0_`80F@2o0P2:0;430<80/080c`270P3T02`20?`j00030>C0003=oP00SOh0
0080SOh00`2?o00308oh00<0S_@00`2=l@0508g^00<0S>/0AP3oool002X0oooo2000G=89001Ld@P0
05_?2@00F/d9000`b`T003381P00;lD30006a@D000K01@0W0;l0101I0;l0EP2b05H0/P2:0;430<80
/0080<l0Q`3H05X0i00/0>@0;03l>P00i<000<gn001jk`0208gn0080So`00`2?n00308kd00<0SO40
1P2=kP0308c[04L0oooo000Z0?ooo`P005cB2@00G=48001Kc`T005[=1000FL/5000`b`T003381`00
;lD20006a@H000K0100W0;l305H0/P0<08X0/@320;00`P2`0<80/03?08L0f01J0>@0;03a0000o3X0
0<gn001jk`00SOh00`1Cn`0305Kj00<0EoP00`1Gm00505Ob00<0S>/0B@3oool002X0oooo2000G=89
001Ld@P005_?2@00F/d8001Ib`X003382000;lD80006`0<09`2o00@09@2c05H0/P1F0;80RP2a0`32
0;001`3?08L0f01J0>@0;03l>P00000007[_002=oP000`1Cn`0205Kj00<0EoP00`1Gm00505Ob00<0
Enl0B`3oool002X0oooo2000G=89001Ld@P005_?2@00F/d8001Ib`<005S91P00<<P9000_a@8002k0
1`001/000`0W0;l09@2c02D0/`0205H0/P0308X0/@320;00`P2`0080c`270P3T02`00`3l>P00N^l0
04cd000205?k0080E_X00`1Gn00405Od00@0Eo800`1Gk`1=0?ooo`00:P3oool8001LdPT005cA2000
Fll9001Jc@P005W;1P00F<T3000`b0T002o50`00;/060006`0<09@2c0P1F0;800`2:0;40`P2`0<80
/0020<l0Q`040>@0;03a0000o3X004cd0080Do/00P1FnP0305Oh00<0Eo@0101GlP0305O_04l0oooo
000Z0?ooo`P005cB2@00G=48001Kc`T005[=2000FL/8001Hb@X002o51000;/050006`0030006]@0U
0;<09@2c0080EP2b00P0RP2a0<80/0320;00c`270=P0FP3T02`0o3X004cd0080Do/000@0E_X005Oh
001Gn000EoP00`1Gm00405Ob00<0Enl0D@3oool002X0oooo2000G=89001Ld@P005_?2@00F/d8001I
b`P005S90`00E/H7000_a@H002k00`001/001P001[D09@2c02D0/`0U0;<0EP2b08X0/@80`P2`00H0
c`270=P0FP3T02`0o3X005?k001FnP0305Oh00@0Eo@00`1GlP0305O_05<0oooo000Z0?ooo`P005cB
2@00G=48001Kc`T005[=2000FL/8001Hb@H005K61000;lD7000^`08000K00P001[D202D0/`0805H0
/P2:0;40`P2`0<80/03?08L0i00/0?400000000302?f00@0Eo@00`1GlP0305O_05D0oooo000Z0?oo
o`P005cB2@00G=48001Kc`T005[=2000FL/8001Hb@T005K62@00;/030006]@809@2c00L0EP2b08X0
/@320;00`P2`0<l0Q`3T02`0o3X000808oH0100Tm@0305Ob00<0Enl0E`3oool002T0oooo2@00G=89
001Ld@P005_?2@00F/d8001Ib`P005S92@00E/H2001C`@L002k000<002Vg0006]@001[D00P0U0;<0
1`1F0;80RP2a0<80/0320;00c`270>@0;03l>P00100Tm@0302Gc00<0Enl0F@3oool002X0oooo2@00
Q]<70025dPT005_?2@00F/d8001Ib`P005S92@00E/H4001C`@D002k00P00:KL20006]@0302D0/`1F
0;80EP2b0080`P2`00@0f01J0?40000Tm@009?D0100Ul`0302Ga05/0oooo000Z0?ooo`T008KC2000
QM880024d0P005[=2@00FL/8001Hb@T005K61P00Dl43000^`08002Vg0P001[D202D0/`0505H0/P32
0;00c`270>@0;03l>P000`0Ul`0402Ga05d0oooo000Z0?ooo`T008KC2000QM890024d0P008;>1`00
PL`9001Hb@T005K62000Dl44000Y]`8000Je00H09@2c05H0/P320;00c`270>@0;00Ul`0402Ga0600
oooo000[0?ooo`P008KC2000QM890024d0P008;>2000PL`8001nbPT005K62000Dl42001=^@<002Vg
00H000Je02D0/`1F0;80`P2`0<l0Q`3a000302Ga0680oooo000[0?ooo`T008KC2000QM880024d0P0
08;>2000PL`9001nbPL007c62@00Dl43001=^@8002Vg00H000Je02D0/`1F0;80`P2`0<l0Q`3l>P1U
0?ooo`00:`3oool90026d`P008GB2000Q=080022cPP0087<2@00O/X8001laP@007S21000Dl44001=
^@8002Vg00@000Je02D0/`320;00i00/IP3oool002/0oooo2@00Q]<80025dPP008C@2000P/h80021
c0T007k:2000O<H8001h`PD004fi0P00:KL00`0U0;<0`P2`0?40001V0?ooo`00;03oool80026d`P0
08GB2000Q=080022cPP0087<2@00O/X8001laPP007S20`00L[X3001=^@03000Y]`001[D0`P2`06L0
oooo000/0?ooo`T008KC2000QM880024d0P008;>2000PL`8001nbPP007c62000N<86001b^P03001=
^@00:KL0`P2`06L0oooo000/0?ooo`T008KC2000QM880024d0P008;>2000PL`8001nbPP007c62000
N<88001b^VP0oooo000]0?ooo`P008KC2000QM880024d0P008;>2000PL`8001nbPP007c62000N<80
2@00T[L008f_002=[`00SJl002mH002=[`009E`000e]0:D0O@1W0?ooo`00;@3oool80026d`P008GB
2000Q=080022cPP0087<2000O/X9002G^`8009:g1@000R@3000_F08002EL00@001]T000=K@0=07D0
Y@1mI`3oool002d0oooo2@00Q]<80025dPL008C@2000P/h80021c0T009Zn2@00Uk/200029004002B
]`000R@0008T000290@002EL00H001]T000=K@0=07D0>`1j0:D0O@3`00QV0?ooo`00;@3oool90026
d`P008GB1`00Q=080022cPT009g12000V[h2002G^`D0000010000R@4000>;`8002EL0P006f@01P00
3Fd03@1e00d0M@0k07X0Y@1m0=T0BVH0oooo000^0?ooo`P008KC2000QM870024d0T009o22000WL43
002J_P/000002@003Rl3000KI08000e]00D03@1e03/0NP1]07d0Y@1m0<`0KP1V0?ooo`00;P3oool8
0026d`P008GB2000XL@8002O`P8009g11@0000000`00WL40000000000004000000P000021@003Rl4
000?>08001]T0P003Fd200d0M@0503/0NP1]07d0Y@1m0<`0KP3`00P0I@3oool002h0oooo2000Q]<9
002Sa@P00:742000Wl8=000000P000022@003cP3000=K@803@1e0P0k07X0101]07d0Y@1m0<`0KP3I
04YU0?ooo`00;P3oool9002Ta`P00:?52000XL@3002O`Q8000002@0000h4000?>0D000Pn00@000e]
00d0M@0=07D03@1e0P0k07X01@1]07d0Y@1m0<`0KP3I04X0ePl006@0oooo000_0?ooo`P00:C72000
XlD2002Qa0D0000000<00:740000000000005000000800003PT000Pn0`0=07D203/0NP80K@1m0P2U
07d00`3I04X0l0080?ooo`1S0?ooo`00;`3oool9002Ta`800:?51@00Y;HN000000@0000>1@000QD6
0008?P<03@110P0=07D203/0NP80K@1m0P2U07d00`3<06h0iP0V0?ooo`1S0?ooo`00<03oool6002T
a`03002_aP00Y;H00:Bf00800:Bf8P00000:00025@<000Pn1P0=044303/0NP80K@1m0P2U07d00`3<
06h0f@1:0=H?001S0?ooo`00;P3oool2001`]2l0000020000QD700d0@@<0>P110P0k07X206d0O@80
Y@1m00<0c01^0=T0BP3`00P0H`3oool002L0oooo>@00000900`060<03@111P0j044306d0O@80Y@1m
00@0c01^0=T0BP3V02H0ePl0HP3oool00380oooo9`00000:00/000L0300H1`0j044206`0?@80K@1m
0P2U07d20<`0KP030=T0BP3`00P0oooo0640oooo000b0?ooo`L00:C71`03000600@000L01P001`07
000800T000T02`001`0f01L403X0@@@0K00m0`2U07d20<`0KP030=T0BP3`00P0oooo0640oooo000c
0?ooo`P00:C71@00XlD600<000@010001P06000700L000P02@00200`000703H05`H0K00m0P2R03D0
1P2U07d0c01^0<`0KP3I04X0iP0V0=H?0640oooo000c0?ooo`T00:C72000XlD3002Qa0D0400000<0
5P0000H0000600001006000600L000T0:@001`0`000403H05`<0H`0?101/03d30:80=@80c01^0P3I
04X00`3`00P0oooo0?ooo`1O0?ooo`00=03oool8002Ta`P00:?51`00XL@2002MSPD040001P0L0005
028000P0:@001P0`000706<03`80K00m102R03D01@340240f@1:0=T0BP3`00P0ePl00600oooo000e
0?ooo`P00:C72000XlD3002Qa0@009n@1`00WHh4010000D07000100R000702T000L0F0001@1S00l5
0:80=@80a00Q00<0f@1:0>H09P3F3`00H03oool003D0oooo2000Y<L8002Sa@P009n@2@00WHh3002K
S@<07@00100L0003028000L0B`001P1H000306<03`80TP000`2R03D20<@08@030<H01@3V02H0l008
0600oooo000f0?ooo`P00:C71000XlD4002QT@P009n@2@00WHh8002KS@0301d0000W0000<P000080
<P000P0n000604/000H0F0001@2B00001`2R03D0a00Q0<@08@340240aP050?00203F3`00G`3oool0
03H0oooo2000Y<L9002QT@P009n@2000WHh8002KS@D009IG00<09`000380000b00000P0n000604/0
00<0F0000P1n0004098000<0a00Q0P3600D00`3F3`00oooo0?ooo`1M0?ooo`00=`3oool4002Ta`@0
0:>A2@00XI48002OT0P009f>1@00Vhd3002IF@P009IG00@09`000380000b0000?P001@1;000507h0
00<0TP0000<0[0000<@08@3402400P3600D00`000000oooo0?ooo`1L0?ooo`00=`3oool9002ST@T0
0:6A1`00Wi09002MSP8009^=1P00VET9002FE`0501d0000W00009`000380000n00001@1Y000407h0
00040980002/0000[0000:`00080aP0500<0_0000?ooo`3oool0G03oool003P0oooo2@00Xi49002Q
T@L009n@2000WHh9002IF@P009IG00D009@S002@8P00T280090R0000/P020380000304<0001E0000
J@000080J@000`1n00040:`000030:80003600D0_00005d0oooo000i0?ooo`T00:>A2000XI48002O
T0H009f>0`00W5X8002IF@H009IG0`00U2<6002@8P040000/P130000@`0005D00080J@000P1n0002
08h00080[00000<0XP000<H01@2l0000G03oool003X0oooo2@00Xi48002QT@P009n@1000WHh5002L
FPP009UI1000UUL5002D8`@0090R100<S@001@130000002b0380001E0000J@0000@0SP0000@0[000
0:80002R0000_000F`3oool003/0oooo2@00Xi48002QT@P009n@0P00WHh7002LFPP009UI0P00UUL7
002D8`<0090R1P0<S@001P0]RP00;H800000/P000;80E@00074000<0SP000P2R00000`2l0000oooo
0?ooo`1H0?ooo`00?03oool8002ST@T00:6A1`00Wi0:002LFPP009UI2@00U2<2002@8PH038d00`0]
RP000`0]PP00Agd004<000020000/P<0SP000P2R001I0?ooo`00?@3oool8002ST@T00:6A1@00Wi03
002NFPT009aJ1`00VET2002H90P009@S1`0<S@0402f:00<0Agd000P0F7H0038000000;80002b08h0
001k0000XP0008H005L0oooo000n0?ooo`P00:>A2@00XI42002OT0H009iJ2@00W5X5002IF@@009PT
1`00U2<200bB00D038d01@0]RP000`19QP00Agd004Mm000205Qf0003051P00000:@0002`0080002`
00<0QP000?ooo`3oool0E03oool003l0oooo2000Xi48002QT@T009iJ2@00W5X4002IF@D009PT1P00
U2<300bB00@038d01@0]RP0304V600<0F7H00P1@H0000`0]>`00002T0000/0020000/5@0oooo0010
0?ooo`P00:>A1P00XI43002PF`P009iJ2@00W5X2002IF@P009PT1000U2<500bB008038d01@0]RP04
04V60080GH800`1@H000100]>`0001T0000900000:@30000/540oooo00110?ooo`P00:>A1000XI45
002PF`P009iJ2@00W5X:002H90<009@S1P0<TP000`0<S@00;HX002f:000302f:00D0BHH00P1MPP02
05]^000702dk000K9P006bH001/V001I0000001`0000Y0040000/4d0oooo00120?ooo`P00:>A0P00
XI47002PF`P009iJ2000W5X2002J90T009PT0P00U2<700bB00H0;HX01019QP0305f20080Ffh00P10
B@0201/V00050009000003d0001`0000L0000:@010000;1:0?ooo`00@`3oool7002ST@X00:1K2000
WUX6002LFP@009XT2@00V2@800bB0080;Y00100]RP0504V600<0GH800P1KKP02041900806bH000<0
00T000006@0003d00P0007020000Y0@0002`A`3oool004@0oooo1@00Xi43002QG0T00:1K2000WUX4
002LFPH009XT2000V2@200bF00H03980100^T00202f:00D0BHH0101MPP0205]^0080@4T00`0K9P02
00006@050000?@000700001`0000L00008@01@000;140?ooo`00A@3oool2002ST@H00:5L2@00X5/8
002NFP8009aJ2000VR@7002H90<039H01@0<TP0602j@00H0BHH00`1MPP0305]^00<0@4T00P0K9P03
00006@040000?@000700001`0000L08000241@0008U10?ooo`00A@3oool9002QG0T00:1K2000WUX;
002J90@009PT1@0<UP0400bB00L0;Y000P1;S@0304V600@0GH800`1KKP03041900806bH000D01`d0
00006@0001T0000I0000B0020000CP040000L00007`000240000Q0@00029?`3oool004L0oooo2000
XE`9002PF`H009iJ0`00WB@:002J90<009PT1`0<UP0200bB00L0;Y00101;S@0204V600@0GH800`1K
KP03041900806bH00P073@0200006@0300006`0004P0001>0080001>00<0001l0000Q00008@01000
08Tm0?ooo`00B03oool8002QG0T00:1K1000WUX5002M90X009XT0P00V2@800bF000300bB000^T000
;Y0000H0;Y001@1;S@0505f200<0Ffh00`10B@0302l]00801`d000<0000I00006`0001/0100004h0
100005<0001l0000Q00008@30000RC/0oooo00190?ooo`P00:5L2@00X5/2002NFPP009dT2@00VR@:
00bF00P0;Y001P1;S@04066900@0Ffh0101<D@0202l]00<01`d00`0001/30000CP<0001C0P0008@3
0000RCT0oooo001:0?ooo`T00:5L2000X5/:002M90P009XT0P0<V@0900bF0080;Y@01@0^T00704^=
00@0HHT0101RM`0404aA00<0;bd00P073@0300006`@0001>0`0005<200H0EP030000Q00008T00029
03L0oooo001<0?ooo`P00:5L1`00X5/2002N90X009dT1P00VR@400bI00L039H0100^U00402j@00H0
Bhd01@1QR@04069g00@0C5400`0_;@0200L=000501/?000001/0000K00006`0801`00P0004h40000
D`<01P1F0P0008Te0?ooo`00C@3oool8002QG0D00:1K1000WR@:002M90@009XT1`0<V@0500bF00H0
;Y@00P0^T00704^=00D0HHT0101RM`0504aA00<0;bd000<01`d001/?000K3`000P0001/300P07003
0000CP0005<0001C0080001C0`0605H00`0B05P000290?ooo`0b0?ooo`00CP3oool8002QG0@00:1K
1P00WR@:002M908009XT2@0<V@0300bF00P0;Y@01`1;S@05066900D0HWL01@1<D@0302l]00@06`l0
00<0000K00P0700801`00P0801`40000D`@01P1F0P0B05Pa0?ooo`00C`3oool8002QG0800:1K2000
WR@:002M90`039T000<039H002jD000^U0001`0^U00304bB00@0Bhd01@1QR@05069g00D0C5400P0_
;@0203`a00@06`l01@0801`0100G01d0001C0000D`0005<300H0EP<04P1H;`3oool00540oooo1`00
XE`;002N90P009dT0P0<V`0;00bI00T0;Y@01`1<TP06066900D0HWL01@1<D@0403`a00@06`l01@08
01`301L07@80001C0`0605H30180F2d0oooo001B0?ooo`H00:5L0P00X2D:002N90L009dT100<V`09
00bI00<0;iL01`0^U00704bB00<0Hhl00`1QR@05069g00<0C5400`1DE`0403`a00<06`l00P0Z4003
00P070D05`0M100605H30180F2/0oooo001C0?ooo`@00:5L1@00X2D:002N90D009dT1P0<V`0700bI
00D0;iL01@0^U00804bB00D0Hhl01P1RM`0605AG00@0?3400P0K3`0402X@0080200L1@0G01d202<0
7@801P1F100B05PY0?ooo`00E03oool2002QG0P00:0U2@00WR@4002M90P039/01@0<V@0702nG00@0
;Y@0201<TP0506>?00L0Igd01P1DE`0403`a000301/?000Z4000:Q0000<0:Q0000<0200L01L07@0G
01d00`0G01d402<07@0300H0EP0B05P04P1H00804P1H9`3oool005D0oooo2`00X2D9002N908009dT
2P0<V`0300bI00T0;iL00P0^U00804bB00H0Hhl01`1WO@0605AG00@0?3401`0Z400501L07@D08`0M
1@0B05PU0?ooo`00E`3oool:002P9@T009hT3@0<V`000`0<V@00;iL002nG000902nG00T0C9801P1S
S`0706Mm00L0E5L00P0l<@0304Dd00D0:Q000P0d4@0301L07@H08`0M0P0/01h30180F2<0oooo001I
0?ooo`X00:0U1`00WR@300bM00/039/0300_U`0404fF00D0C9801P1SS`0706Mm00L0E5L01P15=003
02X@00@0=1400P0G01d602<07@D0;00N8P3oool005/0oooo2P00X2D4002N90H039d02P0<V`0202nJ
00T0;iL02@1=UP0706>?00L0Igd0101DE`0405YK00H0AC@00P0Z400503@A000301L07@0S01d08`0M
00@08`0M1P0/01hP0?ooo`00G@3oool:002P9@8009hT200<W@0800bK00D0;iX01P0_U`0:04fF00@0
IY@00`1SS`0706Mm00P0FU/01`15=00703@A00H08`0M1P0/01hO0?ooo`00GP3oool:002P9@/039d0
1P0<V`0702nJ00D0;iL02P1=UP0706JD00P0Jh801`1JF`0604Dd0080C3L01P0d4@0203`B00@08`0M
1P0/01hN0?ooo`00H03oool8002P9@<039l02P0<W@0400bK00X0;iX00P0_U`0:04fF00P0IY@0201[
PP0805YK00<0AC@01@1<=`0403@A00D0?1800P0S01d602`07Qd0oooo001R0?ooo`H00:0U1@0<W`0:
00bM008039/0300_VP0;04fF00P0IY@0201[PP0805YK0080AC@01`1<=`0303@A00L0?1801P0/01hL
0?ooo`00I03oool4002P9@L039l02P0<W@0=02nJ00<0CYT01`1=UP0906JD00T0Jh801`1JF`0:04`g
000303@A000l4P00?18000H0?1800P124P0402`07Q/0oooo001V0?ooo`800:0U2@0<W`0800bM00<0
;i`02P0_VP0704jI00@0CIH02@1VU00906^200@0FU/0101OGP0904`g00P0?1801@124P0202`07QX0
oooo001W0?ooo``039l01P0<W@0602nL00P0;iX02P1>V@0:06JD00T0Jh802@1OGP0704`g00<0DCP0
1@0l4P08048B01T0oooo001Z0?ooo`/039l0100<W@0902nL00D0;iX02`1>V@0:06NG00X0KXD02@1O
GP0404`g00H0DCP0100l4P08048B01P0oooo001/0?ooo`/039l00P0<W@0<02nL00<0;iX02`1>V@0:
06NG00X0KXD02P1OGP0204`g00P0DCP00P0l4P08048B01P0oooo001_0?ooo`X039l03`0_W00<04jI
00X0IiL02P1^Q@0:05mN00/0DCP02@124P0G0?ooo`00L@3oool900bO00<0;ih0300_W00404nK00P0
CYT02P1WU`0;06j500H0Geh0101SH009054h00<0ESX01P124P0G0?ooo`00L`3oool700bO00H0;ih0
2@0_W00904nK00@0CYT02P1WU`0;06j500<0Geh0201SH007054h00D0ESX01@124P0F0?ooo`00MP3o
ool400bO00X0;ih01P0_W00<04nK00/0IiL02`1^Q@0<06=P00@0DCP02@1F>P02048B01H0oooo001h
0?ooo`8039l03@0_WP0302nL00d0Ci/02`1YVP0<072800`0Hf000P1A>00;05Hj01H0oooo001j0?oo
oa00;ih03P1?V`0;06VJ00`0L8P0301SH00<05Hj01H0oooo001n0?ooo`d0;ih00`1?W@0:04nK00`0
JIX03@1`R00806=P00@0IV802@1F>P0G0?ooo`00P@3oool:02nN00L0Cid01`1?V`0<06VJ00d0L8P0
101SH00906IR00L0ESX05`3oool008@0oooo200_WP0:04nM00@0Ci/0301YVP0=072800h0IV80101F
>P0H0?ooo`00Q`3oool502nN00h0Cid03@1YVP07072800L0LX/03P1VHP0205Hj01P0oooo002:0?oo
o`<0;ih03P1?W@0=06ZL00l0LX/03@1VHP0I0?ooo`00S@3oool?04nM00h0JY`03P1bR`0906IR01`0
oooo002C0?ooo`X0Cid03P1ZW00?07:;00@0IV807`3oool009T0oooo1@1?W@0>06ZL00l0LX/08P3o
ool009l0oooo3P1ZW00807:;02P0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool0
0=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3o
ool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00
g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo003M0?ooo`00g@3oool00=d0oooo0000\
\>"],
    ImageRangeCache->{{{0, 220.938}, {238.938, 0}} -> {0, 0, 0, 0}}],
  StyleBox["\n\t\tFigure 2.A",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  A graphical view of the Riemann surface for  ",
  Cell[BoxData[
      \(w = z\^\(1\/2\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tConsider ",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^\(1\/2\)\)\)]],
  ", which has two values for any ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ".  Each function ",
  Cell[BoxData[
      RowBox[{\(f\_1\), \((z)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(f\_2\), \((z)\)}]]],
  " in Figure 2.18 is single-valued on the domain formed by cutting the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane along the negative ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " axis.  Let ",
  Cell[BoxData[
      \(D\_1\)]],
  " and ",
  Cell[BoxData[
      \(D\_2\)]],
  " be the domains of ",
  Cell[BoxData[
      RowBox[{\(f\_1\), \((z)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(f\_2\), \((z)\)}]]],
  ", respectively.  The range set for ",
  Cell[BoxData[
      \(\(f\_1\) \((z)\)\)]],
  " is the set ",
  Cell[BoxData[
      \(H\_1\)]],
  " consisting of the right half-plane, and the positive ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " axis; the range set for ",
  Cell[BoxData[
      \(\(f\_2\) \((z)\)\)]],
  " is the set ",
  Cell[BoxData[
      \(H\_2\)]],
  " consisting of the left half-plane and the negative ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " axis.  The sets ",
  Cell[BoxData[
      RowBox[{\(H\_1\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(H\_2\)}]]],
  " are \"glued together\" along the positive v axis and the negative ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " axis to form the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane with the origin deleted."
}], "Text"],

Cell[TextData[{
  "\tWe stack ",
  Cell[BoxData[
      \(D\_1\)]],
  " directly above ",
  Cell[BoxData[
      \(D\_2\)]],
  ".  The edge of ",
  Cell[BoxData[
      \(D\_1\)]],
  " in the upper half-plane is joined to the edge of ",
  Cell[BoxData[
      \(D\_2\)]],
  " in the lower half-plane, and the edge of ",
  Cell[BoxData[
      \(D\_1\)]],
  " in the lower half-plane is joined to the edge of ",
  Cell[BoxData[
      \(D\_2\)]],
  " in the upper half-plane.  When these domains are glued together in this \
manner, they form ",
  StyleBox["R",
    FontFamily->"Courier New"],
  ", which is a Riemann surface domain for the mapping ",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^\(1\/2\)\)\)]],
  ".  The portions of ",
  Cell[BoxData[
      RowBox[{\(D\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(D\_2\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "R"}]}]]],
  " that lie in ",
  Cell[BoxData[
      \({z : \(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)}\)]],
  " are shown in Figure 2.20."
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6193 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1 -0.147002 1 [
[ 0 0 0 0 ]
[ 1 .6193 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .6193 L
0 .6193 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.46506 .54239 m
.46616 .59988 L
s
.46429 .50194 m .46506 .54239 L .3297 .54623 L p 1 1 1 r
F P
0 g
s
.46506 .54239 m .46429 .50194 L .57405 .48079 L p 1 1 1 r
F P
0 g
s
.57405 .48079 m .59948 .51679 L .46506 .54239 L p 1 1 1 r
F P
0 g
s
.59948 .51679 m .57405 .48079 L .67053 .44188 L p 1 1 1 r
F P
0 g
s
.67053 .44188 m .71877 .46979 L .59948 .51679 L p 1 1 1 r
F P
0 g
s
.35381 .50475 m .3297 .54623 L .20766 .52883 L p 1 1 1 r
F P
0 g
s
.3297 .54623 m .35381 .50475 L .46429 .50194 L p 1 1 1 r
F P
0 g
s
.46349 .45966 m .46429 .50194 L .35381 .50475 L p 1 1 1 r
F P
0 g
s
.46429 .50194 m .46349 .45966 L .54754 .44327 L p 1 1 1 r
F P
0 g
s
.54754 .44327 m .57405 .48079 L .46429 .50194 L p 1 1 1 r
F P
0 g
s
.57405 .48079 m .54754 .44327 L .6207 .41305 L p 1 1 1 r
F P
0 g
s
.6207 .41305 m .67053 .44188 L .57405 .48079 L p 1 1 1 r
F P
0 g
s
.20766 .52883 m .25521 .48972 L .35381 .50475 L p 1 1 1 r
F P
0 g
s
.37891 .46155 m .35381 .50475 L .25521 .48972 L p 1 1 1 r
F P
0 g
s
.35381 .50475 m .37891 .46155 L .46349 .45966 L p 1 1 1 r
F P
0 g
s
.71877 .46979 m .67053 .44188 L .7412 .38715 L p 1 1 1 r
F P
0 g
s
.7412 .38715 m .80814 .40305 L .71877 .46979 L p 1 1 1 r
F P
0 g
s
.25521 .48972 m .20766 .52883 L .11409 .49173 L p 1 1 1 r
F P
0 g
s
.46265 .41544 m .46349 .45966 L .37891 .46155 L p 1 1 1 r
F P
0 g
s
.46349 .45966 m .46265 .41544 L .51989 .40414 L p 1 1 1 r
F P
0 g
s
.51989 .40414 m .54754 .44327 L .46349 .45966 L p 1 1 1 r
F P
0 g
s
.67053 .44188 m .6207 .41305 L .67303 .37096 L p 1 1 1 r
F P
0 g
s
.67303 .37096 m .7412 .38715 L .67053 .44188 L p 1 1 1 r
F P
0 g
s
.54754 .44327 m .51989 .40414 L .5692 .38326 L p 1 1 1 r
F P
0 g
s
.5692 .38326 m .6207 .41305 L .54754 .44327 L p 1 1 1 r
F P
0 g
s
.25521 .48972 m .30423 .4494 L .37891 .46155 L p 1 1 1 r
F P
0 g
s
.40507 .41653 m .37891 .46155 L .30423 .4494 L p 1 1 1 r
F P
0 g
s
.37891 .46155 m .40507 .41653 L .46265 .41544 L p 1 1 1 r
F P
0 g
s
.11409 .49173 m .18134 .45853 L .25521 .48972 L p 1 1 1 r
F P
0 g
s
.30423 .4494 m .25521 .48972 L .18134 .45853 L p 1 1 1 r
F P
0 g
s
.6207 .41305 m .5692 .38326 L .60361 .35447 L p 1 1 1 r
F P
0 g
s
.60361 .35447 m .67303 .37096 L .6207 .41305 L p 1 1 1 r
F P
0 g
s
.18134 .45853 m .24962 .42483 L .30423 .4494 L p 1 1 1 r
F P
0 g
s
.35479 .4078 m .30423 .4494 L .24962 .42483 L p 1 1 1 r
F P
0 g
s
.30423 .4494 m .35479 .4078 L .40507 .41653 L p 1 1 1 r
F P
0 g
s
.46176 .36912 m .46265 .41544 L .40507 .41653 L p 1 1 1 r
F P
0 g
s
.46265 .41544 m .46176 .36912 L .49101 .36327 L p 1 1 1 r
F P
0 g
s
.49101 .36327 m .51989 .40414 L .46265 .41544 L p 1 1 1 r
F P
0 g
s
.80814 .40305 m .7412 .38715 L .77413 .32056 L p 1 1 1 r
F P
0 g
s
.77413 .32056 m .85245 .32056 L .80814 .40305 L p 1 1 1 r
F P
0 g
s
.51989 .40414 m .49101 .36327 L .51594 .35244 L p 1 1 1 r
F P
0 g
s
.51594 .35244 m .5692 .38326 L .51989 .40414 L p 1 1 1 r
F P
0 g
s
.43235 .36958 m .40507 .41653 L .35479 .4078 L p 1 1 1 r
F P
0 g
s
.40507 .41653 m .43235 .36958 L .46176 .36912 L p 1 1 1 r
F P
0 g
s
.18134 .45853 m .11409 .49173 L .06477 .4382 L p 1 1 1 r
F P
0 g
s
.7412 .38715 m .67303 .37096 L .6958 .32056 L p 1 1 1 r
F P
0 g
s
.6958 .32056 m .77413 .32056 L .7412 .38715 L p 1 1 1 r
F P
0 g
s
.5692 .38326 m .51594 .35244 L .53289 .33768 L p 1 1 1 r
F P
0 g
s
.53289 .33768 m .60361 .35447 L .5692 .38326 L p 1 1 1 r
F P
0 g
s
.24962 .42483 m .31894 .39061 L .35479 .4078 L p 1 1 1 r
F P
0 g
s
.40697 .36488 m .35479 .4078 L .31894 .39061 L p 1 1 1 r
F P
0 g
s
.35479 .4078 m .40697 .36488 L .43235 .36958 L p 1 1 1 r
F P
0 g
s
.06477 .4382 m .14464 .41448 L .18134 .45853 L p 1 1 1 r
F P
0 g
s
.24962 .42483 m .18134 .45853 L .14464 .41448 L p 1 1 1 r
F P
0 g
s
.67303 .37096 m .60361 .35447 L .61748 .32056 L p 1 1 1 r
F P
0 g
s
.61748 .32056 m .6958 .32056 L .67303 .37096 L p 1 1 1 r
F P
0 g
s
.46084 .32056 m .46176 .36912 L .43235 .36958 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .49101 .36327 L .46176 .36912 L closepath p 1 1 1 r
F P
0 g
s
.14464 .41448 m .22418 .39085 L .24962 .42483 L p 1 1 1 r
F P
0 g
s
.31894 .39061 m .24962 .42483 L .22418 .39085 L p 1 1 1 r
F P
0 g
s
.46084 .32056 m .51594 .35244 L .49101 .36327 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .43235 .36958 L .40697 .36488 L closepath p 1 1 1 r
F P
0 g
s
.60361 .35447 m .53289 .33768 L .53916 .32056 L p 1 1 1 r
F P
0 g
s
.53916 .32056 m .61748 .32056 L .60361 .35447 L p 1 1 1 r
F P
0 g
s
.46084 .32056 m .53289 .33768 L .51594 .35244 L closepath p 1 1 1 r
F P
0 g
s
.31894 .39061 m .38934 .35586 L .40697 .36488 L p 1 1 1 r
F P
0 g
s
.46084 .32056 m .40697 .36488 L .38934 .35586 L closepath p 1 1 1 r
F P
0 g
s
.22418 .39085 m .30339 .36733 L .31894 .39061 L p 1 1 1 r
F P
0 g
s
.38934 .35586 m .31894 .39061 L .30339 .36733 L p 1 1 1 r
F P
0 g
s
.15042 .22818 m .0736 .20532 L .08277 .13551 L p .872 .872 .872 r
F P
0 g
s
.46084 .32056 m .53916 .32056 L .53289 .33768 L closepath p 1 1 1 r
F P
0 g
s
.08277 .13551 m .16082 .17371 L .15042 .22818 L p .872 .872 .872 r
F P
0 g
s
.22755 .25114 m .15042 .22818 L .16082 .17371 L p .872 .872 .872 r
F P
0 g
s
.30339 .36733 m .38228 .3439 L .38934 .35586 L p 1 1 1 r
F P
0 g
s
.46084 .32056 m .38934 .35586 L .38228 .3439 L closepath p 1 1 1 r
F P
0 g
s
.16082 .17371 m .23762 .2113 L .22755 .25114 L p .872 .872 .872 r
F P
0 g
s
.305 .27418 m .22755 .25114 L .23762 .2113 L p .872 .872 .872 r
F P
0 g
s
.23762 .2113 m .31321 .2483 L .305 .27418 L p .872 .872 .872 r
F P
0 g
s
.38276 .29733 m .305 .27418 L .31321 .2483 L p .872 .872 .872 r
F P
0 g
s
.31321 .2483 m .3876 .28472 L .38276 .29733 L p .872 .872 .872 r
F P
0 g
s
.46084 .32056 m .38276 .29733 L .3876 .28472 L closepath p .872 .872 .872 r
F P
0 g
s
.85245 .32056 m .77413 .32056 L .76007 .24877 L p 1 1 1 r
F P
0 g
s
.76007 .24877 m .83857 .22994 L .85245 .32056 L p 1 1 1 r
F P
0 g
s
.85245 .32056 m
.9014 .32056 L
s
.77413 .32056 m .6958 .32056 L .68309 .26724 L p 1 1 1 r
F P
0 g
s
.68309 .26724 m .76007 .24877 L .77413 .32056 L p 1 1 1 r
F P
0 g
s
.6958 .32056 m .61748 .32056 L .60758 .28536 L p 1 1 1 r
F P
0 g
s
.60758 .28536 m .68309 .26724 L .6958 .32056 L p 1 1 1 r
F P
0 g
s
.61748 .32056 m .53916 .32056 L .53351 .30313 L p 1 1 1 r
F P
0 g
s
.53351 .30313 m .60758 .28536 L .61748 .32056 L p 1 1 1 r
F P
0 g
s
.46084 .32056 m .53351 .30313 L .53916 .32056 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .51651 .28756 L .53351 .30313 L closepath p .996 .996 .996 r
F P
0 g
s
.46084 .32056 m .4906 .27589 L .51651 .28756 L closepath p .984 .984 .984 r
F P
0 g
s
.46084 .32056 m .45987 .2696 L .4906 .27589 L closepath p .965 .965 .965 r
F P
0 g
s
.46084 .32056 m .42931 .26934 L .45987 .2696 L closepath p .941 .941 .941 r
F P
0 g
s
.46084 .32056 m .4039 .27479 L .42931 .26934 L closepath p .916 .916 .916 r
F P
0 g
s
.46084 .32056 m .3876 .28472 L .4039 .27479 L closepath p .892 .892 .892 r
F P
0 g
s
.34504 .22747 m .4039 .27479 L .3876 .28472 L p .892 .892 .892 r
F P
0 g
s
.3876 .28472 m .31321 .2483 L .34504 .22747 L p .892 .892 .892 r
F P
0 g
s
.60758 .28536 m .53351 .30313 L .51651 .28756 L p .996 .996 .996 r
F P
0 g
s
.28418 .17854 m .34504 .22747 L .31321 .2483 L p .892 .892 .892 r
F P
0 g
s
.31321 .2483 m .23762 .2113 L .28418 .17854 L p .892 .892 .892 r
F P
0 g
s
.39634 .21577 m .42931 .26934 L .4039 .27479 L p .916 .916 .916 r
F P
0 g
s
.4039 .27479 m .34504 .22747 L .39634 .21577 L p .916 .916 .916 r
F P
0 g
s
.51651 .28756 m .57418 .25337 L .60758 .28536 L p .996 .996 .996 r
F P
0 g
s
.57418 .25337 m .51651 .28756 L .4906 .27589 L p .984 .984 .984 r
F P
0 g
s
.68309 .26724 m .60758 .28536 L .57418 .25337 L p .996 .996 .996 r
F P
0 g
s
.45885 .21605 m .45987 .2696 L .42931 .26934 L p .941 .941 .941 r
F P
0 g
s
.42931 .26934 m .39634 .21577 L .45885 .21605 L p .941 .941 .941 r
F P
0 g
s
.4906 .27589 m .52177 .2291 L .57418 .25337 L p .984 .984 .984 r
F P
0 g
s
.52177 .2291 m .4906 .27589 L .45987 .2696 L p .965 .965 .965 r
F P
0 g
s
.22121 .12791 m .28418 .17854 L .23762 .2113 L p .892 .892 .892 r
F P
0 g
s
.23762 .2113 m .16082 .17371 L .22121 .12791 L p .892 .892 .892 r
F P
0 g
s
.45987 .2696 m .45885 .21605 L .52177 .2291 L p .965 .965 .965 r
F P
0 g
s
.76007 .24877 m .68309 .26724 L .63396 .21792 L p .996 .996 .996 r
F P
0 g
s
.57418 .25337 m .63396 .21792 L .68309 .26724 L p .996 .996 .996 r
F P
0 g
s
.15601 .07549 m .22121 .12791 L .16082 .17371 L p .892 .892 .892 r
F P
0 g
s
.16082 .17371 m .08277 .13551 L .15601 .07549 L p .892 .892 .892 r
F P
0 g
s
.36181 .15967 m .39634 .21577 L .34504 .22747 L p .916 .916 .916 r
F P
0 g
s
.34504 .22747 m .28418 .17854 L .36181 .15967 L p .916 .916 .916 r
F P
0 g
s
.63396 .21792 m .57418 .25337 L .52177 .2291 L p .984 .984 .984 r
F P
0 g
s
.83857 .22994 m .76007 .24877 L .69596 .18116 L p .996 .996 .996 r
F P
0 g
s
.63396 .21792 m .69596 .18116 L .76007 .24877 L p .996 .996 .996 r
F P
0 g
s
.45777 .1597 m .45885 .21605 L .39634 .21577 L p .941 .941 .941 r
F P
0 g
s
.39634 .21577 m .36181 .15967 L .45777 .1597 L p .941 .941 .941 r
F P
0 g
s
.52177 .2291 m .55444 .18005 L .63396 .21792 L p .984 .984 .984 r
F P
0 g
s
.55444 .18005 m .52177 .2291 L .45885 .21605 L p .965 .965 .965 r
F P
0 g
s
.69596 .18116 m .76033 .143 L .83857 .22994 L p .996 .996 .996 r
F P
0 g
s
.45885 .21605 m .45777 .1597 L .55444 .18005 L p .965 .965 .965 r
F P
0 g
s
.32562 .10087 m .36181 .15967 L .28418 .17854 L p .916 .916 .916 r
F P
0 g
s
.28418 .17854 m .22121 .12791 L .32562 .10087 L p .916 .916 .916 r
F P
0 g
s
.69596 .18116 m .63396 .21792 L .55444 .18005 L p .984 .984 .984 r
F P
0 g
s
.28763 .03916 m .32562 .10087 L .22121 .12791 L p .916 .916 .916 r
F P
0 g
s
.22121 .12791 m .15601 .07549 L .28763 .03916 L p .916 .916 .916 r
F P
0 g
s
.45664 .10033 m .45777 .1597 L .36181 .15967 L p .941 .941 .941 r
F P
0 g
s
.36181 .15967 m .32562 .10087 L .45664 .10033 L p .941 .941 .941 r
F P
0 g
s
.55444 .18005 m .58873 .12857 L .69596 .18116 L p .984 .984 .984 r
F P
0 g
s
.58873 .12857 m .55444 .18005 L .45777 .1597 L p .965 .965 .965 r
F P
0 g
s
.76033 .143 m .69596 .18116 L .58873 .12857 L p .984 .984 .984 r
F P
0 g
s
.45777 .1597 m .45664 .10033 L .58873 .12857 L p .965 .965 .965 r
F P
0 g
s
.58873 .12857 m .62477 .07447 L .76033 .143 L p .984 .984 .984 r
F P
0 g
s
.45545 .0377 m .45664 .10033 L .32562 .10087 L p .941 .941 .941 r
F P
0 g
s
.32562 .10087 m .28763 .03916 L .45545 .0377 L p .941 .941 .941 r
F P
0 g
s
.62477 .07447 m .58873 .12857 L .45664 .10033 L p .965 .965 .965 r
F P
0 g
s
.45664 .10033 m .45545 .0377 L .62477 .07447 L p .965 .965 .965 r
F P
0 g
s
gsave
.89289 .34183 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.49311 .59115 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 178.313},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/R000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00D@3ooold000009/0oooo001=0?ooo`@000000P3Zj^X00`000000l?3`0?3`l00/0?3`l003
0000003gmoL0moOg00@00000U`3oool004X0oooo0`0000060>[ZjP030000003`l?00l?3`02`0l?3`
00<000000?Ogm`3gmoL0103gmoL500000980oooo00170?ooo`<000002P3Zj^X00`000000l?3`0?3`
l00[0?3`l0030000003gmoL0moOg00T0moOg1000002>0?ooo`00@`3oool4000000d0j^[Z00<00000
0?3`l03`l?00:`3`l?000`000000moOg0?Ogm`0=0?Ogm`D00000R@3oool00400oooo0`00000B0>[Z
jP030000003`l?00l?3`02X0l?3`00<000000?Ogm`3gmoL04P3gmoL4000008D0oooo000m0?ooo`<0
00005P3Zj^X00`000000l?3`0?3`l00Y0?3`l0030000003gmoL0moOg01H0moOg100000210?ooo`00
>@3oool4000001T0j^[Z00<000000?3`l03`l?00:@3`l?000`000000moOg0?Ogm`0J0?Ogm`D00000
O03oool003H0oooo0`00000N0>[ZjP030000003`l?00l?3`02P0l?3`00<000000?Ogm`3gmoL07`3g
moL4000007P0oooo000c0?ooo`<000008@3Zj^X00`000000l?3`0?3`l00X0?3`l0030000003gmoL0
moOg02<0moOg1@00001c0?ooo`00;`3oool4000002D0j^[Z00<000000?3`l03`l?00:03`l?000`00
0000moOg0?Ogm`0W0?Ogm`@00000K`3oool002d0oooo0P00000Z0>[ZjP030000003`l?00l?3`02L0
l?3`00<000000?Ogm`3gmoL0:`3gmoL4000006/0oooo000/0?ooo`030000003Ti>@0000002X0j^[Z
00<000000?3`l03`l?009`3`l?000`000000moOg0?Ogm`0/0?Ogm`030000003kno/0no_k00800000
J@3oool002X0oooo0P0000030>CTi0030000003Zj^X0j^[Z02P0j^[Z00<000000?3`l03`l?009P3`
l?000`000000moOg0?Ogm`0/0?Ogm`030000003kno/0no_k0080no_k0P00001W0?ooo`00:@3oool0
0`000000i>CT0>CTi0040>CTi0800000:@3Zj^X00`000000l?3`0?3`l00U0?3`l0030000003gmoL0
moOg02/0moOg00<000000?_kn`3kno/01@3kno/2000006D0oooo000X0?ooo`030000003Ti>@0i>CT
00L0i>CT00<000000>[ZjP3Zj^X09P3Zj^X00`000000l?3`0?3`l00U0?3`l0030000003gmoL0moOg
02X0moOg00<000000?_kn`3kno/0203kno/2000006<0oooo000W0?ooo`030000003Ti>@0i>CT00T0
i>CT00<000000>[ZjP3Zj^X09P3Zj^X00`000000l?3`0?3`l00T0?3`l0030000003gmoL0moOg02T0
moOg00<000000?_kn`3kno/02`3kno/200000640oooo000U0?ooo`8000003@3Ti>@00`000000j^[Z
0>[ZjP0U0>[ZjP030000003`l?00l?3`02@0l?3`00<000000?Ogm`3gmoL0:@3gmoL00`000000no_k
0?_kn`0=0?_kn`800000G`3oool002@0oooo00<000000>CTi03Ti>@03P3Ti>@00`000000j^[Z0>[Z
jP0T0>[ZjRX00000:03gmoL00`000000no_k0?_kn`0@0?_kn`800000G@3oool002<0oooo00<00000
0>CTi03Ti>@0403Ti>@200000200j^[Z100000020>[ZjP030000003`l?00l?3`0280l?3`00<00000
0?Ogm`3gmoL01000000S0?Ogm`030000003kno/0no_k01<0no_k0P00001K0?ooo`008P3oool00`00
0000i>CT0>CTi00C0>CTi0030000003Zj^X0j^[Z01T0j^[Z100000060>[ZjP030000003`l?00l?3`
0280l?3`00<000000?Ogm`3gmoL0103gmoL5000001d0moOg00<000000?_kn`3kno/05P3kno/20000
05T0oooo000Q0?ooo`030000003Ti>@0i>CT01D0i>CT00<000000>[ZjP3Zj^X0503Zj^X4000000/0
j^[Z00<000000?3`l03`l?008@3`l?000`000000moOg0?Ogm`090?Ogm`D00000603gmoL00`000000
no_k0?_kn`0H0?_kn`800000E`3oool001l0oooo0P00000I0>CTi0030000003Zj^X0j^[Z0100j^[Z
0`00000?0>[ZjP030000003`l?00l?3`0240l?3`00<000000?Ogm`3gmoL03P3gmoL4000001<0moOg
00<000000?_kn`3kno/06`3kno/2000005D0oooo000N0?ooo`030000003Ti>@0i>CT01X0i>CT00<0
00000>[ZjP3Zj^X02`3Zj^X4000001<0j^[Z00<000000?3`l03`l?00803`l?000`000000moOg0?Og
m`0B0?Ogm`D000003@3gmoL00`000000no_k0?_kn`0N0?_kn`800000D`3oool001d0oooo00<00000
0>CTi03Ti>@0703Ti>@2000000L0j^[Z1000000H0>[ZjP030000003`l?00l?3`01l0l?3`00<00000
0?Ogm`3gmoL05`3gmoL5000000L0moOg00<000000?_kn`3kno/08@3kno/200000540oooo000L0?oo
o`030000003Ti>@0i>CT01l0i>CT00<000000>[ZjP3Zj^X01000000L0>[ZjP030000003`l?00l?3`
01l0l?3`00<000000?Ogm`3gmoL0703gmoL4000000<0moOg00<000000?_kn`3kno/08`3kno/20000
04l0oooo000J0?ooo`8000008`3Ti>@200000240j^[Z00<000000?3`l03`l?007P3`l?000`000000
moOg0?Ogm`0P0?Ogm`<00000:03kno/2000004d0oooo000I0?ooo`030000003Ti>@0i>CT0280i>CT
00<000000>CTi00000008@3Zj^X00`000000l?3`0?3`l00N0?3`l0030000003gmoL0moOg0240moOg
00<000000?_kn`3kno/00P00000W0?_kn`800000B`3oool001P0oooo00<000000>CTi03Ti>@08@3T
i>@2000000<0i>CT0P00000P0>[ZjP030000003`l?00l?3`01d0l?3`00<000000?Ogm`3gmoL08@3g
moL00`000000no_k0?_kn`020?_kn`8000009`3kno/2000004T0oooo000H0?ooo`<00000803Ti>@0
0`000000i>CT0>CTi0050>CTi0030000003Zj^X0j^[Z01d0j^[Z00<000000?3`l03`l?007@3`l?00
0`000000moOg0?Ogm`0P0?Ogm`030000003kno/0no_k00D0no_k0P00000W0?_kn`800000A`3oool0
01P0oooo00<000000=oOg`3Ogml00P00000M0>CTi0030000003Ti>@0i>CT00L0i>CT00<000000>[Z
jP3Zj^X07@3Zj^X00`000000l?3`0?3`l00L0?3`l0030000003gmoL0moOg0200moOg00<000000?_k
n`3kno/01`3kno/2000002L0no_k0P0000150?ooo`00603oool00`000000gmoO0=oOg`020=oOg`80
00006@3Ti>@2000000/0i>CT0P00000N0>[ZjP030000003`l?00l?3`01/0l?3`00<000000?Ogm`3g
moL07`3gmoL00`000000no_k0?_kn`0:0?_kn`800000903kno/2000000030?knoP000000oooo04<0
oooo000G0?ooo`030000003Ogml0gmoO00D0gmoO0P00000F0>CTi0030000003Ti>@0i>CT00d0i>CT
00<000000>[ZjP3Zj^X06`3Zj^X00`000000l?3`0?3`l00K0?3`l0030000003gmoL0moOg01h0moOg
00<000000?_kn`3kno/03@3kno/200000200no_k0P0000040?knoP030000003oool0oooo0440oooo
000G0?ooo`030000003Ogml0gmoO00L0gmoO0P00000C0>CTi0030000003Ti>@0i>CT00l0i>CT00<0
00000>[ZjP3Zj^X06`3Zj^X00`000000l?3`0?3`l00J0?3`l0030000003gmoL0moOg01h0moOg00<0
00000?_kn`3kno/03`3kno/2000001`0no_k0P0000070?knoP030000003oool0oooo0400oooo000G
0?ooo`030000003Ogml0gmoO00T0gmoO0P00000?0>CTi08000004`3Ti>@00`000000j^[Z0>[ZjP0J
0>[ZjP030000003`l?00l?3`01X0l?3`00<000000?Ogm`3gmoL07@3gmoL00`000000no_k0?_kn`0B
0?_kn`8000006@3kno/00`000000o_kn0?knoP080?knoP030000003oool0oooo03l0oooo000G0?oo
o`030000003Ogml0gmoO00/0gmoO0P00000<0>CTi0030000003Ti>@0i>CT01@0i>CT0P00000I0>[Z
jR4000007@3gmoL00`000000no_k0?_kn`0D0?_kn`8000005@3kno/2000000/0o_kn00<000000?oo
o`3oool0?`3oool001L0oooo00<000000=oOg`3Ogml03@3Ogml2000000T0i>CT00<000000>CTi03T
i>@05`3Ti>@00`000000j^[Z0>[ZjP0B0>[ZjP@000000`3Zj^X00`000000l?3`0?3`l00H0?3`l003
0000003gmoL0moOg00@00000603gmoL00`000000no_k0?_kn`0G0?_kn`8000004@3kno/2000000h0
o_kn00<000000?ooo`3oool0?P3oool001L0oooo00<000000=oOg`3Ogml03`3Ogml2000000D0i>CT
0P00000K0>CTi0030000003Zj^X0j^[Z00d0j^[Z100000070>[ZjP030000003`l?00l?3`01P0l?3`
00<000000?Ogm`3gmoL0103gmoL500000180moOg00<000000?_kn`3kno/06P3kno/2000000h0no_k
00<000000?knoP3no_h03`3no_h00`000000oooo0?ooo`0m0?ooo`005P3oool00`000000gmoO0=oO
g`0B0=oOg`8000000P3Ti>@00`000000i>CT0>CTi00L0>CTi0800000203Zj^X5000000`0j^[Z00<0
00000?3`l03`l?005`3`l?000`000000moOg0?Ogm`090?Ogm`D000003@3gmoL00`000000no_k0?_k
n`0L0?_kn`8000002P3kno/2000001<0o_kn00<000000?ooo`3oool0?03oool001H0oooo00<00000
0=oOg`3Ogml0503Ogml200000240i>CT00@000000>[ZjP3Zj^X0j^[Z1000000A0>[ZjP030000003`
l?00l?3`01L0l?3`00<000000?Ogm`3gmoL03P3gmoL4000000P0moOg00<000000?_kn`3kno/07`3k
no/2000000H0no_k0P00000F0?knoP030000003oool0oooo03/0oooo000F0?ooo`030000003Ogml0
gmoO01D0gmoO0`00000P0>CTi0<000005P3Zj^X00`000000l?3`0?3`l00F0?3`l0030000003gmoL0
moOg0180moOg1@0000030?Ogm`030000003kno/0no_k0240no_k0P0000020?_kn`8000006@3no_h0
0`000000oooo0?ooo`0j0?ooo`005P3oool00`000000gmoO0=oOg`0E0=oOg`030000003Ogml0gmoO
008000007@3Ti>@00`000000i>CT0000000H0>[ZjP030000003`l?00l?3`01D0l?3`00<000000?Og
m`3gmoL05`3gmoL3000002H0no_k0P00000L0?knoP030000003oool0oooo03T0oooo000F0?ooo`03
0000003Ogml0gmoO01@0gmoO00<000000=oOg`3Ogml00`3Ogml2000001T0i>CT0P0000030>CTi080
00005P3Zj^X00`000000l?3`0?3`l00E0?3`l0030000003gmoL0moOg01P0moOg00@000000?_kn`00
000000008`3kno/2000000030?knoP000000o_kn01/0o_kn00<000000?ooo`3oool0>03oool001H0
oooo00<000000=oOg`3Ogml0503Ogml00`000000gmoO0=oOg`050=oOg`8000005P3Ti>@00`000000
i>CT0>CTi0050>CTi0030000003Zj^X0j^[Z01@0j^[Z00<000000?3`l03`l?00503`l?000`000000
moOg0?Ogm`0H0?Ogm`040000003kno/0no_k0?_kn`8000007`3kno/2000000@0o_kn00<000000?kn
oP3no_h06@3no_h00`000000oooo0?ooo`0h0?ooo`005P3oool00`000000gmoO0=oOg`0D0=oOg`03
0000003Ogml0gmoO00L0gmoO0P00000C0>CTi0030000003Ti>@0i>CT00L0i>CT00<000000>[ZjP3Z
j^X0503Zj^X00`000000l?3`0?3`l00C0?3`l0030000003gmoL0moOg01L0moOg00<000000?_kn`3k
no/0103kno/2000001`0no_k00<000000?knoP3no_h01@3no_h00`000000o_kn0?knoP0I0?knoP03
0000003oool0oooo03L0oooo000E0?ooo`030000003Ogml0gmoO01D0gmoO00<000000=oOg`3Ogml0
2@3Ogml2000000l0i>CT0P00000;0>CTi0800000503Zj^X00`000000l?3`0?3`l00C0?3`l0030000
003gmoL0moOg01H0moOg00<000000?_kn`3kno/01`3kno/2000001P0no_k0P0000090?knoP030000
003no_h0o_kn01T0o_kn00<000000?ooo`3oool0=P3oool001D0oooo00<000000=oOg`3Ogml05@3O
gml00`000000gmoO0=oOg`0;0=oOg`800000303Ti>@00`000000i>CT0>CTi00=0>CTi0030000003Z
j^X0j^[Z0180j^[Z00<000000?3`l03`l?004P3`l?000`000000moOg0?Ogm`0E0?Ogm`030000003k
no/0no_k00X0no_k0P00000E0?_kn`030000003no_h0o_kn00X0o_kn00<000000?knoP3no_h06@3n
o_h00`000000oooo0?ooo`0e0?ooo`005@3oool00`000000gmoO0=oOg`0D0=oOg`030000003Ogml0
gmoO00h0gmoO0P0000090>CTi0030000003Ti>@0i>CT00l0i>CT00<000000>[ZjP3Zj^X04@3Zj^X0
0`000000l?3`0?3`l00B0?3`l0030000003gmoL0moOg01D0moOg00<000000?_kn`3kno/0303kno/2
00000140no_k0P00000>0?knoP030000003no_h0o_kn01T0o_kn00<000000?ooo`3oool0=03oool0
01D0oooo0P00000E0=oOg`030000003Ogml0gmoO0100gmoO0P0000050>CTi08000004`3Ti>@00`00
0000j^[Z0>[ZjP0A0>[ZjP030000003`l?00l?3`0140l?3`00<000000?Ogm`3gmoL0503gmoL00`00
0000no_k0?_kn`0?0?_kn`8000003@3kno/200000140o_kn00<000000?knoP3no_h06@3no_h00`00
0000oooo0?ooo`0c0?ooo`005`3oool300000180gmoO00<000000=oOg`3Ogml04P3Ogml200000080
i>CT00<000000>CTi03Ti>@0503Ti>@200000180j^[Z00<000000?3`l03`l?00403`l?000`000000
moOg0?Ogm`0C0?Ogm`030000003kno/0no_k0180no_k0P00000:0?_kn`030000003no_h0o_kn0180
o_kn00<000000?knoP3no_h06@3no_h00`000000oooo0?ooo`0b0?ooo`006P3oool3000000l0gmoO
00<000000=oOg`3Ogml0503Ogml3000001P0i>CT00<000000>[ZjP3Zj^X03`3Zj^X00`000000l?3`
0?3`l00@0?3`l0030000003gmoL0moOg01<0moOg00<000000?_kn`3kno/0503kno/2000000H0no_k
0P00000F0?knoP030000003no_h0o_kn01T0o_kn00<000000?ooo`3oool0<@3oool001d0oooo0`00
000<0=oOg`030000003Ogml0gmoO01D0gmoO00@000000=oOg`00000000005`3Ti>@00`000000j^[Z
0>[ZjP0=0>[ZjQL000004P3gmoL00`000000no_k0?_kn`0G0?_kn`8000000P3kno/2000001P0o_kn
00<000000?knoP3no_h06@3no_h00`000000oooo0?ooo`0a0?ooo`00803oool4000000P0gmoO00<0
00000=oOg`3Ogml0503Ogml00`000000gmoO0=oOg`020=oOg`8000005P3Ti>@2000000T0j^[Z1000
00030>[ZjP030000003`l?00l?3`00h0l?3`00<000000?Ogm`3gmoL01000000=0?Ogm`030000003k
no/0no_k01X0no_k0P00000K0?knoP030000003no_h0o_kn01T0o_kn00<000000?ooo`3oool0<03o
ool002@0oooo0`0000040=oOg`030000003Ogml0gmoO01D0gmoO00<000000=oOg`3Ogml0103Ogml2
000001H0i>CT00@000000>[ZjP3Zj^X0j^[Z1@0000070>[ZjP030000003`l?00l?3`00h0l?3`00<0
00000?Ogm`3gmoL0103gmoL5000000L0moOg00<000000?_kn`3kno/06P3kno/2000000030?knoP00
0000o_kn01X0o_kn00<000000?knoP3no_h06@3no_h00`000000oooo0?ooo`0_0?ooo`009`3oool3
000000030=oOg`000000gmoO01H0gmoO00<000000=oOg`3Ogml01P3Ogml2000001D0i>CT0`00000=
0>[ZjP030000003`l?00l?3`00d0l?3`00<000000?Ogm`3gmoL02@3gmoL4000000<0moOg00<00000
0?_kn`3kno/0603kno/2000000@0o_kn00<000000?knoP3no_h06@3no_h00`000000o_kn0?knoP0I
0?knoP030000003oool0oooo02h0oooo000Z0?ooo`<000005P3Ogml00`000000gmoO0=oOg`080=oO
g`<00000403Ti>@2000000030>CTi0000000j^[Z00h0j^[Z00<000000?3`l03`l?00303`l?000`00
0000moOg0?Ogm`0=0?Ogm`@000006@3kno/00`000000o_kn0?knoP050?knoP030000003no_h0o_kn
01T0o_kn00<000000?knoP3no_h05`3no_h3000002l0oooo000]0?ooo`@000004@3Ogml00`000000
gmoO0=oOg`0<0=oOg`8000003@3Ti>@00`000000i>CT0>CTi0020>CTi0030000003Zj^X0j^[Z00`0
j^[Z00<000000?3`l03`l?00303`l?000`000000moOg0?Ogm`0>0?Ogm`030000003kno/0no_k0080
00005@3kno/2000000T0o_kn00<000000?knoP3no_h06@3no_h00`000000o_kn0?knoP0B0?knoP@0
00000P3oool00`000000oooo0?ooo`0]0?ooo`00<@3oool4000000d0gmoO00<000000=oOg`3Ogml0
3P3Ogml2000000T0i>CT0P0000060>CTi0030000003Zj^X0j^[Z00`0j^[Z00<000000?3`l03`l?00
2`3`l?000`000000moOg0?Ogm`0>0?Ogm`030000003kno/0no_k0080no_k0P00000A0?_kn`800000
303no_h00`000000o_kn0?knoP0I0?knoP030000003no_h0o_kn00`0o_kn1@0000060?ooo`030000
003oool0oooo02d0oooo000e0?ooo`<000002P3Ogml00`000000gmoO0=oOg`0@0=oOg`8000001P3T
i>@00`000000i>CT0>CTi0070>CTi08000003@3Zj^X00`000000l?3`0?3`l00:0?3`l0030000003g
moL0moOg00d0moOg00<000000?_kn`3kno/01@3kno/2000000d0no_k0P00000?0?knoP030000003n
o_h0o_kn01T0o_kn00<000000?knoP3no_h01P3no_h5000000/0oooo00<000000?ooo`3oool0;@3o
ool003P0oooo100000060=oOg`030000003Ogml0gmoO0180gmoO0P0000020>CTi0800000303Ti>@0
0`000000j^[Z0>[ZjP0:0>[ZjP030000003`l?00l?3`00/0l?3`00<000000?Ogm`3gmoL02`3gmoL0
0`000000no_k0?_kn`080?_kn`8000002P3kno/00`000000o_kn0?knoP0@0?knoP030000003no_h0
o_kn01T0o_kn00@000000?knoP3no_h0o_kn1000000A0?ooo`030000003oool0oooo02`0oooo000l
0?ooo`@0000000<0gmoO0000003Ogml05P3Ogml2000000l0i>CT00<000000>[ZjP3Zj^X02P3Zj^X0
0`000000l?3`0?3`l00:0?3`l0030000003gmoL0moOg00/0moOg00<000000?_kn`3kno/02P3kno/2
000000H0no_k0P00000D0?knoP030000003no_h0o_kn01P0o_kn1000000E0?ooo`030000003oool0
oooo02`0oooo00100?ooo`<000005`3Ogml3000000h0i>CT00<000000>[ZjP3Zj^X02P3Zj^X00`00
0000l?3`0?3`l0090?3`l0030000003gmoL0moOg00X0moOg00<000000?_kn`3kno/03@3kno/20000
0080no_k0P00000G0?knoP030000003no_h0o_kn01<0o_kn100000000`3oool000000?ooo`0F0?oo
o`030000003oool0oooo02`0oooo00130?ooo`<000004`3Ogml010000000gmoO0=oOg`3Ogml20000
00d0i>CT00<000000>[ZjP3Zj^X02@3Zj^X00`000000l?3`0?3`l0090?3`l0030000003gmoL0moOg
00T0moOg00<000000?_kn`3kno/0403kno/2000001X0o_kn00<000000?knoP3no_h03P3no_h40000
00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0/0?ooo`00AP3oool300000100
gmoO00<000000=oOg`3Ogml00`3Ogml2000000`0i>CT00<000000>[ZjP3Zj^X02@3Zj^X00`000000
l?3`0?3`l0080?3`l0030000003gmoL0moOg00P0moOg00<000000?_kn`3kno/0403kno/200000003
0?knoP000000o_kn01T0o_kn00<000000?knoP3no_h02P3no_h3000000X0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0/0?ooo`00B@3oool3000000`0gmoO00<000000=oOg`3Ogml0
1P3Ogml2000000/0i>CT00<000000>[ZjP3Zj^X02@3Zj^X00`000000l?3`0?3`l0070?3`l0030000
003gmoL0moOg00P0moOg00<000000?_kn`3kno/03`3kno/00`000000o_kn0?knoP020?knoP030000
003no_h0o_kn01P0o_kn00<000000?knoP3no_h01@3no_h4000000d0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0/0?ooo`00C03oool4000000P0gmoO00<000000=oOg`3Ogml0203O
gml2000000X0i>CT0P0000090>[ZjP030000003`l?00l?3`00L0l?3`00<000000?Ogm`3gmoL01`3g
moL00`000000no_k0?_kn`0>0?_kn`8000001P3no_h00`000000o_kn0?knoP0H0?knoP030000003n
o_h0o_kn00@000004@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02/0oooo001@
0?ooo`<000001@3Ogml00`000000gmoO0=oOg`0:0=oOg`8000002P3Ti>@00`000000j^[Z0>[ZjP06
0>[ZjP`000001`3gmoL00`000000no_k0?_kn`0=0?_kn`8000002@3no_h00`000000o_kn0?knoP0F
0?knoP@000005@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02/0oooo001C0?oo
o`<0000000<0gmoO0000003Ogml03P3Ogml2000000T0i>CT00@000000>[ZjP3Zj^X0j^[Z10000002
0>[ZjP030000003`l?00l?3`00D0l?3`00<000000?Ogm`0000000`0000030?Ogm`030000003kno/0
no_k00`0no_k00<000000?knoP3no_h02P3no_h200000180o_kn100000020?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0[0?ooo`00EP3oool30000
0100gmoO0P0000080>CTi0<000001P3Zj^X00`000000l?3`0?3`l0050?3`l0030000003gmoL0moOg
00<0moOg0`00000=0?_kn`8000003`3no_h00`000000o_kn0?knoP0;0?knoP@000001`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:`3oool005T0
oooo1000000>0=oOg`8000001@3Ti>@00`000000i>CT000000080>[ZjP030000003`l?00l?3`00@0
l?3`00<000000?Ogm`3gmoL0103gmoL010000000no_k00000000000:0?_kn`030000003no_h0o_kn
0100o_kn00<000000?knoP3no_h01P3no_h4000000/0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo02/0oooo001M0?ooo`@00000303Ogml200000003
0>CTi0000000000000<0i>CT0P0000060>[ZjP030000003`l?00l?3`00@0l?3`00<000000?Ogm`3g
moL0103gmoL010000000no_k0?_kn`3kno/2000000H0no_k0P00000D0?knoP040000003no_h0o_kn
0?knoP@000003`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0:`3oool00640oooo0`00000;0=oOg`8000001P3Ti>@00`000000j^[Z0>[ZjP040>[Z
jP030000003`l?00l?3`00<0l?3`00<000000?Ogm`3gmoL00`3gmoL00`000000no_k0?_kn`040?_k
n`8000000P3kno/2000001L0o_kn0`00000C0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0[0?ooo`00I03oool4000000H0gmoO00<000000=oOg`3O
gml00P0000050>CTi0030000003Zj^X0j^[Z00@0j^[Z00<000000?3`l03`l?000P3`l?000`000000
moOg0?Ogm`030?Ogm`030000003kno/0no_k00H0no_k0P00000C0?knoP@000000P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0Z0?ooo`00J03oool400000080gmoO00<000000=oOg`3Ogml00P3Ogml2000000@0i>CT
0P0000040>[ZjP030000003`l?00l?3`0080l?3`00<000000?Ogm`3gmoL00P3gmoL00`000000no_k
0?_kn`060?_kn`80000000<0o_kn0000003no_h03@3no_h4000000L0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
:P3oool006`0oooo0`0000060=oOg`800000103Ti>@00`000000j^[Z0>[ZjP020>[ZjP050000003`
l?00l?3`0?3`l00000000`3gmoL00`000000no_k0?_kn`050?_kn`800000103no_h2000000P0o_kn
1000000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo02X0oooo001_0?ooo`<000001@3Ogml2000000<0i>CT00D0
00000>[ZjP3Zj^X0j^[Z000000030?3`l0050000003gmoL0moOg0?Ogm`0000001@3kno/2000000P0
o_kn00@000000?knoP3no_h0o_kn1000000?0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02X0oooo001b0?ooo`@0
00000`3Ogml200000080i>CT0P0000020>[ZjP040000003`l?00l?3`00000080moOg00<000000?_k
n`3kno/00`3kno/00`000000o_kn0?knoP070?knoPD000004`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0Z0?oo
o`00MP3oool300000080gmoO0P0000020>CTi0080000003Zj^X0j^[Z0000003`l?0000000?Ogm`00
00040?_kn`8000001P3no_h400000080oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0Z0?ooo`00N@3oool30000000;0=oOg`00000000000>CTi0000000j^[Z0000003`l?0000000?Og
m`0000000P3kno/2000000@0o_kn100000060?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0:@3oool007`0oooo2P0000000`3kno/00000000000020?knoP@000002`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo02T0oooo00200?ooo`/000003`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo02T0oooo00230?oooh0000007@3oool00800oooo2P00000@
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:P3oool007`0oooo2P000000103o
ool000000000003oool4000000/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0Z
0?ooo`00N@3oool30000000;0?ooo`00000000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool2000000<0oooo100000070?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0:`3oool007H0oooo0`0000020?ooo`8000000P3oool01P000000oooo0?ooo`000000oooo0000
0080oooo00D000000?ooo`3oool0oooo000000060?ooo`@000000P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo02/0oooo001b0?ooo`@000000`3oool2000000<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`800000203oool5000001@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0203oool2000000030?ooo`000000000001l0oooo001_0?ooo`<000001@3oool2
000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
1@3oool2000000L0oooo00@000000?ooo`3oool0oooo1000000@0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`000000803oool006`0oooo0`0000060?ooo`800000103oool2000000<0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`03
0000003oool0oooo00H0oooo1000000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool07`3oool006P0oooo100000020?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo0P0000000`3oool000000?ooo`0<0?ooo`@000001`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`090?ooo`80000000<0oooo0000000000007`3oool006@0oooo100000060?ooo`030000003o
ool0oooo008000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`8000004P3oool400000080oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0;P3oool00640oooo0`00000;0?ooo`8000001`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`8000000P3oool2000001@0oooo1@00000C0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0^0?ooo`00G@3oool4000000`0oooo0P0000000`3o
ool00000000000040?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`0000060?ooo`8000004`3oool010000000oooo0?ooo`3oool5
000000d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo02l0oooo001I0?ooo`@000003P3oool2000000D0oooo0P0000000`3oool000000?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool3000000/0oooo00<000000?oo
o`3oool03P3oool2000000T0oooo1@0000080?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0`0?ooo`00EP3oool300000100oooo0P0000090?ooo`@0
00001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@000000P3oool00`000000
oooo0?ooo`0:0?ooo`8000003@3oool00`000000oooo0?ooo`0>0?ooo`D000000P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0<03oool005<0oooo
0`0000020?ooo`030000003oool0oooo00`0oooo0P00000:0?ooo`030000003oool0oooo0080oooo
3`0000060?ooo`030000003oool0oooo00`0oooo0P00000:0?ooo`030000003oool0oooo01@0oooo
1000000C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0<@3oool004l0oooo1000
00050?ooo`030000003oool0oooo00X0oooo0P00000:0?ooo`800000203oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01000000?0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0<@3oool004`0oooo0`00000:0?ooo`030000003oool0
oooo00L0oooo0P00000;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo0P0000040?ooo`8000005`3oool2
000000L0oooo1000000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0<P3oool0
04T0oooo0`00000=0?ooo`030000003oool0oooo00D0oooo0P00000<0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00h0oooo0P0000000`3oool000000?ooo`0G0?ooo`030000003oool0oooo00/0oooo100000060?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0<P3oool004D0oooo1000000A0?ooo`03
0000003oool0oooo0080oooo0P00000=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo0P00000H0?ooo`03
0000003oool0oooo0100oooo100000000`3oool000000?ooo`0D0?ooo`030000003oool0oooo03<0
oooo00120?ooo`<000005@3oool00`000000oooo0?ooo`02000000d0oooo0P00000;0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`800000
0P3oool2000001D0oooo00<000000?ooo`3oool05@3oool3000001@0oooo00<000000?ooo`3oool0
<`3oool003l0oooo0`00000I0?ooo`8000003P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`8000001P3o
ool200000140oooo0P00000H0?ooo`030000003oool0oooo00@000003`3oool00`000000oooo0?oo
o`0d0?ooo`00?03oool300000080oooo00<000000?ooo`3oool05@3oool2000000030?ooo`000000
000000`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool01@3oool3000000X0oooo0P00000>0?ooo`030000003oool0
oooo01H0oooo0P0000070?ooo`@000002`3oool00`000000oooo0?ooo`0d0?ooo`00>03oool40000
00D0oooo00<000000?ooo`3oool04`3oool2000000D0oooo0P0000090?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00<0oooo0P00000?0?ooo`8000002`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00/0oooo100000060?ooo`030000003oool0oooo03D0oooo000e0?ooo`<000002P3oool00`000000
oooo0?ooo`0@0?ooo`8000002@3oool2000000D0oooo0P00000=0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`02000001<0oooo0P0000080?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0403oool400000080oooo00<000000?ooo`3o
ool0=@3oool00380oooo0`00000>0?ooo`030000003oool0oooo00d0oooo0P00000=0?ooo`800000
0P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
303oool4000001L0oooo0P0000040?ooo`800000603oool00`000000oooo0?ooo`0E0?ooo`800000
>03oool002h0oooo1000000A0?ooo`030000003oool0oooo00/0oooo0P00000A0?ooo`D00000303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo1P0000030?ooo`030000003o
ool0oooo01L0oooo0P0000000`3oool000000?ooo`0G0?ooo`800000603oool00`000000oooo0?oo
o`0g0?ooo`00:`3oool3000001H0oooo00<000000?ooo`3oool0203oool2000001<0oooo00<00000
0?ooo`3oool00P3oool8000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`06
000000T0oooo00<000000?ooo`3oool0603oool2000001P0oooo00<000000?ooo`3oool05P3oool2
000003X0oooo000X0?ooo`<000006P3oool00`000000oooo0?ooo`050?ooo`800000503oool00`00
0000oooo0?ooo`0;0?oooaH00000403oool00`000000oooo0?ooo`0E0?ooo`8000000P3oool20000
01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0j0?ooo`009@3oool300000080
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`800000503oool200000100
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180
oooo0P0000060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0k0?ooo`008@3oool4000000H0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`02000001D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool03P3oool3000000T0oooo0P00000?0?ooo`800000
5`3oool2000003h0oooo000N0?ooo`<000002`3oool00`000000oooo0?ooo`0G0?ooo`<000005P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0?P3oool001/0oooo0`00000?0?ooo`030000003oool0
oooo01@0oooo0P0000030?ooo`8000004`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`8000004@3oool2
000000X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0o0?ooo`005`3oool40000
01<0oooo00<000000?ooo`3oool04@3oool2000000L0oooo0P00000@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00D0oooo0`00000E0?ooo`8000001`3oool00`000000oooo0?ooo`0E0?ooo`800000@P3oool001@0
oooo0`00000G0?ooo`030000003oool0oooo00l0oooo0P00000;0?ooo`8000003@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`020?ooo`8000006P3oool00`000000oooo0?ooo`020?ooo`8000005`3oool00`000000
oooo0?ooo`120?ooo`004P3oool2000001/0oooo00<000000?ooo`3oool0303oool2000000l0oooo
0`0000080?ooo`800000503oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool00P00000M0?ooo`80000000<0oooo0000003oool05`3oool00`000000oooo
0?ooo`130?ooo`004`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00T0oooo0P00
000D0?ooo`8000001@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool400000200oooo0P00000G0?ooo`800000AP3oool001@0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`800000603oool200000080oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00h0oooo1@000003
0?ooo`030000003oool0oooo01`0oooo0P0000020?ooo`800000503oool00`000000oooo0?ooo`16
0?ooo`005@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo0P00000L0?oo
o`D000004`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00X0oooo100000080?oo
o`030000003oool0oooo01T0oooo0`0000060?ooo`8000004@3oool00`000000oooo0?ooo`170?oo
o`005P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo008000007P3oool00`000000
oooo0?ooo`020?ooo`L000002`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0
oooo1@00000=0?ooo`030000003oool0oooo01H0oooo0P00000;0?ooo`8000003@3oool2000004X0
oooo000G0?ooo`030000003oool0oooo01X0oooo0P00000N0?ooo`800000303oool7000000@0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`05000001<0oooo00<000000?ooo`3oool0
4P3oool3000000l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1:0?ooo`00603o
ool00`000000oooo0?ooo`0G0?ooo`8000000P3oool2000001/0oooo00<000000?ooo`3oool04`3o
oolO000001P0oooo00<000000?ooo`3oool0403oool2000001<0oooo0P0000080?ooo`030000003o
ool0oooo04/0oooo000I0?ooo`030000003oool0oooo01@0oooo0P0000060?ooo`800000603oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0<0?ooo`<000005`3oool2000000@0oooo0P00001>0?ooo`006P3oool00`00
0000oooo0?ooo`0A0?ooo`8000002P3oool3000001@0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool30000
01`0oooo0P0000000`3oool000000?ooo`1?0?ooo`006`3oool00`000000oooo0?ooo`0>0?ooo`80
00003`3oool200000100oooo0P00000I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`060?ooo`800000803oool200000540oooo000L0?ooo`030000
003oool0oooo00/0oooo0P00000C0?ooo`8000003@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`<00000
7`3oool3000005<0oooo000M0?ooo`030000003oool0oooo00P0oooo0P00000G0?ooo`<000002@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0200000200oooo0P00001F0?ooo`007P3oool00`000000oooo0?ooo`05
0?ooo`800000703oool2000000D0oooo0P00000L0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool06P3oool4000001l0oooo0`00001H0?ooo`007`3oool00`000000oooo0?ooo`020?oo
o`800000803oool200000080oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01D0oooo1@0000030?ooo`030000003oool0oooo01X0oooo0`00001K0?oo
o`00803oool010000000oooo00000000000T0?ooo`@00000703oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0100oooo1@0000080?ooo`030000003oool0oooo01P0oooo0P00001N0?oo
o`008@3oool2000002D0oooo00@000000?ooo`3oool0oooo1P00000E0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool02P3oool6000000h0oooo00<000000?ooo`3oool0503oool30000
0600oooo000S0?ooo`8000008P3oool00`000000oooo0?ooo`080?ooo`D00000403oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo1@00000E0?ooo`030000003oool0oooo0100
oooo0`00001S0?ooo`009@3oool2000001h0oooo0P00000@0?ooo`H000002@3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo00D000006P3oool00`000000oooo0?ooo`0>0?ooo`800000
IP3oool002L0oooo0`00000J0?ooo`030000003oool0oooo01H0oooo1P0000030?ooo`030000003o
ool0oooo00d0oooo4P00000P0?ooo`030000003oool0oooo00X0oooo0`00001X0?ooo`00:P3oool2
000001L0oooo00<000000?ooo`3oool07@3ooolC000000l0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`060?ooo`<00000J`3oool002`0oooo0P00000D0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00<0oooo0P00001^0?ooo`00;P3oool300000100oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00`00001`0?ooo`00
<@3oool2000000d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0240oooo1000001c0?ooo`00<`3oool3000000P0oooo0P00000S0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool06`3oool6000007L0oooo000f0?ooo`8000001@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool05P3oool5
000007d0oooo000h0?ooo`8000000P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool04@3oool500000880oooo000j0?ooo`D000008P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00/0oooo1P0000270?ooo`00?`3oool7000001X0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`060?ooo`D00000S@3oool004H0oooo1`00
000C0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01P00002B0?ooo`00C@3oool7
000000/0oooo00<000000?ooo`3oool06P3oool<000009P0oooo001D0?ooo`L00000103oool00`00
0000oooo0?ooo`060?oooa@000002@3oool00`000000oooo0?ooo`2H0?ooo`00F`3oool=000001d0
oooo00<000000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool0V03oool008D0oooo00<0
00000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool0V03oool008D0oooo00<000000?oo
o`3oool0V03oool008D0oooo00<000000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool0
V03oool008D0oooo00<000000?ooo`3oool0V03oool008D0oooo00<000000?ooo`3oool0V03oool0
08D0oooo00<000000?ooo`3oool00`3oool2000009<0oooo00250?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0T@3oool008D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`2@0?ooo`00Q@3oool00`000000oooo0?ooo`040?ooo`030000003oool000000940oooo0025
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000T@3oool008D0oooo00<00000
0?ooo`3oool00P3oool3000000030?ooo`00000000000900oooo00250?ooo`030000003oool0oooo
09P0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {177.313, 0}} -> {0, 0, 0, 0}}],
  StyleBox["     ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% PlotRegion
.1 .9 .1 .9 MPlotRegion
% Scaling calculations
0.5 0.434783 0.5 0.434783 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
.5 .49565 m
.50002 .49565 L
.50003 .49565 L
.50005 .49565 L
.50007 .49565 L
.5001 .49565 L
.50013 .49565 L
.50017 .49566 L
.5002 .49566 L
.50027 .49566 L
.50034 .49567 L
.50041 .49567 L
.50055 .49569 L
.5007 .49571 L
.50084 .49573 L
.50115 .49581 L
.50141 .49589 L
.50168 .49599 L
.5022 .49625 L
.50267 .49657 L
.50311 .49696 L
.50349 .4974 L
.50379 .49786 L
.50392 .49811 L
.50404 .49839 L
.50414 .49867 L
.50421 .49893 L
.50427 .49921 L
.5043 .49936 L
.50432 .4995 L
.50433 .49964 L
.50434 .49971 L
.50434 .49979 L
.50435 .49985 L
.50435 .49989 L
.50435 .49991 L
.50435 .49992 L
.50435 .49994 L
.50435 .49995 L
.50435 .49997 L
.50435 .49998 L
.50435 .5 L
.50435 .50002 L
.50435 .50004 L
.50435 .50005 L
.50435 .50007 L
.50435 .50009 L
.50435 .50012 L
.50435 .50015 L
.50434 .50019 L
Mistroke
.50434 .50026 L
.50434 .50032 L
.50432 .50046 L
.5043 .50061 L
.50428 .50076 L
.50425 .50092 L
.50418 .5012 L
.50409 .50147 L
.50398 .50175 L
.50373 .50223 L
.5034 .50271 L
.50302 .50312 L
.50257 .50351 L
.50209 .50381 L
.50159 .50405 L
.50132 .50414 L
.50103 .50422 L
.5009 .50425 L
.50076 .50428 L
.50064 .5043 L
.5005 .50432 L
.50037 .50433 L
.50026 .50434 L
.50019 .50434 L
.50013 .50435 L
.5001 .50435 L
.50008 .50435 L
.50007 .50435 L
.50005 .50435 L
.50003 .50435 L
.50002 .50435 L
.5 .50435 L
Mfstroke
.5001 .30551 m
.50085 .30551 L
.50154 .30552 L
.50233 .30552 L
.50308 .30554 L
.50441 .30556 L
.50585 .3056 L
.50744 .30565 L
.50913 .30573 L
.51215 .30589 L
.51527 .30611 L
.51818 .30636 L
.52481 .3071 L
.53153 .30808 L
.53766 .30919 L
.55129 .31239 L
.56292 .31597 L
.57534 .3207 L
.59863 .33237 L
.61938 .34646 L
.63924 .36422 L
.65592 .38374 L
.6694 .40445 L
.6752 .41556 L
.68073 .42816 L
.6852 .44063 L
.68853 .45223 L
.69121 .46445 L
.69235 .47125 L
.69321 .47772 L
.69382 .48388 L
.69405 .48699 L
.69425 .49044 L
.69438 .49337 L
.69443 .49502 L
.69444 .4958 L
.69446 .49653 L
.69447 .49723 L
.69448 .49786 L
.69448 .49856 L
.69449 .49932 L
.69449 .50004 L
.69449 .50082 L
.69448 .50157 L
.69448 .50225 L
.69447 .50305 L
.69445 .50382 L
.69442 .50525 L
.69437 .50679 L
.69431 .50846 L
Mistroke
.69415 .51148 L
.69397 .51427 L
.69339 .52066 L
.69255 .52743 L
.6915 .53396 L
.69013 .54097 L
.68698 .55352 L
.68305 .56572 L
.67804 .57827 L
.66686 .59992 L
.65208 .62124 L
.63529 .63972 L
.61501 .65684 L
.59344 .67057 L
.57116 .681 L
.55919 .68526 L
.54621 .68892 L
.54034 .69026 L
.53397 .6915 L
.52844 .6924 L
.52237 .6932 L
.51676 .69377 L
.51153 .69415 L
.50863 .6943 L
.506 .6944 L
.50454 .69444 L
.50377 .69445 L
.50296 .69447 L
.50225 .69448 L
.50147 .69448 L
.50076 .69449 L
.5001 .69449 L
Mfstroke
.50014 .22498 m
.5012 .22499 L
.50217 .22499 L
.50329 .225 L
.50435 .22502 L
.50623 .22506 L
.50828 .22511 L
.51053 .22519 L
.51291 .22529 L
.51718 .22552 L
.52159 .22583 L
.52571 .22619 L
.53508 .22723 L
.54459 .22862 L
.55325 .23019 L
.57252 .23472 L
.58898 .23978 L
.60654 .24646 L
.63946 .26297 L
.6688 .28289 L
.6969 .308 L
.72048 .33561 L
.73954 .36489 L
.74774 .3806 L
.75556 .39841 L
.76189 .41604 L
.76659 .43246 L
.77038 .44974 L
.77199 .45934 L
.7732 .46849 L
.77407 .4772 L
.7744 .48161 L
.77468 .48648 L
.77486 .49062 L
.77492 .49295 L
.77495 .49406 L
.77497 .49509 L
.77499 .49608 L
.775 .49697 L
.77501 .49797 L
.77501 .49903 L
.77502 .50006 L
.77501 .50117 L
.77501 .50221 L
.775 .50318 L
.77498 .50432 L
.77496 .5054 L
.77491 .50742 L
.77485 .5096 L
.77475 .51197 L
Mistroke
.77454 .51623 L
.77427 .52018 L
.77346 .52921 L
.77227 .53879 L
.77079 .54802 L
.76884 .55793 L
.7644 .57568 L
.75884 .59293 L
.75176 .61068 L
.73594 .64129 L
.71504 .67144 L
.6913 .69758 L
.66262 .72178 L
.63212 .7412 L
.60062 .75595 L
.5837 .76197 L
.56535 .76714 L
.55704 .76903 L
.54804 .77079 L
.54021 .77206 L
.53163 .77319 L
.52369 .77399 L
.5163 .77453 L
.51221 .77474 L
.50849 .77488 L
.50642 .77494 L
.50534 .77496 L
.50419 .77498 L
.50318 .775 L
.50208 .77501 L
.50108 .77501 L
.50014 .77502 L
Mfstroke
.50017 .16319 m
.50147 .16319 L
.50266 .1632 L
.50403 .16321 L
.50533 .16323 L
.50763 .16328 L
.51014 .16334 L
.51289 .16344 L
.51581 .16356 L
.52104 .16385 L
.52644 .16423 L
.53149 .16467 L
.54296 .16594 L
.55461 .16765 L
.56521 .16956 L
.58881 .17511 L
.60897 .1813 L
.63048 .18949 L
.6708 .20971 L
.70673 .2341 L
.74114 .26486 L
.77001 .29867 L
.79336 .33453 L
.80341 .35377 L
.81299 .37559 L
.82073 .39718 L
.82649 .41728 L
.83114 .43844 L
.83311 .45021 L
.83459 .46141 L
.83565 .47208 L
.83606 .47748 L
.8364 .48344 L
.83661 .48852 L
.8367 .49137 L
.83673 .49273 L
.83676 .49399 L
.83677 .4952 L
.83679 .49629 L
.8368 .49751 L
.83681 .49881 L
.83681 .50007 L
.83681 .50143 L
.8368 .50271 L
.83679 .5039 L
.83677 .50529 L
.83674 .50661 L
.83669 .50909 L
.8366 .51175 L
.83649 .51466 L
Mistroke
.83622 .51988 L
.8359 .52471 L
.8349 .53577 L
.83344 .5475 L
.83164 .55881 L
.82925 .57095 L
.8238 .59269 L
.817 .61381 L
.80833 .63555 L
.78896 .67304 L
.76336 .70996 L
.73429 .74197 L
.69917 .77161 L
.66181 .79539 L
.62323 .81346 L
.6025 .82083 L
.58003 .82716 L
.56986 .82948 L
.55883 .83163 L
.54925 .83319 L
.53873 .83457 L
.52902 .83556 L
.51997 .83622 L
.51495 .83648 L
.51039 .83665 L
.50787 .83672 L
.50654 .83675 L
.50513 .83677 L
.5039 .83679 L
.50255 .8368 L
.50132 .83681 L
.50017 .83681 L
Mfstroke
.50019 .11109 m
.5017 .1111 L
.50307 .11111 L
.50466 .11112 L
.50615 .11114 L
.50882 .11119 L
.5117 .11127 L
.51488 .11138 L
.51826 .11152 L
.5243 .11185 L
.53053 .11229 L
.53636 .1128 L
.54961 .11427 L
.56306 .11624 L
.5753 .11845 L
.60255 .12486 L
.62582 .13201 L
.65066 .14146 L
.69722 .16481 L
.73871 .19297 L
.77844 .22849 L
.81178 .26753 L
.83874 .30894 L
.85034 .33115 L
.8614 .35634 L
.87034 .38127 L
.87699 .40449 L
.88236 .42892 L
.88463 .44251 L
.88634 .45544 L
.88757 .46776 L
.88804 .47399 L
.88844 .48088 L
.88868 .48674 L
.88878 .49004 L
.88882 .4916 L
.88884 .49306 L
.88887 .49445 L
.88888 .49572 L
.8889 .49713 L
.8889 .49863 L
.88891 .50008 L
.8889 .50165 L
.88889 .50313 L
.88888 .5045 L
.88886 .5061 L
.88883 .50763 L
.88876 .51049 L
.88867 .51357 L
.88854 .51693 L
Mistroke
.88823 .52295 L
.88786 .52854 L
.88671 .5413 L
.88502 .55485 L
.88293 .56791 L
.88018 .58192 L
.87389 .60703 L
.86603 .63141 L
.85602 .65651 L
.83365 .69981 L
.8041 .74243 L
.77053 .7794 L
.72997 .81363 L
.68684 .84108 L
.64229 .86194 L
.61836 .87046 L
.59241 .87777 L
.58066 .88045 L
.56793 .88293 L
.55687 .88473 L
.54472 .88633 L
.5335 .88746 L
.52305 .88822 L
.51726 .88852 L
.512 .88872 L
.50908 .8888 L
.50755 .88883 L
.50592 .88886 L
.5045 .88888 L
.50294 .88889 L
.50152 .8889 L
.50019 .88891 L
Mfstroke
.5 .49565 m
.50004 .41233 L
.50006 .37331 L
.50008 .34539 L
.50009 .32264 L
.5001 .30127 L
.50011 .28267 L
.50012 .2645 L
.50013 .24824 L
.50013 .23353 L
.50014 .21872 L
.50015 .20516 L
.50015 .19269 L
.50016 .17995 L
.50017 .16814 L
.50017 .15604 L
.50018 .14477 L
.50018 .13425 L
.50019 .12339 L
.50019 .11321 L
.5002 .10269 L
.5002 .0928 L
.50021 .08351 L
.50021 .07386 L
.50022 .06522 L
s
.50085 .49574 m
.51714 .41402 L
.52476 .37576 L
.53022 .34838 L
.53467 .32606 L
.53884 .3051 L
.54248 .28686 L
.54603 .26904 L
.54921 .25309 L
.55208 .23866 L
.55498 .22414 L
.55763 .21085 L
.56007 .19862 L
.56256 .18612 L
.56486 .17454 L
.56723 .16267 L
.56943 .15162 L
.57149 .14131 L
.57361 .13065 L
.5756 .12067 L
.57766 .11035 L
.57959 .10066 L
.58141 .09155 L
.58329 .08208 L
.58498 .0736 L
s
.50167 .49598 m
.53357 .41901 L
.54851 .38297 L
.5592 .35718 L
.56791 .33616 L
.5761 .31641 L
.58322 .29923 L
.59018 .28245 L
.5964 .26742 L
.60204 .25383 L
.60771 .24016 L
.6129 .22763 L
.61767 .21611 L
.62255 .20434 L
.62707 .19344 L
.63171 .18225 L
.63602 .17184 L
.64005 .16213 L
.64421 .15209 L
.64811 .14269 L
.65214 .13297 L
.65592 .12384 L
.65948 .11526 L
.66318 .10634 L
.66648 .09835 L
s
.50242 .49638 m
.54872 .42711 L
.5704 .39467 L
.58591 .37146 L
.59855 .35254 L
.61043 .33477 L
.62077 .31931 L
.63086 .30421 L
.6399 .29068 L
.64807 .27845 L
.6563 .26614 L
.66383 .25487 L
.67076 .2445 L
.67785 .23391 L
.6844 .22409 L
.69113 .21403 L
.69739 .20466 L
.70324 .19592 L
.70928 .18688 L
.71493 .17842 L
.72078 .16967 L
.72627 .16146 L
.73143 .15373 L
.7368 .1457 L
.7416 .13852 L
s
.50308 .49692 m
.56199 .43801 L
.58958 .41042 L
.60932 .39068 L
.62541 .37459 L
.64053 .35947 L
.65368 .34632 L
.66652 .33348 L
.67802 .32198 L
.68843 .31157 L
.6989 .3011 L
.70848 .29152 L
.7173 .2827 L
.72631 .27369 L
.73466 .26534 L
.74322 .25678 L
.75119 .24881 L
.75862 .24138 L
.76631 .23369 L
.7735 .2265 L
.78094 .21906 L
.78793 .21207 L
.7945 .2055 L
.80133 .19867 L
.80744 .19256 L
s
.50362 .49758 m
.57289 .45128 L
.60533 .4296 L
.62854 .41409 L
.64746 .40145 L
.66523 .38957 L
.68069 .37923 L
.69579 .36914 L
.70932 .3601 L
.72155 .35193 L
.73386 .3437 L
.74513 .33617 L
.7555 .32924 L
.76609 .32215 L
.77591 .3156 L
.78597 .30887 L
.79534 .30261 L
.80408 .29676 L
.81312 .29072 L
.82158 .28507 L
.83033 .27922 L
.83854 .27373 L
.84627 .26857 L
.8543 .2632 L
.86148 .2584 L
s
.50402 .49833 m
.58099 .46643 L
.61703 .45149 L
.64282 .4408 L
.66384 .43209 L
.68359 .4239 L
.70077 .41678 L
.71755 .40982 L
.73258 .4036 L
.74617 .39796 L
.75984 .39229 L
.77237 .3871 L
.78389 .38233 L
.79566 .37745 L
.80656 .37293 L
.81775 .36829 L
.82816 .36398 L
.83787 .35995 L
.84791 .35579 L
.85731 .35189 L
.86703 .34786 L
.87616 .34408 L
.88474 .34052 L
.89366 .33682 L
.90165 .33352 L
s
.50426 .49915 m
.58598 .48286 L
.62424 .47524 L
.65162 .46978 L
.67394 .46533 L
.6949 .46116 L
.71314 .45752 L
.73096 .45397 L
.74691 .45079 L
.76134 .44792 L
.77586 .44502 L
.78915 .44237 L
.80138 .43993 L
.81388 .43744 L
.82546 .43514 L
.83733 .43277 L
.84838 .43057 L
.85869 .42851 L
.86935 .42639 L
.87933 .4244 L
.88965 .42234 L
.89934 .42041 L
.90845 .41859 L
.91792 .41671 L
.9264 .41502 L
s
.50435 .5 m
.58767 .49996 L
.62669 .49994 L
.65461 .49992 L
.67736 .49991 L
.69873 .4999 L
.71733 .49989 L
.7355 .49988 L
.75176 .49987 L
.76647 .49987 L
.78128 .49986 L
.79484 .49985 L
.80731 .49985 L
.82005 .49984 L
.83186 .49983 L
.84396 .49983 L
.85523 .49982 L
.86575 .49982 L
.87661 .49981 L
.88679 .49981 L
.89731 .4998 L
.9072 .4998 L
.91649 .49979 L
.92614 .49979 L
.93478 .49978 L
s
.50427 .50085 m
.586 .51705 L
.62427 .52464 L
.65165 .53007 L
.67397 .53449 L
.69494 .53865 L
.71319 .54227 L
.731 .5458 L
.74696 .54896 L
.76139 .55182 L
.77591 .5547 L
.78921 .55734 L
.80144 .55976 L
.81394 .56224 L
.82552 .56454 L
.8374 .56689 L
.84845 .56909 L
.85877 .57113 L
.86942 .57324 L
.8794 .57522 L
.88973 .57727 L
.89942 .57919 L
.90853 .581 L
.91801 .58288 L
.92648 .58456 L
s
.50402 .50166 m
.58103 .53349 L
.61708 .54839 L
.64288 .55906 L
.66391 .56775 L
.68366 .57591 L
.70085 .58302 L
.71764 .58996 L
.73267 .59617 L
.74627 .60179 L
.75995 .60745 L
.77248 .61263 L
.784 .61739 L
.79578 .62226 L
.80669 .62677 L
.81788 .63139 L
.8283 .6357 L
.83801 .63971 L
.84805 .64386 L
.85746 .64775 L
.86718 .65177 L
.87632 .65555 L
.8849 .65909 L
.89383 .66278 L
.90181 .66608 L
s
.50362 .50241 m
.57294 .54865 L
.6054 .57029 L
.62863 .58578 L
.64755 .59841 L
.66534 .61027 L
.68081 .62059 L
.69593 .63067 L
.70946 .63969 L
.7217 .64785 L
.73401 .65607 L
.74529 .66359 L
.75567 .67051 L
.76627 .67758 L
.77609 .68413 L
.78616 .69085 L
.79554 .6971 L
.80429 .70293 L
.81333 .70896 L
.82179 .71461 L
.83055 .72045 L
.83877 .72593 L
.8465 .73108 L
.85453 .73644 L
.86172 .74124 L
s
.50308 .50307 m
.56206 .56193 L
.58967 .58949 L
.60943 .60921 L
.62554 .62529 L
.64067 .64039 L
.65383 .65353 L
.66669 .66636 L
.6782 .67785 L
.68861 .68824 L
.6991 .6987 L
.70869 .70827 L
.71752 .71708 L
.72654 .72609 L
.73489 .73442 L
.74346 .74298 L
.75144 .75094 L
.75888 .75836 L
.76657 .76604 L
.77377 .77323 L
.78122 .78066 L
.78822 .78764 L
.79479 .79421 L
.80163 .80103 L
.80775 .80713 L
s
.50242 .50361 m
.54879 .57284 L
.5705 .60526 L
.58604 .62845 L
.5987 .64736 L
.6106 .66512 L
.62095 .68057 L
.63106 .69566 L
.64011 .70918 L
.64829 .7214 L
.65653 .7337 L
.66408 .74496 L
.67102 .75533 L
.67811 .76591 L
.68468 .77572 L
.69142 .78578 L
.69769 .79514 L
.70354 .80388 L
.70959 .81291 L
.71525 .82136 L
.72111 .8301 L
.72661 .83832 L
.73178 .84603 L
.73715 .85406 L
.74196 .86124 L
s
.50167 .50402 m
.53365 .58096 L
.54863 .61698 L
.55934 .64276 L
.56808 .66377 L
.57628 .68351 L
.58342 .70069 L
.59039 .71746 L
.59664 .73248 L
.60228 .74606 L
.60797 .75974 L
.61317 .77225 L
.61796 .78377 L
.62285 .79554 L
.62738 .80644 L
.63203 .81762 L
.63635 .82802 L
.64039 .83773 L
.64456 .84777 L
.64846 .85716 L
.6525 .86688 L
.6563 .87601 L
.65986 .88458 L
.66357 .8935 L
.66689 .90148 L
s
.50085 .50426 m
.51722 .58597 L
.52489 .62422 L
.53037 .65159 L
.53484 .6739 L
.53904 .69486 L
.54269 .7131 L
.54626 .73091 L
.54946 .74686 L
.55235 .76128 L
.55525 .7758 L
.55792 .78909 L
.56037 .80132 L
.56287 .81382 L
.56519 .82539 L
.56757 .83726 L
.56978 .84831 L
.57185 .85862 L
.57398 .86928 L
.57598 .87925 L
.57805 .88957 L
.57999 .89926 L
.58181 .90837 L
.58371 .91784 L
.58541 .92631 L
s
.50001 .50435 m
.50013 .58767 L
.50019 .62669 L
.50023 .65461 L
.50027 .67736 L
.5003 .69873 L
.50033 .71733 L
.50035 .7355 L
.50038 .75176 L
.5004 .76647 L
.50042 .78128 L
.50044 .79484 L
.50046 .80731 L
.50048 .82005 L
.5005 .83186 L
.50052 .84396 L
.50053 .85523 L
.50055 .86575 L
.50056 .87661 L
.50058 .88679 L
.5006 .89731 L
.50061 .9072 L
.50062 .91649 L
.50064 .92614 L
.50065 .93478 L
s
gsave
.97826 .54348 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.54348 .97826 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97826 .5 m
1 .5 L
s
% Start of user PostScript
1.1 0 1.15 0 MAarrowhead1
% End of user PostScript
.5 .97826 m
.5 1 L
s
% Start of user PostScript
0 1.1 0 1.15 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{178.313, 178.313},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002b0000/R000`400?l00000o`00003o/P3oool0
0;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3o
ool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00
F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool0
0`000000oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool00`000000
oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?oo
o`1G0?ooo`00F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?ooo`1G0?oo
o`00F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo04/0oooo001H0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0B`3o
ool005P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1;0?ooo`00F03oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo04/0oooo001H0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0o0?ooo`00F03oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@03oool005P0oooo2P00
00000`3oool000000?ooo`0:0?ooo`030000003oool0oooo0400oooo001H0?ooo`030000003oool0
oooo00L0oooo0`0000090?ooo`030000003oool0oooo0440oooo001H0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`0000000`0000050?ooo`030000003oool0oooo0440oooo001H0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool300000080oooo00<000000?ooo`3o
ool0@@3oool005P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`<00000
2`3oool00`000000oooo0?ooo`0e0?ooo`00F03oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00@000000?ooo`00000000002@3oool00`000000oooo0?ooo`0e0?ooo`00F03o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool2000000H0oooo00<000000?ooo`3oool0=P3oool005P0oooo1`0000030?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0103oool2000000<0oooo00<000000?ooo`3oool0=`3oool0
05P0oooo00<000000?ooo`3oool0103oool4000000P0oooo00<000000?ooo`3oool01`3oool30000
03X0oooo001H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000`0000040?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0>03oool005P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`<0000000<0oooo0000003oool02@3oool010000000oooo
00000000000h0?ooo`00F03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
0P0000090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0[0?ooo`00F03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00@0
00000?ooo`00000000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0;03oool005P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`040000003oool0oooo0?ooo`800000103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool005P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000
2@3oool200000080oooo00<000000?ooo`3oool0;P3oool005P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo0P00000<0?ooo`800000<@3o
ool005P0oooo1`0000000`3oool000000?ooo`060?ooo`030000003oool0oooo00L0oooo0`00000:
0?ooo`800000<@3oool005P0oooo00<000000?ooo`3oool0103oool5000000<0oooo00<000000?oo
o`3oool01`3oool01@000000oooo0?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000<03o
ool005P0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`3oool2000000030?ooo`00
0000oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`000000<03oool005P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`<000001`3oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02d0oooo001H0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool010000000oooo0000000000040?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`0000001`3oool00`000000oooo0?ooo`0/0?ooo`00F03oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000
oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`8000009P3oool0
05P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo0P00000:0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0V0?ooo`00F03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool3000000P0oooo00D000000?ooo`3oool0oooo000000080?oo
o`040000003oool00000000002T0oooo001H0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo0P00000[0?ooo`00F03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`800000:`3oool005P0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo
02P0oooo001H0?ooo`D0000000<0oooo0000003oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo0P00000:0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0:03oool005P0oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`060?ooo`8000002`3oool2000000H0oooo00<000000?ooo`3o
ool09`3oool005P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04000000D0oooo
00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000090?ooo`800000203oool00`000000
oooo0?ooo`0V0?ooo`00F03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
0`0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool09P3oool005P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool20000
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01h0oooo001H0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?oo
o`8000001P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`8000008@3oool005P0oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`070?ooo`<00000203oool00`000000oooo0?ooo`050?ooo`@000008`3oool0
05P0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000090?ooo`030000003o
ool0oooo00<0oooo0`00000V0?ooo`00F03oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`8000002@3oool2000000030?ooo`000000oooo00T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02@0oooo001H0?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo0P0000070?ooo`800000103oool00`000000oooo0?ooo`070?ooo`@00000103oool00`000000
oooo0?ooo`0S0?ooo`00F03oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`@000001P3oool00`000000oooo0?ooo`0S0?ooo`00F03oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0080oooo
0P0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool005P0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`040?ooo`<000002@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0R0?ooo`00F03oool010000000oooo0?ooo`0000020?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`8000002`3oool4
000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`00F03oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`0000080?ooo`80000000<0oooo0000003oool0203oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0240oooo001H0?ooo`060000003oool0oooo0000003oool0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`03
0000003oool0oooo00@0oooo0P0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0Q0?ooo`00F03oool01P000000oooo0?ooo`000000oooo0000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`0000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
10000000oooo0?ooo`3oool4000001`0oooo001H0?ooo`080000003oool0oooo0000003oool00000
0?ooo`0000030?ooo`030000003oool0oooo0080oooo0P0000070?ooo`<000002@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo1@00000P0?ooo`00F03oool01`000000oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo0`0000000`3oool000000?ooo`0:0?ooo`030000003oool0oooo00H0oooo1P0000000`3o
ool000000?ooo`0R0?ooo`00F03oool01`000000oooo0000003oool000000?ooo`0000000P3oool0
10000000oooo0?ooo`3oool2000000D0oooo0P0000040?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00P3oool5000000H0oooo00<000000?ooo`3oool08@3oool005P0oooo00H00000
0?ooo`00000000000?ooo`0000020?ooo`030000003oool0oooo008000001@3oool2000000H0oooo
00<000000?ooo`3oool0203oool6000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0P0?ooo`00F03oool00`000000oooo0000000200000080oooo00@000000?ooo`3oool00000
1@3oool2000000T0oooo00<000000?ooo`3oool00P3oool5000000030?ooo`000000oooo00L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0P0?ooo`00F03oool400000080oooo00@0
00000?ooo`0000000000103oool2000000/0oooo1@0000070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`00F03oool4000000040?ooo`00
0000oooo000000<0oooo0`00000:0?ooo`@000002`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0803oool005P0oooo0`000000103oool000000000
000000020?ooo`8000001@3oool8000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool005P0oooo0P00
00000`3oool00000000000020?ooo`8000000P3oool5000000`0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0803o
ool005P0oooo100000000`3oool000000000000400000140oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool2
000001T0oooo001H0?ooo`80000000<0oooo0000000000000P00000E0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo1P00000E0?ooo`004@3ooon?00000180oooo001H0?ooo`X000004P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`L00000503oool005P0oooo0P0000000`3oool0000000000002000000<0oooo1@00
000=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo0`00000H0?ooo`00F03oool3000000040?ooo`000000
00000?ooo`8000001P3oool5000000P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool005P0oooo10000000
0`3oool00000000000020?ooo`8000002@3oool4000000<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool4
000001<0oooo001H0?ooo`@0000000<0oooo0000003oool00P0000020?ooo`<000002P3oool50000
00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00P0oooo00@000000?ooo`3oool00000503oool005P0oooo0P0000001@3oool000000000003oool0
00000080oooo00<000000?ooo`3oool00P3oool2000000/0oooo00<000000?ooo`00000010000005
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`08
0?ooo`040000003oool0oooo000001@0oooo001H0?ooo`080000003oool000000000003oool00000
0?ooo`0000020?ooo`030000003oool0oooo00<0oooo0`0000080?ooo`030000003oool0oooo00@0
oooo100000000`3oool000000?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool2000000030?ooo`000000000001@0oooo001H0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo0P0000060?ooo`<00000103oool00`000000oooo0?ooo`09
0?ooo`H000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0200oooo001H0?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`040000003oool0oooo0?ooo`800000
1`3oool200000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`D00000
1@3oool00`000000oooo0?ooo`0Q0?ooo`00F03oool00`000000oooo000000020?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`800000303o
ool00`000000oooo0?ooo`060?ooo`030000003oool0000000D000008`3oool005P0oooo00H00000
0?ooo`3oool000000?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0P0000070?ooo`<0
00002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo1@00000O0?ooo`00
F03oool01P000000oooo0?ooo`000000oooo00000080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P0000070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`<00000703oool0
05P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00<0oooo0P0000030?ooo`030000003oool0oooo00<0oooo100000030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`00F03oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0P0000050?ooo`800000
00<0oooo0000003oool0203oool2000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0R0?ooo`00F03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`040?ooo`8000002`3oool2000000L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`00F03oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000002P3oool00`000000oooo00000002000000@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`00F03oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool08`3oool005P0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`0000050?ooo`80
00001P3oool00`000000oooo0?ooo`050?ooo`<000001P3oool00`000000oooo0?ooo`0S0?ooo`00
F03oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`0000000000103oool00`000000oooo0?ooo`0S0?ooo`00F03oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`8000002@3oool0
1@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool4000002H0oooo001H
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo008000000P3oool00`000000oooo0?ooo`070?ooo`<000002@3oool00`000000oooo0?oo
o`050?ooo`8000009@3oool005P0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo0080oooo0P0000050?ooo`030000003oool0oooo00L0oooo0P0000080?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`0000000P00000R0?ooo`00F03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0`0000060?ooo`8000001`3o
ool010000000oooo0000000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool200000200oooo001H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0000000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0U0?ooo`00F03oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo0P0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`80000000<0oooo0000003oool01`3oool00`000000oooo0?oo
o`0V0?ooo`00F03oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool00000
1P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000T0oooo0P0000070?ooo`03
0000003oool0oooo02L0oooo001H0?ooo`T000000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00H0oooo0P00000:0?ooo`<000001P3oool00`000000oooo0?ooo`0W0?ooo`00F03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`8000002@3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0:03oool005P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`02000000L0oooo00<000000?ooo`3oool00P3oool4000002/0oooo001H0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0:@3oool005P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000:P3oool005P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P0000090?oo
o`040000003oool0oooo000000P0oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`00F03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool3
000000X0oooo0P0000090?ooo`030000003oool0oooo0080oooo0P00000W0?ooo`00F03oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P000002
0?ooo`030000003oool0oooo00P0oooo0`0000070?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0903oool005P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`<000001@3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001@3oool0
0`000000oooo0?ooo`0]0?ooo`00F03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo0P0000080?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`050000003oool0oooo
0?ooo`000000<03oool005P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030000
00030?ooo`000000oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`050000003oool0oooo0?ooo`000000<03oool005P0oooo00<000000?ooo`3oool00`3oool50000
00D0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
00000340oooo001H0?ooo`H000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo0P00000;0?ooo`030000003oool0oooo0300oooo001H0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`<000002P3oool00`000000
oooo0000000a0?ooo`00F03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000090?ooo`050000003oool0oooo0?oo
o`000000<03oool005P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`8000001@3oool00`00
0000oooo0?ooo`0]0?ooo`00F03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00@000000?ooo`00000000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo0P00000]0?ooo`00F03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo0`00000:0?ooo`040000003oool0oooo000003P0oooo001H0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool300000080oooo00<000000?ooo`3oool02@3oool2000003T0
oooo001H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000P0000050?ooo`030000
003oool0oooo00P0oooo0P00000j0?ooo`00F03oool010000000oooo0?ooo`3oool7000000P0oooo
00<000000?ooo`3oool01P3oool2000000030?ooo`000000oooo03T0oooo001H0?ooo`@000001P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000003o
ool0oooo03L0oooo001H0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`02000000L0oooo00<000000?ooo`3oool0=P3oool005P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`<000002P3oool00`000000oooo0?ooo`0e0?oo
o`00F03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0`00000<0?ooo`03
0000003oool0oooo03D0oooo001H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool3000000<0oooo00<000000?ooo`3oool0@@3oool005P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo00000002000000H0oooo00<000000?ooo`3oool0@@3oool005P0oooo00<00000
0?ooo`3oool01@3oool5000000X0oooo00<000000?ooo`3oool0@03oool005P0oooo200000030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@03oool005P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0400oooo001H0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0o0?ooo`00F03o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04/0oooo001H0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0B`3oool005P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`1;0?ooo`00F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool00`000000oooo
0?ooo`1G0?ooo`00EP3oool5000005L0oooo001F0?ooo`D00000E`3oool005H0oooo1000001H0?oo
o`00E`3oool3000000<0oooo0P00001C0?ooo`00E`3oool3000000<0oooo0P00001C0?ooo`00E`3o
ool300000080oooo00@000000?ooo`3oool00000DP3oool005L0oooo0P0000020?ooo`8000000P3o
ool200000540oooo001H0?ooo`030000003oool0oooo05L0oooo001H0?ooo`030000003oool0oooo
05L0oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3o
ool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00
/P3oool00001\
\>"],
    ImageRangeCache->{{{17.6875, 159.563}, {159.625, 17.75}} -> {-1, -1, 0, 
    0}}],
  "  ",
  StyleBox["\n\t\t\t(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  A portion of  ",
  Cell[BoxData[
      \(D\_1\)]],
  "  and its image under  ",
  Cell[BoxData[
      \(w = z\^\(1\/2\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6193 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1 -0.147002 1 [
[ 0 0 0 0 ]
[ 1 .6193 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .6193 L
0 .6193 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.46467 .38119 m .46551 .39454 L .33227 .37102 L p .893 .893 .893 r
F P
0 g
s
.46551 .39454 m .46467 .38119 L .57344 .38532 L p .932 .932 .932 r
F P
0 g
s
.57344 .38532 m .59848 .39972 L .46551 .39454 L p .932 .932 .932 r
F P
0 g
s
.46551 .39454 m
.46631 .40728 L
s
.35562 .36186 m .33227 .37102 L .2127 .3297 L p .865 .865 .865 r
F P
0 g
s
.33227 .37102 m .35562 .36186 L .46467 .38119 L p .893 .893 .893 r
F P
0 g
s
.59848 .39972 m .57344 .38532 L .66954 .3749 L p .967 .967 .967 r
F P
0 g
s
.66954 .3749 m .7172 .38731 L .59848 .39972 L p .967 .967 .967 r
F P
0 g
s
.46378 .36718 m .46467 .38119 L .35562 .36186 L p .893 .893 .893 r
F P
0 g
s
.46467 .38119 m .46378 .36718 L .54724 .37025 L p .932 .932 .932 r
F P
0 g
s
.54724 .37025 m .57344 .38532 L .46467 .38119 L p .932 .932 .932 r
F P
0 g
s
.2127 .3297 m .25865 .328 L .35562 .36186 L p .865 .865 .865 r
F P
0 g
s
.38006 .35227 m .35562 .36186 L .25865 .328 L p .865 .865 .865 r
F P
0 g
s
.35562 .36186 m .38006 .35227 L .46378 .36718 L p .893 .893 .893 r
F P
0 g
s
.25865 .328 m .2127 .3297 L .12142 .27285 L p .854 .854 .854 r
F P
0 g
s
.57344 .38532 m .54724 .37025 L .62017 .36204 L p .967 .967 .967 r
F P
0 g
s
.62017 .36204 m .66954 .3749 L .57344 .38532 L p .967 .967 .967 r
F P
0 g
s
.7172 .38731 m .66954 .3749 L .74046 .35203 L p .99 .99 .99 r
F P
0 g
s
.74046 .35203 m .80696 .35951 L .7172 .38731 L p .99 .99 .99 r
F P
0 g
s
.46285 .35244 m .46378 .36718 L .38006 .35227 L p .893 .893 .893 r
F P
0 g
s
.46378 .36718 m .46285 .35244 L .5198 .35447 L p .932 .932 .932 r
F P
0 g
s
.5198 .35447 m .54724 .37025 L .46378 .36718 L p .932 .932 .932 r
F P
0 g
s
.12142 .27285 m .18624 .28196 L .25865 .328 L p .854 .854 .854 r
F P
0 g
s
.30633 .32625 m .25865 .328 L .18624 .28196 L p .854 .854 .854 r
F P
0 g
s
.25865 .328 m .30633 .32625 L .38006 .35227 L p .865 .865 .865 r
F P
0 g
s
.40568 .34221 m .38006 .35227 L .30633 .32625 L p .865 .865 .865 r
F P
0 g
s
.38006 .35227 m .40568 .34221 L .46285 .35244 L p .893 .893 .893 r
F P
0 g
s
.66954 .3749 m .62017 .36204 L .67263 .3444 L p .99 .99 .99 r
F P
0 g
s
.67263 .3444 m .74046 .35203 L .66954 .3749 L p .99 .99 .99 r
F P
0 g
s
.54724 .37025 m .5198 .35447 L .56899 .34872 L p .967 .967 .967 r
F P
0 g
s
.56899 .34872 m .62017 .36204 L .54724 .37025 L p .967 .967 .967 r
F P
0 g
s
.18624 .28196 m .25254 .29128 L .30633 .32625 L p .854 .854 .854 r
F P
0 g
s
.35585 .32443 m .30633 .32625 L .25254 .29128 L p .854 .854 .854 r
F P
0 g
s
.30633 .32625 m .35585 .32443 L .40568 .34221 L p .865 .865 .865 r
F P
0 g
s
.18624 .28196 m .12142 .27285 L .0736 .20532 L p .858 .858 .858 r
F P
0 g
s
.62017 .36204 m .56899 .34872 L .60345 .33661 L p .99 .99 .99 r
F P
0 g
s
.60345 .33661 m .67263 .3444 L .62017 .36204 L p .99 .99 .99 r
F P
0 g
s
.46187 .33692 m .46285 .35244 L .40568 .34221 L p .893 .893 .893 r
F P
0 g
s
.46285 .35244 m .46187 .33692 L .49103 .33793 L p .932 .932 .932 r
F P
0 g
s
.49103 .33793 m .5198 .35447 L .46285 .35244 L p .932 .932 .932 r
F P
0 g
s
.80696 .35951 m .74046 .35203 L .77413 .32056 L p .999 .999 .999 r
F P
0 g
s
.77413 .32056 m .85245 .32056 L .80696 .35951 L p .999 .999 .999 r
F P
0 g
s
.43258 .33165 m .40568 .34221 L .35585 .32443 L p .865 .865 .865 r
F P
0 g
s
.40568 .34221 m .43258 .33165 L .46187 .33692 L p .893 .893 .893 r
F P
0 g
s
.5198 .35447 m .49103 .33793 L .51592 .3349 L p .967 .967 .967 r
F P
0 g
s
.51592 .3349 m .56899 .34872 L .5198 .35447 L p .967 .967 .967 r
F P
0 g
s
.0736 .20532 m .15042 .22818 L .18624 .28196 L p .858 .858 .858 r
F P
0 g
s
.25254 .29128 m .18624 .28196 L .15042 .22818 L p .858 .858 .858 r
F P
0 g
s
.74046 .35203 m .67263 .3444 L .6958 .32056 L p .999 .999 .999 r
F P
0 g
s
.6958 .32056 m .77413 .32056 L .74046 .35203 L p .999 .999 .999 r
F P
0 g
s
.25254 .29128 m .32037 .30082 L .35585 .32443 L p .854 .854 .854 r
F P
0 g
s
.40731 .32253 m .35585 .32443 L .32037 .30082 L p .854 .854 .854 r
F P
0 g
s
.35585 .32443 m .40731 .32253 L .43258 .33165 L p .865 .865 .865 r
F P
0 g
s
.56899 .34872 m .51592 .3349 L .53286 .32867 L p .99 .99 .99 r
F P
0 g
s
.53286 .32867 m .60345 .33661 L .56899 .34872 L p .99 .99 .99 r
F P
0 g
s
.15042 .22818 m .22755 .25114 L .25254 .29128 L p .858 .858 .858 r
F P
0 g
s
.32037 .30082 m .25254 .29128 L .22755 .25114 L p .858 .858 .858 r
F P
0 g
s
.67263 .3444 m .60345 .33661 L .61748 .32056 L p .999 .999 .999 r
F P
0 g
s
.61748 .32056 m .6958 .32056 L .67263 .3444 L p .999 .999 .999 r
F P
0 g
s
.46084 .32056 m .46187 .33692 L .43258 .33165 L closepath p .893 .893 .893 r
F P
0 g
s
.46084 .32056 m .49103 .33793 L .46187 .33692 L closepath p .932 .932 .932 r
F P
0 g
s
.46084 .32056 m .43258 .33165 L .40731 .32253 L closepath p .865 .865 .865 r
F P
0 g
s
.46084 .32056 m .51592 .3349 L .49103 .33793 L closepath p .967 .967 .967 r
F P
0 g
s
.22755 .25114 m .305 .27418 L .32037 .30082 L p .858 .858 .858 r
F P
0 g
s
.38978 .31057 m .32037 .30082 L .305 .27418 L p .858 .858 .858 r
F P
0 g
s
.32037 .30082 m .38978 .31057 L .40731 .32253 L p .854 .854 .854 r
F P
0 g
s
.60345 .33661 m .53286 .32867 L .53916 .32056 L p .999 .999 .999 r
F P
0 g
s
.53916 .32056 m .61748 .32056 L .60345 .33661 L p .999 .999 .999 r
F P
0 g
s
.46084 .32056 m .40731 .32253 L .38978 .31057 L closepath p .854 .854 .854 r
F P
0 g
s
.46084 .32056 m .53286 .32867 L .51592 .3349 L closepath p .99 .99 .99 r
F P
0 g
s
.305 .27418 m .38276 .29733 L .38978 .31057 L p .858 .858 .858 r
F P
0 g
s
.46084 .32056 m .38978 .31057 L .38276 .29733 L closepath p .858 .858 .858 r
F P
0 g
s
.46084 .32056 m .53916 .32056 L .53286 .32867 L closepath p .999 .999 .999 r
F P
0 g
s
.85245 .32056 m .77413 .32056 L .76094 .28642 L p .999 .999 .999 r
F P
0 g
s
.76094 .28642 m .84 .27743 L .85245 .32056 L p .999 .999 .999 r
F P
0 g
s
.85245 .32056 m
.9014 .32056 L
s
.77413 .32056 m .6958 .32056 L .68354 .29523 L p .999 .999 .999 r
F P
0 g
s
.68354 .29523 m .76094 .28642 L .77413 .32056 L p .999 .999 .999 r
F P
0 g
s
.6958 .32056 m .61748 .32056 L .60776 .30385 L p .999 .999 .999 r
F P
0 g
s
.60776 .30385 m .68354 .29523 L .6958 .32056 L p .999 .999 .999 r
F P
0 g
s
.61748 .32056 m .53916 .32056 L .53354 .31229 L p .999 .999 .999 r
F P
0 g
s
.53354 .31229 m .60776 .30385 L .61748 .32056 L p .999 .999 .999 r
F P
0 g
s
.46084 .32056 m .53354 .31229 L .53916 .32056 L closepath p .999 .999 .999 r
F P
0 g
s
.46084 .32056 m .51653 .30567 L .53354 .31229 L closepath p .997 .997 .997 r
F P
0 g
s
.46084 .32056 m .49058 .30232 L .51653 .30567 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .45975 .3033 L .49058 .30232 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .42907 .3089 L .45975 .3033 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .40353 .31851 L .42907 .3089 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .38714 .33079 L .40353 .31851 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .38228 .3439 L .38714 .33079 L closepath p 1 1 1 r
F P
0 g
s
.31167 .34127 m .38714 .33079 L .38228 .3439 L p 1 1 1 r
F P
0 g
s
.38228 .3439 m .30339 .36733 L .31167 .34127 L p 1 1 1 r
F P
0 g
s
.23434 .352 m .31167 .34127 L .30339 .36733 L p 1 1 1 r
F P
0 g
s
.30339 .36733 m .22418 .39085 L .23434 .352 L p 1 1 1 r
F P
0 g
s
.15509 .363 m .23434 .352 L .22418 .39085 L p 1 1 1 r
F P
0 g
s
.22418 .39085 m .14464 .41448 L .15509 .363 L p 1 1 1 r
F P
0 g
s
.07385 .37428 m .15509 .363 L .14464 .41448 L p 1 1 1 r
F P
0 g
s
.14464 .41448 m .06477 .4382 L .07385 .37428 L p 1 1 1 r
F P
0 g
s
.60776 .30385 m .53354 .31229 L .51653 .30567 L p .997 .997 .997 r
F P
0 g
s
.34382 .31638 m .40353 .31851 L .38714 .33079 L p 1 1 1 r
F P
0 g
s
.38714 .33079 m .31167 .34127 L .34382 .31638 L p 1 1 1 r
F P
0 g
s
.51653 .30567 m .57442 .29019 L .60776 .30385 L p .997 .997 .997 r
F P
0 g
s
.57442 .29019 m .51653 .30567 L .49058 .30232 L p 1 1 1 r
F P
0 g
s
.39559 .2966 m .42907 .3089 L .40353 .31851 L p 1 1 1 r
F P
0 g
s
.40353 .31851 m .34382 .31638 L .39559 .2966 L p 1 1 1 r
F P
0 g
s
.68354 .29523 m .60776 .30385 L .57442 .29019 L p .997 .997 .997 r
F P
0 g
s
.28157 .31415 m .34382 .31638 L .31167 .34127 L p 1 1 1 r
F P
0 g
s
.31167 .34127 m .23434 .352 L .28157 .31415 L p 1 1 1 r
F P
0 g
s
.49058 .30232 m .52187 .28311 L .57442 .29019 L p 1 1 1 r
F P
0 g
s
.52187 .28311 m .49058 .30232 L .45975 .3033 L p 1 1 1 r
F P
0 g
s
.4586 .28504 m .45975 .3033 L .42907 .3089 L p 1 1 1 r
F P
0 g
s
.42907 .3089 m .39559 .2966 L .4586 .28504 L p 1 1 1 r
F P
0 g
s
.45975 .3033 m .4586 .28504 L .52187 .28311 L p 1 1 1 r
F P
0 g
s
.76094 .28642 m .68354 .29523 L .63462 .27409 L p .997 .997 .997 r
F P
0 g
s
.57442 .29019 m .63462 .27409 L .68354 .29523 L p .997 .997 .997 r
F P
0 g
s
.21661 .31183 m .28157 .31415 L .23434 .352 L p 1 1 1 r
F P
0 g
s
.23434 .352 m .15509 .363 L .21661 .31183 L p 1 1 1 r
F P
0 g
s
.63462 .27409 m .57442 .29019 L .52187 .28311 L p 1 1 1 r
F P
0 g
s
.36028 .28364 m .39559 .2966 L .34382 .31638 L p 1 1 1 r
F P
0 g
s
.34382 .31638 m .28157 .31415 L .36028 .28364 L p 1 1 1 r
F P
0 g
s
.84 .27743 m .76094 .28642 L .69729 .25734 L p .997 .997 .997 r
F P
0 g
s
.63462 .27409 m .69729 .25734 L .76094 .28642 L p .997 .997 .997 r
F P
0 g
s
.14876 .3094 m .21661 .31183 L .15509 .363 L p 1 1 1 r
F P
0 g
s
.15509 .363 m .07385 .37428 L .14876 .3094 L p 1 1 1 r
F P
0 g
s
.52187 .28311 m .55484 .26288 L .63462 .27409 L p 1 1 1 r
F P
0 g
s
.55484 .26288 m .52187 .28311 L .4586 .28504 L p 1 1 1 r
F P
0 g
s
.45737 .26571 m .4586 .28504 L .39559 .2966 L p 1 1 1 r
F P
0 g
s
.39559 .2966 m .36028 .28364 L .45737 .26571 L p 1 1 1 r
F P
0 g
s
.69729 .25734 m .76258 .23988 L .84 .27743 L p .997 .997 .997 r
F P
0 g
s
.4586 .28504 m .45737 .26571 L .55484 .26288 L p 1 1 1 r
F P
0 g
s
.69729 .25734 m .63462 .27409 L .55484 .26288 L p 1 1 1 r
F P
0 g
s
.32297 .26993 m .36028 .28364 L .28157 .31415 L p 1 1 1 r
F P
0 g
s
.28157 .31415 m .21661 .31183 L .32297 .26993 L p 1 1 1 r
F P
0 g
s
.55484 .26288 m .58963 .24153 L .69729 .25734 L p 1 1 1 r
F P
0 g
s
.58963 .24153 m .55484 .26288 L .45737 .26571 L p 1 1 1 r
F P
0 g
s
.76258 .23988 m .69729 .25734 L .58963 .24153 L p 1 1 1 r
F P
0 g
s
.45608 .2452 m .45737 .26571 L .36028 .28364 L p 1 1 1 r
F P
0 g
s
.36028 .28364 m .32297 .26993 L .45608 .2452 L p 1 1 1 r
F P
0 g
s
.28349 .25544 m .32297 .26993 L .21661 .31183 L p 1 1 1 r
F P
0 g
s
.21661 .31183 m .14876 .3094 L .28349 .25544 L p 1 1 1 r
F P
0 g
s
.45737 .26571 m .45608 .2452 L .58963 .24153 L p 1 1 1 r
F P
0 g
s
.58963 .24153 m .62639 .21897 L .76258 .23988 L p 1 1 1 r
F P
0 g
s
.62639 .21897 m .58963 .24153 L .45608 .2452 L p 1 1 1 r
F P
0 g
s
.4547 .2234 m .45608 .2452 L .32297 .26993 L p 1 1 1 r
F P
0 g
s
.32297 .26993 m .28349 .25544 L .4547 .2234 L p 1 1 1 r
F P
0 g
s
.45608 .2452 m .4547 .2234 L .62639 .21897 L p 1 1 1 r
F P
0 g
s
gsave
.89289 .34183 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4668 .51799 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 178.313},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/R000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`005@3oool200000?l0oooo2P3o
ool001H0oooo1000003o0?ooo`L0oooo000F0?ooo`040000003Kfm/0fm_K0=_Kf`<00000o`3oool4
0?ooo`005`3oool00`000000fm_K0=_Kf`030=_Kf`<00000o`3oool10?ooo`00603oool00`000000
fm_K0=_Kf`050=_Kf`@00000M`3ooolL000006T0oooo000I0?ooo`030000003Kfm/0fm_K00P0fm_K
0`00001I0?oooa/000005P3oool2000000@0oooo1P00001S0?ooo`006@3oool00`000000fm_K0=_K
f`0;0=_Kf`<00000D03oool600000080oooo00<000000?ooo`3oool0:P3oool2000000`0oooo1`00
001L0?ooo`006P3oool00`000000fm_K0=_Kf`0=0=_Kf`<00000B03oool5000000P0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`H00000EP3oool001/0oooo00<000000=_K
f`3Kfm/03P3Kfm/5000003h0oooo1P00000=0?ooo`030000003oool0oooo02L0oooo0P00000L0?oo
o`L00000C`3oool001`0oooo00<000000=_Kf`3Kfm/03@3Kfm/00`000000fm_K0=_Kf`020=_Kf`@0
0000=@3oool5000001<0oooo00<000000?ooo`3oool09@3oool2000002D0oooo1P0000190?ooo`00
703oool00`000000fm_K0=_Kf`0>0=_Kf`030000003Kfm/0fm_K00D0fm_K0`00000]0?ooo`D00000
603oool00`000000oooo0?ooo`0A0?oooa@00000;@3oool4000004D0oooo000M0?ooo`030000003K
fm/0fm_K00h0fm_K00<000000=_Kf`3Kfm/01`3Kfm/4000002<0oooo1P00000K0?oooaH000004@3o
ool2000000<0oooo1P00000S0?ooo`@000000P3oool2000004<0oooo000N0?ooo`030000003Kfm/0
fm_K00d0fm_K00<000000=_Kf`3Kfm/02`3Kfm/4000001X0oooo1@00000K0?ooo`H000000P3oool0
0`000000oooo0?ooo`0P0?ooo`8000002`3oool6000001T0oooo100000080?ooo`800000@@3oool0
01l0oooo00<000000=_Kf`3Kfm/03@3Kfm/00`000000fm_K0=_Kf`0>0=_Kf`<000004@3oool60000
01/0oooo1@0000080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04@3oool60000
00l0oooo1000000>0?ooo`800000?`3oool001l0oooo00<000000=_Kf`3Kfm/03P3Kfm/00`000000
fm_K0=_Kf`0?0=_Kf`@000002P3oool4000001`0oooo1@00000=0?ooo`030000003oool0oooo01d0
oooo0P00000J0?ooo`H000001@3oool4000001@0oooo0P00000m0?ooo`00803oool00`000000fm_K
0=_Kf`0=0=_Kf`030000003Kfm/0fm_K00l0fm_K00@000000=_Kf`3Kfm/0fm_K0`0000050?ooo`80
00000`3oool3000001@0oooo1P00000C0?ooo`030000003oool0oooo01X0oooo0P00000R0?ooo`D0
00006P3oool2000003/0oooo000Q0?ooo`030000003Kfm/0fm_K00d0fm_K00<000000=_Kf`3Kfm/0
3`3Kfm/00`000000fm_K0=_Kf`030=_Kf`D00000203oool2000000d0oooo1@00000I0?ooo`030000
003oool0oooo00`0oooo4000000P0?ooo`@000000`3oool2000001X0oooo0P00000i0?ooo`008P3o
ool00`000000fm_K0=_Kf`0=0=_Kf`030000003Kfm/0fm_K00h0fm_K00<000000=_Kf`3Kfm/00`3K
fm/2000000d0oooo0`0000040?ooo`H00000703ooolA000000/0oooo0P0000030?ooo`H000005`3o
ool3000000T0oooo0P00000J0?ooo`800000=`3oool00280oooo00<000000=_Kf`3Kfm/03@3Kfm/0
0`000000fm_K0=_Kf`0?0=_Kf`030000003Kfm/0fm_K008000004P3oool4000001`0oooo1P000002
0?ooo`030000003oool0oooo01D0oooo0P00000;0?ooo`H000003P3oool3000000h0oooo0`00000I
0?ooo`800000=@3oool002<0oooo0`00000=0=_Kf`030000003Kfm/0fm_K00h0fm_K0`00000B0?oo
o`8000000`3oool3000001D0oooo1@0000080?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool04@3oool6000000@0oooo1000000D0?ooo`8000006@3oool2000003<0oooo000T0?ooo`P0
0000203Kfm/00`000000fm_K0=_Kf`0;0=_Kf`8000004P3oool3000000P0oooo0P00000=0?ooo`H0
00003@3oool00`000000oooo0?ooo`0B0?ooo`8000006P3oool4000001X0oooo0`00000H0?ooo`80
0000<@3oool002H0oooo00<000000=[JfP3Jf]X00`3Jf]X600000080fm_K00<000000=_Kf`3Kfm/0
203Kfm/300000180oooo0P00000=0?ooo`<00000103oool6000001<0oooo00<000000?ooo`3oool0
403oool2000001P0oooo100000040?ooo`8000006`3oool2000001@0oooo1P00000_0?ooo`009`3o
ool2000000T0f][J1`0000040=_Kf`8000004P3oool300000180oooo1000000I0?ooo`030000003o
ool0oooo00L0oooo3000000B0?ooo`D000002P3oool2000001/0oooo0P0000070?ooo`/000001@3o
ool00`000000oooo0?ooo`0]0?ooo`00:@3oool00`000000f][J0=[JfP0:0=[JfP80000000<0f][J
0000000000000P00000B0?ooo`8000004`3oool2000000<0oooo0P00000F0?ooo``000001P3oool2
000000@0oooo200000060?ooo`@000004@3oool3000001P0oooo2@00000A0?ooo`030000003oool0
oooo02`0oooo000Z0?ooo`800000303Jf]X200000180oooo0`00000B0?ooo`<000001`3oool30000
00d0oooo1P0000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool60000
01P0oooo0P00000?0?ooo`L000000`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
02`0oooo000/0?ooo`030000003Jf]X0f][J00H0f][J0`00000B0?ooo`8000004`3oool2000000d0
oooo0P0000050?ooo`H00000203oool00`000000oooo0?ooo`0:0?ooo`8000003P3oool3000000<0
oooo0P00000I0?ooo`8000001@3oool8000000/0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0/0?ooo`00;@3oool2000000@0f][J0P00000B0?ooo`<000004P3oool300000140oooo
1@00000>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool3000000P0oooo
0`00000D0?ooo`T000004`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02/0oooo
000_0?ooo`040000003Jf]X0000000000180oooo0P00000B0?ooo`<000004P3oool2000000<0oooo
0P00000>0?ooo`030000003oool0oooo00L0oooo0P00000:0?ooo`@000003P3oool2000000L0oooo
2`0000050?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0[0?ooo`00;P3oool300000140oooo0`00000B0?ooo`8000004P3oool3000000L0oooo0`00
000:0?ooo`h000001P3oool3000001@0oooo1`00000A0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0[0?ooo`00;03oool200000180oooo0P00000B
0?ooo`<000004P3oool2000000d0oooo0P0000040?ooo`@0000000<0oooo0000003oool01@3oool2
000000@0oooo1P00000>0?ooo`L00000103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0Z0?ooo`00:P3ooolM0000
00/0oooo0P00000B0?ooo`<000004@3oool4000000D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`@000000`3oool2000000D0oooo1`00000;0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
02X0oooo000Y0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01`3ooolB000000/0
oooo0P00000@0?ooo`@000000`3oool3000000@0oooo00<000000?ooo`3oool00P0000020?ooo`@0
00001@3oool9000001<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0:P3oool002P0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo8`0000040?ooo`<00000
00<0oooo0000000000003P0000050?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
:@3oool002H0oooo0P00000B0?ooo`8000004P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01`3ooon7000001d0oooo000U0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0403oool200000140oooo0P00000@0?ooo`030000003oool0
oooo00H0oooo2@0000000`3Ti>@000000000000=000000H0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0Z0?ooo`00903oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00L000000P3oool5000000<0i>CT00@000000>k^kP3^k^h000000P3gmoL4000000D0oOgm2@00000C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo02/0oooo000S0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo1`0000060?oo
o`D000001P3Ti>@010000000k^k^0>k^kP3^k^h2000000@0moOg100000040?gmo@800000103moOd7
000000`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo01<0oooo0P00000^0?ooo`008P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool03`3oool2000000P0oooo1`0000020?ooo`030000003oool0oooo
00D0oooo1@0000030>CTi0@000000P3Ti>@00`000000k^k^0>k^kP030>k^kP8000001@3gmoL50000
00d0oOgm1`0000040?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo02h0oooo000Q0?ooo`030000003oool0oooo0100
oooo0P00000B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0200000090?ooo`04
0000003oool0oooo0?ooo`L000002@3Ti>@?000000D0moOg1000000@0?gmo@P00000403oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool20000
00030?ooo`000000000001l0oooo000O0?ooo`8000004P3oool00`000000oooo0?ooo`0@0?ooo`80
00003P3oool700000100oooo00<000000?ooo`0000000P0000000`3MgMd0000000000002000000d0
i>CT00<000000>k^kP3^k^h01P3^k^h2000000/0moOg1000000;0?gmo@<000001P3moOd:000000D0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`000000803oool001h0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00L0oooo1`0000030?ooo`030000003oool0oooo0100oooo
0`0000020=gMg@800000103Ti>@5000000P0i>CT00<000000>k^kP3^k^h0203^k^h2000000d0moOg
100000030?gmo@@000004`3moOd900000140oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01l0oooo000M0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`08000000T0oooo00<000000?ooo`3oool03@3o
ool4000000<0gMgM0P00000;0>CTi0H000000P3Ti>@00`000000k^k^0>k^kP0:0>k^kP8000003@3g
moL5000001L0oOgm0`0000060?gmo@X000001P3oool00`000000oooo0?ooo`0B0?ooo`800000403o
ool2000000030?ooo`000000000001l0oooo000L0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool03@3oool700000140oooo00<000000?ooo`3oool02@3oool4000000@0gMgM0`00000C
0>CTi0/000001P3^k^h2000000@0moOg1`0000050?Ogm`@00000403moOd3000001<0oOgm2P00000@
0?ooo`030000003oool0oooo03@0oooo000K0?ooo`030000003oool0oooo0100oooo0P0000080?oo
o`P000000`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo0`0000060=gM
g@800000103Ti>@6000000h0i>CT00<000000>k^kP3^k^h01P3^k^h<00000100moOg0`00000:0?gm
o@<000005`3moOd3000000H0oOgm2P0000050?ooo`030000003oool0oooo03D0oooo000J0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool02000000:0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool00P3oool4000000040=gMg@0000000000000000<0gMgM0P00000<0>CT
i0H00000203Ti>@00`000000k^k^0>k^kP0?0>k^kP800000503gmoL4000000<0oOgm0`00000G0?gm
o@<000004`3moOd5000003P0oooo000H0?ooo`8000003`3oool700000180oooo00<000000?ooo`3o
ool04P3oool00`000000oooo00000003000000P0gMgM0`00000D0>CTi0H000000`3Ti>@00`000000
k^k^0>k^kP0@0>k^kP8000004`3gmoL6000001P0oOgm0P00000F0?gmo@<00000>P3oool001L0oooo
00<000000?ooo`3oool01`3oool8000000<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0A0?ooo`<000000P3oool3000000<0gMgM100000050>CTi0H000004P3Ti>@?000000T0k^k^
0P0000070?Ogm`X000001P3gmoL400000140oOgm0`00000D0?gmo@@00000?@3oool001H0oooo00<0
00000?ooo`3oool02000000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03P3o
ool3000000P0oooo0`00000?0>CTi0H000003`3Ti>@00`000000k^k^0>k^kP090>k^kQ800000503g
moL4000000X0oOgm0`00000D0?gmo@<00000@@3oool001D0oooo1000000B0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool02`3oool4000000l0oooo1P00000>0>CTi0H000002@3Ti>@0
0`000000k^k^0>k^kP0F0>k^kP8000006`3gmoL4000000<0oOgm0`00000D0?gmo@<00000A03oool0
01D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00P0oooo0`00000I0?ooo`D000003`3Ti>@6000000<0i>CT00<000000>k^kP3^k^h0603^k^h00`00
0000moOg0?Ogm`0I0?Ogm`L000004`3moOd3000004L0oooo000E0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`<000008@3oool500000100
i>CT2`00000D0>k^kP030000003gmoL0moOg00l0moOg2@0000070?Ogm`@000002`3moOd4000004X0
oooo000E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool010000000oooo
0?ooo`3oool4000002T0oooo1P00000=0>CTi0030000003^k^h0k^k^00D0k^k^400000050>k^kP80
00001@3gmoL:000001@0moOg100000040?gmo@<00000CP3oool001@0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0B0?ooo`030000003oool0000000800000<`3oool5000000P0i>CT
00<000000>k^kP3^k^h05@3^k^h<00000200moOg1P00001A0?ooo`00503oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0180oooo0`00000k0?ooo`H000000P3Ti>@00`000000k^k^0>k^
kP0M0>k^kP8000006P3gmoL8000005L0oooo000D0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool03`3oool3000004@0oooo3000000H0>k^kP8000003`3gmoL9000005l0oooo000D0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool4000004T0oooo00<000000?oo
o`3oool01`3ooolC000000L0k^k^0P0000050?Ogm`P00000J03oool001@0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`080?ooo`<00000C@3oool00`000000oooo0?ooo`0J0?ooo`h0
0000L03oool001@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`<00000
D03oool00`000000oooo0?ooo`2H0?ooo`004`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0080oooo1000001C0?ooo`030000003oool0oooo09P0oooo000C0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`0000000P00003b0?ooo`004`3oool00`000000oooo0?ooo`0B0?oo
o`<00000m@3oool001<0oooo00<000000?ooo`3oool03`3oool300000?P0oooo000C0?ooo`030000
003oool0oooo00/0oooo1000003k0?ooo`004`3oool00`000000oooo0?ooo`080?ooo`<00000o`3o
ool00180oooo00<000000?ooo`3oool01P3oool300000?l0oooo0`3oool00180oooo00<000000?oo
o`3oool00P3oool400000?l0oooo1P3oool00180oooo00<000000?ooo`0000000P00003o0?ooo`X0
oooo000B0?ooo`800000o`3oool=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00P`3oool2000009/0oooo00240?ooo`030000003oool0oooo09T0oooo00250?ooo`030000003o
ool0oooo09P0oooo00240?ooo`030000003oool0000009T0oooo00230?ooo`040000003oool0oooo
000009T0oooo00220?ooo`<0000000<0oooo000000000000V03oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
    ImageRangeCache->{{{0, 287}, {177.313, 0}} -> {0, 0, 0, 0}}],
  StyleBox["     ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% PlotRegion
.1 .9 .1 .9 MPlotRegion
% Scaling calculations
0.5 0.434783 0.5 0.434783 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
.5 .50435 m
.49998 .50435 L
.49997 .50435 L
.49995 .50435 L
.49993 .50435 L
.4999 .50435 L
.49987 .50435 L
.49983 .50434 L
.4998 .50434 L
.49973 .50434 L
.49966 .50433 L
.49959 .50433 L
.49945 .50431 L
.4993 .50429 L
.49916 .50427 L
.49885 .50419 L
.49859 .50411 L
.49832 .50401 L
.4978 .50375 L
.49733 .50343 L
.49689 .50304 L
.49651 .5026 L
.49621 .50214 L
.49608 .50189 L
.49596 .50161 L
.49586 .50133 L
.49579 .50107 L
.49573 .50079 L
.4957 .50064 L
.49568 .5005 L
.49567 .50036 L
.49566 .50029 L
.49566 .50021 L
.49565 .50015 L
.49565 .50011 L
.49565 .50009 L
.49565 .50008 L
.49565 .50006 L
.49565 .50005 L
.49565 .50003 L
.49565 .50002 L
.49565 .5 L
.49565 .49998 L
.49565 .49996 L
.49565 .49995 L
.49565 .49993 L
.49565 .49991 L
.49565 .49988 L
.49565 .49985 L
.49566 .49981 L
Mistroke
.49566 .49974 L
.49566 .49968 L
.49568 .49954 L
.4957 .49939 L
.49572 .49924 L
.49575 .49908 L
.49582 .4988 L
.49591 .49853 L
.49602 .49825 L
.49627 .49777 L
.4966 .49729 L
.49698 .49688 L
.49743 .49649 L
.49791 .49619 L
.49841 .49595 L
.49868 .49586 L
.49897 .49578 L
.4991 .49575 L
.49924 .49572 L
.49936 .4957 L
.4995 .49568 L
.49963 .49567 L
.49974 .49566 L
.49981 .49566 L
.49987 .49565 L
.4999 .49565 L
.49992 .49565 L
.49993 .49565 L
.49995 .49565 L
.49997 .49565 L
.49998 .49565 L
.5 .49565 L
Mfstroke
.4999 .69449 m
.49915 .69449 L
.49846 .69448 L
.49767 .69448 L
.49692 .69446 L
.49559 .69444 L
.49415 .6944 L
.49256 .69435 L
.49087 .69427 L
.48785 .69411 L
.48473 .69389 L
.48182 .69364 L
.47519 .6929 L
.46847 .69192 L
.46234 .69081 L
.44871 .68761 L
.43708 .68403 L
.42466 .6793 L
.40137 .66763 L
.38062 .65354 L
.36076 .63578 L
.34408 .61626 L
.3306 .59555 L
.3248 .58444 L
.31927 .57184 L
.3148 .55937 L
.31147 .54777 L
.30879 .53555 L
.30765 .52875 L
.30679 .52228 L
.30618 .51612 L
.30595 .51301 L
.30575 .50956 L
.30562 .50663 L
.30557 .50498 L
.30556 .5042 L
.30554 .50347 L
.30553 .50277 L
.30552 .50214 L
.30552 .50144 L
.30551 .50068 L
.30551 .49996 L
.30551 .49918 L
.30552 .49843 L
.30552 .49775 L
.30553 .49695 L
.30555 .49618 L
.30558 .49475 L
.30563 .49321 L
.30569 .49154 L
Mistroke
.30585 .48852 L
.30603 .48573 L
.30661 .47934 L
.30745 .47257 L
.3085 .46604 L
.30987 .45903 L
.31302 .44648 L
.31695 .43428 L
.32196 .42173 L
.33314 .40008 L
.34792 .37876 L
.36471 .36028 L
.38499 .34316 L
.40656 .32943 L
.42884 .319 L
.44081 .31474 L
.45379 .31108 L
.45966 .30974 L
.46603 .3085 L
.47156 .3076 L
.47763 .3068 L
.48324 .30623 L
.48847 .30585 L
.49137 .3057 L
.494 .3056 L
.49546 .30556 L
.49623 .30555 L
.49704 .30553 L
.49775 .30552 L
.49853 .30552 L
.49924 .30551 L
.4999 .30551 L
Mfstroke
.49986 .77502 m
.4988 .77501 L
.49783 .77501 L
.49671 .775 L
.49565 .77498 L
.49377 .77494 L
.49172 .77489 L
.48947 .77481 L
.48709 .77471 L
.48282 .77448 L
.47841 .77417 L
.47429 .77381 L
.46492 .77277 L
.45541 .77138 L
.44675 .76981 L
.42748 .76528 L
.41102 .76022 L
.39346 .75354 L
.36054 .73703 L
.3312 .71711 L
.3031 .692 L
.27952 .66439 L
.26046 .63511 L
.25226 .6194 L
.24444 .60159 L
.23811 .58396 L
.23341 .56754 L
.22962 .55026 L
.22801 .54066 L
.2268 .53151 L
.22593 .5228 L
.2256 .51839 L
.22532 .51352 L
.22514 .50938 L
.22508 .50705 L
.22505 .50594 L
.22503 .50491 L
.22501 .50392 L
.225 .50303 L
.22499 .50203 L
.22499 .50097 L
.22498 .49994 L
.22499 .49883 L
.22499 .49779 L
.225 .49682 L
.22502 .49568 L
.22504 .4946 L
.22509 .49258 L
.22515 .4904 L
.22525 .48803 L
Mistroke
.22546 .48377 L
.22573 .47982 L
.22654 .47079 L
.22773 .46121 L
.22921 .45198 L
.23116 .44207 L
.2356 .42432 L
.24116 .40707 L
.24824 .38932 L
.26406 .35871 L
.28496 .32856 L
.3087 .30242 L
.33738 .27822 L
.36788 .2588 L
.39938 .24405 L
.4163 .23803 L
.43465 .23286 L
.44296 .23097 L
.45196 .22921 L
.45979 .22794 L
.46837 .22681 L
.47631 .22601 L
.4837 .22547 L
.48779 .22526 L
.49151 .22512 L
.49358 .22506 L
.49466 .22504 L
.49581 .22502 L
.49682 .225 L
.49792 .22499 L
.49892 .22499 L
.49986 .22498 L
Mfstroke
.49983 .83681 m
.49853 .83681 L
.49734 .8368 L
.49597 .83679 L
.49467 .83677 L
.49237 .83672 L
.48986 .83666 L
.48711 .83656 L
.48419 .83644 L
.47896 .83615 L
.47356 .83577 L
.46851 .83533 L
.45704 .83406 L
.44539 .83235 L
.43479 .83044 L
.41119 .82489 L
.39103 .8187 L
.36952 .81051 L
.3292 .79029 L
.29327 .7659 L
.25886 .73514 L
.22999 .70133 L
.20664 .66547 L
.19659 .64623 L
.18701 .62441 L
.17927 .60282 L
.17351 .58272 L
.16886 .56156 L
.16689 .54979 L
.16541 .53859 L
.16435 .52792 L
.16394 .52252 L
.1636 .51656 L
.16339 .51148 L
.1633 .50863 L
.16327 .50727 L
.16324 .50601 L
.16323 .5048 L
.16321 .50371 L
.1632 .50249 L
.16319 .50119 L
.16319 .49993 L
.16319 .49857 L
.1632 .49729 L
.16321 .4961 L
.16323 .49471 L
.16326 .49339 L
.16331 .49091 L
.1634 .48825 L
.16351 .48534 L
Mistroke
.16378 .48012 L
.1641 .47529 L
.1651 .46423 L
.16656 .4525 L
.16836 .44119 L
.17075 .42905 L
.1762 .40731 L
.183 .38619 L
.19167 .36445 L
.21104 .32696 L
.23664 .29004 L
.26571 .25803 L
.30083 .22839 L
.33819 .20461 L
.37677 .18654 L
.3975 .17917 L
.41997 .17284 L
.43014 .17052 L
.44117 .16837 L
.45075 .16681 L
.46127 .16543 L
.47098 .16444 L
.48003 .16378 L
.48505 .16352 L
.48961 .16335 L
.49213 .16328 L
.49346 .16325 L
.49487 .16323 L
.4961 .16321 L
.49745 .1632 L
.49868 .16319 L
.49983 .16319 L
Mfstroke
.49981 .88891 m
.4983 .8889 L
.49693 .88889 L
.49534 .88888 L
.49385 .88886 L
.49118 .88881 L
.4883 .88873 L
.48512 .88862 L
.48174 .88848 L
.4757 .88815 L
.46947 .88771 L
.46364 .8872 L
.45039 .88573 L
.43694 .88376 L
.4247 .88155 L
.39745 .87514 L
.37418 .86799 L
.34934 .85854 L
.30278 .83519 L
.26129 .80703 L
.22156 .77151 L
.18822 .73247 L
.16126 .69106 L
.14966 .66885 L
.1386 .64366 L
.12966 .61873 L
.12301 .59551 L
.11764 .57108 L
.11537 .55749 L
.11366 .54456 L
.11243 .53224 L
.11196 .52601 L
.11156 .51912 L
.11132 .51326 L
.11122 .50996 L
.11118 .5084 L
.11116 .50694 L
.11113 .50555 L
.11112 .50428 L
.1111 .50287 L
.1111 .50137 L
.11109 .49992 L
.1111 .49835 L
.11111 .49687 L
.11112 .4955 L
.11114 .4939 L
.11117 .49237 L
.11124 .48951 L
.11133 .48643 L
.11146 .48307 L
Mistroke
.11177 .47705 L
.11214 .47146 L
.11329 .4587 L
.11498 .44515 L
.11707 .43209 L
.11982 .41808 L
.12611 .39297 L
.13397 .36859 L
.14398 .34349 L
.16635 .30019 L
.1959 .25757 L
.22947 .2206 L
.27003 .18637 L
.31316 .15892 L
.35771 .13806 L
.38164 .12954 L
.40759 .12223 L
.41934 .11955 L
.43207 .11707 L
.44313 .11527 L
.45528 .11367 L
.4665 .11254 L
.47695 .11178 L
.48274 .11148 L
.488 .11128 L
.49092 .1112 L
.49245 .11117 L
.49408 .11114 L
.4955 .11112 L
.49706 .11111 L
.49848 .1111 L
.49981 .11109 L
Mfstroke
.5 .50435 m
.49996 .58767 L
.49994 .62669 L
.49992 .65461 L
.49991 .67736 L
.4999 .69873 L
.49989 .71733 L
.49988 .7355 L
.49987 .75176 L
.49987 .76647 L
.49986 .78128 L
.49985 .79484 L
.49985 .80731 L
.49984 .82005 L
.49983 .83186 L
.49983 .84396 L
.49982 .85523 L
.49982 .86575 L
.49981 .87661 L
.49981 .88679 L
.4998 .89731 L
.4998 .9072 L
.49979 .91649 L
.49979 .92614 L
.49978 .93478 L
s
.49915 .50426 m
.48286 .58598 L
.47524 .62424 L
.46978 .65162 L
.46533 .67394 L
.46116 .6949 L
.45752 .71314 L
.45397 .73096 L
.45079 .74691 L
.44792 .76134 L
.44502 .77586 L
.44237 .78915 L
.43993 .80138 L
.43744 .81388 L
.43514 .82546 L
.43277 .83733 L
.43057 .84838 L
.42851 .85869 L
.42639 .86935 L
.4244 .87933 L
.42234 .88965 L
.42041 .89934 L
.41859 .90845 L
.41671 .91792 L
.41502 .9264 L
s
.49833 .50402 m
.46643 .58099 L
.45149 .61703 L
.4408 .64282 L
.43209 .66384 L
.4239 .68359 L
.41678 .70077 L
.40982 .71755 L
.4036 .73258 L
.39796 .74617 L
.39229 .75984 L
.3871 .77237 L
.38233 .78389 L
.37745 .79566 L
.37293 .80656 L
.36829 .81775 L
.36398 .82816 L
.35995 .83787 L
.35579 .84791 L
.35189 .85731 L
.34786 .86703 L
.34408 .87616 L
.34052 .88474 L
.33682 .89366 L
.33352 .90165 L
s
.49758 .50362 m
.45128 .57289 L
.4296 .60533 L
.41409 .62854 L
.40145 .64746 L
.38957 .66523 L
.37923 .68069 L
.36914 .69579 L
.3601 .70932 L
.35193 .72155 L
.3437 .73386 L
.33617 .74513 L
.32924 .7555 L
.32215 .76609 L
.3156 .77591 L
.30887 .78597 L
.30261 .79534 L
.29676 .80408 L
.29072 .81312 L
.28507 .82158 L
.27922 .83033 L
.27373 .83854 L
.26857 .84627 L
.2632 .8543 L
.2584 .86148 L
s
.49692 .50308 m
.43801 .56199 L
.41042 .58958 L
.39068 .60932 L
.37459 .62541 L
.35947 .64053 L
.34632 .65368 L
.33348 .66652 L
.32198 .67802 L
.31157 .68843 L
.3011 .6989 L
.29152 .70848 L
.2827 .7173 L
.27369 .72631 L
.26534 .73466 L
.25678 .74322 L
.24881 .75119 L
.24138 .75862 L
.23369 .76631 L
.2265 .7735 L
.21906 .78094 L
.21207 .78793 L
.2055 .7945 L
.19867 .80133 L
.19256 .80744 L
s
.49638 .50242 m
.42711 .54872 L
.39467 .5704 L
.37146 .58591 L
.35254 .59855 L
.33477 .61043 L
.31931 .62077 L
.30421 .63086 L
.29068 .6399 L
.27845 .64807 L
.26614 .6563 L
.25487 .66383 L
.2445 .67076 L
.23391 .67785 L
.22409 .6844 L
.21403 .69113 L
.20466 .69739 L
.19592 .70324 L
.18688 .70928 L
.17842 .71493 L
.16967 .72078 L
.16146 .72627 L
.15373 .73143 L
.1457 .7368 L
.13852 .7416 L
s
.49598 .50167 m
.41901 .53357 L
.38297 .54851 L
.35718 .5592 L
.33616 .56791 L
.31641 .5761 L
.29923 .58322 L
.28245 .59018 L
.26742 .5964 L
.25383 .60204 L
.24016 .60771 L
.22763 .6129 L
.21611 .61767 L
.20434 .62255 L
.19344 .62707 L
.18225 .63171 L
.17184 .63602 L
.16213 .64005 L
.15209 .64421 L
.14269 .64811 L
.13297 .65214 L
.12384 .65592 L
.11526 .65948 L
.10634 .66318 L
.09835 .66648 L
s
.49574 .50085 m
.41402 .51714 L
.37576 .52476 L
.34838 .53022 L
.32606 .53467 L
.3051 .53884 L
.28686 .54248 L
.26904 .54603 L
.25309 .54921 L
.23866 .55208 L
.22414 .55498 L
.21085 .55763 L
.19862 .56007 L
.18612 .56256 L
.17454 .56486 L
.16267 .56723 L
.15162 .56943 L
.14131 .57149 L
.13065 .57361 L
.12067 .5756 L
.11035 .57766 L
.10066 .57959 L
.09155 .58141 L
.08208 .58329 L
.0736 .58498 L
s
.49565 .5 m
.41233 .50004 L
.37331 .50006 L
.34539 .50008 L
.32264 .50009 L
.30127 .5001 L
.28267 .50011 L
.2645 .50012 L
.24824 .50013 L
.23353 .50013 L
.21872 .50014 L
.20516 .50015 L
.19269 .50015 L
.17995 .50016 L
.16814 .50017 L
.15604 .50017 L
.14477 .50018 L
.13425 .50018 L
.12339 .50019 L
.11321 .50019 L
.10269 .5002 L
.0928 .5002 L
.08351 .50021 L
.07386 .50021 L
.06522 .50022 L
s
.49573 .49915 m
.414 .48295 L
.37573 .47536 L
.34835 .46993 L
.32603 .46551 L
.30506 .46135 L
.28681 .45773 L
.269 .4542 L
.25304 .45104 L
.23861 .44818 L
.22409 .4453 L
.21079 .44266 L
.19856 .44024 L
.18606 .43776 L
.17448 .43546 L
.1626 .43311 L
.15155 .43091 L
.14123 .42887 L
.13058 .42676 L
.1206 .42478 L
.11027 .42273 L
.10058 .42081 L
.09147 .419 L
.08199 .41712 L
.07352 .41544 L
s
.49598 .49834 m
.41897 .46651 L
.38292 .45161 L
.35712 .44094 L
.33609 .43225 L
.31634 .42409 L
.29915 .41698 L
.28236 .41004 L
.26733 .40383 L
.25373 .39821 L
.24005 .39255 L
.22752 .38737 L
.216 .38261 L
.20422 .37774 L
.19331 .37323 L
.18212 .36861 L
.1717 .3643 L
.16199 .36029 L
.15195 .35614 L
.14254 .35225 L
.13282 .34823 L
.12368 .34445 L
.1151 .34091 L
.10617 .33722 L
.09819 .33392 L
s
.49638 .49759 m
.42706 .45135 L
.3946 .42971 L
.37137 .41422 L
.35245 .40159 L
.33466 .38973 L
.31919 .37941 L
.30407 .36933 L
.29054 .36031 L
.2783 .35215 L
.26599 .34393 L
.25471 .33641 L
.24433 .32949 L
.23373 .32242 L
.22391 .31587 L
.21384 .30915 L
.20446 .3029 L
.19571 .29707 L
.18667 .29104 L
.17821 .28539 L
.16945 .27955 L
.16123 .27407 L
.1535 .26892 L
.14547 .26356 L
.13828 .25876 L
s
.49692 .49693 m
.43794 .43807 L
.41033 .41051 L
.39057 .39079 L
.37446 .37471 L
.35933 .35961 L
.34617 .34647 L
.33331 .33364 L
.3218 .32215 L
.31139 .31176 L
.3009 .3013 L
.29131 .29173 L
.28248 .28292 L
.27346 .27391 L
.26511 .26558 L
.25654 .25702 L
.24856 .24906 L
.24112 .24164 L
.23343 .23396 L
.22623 .22677 L
.21878 .21934 L
.21178 .21236 L
.20521 .20579 L
.19837 .19897 L
.19225 .19287 L
s
.49758 .49639 m
.45121 .42716 L
.4295 .39474 L
.41396 .37155 L
.4013 .35264 L
.3894 .33488 L
.37905 .31943 L
.36894 .30434 L
.35989 .29082 L
.35171 .2786 L
.34347 .2663 L
.33592 .25504 L
.32898 .24467 L
.32189 .23409 L
.31532 .22428 L
.30858 .21422 L
.30231 .20486 L
.29646 .19612 L
.29041 .18709 L
.28475 .17864 L
.27889 .1699 L
.27339 .16168 L
.26822 .15397 L
.26285 .14594 L
.25804 .13876 L
s
.49833 .49598 m
.46635 .41904 L
.45137 .38302 L
.44066 .35724 L
.43192 .33623 L
.42372 .31649 L
.41658 .29931 L
.40961 .28254 L
.40336 .26752 L
.39772 .25394 L
.39203 .24026 L
.38683 .22775 L
.38204 .21623 L
.37715 .20446 L
.37262 .19356 L
.36797 .18238 L
.36365 .17198 L
.35961 .16227 L
.35544 .15223 L
.35154 .14284 L
.3475 .13312 L
.3437 .12399 L
.34014 .11542 L
.33643 .1065 L
.33311 .09852 L
s
.49915 .49574 m
.48278 .41403 L
.47511 .37578 L
.46963 .34841 L
.46516 .3261 L
.46096 .30514 L
.45731 .2869 L
.45374 .26909 L
.45054 .25314 L
.44765 .23872 L
.44475 .2242 L
.44208 .21091 L
.43963 .19868 L
.43713 .18618 L
.43481 .17461 L
.43243 .16274 L
.43022 .15169 L
.42815 .14138 L
.42602 .13072 L
.42402 .12075 L
.42195 .11043 L
.42001 .10074 L
.41819 .09163 L
.41629 .08216 L
.41459 .07369 L
s
.49999 .49565 m
.49987 .41233 L
.49981 .37331 L
.49977 .34539 L
.49973 .32264 L
.4997 .30127 L
.49967 .28267 L
.49965 .2645 L
.49962 .24824 L
.4996 .23353 L
.49958 .21872 L
.49956 .20516 L
.49954 .19269 L
.49952 .17995 L
.4995 .16814 L
.49948 .15604 L
.49947 .14477 L
.49945 .13425 L
.49944 .12339 L
.49942 .11321 L
.4994 .10269 L
.49939 .0928 L
.49938 .08351 L
.49936 .07386 L
.49935 .06522 L
s
gsave
.97826 .54348 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.54348 .97826 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97826 .5 m
1 .5 L
s
% Start of user PostScript
1.1 0 1.15 0 MAarrowhead1
% End of user PostScript
.5 .97826 m
.5 1 L
s
% Start of user PostScript
0 1.1 0 1.15 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{178.313, 178.313},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002b0000/R000`400?l00000o`00003o/P3oool0
0;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3o
ool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00
F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool0
0`000000oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool00`000000
oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?oo
o`1G0?ooo`00F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?ooo`1G0?oo
o`00F03oool00`000000oooo0?ooo`1G0?ooo`00C03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo05L0oooo001<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0E`3o
ool004`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1G0?ooo`00C@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo05L0oooo00100?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1G0?ooo`00@@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0E`3oool00440oooo00<0
00000?ooo`3oool02@3oool<000005T0oooo00120?ooo`030000003oool0oooo00D0oooo1000000:
0?ooo`030000003oool0oooo05L0oooo00120?ooo`040000003oool0oooo0?ooo`@00000103oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo05L0oooo00120?ooo`040000003oool00000
000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1G0?ooo`00=P3oool00`00
0000oooo0?ooo`090?ooo`8000002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
05L0oooo000f0?ooo`030000003oool0oooo00L0oooo0P0000020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1G0?ooo`00=`3oool00`000000oooo
0?ooo`040?ooo`800000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0E`3oool003P0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`030000
003oool0oooo00P0oooo00@000000?ooo`3oool0oooo1P00001I0?ooo`00>@3oool00`000000oooo
000000090?ooo`030000003oool0oooo00@0oooo1`0000050?ooo`030000003oool0oooo05L0oooo
000i0?ooo`8000002P3oool010000000oooo0?ooo`3oool3000000<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1G0?ooo`00>03oool00`000000oooo0000000:0?ooo`040000003o
ool00000000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1G0?ooo`00;03o
ool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000X0oooo0P0000080?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0E`3oool002d0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P0000000`3oool000000?oo
o`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0E`3oool002h0oooo00<00000
0?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05L0oooo000_0?oo
o`050000003oool0oooo0?ooo`0000002@3oool010000000oooo0000000000060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1G0?ooo`00<03oool0
0`000000oooo0000000:0?ooo`800000203oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0E`3oool00340oooo00<000000?ooo`3oool0203oool00`00
0000oooo000000090?ooo`030000003oool0oooo00D0oooo2@00001I0?ooo`00<03oool00`000000
oooo000000080?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`030?oo
o`<000001`3oool00`000000oooo0?ooo`1G0?ooo`00;`3oool01@000000oooo0?ooo`3oool00000
00D0oooo0P0000040?ooo`030000003oool0oooo00L0oooo1@0000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0E`3oool002h0oooo00<000000?ooo`3oool00`3oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01@3oool2000000L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1G0?ooo`00;@3oool00`000000oooo0?ooo`050?ooo`<0
00002@3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0E`3oool002D0oooo0P0000050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05L0
oooo000W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0000000:0?ooo`<000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0E`3oool002P0oooo00@000000?ooo`3oool000002@3oool010000000oooo
0?ooo`0000080?ooo`<000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0E`3oool002T0oooo0P0000090?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1G0?ooo`00:P3oool3000000H0oooo
00<000000?ooo`3oool0103oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`1G0?ooo`00:@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
1P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05L0oooo000Y0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000002P3oool2000000P0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<00000F@3oool002P0oooo
00<000000?ooo`3oool0103oool3000000X0oooo0P0000080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3oool0E`3oool002P0oooo00<0
00000?ooo`3oool01@3oool2000000T0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`030?ooo`D0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`1G0?ooo`009`3o
ool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0E`3oool001l0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1G0?ooo`00803o
ool3000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`8000000`3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000F@3oool002<0oooo0P0000000`3oool00000
0?ooo`050?ooo`030000003oool0oooo00H0oooo0`0000090?ooo`030000003oool0oooo00<0oooo
0P0000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000001I0?ooo`00
9@3oool3000000D0oooo00<000000?ooo`3oool0203oool2000000T0oooo00<000000?ooo`3oool0
0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000005T0oooo000U0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0203oool010000000oooo0?ooo`0000090?ooo`8000001@3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`1G0?ooo`00903oool00`00
0000oooo0?ooo`020?ooo`@000002@3oool00`000000oooo0?ooo`020?ooo`8000001`3oool20000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000005T0oooo000T0?ooo`030000003oool0oooo00D0oooo0`0000060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo000000050?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo05L0oooo000S0?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`030000003oool0
oooo00H0oooo0P0000030?ooo`040000003oool0oooo0?ooo`800000103oool01@000000oooo0?oo
o`3oool0000000<0oooo00@000000?ooo`3oool00000F@3oool002<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000/0oooo0`0000060?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0E`3oool002<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`@000002`3oool2000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0E`3oool002<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00800000203oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0000001I0?ooo`008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool3000000D0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`050000
003oool0oooo0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000005T0oooo000L0?oo
o`<000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool200000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo000005T0oooo
000O0?ooo`H00000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0`00
00070?ooo`800000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000
oooo0000001I0?ooo`008P3oool00`000000oooo0?ooo`05000000T0oooo00<000000?ooo`3oool0
203oool00`000000oooo00000002000000H0oooo00<000000?ooo`3oool00P3oool02`000000oooo
0?ooo`3oool000000?ooo`000000oooo0000003oool0000005T0oooo000R0?ooo`030000003oool0
oooo00@0oooo1@0000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2
000000D0oooo0P0000030?ooo`060000003oool0oooo0000003oool000000P3oool2000005T0oooo
000R0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool6000000X0oooo00<0
00000?ooo`3oool0103oool2000000D0oooo0P0000020?ooo`070000003oool0oooo0000003oool0
00000?ooo`02000005T0oooo000Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo00000004000000@0oooo00<000000?ooo`3oool01`3oool3000000@0oooo
00@000000?ooo`3oool000000P3oool2000000030?ooo`000000000005T0oooo000Q0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`D00000
303oool2000000<0oooo0P0000001@3oool000000?ooo`000000oooo00<00000F@3oool00240oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
1000000;0?ooo`<000000P3oool8000005T0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`P00000
1P3oool200000080oooo00<000000?ooo`0000000`00001I0?ooo`008@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`D000000`3oool2000000030?ooo`000000000000<00000F@3oool00240oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03P3oool4000000040?ooo`00000000000?ooo`<00000?P3oool2000001T0oooo000Q
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0180oooo1@0000000`3oool000000?ooo`0m0?ooo`H000005@3oool0
0140ooooS`00000B0?ooo`008@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`T00000?P3oool7000001@0
oooo000Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo1P0000030?ooo`H00000?P3oool3000001P0oooo
000Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00H0oooo100000070?ooo`80000000<0oooo0000000000000`00
001I0?ooo`008@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`@000002@3oool2000000030?ooo`000000
000000D00000@P3oool4000001<0oooo000Q0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`080?ooo`H000002P3oool300000080oooo00D000000?oo
o`00000000000?ooo`0300000440oooo00@000000?ooo`3oool00000503oool00240oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo1@000000
0`3oool000000?ooo`0;0?ooo`8000000`3oool2000000030?ooo`000000oooo0080000000<0oooo
000000000000@@3oool010000000oooo0?ooo`00000D0?ooo`008@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo1@0000060?ooo`030000003oool0oooo00L0oooo0`000004
0?ooo`090000003oool0oooo0000003oool000000?ooo`000000oooo00800000@03oool200000003
0?ooo`000000000001@0oooo000R0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
oooo1P00000;0?ooo`030000003oool0oooo0080oooo100000050?ooo`8000000P3oool01@000000
oooo0000003oool000000080oooo0P00001I0?ooo`008P3oool00`000000oooo0?ooo`030?ooo`D0
00001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo008000001`3oool2000000<0
oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000F@3oool00280oooo00<0
00000?ooo`0000000`0000000`3oool000000?ooo`070?ooo`030000003oool0oooo00T0oooo0`00
00080?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`03
0000003oool0000005T0oooo000N0?ooo`H000001P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool2000000@0oooo00@000000?ooo`3oool0
00000P3oool01P000000oooo0?ooo`000000oooo000005T0oooo000L0?ooo`8000001@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool30000
00030?ooo`000000oooo00D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
00000080oooo00H000000?ooo`3oool000000?ooo`00001I0?ooo`008`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0oooo100000050?ooo`040000
003oool0oooo0?ooo`8000001@3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?oo
o`3oool0oooo0000003oool0000005T0oooo000S0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool3000000X0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000F@3oool002<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`800000303oool2000000H0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000005T0oooo
000T0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool200000080oooo00<0
00000?ooo`3oool01`3oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000F@3oool002@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo00000002000000@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000
oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000F@3oool002@0oooo00<000000?oo
o`3oool0103oool3000000L0oooo00<000000?ooo`3oool0103oool2000000D0oooo00@000000?oo
o`3oool000001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000
F@3oool002D0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000090?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool2000000D0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0E`3oool002D0oooo00<0
00000?ooo`0000000P0000030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
2@3oool2000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0E`3oool002@0oooo0`0000060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`0000002@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000005T0oooo000R0?ooo`80
000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`060?ooo`8000002@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000005T0oooo000O0?ooo`<00000103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo0P0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo05L0oooo000V0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo05L0oooo000W0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`000000
00001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1G0?ooo`00
9`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`030?ooo`D0000000<0oooo0000003oool00`3oool00`000000
oooo0?ooo`1G0?ooo`00:03oool00`000000oooo0?ooo`050?ooo`8000002P3oool2000000P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`L00000F@3oool002T0oooo00<0
00000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool01`3oool2000000P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0E`3oool002T0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1G0?ooo`00:P3o
ool3000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0E`3oool002T0oooo0`0000080?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1G0?ooo`00:03oool0
10000000oooo0?ooo`0000090?ooo`040000003oool0oooo000000P0oooo0P0000070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1G0?ooo`009P3o
ool2000000@0oooo00<000000?ooo`3oool01`3oool2000000X0oooo0`0000050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1G0?ooo`009@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo0P0000090?ooo`040000003oool0
oooo0?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0E`3oool002h0oooo00<000000?ooo`3oool00`3oool200000080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`80000000<0oooo0000003oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo05L0oooo000_0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo0P000006
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0E`3oool00300oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`000000100000000`3oool000000?ooo`050?ooo`030000003oool0oooo05L0oooo000a0?oo
o`800000203oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool01@3oool3
000000D0oooo00<000000?ooo`3oool0E`3oool00340oooo0P0000090?ooo`<00000203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H00000F@3oool00300oooo00@000000?ooo`3o
ool000002@3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo05L0oooo000_0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo05L0oooo000^0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0E`3oool002d0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
0P0000000`3oool000000?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
E`3oool003L0oooo0P0000000`3oool000000?ooo`090?ooo`<000001`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo05L0oooo000i0?ooo`8000002P3oool00`000000oooo0?ooo`03
000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1G0?ooo`00>@3oool30000
00T0oooo00<000000?ooo`3oool00`3oool3000000030?ooo`000000oooo00L0oooo00<000000?oo
o`3oool0E`3oool003T0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`070?oo
o`L000000`3oool00`000000oooo0?ooo`1G0?ooo`00>03oool00`000000oooo0?ooo`020?ooo`80
00001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo1000001I0?ooo`00
=`3oool00`000000oooo0?ooo`050?ooo`8000000`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0E`3oool003L0oooo00<000000?ooo`3oool01`3o
ool3000000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1G0?ooo`00=P3oool0
0`000000oooo0?ooo`0:0?ooo`8000002@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo05L0oooo00130?ooo`030000003oool00000008000001P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo05L0oooo00120?ooo`030000003oool0oooo00<0oooo100000000`3oool0
00000?ooo`090?ooo`030000003oool0oooo05L0oooo00120?ooo`030000003oool0oooo00L0oooo
100000080?ooo`030000003oool0oooo05L0oooo00110?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@00001I0?ooo`00@@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0E`3oool00440oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo05L0oooo001=0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0E`3oool004`0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1G0?ooo`00C03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05L0oooo001H
0?ooo`030000003oool0oooo05L0oooo001H0?ooo`030000003oool0oooo05L0oooo001F0?ooo`D0
0000E`3oool005H0oooo1@00001G0?ooo`00EP3oool4000005P0oooo001G0?ooo`<000000`3oool2
000005<0oooo001G0?ooo`<000000`3oool2000005<0oooo001G0?ooo`<000000P3oool010000000
oooo0?ooo`00001B0?ooo`00E`3oool200000080oooo0P0000020?ooo`800000D@3oool005P0oooo
00<000000?ooo`3oool0E`3oool005P0oooo00<000000?ooo`3oool0E`3oool00;80oooo002b0?oo
o`00/P3oool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3oool00;80oooo002b
0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00\
\>"],
    ImageRangeCache->{{{17.6875, 159.563}, {159.625, 17.75}} -> {-1, -1, 0, 
    0}}],
  "  ",
  StyleBox["\n\t\t\t(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  A portion of  ",
  Cell[BoxData[
      \(D\_2\)]],
  "  and its image under  ",
  Cell[BoxData[
      \(w = z\^\(1\/2\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6193 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.22045e-016 1 -0.147002 1 [
[ 0 0 0 0 ]
[ 1 .6193 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .6193 L
0 .6193 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.53377 .43588 m .533 .44741 L .40582 .45287 L p 1 1 1 r
F P
0 g
s
.533 .44741 m .53377 .43588 L .63796 .41773 L p 1 1 1 r
F P
0 g
s
.63796 .41773 m .66043 .42529 L .533 .44741 L p 1 1 1 r
F P
0 g
s
.66043 .42529 m .63796 .41773 L .73041 .38647 L p 1 1 1 r
F P
0 g
s
.73041 .38647 m .77451 .38707 L .66043 .42529 L p 1 1 1 r
F P
0 g
s
.42984 .44026 m .40582 .45287 L .29252 .44238 L p .996 .996 .996 r
F P
0 g
s
.40582 .45287 m .42984 .44026 L .53377 .43588 L p 1 1 1 r
F P
0 g
s
.53411 .55179 m .53341 .58944 L .4049 .5653 L p .963 .963 .963 r
F P
0 g
s
.53341 .58944 m .53411 .55179 L .63961 .55486 L p .94 .94 .94 r
F P
0 g
s
.63961 .55486 m .66278 .59356 L .53341 .58944 L p .94 .94 .94 r
F P
0 g
s
.42928 .53188 m .4049 .5653 L .29108 .52153 L p .983 .983 .983 r
F P
0 g
s
.4049 .5653 m .42928 .53188 L .53411 .55179 L p .963 .963 .963 r
F P
0 g
s
.66278 .59356 m .63961 .55486 L .73354 .54155 L p .916 .916 .916 r
F P
0 g
s
.73354 .54155 m .7791 .57815 L .66278 .59356 L p .916 .916 .916 r
F P
0 g
s
.53458 .42381 m .53377 .43588 L .42984 .44026 L p 1 1 1 r
F P
0 g
s
.53377 .43588 m .53458 .42381 L .61449 .40983 L p 1 1 1 r
F P
0 g
s
.61449 .40983 m .63796 .41773 L .53377 .43588 L p 1 1 1 r
F P
0 g
s
.63796 .41773 m .61449 .40983 L .68473 .38585 L p 1 1 1 r
F P
0 g
s
.68473 .38585 m .73041 .38647 L .63796 .41773 L p 1 1 1 r
F P
0 g
s
.77451 .38707 m .73041 .38647 L .79911 .34432 L p 1 1 1 r
F P
0 g
s
.79911 .34432 m .86109 .33496 L .77451 .38707 L p 1 1 1 r
F P
0 g
s
.29252 .44238 m .33818 .43146 L .42984 .44026 L p .996 .996 .996 r
F P
0 g
s
.45491 .42709 m .42984 .44026 L .33818 .43146 L p .996 .996 .996 r
F P
0 g
s
.42984 .44026 m .45491 .42709 L .53458 .42381 L p 1 1 1 r
F P
0 g
s
.53485 .51251 m .53411 .55179 L .42928 .53188 L p .963 .963 .963 r
F P
0 g
s
.53411 .55179 m .53485 .51251 L .61553 .51463 L p .94 .94 .94 r
F P
0 g
s
.61553 .51463 m .63961 .55486 L .53411 .55179 L p .94 .94 .94 r
F P
0 g
s
.33818 .43146 m .29252 .44238 L .20732 .41805 L p .994 .994 .994 r
F P
0 g
s
.29108 .52153 m .33727 .4957 L .42928 .53188 L p .983 .983 .983 r
F P
0 g
s
.45464 .49711 m .42928 .53188 L .33727 .4957 L p .983 .983 .983 r
F P
0 g
s
.42928 .53188 m .45464 .49711 L .53485 .51251 L p .963 .963 .963 r
F P
0 g
s
.63961 .55486 m .61553 .51463 L .68664 .50387 L p .916 .916 .916 r
F P
0 g
s
.68664 .50387 m .73354 .54155 L .63961 .55486 L p .916 .916 .916 r
F P
0 g
s
.33727 .4957 m .29108 .52153 L .20625 .45977 L p .995 .995 .995 r
F P
0 g
s
.53542 .41114 m .53458 .42381 L .45491 .42709 L p 1 1 1 r
F P
0 g
s
.53458 .42381 m .53542 .41114 L .58993 .40157 L p 1 1 1 r
F P
0 g
s
.58993 .40157 m .61449 .40983 L .53458 .42381 L p 1 1 1 r
F P
0 g
s
.7791 .57815 m .73354 .54155 L .80356 .51346 L p .893 .893 .893 r
F P
0 g
s
.80356 .51346 m .86776 .5447 L .7791 .57815 L p .893 .893 .893 r
F P
0 g
s
.73041 .38647 m .68473 .38585 L .73578 .35388 L p 1 1 1 r
F P
0 g
s
.73578 .35388 m .79911 .34432 L .73041 .38647 L p 1 1 1 r
F P
0 g
s
.61449 .40983 m .58993 .40157 L .63738 .38521 L p 1 1 1 r
F P
0 g
s
.63738 .38521 m .68473 .38585 L .61449 .40983 L p 1 1 1 r
F P
0 g
s
.20732 .41805 m .27084 .41147 L .33818 .43146 L p .994 .994 .994 r
F P
0 g
s
.3854 .42017 m .33818 .43146 L .27084 .41147 L p .994 .994 .994 r
F P
0 g
s
.33818 .43146 m .3854 .42017 L .45491 .42709 L p .996 .996 .996 r
F P
0 g
s
.48112 .41332 m .45491 .42709 L .3854 .42017 L p .996 .996 .996 r
F P
0 g
s
.45491 .42709 m .48112 .41332 L .53542 .41114 L p 1 1 1 r
F P
0 g
s
.53561 .47151 m .53485 .51251 L .45464 .49711 L p .963 .963 .963 r
F P
0 g
s
.53485 .51251 m .53561 .47151 L .59049 .47279 L p .94 .94 .94 r
F P
0 g
s
.59049 .47279 m .61553 .51463 L .53485 .51251 L p .94 .94 .94 r
F P
0 g
s
.20625 .45977 m .27016 .44511 L .33727 .4957 L p .995 .995 .995 r
F P
0 g
s
.38491 .46905 m .33727 .4957 L .27016 .44511 L p .995 .995 .995 r
F P
0 g
s
.33727 .4957 m .38491 .46905 L .45464 .49711 L p .983 .983 .983 r
F P
0 g
s
.48104 .46091 m .45464 .49711 L .38491 .46905 L p .983 .983 .983 r
F P
0 g
s
.45464 .49711 m .48104 .46091 L .53561 .47151 L p .963 .963 .963 r
F P
0 g
s
.61553 .51463 m .59049 .47279 L .63834 .46506 L p .916 .916 .916 r
F P
0 g
s
.63834 .46506 m .68664 .50387 L .61553 .51463 L p .916 .916 .916 r
F P
0 g
s
.73354 .54155 m .68664 .50387 L .73843 .48176 L p .893 .893 .893 r
F P
0 g
s
.73843 .48176 m .80356 .51346 L .73354 .54155 L p .893 .893 .893 r
F P
0 g
s
.68473 .38585 m .63738 .38521 L .67106 .36365 L p 1 1 1 r
F P
0 g
s
.67106 .36365 m .73578 .35388 L .68473 .38585 L p 1 1 1 r
F P
0 g
s
.86109 .33496 m .79911 .34432 L .83266 .29545 L p 1 1 1 r
F P
0 g
s
.83266 .29545 m .9058 .27356 L .86109 .33496 L p 1 1 1 r
F P
0 g
s
.27084 .41147 m .33555 .40476 L .3854 .42017 L p .994 .994 .994 r
F P
0 g
s
.43426 .40848 m .3854 .42017 L .33555 .40476 L p .994 .994 .994 r
F P
0 g
s
.3854 .42017 m .43426 .40848 L .48112 .41332 L p .996 .996 .996 r
F P
0 g
s
.53631 .39784 m .53542 .41114 L .48112 .41332 L p 1 1 1 r
F P
0 g
s
.53542 .41114 m .53631 .39784 L .56421 .39292 L p 1 1 1 r
F P
0 g
s
.56421 .39292 m .58993 .40157 L .53542 .41114 L p 1 1 1 r
F P
0 g
s
.27016 .44511 m .33519 .4302 L .38491 .46905 L p .995 .995 .995 r
F P
0 g
s
.43407 .44156 m .38491 .46905 L .33519 .4302 L p .995 .995 .995 r
F P
0 g
s
.38491 .46905 m .43407 .44156 L .48104 .46091 L p .983 .983 .983 r
F P
0 g
s
.27084 .41147 m .20732 .41805 L .16475 .38385 L p .996 .996 .996 r
F P
0 g
s
.58993 .40157 m .56421 .39292 L .58825 .38454 L p 1 1 1 r
F P
0 g
s
.58825 .38454 m .63738 .38521 L .58993 .40157 L p 1 1 1 r
F P
0 g
s
.50854 .39893 m .48112 .41332 L .43426 .40848 L p .996 .996 .996 r
F P
0 g
s
.48112 .41332 m .50854 .39893 L .53631 .39784 L p 1 1 1 r
F P
0 g
s
.68664 .50387 m .63834 .46506 L .67235 .4496 L p .893 .893 .893 r
F P
0 g
s
.67235 .4496 m .73843 .48176 L .68664 .50387 L p .893 .893 .893 r
F P
0 g
s
.53641 .42867 m .53561 .47151 L .48104 .46091 L p .963 .963 .963 r
F P
0 g
s
.53561 .47151 m .53641 .42867 L .56441 .42923 L p .94 .94 .94 r
F P
0 g
s
.56441 .42923 m .59049 .47279 L .53561 .47151 L p .94 .94 .94 r
F P
0 g
s
.79911 .34432 m .73578 .35388 L .75924 .31742 L p 1 1 1 r
F P
0 g
s
.75924 .31742 m .83266 .29545 L .79911 .34432 L p 1 1 1 r
F P
0 g
s
.27016 .44511 m .20625 .45977 L .16475 .38385 L p 1 1 1 r
F P
0 g
s
.50856 .42319 m .48104 .46091 L .43407 .44156 L p .983 .983 .983 r
F P
0 g
s
.48104 .46091 m .50856 .42319 L .53641 .42867 L p .963 .963 .963 r
F P
0 g
s
.59049 .47279 m .56441 .42923 L .58856 .42507 L p .916 .916 .916 r
F P
0 g
s
.58856 .42507 m .63834 .46506 L .59049 .47279 L p .916 .916 .916 r
F P
0 g
s
.16475 .38385 m .23925 .38385 L .27084 .41147 L p .996 .996 .996 r
F P
0 g
s
.33555 .40476 m .27084 .41147 L .23925 .38385 L p .996 .996 .996 r
F P
0 g
s
.63738 .38521 m .58825 .38454 L .6049 .37364 L p 1 1 1 r
F P
0 g
s
.6049 .37364 m .67106 .36365 L .63738 .38521 L p 1 1 1 r
F P
0 g
s
.86776 .5447 m .80356 .51346 L .83789 .47364 L p .874 .874 .874 r
F P
0 g
s
.83789 .47364 m .91379 .49631 L .86776 .5447 L p .874 .874 .874 r
F P
0 g
s
.33555 .40476 m .4015 .39792 L .43426 .40848 L p .994 .994 .994 r
F P
0 g
s
.48484 .39638 m .43426 .40848 L .4015 .39792 L p .994 .994 .994 r
F P
0 g
s
.43426 .40848 m .48484 .39638 L .50854 .39893 L p .996 .996 .996 r
F P
0 g
s
.16475 .38385 m .23925 .38385 L .27016 .44511 L p 1 1 1 r
F P
0 g
s
.33519 .4302 m .27016 .44511 L .23925 .38385 L p 1 1 1 r
F P
0 g
s
.73578 .35388 m .67106 .36365 L .68553 .33948 L p 1 1 1 r
F P
0 g
s
.68553 .33948 m .75924 .31742 L .73578 .35388 L p 1 1 1 r
F P
0 g
s
.33519 .4302 m .40136 .41502 L .43407 .44156 L p .995 .995 .995 r
F P
0 g
s
.48482 .41317 m .43407 .44156 L .40136 .41502 L p .995 .995 .995 r
F P
0 g
s
.43407 .44156 m .48482 .41317 L .50856 .42319 L p .983 .983 .983 r
F P
0 g
s
.63834 .46506 m .58856 .42507 L .6053 .41697 L p .893 .893 .893 r
F P
0 g
s
.6053 .41697 m .67235 .4496 L .63834 .46506 L p .893 .893 .893 r
F P
0 g
s
.80356 .51346 m .73843 .48176 L .76229 .45106 L p .874 .874 .874 r
F P
0 g
s
.76229 .45106 m .83789 .47364 L .80356 .51346 L p .874 .874 .874 r
F P
0 g
s
.23925 .38385 m .31375 .38385 L .33555 .40476 L p .996 .996 .996 r
F P
0 g
s
.4015 .39792 m .33555 .40476 L .31375 .38385 L p .996 .996 .996 r
F P
0 g
s
.23925 .38385 m .31375 .38385 L .33519 .4302 L p 1 1 1 r
F P
0 g
s
.40136 .41502 m .33519 .4302 L .31375 .38385 L p 1 1 1 r
F P
0 g
s
.53725 .38385 m .53631 .39784 L .50854 .39893 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .56421 .39292 L .53631 .39784 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .58825 .38454 L .56421 .39292 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .50854 .39893 L .48484 .39638 L closepath p .996 .996 .996 r
F P
0 g
s
.53725 .38385 m .53641 .42867 L .50856 .42319 L closepath p .963 .963 .963 r
F P
0 g
s
.53725 .38385 m .56441 .42923 L .53641 .42867 L closepath p .94 .94 .94 r
F P
0 g
s
.67106 .36365 m .6049 .37364 L .61153 .36162 L p 1 1 1 r
F P
0 g
s
.61153 .36162 m .68553 .33948 L .67106 .36365 L p 1 1 1 r
F P
0 g
s
.73843 .48176 m .67235 .4496 L .68698 .42857 L p .874 .874 .874 r
F P
0 g
s
.68698 .42857 m .76229 .45106 L .73843 .48176 L p .874 .874 .874 r
F P
0 g
s
.53725 .38385 m .50856 .42319 L .48482 .41317 L closepath p .983 .983 .983 r
F P
0 g
s
.53725 .38385 m .58856 .42507 L .56441 .42923 L closepath p .916 .916 .916 r
F P
0 g
s
.31375 .38385 m .38825 .38385 L .4015 .39792 L p .996 .996 .996 r
F P
0 g
s
.46872 .39095 m .4015 .39792 L .38825 .38385 L p .996 .996 .996 r
F P
0 g
s
.4015 .39792 m .46872 .39095 L .48484 .39638 L p .994 .994 .994 r
F P
0 g
s
.53725 .38385 m .6049 .37364 L .58825 .38454 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .48484 .39638 L .46872 .39095 L closepath p .994 .994 .994 r
F P
0 g
s
.31375 .38385 m .38825 .38385 L .40136 .41502 L p 1 1 1 r
F P
0 g
s
.4687 .39957 m .40136 .41502 L .38825 .38385 L p 1 1 1 r
F P
0 g
s
.40136 .41502 m .4687 .39957 L .48482 .41317 L p .995 .995 .995 r
F P
0 g
s
.53725 .38385 m .48482 .41317 L .4687 .39957 L closepath p .995 .995 .995 r
F P
0 g
s
.53725 .38385 m .6053 .41697 L .58856 .42507 L closepath p .893 .893 .893 r
F P
0 g
s
.67235 .4496 m .6053 .41697 L .61197 .40617 L p .874 .874 .874 r
F P
0 g
s
.61197 .40617 m .68698 .42857 L .67235 .4496 L p .874 .874 .874 r
F P
0 g
s
.53725 .38385 m .61153 .36162 L .6049 .37364 L closepath p 1 1 1 r
F P
0 g
s
.9058 .27356 m .83266 .29545 L .82213 .24631 L p 1 1 1 r
F P
0 g
s
.82213 .24631 m .8961 .2106 L .9058 .27356 L p 1 1 1 r
F P
0 g
s
.38825 .38385 m .46275 .38385 L .46872 .39095 L p .996 .996 .996 r
F P
0 g
s
.53725 .38385 m .46872 .39095 L .46275 .38385 L closepath p .996 .996 .996 r
F P
0 g
s
.38825 .38385 m .46275 .38385 L .4687 .39957 L p 1 1 1 r
F P
0 g
s
.53725 .38385 m .4687 .39957 L .46275 .38385 L closepath p 1 1 1 r
F P
0 g
s
.83266 .29545 m .75924 .31742 L .74929 .28148 L p 1 1 1 r
F P
0 g
s
.74929 .28148 m .82213 .24631 L .83266 .29545 L p 1 1 1 r
F P
0 g
s
.53725 .38385 m .61197 .40617 L .6053 .41697 L closepath p .874 .874 .874 r
F P
0 g
s
.75924 .31742 m .68553 .33948 L .67755 .31612 L p 1 1 1 r
F P
0 g
s
.67755 .31612 m .74929 .28148 L .75924 .31742 L p 1 1 1 r
F P
0 g
s
.68553 .33948 m .61153 .36162 L .60687 .35024 L p 1 1 1 r
F P
0 g
s
.60687 .35024 m .67755 .31612 L .68553 .33948 L p 1 1 1 r
F P
0 g
s
.53725 .38385 m .60687 .35024 L .61153 .36162 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .59134 .34133 L .60687 .35024 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .56717 .33653 L .59134 .34133 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .53813 .33692 L .56717 .33653 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .50893 .34279 L .53813 .33692 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .48431 .35354 L .50893 .34279 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .46814 .36784 L .48431 .35354 L closepath p 1 1 1 r
F P
0 g
s
.17872 .30081 m .25309 .31804 L .23925 .38385 L p 1 1 1 r
F P
0 g
s
.23925 .38385 m .16475 .38385 L .17872 .30081 L p 1 1 1 r
F P
0 g
s
.25309 .31804 m .32609 .33495 L .31375 .38385 L p 1 1 1 r
F P
0 g
s
.31375 .38385 m .23925 .38385 L .25309 .31804 L p 1 1 1 r
F P
0 g
s
.32609 .33495 m .39776 .35154 L .38825 .38385 L p 1 1 1 r
F P
0 g
s
.38825 .38385 m .31375 .38385 L .32609 .33495 L p 1 1 1 r
F P
0 g
s
.39776 .35154 m .46814 .36784 L .46275 .38385 L p 1 1 1 r
F P
0 g
s
.46275 .38385 m .38825 .38385 L .39776 .35154 L p 1 1 1 r
F P
0 g
s
.53725 .38385 m .46275 .38385 L .46814 .36784 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .60729 .39429 L .61197 .40617 L closepath p .86 .86 .86 r
F P
0 g
s
.53725 .38385 m .59168 .38313 L .60729 .39429 L closepath p .854 .854 .854 r
F P
0 g
s
.53725 .38385 m .56739 .37433 L .59168 .38313 L closepath p .863 .863 .863 r
F P
0 g
s
.53725 .38385 m .53824 .36912 L .56739 .37433 L closepath p .888 .888 .888 r
F P
0 g
s
.53725 .38385 m .50895 .36804 L .53824 .36912 L closepath p .926 .926 .926 r
F P
0 g
s
.53725 .38385 m .48429 .37086 L .50895 .36804 L closepath p .963 .963 .963 r
F P
0 g
s
.53725 .38385 m .46811 .37661 L .48429 .37086 L closepath p .987 .987 .987 r
F P
0 g
s
.17743 .34615 m .25231 .354 L .23925 .38385 L p .996 .996 .996 r
F P
0 g
s
.23925 .38385 m .16475 .38385 L .17743 .34615 L p .996 .996 .996 r
F P
0 g
s
.25231 .354 m .32568 .36168 L .31375 .38385 L p .996 .996 .996 r
F P
0 g
s
.31375 .38385 m .23925 .38385 L .25231 .354 L p .996 .996 .996 r
F P
0 g
s
.32568 .36168 m .3976 .36922 L .38825 .38385 L p .996 .996 .996 r
F P
0 g
s
.38825 .38385 m .31375 .38385 L .32568 .36168 L p .996 .996 .996 r
F P
0 g
s
.3976 .36922 m .46811 .37661 L .46275 .38385 L p .996 .996 .996 r
F P
0 g
s
.46275 .38385 m .38825 .38385 L .3976 .36922 L p .996 .996 .996 r
F P
0 g
s
.53725 .38385 m .46275 .38385 L .46811 .37661 L closepath p .996 .996 .996 r
F P
0 g
s
.68698 .42857 m .61197 .40617 L .60729 .39429 L p .86 .86 .86 r
F P
0 g
s
.76229 .45106 m .68698 .42857 L .67894 .40498 L p .86 .86 .86 r
F P
0 g
s
.60729 .39429 m .67894 .40498 L .68698 .42857 L p .86 .86 .86 r
F P
0 g
s
.83789 .47364 m .76229 .45106 L .75225 .41591 L p .86 .86 .86 r
F P
0 g
s
.67894 .40498 m .75225 .41591 L .76229 .45106 L p .86 .86 .86 r
F P
0 g
s
.67755 .31612 m .60687 .35024 L .59134 .34133 L p 1 1 1 r
F P
0 g
s
.91379 .49631 m .83789 .47364 L .8273 .4271 L p .86 .86 .86 r
F P
0 g
s
.75225 .41591 m .8273 .4271 L .83789 .47364 L p .86 .86 .86 r
F P
0 g
s
.42957 .3222 m .48431 .35354 L .46814 .36784 L p 1 1 1 r
F P
0 g
s
.46814 .36784 m .39776 .35154 L .42957 .3222 L p 1 1 1 r
F P
0 g
s
.42935 .35738 m .48429 .37086 L .46811 .37661 L p .987 .987 .987 r
F P
0 g
s
.46811 .37661 m .3976 .36922 L .42935 .35738 L p .987 .987 .987 r
F P
0 g
s
.8273 .4271 m .90413 .43856 L .91379 .49631 L p .86 .86 .86 r
F P
0 g
s
.67894 .40498 m .60729 .39429 L .59168 .38313 L p .854 .854 .854 r
F P
0 g
s
.74929 .28148 m .67755 .31612 L .64716 .29746 L p 1 1 1 r
F P
0 g
s
.59134 .34133 m .64716 .29746 L .67755 .31612 L p 1 1 1 r
F P
0 g
s
.64716 .29746 m .59134 .34133 L .56717 .33653 L p 1 1 1 r
F P
0 g
s
.47934 .29988 m .50893 .34279 L .48431 .35354 L p 1 1 1 r
F P
0 g
s
.48431 .35354 m .42957 .3222 L .47934 .29988 L p 1 1 1 r
F P
0 g
s
.37292 .28977 m .42957 .3222 L .39776 .35154 L p 1 1 1 r
F P
0 g
s
.39776 .35154 m .32609 .33495 L .37292 .28977 L p 1 1 1 r
F P
0 g
s
.47925 .35145 m .50895 .36804 L .48429 .37086 L p .963 .963 .963 r
F P
0 g
s
.48429 .37086 m .42935 .35738 L .47925 .35145 L p .963 .963 .963 r
F P
0 g
s
.59168 .38313 m .64826 .38238 L .67894 .40498 L p .854 .854 .854 r
F P
0 g
s
.64826 .38238 m .59168 .38313 L .56739 .37433 L p .863 .863 .863 r
F P
0 g
s
.37232 .34339 m .42935 .35738 L .3976 .36922 L p .987 .987 .987 r
F P
0 g
s
.3976 .36922 m .32568 .36168 L .37232 .34339 L p .987 .987 .987 r
F P
0 g
s
.56717 .33653 m .59839 .28715 L .64716 .29746 L p 1 1 1 r
F P
0 g
s
.59839 .28715 m .56717 .33653 L .53813 .33692 L p 1 1 1 r
F P
0 g
s
.53905 .28773 m .53813 .33692 L .50893 .34279 L p 1 1 1 r
F P
0 g
s
.50893 .34279 m .47934 .29988 L .53905 .28773 L p 1 1 1 r
F P
0 g
s
.82213 .24631 m .74929 .28148 L .70478 .25217 L p 1 1 1 r
F P
0 g
s
.64716 .29746 m .70478 .25217 L .74929 .28148 L p 1 1 1 r
F P
0 g
s
.75225 .41591 m .67894 .40498 L .64826 .38238 L p .854 .854 .854 r
F P
0 g
s
.53813 .33692 m .53905 .28773 L .59839 .28715 L p 1 1 1 r
F P
0 g
s
.53927 .35359 m .53824 .36912 L .50895 .36804 L p .926 .926 .926 r
F P
0 g
s
.50895 .36804 m .47925 .35145 L .53927 .35359 L p .926 .926 .926 r
F P
0 g
s
.56739 .37433 m .59906 .36433 L .64826 .38238 L p .863 .863 .863 r
F P
0 g
s
.59906 .36433 m .56739 .37433 L .53824 .36912 L p .888 .888 .888 r
F P
0 g
s
.53824 .36912 m .53927 .35359 L .59906 .36433 L p .888 .888 .888 r
F P
0 g
s
.31427 .2562 m .37292 .28977 L .32609 .33495 L p 1 1 1 r
F P
0 g
s
.32609 .33495 m .25309 .31804 L .31427 .2562 L p 1 1 1 r
F P
0 g
s
.31308 .32885 m .37232 .34339 L .32568 .36168 L p .987 .987 .987 r
F P
0 g
s
.32568 .36168 m .25231 .354 L .31308 .32885 L p .987 .987 .987 r
F P
0 g
s
.8961 .2106 m .82213 .24631 L .7643 .20538 L p 1 1 1 r
F P
0 g
s
.70478 .25217 m .7643 .20538 L .82213 .24631 L p 1 1 1 r
F P
0 g
s
.70478 .25217 m .64716 .29746 L .59839 .28715 L p 1 1 1 r
F P
0 g
s
.4484 .25501 m .47934 .29988 L .42957 .3222 L p 1 1 1 r
F P
0 g
s
.42957 .3222 m .37292 .28977 L .4484 .25501 L p 1 1 1 r
F P
0 g
s
.8273 .4271 m .75225 .41591 L .70713 .38161 L p .854 .854 .854 r
F P
0 g
s
.64826 .38238 m .70713 .38161 L .75225 .41591 L p .854 .854 .854 r
F P
0 g
s
.25351 .22142 m .31427 .2562 L .25309 .31804 L p 1 1 1 r
F P
0 g
s
.25309 .31804 m .17872 .30081 L .25351 .22142 L p 1 1 1 r
F P
0 g
s
.44804 .33402 m .47925 .35145 L .42935 .35738 L p .963 .963 .963 r
F P
0 g
s
.42935 .35738 m .37232 .34339 L .44804 .33402 L p .963 .963 .963 r
F P
0 g
s
.7643 .20538 m .82581 .15703 L .8961 .2106 L p 1 1 1 r
F P
0 g
s
.70713 .38161 m .64826 .38238 L .59906 .36433 L p .863 .863 .863 r
F P
0 g
s
.25149 .31374 m .31308 .32885 L .25231 .354 L p .987 .987 .987 r
F P
0 g
s
.25231 .354 m .17743 .34615 L .25149 .31374 L p .987 .987 .987 r
F P
0 g
s
.59839 .28715 m .631 .23557 L .70478 .25217 L p 1 1 1 r
F P
0 g
s
.631 .23557 m .59839 .28715 L .53905 .28773 L p 1 1 1 r
F P
0 g
s
.54001 .23611 m .53905 .28773 L .47934 .29988 L p 1 1 1 r
F P
0 g
s
.47934 .29988 m .4484 .25501 L .54001 .23611 L p 1 1 1 r
F P
0 g
s
.90413 .43856 m .8273 .4271 L .76842 .3808 L p .854 .854 .854 r
F P
0 g
s
.70713 .38161 m .76842 .3808 L .8273 .4271 L p .854 .854 .854 r
F P
0 g
s
.53905 .28773 m .54001 .23611 L .631 .23557 L p 1 1 1 r
F P
0 g
s
.7643 .20538 m .70478 .25217 L .631 .23557 L p 1 1 1 r
F P
0 g
s
.54037 .33719 m .53927 .35359 L .47925 .35145 L p .926 .926 .926 r
F P
0 g
s
.47925 .35145 m .44804 .33402 L .54037 .33719 L p .926 .926 .926 r
F P
0 g
s
.59906 .36433 m .63237 .35381 L .70713 .38161 L p .863 .863 .863 r
F P
0 g
s
.63237 .35381 m .59906 .36433 L .53927 .35359 L p .888 .888 .888 r
F P
0 g
s
.416 .20804 m .4484 .25501 L .37292 .28977 L p 1 1 1 r
F P
0 g
s
.37292 .28977 m .31427 .2562 L .416 .20804 L p 1 1 1 r
F P
0 g
s
.53927 .35359 m .54037 .33719 L .63237 .35381 L p .888 .888 .888 r
F P
0 g
s
.4152 .31568 m .44804 .33402 L .37232 .34339 L p .963 .963 .963 r
F P
0 g
s
.37232 .34339 m .31308 .32885 L .4152 .31568 L p .963 .963 .963 r
F P
0 g
s
.76842 .3808 m .8323 .37995 L .90413 .43856 L p .854 .854 .854 r
F P
0 g
s
.76842 .3808 m .70713 .38161 L .63237 .35381 L p .863 .863 .863 r
F P
0 g
s
.82581 .15703 m .7643 .20538 L .6651 .18163 L p 1 1 1 r
F P
0 g
s
.631 .23557 m .6651 .18163 L .7643 .20538 L p 1 1 1 r
F P
0 g
s
.6651 .18163 m .631 .23557 L .54001 .23611 L p 1 1 1 r
F P
0 g
s
.54103 .18186 m .54001 .23611 L .4484 .25501 L p 1 1 1 r
F P
0 g
s
.4484 .25501 m .416 .20804 L .54103 .18186 L p 1 1 1 r
F P
0 g
s
.38205 .1588 m .416 .20804 L .31427 .2562 L p 1 1 1 r
F P
0 g
s
.31427 .2562 m .25351 .22142 L .38205 .1588 L p 1 1 1 r
F P
0 g
s
.54001 .23611 m .54103 .18186 L .6651 .18163 L p 1 1 1 r
F P
0 g
s
.54153 .31986 m .54037 .33719 L .44804 .33402 L p .926 .926 .926 r
F P
0 g
s
.44804 .33402 m .4152 .31568 L .54153 .31986 L p .926 .926 .926 r
F P
0 g
s
.3806 .29635 m .4152 .31568 L .31308 .32885 L p .963 .963 .963 r
F P
0 g
s
.31308 .32885 m .25149 .31374 L .3806 .29635 L p .963 .963 .963 r
F P
0 g
s
.63237 .35381 m .66747 .34272 L .76842 .3808 L p .863 .863 .863 r
F P
0 g
s
.66747 .34272 m .63237 .35381 L .54037 .33719 L p .888 .888 .888 r
F P
0 g
s
.8323 .37995 m .76842 .3808 L .66747 .34272 L p .863 .863 .863 r
F P
0 g
s
.6651 .18163 m .7008 .12517 L .82581 .15703 L p 1 1 1 r
F P
0 g
s
.54037 .33719 m .54153 .31986 L .66747 .34272 L p .888 .888 .888 r
F P
0 g
s
.7008 .12517 m .6651 .18163 L .54103 .18186 L p 1 1 1 r
F P
0 g
s
.54209 .1248 m .54103 .18186 L .416 .20804 L p 1 1 1 r
F P
0 g
s
.416 .20804 m .38205 .1588 L .54209 .1248 L p 1 1 1 r
F P
0 g
s
.54103 .18186 m .54209 .1248 L .7008 .12517 L p 1 1 1 r
F P
0 g
s
.54276 .30149 m .54153 .31986 L .4152 .31568 L p .926 .926 .926 r
F P
0 g
s
.4152 .31568 m .3806 .29635 L .54276 .30149 L p .926 .926 .926 r
F P
0 g
s
.66747 .34272 m .7045 .33103 L .8323 .37995 L p .863 .863 .863 r
F P
0 g
s
.7045 .33103 m .66747 .34272 L .54153 .31986 L p .888 .888 .888 r
F P
0 g
s
.54153 .31986 m .54276 .30149 L .7045 .33103 L p .888 .888 .888 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 178.313},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/R000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00V@3ooola000005H0oooo002E0?ooo`@000000P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00@00000DP3oool00900oooo1@0000060?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0103oool4000004h0oooo002;0?ooo`D000002`3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo00T0oooo1000001:0?ooo`00Q`3oool400000100oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0>0?ooo`@00000AP3oool00880oooo1@00000D0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool04P3oool400000480oooo001n0?ooo`@0
00006@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01L0oooo1000000n0?ooo`00
N@3oool5000001d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0K0?ooo`@00000
>P3oool007@0oooo1@00000R0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0803o
ool4000003H0oooo001`0?ooo`@000009`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo02D0oooo0`00000c0?ooo`00K03oool4000002/0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool000000380oooo001Z0?ooo`8000000P3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool09@3oool2000000<0
oooo0P00000`0?ooo`00J03oool2000000@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0]0?ooo`00IP3oool2000000L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0/0?ooo`00I03oool2000000X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool02@3oool2000002`0oooo001R0?oo
o`8000003@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02T0oooo001P0?ooo`80
00003`3oool00`000000oooo0?ooo`0U0?ooobP000008P3oool200000100oooo00<000000?ooo`3o
ool0:03oool005h0oooo0P00000B0?ooo`030000003oool0oooo0200oooo100000020?ooo`030000
003oool0oooo01l0oooo00@000000?ooo`3oool0oooo1000000M0?ooo`030000003oool0oooo0140
oooo0P00000X0?ooo`00G03oool2000001D0oooo00<000000?ooo`3oool06P3oool5000000H0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`050?ooo`@00000603oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo02D0oooo001J0?ooo`8000005`3oool00`000000oooo0?oo
o`0F0?ooo`@000002`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00X0oooo1000
000C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0903oool005P0oooo0P00000J
0?ooo`030000003oool0oooo0100oooo1@00000?0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool03P3oool4000000h0oooo00<000000?ooo`3oool0603oool2000002@0oooo001F0?oo
o`8000007@3oool00`000000oooo0?ooo`0;0?ooo`@00000503oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01<0oooo100000080?ooo`8000007@3oool00`000000oooo0?ooo`0Q0?oo
o`00E03oool200000200oooo00<000000?ooo`3oool01@3oool5000001P0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0G0?ooo`@000000`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0200oooo001B0?ooo`8000008P3oool010000000oooo0?ooo`3oool4000001d0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`<000008P3oool200000200
oooo001@0?ooo`800000903oool400000200oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool07@3oool004h0oooo0P00
000T0?ooo`8000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0703oool2000000<0oooo0P00000O0?ooo`<000007`3oool004`0oooo0P00000T
0?ooo`800000103oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01X0oooo0P000002
0?ooo`030000003oool0oooo01d0oooo001:0?ooo`800000903oool2000000L0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0G0?ooo`800000103oool00`000000oooo0?ooo`0M0?oo
o`00B03oool2000002@0oooo0P00000:0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0J0?ooo`8000002`3oool2000001D0oooo0P0000070?ooo`03
0000003oool0oooo01`0oooo00170?ooo`040000003oool0000000000240oooo0P00000<0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool2000000T0oooo00<000000?ooo`3o
ool0703oool004H0oooo00<000000?ooo`3oool00P3oool2000001d0oooo0P00000?0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03@3oool2000000/0oooo00<000000?ooo`3oool0
703oool004D0oooo00<000000?ooo`3oool01@3oool2000001T0oooo0P00000B0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`8000004`3o
ool2000000/0oooo0P00000=0?ooo`030000003oool0oooo01`0oooo00140?ooo`030000003oool0
oooo00P0oooo0P00000E0?ooo`8000005@3oool00`000000oooo0?ooo`0H0?ooob0000005`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo0P00000?0?ooo`030000003oool0
oooo01`0oooo00130?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0403oool20000
01L0oooo00<000000?ooo`3oool04`3oool500000080oooo00<000000?ooo`3oool05`3oool01000
0000oooo0?ooo`3oool500000140oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`03
0?ooo`8000004@3oool00`000000oooo0?ooo`0L0?ooo`00@P3oool00`000000oooo0?ooo`0=0?oo
o`8000003P3oool2000001X0oooo00<000000?ooo`3oool03@3oool5000000L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`060?ooo`H000002@3oool2000001/0oooo0P0000000`3o
ool000000000000D0?ooo`030000003oool0oooo01/0oooo00110?ooo`030000003oool0oooo0100
oooo0P00000:0?ooo`8000007@3oool00`000000oooo0?ooo`060?ooo`H00000303oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00d0oooo1@0000030?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0K0?ooo`00@03oool00`000000oooo
0?ooo`0C0?ooo`8000001P3oool2000001l0oooo00@000000?ooo`3oool0oooo1@00000B0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool04`3oool3000001d0oooo0P0000000`3oool0
00000?ooo`0E0?ooo`030000003oool0oooo01/0oooo000o0?ooo`030000003oool0oooo01H0oooo
0P0000020?ooo`8000008@3oool4000001L0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0000001X0oooo0P0000030?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool06`3oool003h0oooo00<000000?ooo`3oool06@3oool200000240oooo0P00
00020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0C0?ooo`8000000`3oool2000001H0oooo0P0000060?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool06`3oool003d0oooo00<000000?ooo`3oool06@3oool010000000oooo00000000
000N0?ooo`800000103oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo0P00
00080?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06`3oool003d0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`8000006P3oool2000000L0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`8000002P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01X0oooo000l0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01@3oool2000001H0oooo0P00000:0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool2000000`0oooo0P00000<0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool003/0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`080?ooo`8000004P3oool2000000`0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`070?ooo`8000003P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01X0oooo000j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
2`3oool2000000h0oooo0P00000?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
103oool200000140oooo00<000000?ooo`3oool04P3oool2000001`0oooo000i0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool03P3oool2000000X0oooo0P00000B0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`8000004`3o
ool200000080oooo0P00000C0?ooo`030000003oool0oooo00h0oooo1@00000M0?ooo`00>03oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo0P0000060?ooo`8000005@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0E0?ooo`8000005@3oool00`000000oooo0?ooo`0;0?ooo`<000000`3oool0
0`000000oooo0?ooo`0L0?ooo`00=`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
01@0oooo0P0000020?ooo`8000005`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00H0oooo2`00000?0?ooo`030000003oool0oooo01@0oooo0`00000F0?ooo`030000003oool0oooo
00L0oooo100000060?ooo`030000003oool0oooo01`0oooo000f0?ooo`030000003oool0oooo01L0
oooo0P00000I0?ooo`8000006P3oool00`000000oooo0?ooo`0>0?ooo`/000001`3oool010000000
oooo0?ooo`3oool4000000T0oooo0P00000E0?ooo`8000000`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00<0oooo0`0000090?ooo`030000003oool0oooo01d0oooo000e0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0603oool010000000oooo00000000000J0?oo
o`030000003oool0oooo00L0oooo1P0000020?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01@3oool5000000<0oooo00<000000?ooo`3oool04`3oool2000000D0oooo00<000000?oo
o`3oool0503oool00`000000oooo00000003000000/0oooo00<000000?ooo`3oool07P3oool003@0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0H0?oooa0000003`3oool010000000
oooo0?ooo`3oool6000000P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?oo
o`<00000503oool2000000L0oooo00<000000?ooo`3oool04`3oool3000000h0oooo00<000000?oo
o`3oool07`3oool003<0oooo0`00000G0?ooo`030000003oool0oooo0180oooo200000040?KfmP80
00002@3]kNdG000000X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`04
0000003oool0000000000100oooo0P0000090?ooo`030000003oool0oooo00l0oooo1@00000@0?oo
o`030000003oool0oooo01l0oooo000c0?ooo`030000003oool0oooo00@000004P3oool00`000000
oooo0?ooo`0<0?ooo`L000003P3fm_H2000001h0kNg]3P00000:0?ooo`030000003oool0oooo00/0
oooo0P0000040?ooo`030000003oool0oooo00/0oooo0P00000<0?ooo`030000003oool0oooo00/0
oooo0`0000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0803oool003<0oooo
00<000000?ooo`3oool0103oool4000000d0oooo00<000000?ooo`3oool01P3oool7000001L0m_Kf
00<000000>g]k@3]kNd09P3]kNd00`000000hn?S0>?Sh`06000000<0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`050?ooo`8000002@3oool2000000h0oooo00<000000?ooo`3oool0
1`3oool4000000H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Q0?ooo`00<P3o
ool00`000000oooo0?ooo`090?ooo`@00000203oool00`000000oooo00000007000001l0m_Kf0P00
000V0>g]k@030000003Shn<0hn?S00H0hn?S1P00000:0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0103oool200000100oooo00<000000?ooo`3oool0103oool3000000T0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0R0?ooo`00<P3oool00`000000oooo0?ooo`0=
0?ooo`@0000000<0oooo0000000000000`00000Y0?KfmP800000903]kNd00`000000hn?S0>?Sh`0<
0>?Sh`H000000`3oool00`000000oooo0?ooo`0:0?ooo`8000000P3oool2000001<0oooo00<00000
0?ooo`0000000`00000<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool08P3oool0
0380oooo00<000000?ooo`3oool0403oool2000000@0o?cl1000000T0?KfmQH000004P3]kNd00`00
0000hn?S0>?Sh`0B0>?Sh`H00000303oool2000001D0oooo0P00000?0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool08`3oool00380oooo00<000000?ooo`3oool03P3oool2000000X0
o?cl1000000F0?KfmPX000001@3fm_H2000000l0kNg]4`00000J0>?Sh`H000000`3oool200000003
0?ooo`000000oooo0100oooo1@00000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0903oool00380oooo00<000000?ooo`3oool02`3oool300000100o?cl100000080?KfmPX00000
4@3fm_H2000001l0kNg]00<000000>?Sh`3Shn<01P00000H0>?Sh`H0000000<0oooo0000003oool0
303oool3000000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo02D0oooo000b0?ooo`030000003oool0oooo00T0oooo0P00000G0?clo0P000007@3f
m_H2000001d0kNg]00<000000>?Sh`3Shn<01P3Shn<6000001P0hn?S1P0000050?ooo`@000001P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09@3o
ool00340oooo00<000000?ooo`3oool0203oool2000001P0o?cl0P0000030?clo0@000007`3fm_H2
000001/0kNg]00<000000>?Sh`3Shn<0303Shn<6000001P0hn?S1@00000:0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0V0?ooo`00<@3oool00`00
0000oooo0?ooo`050?ooo`<00000603lo?`2000000T0o?cl0`00000K0?KfmQ4000003@3]kNd00`00
0000hn?S0>?Sh`0B0>?Sh`H000003`3Shn<4000000<0g=cL0P0000080?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool02P3oool3000002T0oooo000a0?ooo`030000003oool0oooo00<0
oooo0P00000I0?clo08000003P3lo?`300000140m_Kf1`0000040?KfmP8000002`3]kNd>000001X0
hn?S1P0000050>?Sh`@000002@3Lg=`3000000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`050?ooo`P00000:P3oool00340oooo00@000000?ooo`3oool0oooo0P00000I0?clo080
00004`3lo?`4000000D0m_Kf2000000=0?KfmP8000005P3]kNd010000000hn?S0>?Sh`3Shn<60000
01L0hn?S1@00000@0=cLg08000000P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool00000
00D000001@3oool00`000000oooo0?ooo`0Z0?ooo`00<@3oool00`000000oooo00000003000001L0
o?cl0P00000I0?clo0D000005`3fm_H2000001<0kNg]00<000000>?Sh`3Shn<0203Shn<7000000l0
hn?S0`0000030=cLg0800000403Lg=`3000000d0oooo1@0000090?ooo`800000;@3oool00340oooo
00<000000?ooo`0000000`3no_h7000000h0o?cl0P00000I0?clo0800000103lo?`4000001H0m_Kf
0P00000A0>g]k@030000003Shn<0hn?S00l0hn?S1P0000050>?Sh`@00000203Lg=`300000100g=cL
0`0000040?ooo`P000002P3oool2000002l0oooo000`0?ooo`030000003oool0000000/0o_kn1`00
00050?clo0800000603lo?`3000000X0o?cl1000000A0?KfmQD000005`3Shn<5000000l0g=cL0`00
000@0=cLg0@00000103oool2000000/0oooo00<000000?ooo`3oool0;`3oool00300oooo00<00000
0?ooo`0000004P3no_h9000001<0o?cl0`00000A0?clo0@000001P3fm_H7000000@0m_Kf0P00000>
0>g]k@030000003Shn<0hn?S00H000003P3Shn<3000000<0g=cL0P00000@0=cLg0800000403Lg=`3
00000080oooo00<000000?ooo`3oool02@3oool200000380oooo000`0?ooo`030000003oool00000
01@0o_kn00<000000?knoP3no_h0103no_h:000000L0o?cl0P00000H0?clo0H000003@3fm_H20000
00`0kNg]00<000000>?Sh`3Shn<01P3Shn<6000000@0hn?S100000080=cLg0<000003`3Lg=`30000
0100g=cL0P00000;0?ooo`030000003oool0oooo0380oooo000`0?ooo`8000005@3no_h00`000000
o_kn0?knoP0>0?knoP/00000503lo?`3000000@0o?cl1@00000;0?KfmP8000002P3]kNd00`000000
hn?S0>?Sh`0<0>?Sh`@000003`3Lg=`3000000l0g=cL0`00000?0=cLg0<000001P3oool2000003D0
oooo000`0?ooo`800000503no_h00`000000o_kn0?knoP0C0?knoP030000003no_h0o_kn00@0o_kn
2P0000070?clo0<00000303lo?`6000000L0m_Kf0P0000080>g]k@030000003Shn<0hn?S00X0hn?S
0`0000030=cLg0800000403Lg=`200000100g=cL0P00000@0=cLg08000000P3oool2000003L0oooo
000`0?ooo`030000003no_h0o_kn01<0o_kn00<000000?knoP3no_h04`3no_h00`000000o_kn0?kn
oP0>0?knoPX000004P3lo?`E000000H0hn?S0`0000080=cLg0800000403Lg=`3000000l0g=cL0`00
000?0=cLg0<00000>03oool002l0oooo0P00000D0?knoP030000003no_h0o_kn01<0o_kn00<00000
0?knoP3no_h04`3no_h00`000000o_kn0?knoP030?knoPX000001`3lo?`2000000<0o?cl10000002
0?KfmP8000001@3]kNd010000000hn?S0>?Sh`3Shn<6000000d0g=cL0`00000@0=cLg0<000003`3L
g=`3000000l0g=cL0`00000e0?ooo`00;`3oool2000001@0o_kn00<000000?knoP3no_h04`3no_h0
0`000000o_kn0?knoP0B0?knoP030000003no_h0o_kn00h0o_kn2P0000060?clo0H000000`3]kNd0
0`000000hn?S0>?Sh`020>?Sh`8000000`3Lg=`2000000h0g=cL0P00000A0=cLg0800000403Lg=`2
00000100g=cL0P00000c0?ooo`00;`3oool00`000000o_kn0?knoP0B0?knoP030000003no_h0o_kn
01<0o_kn00<000000?knoP3no_h04`3no_h00`000000o_kn0?knoP0B0?knoP030000003no_h0o_kn
00<0o_kn3P0000000`3]kNd000000>?Sh`03000000L0g=cL0P00000>0=cLg08000002P3Lg=`]0000
0340oooo000_0?oooi<000002@3Jf]X00`000000f][J0=[JfP0?0=[JfP030000003Jf]X0f][J00l0
f][J00<000000?ooo`3oool0;P3oool00300oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0>0?ooo`l000001P3Jf]X2000000h0f][J0P00000@0=[JfP800000403Jf]X200000100f][J
0P00000^0?ooo`00<03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo1000
00001@3no_h00000000000000000m_Kf00D0000000D0gmoO00000000000000000=cLg00700000003
0=[JfP000000000000h0f][J00<000000=[JfP3Jf]X03`3Jf]X00`000000f][J0=[JfP0?0=[JfP03
0000003Jf]X0f][J00l0f][J00<000000?ooo`3oool0:`3oool00340oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`050?ooo`@000000`3no_h200000080no_k00@000000?KfmP000000
l?3`1@0000020=oOg`@00000103Lg=`7000000/0f][J0P00000@0=[JfP030000003Jf]X0f][J00l0
f][J00<000000=[JfP3Jf]X03`3Jf]X00`000000oooo0?ooo`0Z0?ooo`00<@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00@000001@3no_h2000000<0no_k00H000000?KfmP3fm_H0
00000?3`l00000020>[ZjP040000003Ti>@00000000000@0gmoO0`0000040=cLg0040000003Lg=`0
g=cL0=cLg0H000001`3Jf]X00`000000f][J0=[JfP0>0=[JfP800000403Jf]X200000100f][J00<0
00000?ooo`3oool0:@3oool00380oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool5000000L0o_kn0P000004
0?_kn`050000003fm_H0m_Kf0?KfmP0000000P3`l?0010000000j^[Z0>[ZjP0000020>CTi0800000
1@3Ogml4000000030=cLg0000000g=cL00L0g=cL1P0000020=[JfP800000403Jf]X00`000000f][J
0=[JfP0?0=[JfP030000003Jf]X0f][J00h0f][J0P00000Y0?ooo`00<P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0:0?ooo`D000000`3no_h2000000D0o_kn0P0000050?_kn`030000003fm_H0m_Kf0080m_Kf00@0
00000?3`l03`l?0000000`3Zj^X010000000i>CT0>CTi03Ti>@2000000L0gmoO0`00000>0=cLg0L0
00003@3Jf]X00`000000f][J0=[JfP0?0=[JfP030000003Jf]X0f][J00l0f][J00<000000?ooo`3o
ool09P3oool003<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool01P3oool4000000X0o_kn0P0000000`3no_h00000
000000060?_kn`030000003fm_H0m_Kf0080m_Kf00<000000?3`l03`l?000P3`l?001@000000j^[Z
0>[ZjP3Zj^X0000000@0i>CT0P0000050=oOg`030000003Ogml0gmoO00<000003P3Lg=`010000000
g=cL0=cLg03Lg=`7000000L0f][J0P00000@0=[JfP800000403Jf]X00`000000oooo0?ooo`0U0?oo
o`00<`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0500000100o_kn00<000000?_kn`3kno/01@3kno/00`000000
m_Kf0?KfmP030?KfmP030000003`l?00l?3`0080l?3`00<000000>[ZjP3Zj^X00P3Zj^X00`000000
i>CT0>CTi0030>CTi08000000`3Ogml00`000000gmoO0=oOg`030=oOg`<00000303Lg=`00`000000
g=cL0=cLg0070=cLg0L000000P3Jf]X00`000000f][J0=[JfP0?0=[JfP030000003Jf]X0f][J00h0
f][J00<000000?ooo`3oool0903oool003@0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0100oooo1@00000C0?knoP80000000<0no_k000000000000
1@3kno/00`000000m_Kf0?KfmP030?KfmP030000003`l?00l?3`00<0l?3`00<000000>[ZjP3Zj^X0
0P3Zj^X2000000D0i>CT0`0000090=oOg`<000002@3Lg=`00`000000g=cL0=cLg00>0=cLg0L00000
3P3Jf]X00`000000f][J0=[JfP0>0=[JfP030000003oool0oooo02<0oooo000d0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`D000000`3n
o_h00`000000o_kn0?knoP0@0?knoP8000001@3kno/200000080no_k00<000000?KfmP3fm_H0103f
m_H00`000000l?3`0?3`l0030?3`l0030000003Zj^X0j^[Z00@0j^[Z00<000000>CTi03Ti>@00`3T
i>@3000000/0gmoO100000060=cLg0030000003Lg=`0g=cL0100g=cL00@000000=cLg03Lg=`0g=cL
1`0000080=[JfP8000003`3Jf]X2000002<0oooo000e0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`@000002@3no_h00`000000o_kn0?kn
oP0>0?knoP030000003kno/0no_k00L0no_k0`0000060?KfmP030000003`l?00l?3`00@0l?3`00<0
00000>[ZjP3Zj^X0103Zj^X00`000000i>CT0>CTi002000000<0i>CT0P00000=0=oOg`<000000`3L
g=`00`000000g=cL0=cLg00A0=cLg0030000003Lg=`0g=cL00L0g=cL200000020=[JfP030000003J
f]X0f][J00h0f][J00<000000?ooo`3oool0803oool003H0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D000003P3no_h00`000000o_kn0?knoP0;
0?knoP8000002P3kno/00`000000m_Kf0?KfmP0400000080m_Kf00<000000?3`l03`l?00103`l?00
0`000000j^[Z0>[ZjP020>[ZjPD000001`3Ti>@2000000h0gmoO0P0000020=cLg0030000003Lg=`0
g=cL0100g=cL00<000000=cLg03Lg=`03`3Lg=`6000000h0f][J00<000000?ooo`3oool07`3oool0
03H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`@00000503no_h20000
00T0o_kn0P00000<0?_kn`030000003fm_H0m_Kf00@0m_Kf3P0000040>[ZjP800000203Ti>@20000
00l0gmoO0`00000A0=cLg0030000003Lg=`0g=cL0180g=cL00<000000=cLg03Lg=`01P0000090=[J
fP030000003oool0oooo01h0oooo000g0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool03@3oool400000080o_kn00<000000?knoP3no_h05@3no_h00`000000o_kn0?knoP050?knoP03
0000003kno/0no_k00/0no_k00<000000?KfmP3fm_H01`3fm_H00`000000l?3`0?3`l0060?3`l003
0000003Zj^X0j^[Z00H0j^[Z00<000000>CTi03Ti>@01`3Ti>@2000000d0gmoO00<000000=oOg`3O
gml01000000=0=cLg0030000003Lg=`0g=cL0180g=cL00<000000=cLg03Lg=`01P3Lg=`5000000D0
f][J0P00000N0?ooo`00=`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo
100000070?knoP8000005P3no_h00`000000o_kn0?knoP020?knoP8000003@3kno/00`000000m_Kf
0?KfmP080?KfmP030000003`l?00l?3`00H0l?3`00<000000>[ZjP3Zj^X01`3Zj^X00`000000i>CT
0>CTi0080>CTi08000002P3Ogml00`000000gmoO0=oOg`050=oOg`<000002`3Lg=`00`000000g=cL
0=cLg00B0=cLg0030000003Lg=`0g=cL00X0g=cL1P0000000`3Jf]X000000?ooo`0L0?ooo`00>03o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo1000000=0?knoP030000003n
o_h0o_kn01@0o_kn00@000000?knoP00000000003`3kno/00`000000m_Kf0?KfmP080?KfmP030000
003`l?00l?3`00L0l?3`00<000000>[ZjP3Zj^X01`3Zj^X2000000X0i>CT0P0000070=oOg`030000
003Ogml0gmoO00T0gmoO100000070=cLg0030000003Lg=`0g=cL0180g=cL00<000000=cLg03Lg=`0
403Lg=`3000001`0oooo000h0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01000
000B0?knoP030000003no_h0o_kn01@0o_kn0P00000?0?_kn`030000003fm_H0m_Kf00T0m_Kf00<0
00000?3`l03`l?001`3`l?000`000000j^[Z0>[ZjP090>[ZjP030000003Ti>@0i>CT00T0i>CT0P00
00050=oOg`030000003Ogml0gmoO00d0gmoO0`0000040=cLg0030000003Lg=`0g=cL0180g=cL00<0
00000=cLg03Lg=`04P3Lg=`00`000000oooo0?ooo`0J0?ooo`00>@3oool00`000000oooo0?ooo`0?
0?ooo`@000005`3no_h00`000000o_kn0?knoP0A0?knoP8000000P3kno/3000000`0no_k00<00000
0?KfmP3fm_H02@3fm_H00`000000l?3`0?3`l0080?3`l0030000003Zj^X0j^[Z00T0j^[Z00<00000
0>CTi03Ti>@02P3Ti>@200000080gmoO00<000000=oOg`3Ogml04@3Ogml4000000030=cLg0000000
g=cL0180g=cL00<000000=cLg03Lg=`04P3Lg=`00`000000oooo0?ooo`0J0?ooo`00>@3oool00`00
0000oooo0?ooo`0;0?ooo`@000000`3no_h2000001L0o_kn0P00000?0?knoP8000001`3kno/20000
00T0no_k00<000000?KfmP3fm_H02P3fm_H00`000000l?3`0?3`l0090?3`l0030000003Zj^X0j^[Z
00T0j^[Z0P00000<0>CTi0<000005`3Ogml300000180g=cL00<000000=cLg03Lg=`04P3Lg=`00`00
0000oooo0?ooo`0J0?ooo`00>P3oool00`000000oooo0?ooo`050?ooo`D000002@3no_h00`000000
o_kn0?knoP0F0?knoP030000003no_h0o_kn00X0o_kn0P00000;0?_kn`<000001@3kno/00`000000
m_Kf0?KfmP0;0?KfmP030000003`l?00l?3`00T0l?3`00<000000>[ZjP3Zj^X02`3Zj^X00`000000
i>CT0>CTi0070>CTi08000000`3Ti>@2000001D0gmoO00<000000=oOg`3Ogml00`00000@0=cLg003
0000003Lg=`0g=cL0140g=cL00<000000?ooo`3oool06P3oool003X0oooo00@000000?ooo`3oool0
oooo1000000?0?knoP030000003no_h0o_kn01H0o_kn00<000000?knoP3no_h01`3no_h200000100
no_k0`0000020?_kn`030000003fm_H0m_Kf00/0m_Kf00<000000?3`l03`l?002P3`l?000`000000
j^[Z0>[ZjP0;0>[ZjP030000003Ti>@0i>CT00@0i>CT0P0000070>CTi08000004P3Ogml00`000000
gmoO0=oOg`040=oOg`<000003@3Lg=`00`000000g=cL0=cLg00B0=cLg0030000003oool0oooo01T0
oooo000k0?ooo`<00000503no_h2000001L0o_kn0P0000050?knoP8000005@3kno/4000000`0m_Kf
00<000000?3`l03`l?002`3`l?000`000000j^[Z0>[ZjP0;0>[ZjP8000000P3Ti>@2000000/0i>CT
0P00000@0=oOg`030000003Ogml0gmoO00L0gmoO0`00000:0=cLg0030000003Lg=`0g=cL0180g=cL
00<000000?ooo`3oool06@3oool003`0oooo00<000000?knoP3no_h05@3no_h00`000000o_kn0?kn
oP0F0?knoP030000003no_h0o_kn008000005`3kno/010000000m_Kf0?KfmP3fm_H5000000L0m_Kf
00<000000?3`l03`l?002`3`l?000`000000j^[Z0>[ZjP0;0>[ZjP@000003`3Ti>@2000000d0gmoO
00<000000=oOg`3Ogml02`3Ogml4000000H0g=cL00<000000=cLg03Lg=`04P3Lg=`00`000000oooo
0?ooo`0I0?ooo`00?@3oool2000001H0o_kn00<000000?knoP3no_h05P3no_h2000001T0no_k00<0
00000?KfmP3fm_H01P3fm_H500000080m_Kf00<000000?3`l03`l?00303`l?000`000000j^[Z0>[Z
jP060>[ZjP@000000`3Zj^X00`000000i>CT0>CTi00?0>CTi08000002P3Ogml00`000000gmoO0=oO
g`0@0=oOg`<00000103Lg=`00`000000g=cL0=cLg00A0=cLg0030000003oool0oooo01T0oooo000o
0?ooo`030000003no_h0o_kn01@0o_kn0P00000D0?knoP8000000P3kno/2000001H0no_k00<00000
0?KfmP3fm_H0303fm_H:000000L0l?3`00@000000>[ZjP3Zj^X0j^[Z1@0000080>[ZjP030000003T
i>@0i>CT0100i>CT0P0000070=oOg`030000003Ogml0gmoO01@0gmoO0`0000000`3Lg=`000000=cL
g00B0=cLg0030000003oool0oooo01T0oooo00100?ooo`030000003no_h0o_kn01D0o_kn00<00000
0?knoP3no_h03`3no_h2000000H0no_k0P00000C0?_kn`030000003fm_H0m_Kf00l0m_Kf00<00000
0?3`l03`l?001@3`l?0;000000h0j^[Z0P00000B0>CTi08000001@3Ogml00`000000gmoO0=oOg`0G
0=oOg`<000004P3Lg=`00`000000oooo0?ooo`0I0?ooo`00@@3oool2000001H0o_kn00<000000?kn
oP3no_h0303no_h2000000X0no_k0P00000@0?_kn`030000003fm_H0m_Kf0100m_Kf00<000000?3`
l03`l?003P3`l?000`000000j^[Z0>[ZjP0?0>[ZjP030000003Ti>@0i>CT0140i>CT0P0000020=oO
g`030000003Ogml0gmoO01P0gmoO00<000000=oOg`3Ogml01000000>0=cLg0030000003oool0oooo
01T0oooo00130?ooo`030000003no_h0o_kn01@0o_kn0P00000;0?knoP030000003kno/0no_k00`0
no_k0P00000>0?_kn`030000003fm_H0m_Kf0100m_Kf00<000000?3`l03`l?003P3`l?000`000000
j^[Z0>[ZjP0@0>[ZjP030000003Ti>@0i>CT0180i>CT0`00000I0=oOg`030000003Ogml0gmoO00D0
gmoO0`00000;0=cLg0030000003oool0oooo01T0oooo00140?ooo`030000003no_h0o_kn01D0o_kn
00<000000?knoP3no_h01P3no_h200000140no_k0`00000:0?_kn`030000003fm_H0m_Kf0140m_Kf
00<000000?3`l03`l?003`3`l?000`000000j^[Z0>[ZjP0@0>[ZjP030000003Ti>@0i>CT00l0i>CT
0P0000030>CTi08000005P3Ogml00`000000gmoO0=oOg`090=oOg`@00000203Lg=`00`000000oooo
0?ooo`0H0?ooo`00A@3oool2000001H0o_kn00<000000?knoP3no_h00`3no_h2000001H0no_k0P00
00070?_kn`030000003fm_H0m_Kf0180m_Kf00<000000?3`l03`l?003`3`l?000`000000j^[Z0>[Z
jP0A0>[ZjP030000003Ti>@0i>CT00/0i>CT0`0000070>CTi08000004`3Ogml00`000000gmoO0=oO
g`0>0=oOg`<000001@3Lg=`00`000000oooo0?ooo`0H0?ooo`00A`3oool00`000000o_kn0?knoP0D
0?knoP80000000<0o_kn0000000000006P3kno/2000000@0no_k00<000000?KfmP3fm_H04`3fm_H0
0`000000l?3`0?3`l00@0?3`l0030000003Zj^X0j^[Z0140j^[Z0P0000090>CTi0800000303Ti>@2
00000100gmoO00<000000=oOg`3Ogml04P3Ogml4000000030=cLg0000000oooo01T0oooo00180?oo
o`030000003no_h0o_kn01D0o_kn00<000000?_kn`3kno/0703kno/200000080no_k00<000000?Kf
mP3fm_H04`3fm_H00`000000l?3`0?3`l00@0?3`l0030000003Zj^X0j^[Z01<0j^[Z00<000000>CT
i03Ti>@00`3Ti>@300000100i>CT0P00000>0=oOg`030000003Ogml0gmoO01H0gmoO0P00000J0?oo
o`00B@3oool2000001<0o_kn0P0000020?_kn`<00000703kno/4000001@0m_Kf00<000000?3`l03`
l?004@3`l?000`000000j^[Z0>[ZjP0C0>[ZjP030000003Ti>@0i>CT008000005@3Ti>@2000000/0
gmoO00<000000=oOg`3Ogml05`3Ogml00`000000oooo0?ooo`0I0?ooo`00B`3oool00`000000o_kn
0?knoP0>0?knoP8000001`3kno/2000001X0no_k00@000000?KfmP3fm_H0m_Kf1P00000>0?KfmP03
0000003`l?00l?3`0180l?3`00<000000>[ZjP3Zj^X04@3Zj^X4000001T0i>CT0P0000080=oOg`03
0000003Ogml0gmoO01L0gmoO00<000000?ooo`3oool06P3oool004`0oooo00<000000?knoP3no_h0
303no_h00`000000no_k0?_kn`090?_kn`<000005P3kno/00`000000m_Kf0?KfmP080?KfmPH00000
203fm_H00`000000l?3`0?3`l00B0?3`l0030000003Zj^X0j^[Z00`0j^[Z1@0000030>[ZjP030000
003Ti>@0i>CT01T0i>CT0P0000050=oOg`030000003Ogml0gmoO01L0gmoO00<000000?ooo`3oool0
6`3oool004d0oooo0P00000:0?knoP8000003`3kno/3000001<0no_k00<000000?KfmP3fm_H03P3f
m_H600000080m_Kf00<000000?3`l03`l?004`3`l?000`000000j^[Z0>[ZjP060>[ZjPD000002@3Z
j^X2000001/0i>CT0P0000020=oOg`030000003Ogml0gmoO01L0gmoO00<000000?ooo`3oool0703o
ool004l0oooo00<000000?knoP3no_h01P3no_h00`000000no_k0?_kn`0B0?_kn`800000403kno/0
0`000000m_Kf0?KfmP0E0?KfmPh000002P3`l?0010000000j^[Z0>[ZjP3Zj^X500000100j^[Z00<0
00000>CTi03Ti>@06P3Ti>@2000001T0gmoO00<000000?ooo`3oool07@3oool00500oooo00<00000
0?knoP3no_h00`3no_h2000001L0no_k0`00000<0?_kn`030000003fm_H0m_Kf01P0m_Kf00<00000
0?3`l03`l?002@3`l?0>000001H0j^[Z00<000000>CTi03Ti>@05`3Ti>@200000080i>CT0P00000F
0=oOg`030000003oool0oooo01h0oooo001A0?ooo`80000000<0o_kn000000000000703kno/30000
00P0no_k00<000000?KfmP3fm_H06@3fm_H00`000000l?3`0?3`l00E0?3`l0030000003Zj^X0j^[Z
01H0j^[Z00<000000>CTi03Ti>@04`3Ti>@3000000H0i>CT0P00000C0=oOg`030000003oool0oooo
01l0oooo001C0?ooo`030000003kno/0no_k01l0no_k0P0000060?_kn`030000003fm_H0m_Kf01T0
m_Kf00<000000?3`l03`l?005@3`l?000`000000j^[Z0>[ZjP0G0>[ZjP8000004@3Ti>@2000000/0
i>CT0P00000A0=oOg`030000003oool0oooo01l0oooo001E0?ooo`<000007`3kno/300000080no_k
00<000000?KfmP3fm_H06P3fm_H00`000000l?3`0?3`l00F0?3`l0030000003Zj^X0j^[Z01P0j^[Z
00<000000>CTi03Ti>@02`3Ti>@3000000l0i>CT0P00000>0=oOg`030000003oool0oooo0200oooo
001H0?ooo`800000803kno/4000001/0m_Kf00<000000?3`l03`l?005`3`l?000`000000j^[Z0>[Z
jP0H0>[ZjP030000003Ti>@0i>CT00P0i>CT0P00000D0>CTi08000002`3Ogml00`000000oooo0?oo
o`0Q0?ooo`00FP3oool3000001d0no_k00@000000?KfmP3fm_H0m_Kf1@00000F0?KfmP030000003`
l?00l?3`01L0l?3`00<000000>[ZjP3Zj^X06@3Zj^X2000000D0i>CT0`00000H0>CTi0800000203O
gml00`000000oooo0?ooo`0R0?ooo`00G@3oool3000001X0no_k00<000000?KfmP3fm_H01P3fm_H5
00000140m_Kf00<000000?3`l03`l?00603`l?000`000000j^[Z0>[ZjP0J0>[ZjP030000003Ti>@0
i>CT008000007@3Ti>@2000000D0gmoO00<000000?ooo`3oool08`3oool00600oooo0`00000F0?_k
n`030000003fm_H0m_Kf00`0m_Kf1@00000<0?KfmP030000003`l?00l?3`01P0l?3`00<000000>[Z
jP3Zj^X0603Zj^X500000240i>CT0P0000020=oOg`030000003oool0oooo02@0oooo001S0?ooo`80
00004`3kno/00`000000m_Kf0?KfmP0B0?KfmPD000001`3fm_H00`000000l?3`0?3`l00I0?3`l003
0000003Zj^X0j^[Z0100j^[Z1`0000040>[ZjP030000003Ti>@0i>CT0240i>CT0P00000W0?ooo`00
I@3oool3000000l0no_k00<000000?KfmP3fm_H0603fm_H500000080m_Kf00<000000?3`l03`l?00
6P3`l?000`000000j^[Z0>[ZjP090>[ZjPH00000303Zj^X00`000000i>CT0>CTi00N0>CTi0800000
:@3oool006P0oooo0`00000<0?_kn`030000003fm_H0m_Kf01d0m_Kf4@00000>0?3`l0030000003Z
j^X0j^[Z0080j^[Z1`00000C0>[ZjP8000006`3Ti>@3000002/0oooo001[0?ooo`<00000203kno/0
0`000000m_Kf0?KfmP0P0?KfmP030000003`l?00l?3`00`0l?3`4`00000L0>[ZjP030000003Ti>@0
i>CT01H0i>CT0P00000^0?ooo`00KP3oool2000000D0no_k00<000000?KfmP3fm_H08@3fm_H00`00
0000l?3`0?3`l00L0?3`l0030000003Zj^X0j^[Z01d0j^[Z00<000000>CTi03Ti>@04P3Ti>@30000
0300oooo001`0?ooo`<000000P3kno/00`000000m_Kf0?KfmP0Q0?KfmP030000003`l?00l?3`01`0
l?3`00<000000>[ZjP3Zj^X07P3Zj^X00`000000i>CT0>CTi00?0>CTi0800000<`3oool007<0oooo
1000000R0?KfmP030000003`l?00l?3`01d0l?3`00<000000>[ZjP3Zj^X07P3Zj^X00`000000i>CT
0>CTi00;0>CTi0<00000=@3oool007L0oooo1@00000M0?KfmP030000003`l?00l?3`01h0l?3`00<0
00000>[ZjP3Zj^X07P3Zj^X2000000T0i>CT0P00000h0?ooo`00O03oool6000001L0m_Kf00<00000
0?3`l03`l?007P3`l?000`000000j^[Z0>[ZjP0P0>[ZjP030000003Ti>@0i>CT00<0i>CT0`00000j
0?ooo`00PP3oool500000180m_Kf00<000000?3`l03`l?007`3`l?000`000000j^[Z0>[ZjP0P0>[Z
jP030000003Ti>@0i>CT00800000?@3oool008L0oooo1@00000=0?KfmP030000003`l?00l?3`01l0
l?3`00<000000>[ZjP3Zj^X07@3Zj^X6000003l0oooo002<0?ooo`H000001`3fm_H00`000000l?3`
0?3`l00P0?3`l0030000003Zj^X0j^[Z01@0j^[Z200000150?ooo`00TP3oool500000080m_Kf00<0
00000?3`l03`l?008@3`l?000`000000j^[Z0>[ZjP0;0>[ZjPP00000C@3oool009L0oooo5@00000A
0?3`l0030000003Zj^X0j^[Z00<0j^[Z2000001E0?ooo`00[03ooolG000005d0oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {177.313, 0}} -> {0, 0, 0, 0}}],
  StyleBox["     ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% PlotRegion
.1 .9 .1 .9 MPlotRegion
% Scaling calculations
0.5 0.434783 0.5 0.434783 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
.5 .49565 m
.50002 .49565 L
.50003 .49565 L
.50005 .49565 L
.50007 .49565 L
.5001 .49565 L
.50013 .49565 L
.50017 .49566 L
.5002 .49566 L
.50027 .49566 L
.50034 .49567 L
.50041 .49567 L
.50055 .49569 L
.5007 .49571 L
.50084 .49573 L
.50115 .49581 L
.50141 .49589 L
.50168 .49599 L
.5022 .49625 L
.50267 .49657 L
.50311 .49696 L
.50349 .4974 L
.50379 .49786 L
.50392 .49811 L
.50404 .49839 L
.50414 .49867 L
.50421 .49893 L
.50427 .49921 L
.5043 .49936 L
.50432 .4995 L
.50433 .49964 L
.50434 .49971 L
.50434 .49979 L
.50435 .49985 L
.50435 .49989 L
.50435 .49991 L
.50435 .49992 L
.50435 .49994 L
.50435 .49995 L
.50435 .49997 L
.50435 .49998 L
.50435 .5 L
.50435 .50002 L
.50435 .50004 L
.50435 .50005 L
.50435 .50007 L
.50435 .50009 L
.50435 .50012 L
.50435 .50015 L
.50434 .50019 L
Mistroke
.50434 .50026 L
.50434 .50032 L
.50432 .50046 L
.5043 .50061 L
.50428 .50076 L
.50425 .50092 L
.50418 .5012 L
.50409 .50147 L
.50398 .50175 L
.50373 .50223 L
.5034 .50271 L
.50302 .50312 L
.50257 .50351 L
.50209 .50381 L
.50159 .50405 L
.50132 .50414 L
.50103 .50422 L
.5009 .50425 L
.50076 .50428 L
.50064 .5043 L
.5005 .50432 L
.50037 .50433 L
.50026 .50434 L
.50019 .50434 L
.50013 .50435 L
.5001 .50435 L
.50008 .50435 L
.50007 .50435 L
.50005 .50435 L
.50003 .50435 L
.50002 .50435 L
.5 .50435 L
Mfstroke
.5001 .30551 m
.50085 .30551 L
.50154 .30552 L
.50233 .30552 L
.50308 .30554 L
.50441 .30556 L
.50585 .3056 L
.50744 .30565 L
.50913 .30573 L
.51215 .30589 L
.51527 .30611 L
.51818 .30636 L
.52481 .3071 L
.53153 .30808 L
.53766 .30919 L
.55129 .31239 L
.56292 .31597 L
.57534 .3207 L
.59863 .33237 L
.61938 .34646 L
.63924 .36422 L
.65592 .38374 L
.6694 .40445 L
.6752 .41556 L
.68073 .42816 L
.6852 .44063 L
.68853 .45223 L
.69121 .46445 L
.69235 .47125 L
.69321 .47772 L
.69382 .48388 L
.69405 .48699 L
.69425 .49044 L
.69438 .49337 L
.69443 .49502 L
.69444 .4958 L
.69446 .49653 L
.69447 .49723 L
.69448 .49786 L
.69448 .49856 L
.69449 .49932 L
.69449 .50004 L
.69449 .50082 L
.69448 .50157 L
.69448 .50225 L
.69447 .50305 L
.69445 .50382 L
.69442 .50525 L
.69437 .50679 L
.69431 .50846 L
Mistroke
.69415 .51148 L
.69397 .51427 L
.69339 .52066 L
.69255 .52743 L
.6915 .53396 L
.69013 .54097 L
.68698 .55352 L
.68305 .56572 L
.67804 .57827 L
.66686 .59992 L
.65208 .62124 L
.63529 .63972 L
.61501 .65684 L
.59344 .67057 L
.57116 .681 L
.55919 .68526 L
.54621 .68892 L
.54034 .69026 L
.53397 .6915 L
.52844 .6924 L
.52237 .6932 L
.51676 .69377 L
.51153 .69415 L
.50863 .6943 L
.506 .6944 L
.50454 .69444 L
.50377 .69445 L
.50296 .69447 L
.50225 .69448 L
.50147 .69448 L
.50076 .69449 L
.5001 .69449 L
Mfstroke
.50014 .22498 m
.5012 .22499 L
.50217 .22499 L
.50329 .225 L
.50435 .22502 L
.50623 .22506 L
.50828 .22511 L
.51053 .22519 L
.51291 .22529 L
.51718 .22552 L
.52159 .22583 L
.52571 .22619 L
.53508 .22723 L
.54459 .22862 L
.55325 .23019 L
.57252 .23472 L
.58898 .23978 L
.60654 .24646 L
.63946 .26297 L
.6688 .28289 L
.6969 .308 L
.72048 .33561 L
.73954 .36489 L
.74774 .3806 L
.75556 .39841 L
.76189 .41604 L
.76659 .43246 L
.77038 .44974 L
.77199 .45934 L
.7732 .46849 L
.77407 .4772 L
.7744 .48161 L
.77468 .48648 L
.77486 .49062 L
.77492 .49295 L
.77495 .49406 L
.77497 .49509 L
.77499 .49608 L
.775 .49697 L
.77501 .49797 L
.77501 .49903 L
.77502 .50006 L
.77501 .50117 L
.77501 .50221 L
.775 .50318 L
.77498 .50432 L
.77496 .5054 L
.77491 .50742 L
.77485 .5096 L
.77475 .51197 L
Mistroke
.77454 .51623 L
.77427 .52018 L
.77346 .52921 L
.77227 .53879 L
.77079 .54802 L
.76884 .55793 L
.7644 .57568 L
.75884 .59293 L
.75176 .61068 L
.73594 .64129 L
.71504 .67144 L
.6913 .69758 L
.66262 .72178 L
.63212 .7412 L
.60062 .75595 L
.5837 .76197 L
.56535 .76714 L
.55704 .76903 L
.54804 .77079 L
.54021 .77206 L
.53163 .77319 L
.52369 .77399 L
.5163 .77453 L
.51221 .77474 L
.50849 .77488 L
.50642 .77494 L
.50534 .77496 L
.50419 .77498 L
.50318 .775 L
.50208 .77501 L
.50108 .77501 L
.50014 .77502 L
Mfstroke
.50017 .16319 m
.50147 .16319 L
.50266 .1632 L
.50403 .16321 L
.50533 .16323 L
.50763 .16328 L
.51014 .16334 L
.51289 .16344 L
.51581 .16356 L
.52104 .16385 L
.52644 .16423 L
.53149 .16467 L
.54296 .16594 L
.55461 .16765 L
.56521 .16956 L
.58881 .17511 L
.60897 .1813 L
.63048 .18949 L
.6708 .20971 L
.70673 .2341 L
.74114 .26486 L
.77001 .29867 L
.79336 .33453 L
.80341 .35377 L
.81299 .37559 L
.82073 .39718 L
.82649 .41728 L
.83114 .43844 L
.83311 .45021 L
.83459 .46141 L
.83565 .47208 L
.83606 .47748 L
.8364 .48344 L
.83661 .48852 L
.8367 .49137 L
.83673 .49273 L
.83676 .49399 L
.83677 .4952 L
.83679 .49629 L
.8368 .49751 L
.83681 .49881 L
.83681 .50007 L
.83681 .50143 L
.8368 .50271 L
.83679 .5039 L
.83677 .50529 L
.83674 .50661 L
.83669 .50909 L
.8366 .51175 L
.83649 .51466 L
Mistroke
.83622 .51988 L
.8359 .52471 L
.8349 .53577 L
.83344 .5475 L
.83164 .55881 L
.82925 .57095 L
.8238 .59269 L
.817 .61381 L
.80833 .63555 L
.78896 .67304 L
.76336 .70996 L
.73429 .74197 L
.69917 .77161 L
.66181 .79539 L
.62323 .81346 L
.6025 .82083 L
.58003 .82716 L
.56986 .82948 L
.55883 .83163 L
.54925 .83319 L
.53873 .83457 L
.52902 .83556 L
.51997 .83622 L
.51495 .83648 L
.51039 .83665 L
.50787 .83672 L
.50654 .83675 L
.50513 .83677 L
.5039 .83679 L
.50255 .8368 L
.50132 .83681 L
.50017 .83681 L
Mfstroke
.50019 .11109 m
.5017 .1111 L
.50307 .11111 L
.50466 .11112 L
.50615 .11114 L
.50882 .11119 L
.5117 .11127 L
.51488 .11138 L
.51826 .11152 L
.5243 .11185 L
.53053 .11229 L
.53636 .1128 L
.54961 .11427 L
.56306 .11624 L
.5753 .11845 L
.60255 .12486 L
.62582 .13201 L
.65066 .14146 L
.69722 .16481 L
.73871 .19297 L
.77844 .22849 L
.81178 .26753 L
.83874 .30894 L
.85034 .33115 L
.8614 .35634 L
.87034 .38127 L
.87699 .40449 L
.88236 .42892 L
.88463 .44251 L
.88634 .45544 L
.88757 .46776 L
.88804 .47399 L
.88844 .48088 L
.88868 .48674 L
.88878 .49004 L
.88882 .4916 L
.88884 .49306 L
.88887 .49445 L
.88888 .49572 L
.8889 .49713 L
.8889 .49863 L
.88891 .50008 L
.8889 .50165 L
.88889 .50313 L
.88888 .5045 L
.88886 .5061 L
.88883 .50763 L
.88876 .51049 L
.88867 .51357 L
.88854 .51693 L
Mistroke
.88823 .52295 L
.88786 .52854 L
.88671 .5413 L
.88502 .55485 L
.88293 .56791 L
.88018 .58192 L
.87389 .60703 L
.86603 .63141 L
.85602 .65651 L
.83365 .69981 L
.8041 .74243 L
.77053 .7794 L
.72997 .81363 L
.68684 .84108 L
.64229 .86194 L
.61836 .87046 L
.59241 .87777 L
.58066 .88045 L
.56793 .88293 L
.55687 .88473 L
.54472 .88633 L
.5335 .88746 L
.52305 .88822 L
.51726 .88852 L
.512 .88872 L
.50908 .8888 L
.50755 .88883 L
.50592 .88886 L
.5045 .88888 L
.50294 .88889 L
.50152 .8889 L
.50019 .88891 L
Mfstroke
.5 .49565 m
.50004 .41233 L
.50006 .37331 L
.50008 .34539 L
.50009 .32264 L
.5001 .30127 L
.50011 .28267 L
.50012 .2645 L
.50013 .24824 L
.50013 .23353 L
.50014 .21872 L
.50015 .20516 L
.50015 .19269 L
.50016 .17995 L
.50017 .16814 L
.50017 .15604 L
.50018 .14477 L
.50018 .13425 L
.50019 .12339 L
.50019 .11321 L
.5002 .10269 L
.5002 .0928 L
.50021 .08351 L
.50021 .07386 L
.50022 .06522 L
s
.50085 .49574 m
.51714 .41402 L
.52476 .37576 L
.53022 .34838 L
.53467 .32606 L
.53884 .3051 L
.54248 .28686 L
.54603 .26904 L
.54921 .25309 L
.55208 .23866 L
.55498 .22414 L
.55763 .21085 L
.56007 .19862 L
.56256 .18612 L
.56486 .17454 L
.56723 .16267 L
.56943 .15162 L
.57149 .14131 L
.57361 .13065 L
.5756 .12067 L
.57766 .11035 L
.57959 .10066 L
.58141 .09155 L
.58329 .08208 L
.58498 .0736 L
s
.50167 .49598 m
.53357 .41901 L
.54851 .38297 L
.5592 .35718 L
.56791 .33616 L
.5761 .31641 L
.58322 .29923 L
.59018 .28245 L
.5964 .26742 L
.60204 .25383 L
.60771 .24016 L
.6129 .22763 L
.61767 .21611 L
.62255 .20434 L
.62707 .19344 L
.63171 .18225 L
.63602 .17184 L
.64005 .16213 L
.64421 .15209 L
.64811 .14269 L
.65214 .13297 L
.65592 .12384 L
.65948 .11526 L
.66318 .10634 L
.66648 .09835 L
s
.50242 .49638 m
.54872 .42711 L
.5704 .39467 L
.58591 .37146 L
.59855 .35254 L
.61043 .33477 L
.62077 .31931 L
.63086 .30421 L
.6399 .29068 L
.64807 .27845 L
.6563 .26614 L
.66383 .25487 L
.67076 .2445 L
.67785 .23391 L
.6844 .22409 L
.69113 .21403 L
.69739 .20466 L
.70324 .19592 L
.70928 .18688 L
.71493 .17842 L
.72078 .16967 L
.72627 .16146 L
.73143 .15373 L
.7368 .1457 L
.7416 .13852 L
s
.50308 .49692 m
.56199 .43801 L
.58958 .41042 L
.60932 .39068 L
.62541 .37459 L
.64053 .35947 L
.65368 .34632 L
.66652 .33348 L
.67802 .32198 L
.68843 .31157 L
.6989 .3011 L
.70848 .29152 L
.7173 .2827 L
.72631 .27369 L
.73466 .26534 L
.74322 .25678 L
.75119 .24881 L
.75862 .24138 L
.76631 .23369 L
.7735 .2265 L
.78094 .21906 L
.78793 .21207 L
.7945 .2055 L
.80133 .19867 L
.80744 .19256 L
s
.50362 .49758 m
.57289 .45128 L
.60533 .4296 L
.62854 .41409 L
.64746 .40145 L
.66523 .38957 L
.68069 .37923 L
.69579 .36914 L
.70932 .3601 L
.72155 .35193 L
.73386 .3437 L
.74513 .33617 L
.7555 .32924 L
.76609 .32215 L
.77591 .3156 L
.78597 .30887 L
.79534 .30261 L
.80408 .29676 L
.81312 .29072 L
.82158 .28507 L
.83033 .27922 L
.83854 .27373 L
.84627 .26857 L
.8543 .2632 L
.86148 .2584 L
s
.50402 .49833 m
.58099 .46643 L
.61703 .45149 L
.64282 .4408 L
.66384 .43209 L
.68359 .4239 L
.70077 .41678 L
.71755 .40982 L
.73258 .4036 L
.74617 .39796 L
.75984 .39229 L
.77237 .3871 L
.78389 .38233 L
.79566 .37745 L
.80656 .37293 L
.81775 .36829 L
.82816 .36398 L
.83787 .35995 L
.84791 .35579 L
.85731 .35189 L
.86703 .34786 L
.87616 .34408 L
.88474 .34052 L
.89366 .33682 L
.90165 .33352 L
s
.50426 .49915 m
.58598 .48286 L
.62424 .47524 L
.65162 .46978 L
.67394 .46533 L
.6949 .46116 L
.71314 .45752 L
.73096 .45397 L
.74691 .45079 L
.76134 .44792 L
.77586 .44502 L
.78915 .44237 L
.80138 .43993 L
.81388 .43744 L
.82546 .43514 L
.83733 .43277 L
.84838 .43057 L
.85869 .42851 L
.86935 .42639 L
.87933 .4244 L
.88965 .42234 L
.89934 .42041 L
.90845 .41859 L
.91792 .41671 L
.9264 .41502 L
s
.50435 .5 m
.58767 .49996 L
.62669 .49994 L
.65461 .49992 L
.67736 .49991 L
.69873 .4999 L
.71733 .49989 L
.7355 .49988 L
.75176 .49987 L
.76647 .49987 L
.78128 .49986 L
.79484 .49985 L
.80731 .49985 L
.82005 .49984 L
.83186 .49983 L
.84396 .49983 L
.85523 .49982 L
.86575 .49982 L
.87661 .49981 L
.88679 .49981 L
.89731 .4998 L
.9072 .4998 L
.91649 .49979 L
.92614 .49979 L
.93478 .49978 L
s
.50427 .50085 m
.586 .51705 L
.62427 .52464 L
.65165 .53007 L
.67397 .53449 L
.69494 .53865 L
.71319 .54227 L
.731 .5458 L
.74696 .54896 L
.76139 .55182 L
.77591 .5547 L
.78921 .55734 L
.80144 .55976 L
.81394 .56224 L
.82552 .56454 L
.8374 .56689 L
.84845 .56909 L
.85877 .57113 L
.86942 .57324 L
.8794 .57522 L
.88973 .57727 L
.89942 .57919 L
.90853 .581 L
.91801 .58288 L
.92648 .58456 L
s
.50402 .50166 m
.58103 .53349 L
.61708 .54839 L
.64288 .55906 L
.66391 .56775 L
.68366 .57591 L
.70085 .58302 L
.71764 .58996 L
.73267 .59617 L
.74627 .60179 L
.75995 .60745 L
.77248 .61263 L
.784 .61739 L
.79578 .62226 L
.80669 .62677 L
.81788 .63139 L
.8283 .6357 L
.83801 .63971 L
.84805 .64386 L
.85746 .64775 L
.86718 .65177 L
.87632 .65555 L
.8849 .65909 L
.89383 .66278 L
.90181 .66608 L
s
.50362 .50241 m
.57294 .54865 L
.6054 .57029 L
.62863 .58578 L
.64755 .59841 L
.66534 .61027 L
.68081 .62059 L
.69593 .63067 L
.70946 .63969 L
.7217 .64785 L
.73401 .65607 L
.74529 .66359 L
.75567 .67051 L
.76627 .67758 L
.77609 .68413 L
.78616 .69085 L
.79554 .6971 L
.80429 .70293 L
.81333 .70896 L
.82179 .71461 L
.83055 .72045 L
.83877 .72593 L
.8465 .73108 L
.85453 .73644 L
.86172 .74124 L
s
.50308 .50307 m
.56206 .56193 L
.58967 .58949 L
.60943 .60921 L
.62554 .62529 L
.64067 .64039 L
.65383 .65353 L
.66669 .66636 L
.6782 .67785 L
.68861 .68824 L
.6991 .6987 L
.70869 .70827 L
.71752 .71708 L
.72654 .72609 L
.73489 .73442 L
.74346 .74298 L
.75144 .75094 L
.75888 .75836 L
.76657 .76604 L
.77377 .77323 L
.78122 .78066 L
.78822 .78764 L
.79479 .79421 L
.80163 .80103 L
.80775 .80713 L
s
.50242 .50361 m
.54879 .57284 L
.5705 .60526 L
.58604 .62845 L
.5987 .64736 L
.6106 .66512 L
.62095 .68057 L
.63106 .69566 L
.64011 .70918 L
.64829 .7214 L
.65653 .7337 L
.66408 .74496 L
.67102 .75533 L
.67811 .76591 L
.68468 .77572 L
.69142 .78578 L
.69769 .79514 L
.70354 .80388 L
.70959 .81291 L
.71525 .82136 L
.72111 .8301 L
.72661 .83832 L
.73178 .84603 L
.73715 .85406 L
.74196 .86124 L
s
.50167 .50402 m
.53365 .58096 L
.54863 .61698 L
.55934 .64276 L
.56808 .66377 L
.57628 .68351 L
.58342 .70069 L
.59039 .71746 L
.59664 .73248 L
.60228 .74606 L
.60797 .75974 L
.61317 .77225 L
.61796 .78377 L
.62285 .79554 L
.62738 .80644 L
.63203 .81762 L
.63635 .82802 L
.64039 .83773 L
.64456 .84777 L
.64846 .85716 L
.6525 .86688 L
.6563 .87601 L
.65986 .88458 L
.66357 .8935 L
.66689 .90148 L
s
.50085 .50426 m
.51722 .58597 L
.52489 .62422 L
.53037 .65159 L
.53484 .6739 L
.53904 .69486 L
.54269 .7131 L
.54626 .73091 L
.54946 .74686 L
.55235 .76128 L
.55525 .7758 L
.55792 .78909 L
.56037 .80132 L
.56287 .81382 L
.56519 .82539 L
.56757 .83726 L
.56978 .84831 L
.57185 .85862 L
.57398 .86928 L
.57598 .87925 L
.57805 .88957 L
.57999 .89926 L
.58181 .90837 L
.58371 .91784 L
.58541 .92631 L
s
.50001 .50435 m
.50013 .58767 L
.50019 .62669 L
.50023 .65461 L
.50027 .67736 L
.5003 .69873 L
.50033 .71733 L
.50035 .7355 L
.50038 .75176 L
.5004 .76647 L
.50042 .78128 L
.50044 .79484 L
.50046 .80731 L
.50048 .82005 L
.5005 .83186 L
.50052 .84396 L
.50053 .85523 L
.50055 .86575 L
.50056 .87661 L
.50058 .88679 L
.5006 .89731 L
.50061 .9072 L
.50062 .91649 L
.50064 .92614 L
.50065 .93478 L
s
.5 .50435 m
.49998 .50435 L
.49997 .50435 L
.49995 .50435 L
.49993 .50435 L
.4999 .50435 L
.49987 .50435 L
.49983 .50434 L
.4998 .50434 L
.49973 .50434 L
.49966 .50433 L
.49959 .50433 L
.49945 .50431 L
.4993 .50429 L
.49916 .50427 L
.49885 .50419 L
.49859 .50411 L
.49832 .50401 L
.4978 .50375 L
.49733 .50343 L
.49689 .50304 L
.49651 .5026 L
.49621 .50214 L
.49608 .50189 L
.49596 .50161 L
.49586 .50133 L
.49579 .50107 L
.49573 .50079 L
.4957 .50064 L
.49568 .5005 L
.49567 .50036 L
.49566 .50029 L
.49566 .50021 L
.49565 .50015 L
.49565 .50011 L
.49565 .50009 L
.49565 .50008 L
.49565 .50006 L
.49565 .50005 L
.49565 .50003 L
.49565 .50002 L
.49565 .5 L
.49565 .49998 L
.49565 .49996 L
.49565 .49995 L
.49565 .49993 L
.49565 .49991 L
.49565 .49988 L
.49565 .49985 L
.49566 .49981 L
Mistroke
.49566 .49974 L
.49566 .49968 L
.49568 .49954 L
.4957 .49939 L
.49572 .49924 L
.49575 .49908 L
.49582 .4988 L
.49591 .49853 L
.49602 .49825 L
.49627 .49777 L
.4966 .49729 L
.49698 .49688 L
.49743 .49649 L
.49791 .49619 L
.49841 .49595 L
.49868 .49586 L
.49897 .49578 L
.4991 .49575 L
.49924 .49572 L
.49936 .4957 L
.4995 .49568 L
.49963 .49567 L
.49974 .49566 L
.49981 .49566 L
.49987 .49565 L
.4999 .49565 L
.49992 .49565 L
.49993 .49565 L
.49995 .49565 L
.49997 .49565 L
.49998 .49565 L
.5 .49565 L
Mfstroke
.4999 .69449 m
.49915 .69449 L
.49846 .69448 L
.49767 .69448 L
.49692 .69446 L
.49559 .69444 L
.49415 .6944 L
.49256 .69435 L
.49087 .69427 L
.48785 .69411 L
.48473 .69389 L
.48182 .69364 L
.47519 .6929 L
.46847 .69192 L
.46234 .69081 L
.44871 .68761 L
.43708 .68403 L
.42466 .6793 L
.40137 .66763 L
.38062 .65354 L
.36076 .63578 L
.34408 .61626 L
.3306 .59555 L
.3248 .58444 L
.31927 .57184 L
.3148 .55937 L
.31147 .54777 L
.30879 .53555 L
.30765 .52875 L
.30679 .52228 L
.30618 .51612 L
.30595 .51301 L
.30575 .50956 L
.30562 .50663 L
.30557 .50498 L
.30556 .5042 L
.30554 .50347 L
.30553 .50277 L
.30552 .50214 L
.30552 .50144 L
.30551 .50068 L
.30551 .49996 L
.30551 .49918 L
.30552 .49843 L
.30552 .49775 L
.30553 .49695 L
.30555 .49618 L
.30558 .49475 L
.30563 .49321 L
.30569 .49154 L
Mistroke
.30585 .48852 L
.30603 .48573 L
.30661 .47934 L
.30745 .47257 L
.3085 .46604 L
.30987 .45903 L
.31302 .44648 L
.31695 .43428 L
.32196 .42173 L
.33314 .40008 L
.34792 .37876 L
.36471 .36028 L
.38499 .34316 L
.40656 .32943 L
.42884 .319 L
.44081 .31474 L
.45379 .31108 L
.45966 .30974 L
.46603 .3085 L
.47156 .3076 L
.47763 .3068 L
.48324 .30623 L
.48847 .30585 L
.49137 .3057 L
.494 .3056 L
.49546 .30556 L
.49623 .30555 L
.49704 .30553 L
.49775 .30552 L
.49853 .30552 L
.49924 .30551 L
.4999 .30551 L
Mfstroke
.49986 .77502 m
.4988 .77501 L
.49783 .77501 L
.49671 .775 L
.49565 .77498 L
.49377 .77494 L
.49172 .77489 L
.48947 .77481 L
.48709 .77471 L
.48282 .77448 L
.47841 .77417 L
.47429 .77381 L
.46492 .77277 L
.45541 .77138 L
.44675 .76981 L
.42748 .76528 L
.41102 .76022 L
.39346 .75354 L
.36054 .73703 L
.3312 .71711 L
.3031 .692 L
.27952 .66439 L
.26046 .63511 L
.25226 .6194 L
.24444 .60159 L
.23811 .58396 L
.23341 .56754 L
.22962 .55026 L
.22801 .54066 L
.2268 .53151 L
.22593 .5228 L
.2256 .51839 L
.22532 .51352 L
.22514 .50938 L
.22508 .50705 L
.22505 .50594 L
.22503 .50491 L
.22501 .50392 L
.225 .50303 L
.22499 .50203 L
.22499 .50097 L
.22498 .49994 L
.22499 .49883 L
.22499 .49779 L
.225 .49682 L
.22502 .49568 L
.22504 .4946 L
.22509 .49258 L
.22515 .4904 L
.22525 .48803 L
Mistroke
.22546 .48377 L
.22573 .47982 L
.22654 .47079 L
.22773 .46121 L
.22921 .45198 L
.23116 .44207 L
.2356 .42432 L
.24116 .40707 L
.24824 .38932 L
.26406 .35871 L
.28496 .32856 L
.3087 .30242 L
.33738 .27822 L
.36788 .2588 L
.39938 .24405 L
.4163 .23803 L
.43465 .23286 L
.44296 .23097 L
.45196 .22921 L
.45979 .22794 L
.46837 .22681 L
.47631 .22601 L
.4837 .22547 L
.48779 .22526 L
.49151 .22512 L
.49358 .22506 L
.49466 .22504 L
.49581 .22502 L
.49682 .225 L
.49792 .22499 L
.49892 .22499 L
.49986 .22498 L
Mfstroke
.49983 .83681 m
.49853 .83681 L
.49734 .8368 L
.49597 .83679 L
.49467 .83677 L
.49237 .83672 L
.48986 .83666 L
.48711 .83656 L
.48419 .83644 L
.47896 .83615 L
.47356 .83577 L
.46851 .83533 L
.45704 .83406 L
.44539 .83235 L
.43479 .83044 L
.41119 .82489 L
.39103 .8187 L
.36952 .81051 L
.3292 .79029 L
.29327 .7659 L
.25886 .73514 L
.22999 .70133 L
.20664 .66547 L
.19659 .64623 L
.18701 .62441 L
.17927 .60282 L
.17351 .58272 L
.16886 .56156 L
.16689 .54979 L
.16541 .53859 L
.16435 .52792 L
.16394 .52252 L
.1636 .51656 L
.16339 .51148 L
.1633 .50863 L
.16327 .50727 L
.16324 .50601 L
.16323 .5048 L
.16321 .50371 L
.1632 .50249 L
.16319 .50119 L
.16319 .49993 L
.16319 .49857 L
.1632 .49729 L
.16321 .4961 L
.16323 .49471 L
.16326 .49339 L
.16331 .49091 L
.1634 .48825 L
.16351 .48534 L
Mistroke
.16378 .48012 L
.1641 .47529 L
.1651 .46423 L
.16656 .4525 L
.16836 .44119 L
.17075 .42905 L
.1762 .40731 L
.183 .38619 L
.19167 .36445 L
.21104 .32696 L
.23664 .29004 L
.26571 .25803 L
.30083 .22839 L
.33819 .20461 L
.37677 .18654 L
.3975 .17917 L
.41997 .17284 L
.43014 .17052 L
.44117 .16837 L
.45075 .16681 L
.46127 .16543 L
.47098 .16444 L
.48003 .16378 L
.48505 .16352 L
.48961 .16335 L
.49213 .16328 L
.49346 .16325 L
.49487 .16323 L
.4961 .16321 L
.49745 .1632 L
.49868 .16319 L
.49983 .16319 L
Mfstroke
.49981 .88891 m
.4983 .8889 L
.49693 .88889 L
.49534 .88888 L
.49385 .88886 L
.49118 .88881 L
.4883 .88873 L
.48512 .88862 L
.48174 .88848 L
.4757 .88815 L
.46947 .88771 L
.46364 .8872 L
.45039 .88573 L
.43694 .88376 L
.4247 .88155 L
.39745 .87514 L
.37418 .86799 L
.34934 .85854 L
.30278 .83519 L
.26129 .80703 L
.22156 .77151 L
.18822 .73247 L
.16126 .69106 L
.14966 .66885 L
.1386 .64366 L
.12966 .61873 L
.12301 .59551 L
.11764 .57108 L
.11537 .55749 L
.11366 .54456 L
.11243 .53224 L
.11196 .52601 L
.11156 .51912 L
.11132 .51326 L
.11122 .50996 L
.11118 .5084 L
.11116 .50694 L
.11113 .50555 L
.11112 .50428 L
.1111 .50287 L
.1111 .50137 L
.11109 .49992 L
.1111 .49835 L
.11111 .49687 L
.11112 .4955 L
.11114 .4939 L
.11117 .49237 L
.11124 .48951 L
.11133 .48643 L
.11146 .48307 L
Mistroke
.11177 .47705 L
.11214 .47146 L
.11329 .4587 L
.11498 .44515 L
.11707 .43209 L
.11982 .41808 L
.12611 .39297 L
.13397 .36859 L
.14398 .34349 L
.16635 .30019 L
.1959 .25757 L
.22947 .2206 L
.27003 .18637 L
.31316 .15892 L
.35771 .13806 L
.38164 .12954 L
.40759 .12223 L
.41934 .11955 L
.43207 .11707 L
.44313 .11527 L
.45528 .11367 L
.4665 .11254 L
.47695 .11178 L
.48274 .11148 L
.488 .11128 L
.49092 .1112 L
.49245 .11117 L
.49408 .11114 L
.4955 .11112 L
.49706 .11111 L
.49848 .1111 L
.49981 .11109 L
Mfstroke
.5 .50435 m
.49996 .58767 L
.49994 .62669 L
.49992 .65461 L
.49991 .67736 L
.4999 .69873 L
.49989 .71733 L
.49988 .7355 L
.49987 .75176 L
.49987 .76647 L
.49986 .78128 L
.49985 .79484 L
.49985 .80731 L
.49984 .82005 L
.49983 .83186 L
.49983 .84396 L
.49982 .85523 L
.49982 .86575 L
.49981 .87661 L
.49981 .88679 L
.4998 .89731 L
.4998 .9072 L
.49979 .91649 L
.49979 .92614 L
.49978 .93478 L
s
.49915 .50426 m
.48286 .58598 L
.47524 .62424 L
.46978 .65162 L
.46533 .67394 L
.46116 .6949 L
.45752 .71314 L
.45397 .73096 L
.45079 .74691 L
.44792 .76134 L
.44502 .77586 L
.44237 .78915 L
.43993 .80138 L
.43744 .81388 L
.43514 .82546 L
.43277 .83733 L
.43057 .84838 L
.42851 .85869 L
.42639 .86935 L
.4244 .87933 L
.42234 .88965 L
.42041 .89934 L
.41859 .90845 L
.41671 .91792 L
.41502 .9264 L
s
.49833 .50402 m
.46643 .58099 L
.45149 .61703 L
.4408 .64282 L
.43209 .66384 L
.4239 .68359 L
.41678 .70077 L
.40982 .71755 L
.4036 .73258 L
.39796 .74617 L
.39229 .75984 L
.3871 .77237 L
.38233 .78389 L
.37745 .79566 L
.37293 .80656 L
.36829 .81775 L
.36398 .82816 L
.35995 .83787 L
.35579 .84791 L
.35189 .85731 L
.34786 .86703 L
.34408 .87616 L
.34052 .88474 L
.33682 .89366 L
.33352 .90165 L
s
.49758 .50362 m
.45128 .57289 L
.4296 .60533 L
.41409 .62854 L
.40145 .64746 L
.38957 .66523 L
.37923 .68069 L
.36914 .69579 L
.3601 .70932 L
.35193 .72155 L
.3437 .73386 L
.33617 .74513 L
.32924 .7555 L
.32215 .76609 L
.3156 .77591 L
.30887 .78597 L
.30261 .79534 L
.29676 .80408 L
.29072 .81312 L
.28507 .82158 L
.27922 .83033 L
.27373 .83854 L
.26857 .84627 L
.2632 .8543 L
.2584 .86148 L
s
.49692 .50308 m
.43801 .56199 L
.41042 .58958 L
.39068 .60932 L
.37459 .62541 L
.35947 .64053 L
.34632 .65368 L
.33348 .66652 L
.32198 .67802 L
.31157 .68843 L
.3011 .6989 L
.29152 .70848 L
.2827 .7173 L
.27369 .72631 L
.26534 .73466 L
.25678 .74322 L
.24881 .75119 L
.24138 .75862 L
.23369 .76631 L
.2265 .7735 L
.21906 .78094 L
.21207 .78793 L
.2055 .7945 L
.19867 .80133 L
.19256 .80744 L
s
.49638 .50242 m
.42711 .54872 L
.39467 .5704 L
.37146 .58591 L
.35254 .59855 L
.33477 .61043 L
.31931 .62077 L
.30421 .63086 L
.29068 .6399 L
.27845 .64807 L
.26614 .6563 L
.25487 .66383 L
.2445 .67076 L
.23391 .67785 L
.22409 .6844 L
.21403 .69113 L
.20466 .69739 L
.19592 .70324 L
.18688 .70928 L
.17842 .71493 L
.16967 .72078 L
.16146 .72627 L
.15373 .73143 L
.1457 .7368 L
.13852 .7416 L
s
.49598 .50167 m
.41901 .53357 L
.38297 .54851 L
.35718 .5592 L
.33616 .56791 L
.31641 .5761 L
.29923 .58322 L
.28245 .59018 L
.26742 .5964 L
.25383 .60204 L
.24016 .60771 L
.22763 .6129 L
.21611 .61767 L
.20434 .62255 L
.19344 .62707 L
.18225 .63171 L
.17184 .63602 L
.16213 .64005 L
.15209 .64421 L
.14269 .64811 L
.13297 .65214 L
.12384 .65592 L
.11526 .65948 L
.10634 .66318 L
.09835 .66648 L
s
.49574 .50085 m
.41402 .51714 L
.37576 .52476 L
.34838 .53022 L
.32606 .53467 L
.3051 .53884 L
.28686 .54248 L
.26904 .54603 L
.25309 .54921 L
.23866 .55208 L
.22414 .55498 L
.21085 .55763 L
.19862 .56007 L
.18612 .56256 L
.17454 .56486 L
.16267 .56723 L
.15162 .56943 L
.14131 .57149 L
.13065 .57361 L
.12067 .5756 L
.11035 .57766 L
.10066 .57959 L
.09155 .58141 L
.08208 .58329 L
.0736 .58498 L
s
.49565 .5 m
.41233 .50004 L
.37331 .50006 L
.34539 .50008 L
.32264 .50009 L
.30127 .5001 L
.28267 .50011 L
.2645 .50012 L
.24824 .50013 L
.23353 .50013 L
.21872 .50014 L
.20516 .50015 L
.19269 .50015 L
.17995 .50016 L
.16814 .50017 L
.15604 .50017 L
.14477 .50018 L
.13425 .50018 L
.12339 .50019 L
.11321 .50019 L
.10269 .5002 L
.0928 .5002 L
.08351 .50021 L
.07386 .50021 L
.06522 .50022 L
s
.49573 .49915 m
.414 .48295 L
.37573 .47536 L
.34835 .46993 L
.32603 .46551 L
.30506 .46135 L
.28681 .45773 L
.269 .4542 L
.25304 .45104 L
.23861 .44818 L
.22409 .4453 L
.21079 .44266 L
.19856 .44024 L
.18606 .43776 L
.17448 .43546 L
.1626 .43311 L
.15155 .43091 L
.14123 .42887 L
.13058 .42676 L
.1206 .42478 L
.11027 .42273 L
.10058 .42081 L
.09147 .419 L
.08199 .41712 L
.07352 .41544 L
s
.49598 .49834 m
.41897 .46651 L
.38292 .45161 L
.35712 .44094 L
.33609 .43225 L
.31634 .42409 L
.29915 .41698 L
.28236 .41004 L
.26733 .40383 L
.25373 .39821 L
.24005 .39255 L
.22752 .38737 L
.216 .38261 L
.20422 .37774 L
.19331 .37323 L
.18212 .36861 L
.1717 .3643 L
.16199 .36029 L
.15195 .35614 L
.14254 .35225 L
.13282 .34823 L
.12368 .34445 L
.1151 .34091 L
.10617 .33722 L
.09819 .33392 L
s
.49638 .49759 m
.42706 .45135 L
.3946 .42971 L
.37137 .41422 L
.35245 .40159 L
.33466 .38973 L
.31919 .37941 L
.30407 .36933 L
.29054 .36031 L
.2783 .35215 L
.26599 .34393 L
.25471 .33641 L
.24433 .32949 L
.23373 .32242 L
.22391 .31587 L
.21384 .30915 L
.20446 .3029 L
.19571 .29707 L
.18667 .29104 L
.17821 .28539 L
.16945 .27955 L
.16123 .27407 L
.1535 .26892 L
.14547 .26356 L
.13828 .25876 L
s
.49692 .49693 m
.43794 .43807 L
.41033 .41051 L
.39057 .39079 L
.37446 .37471 L
.35933 .35961 L
.34617 .34647 L
.33331 .33364 L
.3218 .32215 L
.31139 .31176 L
.3009 .3013 L
.29131 .29173 L
.28248 .28292 L
.27346 .27391 L
.26511 .26558 L
.25654 .25702 L
.24856 .24906 L
.24112 .24164 L
.23343 .23396 L
.22623 .22677 L
.21878 .21934 L
.21178 .21236 L
.20521 .20579 L
.19837 .19897 L
.19225 .19287 L
s
.49758 .49639 m
.45121 .42716 L
.4295 .39474 L
.41396 .37155 L
.4013 .35264 L
.3894 .33488 L
.37905 .31943 L
.36894 .30434 L
.35989 .29082 L
.35171 .2786 L
.34347 .2663 L
.33592 .25504 L
.32898 .24467 L
.32189 .23409 L
.31532 .22428 L
.30858 .21422 L
.30231 .20486 L
.29646 .19612 L
.29041 .18709 L
.28475 .17864 L
.27889 .1699 L
.27339 .16168 L
.26822 .15397 L
.26285 .14594 L
.25804 .13876 L
s
.49833 .49598 m
.46635 .41904 L
.45137 .38302 L
.44066 .35724 L
.43192 .33623 L
.42372 .31649 L
.41658 .29931 L
.40961 .28254 L
.40336 .26752 L
.39772 .25394 L
.39203 .24026 L
.38683 .22775 L
.38204 .21623 L
.37715 .20446 L
.37262 .19356 L
.36797 .18238 L
.36365 .17198 L
.35961 .16227 L
.35544 .15223 L
.35154 .14284 L
.3475 .13312 L
.3437 .12399 L
.34014 .11542 L
.33643 .1065 L
.33311 .09852 L
s
.49915 .49574 m
.48278 .41403 L
.47511 .37578 L
.46963 .34841 L
.46516 .3261 L
.46096 .30514 L
.45731 .2869 L
.45374 .26909 L
.45054 .25314 L
.44765 .23872 L
.44475 .2242 L
.44208 .21091 L
.43963 .19868 L
.43713 .18618 L
.43481 .17461 L
.43243 .16274 L
.43022 .15169 L
.42815 .14138 L
.42602 .13072 L
.42402 .12075 L
.42195 .11043 L
.42001 .10074 L
.41819 .09163 L
.41629 .08216 L
.41459 .07369 L
s
.49999 .49565 m
.49987 .41233 L
.49981 .37331 L
.49977 .34539 L
.49973 .32264 L
.4997 .30127 L
.49967 .28267 L
.49965 .2645 L
.49962 .24824 L
.4996 .23353 L
.49958 .21872 L
.49956 .20516 L
.49954 .19269 L
.49952 .17995 L
.4995 .16814 L
.49948 .15604 L
.49947 .14477 L
.49945 .13425 L
.49944 .12339 L
.49942 .11321 L
.4994 .10269 L
.49939 .0928 L
.49938 .08351 L
.49936 .07386 L
.49935 .06522 L
s
gsave
.97826 .54348 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.54348 .97826 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97826 .5 m
1 .5 L
s
% Start of user PostScript
1.1 0 1.15 0 MAarrowhead1
% End of user PostScript
.5 .97826 m
.5 1 L
s
% Start of user PostScript
0 1.1 0 1.15 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{178.313, 178.313},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002b0000/R000`400?l00000o`00003o/P3oool0
0;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3o
ool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00
F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool0
0`000000oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool00`000000
oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?oo
o`1G0?ooo`00F03oool00`000000oooo0?ooo`1G0?ooo`00F03oool00`000000oooo0?ooo`1G0?oo
o`00F03oool00`000000oooo0?ooo`1G0?ooo`00C03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0B`3oool004`0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04/0oooo001<0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1;0?ooo`00C@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0B`3oool00400
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0o0?ooo`00@@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0400oooo00110?ooo`030000003oool0oooo00T0oooo5@00
00000`3oool000000?ooo`0:0?ooo`030000003oool0oooo0400oooo00120?ooo`030000003oool0
oooo00D0oooo1000000:0?ooo`030000003oool0oooo00L0oooo0`0000090?ooo`030000003oool0
oooo0440oooo00120?ooo`040000003oool0oooo0?ooo`@00000103oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000000`0000050?ooo`030000003oool0
oooo0440oooo00120?ooo`040000003oool00000000000P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo0`0000020?ooo`030000003oool0
oooo0440oooo000f0?ooo`030000003oool0oooo00T0oooo0P00000:0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`<000002`3oool00`00
0000oooo0?ooo`0e0?ooo`00=P3oool00`000000oooo0?ooo`070?ooo`8000000P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`040000003oool00000000000T0oooo00<000000?ooo`3oool0=@3oool003L0
oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`0f0?ooo`00>03oool010000000oooo
0?ooo`3oool2000000H0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`3oool<0000
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`00
0000oooo0?ooo`0g0?ooo`00>@3oool00`000000oooo000000090?ooo`030000003oool0oooo00@0
oooo1`0000050?ooo`030000003oool0oooo00@0oooo100000080?ooo`030000003oool0oooo00L0
oooo0`00000j0?ooo`00>@3oool2000000X0oooo00@000000?ooo`3oool0oooo0`0000030?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo00000003000000@0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0h0?ooo`00>03oool00`000000oooo
0000000:0?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo0`0000000`3oool000000?ooo`090?ooo`04
0000003oool00000000003P0oooo000/0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3o
ool000002P3oool2000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo0P0000090?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0[0?ooo`00;@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool2000000030?ooo`000000oooo00P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00@000000?ooo`00000000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0;03oool002h0oooo00<000000?ooo`3oool00`3oool2000000H0
oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool010000000
oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo02d0oooo000_0?ooo`050000003oool0oooo0?ooo`0000002@3oool01000
0000oooo0000000000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`0000090?ooo`8000000P3oool00`000000oooo0?ooo`0^0?ooo`00<03oool0
0`000000oooo0000000:0?ooo`800000203oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo0P00000<0?ooo`800000<@3oool00340oooo00<000000?ooo`3oool0203oool00`00
0000oooo000000090?ooo`030000003oool0oooo00D0oooo3`0000000`3oool000000?ooo`060?oo
o`030000003oool0oooo00L0oooo0`00000:0?ooo`800000<@3oool00300oooo00<000000?ooo`00
0000203oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00`3oool30000
00L0oooo00<000000?ooo`3oool0103oool5000000<0oooo00<000000?ooo`3oool01`3oool01@00
0000oooo0?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000<03oool002l0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`800000103oool00`000000oooo0?ooo`070?ooo`D000000`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo
0P0000000`3oool000000?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool000000300oooo000^0?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00D0oooo0P0000070?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`<0
00001`3oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02d0oooo000]0?ooo`030000003oool0oooo00D0oooo0`0000090?ooo`030000
003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00@000000?ooo`000000
0000103oool00`000000oooo0?ooo`070?ooo`030000003oool0000000L0oooo00<000000?ooo`3o
ool0;03oool002D0oooo0P0000050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`80000000<0oooo0000003oool02P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo0P00000V0?ooo`009`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`0000002P3oool3000000D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`8000002P3oool00`000000oooo000000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool09P3oool002P0oooo00@000000?ooo`3oool00000
2@3oool010000000oooo0?ooo`0000080?ooo`<000001P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00D0oooo0`0000080?ooo`050000003oool0oooo0?ooo`000000203oool01000
0000oooo00000000000Y0?ooo`00:@3oool2000000T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo0P00000[0?ooo`00:P3oool3000000H0oooo00<00000
0?ooo`3oool0103oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`800000:`3oool002T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo000000P0oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool0
:03oool002T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000:0?ooo`800000
203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
1`0000000`3oool000000?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool2000000X0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0X0?ooo`00
:03oool00`000000oooo0?ooo`040?ooo`<000002P3oool2000000P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo0P00000;0?ooo`800000
1P3oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`050?ooo`8000002@3o
ool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo1@0000000`3oool00000
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0100000050?ooo`030000
003oool0oooo00H0oooo00@000000?ooo`3oool000002@3oool2000000P0oooo00<000000?ooo`3o
ool09P3oool002L0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000070?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`80
00001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool300000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`0V0?oo
o`007`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P00
00040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0N0?ooo`00803oool3000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`8000000`3o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000060?ooo`030000003oool0oooo00H0oooo
00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo0P00000Q0?ooo`008`3oool2000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool0
1P3oool3000000T0oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool01`3oool3000000P0
oooo00<000000?ooo`3oool01@3oool4000002<0oooo000U0?ooo`<000001@3oool00`000000oooo
0?ooo`080?ooo`8000002@3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00P0oooo0P0000090?ooo`030000003oool0oooo00<0oooo0`00000V0?oo
o`009@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0oooo00@000000?oo
o`3oool000002@3oool2000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`00
00001@3oool2000000T0oooo0P0000000`3oool000000?ooo`090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0T0?ooo`00903oool00`000000oooo0?ooo`020?ooo`@0
00002@3oool00`000000oooo0?ooo`020?ooo`8000001`3oool2000000D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo0P0000070?ooo`800000103oool0
0`000000oooo0?ooo`070?ooo`@00000103oool00`000000oooo0?ooo`0S0?ooo`00903oool00`00
0000oooo0?ooo`050?ooo`<000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000050?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`@000001P3oool00`000000oooo0?ooo`0S0?ooo`008`3oool00`000000oooo
0?ooo`050?ooo`040000003oool0oooo0?ooo`800000103oool00`000000oooo0?ooo`060?ooo`80
00000`3oool010000000oooo0?ooo`3oool2000000@0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000080?ooo`03
0000003oool0oooo0080oooo0P0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool08P3oool002<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000/0oooo0`0000060?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`<000002@3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`00
8`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo1000000;0?ooo`800000
1`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`040?ooo`8000002`3oool4000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0Q0?ooo`008`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P0000080?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool00000203oool2000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0Q0?ooo`008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool3000000D0oooo00@000000?ooo`3oool0oooo0P0000050?oo
o`050000003oool0oooo0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo00000080oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
0P0000030?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`00703oool3000000<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo0P00
00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool000000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool00000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`0000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
10000000oooo0?ooo`3oool4000001`0oooo000O0?ooo`H00000103oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo0`0000070?ooo`800000103oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000P3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`8000001`3oool3000000T0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`D00000803oool00280oooo00<000000?ooo`3oool0
1@0000090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000000P0000060?ooo`030000
003oool0oooo0080oooo014000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool3000000030?ooo`000000oooo00X0oooo00<000000?ooo`3oool01P3oool60000
00030?ooo`000000oooo0280oooo000R0?ooo`030000003oool0oooo00@0oooo1@0000040?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000D0oooo0P0000030?ooo`06
0000003oool0oooo0000003oool000000P3oool2000000060?ooo`000000oooo0000003oool00000
0P3oool010000000oooo0?ooo`3oool2000000D0oooo0P0000040?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool5000000H0oooo00<000000?ooo`3oool08@3oool00280oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`H000002P3oool00`000000oooo
0?ooo`040?ooo`8000001@3oool200000080oooo00L000000?ooo`3oool000000?ooo`000000oooo
0080000000D0oooo000000000000oooo000000020?ooo`030000003oool0oooo008000001@3oool2
000000H0oooo00<000000?ooo`3oool0203oool6000000@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0P0?ooo`008@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`000000100000040?ooo`030000003oool0oooo00L0oooo0`0000040?oo
o`040000003oool0oooo00000080oooo0P000000103oool000000000003oool300000080oooo00@0
00000?ooo`3oool000001@3oool2000000T0oooo00<000000?ooo`3oool00P3oool5000000030?oo
o`000000oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0P0?ooo`008@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool5000000`0oooo0P0000030?ooo`80000000D0oooo0000003oool000000?ooo`0600000080oooo
00@000000?ooo`0000000000103oool2000000/0oooo1@0000070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`008@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool4000000/0oooo
0`0000020?ooo`/0000000@0oooo0000003oool000000`3oool3000000X0oooo1000000;0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`00
8@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2@3oool010000000oooo0?ooo`3oool8000000H0oooo0P0000020?ooo`030000003oool0000000D0
000000@0oooo00000000000000000P3oool2000000D0oooo200000030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0200oooo000Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo1@0000030?ooo`80000000<0oooo00000000
0000100000000`3oool00000000000020?ooo`8000000P3oool5000000`0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0803oool00240oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool4000000040?ooo`00000000000?ooo`H0
000000<0oooo0000000000001000000A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0P00000I0?ooo`00
8@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0B0?ooo`D0000000@0oooo000000000000oooo1000000E0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo1P00000E0?ooo`004@3ooon?00000180oooo000Q0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0100oooo4P00000B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo1`00000D0?ooo`008@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`H000000`3oool7000000030?ooo`0000000000008000000`3oool5
000000d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool3000001P0oooo000Q0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00H0oooo100000070?ooo`80000000<0oooo0000000000001@000000103oool000000000003oool2
000000H0oooo1@0000080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0200oooo000Q0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0080oooo100000090?ooo`80000000<0oooo000000000000200000000`3oool00000000000020?oo
o`8000002@3oool4000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool4000001<0oooo000Q0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`H0
00002P3oool300000080oooo00D000000?ooo`00000000000?ooo`06000000030?ooo`000000oooo
008000000P3oool3000000X0oooo1@00000:0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000001@0oooo000Q0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`D0000000<0oooo0000003oool02`3oool2000000<0oooo0P0000000`3oool000000?ooo`020000
00050?ooo`00000000000000003oool00P0000001@3oool000000?ooo`3oool0000000@0oooo0P00
000;0?ooo`030000003oool0000000@000001@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000D0?ooo`008@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo1@0000060?ooo`030000003o
ool0oooo00L0oooo0`0000040?ooo`090000003oool0oooo0000003oool000000?ooo`000000oooo
0080000000L0oooo000000000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3o
ool3000000P0oooo00<000000?ooo`3oool0103oool4000000030?ooo`000000oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`80000000<0oooo000000000000503o
ool00280oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool6000000/0oooo00<0
00000?ooo`3oool00P3oool4000000D0oooo0P0000020?ooo`050000003oool000000?ooo`000000
0P3oool2000000080?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`8000001P3oool3
000000@0oooo00<000000?ooo`3oool02@3oool6000000<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0P0?ooo`008P3oool00`000000oooo0?ooo`030?ooo`D000001@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo008000001`3oool2000000<0oooo010000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3o
ool010000000oooo0?ooo`3oool2000000L0oooo0P0000020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool5000000D0oooo00<000000?ooo`3oool08@3oool00280oooo00<0
00000?ooo`0000000`0000000`3oool000000?ooo`070?ooo`030000003oool0oooo00T0oooo0`00
00080?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool2000000`0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo00000005000002<0oooo000N0?ooo`H000001P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool2000000@0oooo00@000000?ooo`3o
ool000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`0000000P3o
ool010000000oooo0?ooo`0000040?ooo`8000001`3oool3000000X0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`D000007`3oool001`0oooo0P0000050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`<0000000<0
oooo0000003oool01@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000
0P3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo0`00000L0?ooo`008`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00@000000?ooo`3oool0oooo100000050?ooo`040000003oool0oooo0?ooo`8000001@3o
ool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo0P00
00030?ooo`030000003oool0oooo00<0oooo100000030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`008`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo0`00000:0?ooo`030000003oool0000000H0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool2000000030?oo
o`000000oooo00P0oooo0P0000000`3oool000000?ooo`070?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool08P3oool002<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`800000303oool2000000H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000030?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P00000;0?ooo`8000001`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo000T0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool01`3oool200000003
0?ooo`000000oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000:0?ooo`030000003o
ool0000000800000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo000T
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000P0000040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000D0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000080?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool08`3oool002@0oooo00<000000?ooo`3oool0103oool30000
00L0oooo00<000000?ooo`3oool0103oool2000000D0oooo00@000000?ooo`3oool000001@3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000050?oo
o`8000001P3oool00`000000oooo0?ooo`050?ooo`<000001P3oool00`000000oooo0?ooo`0S0?oo
o`009@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`800000203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`0000000000103oool00`000000oooo0?oo
o`0S0?ooo`009@3oool00`000000oooo00000002000000<0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`0000090?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`8000002@3oool01@000000oooo0?ooo`3oool0000000P0oooo00<00000
0?ooo`3oool00P3oool4000002H0oooo000T0?ooo`<000001P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0000000T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0200000080oooo00<0
00000?ooo`3oool01`3oool3000000T0oooo00<000000?ooo`3oool01@3oool2000002D0oooo000R
0?ooo`80000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`060?ooo`8000002@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`8000001@3oool00`000000oooo0?ooo`070?ooo`800000203oool00`000000oooo0?oo
o`060?ooo`030000003oool00000008000008P3oool001l0oooo0`0000040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00`3oool200000080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo0?ooo`<000001P3oool2000000L0oooo00@000000?ooo`00000000001P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000P0?ooo`009P3oool00`000000oooo0?oo
o`070?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool09@3oool002L0oooo00<000000?ooo`3oool01P3oool010000000oooo
0000000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P0000000`3oool000000?ooo`070?ooo`03
0000003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo1@0000000`3oool0
00000?ooo`030?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`000006
0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000002@3oool2000000L0oooo00<0
00000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool01@3oool2000000X0oooo0P000008
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool?00000080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`8000002P3oool3000000H0oooo00<00000
0?ooo`3oool09`3oool002T0oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?oo
o`3oool01`3oool2000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool2000000T0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo02P0oooo000Y0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`02000000L0oooo00<000000?ooo`3oool00P3o
ool4000002/0oooo000Z0?ooo`<000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool2000000@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02T0oooo000Y
0?ooo`<00000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`000000:P3oool002P0oooo00@000000?ooo`3oool000002@3oool010000000oooo0?oo
o`0000080?ooo`8000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo
0P0000090?ooo`040000003oool0oooo000000P0oooo00D000000?ooo`3oool0oooo0000000Y0?oo
o`009P3oool2000000@0oooo00<000000?ooo`3oool01`3oool2000000X0oooo0`0000050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool3000000X0oooo0P0000090?ooo`03
0000003oool0oooo0080oooo0P00000W0?ooo`009@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo0P0000090?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`080?oo
o`<000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo000^0?ooo`03
0000003oool0oooo00<0oooo0P0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00`3oool2000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0`0000050?ooo`030000003oool0oooo00H0
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo02d0oooo000_0?ooo`05
0000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`800000203oool00`000000oooo0?ooo`030?ooo`8000001@3oool01@00
0000oooo0?ooo`3oool000000300oooo000`0?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000@0000000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0000000<0oooo
0000003oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00D00000
0?ooo`3oool0oooo0000000`0?ooo`00<@3oool2000000P0oooo00D000000?ooo`3oool0oooo0000
00080?ooo`030000003oool0oooo00D0oooo0`0000050?ooo`030000003oool0oooo00<0oooo1@00
00050?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0000000a0?ooo`00<@3oool2000000T0oooo0`0000080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool02`0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool2000000/0oooo00<000000?ooo`3oool0<03oool00300oooo00@000000?ooo`3oool000002@3o
ool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`<000002P3o
ool00`000000oooo0000000a0?ooo`00;`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`0000090?ooo`050000003oool0oooo0?ooo`00
0000<03oool002h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
oooo0P0000040?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`030000003oool0oooo02d0
oooo000]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`80000000<0oooo0000003oool0203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool010000000oooo0000000000070?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool2000002d0oooo000g0?ooo`800000
00<0oooo0000003oool02@3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo0`00000:0?ooo`040000003oool0oooo000003P0
oooo000i0?ooo`8000002P3oool00`000000oooo0?ooo`03000000@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0`0000020?ooo`030000
003oool0oooo00T0oooo0P00000i0?ooo`00>@3oool3000000T0oooo00<000000?ooo`3oool00`3o
ool3000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
0002000000D0oooo00<000000?ooo`3oool0203oool2000003X0oooo000i0?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool01`3oool7000000<0oooo00@000000?ooo`3oool0oooo
1`0000080?ooo`030000003oool0oooo00H0oooo0P0000000`3oool000000?ooo`0i0?ooo`00>03o
ool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo1`0000060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool2000000@0oooo00<000000?ooo`3oool0=`3oool003L0oooo00<000000?ooo`3oool01@3oool2
000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02000000L0oooo00<00000
0?ooo`3oool0=P3oool003L0oooo00<000000?ooo`3oool01`3oool3000000X0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo0`00000:0?oo
o`030000003oool0oooo03D0oooo000f0?ooo`030000003oool0oooo00X0oooo0P0000090?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`<0
0000303oool00`000000oooo0?ooo`0e0?ooo`00@`3oool00`000000oooo00000002000000H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
0`0000030?ooo`030000003oool0oooo0440oooo00120?ooo`030000003oool0oooo00<0oooo1000
00000`3oool000000?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000000P00
00060?ooo`030000003oool0oooo0440oooo00120?ooo`030000003oool0oooo00L0oooo10000008
0?ooo`030000003oool0oooo00D0oooo1@00000:0?ooo`030000003oool0oooo0400oooo00110?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0400000030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0@03oool00440oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`100?ooo`00@@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03l0oooo
001=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`1;0?ooo`00C03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0B`3oool004`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo04/0oooo001H0?ooo`030000003oool0oooo05L0oooo001H0?ooo`030000
003oool0oooo05L0oooo001F0?ooo`D00000E`3oool005H0oooo1@00001G0?ooo`00EP3oool40000
05P0oooo001G0?ooo`<000000`3oool2000005<0oooo001G0?ooo`<000000`3oool2000005<0oooo
001G0?ooo`<000000P3oool010000000oooo0?ooo`00001B0?ooo`00E`3oool200000080oooo0P00
00020?ooo`800000D@3oool005P0oooo00<000000?ooo`3oool0E`3oool005P0oooo00<000000?oo
o`3oool0E`3oool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3oool00;80oooo
002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3oool00;80oooo002b0?ooo`00/P3oool00;80
oooo002b0?ooo`00\
\>"],
    ImageRangeCache->{{{17.6875, 159.563}, {159.625, 17.75}} -> {-1, -1, 0, 
    0}}],
  StyleBox["  \n\t\t\t(c)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  A portion of ",
  StyleBox["R",
    FontFamily->"Courier New"],
  " and its image under  ",
  Cell[BoxData[
      \(w = z\^\(1\/2\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\tFigure 2.20",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Formation of the Riemann surface for  ",
  Cell[BoxData[
      \(w = z\^\(1\/2\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to draw a picture of the Riemann surface for  ",
  Cell[BoxData[
      \(w = z\^\(1\/2\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ParametricPlot3D`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[{r\ Cos[\[Theta]], 
          r\ Sin[\[Theta]], \@r\%2\ Cos[\[Theta]\/2], 
          SurfaceColor[Hue[\[Theta]\/\(2  \[Pi]\)]]}, {r, 0, 1}, {\[Theta], 
          0, 4  \[Pi]}, PlotPoints \[Rule] {20, 90}, Boxed \[Rule] False, 
        Axes \[Rule] None, AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<z\>"}, 
        ViewPoint \[Rule] {1.3, \(-3.2\), 2.0}];\)\)}], "Input"],

Cell[TextData[{
  "This is another way to draw the the Riemann surface for  ",
  Cell[BoxData[
      \(w = z\^\(1\/2\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ParametricPlot3D`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[{r\ Cos[\[Theta]], 
          r\ Sin[\[Theta]], \@r\%2\ Cos[\[Theta]\/2], {EdgeForm[], 
            SurfaceColor[Hue[\[Theta]\/\(2  \[Pi]\)]]}}, {r, 0, 
          1}, {\[Theta], 0, 4  \[Pi]}, PlotPoints \[Rule] {20, 90}, 
        Boxed \[Rule] False, Axes \[Rule] None, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<z\>"}, 
        ViewPoint \[Rule] {1.3, \(-3.2\), 1.8}];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tThe beauty of this structure is that it makes this \"full square root \
function\" continuous for all ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ".  Normally, the principal square root function would be discontinuous \
along the negative real axis, as points near ",
  Cell[BoxData[
      \(\(-1\)\)]],
  " but above that axis would get mapped to points close to ",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  ", and points near ",
  Cell[BoxData[
      \(\(-1\)\)]],
  " but below the axis would get mapped to points close to ",
  Cell[BoxData[
      \(\(-\[ImaginaryI]\)\)]],
  ".  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Graphics for Complex Functions",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexGraphicsBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{978, 621},
WindowMargins->{{15, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 532715, 15479}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 116, 2, 33, "Text"],
Cell[2221, 66, 318, 6, 52, "Text"],
Cell[2542, 74, 425, 7, 71, "Text"],
Cell[2970, 83, 1912, 68, 94, "Text",
  Evaluatable->False],
Cell[4885, 153, 824, 16, 90, "Text"],
Cell[5712, 171, 787, 26, 52, "Text",
  Evaluatable->False],
Cell[6502, 199, 331, 10, 33, "Text",
  Evaluatable->False],
Cell[6836, 211, 4063, 109, 432, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[10924, 324, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[11088, 330, 412, 15, 36, "Text"],
Cell[11503, 347, 1690, 32, 386, "Input"],
Cell[13196, 381, 104, 4, 52, "Text"],
Cell[13303, 387, 1443, 27, 285, "Input"],
Cell[14749, 416, 662, 19, 55, "Text"],
Cell[15414, 437, 1590, 30, 348, "Input"],
Cell[17007, 469, 104, 4, 52, "Text"],
Cell[17114, 475, 1331, 25, 245, "Input"],
Cell[18448, 502, 413, 11, 52, "Text"]
}, Closed]],
Cell[18876, 516, 374, 11, 37, "Text",
  Evaluatable->False],
Cell[19253, 529, 1562, 44, 180, "Text"],
Cell[20818, 575, 427, 17, 33, "Text"],

Cell[CellGroupData[{
Cell[21270, 596, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[21434, 602, 339, 9, 36, "Text"],
Cell[21776, 613, 1842, 38, 380, "Input"],
Cell[23621, 653, 422, 12, 36, "Text"]
}, Closed]],
Cell[24058, 668, 57408, 1616, 234, "Text"],
Cell[81469, 2286, 55975, 1598, 237, "Text"],
Cell[137447, 3886, 319, 14, 37, "Text"],
Cell[137769, 3902, 865, 27, 135, "Text"],
Cell[138637, 3931, 512, 15, 52, "Text"],
Cell[139152, 3948, 34117, 716, 241, "Text"],
Cell[173272, 4666, 238, 9, 37, "Text"],
Cell[173513, 4677, 909, 21, 71, "Text"],
Cell[174425, 4700, 83662, 2022, 282, "Text"],
Cell[258090, 6724, 2304, 77, 94, "Text"],
Cell[260397, 6803, 1768, 58, 75, "Text"],
Cell[262168, 6863, 82711, 2389, 221, "Text"],
Cell[344882, 9254, 64558, 2161, 221, "Text"],
Cell[409443, 11417, 119155, 3935, 221, "Text"],
Cell[528601, 15354, 215, 8, 37, "Text"],

Cell[CellGroupData[{
Cell[528841, 15366, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[528994, 15372, 193, 8, 37, "Text"],
Cell[529190, 15382, 484, 7, 85, "Input"],
Cell[529677, 15391, 141, 5, 37, "Text"],
Cell[529821, 15398, 509, 8, 85, "Input"]
}, Closed]],
Cell[530345, 15409, 626, 19, 49, "Text"],
Cell[530974, 15430, 290, 7, 33, "Text"],
Cell[531267, 15439, 303, 7, 33, "Text"],
Cell[531573, 15448, 257, 5, 33, "Text"],
Cell[531833, 15455, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

