(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     94448,       2566]*)
(*NotebookOutlinePosition[     95456,       2602]*)
(*  CellTagsIndexPosition[     95380,       2596]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 3  Analytic and Harmonic Functions",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Overview",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tDoes the notion of a derivative of a complex function make sense?  \
If so, how should it be defined and what does it represent?  These and \
similar questions are the focus of this chapter.  As you might guess, complex \
derivatives have a meaningful definition, and many of the standard derivative \
theorems from from calculus (such as the product rule and chain rule) carry \
over for complex functions.  There are also some interesting applications.  \
But not everything is symmetric.  You will learn in this chapter that the \
mean value theorem for derivatives does not extend to complex functions.  In \
later chapters you will see that differentiable complex functions are, in \
some sense, much more \"differentiable\" than differentiable real functions."
}], "Text"],

Cell[TextData[StyleBox["Section 3.1  Differentiable and Analytic Functions",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tUsing our imagination, we take our lead from elementary calculus and \
define the derivative of ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " at ",
  Cell[BoxData[
      \(z\_0\)]],
  ", written ",
  Cell[BoxData[
      \(f' \((z\_0)\)\)]],
  ", by  \n\n",
  StyleBox["(3-1)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f' \((z\_0)\)\  = \ 
        lim\+\(z\  \[Rule] \ z\_0\)\ \(f \((z)\)\  - \ f \((z\_0)\)\)\/\(z\  \
- \ z\_0\)\)]],
  ",\n\nprovided that the limit exists.  If it does, we say that the function \
",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " is differentiable at ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  If we write  ",
  Cell[BoxData[
      \(\[CapitalDelta]z = z - z\_0\)]],
  ",  then we can express Equation ",
  StyleBox["(3-1)",
    FontColor->RGBColor[0, 0, 1]],
  " in the form\n\n",
  StyleBox["(3-2)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f' \((z\_0)\)\  = \ 
        lim\+\(\[CapitalDelta]z\  \[Rule] \ 0\)\ \(f \((z\_0 + \
\[CapitalDelta]z)\)\  - \ f \((z\_0)\)\)\/\[CapitalDelta]z\)]],
  ".  \n  \n\tIf we let  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\[CapitalDelta]w = f \((z)\) - f \((z\_0)\)\)]],
  ",  then we can use the ",
  StyleBox[ButtonBox["Leibniz's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Leibniz.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " notation ",
  Cell[BoxData[
      \(dw\/dz\)]],
  " for the derivative:  \n\n",
  StyleBox["(3-3)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f' \((z\_0)\)\  = \ \(dw\/dz\  = \ 
          lim\+\(\[CapitalDelta]z\  \[Rule] \ 0\)\ \[CapitalDelta]w\/\
\[CapitalDelta]z\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the limit definition to find the derivative  ",
  Cell[BoxData[
      \(f' \((z\_0)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[\[CapitalDelta]w, \[CapitalDelta]z, f, z, 
        z];\)\ \), "\[IndentingNewLine]", 
    \(\(lim1 = 
        Limit[\(f[Z] - f[z\_0]\)\/\(Z - z\_0\), Z \[Rule] z\_0, 
          Analytic \[Rule] True];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(z \[Rule] z\_0\)\) \!\(\(f[z] - \
f[z\_0]\)\/\(z - z\_0\)\) = \>\"", lim1\ ];\)\ \)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", " ", 
          RowBox[{"lim1", " ", "\[Equal]", " ", 
            RowBox[{
              SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "[", \(z\_0\), "]"}]}], " ", "]"}], 
        ";"}], " "}]], "Input"],

Cell[BoxData[{
    \(\(lim2 = 
        Limit[\(f[z\_0 + \[CapitalDelta]z] - f[z\_0]\)\/\[CapitalDelta]z, \
\[CapitalDelta]z \[Rule] 0, 
          Analytic \[Rule] True];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(\[CapitalDelta]z \[Rule] 0\)\) \!\(\(f[z\_0 + \
\[CapitalDelta]z] - f[z\_0]\)\/\[CapitalDelta]z\) = \>\"", 
        lim2\ ];\)\ \)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", " ", 
          RowBox[{"lim2", " ", "\[Equal]", " ", 
            RowBox[{
              SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "[", \(z\_0\), "]"}]}], " ", "]"}], 
        ";"}], " "}]], "Input"],

Cell[BoxData[{
    \(\(\[CapitalDelta]w = 
        f[z\_0 + \[CapitalDelta]z] - f[z\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(lim3 = 
        Limit[\[CapitalDelta]w\/\[CapitalDelta]z, \[CapitalDelta]z \[Rule] 0, 
          Analytic \[Rule] True];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(\[CapitalDelta]z \[Rule] 0\)\) \!\(\
\[CapitalDelta]w\/\[CapitalDelta]z\) = \>\"", lim3\ ];\)\ \)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", " ", 
          RowBox[{"lim3", " ", "\[Equal]", " ", 
            RowBox[{
              SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "[", \(z\_0\), "]"}]}], " ", "]"}], 
        ";"}], " "}]], "Input",
  FormatType->TraditionalForm]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the limit definition to find the derivative of  ",
  Cell[BoxData[
      \(f \((z)\) = z\^3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  Using Equation ",
  StyleBox["(3-1)",
    FontColor->RGBColor[0, 0, 1]],
  ", we have  \n\n\t\t\t",
  Cell[BoxData[{
      \(f' \((z\_0)\)\  = \ 
        lim\+\(z\  \[Rule] \ z\_0\)\ \((z\  - \ z\_0)\)\^3\/\(z\  - \ z\_0\)\ \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(lim\+\(z\  \[Rule] \ z\
\_0\)\ \(\((z\^2\  + \ z\ z\_0\  + \ z\_0\%2)\) \((z - z\_0)\)\(\ \)\)\/\(z\  \
- \ z\_0\)\)\)\ \[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(lim\+\(z\  \[Rule] \ z\
\_0\)\ \((z\^2 + z\ z\_0 + z\_0\%2)\)\)\)\ \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\((z\_0\%2 + 
            z\_0\ z\_0 + z\_0\%2)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(3  z\_0\%2\)\)\)}]],
  "  \n\nWe can drop the subscript on ",
  Cell[BoxData[
      \(z\_0\)]],
  " to obtain  ",
  Cell[BoxData[
      \(f' \((z)\) = 3  z\^2\)]],
  "  as a general formula."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 3.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the function f[z].", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[difQuotient, \[CapitalDelta]f\[CapitalDelta]z, f, lim, sub, z, 
        Z];\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^3;\)\ \), "\n", 
    \(\(Print["\<f(z) = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Form the difference quotient.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(\[CapitalDelta]f\[CapitalDelta]z\  = \ \(f[Z] - f[z\_0]\)\/\(Z\  - \ \
z\_0\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[CapitalDelta]f\/\[CapitalDelta]z\) = \!\(\(f[z] - \
f[z\_0]\)\/\(z\\\  - \\\ z\_0\)\)\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[CapitalDelta]f\/\[CapitalDelta]z\) = \>\"", \
\[CapitalDelta]f\[CapitalDelta]z];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Observe that substitution of   ",
  Cell[BoxData[
      RowBox[{\(z\_0\), "  ", 
        StyleBox["for",
          FontFamily->"Times New Roman"], "  ", "z"}]]],
  "  indeterminate."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(sub0\  = \ 
        ReplaceAll[\[CapitalDelta]f\[CapitalDelta]z, 
          Z\  \[Rule] \*"\"\<\!\(z\_0\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(sub1\  = \ 
        ReplaceAll[\[CapitalDelta]f\[CapitalDelta]z, 
          Z\  \[Rule] z\_0];\)\ \), "\n", 
    \(\(Print[\*"\"\<Substitute Z = \!\(z\_0\), \!\(\[CapitalDelta]f\/\
\[CapitalDelta]z\) = \>\"", \[CapitalDelta]f\[CapitalDelta]z];\)\ \), "\n", 
    \(\(Print[\*"\"\<              Get  \
\!\(\[CapitalDelta]f\/\[CapitalDelta]z\) = \>\"", 
        sub0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<                   \
\!\(\[CapitalDelta]f\/\[CapitalDelta]z\) = \>\"", 
        sub1];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Calculate the derivative as the limit of the difference quotient.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(lim\  = \ 
        Limit[\[CapitalDelta]f\[CapitalDelta]z, \ 
          Z \[Rule] z\_0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(df\/dz\) = \!\(lim\+\(\[CapitalDelta]z \[Rule] 0\)\) \
\!\(\(f[z] - f[z\_0]\)\/\(z\\\  - \\\ z\_0\)\)\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(df\/dz\) = \!\(lim\+\(\[CapitalDelta]z \[Rule] 0\)\) \
\>\"", \[CapitalDelta]f\[CapitalDelta]z];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(df\/dz\) = \>\"", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Notice that the difference quotient can be simplified before substitution \
of  ",
  Cell[BoxData[
      RowBox[{\(z\_0\), "  ", 
        StyleBox["for",
          FontFamily->"Times New Roman"], "  ", "z"}]]],
  "  and can be used to find the derivative."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(difQuotient\  = \ 
        Simplify[\[CapitalDelta]f\[CapitalDelta]z];\)\ \), "\
\[IndentingNewLine]", 
    \(\(n\  = \ 
        Factor[Numerator[\[CapitalDelta]f\[CapitalDelta]z]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(d = Denominator[\[CapitalDelta]f\[CapitalDelta]z];\)\ \), "\n", 
    \(\(sub\  = \ 
        ReplaceAll[difQuotient, 
          Z\  \[Rule] z\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(df\/dz\) = \!\(lim\+\(\[CapitalDelta]z \[Rule] 0\)\) \
\!\(\(f[z] - f[z\_0]\)\/\(z\\\  - \\\ z\_0\)\)\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(df\/dz\) = \!\(lim\+\(\[CapitalDelta]z \[Rule] 0\)\) \
\>\"", \[CapitalDelta]f\[CapitalDelta]z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(df\/dz\) = \!\(lim\+\(\[CapitalDelta]z \[Rule] 0\)\) \
\>\"", n, "\</(\>", d, "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(df\/dz\) = \!\(lim\+\(\[CapitalDelta]z \[Rule] 0\)\) \
(\>\"", difQuotient, "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(df\/dz\) = \>\"", 
        sub];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Hence we have used the limit definition to find the derivative of  f[z]  \
at the point  ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  \nThus, the derivative of   ",
  Cell[BoxData[
      RowBox[{\(f \((z)\)\), "=", 
        RowBox[{
          RowBox[{\(z\^3\), "  ", 
            StyleBox["is",
              FontFamily->"Times New Roman"], "  ", \(f'\), \((z)\)}], 
          "=", \(3  z\^2\)}]}]]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\tPay careful attention to the complex value ",
  Cell[BoxData[
      \(\[CapitalDelta]z\)]],
  " in Equation ",
  StyleBox["(3-3)",
    FontColor->RGBColor[0, 0, 1]],
  "; the value of the limit must be independent of the manner in which  ",
  Cell[BoxData[
      \(\[CapitalDelta]z \[Rule] 0\)]],
  ".  If we can find two curves that end at ",
  Cell[BoxData[
      \(z\_0\)]],
  " along which ",
  Cell[BoxData[
      \(\[CapitalDelta]w\/\[CapitalDelta]z\)]],
  " approaches distinct values, then ",
  Cell[BoxData[
      \(\[CapitalDelta]w\/\[CapitalDelta]z\)]],
  " does not have a limit as  ",
  Cell[BoxData[
      \(\[CapitalDelta]z \[Rule] 0\)]],
  "  and ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " does not have a derivative at ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  The same observation applies to the limits in Equations ",
  StyleBox["(3-2)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(3-1)",
    FontColor->RGBColor[0, 0, 1]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 3.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  "Show that the function ",
  " ",
  Cell[BoxData[
      \(f \((z)\) = \(\(z\)\(\ \)\)\&_\)]],
  "  is ",
  StyleBox["nowhere ",
    FontColor->RGBColor[1, 0, 1]],
  "differentiable."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We choose two approaches to the point  ",
  Cell[BoxData[
      \(z\_0\  = \ x\_0 + \[ImaginaryI]\ y\_0\)]],
  "  and compute limits of the difference quotients.  First, we approach ",
  Cell[BoxData[
      \(z\_0\  = \ x\_0 + \[ImaginaryI]\ y\_0\)]],
  " along a line parallel to the x axis by forcing z to be of the form ",
  Cell[BoxData[
      \(z\  = \ x + \[ImaginaryI]\ y\_0\)]],
  ".   \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        " ", \(lim\+\(z\  \[Rule] \ z\_0\)\ \(f \((z)\)\  - \ f \
\((z\_0)\)\)\/\(z\  - \ z\_0\)\  = \ \ lim\+\(\((x + \[ImaginaryI]\ y\_0)\)\  \
\[Rule] \ \((x\_0 + \[ImaginaryI]\ y\_0)\)\)\ \(f \((x + \[ImaginaryI]\ y\_0)\
\)\  - \ f \((x\_0 + \[ImaginaryI]\ y\_0)\)\)\/\(\((x + \[ImaginaryI]\ \
y\_0)\)\  - \ \((x\_0 + \[ImaginaryI]\ y\_0)\)\)\), "\[IndentingNewLine]"}], 
    "\n", 
      RowBox[{
        "                                            ", \(\(=\)\(\ \ \
\)\(lim\+\(\((x + \[ImaginaryI]\ y\_0)\)\  \[Rule] \ \((x\_0 + \[ImaginaryI]\ \
y\_0)\)\)\ \(\((x - \[ImaginaryI]\ y\_0)\)\  - \ \((x\_0 - \[ImaginaryI]\ \
y\_0)\)\)\/\(\((x + \[ImaginaryI]\ y\_0)\)\  - \ \((x\_0 + \[ImaginaryI]\ \
y\_0)\)\)\)\), "\[IndentingNewLine]"}], "\n", 
      RowBox[{
        "                                            ", \(\(=\)\(\ \ \
\)\(lim\+\(\((x + \[ImaginaryI]\ y\_0)\)\  \[Rule] \ \((x\_0 + \[ImaginaryI]\ \
y\_0)\)\)\ \(\((x - \[ImaginaryI]\ y\_0)\)\  - \ \((x\_0 - \[ImaginaryI]\ \
y\_0)\)\)\/\(\((x - x\_0)\)\  + \ \[ImaginaryI] \((y\_0 - \ y\_0)\)\)\)\), 
        "\[IndentingNewLine]"}], "\n", 
      RowBox[{
        "                                            ", \(\(=\)\(\ \ \
\)\(lim\+\(\((x + \[ImaginaryI]\ y\_0)\)\  \[Rule] \ \((x\_0 + \[ImaginaryI]\ \
y\_0)\)\)\ \(x\  - \ x\_0\)\/\(x\  - \ x\_0\)\)\), "\n"}], 
    "\[IndentingNewLine]", 
      RowBox[{"                                            ", 
        RowBox[{"=", " ", 
          RowBox[{"1", 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "    "
}], "Text"],

Cell[TextData[{
  "Next, we approach ",
  Cell[BoxData[
      \(z\_0\)]],
  " along a line parallel to the y axis by forcing z to be of the form  ",
  Cell[BoxData[
      \(z\  = \ x\_0 + \[ImaginaryI]\ y\)]],
  ".   \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        " ", \(lim\+\(z\  \[Rule] \ z\_0\)\ \(f \((z)\)\  - \ f \
\((z\_0)\)\)\/\(z\  - \ z\_0\)\  = \ \ lim\+\(\((x\_0 + \[ImaginaryI]\ y)\)\  \
\[Rule] \ \((x\_0 + \[ImaginaryI]\ y\_0)\)\)\ \(f \((x\_0 + \[ImaginaryI]\ y)\
\)\  - \ f \((x\_0 + \[ImaginaryI]\ y\_0)\)\)\/\(\((x\_0 + \[ImaginaryI]\ \
y)\)\  - \ \((x\_0 + \[ImaginaryI]\ y\_0)\)\)\), "\[IndentingNewLine]"}], 
    "\n", 
      RowBox[{
        "                                            ", \(\(=\)\(\ \ \
\)\(lim\+\(\((x\_0 + \[ImaginaryI]\ y)\)\  \[Rule] \ \((x\_0 + \[ImaginaryI]\ \
y\_0)\)\)\ \(\((x\_0 - \[ImaginaryI]\ y)\)\  - \ \((x\_0 - \[ImaginaryI]\ \
y\_0)\)\)\/\(\((x\_0 + \[ImaginaryI]\ y)\)\  - \ \((x\_0 + \[ImaginaryI]\ \
y\_0)\)\)\)\), "\[IndentingNewLine]"}], "\n", 
      RowBox[{
        "                                            ", \(\(=\)\(\ \ \
\)\(lim\+\(\((x\_0 + \[ImaginaryI]\ y)\)\  \[Rule] \ \((x\_0 + \[ImaginaryI]\ \
y\_0)\)\)\ \(\((x\_0 - \[ImaginaryI]\ y)\)\  - \ \((x\_0 - \[ImaginaryI]\ \
y\_0)\)\)\/\(\((x\_0 - x\_0)\)\  + \ \[ImaginaryI] \((y - \ y\_0)\)\)\)\), 
        "\[IndentingNewLine]"}], "\n", 
      RowBox[{
        "                                            ", \(\(=\)\(\ \ \
\)\(lim\+\(\((x\_0 + \[ImaginaryI]\ y)\)\  \[Rule] \ \((x\_0 + \[ImaginaryI]\ \
y\_0)\)\)\ \(\(-\ \[ImaginaryI]\) \((y\  - \ y\_0)\)\)\/\(\[ImaginaryI] \((y\ \
 - \ y\_0)\)\)\)\), "\n"}], "\[IndentingNewLine]", 
      RowBox[{"                                            ", 
        RowBox[{"=", " ", 
          RowBox[{"-", " ", 
            RowBox[{"1", 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]}]],
  "   "
}], "Text"],

Cell[TextData[{
  "\tThe limits along the two paths are different, so there is no possible \
value for the right side of Equation ",
  StyleBox["(3-1)",
    FontColor->RGBColor[0, 0, 1]],
  ".  Therefore ",
  Cell[BoxData[
      \(f \((z)\) = \(\(z\)\(\ \)\)\&_\)]],
  "  is not differentiable at the point ",
  Cell[BoxData[
      \(z\_0\)]],
  ", and since ",
  Cell[BoxData[
      \(z\_0\)]],
  " was arbitrary, ",
  Cell[BoxData[
      \(\(\(\ \)\(\(f \((z)\)\)\(=\)\(\(\(z\)\(\ \)\)\&_\)\(\ \)\)\)\)]],
  " is ",
  StyleBox["nowhere",
    FontColor->RGBColor[1, 0, 1]],
  " differentiable."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 3.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[\[CapitalDelta]f, \[CapitalDelta]f\[CapitalDelta]x, \
\[CapitalDelta]f\[CapitalDelta]y, \[CapitalDelta]x, \[CapitalDelta]y, f, x, 
        y, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ Conjugate[z];\)\ \), "\n", 
    \(\(Print["\<f(z) = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "First, form the difference quotient using  ",
  Cell[BoxData[
      \(\[CapitalDelta]z = \[CapitalDelta]x\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(\[CapitalDelta]f\[CapitalDelta]x\  = \ \(f[x\_0\  + \ \
\[CapitalDelta]x\  + \ \[ImaginaryI]\ y\_0] - f[x\_0\  + \ \[ImaginaryI]\ \
y\_0]\)\/\(x\_0\  + \ \[CapitalDelta]x\  + \ \[ImaginaryI]\ y\_0\ \  - \ x\_0\
\  - \ \[ImaginaryI]\ y\_0\);\)\ \), "\[IndentingNewLine]", 
    \(\(n = 
        ComplexExpand[
          Numerator[\[CapitalDelta]f\[CapitalDelta]x]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(d = 
        ComplexExpand[
          Denominator[\[CapitalDelta]f\[CapitalDelta]x]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(df\/dz\) = \!\(lim\+\(\[CapitalDelta]x \[Rule] 0\)\) \
\!\(\(f[x\_0\\\  + \\\ \[CapitalDelta]x\\\  + \\\ \[ImaginaryI]\\\ y\_0] - \
f[x\_0\\\  + \\\ \[ImaginaryI]\\\ y\_0]\)\/\(x\_0\\\  + \\\ \
\[CapitalDelta]x\\\  + \\\ \[ImaginaryI]\\\ y\_0\\\ \\\  - \\\ x\_0\\\  - \\\ \
\[ImaginaryI]\\\ y\_0\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[CapitalDelta]f\/\[CapitalDelta]x\) = \>\"", \
\[CapitalDelta]f\[CapitalDelta]x];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[CapitalDelta]f\/\[CapitalDelta]x\) = \>\"", 
        n, "\</\>", d];\)\ \), "\n", 
    \(\(\[CapitalDelta]f\[CapitalDelta]x\  = \ 
        ComplexExpand[\[CapitalDelta]f\[CapitalDelta]x];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[CapitalDelta]f\/\[CapitalDelta]x\) = \>\"", \
\[CapitalDelta]f\[CapitalDelta]x];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["And this limit is easy to compute.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(lim\+\(\[CapitalDelta]z \[Rule] 0\)\) \!\(\
\[CapitalDelta]f\/\[CapitalDelta]z\) = \!\(lim\+\(\[CapitalDelta]x \[Rule] \
0\)\) \>\"", n, "\</\>", d, "\< = \>", 
        Limit[\[CapitalDelta]f\[CapitalDelta]x, \[CapitalDelta]x \[Rule] 
            0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<where  \[CapitalDelta]z = \[CapitalDelta]x\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Second, form the difference quotient using  ",
  Cell[BoxData[
      \(\[CapitalDelta]z = \[ImaginaryI]\ \[CapitalDelta]y\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(\[CapitalDelta]f\[CapitalDelta]y\  = \ \(f[x\_0\  + \ \[ImaginaryI] \
\((y\_0 + \[CapitalDelta]y)\)] - f[x\_0\  + \ \[ImaginaryI]\ y\_0]\)\/\(x\_0\ \
 + \ \[ImaginaryI] \((y\_0 + \[CapitalDelta]y)\)\ \  - \ x\_0\  - \ \
\[ImaginaryI]\ y\_0\);\)\ \), "\[IndentingNewLine]", 
    \(\(n = 
        ComplexExpand[
          Numerator[\[CapitalDelta]f\[CapitalDelta]y]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(d = 
        ComplexExpand[
          Denominator[\[CapitalDelta]f\[CapitalDelta]y]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(df\/dz\) = \!\(lim\+\(\[CapitalDelta]y \[Rule] \
0\)\) \!\(\(f[x\_0\\\  + \\\ \[ImaginaryI] \((y\_0 + \[CapitalDelta]y)\)] - \
f[x\_0\\\  + \\\ \[ImaginaryI]\\\ y\_0]\)\/\(x\_0\\\  + \\\ \[ImaginaryI] \
\((y\_0 + \[CapitalDelta]y)\)\\\ \\\  - \\\ x\_0\\\  - \\\ \[ImaginaryI]\\\ y\
\_0\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[CapitalDelta]f\/\(\[ImaginaryI]\\\ \
\[CapitalDelta]y\)\) = \>\"", \[CapitalDelta]f\[CapitalDelta]y];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[CapitalDelta]f\/\(\[ImaginaryI]\\\ \
\[CapitalDelta]y\)\) = \>\"", n, "\</\>", d];\)\ \), "\n", 
    \(\(\[CapitalDelta]f\[CapitalDelta]y\  = \ 
        ComplexExpand[\[CapitalDelta]f\[CapitalDelta]y];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[CapitalDelta]f\/\(\[ImaginaryI]\\\ \
\[CapitalDelta]y\)\) = \>\"", \[CapitalDelta]f\[CapitalDelta]y];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["And this limit is easy to compute.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(lim\+\(\[CapitalDelta]z \[Rule] 0\)\) \!\(\
\[CapitalDelta]f\/\[CapitalDelta]z\) = \!\(lim\+\(\[CapitalDelta]y \[Rule] \
0\)\) \>\"", n, "\</\>", d, "\< = \>", 
        Limit[\[CapitalDelta]f\[CapitalDelta]y, \[CapitalDelta]y \[Rule] 
            0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<where  \[CapitalDelta]z = \[ImaginaryI] \
\[CapitalDelta]y\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Since the two limits are different for any point  ",
  Cell[BoxData[
      \(z\_0, \ f' \((z\_0)\)\)]],
  "  does ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " exist for any  ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(lim\+\(\[CapitalDelta]z \[Rule] 0\)\) \!\(\
\[CapitalDelta]f\/\[CapitalDelta]z\) = \>\"", 
        Limit[\[CapitalDelta]f\[CapitalDelta]x, \[CapitalDelta]x \[Rule] 
            0], "\<,   where  \[CapitalDelta]z = \[CapitalDelta]x\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(\[CapitalDelta]z \[Rule] 0\)\) \!\(\
\[CapitalDelta]f\/\[CapitalDelta]z\) = \>\"", 
        Limit[\[CapitalDelta]f\[CapitalDelta]y, \[CapitalDelta]y \[Rule] 
            0], "\<,  where  \[CapitalDelta]z = \[ImaginaryI] \
\[CapitalDelta]y\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " differentiate  ",
  Cell[BoxData[
      \(f \((z)\) = \(\(z\)\(\ \)\)\&_\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\< f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f'[x] = \>", \(f'\)[x]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The limit definition has shown that ",
  Cell[BoxData[
      \(f \((z)\) = \(\(z\)\(\ \)\)\&_\)]],
  "  is ",
  StyleBox["nowhere ",
    FontColor->RGBColor[1, 0, 1]],
  "differentiable."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark 3.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  In Section 2.3 we showed that ",
  Cell[BoxData[
      \(f \((z)\) = \(\(z\)\(\ \)\)\&_\)]],
  "  is continuous for all ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ".  Thus, we have a simple example of a function that is continuous \
everywhere but differentiable nowhere.  Such functions are hard to construct \
in real variables. In some sense, the complex case has made pathological \
constructions simpler!"
}], "Text"],

Cell[TextData[{
  "\tWe seldom are interested in studying functions that aren't \
differentiable, or are differentiable at only a single point.  Complex \
functions that have a derivative at all points in a neighborhood of ",
  Cell[BoxData[
      \(z\_0\)]],
  " deserve further study.  In Chapter 7 we demonstrate that, if the complex \
function ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " can be represented by a Taylor series at ",
  Cell[BoxData[
      \(z\_0\)]],
  ", then it must be differentiable in some neighborhood of ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  Functions that are differentiable in neighborhoods of points are \
pillars of the complex analysis edifice; we give them a special name, as \
indicated in the following definition."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 3.1 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Analytic Function",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/AnalyticFunction.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "The complex function ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " is analytic at the point ",
  Cell[BoxData[
      \(z\_0\)]],
  " provided there is some ",
  Cell[BoxData[
      \(\[Epsilon] > 0\)]],
  " such that ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " exists for all ",
  Cell[BoxData[
      \(z \[Element] \(D\_\[Epsilon]\) \((z\_0)\)\)]],
  ".  In other words, ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " must be differentiable not only at ",
  Cell[BoxData[
      \(z\_0\)]],
  ", but also at all points in some ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  "-neighborhood of ",
  Cell[BoxData[
      \(z\_0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\n\tIf ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic at each point in the region ",
  StyleBox["R",
    FontFamily->"Courier New"],
  ", then we say that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic on ",
  StyleBox["R",
    FontFamily->"Courier New"],
  ".  Again, we have a special term if ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic on the whole complex plane. "
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 3.2 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Entire Function",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/EntireFunction.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "If ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic on the whole complex plane then ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is said to be entire. "
}], "Text"],

Cell["\<\
\tPoints of nonanalyticity for a function are called singular points. They \
are important for certain applications in physics and engineering.\
\>", "Text"],

Cell["\<\
\tOur definition of the derivative for complex functions is formally the same \
as for real functions and is the natural extension from real variables to \
complex variables.  The basic differentiation formulas are identical to those \
for real functions, and we obtain the same rules for differentiating powers, \
sums, products, quotients, and compositions of functions.  We can easily \
establish the proof of the differentiation formulas by using the limit \
theorems.\
\>", "Text"],

Cell[TextData[StyleBox["The Rules for Differentiation.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tSuppose that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " are differentiable.  From Equation ",
  StyleBox["(3-2)",
    FontColor->RGBColor[0, 0, 1]],
  " and the technique exhibited in the solution to Example 3.1 we can \
establish the following rules, which are virtually identical to those for \
real-valued functions.  \n\n",
  Cell[BoxData[GridBox[{
          {
            StyleBox[\(\((3 - 4)\)\(\ \)\(\[IndentingNewLine]\)
              \(\ \)\),
              FontFamily->"Times New Roman",
              FontWeight->"Plain",
              FontColor->RGBColor[0, 0, 0.996109]], "           ", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[\(d\/dz\),
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["C",
                    FontFamily->"Courier New",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}], 
                StyleBox[" ",
                  FontFamily->"Courier New",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["=",
                  FontFamily->"Courier New",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Courier New",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["0",
                  FontFamily->"Courier New",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              RowBox[{
                StyleBox["where",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["C",
                  FontFamily->"Courier New",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["is",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["a",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["constant",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              
              StyleBox[
                "                                                           ",
                
                FontFamily->"Times New Roman",
                FontSize->12,
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]},
          {
            RowBox[{
              StyleBox[\((3 - 5)\),
                FontFamily->"Times New Roman",
                FontWeight->"Plain",
                FontColor->RGBColor[0, 0, 0.996109]], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontWeight->"Plain",
                FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}],
             "           ", 
            RowBox[{\(\(d\/dz\) z\^n\  = \ n\ z\^\(n - 1\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              RowBox[{
                StyleBox["where",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], " ", "n", " ", 
                StyleBox["is",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["a",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["positive",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["integer",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["                            ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]},
          {
            RowBox[{
              StyleBox[\((3 - 6)\),
                FontFamily->"Times New Roman",
                FontWeight->"Plain",
                FontColor->RGBColor[0, 0, 0.996109]], 
              StyleBox["  ",
                FontFamily->"Times New Roman",
                FontWeight->"Plain",
                FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}],
             "           ", 
            RowBox[{\(\(d\/dz\)[C\ f \((z)\)]\  = \ C\ f' \((z)\)\), 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              "                                                 "}]},
          {
            RowBox[{
              StyleBox[\((3 - 7)\),
                FontFamily->"Times New Roman",
                FontWeight->"Plain",
                FontColor->RGBColor[0, 0, 0.996109]], 
              StyleBox["  ",
                FontFamily->"Times New Roman",
                FontWeight->"Plain",
                FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}],
             "           ", 
            
            RowBox[{\(\(d\/dz\)[f \((z)\) + g \((z)\)]\  = \ 
                f' \((z)\) + g' \((z)\)\), 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[
                RowBox[{
                  StyleBox["                                  ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], " "}]]}]},
          {
            RowBox[{
              StyleBox[\((3 - 8)\),
                FontFamily->"Times New Roman",
                FontWeight->"Plain",
                FontColor->RGBColor[0, 0, 0.996109]], 
              StyleBox["  ",
                FontFamily->"Times New Roman",
                FontWeight->"Plain",
                FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}],
             "           ", 
            
            RowBox[{\(\(d\/dz\)[f \((z)\) g \((z)\)]\  = \ 
                f \((z)\)\ g' \((z)\) + g \((z)\)\ f' \((z)\)\), 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["      ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]},
          {
            RowBox[{
              StyleBox[\((3 - 9)\),
                FontFamily->"Times New Roman",
                FontWeight->"Plain",
                FontColor->RGBColor[0, 0, 0.996109]], 
              StyleBox["  ",
                FontFamily->"Times New Roman",
                FontWeight->"Plain",
                FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}],
             "           ", 
            RowBox[{
              
              StyleBox[\(\(d\/dz\) \(f \((z)\)\)\/\(g \((z)\)\)\ \  = \ \(g \
\((z)\)\ f' \((z)\)\  - \ f \((z)\)\ g' \((z)\)\)\/\([g \((z)\)]\)\^2\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              RowBox[{
                StyleBox[
                  RowBox[{
                    StyleBox["provided",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox[" ",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox["that",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox[" ",
                      FontFamily->"Courier New",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox["g",
                      FontFamily->"Courier New",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox[\((z)\),
                      FontFamily->"Courier New",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}]}],
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["\[NotEqual]",
                  FontFamily->"Courier New",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["0",
                  FontFamily->"Courier New",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]},
          {
            StyleBox[\((3 - 10)\),
              FontFamily->"Times New Roman",
              FontWeight->"Plain",
              FontColor->RGBColor[0, 0, 0.996109]], "           ", 
            RowBox[{\(\(d\/dz\) f \((g \((z)\))\)\), " ", "=", " ", 
              RowBox[{\(f'\), "f", \((g \((z)\))\), " ", \(g'\), 
                RowBox[{\((z)\), 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[".",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[
                    RowBox[{
                      StyleBox["                                       ",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], " "}]]}]}]}]}
          }]]],
  "  "
}], "Text"],

Cell[TextData[{
  "Important particular cases of Equations ",
  StyleBox["(3-9)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(3-10)",
    FontColor->RGBColor[0, 0, 1]],
  ", respectively, are  \n\n",
  Cell[BoxData[GridBox[{
          {
            RowBox[{
              StyleBox[\((3 - 11)\),
                FontFamily->"Times New Roman",
                FontWeight->"Plain",
                FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}],
             "           ", 
            RowBox[{\(\(d\/dz\) 1\/z\^n\ \  = \ \(-n\)\/z\^\(n + 1\)\), 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              RowBox[{
                RowBox[{
                  StyleBox["for",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Courier New",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["z",
                    FontFamily->"Courier New",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}], 
                StyleBox["\[NotEqual]",
                  FontFamily->"Courier New",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["0",
                  FontFamily->"Courier New",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              RowBox[{
                StyleBox["and",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], " ", "n", " ", 
                StyleBox["is",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["a",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["positive",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["integer",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["                              ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]},
          {
            StyleBox[\((3 - 12)\),
              FontFamily->"Times New Roman",
              FontWeight->"Plain",
              FontColor->RGBColor[0, 0, 0.996109]], "           ", 
            
            RowBox[{\(\(d\/dz\)[f \((z)\)]\^n\  = \ 
                n\ [f \((z)\)]\^\(n - 1\)\ f' \((z)\)\), 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              RowBox[{
                StyleBox["where",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], " ", "n", " ", 
                StyleBox["is",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["a",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["positive",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[\(\(integer\)\(\ \)\(.\)\),
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}]}
          }]]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for the Rules for Differentiation.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the functions and differentiate.
Find the derivative of a scalar multiple.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, f, F, g1, g2, g3, g4, g5, z];\)\ \), "\n", 
    \(\(c\  = \ a\  + \ \[ImaginaryI]\ b;\)\ \), "\n", 
    \(\(g1[z_]\  = \ c\ f[z];\)\ \), "\n", 
    \(\(\(g1'\)[z];\)\ \), "\n", 
    \(\(Print["\<Derivative of a scalar multiple.\>"];\)\ \), "\n", 
    \(\(Print["\< F[z] = \>", g1[z]];\)\ \), "\n", 
    \(\(Print["\< F[z] = \>", Expand[g1[z]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<F'[z] = \>", \(g1'\)[z]];\)\ \), "\n", 
    \(\(Print["\<F'[z] = \>", 
        Expand[\(g1'\)[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Find the derivative of a linear combination.", "Text"],

Cell[BoxData[{
    \(\(g2[
          z_]\  = \ \((a\_1 + \[ImaginaryI]\ b\_1)\)\ f[
              z]\  + \ \((a\_2 + \[ImaginaryI]\ b\_2)\)\ g[z];\)\ \), "\n", 
    \(\(\(g2'\)[z];\)\ \), "\n", 
    \(\(Print["\<Derivative of a linear combination.\>"];\)\ \), "\n", 
    \(\(Print["\< F[z] = \>", g2[z]];\)\ \), "\n", 
    \(\(Print["\< F[z] = \>", Expand[g2[z]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<F'[z] = \>", \(g2'\)[z]];\)\ \), "\n", 
    \(\(Print["\<F'[z] = \>", 
        Expand[\(g2'\)[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Find the derivative of a product of two functions.", "Text"],

Cell[BoxData[{
    \(\(g3[z_]\  = \ f[z]\ g[z];\)\ \), "\n", 
    \(\(\(g3'\)[z];\)\ \), "\n", 
    \(\(Print["\<Derivative of the product of two functions.\>"];\)\ \), "\n\
", 
    \(\(Print["\< F[z] = \>", g3[z]];\)\ \), "\n", 
    \(\(Print["\<F'[z] = \>", \(g3'\)[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Find the derivative of the quotient of two functions.", "Text"],

Cell[BoxData[{
    \(\(g4[z_]\  = \ f[z]\/g[z];\)\ \), "\n", 
    \(\(Print["\<Derivative of the quotient of two functions.\>"];\)\ \), "\n\
", 
    \(\(Print["\< F[z] = \>", g4[z]];\)\ \), "\n", 
    \(\(Print["\<F'[z] = \>", 
        Together[\(g4'\)[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Find the derivative of the composition of two functions.", "Text"],

Cell[BoxData[{
    \(\(g5[z_]\  = \ f[g[z]];\)\ \), "\n", 
    \(\(\(g5'\)[z];\)\ \), "\n", 
    \(\(Print["\<Derivative of the composition of two functions.\>"];\)\ \), \
"\n", 
    \(\(Print["\< F[z] = \>", g5[z]];\)\ \), "\n", 
    \(\(Print["\<F'[z] = \>", 
        Together[\(g5'\)[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  If we use Equation ",
  StyleBox["(3-12)",
    FontColor->RGBColor[0, 0, 1]],
  " with  ",
  Cell[BoxData[
      \(f \((z)\) = z\^2 + \[ImaginaryI]\ 2  z + 3\)]],
  ",  and  ",
  Cell[BoxData[
      \(f' \((z)\) = 2  z + \ 2  \[ImaginaryI]\)]],
  ",  then we get  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(\(d\/dz\) \((z\^2 + \[ImaginaryI]\ 2  z + 3)\)\^4\  = \ 
          4 \(\((z\^2 + \[ImaginaryI]\ 2  z + 3)\)\^3\) \((2  z + \ 
                2  \[ImaginaryI])\)\), "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"                                       ", 
        RowBox[{"=", " ", 
          RowBox[{"8", \(\((z\^2 + \[ImaginaryI]\ 2  z + 3)\)\^3\), 
            RowBox[{\((z + \ \[ImaginaryI])\), 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["  ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 3.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[f, g, w, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^2\  + \ \[ImaginaryI]\ 2  z\  + \ 3;\)\ \), "\n", 
    \(\(F[z_]\  = \ \((f[z])\)\^4;\)\ \), "\[IndentingNewLine]", 
    \(\(g[w_] = w\^4;\)\ \), "\n", 
    \(\(Print["\< f(z) = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<f'(z) = \>", \(f'\)[z]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< g(w) = \>", g[w]];\)\ \), "\n", 
    \(\(Print["\<g'(w) = \>", \(g'\)[w]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g'(f(z)) = \>", \(g'\)[f[z]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\< F(z) = \>", F[z]];\)\ \), "\n", 
    \(\(Print["\<F'(z) = \>", \(F'\)[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F'(z) = g'[f[z] f'[z]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F'(z) = \>", \(g'\)[f[z]] \(f'\)[
            z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  This can be ",
  "compared",
  " with expanding F[z] and calculating the derivative"
}], "Text"],

Cell[BoxData[{
    \(\(Print["\< F(z) = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(H[z_] = Expand[F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< F(z) = \>", H[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F'(z) = \>", \(H'\)[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<F'(z) = g'[f[z] f'[z]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F'(z) = \>", \(g'\)[f[z]] \(f'\)[
            z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F'(z) = \>", 
        Expand[\(g'\)[f[z]] \(f'\)[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tThe proofs of the rules given in Equations  through ",
  StyleBox["(3-10)",
    FontColor->RGBColor[0, 0, 1]],
  " depend on the validity of extending theorems for real functions to their \
complex companions.  Equation ",
  StyleBox["(3-8)",
    FontColor->RGBColor[0, 0, 1]],
  ", for example, relies on Theorem 3.1. "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 3.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is differentiable at  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  then ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is continuous at  ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Proof.  From Equation (3-1), we obtain  \n\n\t\t\t",
  Cell[BoxData[
      \(lim\+\(z\  \[Rule] \ z\_0\)\ \(f \((z)\)\  - \ f \((z\_0)\)\)\/\(z\  \
- \ z\_0\)\ \  = \ \ f' \((z\_0)\)\)]],
  ".  \n\nUsing the multiplicative property of limits given by Formula ",
  StyleBox["(2-19)",
    FontColor->RGBColor[0, 0, 1]],
  ", we get\n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(lim\+\(z\  \[Rule] \ z\_0\)\ \([f \((z)\)\  - \ 
                f \((z\_0)\)]\)\ \  = \ \ lim\+\(z\  \[Rule] \ z\_0\)\ \(\(f \
\((z)\)\  - \ f \((z\_0)\)\)\/\(z\  - \ z\_0\)\) \((z\  - \ z\_0)\)\), "\n"}],
     "\[IndentingNewLine]", 
      RowBox[{
        "                                                    ", \(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] \ z\_0\)\ \(f \((z)\)\  - \ f \((z\_0)\)\)\/\(z\  - \ \
z\_0\)\ \ \(lim\+\(z\  \[Rule] \ z\_0\)\((z\  - \ z\_0)\)\)\)\), 
        "\[IndentingNewLine]"}], "\n", 
      RowBox[{"                                                    ", 
        RowBox[{"=", "  ", 
          RowBox[{\(f' \((z\_0)\)*0\), "  ", "=", "  ", 
            RowBox[{"0", 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]}]],
  "  \n\n This result implies that  ",
  Cell[BoxData[
      \(lim\+\(z\  \[Rule] \ z\_0\)\ f \((z)\)\  = \ f \((z\_0)\)\)]],
  ",  which is equivalent to showing that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is continuous at ",
  Cell[BoxData[
      \(z\_0\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.1 is also in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  "\tWe can establish Equation ",
  StyleBox["(3-8)",
    FontColor->RGBColor[0, 0, 1]],
  " from Theorem 3.1.  Letting ",
  Cell[BoxData[
      \(h \((z)\) = f \((z)\) g \((z)\)\)]],
  " and using Definition 3.1, we write   \n\n\t\t",
  Cell[BoxData[
      \(h' \((z\_0)\)\  = \ \(lim\+\(z\  \[Rule] \ z\_0\)\ \(h \((z)\)\  - \ \
h \((z\_0)\)\)\/\(z\  - \ z\_0\) = \ 
          lim\+\(z\  \[Rule] \ z\_0\)\ \(f \((z)\) g \((z)\)\  - \ f \((z\_0)\
\)\ g \((z\_0)\)\)\/\(z\  - \ z\_0\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "If we subtract and add the term ",
  Cell[BoxData[
      \(f \((z\_0)\) g \((z)\)\)]],
  " in the numerator, we get\n\n\t\t",
  Cell[BoxData[{
      \(h' \((z\_0)\)\  = \ 
        lim\+\(z\  \[Rule] \ z\_0\)\ \(f \((z)\) g \((z)\)\  - f \((z\_0)\) g \
\((z)\) + f \((z\_0)\) g \((z)\) - \ f \((z\_0)\)\ g \((z\_0)\)\)\/\(z\  - \ \
z\_0\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(lim\+\(z\  \[Rule] \ z\
\_0\)\ \(f \((z)\) g \((z)\)\  - f \((z\_0)\) g \((z)\)\)\/\(z\  - \ z\_0\)\  \
+ \ \ lim\+\(z\  \[Rule] \ z\_0\)\ \(f \((z\_0)\) g \((z)\) - \ f \((z\_0)\)\ \
g \((z\_0)\)\)\/\(z\  - \ z\_0\)\)\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(lim\+\(z\  \[Rule] \ z\
\_0\)\ \(\((f \((z)\)\  - f \((z\_0)\))\) g \((z)\)\)\/\(z\  - \ z\_0\)\  + \ \
\ lim\+\(z\  \[Rule] \ z\_0\)\ \(f \((z\_0)\) \((g \((z)\) - \ f \((z\_0)\)\ \
g \((z\_0)\))\)\)\/\(z\  - \ z\_0\)\)\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(lim\+\(z\  \[Rule] \ z\
\_0\)\ \(\(f \((z)\)\  - f \((z\_0)\)\)\/\(z\  - \ 
                    z\_0\)\) \(lim\+\(z\  \[Rule] \ z\_0\)\ 
                g \((z)\)\)\  + \ \ lim\+\(z\  \[Rule] \ z\_0\)\ 
            f \((z\_0)\)\ \(lim\+\(z\  \[Rule] \ z\_0\)\ \(g \((z)\) - \ f \
\((z\_0)\)\ g \((z\_0)\)\)\/\(z\  - \ z\_0\)\)\)\)\)}]],
  "   "
}], "Text"],

Cell[TextData[{
  "Using the definition of the derivative given by Equation ",
  StyleBox["(3-1)",
    FontColor->RGBColor[0, 0, 1]],
  " and the continuity of ",
  Cell[BoxData[
      \(g \((z)\)\)]],
  ", we obtain  ",
  Cell[BoxData[
      \(h' \((z\_0)\)\  = \ 
        f' \((z\_0)\)\ g \((z\_0)\) + \ f \((z\_0)\)\ g' \((z\_0)\)\)]],
  ",  which is what we wanted to establish.  We leave the proofs of the other \
rules as exercises."
}], "Text"],

Cell[TextData[{
  "\tThe rule for differentiating polynomials carries over to the complex \
case as well.  If we let P(z) be a polynomial of degree n, so   \n\n\t\t\t",
  Cell[BoxData[
      \(P \((z)\)\  = \ \(a\_0\  + \ \(a\_1\) z\  + \ \(a\_2\) 
                z\^2\  + \ \(a\_3\) z\^3\  +  ... \)\  + \ \(a\_n\) z\^n\)]],
  ",  \n\nthen mathematical induction, along with Equations ",
  StyleBox["(3-5)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(3-7)",
    FontColor->RGBColor[0, 0, 1]],
  ", gives  \n\n\t\t\t",
  Cell[BoxData[
      \(P' \((z)\)\  = \ \(a\_1\  + \ 2 \( a\_2\) z\  + \ 
              3 \( a\_3\) z\^2\  +  ... \)\  + \ \(a\_\(n - 1\)\) 
            z\^\(n - 1\)\)]],
  ".  \n\nAgain, we leave the proof of this result as an exercise."
}], "Text"],

Cell[TextData[{
  "\tWe can use the differentiation rules as aids in determining when \
functions are analytic.  For example, Equation ",
  StyleBox["(3-9)",
    FontColor->RGBColor[0, 0, 1]],
  " tells us that if ",
  Cell[BoxData[
      RowBox[{"P", \((z)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "Q", \((z)\)}]]],
  " are polynomials, then their quotient  ",
  Cell[BoxData[
      \(\(P \((z)\)\)\/\(Q \((z)\)\)\)]],
  "   is analytic at all points where ",
  Cell[BoxData[
      \(Q \((z)\) \[NotEqual] 0\)]],
  ".  This condition implies that the function ",
  Cell[BoxData[
      \(f \((z)\) = 1\/z\)]],
  "  is analytic for all ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ".  \n\n\tThe square root function is more complicated.  If  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(\(|\)\(z\)\( | \^\(1\/2\)\)\)\)]],
  Cell[BoxData[
      \(\[ExponentialE]\^\(\[ImaginaryI]\ \(Arg \((z)\)\)\/2\)\)]],
  ",  then ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " is analytic at all points except ",
  Cell[BoxData[
      \(z = 0\)]],
  "  (because ",
  Cell[BoxData[
      \(Arg \((0)\)\)]],
  " is undefined) and at points that lie along the negative ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " axis.  The argument function, and therefore the function ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " itself, are not continuous at points that lie along the negative ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " axis."
}], "Text"],

Cell[TextData[{
  "\tWe close this section with a complex extension of a famous theorem, \
which is attributed to ",
  StyleBox[ButtonBox["Guillaume Fran\[CCedilla]ois Antoine Marquis de L'H\
\[OHat]pital",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/De_L'\
Hopital.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " (1661-1704).  The proof of will be given in Chapter 7.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 3.2, (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["L'H\[OHat]pital's Rule",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LHospitalsRule.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " are both analytic at ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  If ",
  Cell[BoxData[
      \(f \((z\_0)\) = 0\)]],
  ", ",
  Cell[BoxData[
      \(g \((z\_0)\) = 0\)]],
  ", and ",
  Cell[BoxData[
      \(g' \((z\_0)\) \[NotEqual] 0\)]],
  "  then  \n\n\t\t\t",
  Cell[BoxData[
      \(lim\+\(z \[Rule] z\_0\)\ \(f \((z)\)\)\/\(g \((z)\)\) = \(f' \((z\_0)\
\)\)\/\(g' \((z\_0)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Proof of Theorem 3.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  ",
  "We defer the proof until Chapter 7, where we will learn some amazing \
things about analytic functions.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for L'Hospital's Rule.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can do it all, however care must be taken with the higher derivative \
cases.  Make the assumption that  ",
  Cell[BoxData[
      \(f \((z\_0)\) = \(0\ \ and\ \ g \((z\_0)\) = 0\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, g, lim, z];\)\ \), "\n", 
    \(\(f[z\_0]\  = \ 0;\)\ \), "\n", 
    \(\(g[z\_0]\  = \ 0;\)\ \), "\n", 
    \(\(lim\  = \ 
        Limit[f[Z]\/g[Z], \ Z \[Rule] z\_0, \ 
          Analytic \[Rule] True];\)\ \), "\n", 
    \(\(Print[\*"\"\<     f[\!\(z\_0\)] = \>\"", f[z\_0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<     g[\!\(z\_0\)] = \>\"", g[z\_0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<    f'[\!\(z\_0\)] = \>\"", \(f'\)[z\_0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<    g'[\!\(z\_0\)] = \>\"", \(g'\)[
          z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    \!\(f[z\_0]\/g[z\_0]\) = \>\"", f[z\_0], "\</\>", 
        g[z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    \!\(f[z\_0]\/g[z\_0]\) = \>\"", 
        f[z\_0]\/g[z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(z \[Rule] z\_0\)\) \!\(f[z]\/g[z]\) = \>\"", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Now, make the second additional assumption that  ",
  Cell[BoxData[
      RowBox[{\(f' \((z\_0)\)\), "=", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], "  ", \(g'\), \((z\_0)\)}], "=",
           "0"}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, g, lim, z];\)\ \), "\n", 
    \(\(f[z\_0]\  = \ 0;\)\ \), "\n", 
    \(\(g[z\_0]\  = \ 0;\)\ \), "\[IndentingNewLine]", 
    \(\(\(f'\)[z\_0]\  = \ 0;\)\ \), "\n", 
    \(\(\(g'\)[z\_0]\  = \ 0;\)\ \), "\n", 
    \(\(lim\  = \ 
        Limit[f[Z]\/g[Z], \ Z \[Rule] z\_0, \ 
          Analytic \[Rule] True];\)\ \), "\n", 
    \(\(Print[\*"\"\<      f[\!\(z\_0\)] = \>\"", f[z\_0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<      g[\!\(z\_0\)] = \>\"", g[z\_0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<     f'[\!\(z\_0\)] = \>\"", \(f'\)[
          z\_0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<     g'[\!\(z\_0\)] = \>\"", \(g'\)[
          z\_0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<    f''[\!\(z\_0\)] = \>\"", \(\(f'\)'\)[
          z\_0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<    g''[\!\(z\_0\)] = \>\"", \(\(g'\)'\)[
          z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(f[z\_0]\/g[z\_0]\) = \>\"", f[z\_0], "\</\>", 
        g[z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    \!\(\(f'\)[z\_0]\/\(g'\)[z\_0]\) = \>\"", \(f'\)[
          z\_0], "\</\>", \(g'\)[z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<      \!\(f[z\_0]\/g[z\_0]\) = \>\"", 
        f[z\_0]\/g[z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<  \!\(lim\+\(z \[Rule] z\_0\)\) \!\(f[z]\/g[z]\) = \
\>\"", lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The third additional assumption is that  ",
  Cell[BoxData[
      RowBox[{\(f'' \((z\_0)\)\), "=", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], "  ", \(g''\), \((z\_0)\)}], 
          "=", "0"}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, g, lim, z];\)\ \), "\n", 
    \(\(f[z\_0]\  = \ 0;\)\ \), "\n", 
    \(\(g[z\_0]\  = \ 0;\)\ \), "\[IndentingNewLine]", 
    \(\(\(f'\)[z\_0]\  = \ 0;\)\ \), "\n", 
    \(\(\(g'\)[z\_0]\  = \ 0;\)\ \), "\[IndentingNewLine]", 
    \(\(\(f''\)[z\_0]\  = \ 0;\)\ \), "\n", 
    \(\(\(g''\)[z\_0]\  = \ 0;\)\ \), "\n", 
    \(\(lim\  = \ 
        Limit[f[Z]\/g[Z], \ Z \[Rule] z\_0, \ 
          Analytic \[Rule] True];\)\ \), "\n", 
    \(\(Print[\*"\"\<       f[\!\(z\_0\)] = \>\"", f[z\_0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<       g[\!\(z\_0\)] = \>\"", g[z\_0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<      f'[\!\(z\_0\)] = \>\"", \(f'\)[
          z\_0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<      g'[\!\(z\_0\)] = \>\"", \(g'\)[
          z\_0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<     f''[\!\(z\_0\)] = \>\"", \(\(f'\)'\)[
          z\_0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<     g''[\!\(z\_0\)] = \>\"", \(\(g'\)'\)[
          z\_0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<    f'''[\!\(z\_0\)] = \>\"", \(\(\(f'\)'\)'\)[
          z\_0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<    g'''[\!\(z\_0\)] = \>\"", \(\(\(g'\)'\)'\)[
          z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<      \!\(f[z\_0]\/g[z\_0]\) = \>\"", f[z\_0], "\</\>", 
        g[z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(\(f'\)[z\_0]\/\(g'\)[z\_0]\) = \>\"", \(f'\)[
          z\_0], "\</\>", \(g'\)[z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    \!\(\(f''\)[z\_0]\/\(g''\)[z\_0]\) = \>\"", \(f''\)[
          z\_0], "\</\>", \(g''\)[z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<       \!\(f[z\_0]\/g[z\_0]\) = \>\"", 
        f[z\_0]\/g[z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(lim\+\(z \[Rule] z\_0\)\) \!\(f[z]\/g[z]\) = \
\>\"", lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use L'Hopital's rule to find  ",
  Cell[BoxData[
      \(lim\+\(z \[Rule] 1 + \[ImaginaryI]\)\(z\^2\  + \ z\  - \ 1\  - \ 3  \
\[ImaginaryI]\)\/\(z\^2\  - \ 2  z\  + \ 2\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[f, g, lim, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ 
        z\^2\  + \ z\  - \ 1\  - \ 3  \[ImaginaryI];\)\ \), "\n", 
    \(\(g[z_]\  = \ z\^2\  - \ 2  z\  + \ 2;\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<g[z] = \>", g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Direct substitution of   ",
  Cell[BoxData[
      \(z = 1 + \[ImaginaryI]\)]],
  "  is indeterminate."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(f[1 + \[ImaginaryI]]\/g[1 + \[ImaginaryI]]\) = \
\>\"", f[1 + \[ImaginaryI]], "\</\>", 
        g[1 + \[ImaginaryI]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(f[1 + \[ImaginaryI]]\/g[1 + \[ImaginaryI]]\) = \
\>\"", f[1 + \[ImaginaryI]]\/g[1 + \[ImaginaryI]]];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Find the limit as  ",
  Cell[BoxData[
      \(z \[Rule] 1 + \[ImaginaryI]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(lim\  = \ 
        Limit[f[z]\/g[z], z \[Rule] 1 + \[ImaginaryI]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(z \[Rule] 1 + i\)\) \!\(f[z]\/g[z]\) = \
\!\(lim\+\(z \[Rule] 1 + i\)\) \>\"", 
        f[z]\/g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(z \[Rule] 1 + i\)\) \!\(f[z]\/g[z]\) = \
\!\(lim\+\(z \[Rule] 1 + i\)\) \>\"", 
        Factor[f[z]]\/Factor[g[z]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<           = \!\(lim\+\(z \[Rule] 1 + i\)\) \>\"", 
        Cancel[f[z]\/g[z]]];\)\ \), "\n", 
    \(\(Print["\<           =  \>", lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Which agrees with the L'Hopital rule computation.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(lim\  = \ 
        Limit[\(f'\)[z]\/\(g'\)[z], 
          z \[Rule] 1 + \[ImaginaryI]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(z \[Rule] 1 + i\)\) \
\!\(\(f'\)[z]\/\(g'\)[z]\) = \!\(lim\+\(z \[Rule] 1 + i\)\) \>\"", \
\(f'\)[z]\/\(g'\)[z]];\)\ \), "\n", 
    \(Print["\<            = \>", lim]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Which agrees with evaluation of the quotient  ",
  Cell[BoxData[
      \(\(f'\)[1 + \[ImaginaryI]]\/\(g'\)[1 + \[ImaginaryI]]\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<  f'[1+\[ImaginaryI]] = \>", \(f'\)[
          1 + \[ImaginaryI]]];\)\ \), "\n", 
    \(\(Print["\<  g'[1+\[ImaginaryI]] = \>", \(g'\)[
          1 + \[ImaginaryI]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\(f'\)[1 + \[ImaginaryI]]\/\(g'\)[1 + \[ImaginaryI]]\
\) = (\>\"", \(f'\)[1 + \[ImaginaryI]], "\<)/\>", \(g'\)[
          1 + \[ImaginaryI]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\(f'\)[1 + \[ImaginaryI]]\/\(g'\)[1 + \[ImaginaryI]]\
\) = \>\"", \(f'\)[1 + \[ImaginaryI]]\/\(g'\)[1 + \[ImaginaryI]]];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Analytic Functions",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/AnalyticFunBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Mean Value Theorem and Rolle's Theorem",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/MeanValueBib.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Polya Vector Field",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/PolyaFieldBib.html"], None},
  
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{976, 605},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[75650, 2037, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[82854, 2254, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 95063, 2582}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 132, 2, 33, "Text"],
Cell[2237, 66, 885, 14, 147, "Text"],
Cell[3125, 82, 140, 2, 33, "Text"],
Cell[3268, 86, 1843, 66, 238, "Text"],
Cell[5114, 154, 273, 10, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5412, 168, 163, 4, 33, "Text",
  Evaluatable->False],
Cell[5578, 174, 388, 7, 101, "Input"],
Cell[5969, 183, 304, 8, 30, "Input"],
Cell[6276, 193, 375, 7, 76, "Input"],
Cell[6654, 202, 304, 8, 30, "Input"],
Cell[6961, 212, 421, 7, 97, "Input"],
Cell[7385, 221, 335, 9, 30, "Input"]
}, Closed]],
Cell[7735, 233, 275, 10, 30, "Text",
  Evaluatable->False],
Cell[8013, 245, 1107, 26, 285, "Text"],

Cell[CellGroupData[{
Cell[9145, 275, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[9308, 281, 88, 2, 33, "Text",
  Evaluatable->False],
Cell[9399, 285, 246, 5, 90, "Input"],
Cell[9648, 292, 93, 2, 33, "Text",
  Evaluatable->False],
Cell[9744, 296, 426, 7, 135, "Input"],
Cell[10173, 305, 261, 9, 33, "Text",
  Evaluatable->False],
Cell[10437, 316, 731, 15, 172, "Input"],
Cell[11171, 333, 137, 4, 33, "Text",
  Evaluatable->False],
Cell[11311, 339, 538, 11, 154, "Input"],
Cell[11852, 352, 335, 10, 33, "Text",
  Evaluatable->False],
Cell[12190, 364, 1085, 21, 282, "Input"],
Cell[13278, 387, 437, 14, 52, "Text"]
}, Closed]],
Cell[13730, 404, 1000, 35, 71, "Text"],
Cell[14733, 441, 354, 15, 33, "Text",
  Evaluatable->False],
Cell[15090, 458, 2573, 56, 279, "Text"],
Cell[17666, 516, 2474, 54, 262, "Text"],
Cell[20143, 572, 607, 21, 52, "Text"],

Cell[CellGroupData[{
Cell[20775, 597, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[20938, 603, 350, 7, 90, "Input"],
Cell[21291, 612, 197, 7, 33, "Text",
  Evaluatable->False],
Cell[21491, 621, 1474, 27, 285, "Input"],
Cell[22968, 650, 98, 2, 33, "Text",
  Evaluatable->False],
Cell[23069, 654, 441, 8, 83, "Input"],
Cell[23513, 664, 213, 7, 33, "Text",
  Evaluatable->False],
Cell[23729, 673, 1527, 29, 291, "Input"],
Cell[25259, 704, 98, 2, 33, "Text",
  Evaluatable->False],
Cell[25360, 708, 455, 8, 84, "Input"],
Cell[25818, 718, 312, 13, 33, "Text",
  Evaluatable->False],
Cell[26133, 733, 636, 11, 97, "Input"],
Cell[26772, 746, 370, 16, 33, "Text",
  Evaluatable->False],
Cell[27145, 764, 176, 3, 70, "Input"],
Cell[27324, 769, 218, 8, 33, "Text"]
}, Closed]],
Cell[27557, 780, 538, 14, 49, "Text"],
Cell[28098, 796, 780, 19, 90, "Text"],
Cell[28881, 817, 1104, 43, 52, "Text"],
Cell[29988, 862, 471, 17, 52, "Text"],
Cell[30462, 881, 651, 22, 33, "Text"],
Cell[31116, 905, 167, 3, 33, "Text"],
Cell[31286, 910, 496, 8, 71, "Text"],
Cell[31785, 920, 168, 4, 33, "Text",
  Evaluatable->False],
Cell[31956, 926, 22914, 558, 334, "Text"],
Cell[54873, 1486, 10833, 267, 111, "Text"],

Cell[CellGroupData[{
Cell[65731, 1757, 185, 4, 33, "Text",
  Evaluatable->False],
Cell[65919, 1763, 104, 3, 52, "Text"],
Cell[66026, 1768, 626, 13, 230, "Input"],
Cell[66655, 1783, 60, 0, 33, "Text"],
Cell[66718, 1785, 611, 13, 190, "Input"],
Cell[67332, 1800, 66, 0, 33, "Text"],
Cell[67401, 1802, 350, 8, 130, "Input"],
Cell[67754, 1812, 69, 0, 33, "Text"],
Cell[67826, 1814, 310, 7, 125, "Input"],
Cell[68139, 1823, 72, 0, 33, "Text"],
Cell[68214, 1825, 370, 9, 130, "Input"]
}, Closed]],
Cell[68599, 1837, 1860, 50, 109, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[70484, 1891, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[70647, 1897, 991, 18, 350, "Input"],
Cell[71641, 1917, 197, 7, 33, "Text"],
Cell[71841, 1926, 634, 11, 190, "Input"]
}, Closed]],
Cell[72490, 1940, 353, 9, 49, "Text"],
Cell[72846, 1951, 417, 19, 33, "Text",
  Evaluatable->False],
Cell[73266, 1972, 2029, 49, 283, "Text"],

Cell[CellGroupData[{
Cell[75320, 2025, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[75468, 2031, 179, 4, 33, "Text",
  Evaluatable->False],
Cell[75650, 2037, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[76010, 2049, 527, 14, 74, "Text"],
Cell[76540, 2065, 1409, 25, 221, "Text"],
Cell[77952, 2092, 451, 13, 52, "Text"],
Cell[78406, 2107, 787, 18, 185, "Text"],
Cell[79196, 2127, 1705, 52, 119, "Text"],
Cell[80904, 2181, 479, 12, 52, "Text"],
Cell[81386, 2195, 1004, 38, 77, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[82415, 2237, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[82563, 2243, 288, 9, 33, "Text",
  Evaluatable->False],
Cell[82854, 2254, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{
Cell[83236, 2268, 173, 4, 30, "Text",
  Evaluatable->False],
Cell[83412, 2274, 276, 8, 33, "Text"],
Cell[83691, 2284, 1055, 20, 354, "Input"],
Cell[84749, 2306, 369, 12, 33, "Text",
  Evaluatable->False],
Cell[85121, 2320, 1564, 30, 490, "Input"],
Cell[86688, 2352, 363, 12, 33, "Text",
  Evaluatable->False],
Cell[87054, 2366, 2034, 38, 606, "Input"]
}, Closed]],
Cell[89103, 2407, 355, 11, 35, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[89483, 2422, 163, 4, 33, "Text",
  Evaluatable->False],
Cell[89649, 2428, 342, 7, 130, "Input"],
Cell[89994, 2437, 181, 7, 33, "Text",
  Evaluatable->False],
Cell[90178, 2446, 369, 7, 104, "Input"],
Cell[90550, 2455, 165, 7, 33, "Text",
  Evaluatable->False],
Cell[90718, 2464, 640, 12, 193, "Input"],
Cell[91361, 2478, 113, 2, 33, "Text",
  Evaluatable->False],
Cell[91477, 2482, 371, 8, 121, "Input"],
Cell[91851, 2492, 215, 7, 38, "Text",
  Evaluatable->False],
Cell[92069, 2501, 665, 12, 165, "Input"]
}, Closed]],
Cell[92749, 2516, 290, 7, 30, "Text"],
Cell[93042, 2525, 287, 7, 33, "Text"],
Cell[93332, 2534, 300, 6, 33, "Text"],
Cell[93635, 2542, 284, 7, 33, "Text"],
Cell[93922, 2551, 257, 5, 33, "Text"],
Cell[94182, 2558, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

