(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    188143,       4991]*)
(*NotebookOutlinePosition[    189450,       5036]*)
(*  CellTagsIndexPosition[    189373,       5030]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Section 3.2  The Cauchy-Riemann Equations",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tIn Section 3.1 we showed that computing the derivative of complex \
functions written in a form such as  ",
  Cell[BoxData[
      \(f \((z)\) = z\^2\)]],
  "  is a rather simple task. But life isn't always so easy.  \nMany times we \
encounter complex functions written as  ",
  Cell[BoxData[
      \(f \((z)\) = u \((x, y)\) + \[ImaginaryI]\ v \((x, y)\)\)]],
  ".   For example, suppose we had  \n\n",
  StyleBox["(3-13)\t",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(f \((x + \[ImaginaryI]\ y)\)\  = \ \(u \((x, 
                  y)\) + \[ImaginaryI]\ v \((x, y)\)\  = \ \((x\^3 - 
                  3\ x\ y\^2)\) + \[ImaginaryI]\ \((3\ x\^2\ y - 
                    y\^3)\)\)\)\)]],
  ".  \n\nIs there some criterion - perhaps involving the partial derivatives \
for  ",
  StyleBox["u(x,y)",
    FontFamily->"Courier New"],
  ",  and  ",
  StyleBox["v(x,y)",
    FontFamily->"Courier New"],
  "  -  that we can use to determine whether f is differentiable, and if so, \
to find the value of ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  "?"
}], "Text"],

Cell[TextData[{
  "\tThe answer to this question is yes, thanks to the independent discovery \
of two important equations by the French mathematician ",
  StyleBox[ButtonBox["Augustin Louis Cauchy",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " (1789-1857) and the German mathematician ",
  StyleBox[ButtonBox["Georg Friedrich Bernhard Riemann",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Riemann.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " (1826-1866)."
}], "Text"],

Cell[TextData[{
  "\tFirst, let's reconsider the derivative of  ",
  Cell[BoxData[
      \(f \((z)\) = z\^2\)]],
  ".  As we have stated, the limit given in Equation ",
  StyleBox["(3-1)",
    FontColor->RGBColor[0, 0, 1]],
  " must not depend on how z approaches ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  We investigate two such approaches: a horizontal approach and a \
vertical approach to ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  Recall from our graphical analysis of  ",
  Cell[BoxData[
      \(w = z\^2\)]],
  "  that the image of a square is a \"curvilinear quadrilateral.\"  For \
convenience, we let the square have vertices  ",
  Cell[BoxData[
      \(z\_0 = 2 + \[ImaginaryI]\)]],
  ",  ",
  Cell[BoxData[
      \(z\_1 = 2.01 + \[ImaginaryI]\)]],
  ",  ",
  Cell[BoxData[
      \(z\_2 = 2 + 1.01  \[ImaginaryI]\)]],
  ",  and  ",
  Cell[BoxData[
      \(z\_3 = 2.01 + 1.01  \[ImaginaryI]\)]],
  ".  Then the image points are  ",
  Cell[BoxData[
      \(w\_0 = 3 + 4\ \[ImaginaryI]\)]],
  ",  ",
  Cell[BoxData[
      \(w\_1 = 3.0401 + 4.02\ \[ImaginaryI]\)]],
  ",  ",
  Cell[BoxData[
      \(w\_2 = 2.9799 + 4.04\ \[ImaginaryI]\)]],
  ",  and  ",
  Cell[BoxData[
      \(w\_3 = 3.02 + 4.0602\ \[ImaginaryI]\)]],
  ", as shown in Figure 3.1.  "
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
-166.583 83.3333 -83.25 83.3333 [
[.5 .07083 -14.375 -13 ]
[.5 .07083 14.375 0 ]
[.91667 .07083 -11.625 -13 ]
[.91667 .07083 11.625 0 ]
[.07083 .5 -28.75 -6.5 ]
[.07083 .5 0 6.5 ]
[.07083 .91667 -23.25 -6.5 ]
[.07083 .91667 0 6.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .08333 m
.5 .08958 L
s
gsave
.5 .07083 -75.375 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.005) show
1.000 setlinewidth
grestore
.91667 .08333 m
.91667 .08958 L
s
gsave
.91667 .07083 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.01) show
1.000 setlinewidth
grestore
0 .08333 m
1 .08333 L
s
.08333 .5 m
.08958 .5 L
s
gsave
.07083 .5 -89.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.005) show
1.000 setlinewidth
grestore
.08333 .91667 m
.08958 .91667 L
s
gsave
.07083 .91667 -84.25 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.01) show
1.000 setlinewidth
grestore
.08333 0 m
.08333 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 .165 .165 r
2 Mabswid
.08333 .08333 m
.11714 .08333 L
.15401 .08333 L
.18863 .08333 L
.22193 .08333 L
.25738 .08333 L
.2915 .08333 L
.32776 .08333 L
.3627 .08333 L
.39631 .08333 L
.43207 .08333 L
.4665 .08333 L
.49961 .08333 L
.53486 .08333 L
.56878 .08333 L
.60486 .08333 L
.6396 .08333 L
.67302 .08333 L
.70858 .08333 L
.74282 .08333 L
.77921 .08333 L
.81427 .08333 L
.848 .08333 L
.88388 .08333 L
.91667 .08333 L
s
0 1 0 r
1 Mabswid
[ .04 .04 ] 0 setdash
.08333 .91667 m
.11714 .91667 L
.15401 .91667 L
.18863 .91667 L
.22193 .91667 L
.25738 .91667 L
.2915 .91667 L
.32776 .91667 L
.3627 .91667 L
.39631 .91667 L
.43207 .91667 L
.4665 .91667 L
.49961 .91667 L
.53486 .91667 L
.56878 .91667 L
.60486 .91667 L
.6396 .91667 L
.67302 .91667 L
.70858 .91667 L
.74282 .91667 L
.77921 .91667 L
.81427 .91667 L
.848 .91667 L
.88388 .91667 L
.91667 .91667 L
s
1 .5 0 r
2 Mabswid
[ ] 0 setdash
.08333 .08333 m
.08333 .11714 L
.08333 .15401 L
.08333 .18863 L
.08333 .22193 L
.08333 .25738 L
.08333 .2915 L
.08333 .32776 L
.08333 .3627 L
.08333 .39631 L
.08333 .43207 L
.08333 .4665 L
.08333 .49961 L
.08333 .53486 L
.08333 .56878 L
.08333 .60486 L
.08333 .6396 L
.08333 .67302 L
.08333 .70858 L
.08333 .74282 L
.08333 .77921 L
.08333 .81427 L
.08333 .848 L
.08333 .88388 L
.08333 .91667 L
s
0 0 1 r
1 Mabswid
[ .04 .04 ] 0 setdash
.91667 .08333 m
.91667 .11714 L
.91667 .15401 L
.91667 .18863 L
.91667 .22193 L
.91667 .25738 L
.91667 .2915 L
.91667 .32776 L
.91667 .3627 L
.91667 .39631 L
.91667 .43207 L
.91667 .4665 L
.91667 .49961 L
.91667 .53486 L
.91667 .56878 L
.91667 .60486 L
.91667 .6396 L
.91667 .67302 L
.91667 .70858 L
.91667 .74282 L
.91667 .77921 L
.91667 .81427 L
.91667 .848 L
.91667 .88388 L
.91667 .91667 L
s
0 g
gsave
.5 .5 -80.625 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
67.750 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.125 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(plane) show
98.250 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.04 w
.08333 .08333 Mdot
0 0 1 r
.91667 .08333 Mdot
0 1 0 r
.08333 .91667 Mdot
1 0 1 r
.91667 .91667 Mdot
0 g
.5 Mabswid
[ ] 0 setdash
gsave
.18333 .14167 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
1.01667 .14167 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18333 .95833 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
1.01667 .95833 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{213, 213},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003E0000eB000`400?l00000o`00003oe@3oool0
0=D0oooo003E0?ooo`00e@3oool00=D0oooo003E0?ooo`00e@3oool00=D0oooo000O0?ooo`030000
003oool0oooo0;<0oooo000O0?ooo`030000003oool0oooo0;<0oooo000O0?ooo`030000003oool0
oooo0;<0oooo000O0?ooo`030000003oool0oooo0;<0oooo000O0?ooo`030000003oool0oooo0;<0
oooo000O0?ooo`030000003oool0oooo04<0oooo1@0000020?ooo`030000003oool0oooo00<00000
0`3oool3000000<0oooo0`00000k0?ooo`D000000P3oool00`000000oooo0?ooo`03000000D0oooo
00<000000?ooo`3oool01`3oool001l0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`050?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`070?ooo`007`3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00L0oooo000O0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool00`000000oooo000000030?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01`3oool001l0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`030000003oool0000000<00000?`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000090?ooo`007`3oool00`00
0000oooo0?ooo`130?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool010000000oooo0?ooo`00000m0?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000090?ooo`007`3oool00`00
0000oooo0?ooo`140?ooo`<000001P3oool3000000<0oooo0`0000030?ooo`@00000>`3oool30000
00H0oooo0`0000050?ooo`030000003oool0oooo00L0oooo000O0?ooo`030000003oool0oooo0;<0
oooo000O0?ooo`030000003oool0oooo0;<0oooo000M0?ooo`<0o`00XP3oool30000oa00oooo000L
0?ooo`D0o`00X03oool50000o`l0oooo000>0?ooo`d000001`3o002N07lZ:PL0003o3P00000001/0
oooo1`3o002N07lZ:PL0003o3P3oool001/0oooo1`3o001?0?ooo`030000003oool0oooo04`0oooo
1`000?l>0?ooo`00703oool50?l00:00oooo1@000?l?0?ooo`007@3oool30?l00:80oooo0`000?l@
0?ooo`007P3oool20?mo0:<0oooo00<0003o0?ooo`3oool03`3oool001h0oooo0P3oO`2S0?ooo`03
0000o`3oool0oooo00l0oooo000N0?ooo`80ogl0X`3oool00`000?l0oooo0?ooo`0?0?ooo`007P3o
ool20?mo00d0oooo00<000000?ooo`3oool0T`3oool00`000?l0oooo0?ooo`090?ooo`D000000@3o
ool001h0oooo0P3oO`050?ooo`D000000P3oool00`000000oooo0000002J0?ooo`D000000`3oool0
0`000000oooo0?ooo`010?ooo`007P3oool20?mo00H0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0000002K0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00@3o
ool001h0oooo0P3oO`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000W03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo000N0?ooo`80ogl0203oool01`00
0000oooo0?ooo`3oool000000?ooo`000000W@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0040oooo000N0?ooo`80ogl01P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo09X0oooo00@000000?ooo`3oool000000P3oool2000000<0oooo000N0?ooo`80ogl01P3o
ool5000009l0oooo1@0000060?ooo`007P3oool20?mo0;D0oooo000N0?ooo`80ogl0X`3oool00`00
0?l0oooo0?ooo`0?0?ooo`007P3oool20?mo0:<0oooo00<0003o0?ooo`3oool03`3oool001h0oooo
0P3oO`2S0?ooo`030000o`3oool0oooo00l0oooo000N0?ooo`80ogl0X`3oool00`000?l0oooo0?oo
o`0?0?ooo`007P3oool20?mo0:<0oooo00<0003o0?ooo`3oool03`3oool001h0oooo0P3oO`2S0?oo
o`030000o`3oool0oooo00l0oooo000N0?ooo`80ogl0X`3oool00`000?l0oooo0?ooo`0?0?ooo`00
7P3oool20?mo0:<0oooo00<0003o0?ooo`3oool03`3oool001h0oooo0P3oO`2S0?ooo`030000o`3o
ool0oooo00l0oooo000N0?ooo`80ogl0]@3oool001h0oooo0P3oO`2e0?ooo`007P3oool20?mo0;D0
oooo000N0?ooo`80ogl0]@3oool001h0oooo0P3oO`2e0?ooo`007P3oool20?mo0;D0oooo000N0?oo
o`80ogl0]@3oool001h0oooo0P3oO`2S0?ooo`030000o`3oool0oooo00l0oooo000N0?ooo`80ogl0
X`3oool00`000?l0oooo0?ooo`0?0?ooo`007P3oool20?mo0:<0oooo00<0003o0?ooo`3oool03`3o
ool001h0oooo0P3oO`2S0?ooo`030000o`3oool0oooo00l0oooo000N0?ooo`80ogl0X`3oool00`00
0?l0oooo0?ooo`0?0?ooo`007P3oool20?mo0:<0oooo00<0003o0?ooo`3oool03`3oool001h0oooo
0P3oO`2S0?ooo`030000o`3oool0oooo00l0oooo000N0?ooo`80ogl0X`3oool00`000?l0oooo0?oo
o`0?0?ooo`007P3oool20?mo0:<0oooo00<0003o0?ooo`3oool03`3oool001h0oooo0P3oO`2e0?oo
o`007P3oool20?mo0;D0oooo000N0?ooo`80ogl0]@3oool001h0oooo0P3oO`2e0?ooo`007P3oool2
0?mo0;D0oooo000N0?ooo`80ogl0]@3oool001h0oooo0P3oO`2e0?ooo`007P3oool20?mo0:<0oooo
00<0003o0?ooo`3oool03`3oool001h0oooo0P3oO`2S0?ooo`030000o`3oool0oooo00l0oooo000N
0?ooo`80ogl0X`3oool00`000?l0oooo0?ooo`0?0?ooo`007P3oool20?mo0:<0oooo00<0003o0?oo
o`3oool03`3oool001h0oooo0P3oO`2S0?ooo`030000o`3oool0oooo00l0oooo000N0?ooo`80ogl0
X`3oool00`000?l0oooo0?ooo`0?0?ooo`007P3oool20?mo0:<0oooo00<0003o0?ooo`3oool03`3o
ool001h0oooo0P3oO`2S0?ooo`030000o`3oool0oooo00l0oooo000N0?ooo`80ogl0X`3oool00`00
0?l0oooo0?ooo`0?0?ooo`007P3oool20?mo0;D0oooo000N0?ooo`80ogl0]@3oool001h0oooo0P3o
O`2e0?ooo`007P3oool20?mo0;D0oooo000N0?ooo`80ogl0]@3oool001h0oooo0P3oO`2e0?ooo`00
7P3oool20?mo0:<0oooo00<0003o0?ooo`3oool03`3oool001h0oooo0P3oO`2S0?ooo`030000o`3o
ool0oooo00l0oooo000N0?ooo`80ogl0X`3oool00`000?l0oooo0?ooo`0?0?ooo`007P3oool20?mo
0:<0oooo00<0003o0?ooo`3oool03`3oool001h0oooo0P3oO`2S0?ooo`030000o`3oool0oooo00l0
oooo000N0?ooo`80ogl0X`3oool00`000?l0oooo0?ooo`0?0?ooo`007P3oool20?mo0:<0oooo00<0
003o0?ooo`3oool03`3oool001h0oooo0P3oO`2S0?ooo`030000o`3oool0oooo00l0oooo000N0?oo
o`80ogl0X`3oool00`000?l0oooo0?ooo`0?0?ooo`007P3oool20?mo0;D0oooo000N0?ooo`80ogl0
]@3oool001h0oooo0P3oO`2e0?ooo`007P3oool20?mo0;D0oooo000N0?ooo`80ogl0]@3oool001h0
oooo0P3oO`2e0?ooo`007P3oool20?mo04/0oooo00<000000?ooo`3oool0I`3oool001h0oooo0P3o
O`1;0?ooo`030000003oool0oooo05D0oooo00<0003o0?ooo`3oool03`3oool000D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`80ogl0?`3o
ool5000000L0oooo0`0000030?ooo`030000003oool0oooo00@000000P3oool010000000oooo0?oo
o`0000030?ooo`<00000?`3oool00`000?l0oooo0?ooo`0?0?ooo`001@3oool00`000000oooo0?oo
o`030?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool00P3oO`100?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000@P3oool00`000?l0oooo0?ooo`0?0?ooo`001@3oool00`000000oooo0?oo
o`030?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oO`000`000000oooo0?ooo`0n0?ooo`040000003oool0oooo0?oo
o`@000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0?ooo`<000000P3o
ool010000000oooo0?ooo`0000020?ooo`@00000?`3oool00`000?l0oooo0?ooo`0?0?ooo`001@3o
ool00`000000oooo0?ooo`030?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool00P3oO`120?ooo`030000003oool0oooo00H0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0m0?ooo`030000o`3o
ool0oooo00l0oooo00030?ooo`030000003oool0000000D0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00<000000?ooo`0000000`0000030?ooo`80ogl0?`3oool5000000L0oooo
0`0000030?ooo`040000003oool0oooo0?ooo`<000000P3oool3000000@0oooo0P0000100?ooo`03
0000o`3oool0oooo00l0oooo00040?ooo`8000001@3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool010000000oooo0?ooo`0000050?ooo`80ogl0D@3oool00`000000oooo0?ooo`1?
0?ooo`030000o`3oool0oooo00l0oooo00050?ooo`030000003oool0oooo00@0oooo0`0000030?oo
o`<000000`3oool400000080oooo0P3oO`1A0?ooo`030000003oool0oooo04l0oooo00<0003o0?oo
o`3oool03`3oool001h0oooo0P3oO`2S0?ooo`030000o`3oool0oooo00l0oooo000N0?ooo`80ogl0
]@3oool001h0oooo0P3oO`2e0?ooo`007P3oool20?mo0;D0oooo000N0?ooo`80ogl0]@3oool001h0
oooo0P3oO`2e0?ooo`007P3oool20?mo0;D0oooo000N0?ooo`80ogl0]@3oool001h0oooo0P3oO`2S
0?ooo`030000o`3oool0oooo00l0oooo000N0?ooo`80ogl0X`3oool00`000?l0oooo0?ooo`0?0?oo
o`007P3oool20?mo0:<0oooo00<0003o0?ooo`3oool03`3oool001h0oooo0P3oO`2S0?ooo`030000
o`3oool0oooo00l0oooo000N0?ooo`80ogl0X`3oool00`000?l0oooo0?ooo`0?0?ooo`007P3oool2
0?mo0:<0oooo00<0003o0?ooo`3oool03`3oool001h0oooo0P3oO`2S0?ooo`030000o`3oool0oooo
00l0oooo000N0?ooo`80ogl0X`3oool00`000?l0oooo0?ooo`0?0?ooo`007P3oool20?mo0:<0oooo
00<0003o0?ooo`3oool03`3oool001h0oooo0P3oO`2e0?ooo`007P3oool20?mo0;D0oooo000N0?oo
o`80ogl0]@3oool001h0oooo0P3oO`2e0?ooo`007P3oool20?mo0;D0oooo000N0?ooo`80ogl0]@3o
ool001h0oooo0P3oO`2e0?ooo`007P3oool20?mo0:<0oooo00<0003o0?ooo`3oool03`3oool001h0
oooo0P3oO`2S0?ooo`030000o`3oool0oooo00l0oooo000N0?ooo`80ogl0X`3oool00`000?l0oooo
0?ooo`0?0?ooo`007P3oool20?mo0:<0oooo00<0003o0?ooo`3oool03`3oool001h0oooo0P3oO`2S
0?ooo`030000o`3oool0oooo00l0oooo000N0?ooo`80ogl0X`3oool00`000?l0oooo0?ooo`0?0?oo
o`007P3oool20?mo0:<0oooo00<0003o0?ooo`3oool03`3oool001h0oooo0P3oO`2S0?ooo`030000
o`3oool0oooo00l0oooo000N0?ooo`80ogl0X`3oool00`000?l0oooo0?ooo`0?0?ooo`007P3oool2
0?mo0;D0oooo000N0?ooo`80ogl0]@3oool001h0oooo0P3oO`2e0?ooo`007P3oool20?mo0;D0oooo
000N0?ooo`80ogl0]@3oool001h0oooo0P3oO`2e0?ooo`007P3oool20?mo0;D0oooo000N0?ooo`80
ogl0X`3oool00`000?l0oooo0?ooo`0?0?ooo`007P3oool20?mo0:<0oooo00<0003o0?ooo`3oool0
3`3oool001h0oooo0P3oO`2S0?ooo`030000o`3oool0oooo00l0oooo000N0?ooo`80ogl0X`3oool0
0`000?l0oooo0?ooo`0?0?ooo`007P3oool20?mo0:<0oooo00<0003o0?ooo`3oool03`3oool001h0
oooo0P3oO`2S0?ooo`030000o`3oool0oooo00l0oooo000N0?ooo`80ogl0X`3oool00`000?l0oooo
0?ooo`0?0?ooo`007P3oool20?mo0:<0oooo00<0003o0?ooo`3oool03`3oool001h0oooo0P3oO`2e
0?ooo`007P3oool20?mo0;D0oooo000N0?ooo`80ogl0]@3oool001h0oooo0P3oO`2e0?ooo`007P3o
ool20?mo0;D0oooo000N0?ooo`80ogl0]@3oool001h0oooo0P3oO`2e0?ooo`007P3oool20?mo0:<0
oooo00<0003o0?ooo`3oool03`3oool001h0oooo0P3oO`2S0?ooo`030000o`3oool0oooo00l0oooo
000N0?ooo`80ogl0X`3oool00`000?l0oooo0?ooo`0?0?ooo`007P3oool20?mo0:<0oooo00<0003o
0?ooo`3oool03`3oool001h0oooo0P3oO`2S0?ooo`030000o`3oool0oooo00l0oooo000N0?ooo`80
ogl0X`3oool00`000?l0oooo0?ooo`0?0?ooo`007P3oool20?mo0:<0oooo00<0003o0?ooo`3oool0
3`3oool001h0oooo0P3oO`2S0?ooo`030000o`3oool0oooo00l0oooo000N0?ooo`80ogl0X`3oool0
0`000?l0oooo0?ooo`0?0?ooo`007P3oool20?mo0;D0oooo000N0?ooo`80ogl0]@3oool001h0oooo
0P3oO`2e0?ooo`007P3oool20?mo0;D0oooo000N0?ooo`80ogl0]@3oool001h0oooo0P3oO`2e0?oo
o`007P3oool20?mo0;D0oooo000N0?ooo`80ogl0X`3oool00`000?l0oooo0?ooo`0?0?ooo`007P3o
ool20?mo0:<0oooo00<0003o0?ooo`3oool03`3oool001h0oooo0P3oO`2S0?ooo`030000o`3oool0
oooo00l0oooo000N0?ooo`80ogl0X`3oool00`000?l0oooo0?ooo`0?0?ooo`002P3oool01@000000
oooo0?ooo`3oool000000080oooo0`0000050?ooo`040000003oool0oooo0?ooo`<00?l0XP3oool3
0?l0oa00oooo000:0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00D00?l0X03oool50?l0o`l0oooo000:0?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool00?l000H00?l0WP3oool7
0?l0o`h0oooo000:0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool00?l000`00?l01P3oool9003o00L0oooo2@00o`070?ooo`T00?l01`3oool9
003o00L0oooo2000o`070?ooo`T00?l01`3oool9003o00L0oooo2@00o`070?ooo`T00?l01P3oool4
003o00L0o`3o3P3oool000P0oooo00<000000?ooo`0000001@3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`000000oooo1`00o`2N0?ooo`L0o`3o3P3oool000T0oooo0P000005
0?ooo`050000003oool0oooo0?ooo`0000000`3oool200000080oooo1@00o`2P0?ooo`D0o`3o3`3o
ool000X0oooo00<000000?ooo`3oool0103oool3000000D0oooo00@000000?ooo`3oool0oooo0`00
o`2R0?ooo`<0o`3o403oool001l0oooo00<000000?ooo`3oool02P3oool300000:40oooo0P000003
0?ooo`007`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0:<0oooo0@0000010?oo
o`40oooo000O0?ooo`030000003oool0oooo00<0oooo1@0000030?ooo`030000003oool0oooo09T0
oooo1@0000030?ooo`030000003oool0oooo0040oooo000O0?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`2J0?ooo`040000003oool0oooo0000
00@0oooo0@0000010?ooo`40oooo000O0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0000002L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000P3oool001l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo09`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`007`3o
ool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000:00oooo00@000000?ooo`3oool0
00001`3oool001l0oooo00<000000?ooo`3oool0103oool5000009l0oooo1@0000060?ooo`007`3o
ool00`000000oooo0?ooo`2c0?ooo`007`3oool00`000000oooo0?ooo`2c0?ooo`007`3oool00`00
0000oooo0?ooo`2c0?ooo`007`3oool00`000000oooo0?ooo`2c0?ooo`007`3oool00`000000oooo
0?ooo`2c0?ooo`00e@3oool00=D0oooo003E0?ooo`00e@3oool00=D0oooo003E0?ooo`00e@3oool0
0001\
\>"],
    ImageRangeCache->{{{0, 212}, {212, 0}} -> {1, 0, 0, 0}}],
  StyleBox["          ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
-42.5143 14.2857 -57.0714 14.2857 [
[.05714 .05893 -11.625 -13 ]
[.05714 .05893 11.625 0 ]
[.2 .05893 -11.625 -13 ]
[.2 .05893 11.625 0 ]
[.48571 .05893 -11.625 -13 ]
[.48571 .05893 11.625 0 ]
[.62857 .05893 -11.625 -13 ]
[.62857 .05893 11.625 0 ]
[.77143 .05893 -11.625 -13 ]
[.77143 .05893 11.625 0 ]
[.91429 .05893 -11.625 -13 ]
[.91429 .05893 11.625 0 ]
[.33036 .21429 -23.25 -6.5 ]
[.33036 .21429 0 6.5 ]
[.33036 .35714 -23.25 -6.5 ]
[.33036 .35714 0 6.5 ]
[.33036 .5 -23.25 -6.5 ]
[.33036 .5 0 6.5 ]
[.33036 .64286 -23.25 -6.5 ]
[.33036 .64286 0 6.5 ]
[.33036 .78571 -23.25 -6.5 ]
[.33036 .78571 0 6.5 ]
[.33036 .92857 -23.25 -6.5 ]
[.33036 .92857 0 6.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05714 .07143 m
.05714 .07768 L
s
gsave
.05714 .05893 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.98) show
1.000 setlinewidth
grestore
.2 .07143 m
.2 .07768 L
s
gsave
.2 .05893 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.99) show
1.000 setlinewidth
grestore
.48571 .07143 m
.48571 .07768 L
s
gsave
.48571 .05893 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.01) show
1.000 setlinewidth
grestore
.62857 .07143 m
.62857 .07768 L
s
gsave
.62857 .05893 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.02) show
1.000 setlinewidth
grestore
.77143 .07143 m
.77143 .07768 L
s
gsave
.77143 .05893 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.03) show
1.000 setlinewidth
grestore
.91429 .07143 m
.91429 .07768 L
s
gsave
.91429 .05893 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.04) show
1.000 setlinewidth
grestore
0 .07143 m
1 .07143 L
s
.34286 .21429 m
.34911 .21429 L
s
gsave
.33036 .21429 -84.25 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.01) show
1.000 setlinewidth
grestore
.34286 .35714 m
.34911 .35714 L
s
gsave
.33036 .35714 -84.25 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.02) show
1.000 setlinewidth
grestore
.34286 .5 m
.34911 .5 L
s
gsave
.33036 .5 -84.25 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.03) show
1.000 setlinewidth
grestore
.34286 .64286 m
.34911 .64286 L
s
gsave
.33036 .64286 -84.25 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.04) show
1.000 setlinewidth
grestore
.34286 .78571 m
.34911 .78571 L
s
gsave
.33036 .78571 -84.25 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.05) show
1.000 setlinewidth
grestore
.34286 .92857 m
.34911 .92857 L
s
gsave
.33036 .92857 -84.25 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.06) show
1.000 setlinewidth
grestore
.34286 0 m
.34286 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 .165 .165 r
2 Mabswid
.34286 .07143 m
.36604 .08302 L
.39133 .09566 L
.41509 .10753 L
.43794 .11895 L
.46226 .1311 L
.48569 .1428 L
.51059 .15523 L
.53458 .16721 L
.55767 .17874 L
.58224 .191 L
.6059 .2028 L
.62866 .21415 L
.65289 .22624 L
.67622 .23787 L
.70103 .25024 L
.72493 .26215 L
.74793 .27361 L
.77241 .2858 L
.79597 .29754 L
.82102 .31001 L
.84517 .32203 L
.8684 .3336 L
.89312 .3459 L
.91571 .35714 L
s
0 1 0 r
1 Mabswid
[ .037 .037 ] 0 setdash
.05571 .64286 m
.0789 .65456 L
.10419 .66733 L
.12794 .67932 L
.15079 .69085 L
.17512 .70313 L
.19854 .71494 L
.22344 .7275 L
.24744 .7396 L
.27053 .75124 L
.2951 .76362 L
.31876 .77554 L
.34152 .78701 L
.36575 .79921 L
.38908 .81096 L
.41389 .82345 L
.43779 .83548 L
.46079 .84706 L
.48526 .85937 L
.50883 .87123 L
.53388 .88383 L
.55802 .89597 L
.58126 .90765 L
.60598 .92007 L
.62857 .93143 L
s
1 .5 0 r
2 Mabswid
[ ] 0 setdash
.34286 .07143 m
.33126 .09461 L
.31862 .11989 L
.30673 .14363 L
.2953 .16647 L
.28312 .19077 L
.2714 .21417 L
.25893 .23904 L
.24691 .26299 L
.23535 .28604 L
.22304 .31056 L
.21118 .33417 L
.19978 .35687 L
.18763 .38105 L
.17593 .40431 L
.16349 .42904 L
.1515 .45287 L
.13996 .47579 L
.12768 .50017 L
.11585 .52365 L
.10328 .5486 L
.09115 .57264 L
.07948 .59577 L
.06707 .62037 L
.05571 .64286 L
s
0 0 1 r
1 Mabswid
[ .037 .037 ] 0 setdash
.91571 .35714 m
.90412 .38044 L
.89147 .40585 L
.87959 .42971 L
.86816 .45266 L
.85598 .47708 L
.84426 .5006 L
.83179 .52559 L
.81977 .54967 L
.80821 .57283 L
.7959 .59747 L
.78404 .6212 L
.77264 .64402 L
.76049 .66831 L
.74879 .69169 L
.73635 .71655 L
.72436 .74049 L
.71282 .76352 L
.70054 .78803 L
.68871 .81163 L
.67613 .8367 L
.66401 .86086 L
.65234 .88411 L
.63992 .90883 L
.62857 .93143 L
s
0 g
gsave
.55714 .5 -81.875 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
70.250 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.625 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(plane) show
100.750 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.04 w
.34286 .07143 Mdot
0 0 1 r
.91571 .35714 Mdot
0 1 0 r
.05571 .64286 Mdot
1 0 1 r
.62857 .93143 Mdot
0 g
.5 Mabswid
[ ] 0 setdash
gsave
.42571 .02857 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97143 .30714 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.08571 .7 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.72857 .92857 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{213, 213},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003E0000eB000`400?l00000o`00003oe@3oool0
04P0oooo00<000000?ooo`3oool0RP3oool004P0oooo00<000000?ooo`3oool0RP3oool004P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1n0?ooo`00B03oool00`000000oooo0?oo
o`080?ooo`030000003oool0000007l0oooo00020?ooo`D000000P3oool00`000000oooo0?ooo`03
000000<0oooo0`00000;0?ooo`D000000P3oool00`000000oooo0?ooo`03000000<0oooo0`00000E
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
0000203oool3000000<0oooo00<000000?ooo`3oool00`0000050?ooo`030000003oool0oooo00X0
oooo0`0000030?ooo`030000003oool0oooo00<000000P3oool5000000/0oooo0`0000030?ooo`03
0000003oool0oooo00<000000`3oool3000000`0oooo0`0000030?ooo`030000003oool0oooo00<0
00001P3oool00`000000oooo0?ooo`080?ooo`000`3oool00`000000oooo0?ooo`050?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`0B0?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000000000000P3oool00`000000oooo
000000070?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo
000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo
00P0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo0?ooo`080?ooo`00103oool00`000000oooo0?ooo`050?ooo`@0000000<0oooo
0000003oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo10000002
0?ooo`@00000503oool01P000000oooo0?ooo`3oool000000?ooo`80000000H0oooo0000003oool0
00000?ooo`00000;0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo
00H000000?ooo`3oool0oooo0000003oool6000000T0oooo00050?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`<000003P3oool00`000000oooo0?ooo`030?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0180oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
203oool2000000D0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00/0
oooo0P0000050?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0;0?oo
o`8000001@3oool01@000000oooo0?ooo`3oool0000000<0oooo0P00000=0?ooo`8000001@3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`080?ooo`001P3o
ool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000X0oooo
00020?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000103oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00<000000`3oool3000000T0oooo00D000000?ooo`3oool0oooo000000040?ooo`05
0000003oool0oooo0?ooo`0000000`3oool2000000/0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00P0oooo
00D000000?ooo`3oool0oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0000000:0?ooo`000`3oool3000000H0oooo0`00
00030?ooo`<00000303oool3000000H0oooo0`0000030?ooo`<000005@3oool00`000000oooo0?oo
o`0C0?ooo`<000001P3oool3000000D0oooo00<000000?ooo`3oool02P3oool3000000H0oooo0`00
00030?ooo`<00000303oool3000000H0oooo0`0000030?ooo`<00000303oool3000000H0oooo0`00
00050?ooo`8000002P3oool004P0oooo00<000000?ooo`3oool0RP3oool004P0oooo0P3o002;0?oo
o`00AP3oool60?l008T0oooo00160?ooo`H0o`00R@3oool004D00000203o002700000040oooo000<
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0603oool80?l001T0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool04@3oool004H0oooo1P3o000207lZ:XL0oooo00160?ooo`H0o`001@1o:RZ40?ooo`00
AP3oool20?mo0080o`000`3oool707lZ:X40oooo00160?ooo`030?mo003oool0000000L0oooo1P1o
:RYo0?ooo`00A@3oool20?mo00030?ooo`000000oooo00T0oooo101o:RYn0?ooo`00A03oool20?mo
0080oooo00<000000?ooo`3oool02P3oool407lZ:W`0oooo00140?ooo`050?mo003oool0oooo0?oo
o`0000003@3oool507lZ:WX0oooo00130?ooo`80ogl00`3oool00`000000oooo0?ooo`0=0?ooo`D0
ObXZN03oool004<0oooo00<0ogl00?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`D0ObXZ
MP3oool00480oooo0P3oO`040?ooo`030000003oool0oooo0140oooo1@1o:RYd0?ooo`00@@3oool3
0?mo00@0oooo00<000000?ooo`3oool04`3oool507lZ:W80oooo00110?ooo`80ogl01@3oool00`00
0000oooo0?ooo`0E0?ooo`D0ObXZL03oool00440oooo0P3oO`050?ooo`030000003oool0oooo01L0
oooo1@1o:RY^0?ooo`00@@3oool00`3oO`00oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo
1@1o:RY/0?ooo`00@03oool20?mo00H0oooo00<000000?ooo`3oool06`3oool507lZ:VX0oooo000o
0?ooo`80ogl01`3oool00`000000oooo0?ooo`0M0?ooo`D0ObXZJ03oool003l0oooo00<0ogl00?oo
o`3oool01P3oool00`000000oooo0?ooo`0O0?ooo`D0ObXZIP3oool003h0oooo0P3oO`080?ooo`03
0000003oool0oooo0240oooo1P1o:RYS0?ooo`00?P3oool00`3oO`00oooo0?ooo`070?ooo`030000
003oool0oooo02<0oooo1P1o:RYQ0?ooo`00?@3oool20?mo00T0oooo00<000000?ooo`3oool09P3o
ool407lZ:V00oooo000l0?ooo`<0ogl02@3oool00`000000oooo0?ooo`0X0?ooo`@0ObXZGP3oool0
03`0oooo0P3oO`0:0?ooo`030000003oool0oooo02T0oooo1@1o:RYL0?ooo`00?03oool20?mo00X0
oooo00<000000?ooo`3oool0:`3oool607lZ:UT0oooo000l0?ooo`030?mo003oool0oooo00T0oooo
00<000000?ooo`3oool0;@3oool607lZ:UL0oooo000k0?ooo`80ogl02`3oool00`000000oooo0?oo
o`0`0?ooo`@0ObXZEP3oool003X0oooo0P3oO`0<0?ooo`030000003oool0oooo0380oooo101o:RYD
0?ooo`00=03oool010000000oooo0?ooo`0000020?ooo`030?mo00000000000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`D0ObXZDP3oool003@0oooo00<000000?oo
o`3oool00P3oool20?mo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo03D0oooo1P1o:RY?0?ooo`00<03oool6000000<0oooo00D0ogl00?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00<0oooo0`00000g0?ooo`H0ObXZC@3oool00300
oooo00D000000?ooo`3oool0oooo000000030?ooo`80ogl00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>P3oool407lZ:T`0oooo000a0?ooo`04
0000003oool0oooo000000<0oooo0P3oO`030?ooo`060000003oool0oooo0000003oool000001@3o
ool00`000000oooo0?ooo`0l0?ooo`@0ObXZBP3oool00380oooo00<000000?ooo`0000000P3oool3
0?mo00<0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`030000003oool0oooo03d0oooo1@1o
:RY80?ooo`00<`3oool200000080oooo0P3oO`00103oool000000000000000050?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0?`3oool607lZ:TD0oooo000g0?ooo`80ogl03`3oool0
0`000000oooo0?ooo`110?ooo`H0ObXZ@`3oool003L0oooo00<0ogl00?ooo`3oool03P3oool00`00
0000oooo0?ooo`140?ooo`@0ObXZ@P3oool003H0oooo0P3oO`0@0?ooo`030000003oool0oooo04H0
oooo101o:RY00?ooo`00=@3oool20?mo0140oooo00<000000?ooo`3oool0A`3oool507lZ:Sh0oooo
000e0?ooo`030?mo003oool0oooo0100oooo00<000000?ooo`3oool0B@3oool607lZ:S/0oooo000d
0?ooo`80ogl04P3oool00`000000oooo0?ooo`1;0?ooo`H0ObXZ>@3oool003@0oooo00<0ogl00?oo
o`3oool04@3oool00`000000oooo0?ooo`1>0?ooo`@0ObXZ>03oool003<0oooo0P3oO`0C0?ooo`03
0000003oool0oooo0500oooo101o:RXf0?ooo`00<P3oool30?mo01<0oooo00<000000?ooo`3oool0
D@3oool507lZ:S@0oooo000b0?ooo`80ogl0503oool00`000000oooo0?ooo`1C0?ooo`H0ObXZ<@3o
ool00380oooo0P3oO`0D0?ooo`030000003oool0oooo05D0oooo1P1o:RX_0?ooo`00<P3oool00`3o
O`00oooo0?ooo`0C0?ooo`030000003oool0oooo05P0oooo101o:RXO0?ooo`D000002P3oool00340
oooo0P3oO`0E0?ooo`030000003oool0oooo05X0oooo101o:RXO0?ooo`030000003oool0oooo00X0
oooo000`0?ooo`80ogl05P3oool00`000000oooo0?ooo`1K0?ooo`D0ObXZ503oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo00X0oooo000`0?ooo`030?mo003oool0oooo01D0oooo
00<000000?ooo`3oool0G@3oool407lZ:Q<0oooo0P0000000`3oool00000000000040?ooo`030000
003oool0oooo00X0oooo000_0?ooo`80ogl05`3oool00`000000oooo0?ooo`1O0?ooo`@0ObXZ4@3o
ool01P000000oooo000000000000oooo000000<0oooo00<000000?ooo`3oool02P3oool002l0oooo
00<0ogl00?ooo`3oool05P3oool00`000000oooo0?ooo`1P0?ooo`D0ObXZ3`3oool01P000000oooo
0?ooo`000000oooo00000080oooo0P00000<0?ooo`00;P3oool20?mo01P0oooo00<000000?ooo`3o
ool0HP3oool607lZ:P`0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=0?oo
o`00;@3oool20?mo01T0oooo00<000000?ooo`3oool0I03oool607lZ:PT0oooo0`0000030?ooo`<0
00003P3oool002d0oooo00<0ogl00?ooo`3oool0603oool00`000000oooo0?ooo`1W0?ooo`@0ObXZ
7`3oool002`0oooo0P3oO`0J0?ooo`030000003oool0oooo06T0oooo101o:RXM0?ooo`00;03oool0
0`3oO`00oooo0?ooo`0I0?ooo`030000003oool0oooo06X0oooo1P1o:RXJ0?ooo`00:`3oool20?mo
01/0oooo00<000000?ooo`3oool0K03oool707lZ:P<0oooo0P000?lB0?ooo`00:P3oool30?mo00L0
oooo00@000000?ooo`3oool000000P3oool300000080oooo1@0000040?ooo`030000003oool0oooo
06l0oooo1@1o:RX60000oa00oooo000Z0?ooo`80ogl0203oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0780oooo0P1o:RX60000oa00oooo000Z0?ooo`80ogl0103oool6000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0L`3oool80000
o`l0oooo000Z0?ooo`030?mo003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`<00000L`3oool8
0000o`l0oooo000Y0?ooo`80ogl01P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07@0oooo1P00
0?l@0?ooo`00:03oool20?mo00P0oooo00<000000?ooo`000000103oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07@0oooo
1P000?l@0?ooo`00:03oool00`3oO`00oooo0?ooo`080?ooo`8000001@3oool3000000<0oooo0`00
00050?ooo`030000003oool0oooo07@0oooo00@0003o0?ooo`000?l0003o4P3oool002L0oooo0P3o
O`0O0?ooo`030000003oool0oooo07@0oooo00<0003o0?ooo`3oool04`3oool002L0oooo00<0ogl0
0?ooo`3oool07P3oool00`000000oooo0?ooo`1d0?ooo`030000o`3oool0oooo01<0oooo000V0?oo
o`80ogl0803oool00`000000oooo0?ooo`1c0?ooo`030000o`3oool0oooo01@0oooo000U0?ooo`<0
ogl0803oool00`000000oooo0?ooo`1c0?ooo`030000o`3oool0oooo01@0oooo000U0?ooo`80ogl0
8@3oool00`000000oooo0?ooo`2:0?ooo`009@3oool20?mo0240oooo00<000000?ooo`3oool0RP3o
ool002D0oooo00<0ogl00?ooo`3oool0803oool00`000000oooo0?ooo`2:0?ooo`00903oool20?mo
0280oooo00<000000?ooo`3oool0RP3oool002<0oooo0P3oO`0S0?ooo`030000003oool0oooo08X0
oooo000S0?ooo`030?mo003oool0oooo0280oooo00<000000?ooo`3oool0RP3oool00280oooo0P3o
O`0T0?ooo`030000003oool0oooo06l0oooo00<0003o0?ooo`3oool0603oool00280oooo00<0ogl0
0?ooo`3oool08`3oool00`000000oooo0?ooo`1_0?ooo`030000o`3oool0oooo01P0oooo000Q0?oo
o`80ogl09@3oool00`000000oooo0?ooo`1^0?ooo`030000o`3oool0oooo01T0oooo000P0?ooo`<0
ogl09@3oool00`000000oooo0?ooo`1^0?ooo`030000o`3oool0oooo01T0oooo000P0?ooo`80ogl0
9P3oool00`000000oooo0?ooo`1]0?ooo`030000o`3oool0oooo01X0oooo000P0?ooo`80ogl09P3o
ool00`000000oooo0?ooo`1]0?ooo`030000o`3oool0oooo01X0oooo000P0?ooo`030?mo003oool0
oooo02D0oooo00<000000?ooo`3oool0K03oool00`000?l0oooo0?ooo`0K0?ooo`007`3oool20?mo
02L0oooo00<000000?ooo`3oool0K03oool00`000?l0oooo0?ooo`0K0?ooo`007P3oool20?mo02P0
oooo00<000000?ooo`3oool0RP3oool001h0oooo00<0ogl00?ooo`3oool09`3oool00`000000oooo
0?ooo`2:0?ooo`007@3oool20?mo02T0oooo00<000000?ooo`3oool0RP3oool001d0oooo00<0ogl0
0?ooo`3oool0:03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0640oooo000L0?oo
o`80ogl0:P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0640oooo000K0?ooo`<0
ogl05P3oool010000000oooo0?ooo`0000020?ooo`<000000`3oool3000000D0oooo00<000000?oo
o`3oool06@3oool01@000000oooo0?ooo`3oool0000000P0oooo0`0000030?ooo`030000003oool0
oooo00@000000P3oool010000000oooo0?ooo`0000030?ooo`<00000B`3oool001/0oooo0P3oO`0G
0?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`070000003oool000000?ooo`00
0000oooo000000070?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002`0oooo00<0003o0?ooo`3o
ool07`3oool001/0oooo0P3oO`0C0?ooo`H000000`3oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`080000003oool000000?oo
o`000000oooo0000003oool400000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`3oool300000080oooo00@000000?ooo`3oool000000P3oool4000002P0oooo00<0003o0?oo
o`3oool0803oool001/0oooo00<0ogl00?ooo`3oool04P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000001@3oool3000001P0oooo00L00000
0?ooo`000000oooo0000003oool0000000L0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo0200oooo000J0?ooo`80ogl05@3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`050?ooo`<000000`3oool010000000oooo0?ooo`3oool300000080oooo0`0000040?ooo`80
0000:@3oool00`000?l0oooo0?ooo`0P0?ooo`006@3oool20?mo01L0oooo00<000000?ooo`000000
103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0Q0?oo
o`006@3oool00`3oO`00oooo0?ooo`0G0?ooo`8000001@3oool3000000<0oooo0`0000050?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0Q0?ooo`00
603oool20?mo02h0oooo00<000000?ooo`3oool0I@3oool00`000?l0oooo0?ooo`0R0?ooo`00603o
ool00`3oO`00oooo0?ooo`0]0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool08P3o
ool001L0oooo0P3oO`0_0?ooo`030000003oool0oooo08X0oooo000F0?ooo`<0ogl0;`3oool00`00
0000oooo0?ooo`2:0?ooo`005P3oool20?mo0300oooo00<000000?ooo`3oool0RP3oool001H0oooo
0P3oO`0`0?ooo`030000003oool0oooo08X0oooo000F0?ooo`030?mo003oool0oooo02l0oooo00<0
00000?ooo`3oool0RP3oool001D0oooo0P3oO`0a0?ooo`030000003oool0oooo08X0oooo000D0?oo
o`80ogl0<P3oool00`000000oooo0?ooo`1Q0?ooo`030000o`3oool0oooo02H0oooo000D0?ooo`03
0?mo003oool0oooo0340oooo00<000000?ooo`3oool0H@3oool00`000?l0oooo0?ooo`0V0?ooo`00
4`3oool20?mo03<0oooo00<000000?ooo`3oool0H03oool00`000?l0oooo0?ooo`0W0?ooo`004`3o
ool00`3oO`00oooo0?ooo`0b0?ooo`030000003oool0oooo0600oooo00<0003o0?ooo`3oool09`3o
ool00180oooo0P3oO`0d0?ooo`030000003oool0oooo05l0oooo00<0003o0?ooo`3oool0:03oool0
0140oooo0`3oO`0d0?ooo`030000003oool0oooo05l0oooo00<0003o0?ooo`3oool0:03oool00140
oooo0P3oO`0e0?ooo`030000003oool0oooo05h0oooo00<0003o0?ooo`3oool0:@3oool00140oooo
0P3oO`0e0?ooo`030000003oool0oooo05h0oooo00<0003o0?ooo`3oool0:@3oool00140oooo00<0
ogl00?ooo`3oool0=03oool00`000000oooo0?ooo`2:0?ooo`00403oool20?mo03H0oooo00<00000
0?ooo`3oool0RP3oool000l0oooo0P3oO`0g0?ooo`030000003oool0oooo08X0oooo000?0?ooo`03
0?mo003oool0oooo03H0oooo00<000000?ooo`3oool0RP3oool000h0oooo0P3oO`0h0?ooo`030000
003oool0oooo08X0oooo000>0?ooo`030?mo003oool0oooo03L0oooo00<000000?ooo`3oool0RP3o
ool000d0oooo0P3oO`0i0?ooo`030000003oool0oooo05X0oooo00<0003o0?ooo`3oool0;@3oool0
00/0oooo0P00o`020?mo03T0oooo00<000000?ooo`3oool0F@3oool00`000?l0oooo0?ooo`0^0?oo
o`002@3oool6003o02D0oooo00@000000?ooo`3oool000000P3oool3000000H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1I0?ooo`030000o`3oool0oooo02h0oooo00090?ooo`H0
0?l09@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo05P0oooo00<0003o0?ooo`3oool0;`3oool000P0
oooo2000o`0P0?ooo`H000000`3oool01P000000oooo0?ooo`3oool000000?ooo`H000000`3oool3
000005P0oooo00<0003o0?ooo`3oool0;`3oool000P0oooo2000o`0P0?ooo`050000003oool0oooo
0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo05P0oooo00<0003o0?ooo`3oool0;`3oool000T0oooo2000
o`0P0?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0E`3oool00`000?l0oooo0?ooo`0`0?oo
o`002@3oool6003o0080oooo00<00?l00?ooo`3oool07P3oool00`000000oooo000000040?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0oooo
05L0oooo00<0003o0?ooo`3oool0<03oool000/0oooo0P00o`050?ooo`03003o003oool0oooo01h0
oooo0P0000050?ooo`<000001@3oool2000000@0oooo00<000000?ooo`3oool0RP3oool004P0oooo
00<000000?ooo`3oool0RP3oool004P0oooo00<000000?ooo`3oool0RP3oool001T0oooo00<00?l0
0?ooo`3oool0;03oool00`000000oooo0?ooo`2:0?ooo`002`3oool3000000`0oooo0`00o`0[0?oo
o`030000003oool0oooo08X0oooo000;0?ooo`030000003oool0oooo00l0oooo0P00o`0Y0?ooo`03
0000003oool0oooo08X0oooo00040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0403oool2003o02L0oooo00<000000?ooo`3oool0D`3oool00`000?l0oooo0?ooo`0d0?ooo`00
103oool2000000030?ooo`000000000000<0oooo00<000000?ooo`3oool04@3oool00`00o`00oooo
0?ooo`0U0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool0=@3oool000@0oooo00X0
00000?ooo`00000000000?ooo`000000oooo0000003oool00000>P3oool00`000000oooo0?ooo`1B
0?ooo`030000o`3oool0oooo03D0oooo00040?ooo`060000003oool0oooo0000003oool000000P3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0540oooo00<0003o0?ooo`3oool0=P3o
ool000@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0J0?ooo`800?l07`3o
ool00`000000oooo0?ooo`1A0?ooo`030000o`3oool0oooo03H0oooo00030?ooo`<000000`3oool3
000001d0oooo0P00o`0M0?ooo`030000003oool0oooo0500oooo00<0003o0?ooo`3oool0=`3oool0
02/0oooo00<00?l00?ooo`3oool06P3oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo
03L0oooo000/0?ooo`800?l06P3oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo03L0
oooo000^0?ooo`03003o003oool0oooo01L0oooo00<000000?ooo`3oool0RP3oool004P0oooo00<0
00000?ooo`3oool0RP3oool004P0oooo00<000000?ooo`3oool0RP3oool003D0oooo00<00?l00?oo
o`3oool0403oool00`000000oooo0?ooo`2:0?ooo`00=P3oool2003o0100oooo00<000000?ooo`3o
ool0RP3oool003P0oooo0P00o`0>0?ooo`030000003oool0oooo08X0oooo000j0?ooo`800?l0303o
ool00`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo03/0oooo000l0?ooo`03003o003oool0
oooo00T0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`0k0?ooo`00B03oool00`00
0000oooo0?ooo`1;0?ooo`030000o`3oool0oooo03`0oooo00180?ooo`030000003oool0oooo04/0
oooo00<0003o0?ooo`3oool0?03oool003@0oooo00@000000?ooo`3oool000000P3oool3000000<0
oooo0`000002003o00<0oooo00<000000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`0m0?ooo`00
=03oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`060000003oool00?l0003o003oool00000C03oool00`000?l0oooo0?ooo`0m0?ooo`00<03oool6
000000<0oooo00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo0?ooo`800?l0
0P0000190?ooo`030000o`3oool0oooo03h0oooo000`0?ooo`050000003oool0oooo0?ooo`000000
103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`0300000000o`00oooo04T0oooo00<0003o0?ooo`3oool0?P3oool00340oooo00@000000?ooo`3o
ool00000103oool01P000000oooo0?ooo`3oool000000?ooo`@000001@3oool00`000000oooo003o
002:0?ooo`00<P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08X0oooo000c0?ooo`8000001@3oool3
000000<0oooo100000040?ooo`030000003oool0oooo08X0oooo00180?ooo`030000003oool0oooo
00H0oooo00<00?l00?ooo`3oool0P@3oool004P0oooo00<000000?ooo`3oool01`3oool2003o0840
oooo00180?ooo`030000003oool0oooo00T0oooo0P00o`1o0?ooo`00B03oool00`000000oooo0?oo
o`0;0?ooo`800?l0>03oool00`000?l0oooo0?ooo`120?ooo`00B03oool00`000000oooo0?ooo`0=
0?ooo`03003o003oool0oooo03D0oooo00<0003o0?ooo`3oool0@P3oool004P0oooo00<000000?oo
o`3oool0A03oool00`000?l0oooo0?ooo`130?ooo`00B03oool00`000000oooo0?ooo`140?ooo`03
0000o`3oool0oooo04<0oooo00180?ooo`030000003oool0oooo01@0oooo00<00?l00?ooo`3oool0
;03oool00`000?l0oooo0?ooo`140?ooo`00B03oool00`000000oooo0?ooo`0E0?ooo`800?l0;03o
ool00`000?l0oooo0?ooo`140?ooo`00B03oool00`000000oooo0?ooo`0G0?ooo`800?l0:@3oool0
0`000?l0oooo0?ooo`150?ooo`00B03oool00`000000oooo0?ooo`0I0?ooo`800?l09`3oool00`00
0?l0oooo0?ooo`150?ooo`00B03oool00`000000oooo0?ooo`0K0?ooo`03003o003oool0oooo06`0
oooo00180?ooo`030000003oool0oooo08X0oooo00180?ooo`030000003oool0oooo08X0oooo0018
0?ooo`030000003oool0oooo0280oooo00<00?l00?ooo`3oool0I@3oool004P0oooo00<000000?oo
o`3oool08`3oool2003o06D0oooo00180?ooo`030000003oool0oooo02D0oooo0P00o`1S0?ooo`00
B03oool00`000000oooo0?ooo`0W0?ooo`800?l05@3oool00`000?l0oooo0?ooo`190?ooo`00B03o
ool00`000000oooo0?ooo`0Y0?ooo`03003o003oool0oooo0140oooo00<0003o0?ooo`3oool0BP3o
ool004P0oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0?ooo`1:0?ooo`00B03oool00`00
0000oooo0?ooo`0l0?ooo`030000o`3oool0oooo04/0oooo00180?ooo`030000003oool0oooo0300
oooo00<00?l00?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`800000@03oool004P0oooo
00<000000?ooo`3oool0<@3oool2003o00T0oooo00<0003o0?ooo`3oool02`3oool00`000000oooo
0?ooo`0m0?ooo`00=03oool010000000oooo0?ooo`0000020?ooo`<000000`3oool3000000D0oooo
00<000000?ooo`3oool0<`3oool2003o00@0oooo0P3o0?l00`000?l0oooo0?ooo`030?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0?P3oool003@0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo03D0oooo00<00?l00?ooo`3o0?l01@3o0?l40?ooo`80000000<0oooo0000
00000000103oool00`000000oooo0?ooo`0m0?ooo`00<03oool6000000<0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool3000003H0oooo00<00?l0
0?l0o`3o0?l0103o0?l40?ooo`0:0000003oool000000000003oool000000?ooo`000000oooo0000
03l0oooo000`0?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03H0oooo203o
0?l30?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`0n0?ooo`00
<@3oool010000000oooo0?ooo`0000040?ooo`060000003oool0oooo0?ooo`000000oooo10000005
0?ooo`030000003oool0oooo03H0oooo203o0?l30?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0@03oool00380oooo00<000000?ooo`000000103oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03L0oooo
1P3o0?l30?ooo`<000000`3oool300000440oooo000c0?ooo`8000001@3oool3000000<0oooo0`00
00050?ooo`030000003oool0oooo03L0oooo1P3o0?m=0?ooo`00B03oool00`000000oooo0?ooo`0i
0?ooo`80o`3oC`3oool004P0oooo00<000000?ooo`3oool0RP3oool004P0oooo00<000000?ooo`3o
ool0RP3oool004P0oooo00<000000?ooo`3oool0RP3oool004P0oooo00<000000?ooo`3oool0RP3o
ool004P0oooo00<000000?ooo`3oool0RP3oool004P0oooo00<000000?ooo`3oool0RP3oool004P0
oooo00<000000?ooo`3oool0RP3oool004P0oooo00<000000?ooo`3oool0RP3oool004P0oooo00<0
00000?ooo`3oool0RP3oool004P0oooo00<000000?ooo`3oool0RP3oool00001\
\>"],
    ImageRangeCache->{{{0, 212}, {212, 0}} -> {2, 3, 0, 0}}],
  "  ",
  StyleBox["\n\t\tFigure 3.1",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " The image of a small square with vertex  ",
  Cell[BoxData[
      \(z\_0 = 2 + \[ImaginaryI]\)]],
  ",  under the mapping  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^2\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[f, Iden, z];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^2;\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {2.0, 3.0, 0.1}, {1.0, 2.0, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{0.0, 3.0}, {0.0, 
              2.0}}, AspectRatio \[Rule] 
          2\/3, \[IndentingNewLine]Ticks \[Rule] {Range[2, 3, 0.5], 
            Range[1, 2, 0.5]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Vertical lines x = a, and horizontal lines y = b.\>"];\)\ \
\), "\n", 
    \(\(CartesianMap[
        f, \ \ {2.0, 3.0, 0.1}, {1.0, 2.0, 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{0, 9}, {0, 12}}, 
        AspectRatio \[Rule] 
          12\/9, \[IndentingNewLine]Ticks \[Rule] {Range[0, 9, 3], 
            Range[0, 12, 4]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<The image parabolas u= \!\(a\^2\)-\!\(v\^2\/\(4\\\ \
a\^2\)\) and u = -\!\(b\^2\)+\!\(v\^2\/\(4\\\ b\^2\)\) under the mapping  w = \
\>\"", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We will need to zoom in closer to the point ",
  Cell[BoxData[
      \(z\_0 = 2 + \[ImaginaryI]\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, Iden, z];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^2;\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {2.0, 2.1, 0.01}, {1.0, 1.1, 
          0.01}, \[IndentingNewLine]PlotRange \[Rule] {{1.8, 2.1}, {0.8, 
              1.1}}, AspectRatio \[Rule] 
          1.0\/1.0, \[IndentingNewLine]Ticks \[Rule] {Range[2.0, 2.1, 0.05], 
            Range[1.0, 1.1, 0.05]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Blue}, 
        AxesOrigin \[Rule] {1.8, 0.8}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Vertical lines x = a, and horizontal lines y = b.\>"];\)\ \
\), "\n", 
    \(\(CartesianMap[
        f, \ {2.0, 2.1, 0.01}, {1.0, 1.1, 
          0.01}, \[IndentingNewLine]PlotRange \[Rule] {{2.5, 3.65}, {3.5, 
              4.65}}, AspectRatio \[Rule] 
          2\/2, \[IndentingNewLine]Ticks \[Rule] {Range[3.0, 3.5, 0.25], 
            Range[4.0, 4.5, 0.25]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}, 
        AxesOrigin \[Rule] {2.5, 3.5}];\)\), "\n", 
    \(\(Print[\*"\"\<The image parabolas u= \!\(a\^2\)-\!\(v\^2\/\(4\\\ \
a\^2\)\) and u = -\!\(b\^2\)+\!\(v\^2\/\(4\\\ b\^2\)\) under the mapping  w = \
\>\"", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We will need to zoom in closer to the point ",
  Cell[BoxData[
      \(z\_0 = 2 + \[ImaginaryI]\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, Iden, z];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^2;\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {2.0, 2.0101, 0.001}, {1.0, 1.01, 
          0.001}, \[IndentingNewLine]PlotRange \[Rule] {{1.98, 
              2.0101}, {0.98, 1.01}}, 
        AspectRatio \[Rule] 
          1.0\/1.0, \[IndentingNewLine]Ticks \[Rule] {Range[2.0, 2.01, 
              0.005], Range[1.0, 1.01, 0.005]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, PlotStyle \[Rule] {Red, Blue}, 
        AxesOrigin \[Rule] {1.98, 0.98}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Vertical lines x = a, and horizontal lines y = b.\>"];\)\ \
\), "\n", 
    \(\(CartesianMap[
        f, \ {2.0, 2.0101, 0.00101}, {1.0, 1.01, 
          0.001}, \[IndentingNewLine]PlotRange \[Rule] {{2.9, 3.07}, {3.9, 
              4.07}}, AspectRatio \[Rule] 
          2\/2, \[IndentingNewLine]Ticks \[Rule] {Range[3.0, 3.04, 0.02], 
            Range[4.0, 4.06, 0.02]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}, 
        AxesOrigin \[Rule] {2.9, 3.9}];\)\), "\n", 
    \(\(Print[\*"\"\<The image parabolas u= \!\(a\^2\)-\!\(v\^2\/\(4\\\ \
a\^2\)\) and u = -\!\(b\^2\)+\!\(v\^2\/\(4\\\ b\^2\)\) under the mapping  w = \
\>\"", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Now we are sufficiently close to see the image points are  ",
  Cell[BoxData[
      \(w\_0 = 3 + 4\ \[ImaginaryI]\)]],
  ",  ",
  Cell[BoxData[
      \(w\_1 = 3.0401 + 4.02\ \[ImaginaryI]\)]],
  ",  ",
  Cell[BoxData[
      \(w\_2 = 2.9799 + 4.04\ \[ImaginaryI]\)]],
  ",  and  ",
  Cell[BoxData[
      \(w\_3 = 3.02 + 4.0602\ \[ImaginaryI]\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\tWe know that f is differentiable, so the limit of the difference \
quotient  ",
  Cell[BoxData[
      \(\(f \((z)\) - f \((z\_0)\)\)\/\(z - z\_0\)\)]],
  "  exists no matter how we approach  ",
  Cell[BoxData[
      \(z\_0 = 2 + \[ImaginaryI]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Thus we can approximate  ",
  Cell[BoxData[
      \(f' \((z\_0)\) = f' \((2 + \[ImaginaryI])\)\)]],
  "  by using a horizontal increment in ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ":  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((2 + \[ImaginaryI])\)\ \  \[TildeTilde] \ \(f \((z\_1)\) - f \
\((z\_0)\)\)\/\(z\_1 - z\_0\)\  = \ \(\(f \((2.01\[InvisibleSpace] + \
\[ImaginaryI])\)\  - \ f \((2 + \
\[ImaginaryI])\)\)\/\(\((2.01\[InvisibleSpace] + \[ImaginaryI])\)\  - \ \((2 \
+ \[ImaginaryI])\)\)\  = \ \(\((3.0401\[InvisibleSpace] + 4.02\ \
\[ImaginaryI])\)\  - \ \((3 + 4\ \[ImaginaryI])\)\)\/\(\((2.01\
\[InvisibleSpace] + \[ImaginaryI])\)\  - \ \((2 + \[ImaginaryI])\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(\(\((3.0401 - 3\[InvisibleSpace])\)\ \  + \ \ \[ImaginaryI] \((4.02 - 4\ \
)\)\)\/\(\((2.01\[InvisibleSpace] - 2)\)\  - \ \[ImaginaryI] \((1 - 1)\)\)\ \ \
 = \ \ \(\(0.0401\  + \ 0.02  \
\[ImaginaryI]\)\/\(\(0.01\)\(\[InvisibleSpace]\)\)\ \  = \ \ 4.01\
\[InvisibleSpace]\  + \ 2\ \[ImaginaryI]\)\)\)\)}]],
  "   "
}], "Text"],

Cell[TextData[{
  "And, we can approximate  ",
  Cell[BoxData[
      \(f' \((z\_0)\) = f' \((2 + \[ImaginaryI])\)\)]],
  "  by using a vertical increment in ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ":  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[\(f' \((2 + \[ImaginaryI])\)\),
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], "\[TildeTilde]", 
            "  ", \(\(f \((z\_2)\)\  - \ 
                  f \((z\_0)\)\)\/\(z\_2\  - \ \ z\_0\)\)}], " ", "=", 
          " ", \(\(f \((2 + 1.01\ \[ImaginaryI])\)\  - \ f \((2 + \
\[ImaginaryI])\)\)\/\(\((2 + 1.01\ \[ImaginaryI])\)\  - \ \((2 + \
\[ImaginaryI])\)\)\  = \ \(\((2.9799\[InvisibleSpace] + 4.04  \
\[ImaginaryI])\)\  - \ \((3 + 4\ \[ImaginaryI])\)\)\/\(\((2 + 1.01\ \
\[ImaginaryI])\)\  - \ \((2 + \[ImaginaryI])\)\)\)}], "   ", 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"                     ", 
        RowBox[{"=", "  ", 
          
          RowBox[{\(\(\((2.9799\[InvisibleSpace] - 
                      3)\)\  + \ \[ImaginaryI] \((4.04 - 4\ )\)\)\/\(\((2 - 
                      2)\)\  + \ \[ImaginaryI] \((1.01\  - 1)\)\)\), "  ", 
            "=", "  ", 
            
            RowBox[{\(\(\(-0.0201\)\  + \ \ 0.04  \[ImaginaryI]\)\/\(0.01\ \
\[ImaginaryI]\)\), "  ", 
              StyleBox["=",
                FontWeight->"Plain"], 
              StyleBox["  ",
                FontWeight->"Plain"], 
              StyleBox[\(4\[InvisibleSpace]\  + \ 2.01\ \[ImaginaryI]\),
                FontWeight->"Plain"]}]}]}]}]}], "Input"],
  "      "
}], "Text"],

Cell[TextData[{
  "Comparing these two results we see that \n\n\t\t\t",
  Cell[BoxData[{\(f' \((2 + \[ImaginaryI])\)\ \  \[TildeTilde] \ \ \(f \
\((z\_1)\)\  - \ f \((z\_0)\)\)\/\(z\_1 - z\_0\)\ \  = \ \ 4.01\
\[InvisibleSpace]\  + \ 2\ \[ImaginaryI]\), "\[IndentingNewLine]", 
      StyleBox["and",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          StyleBox[\(f' \((2 + \[ImaginaryI])\)\),
            FontWeight->"Plain"], 
          StyleBox["  ",
            FontWeight->"Plain"], "\[TildeTilde]", 
          "  ", \(\(f \((z\_2)\)\  - \ 
                f \((z\_0)\)\)\/\(z\_2\  - \ \ z\_0\)\)}], "  ", "=", 
        "  ", \(4\[InvisibleSpace]\  + \ 2.01\ \[ImaginaryI]\)}]}]],
  "  \n\nwhich leads us to speculate that ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(f' \((2 + \[ImaginaryI])\)\),
          FontWeight->"Plain"], "  ", "=", 
        "  ", \(4\[InvisibleSpace]\  + \ 2\ \[ImaginaryI]\)}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThese computations lead to the idea of taking limits along the \
horizontal and vertical directions. When we do so, we get  \n\n\t\t\t",
  Cell[BoxData[{
      \(f' \((2 + \[ImaginaryI])\)\ \  = \ \ \(lim\+\(h \[Rule] 0\)\(f \((2 + \
h + \[ImaginaryI])\)\  - \ f \((2 + \[ImaginaryI])\)\)\/h\ \  = \ \ lim\+\(h \
\[Rule] 0\)\ \(\((2 + h + \[ImaginaryI])\)\^2\  - \ \((3 + 4\ \
\[ImaginaryI])\)\)\/h\)\ \[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(lim\+\(h \
\[Rule] 0\)\ \(3 + 4\ h + h\^2 + \[ImaginaryI]\ \((4 + 2\ h)\)\  - \ \((3 + 4\
\ \[ImaginaryI])\)\)\/h\ \ \  = \ \ \(\(\ \)\(lim\)\)\+\(h \[Rule] 0\)\ \(4  \
h + h\^2\  + \ 2\ h\ \[ImaginaryI]\)\/h\)\)\ \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(lim\+\(h \
\[Rule] 0\)\((4 + h\  + \ 2\ \[ImaginaryI])\)\ \  = \ \ 4\  + \ 
            2\ \[ImaginaryI]\)\)\)}]],
  "   "
}], "Text"],

Cell["and", "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[BoxData[{
      \(f' \((2 + \[ImaginaryI])\)\ \  = \ \ \(lim\+\(h \[Rule] 0\)\(f \((2 + \
\[ImaginaryI] + \[ImaginaryI]\ h)\)\  - \ f \((2 + \[ImaginaryI])\)\)\/\(\
\[ImaginaryI]\ h\)\ \  = \ \ \ lim\+\(h \[Rule] 0\)\ \(\((2 + \[ImaginaryI] + \
\[ImaginaryI]\ h)\)\^2\  - \ \((3 + 4\ \[ImaginaryI])\)\)\/\(\[ImaginaryI]\ h\
\)\)\ \[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(lim\+\(h \
\[Rule] 0\)\ \(3 - 2\ h - h\^2 + \((4 + 4\ h)\) \[ImaginaryI]\  - \ \((3 + 4\ \
\[ImaginaryI])\)\)\/\(\[ImaginaryI]\ h\)\ \  = \ \ \(\(\ \)\(lim\)\)\+\(h \
\[Rule] 0\)\ \(\(-2\) h - \ h\^2 + 4\ h\ \[ImaginaryI]\)\/\(\[ImaginaryI]\ \
h\)\)\)\ \[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(lim\+\(h \
\[Rule] 0\)\((\ 4\  + \ \((2 + h)\) \[ImaginaryI]\ )\)\ \  = \ \ 4\  + \ 
            2\ \[ImaginaryI]\)\)\)}]],
  "  "
}], "Text"],

Cell["\<\
\tWe now generalize this idea by taking limits of an arbitrary differentiable \
complex function and obtain an important result.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Numerical Computations",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[z_] = z\^2;\)\), "\[IndentingNewLine]", 
    \(\(h = 0.1;\)\ \), "\[IndentingNewLine]", 
    \(\(z\_0 = 2 + \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1 = 2 + h + \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_2 = 
        2 + \[ImaginaryI] + \[ImaginaryI]\ h;\)\ \), "\[IndentingNewLine]", 
    \(\(z\_3 = 
        2 + \[ImaginaryI] + \((1 + \[ImaginaryI])\)\ h;\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<   f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(z\_0\) = \>\"", 
        z\_0\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(z\_1\) = \>\"", 
        z\_1\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) - \!\(z\_0\) = (\>\"", z\_1\ , "\<) - (\>", 
        z\_0, "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) - \!\(z\_0\) = \>\"", 
        z\_1\ \  - \ z\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(z\_0\)] = \>\"", 
        f[z\_0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(z\_1\)] = \>\"", 
        f[z\_1]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(z\_1\)] - f[\!\(z\_0\)] = (\>\"", 
        f[z\_1], "\<) - (\>", 
        f[z\_0], "\<)\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(z\_1\)] - f[\!\(z\_0\)] = \>\"", 
        f[z\_1]\  - \ f[z\_0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] \[TildeTilde] \!\(\(f[z\_1] - f[z\_0]\)\/\
\(z\_1 - z\_0\)\)\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] \[TildeTilde] (\>\"", 
        f[z\_1] - f[z\_0], "\<)/(\>", 
        z\_1 - z\_0, "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] \[TildeTilde] \>\"", \(f[z\_1] - \
f[z\_0]\)\/\(z\_1 - z\_0\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The numerical approximation is\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<f'[\>", 
        z\_0, "\<] \[TildeTilde] \>", \(f[z\_1] - f[z\_0]\)\/\(z\_1 - z\_0\)\ \
];\)\)}], "Input"],

Cell[BoxData[{
    \(\(f[z_] = z\^2;\)\), "\[IndentingNewLine]", 
    \(\(h = 0.1;\)\ \), "\[IndentingNewLine]", 
    \(\(z\_0 = 2 + \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1 = 2 + h + \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_2 = 
        2 + \[ImaginaryI] + \[ImaginaryI]\ h;\)\ \), "\[IndentingNewLine]", 
    \(\(z\_3 = 
        2 + \[ImaginaryI] + \((1 + \[ImaginaryI])\)\ h;\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<   f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(z\_0\) = \>\"", 
        z\_0\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(z\_2\) = \>\"", 
        z\_2\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) - \!\(z\_0\) = (\>\"", z\_2\ , "\<) - (\>", 
        z\_0, "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) - \!\(z\_0\) = \>\"", 
        z\_2\ \  - \ z\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(z\_0\)] = \>\"", 
        f[z\_0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(z\_2\)] = \>\"", 
        f[z\_2]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(z\_2\)] - f[\!\(z\_0\)] = (\>\"", 
        f[z\_2], "\<) - (\>", 
        f[z\_0], "\<)\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(z\_2\)] - f[\!\(z\_0\)] = \>\"", 
        f[z\_2]\  - \ f[z\_0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] \[TildeTilde] \!\(\(f[z\_2] - f[z\_0]\)\/\
\(z\_2 - z\_0\)\)\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] \[TildeTilde] (\>\"", 
        f[z\_2] - f[z\_0], "\<)/(\>", 
        z\_2 - z\_0, "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] \[TildeTilde] \>\"", \(f[z\_2] - \
f[z\_0]\)\/\(z\_2 - z\_0\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The numerical approximation is\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<f'[\>", 
        z\_0, "\<] \[TildeTilde] \>", \(f[z\_2] - f[z\_0]\)\/\(z\_2 - z\_0\)\ \
];\)\)}], "Input"],

Cell[BoxData[{
    \(\(f[z_] = z\^2;\)\), "\[IndentingNewLine]", 
    \(\(h = 0.1;\)\ \), "\[IndentingNewLine]", 
    \(\(z\_0 = 2 + \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1 = 2 + h + \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_2 = 
        2 + \[ImaginaryI] + \[ImaginaryI]\ h;\)\ \), "\[IndentingNewLine]", 
    \(\(z\_3 = 
        2 + \[ImaginaryI] + \((1 + \[ImaginaryI])\)\ h;\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<   f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(z\_0\) = \>\"", 
        z\_0\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(z\_3\) = \>\"", 
        z\_3\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) - \!\(z\_0\) = (\>\"", z\_3\ , "\<) - (\>", 
        z\_0, "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) - \!\(z\_0\) = \>\"", 
        z\_3\ \  - \ z\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(z\_0\)] = \>\"", 
        f[z\_0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(z\_3\)] = \>\"", 
        f[z\_3]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(z\_3\)] - f[\!\(z\_0\)] = (\>\"", 
        f[z\_3], "\<) - (\>", 
        f[z\_0], "\<)\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(z\_3\)] - f[\!\(z\_0\)] = \>\"", 
        f[z\_3]\  - \ f[z\_0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] \[TildeTilde] \!\(\(f[z\_3] - f[z\_0]\)\/\
\(z\_3 - z\_0\)\)\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] \[TildeTilde] (\>\"", 
        f[z\_3] - f[z\_0], "\<)/(\>", 
        z\_3 - z\_0, "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] \[TildeTilde] \>\"", \(f[z\_3] - \
f[z\_0]\)\/\(z\_3 - z\_0\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The numerical approximation is\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<f'[\>", 
        z\_0, "\<] \[TildeTilde] \>", \(f[z\_3] - f[z\_0]\)\/\(z\_3 - z\_0\)\ \
];\)\)}], "Input"],

Cell[TextData[{
  "\tWe can use the forward difference formula for numerical differentiation \
and get a more accurate approximation. \n\n\t\t",
  Cell[BoxData[
      \(f' \((z)\)\ \  \[TildeTilde] \ \ \(\(-3\) f \((z)\) + 4  f \((z + \
h\/2)\) - f \((z + h)\)\)\/\(\(h\)\(\ \)\)\)]]
}], "Text"],

Cell[BoxData[{
    \(\(f[z_] = z\^2;\)\), "\[IndentingNewLine]", 
    \(\(h = 0.1;\)\ \), "\[IndentingNewLine]", 
    \(\(z\_0 = 2 + \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1 = 2 + h + \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_2 = 
        2 + \[ImaginaryI] + \[ImaginaryI]\ h;\)\ \), "\[IndentingNewLine]", 
    \(\(z\_3 = 
        2 + \[ImaginaryI] + \((1 + \[ImaginaryI])\)\ h;\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<   f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(z\_0\) = \>\"", 
        z\_0\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(z\_1\) = \>\"", 
        z\_1\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) - \!\(z\_0\) = (\>\"", z\_1\ , "\<) - (\>", 
        z\_0, "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) - \!\(z\_0\) = \>\"", 
        z\_1\ \  - \ z\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    f[\!\(z\_0\)] = \>\"", 
        f[z\_0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(\(z\_1 + z\_0\)\/2\)] = \>\"", 
        f[\(z\_1 + z\_0\)\/2]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    f[\!\(z\_1\)] = \>\"", 
        f[z\_1]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<- f[\!\(z\_1\)] + 4f[\!\(\(z\_1 + z\_0\)\/2\)] - \
3f[\!\(z\_0\)] = (\>\"", \(-\ f[z\_1]\), "\<) + 4(\>", 
        f[\(z\_1 + z\_0\)\/2], "\<) - 3(\>", 
        f[z\_0], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<- f[\!\(z\_1\)] + 4f[\!\(\(z\_1 + z\_0\)\/2\)] - \
3f[\!\(z\_0\)] = (\>\"", \(-\ f[z\_1]\), "\<) + (\>", 
        4  f[\(z\_1 + z\_0\)\/2], "\<) - (\>", 
        3  f[z\_0], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<- f[\!\(z\_1\)] + 4f[\!\(\(z\_1 + z\_0\)\/2\)] - \
3f[\!\(z\_0\)] = (\>\"", Re[\(-\ f[z\_1]\)], "\<)+(\>", 
        Re[4  f[\(z\_1 + z\_0\)\/2]], "\<)-(\>", 
        Re[3  f[z\_0]], "\<) + \[ImaginaryI]((\>", 
        Im[\(-\ f[z\_1]\)], "\<)+(\>", 
        Im[4  f[\(z\_1 + z\_0\)\/2]], "\<)-(\>", 
        Im[3  f[z\_0]], "\<))\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<- f[\!\(z\_1\)] + 4f[\!\(\(z\_1 + z\_0\)\/2\)] - \
3f[\!\(z\_0\)] = \>\"", \(-f[z\_1]\) + 4  f[\(z\_1 + z\_0\)\/2] - 
          3  f[z\_0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] \[TildeTilde] \!\(\(\(-f[z\_1]\) + 4  \
f[\(z\_1 + z\_0\)\/2] - 3  f[z\_0]\)\/\(z\_1 - z\_0\)\)\>\""\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] \[TildeTilde] (\>\"", \(-f[z\_1]\) + 
          4  f[\(z\_1 + z\_0\)\/2] - 3  f[z\_0], "\<)/(\>", 
        z\_1 - z\_0, "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] \[TildeTilde] \>\"", 
        NumberForm[\(\(-f[z\_1]\) + 4  f[\(z\_1 + z\_0\)\/2] - 3  f[z\_0]\)\/\
\(z\_1 - z\_0\), 12]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The numerical approximation is\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<f'[\>", z\_0, "\<] \[TildeTilde] \>", 
        NumberForm[\(\(-f[z\_1]\) + 4  f[\(z\_1 + z\_0\)\/2] - 3  f[z\_0]\)\/\
\(z\_1 - z\_0\), 12]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The true solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[\>", z\_0, "\<]  \>", \(f'\)[z\_0]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  In this case the approximation is exact and the error is zero.  This is \
because ",
  Cell[BoxData[
      \(f \((z)\) = z\^2\)]],
  " is a polynomial of degree less than 3.  \n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  If we want to use a function for which the numerical approximation is \
not exact, then  ",
  Cell[BoxData[
      \(f \((z)\) = z\^3\)]],
  "  will suffice."
}], "Text"],

Cell[BoxData[{
    \(\(f[z_] = z\^3;\)\), "\[IndentingNewLine]", 
    \(\(h = 0.1;\)\ \), "\[IndentingNewLine]", 
    \(\(z\_0 = 2 + \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1 = 2 + h + \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_2 = 
        2 + \[ImaginaryI] + \[ImaginaryI]\ h;\)\ \), "\[IndentingNewLine]", 
    \(\(z\_3 = 
        2 + \[ImaginaryI] + \((1 + \[ImaginaryI])\)\ h;\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<   f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(z\_0\) = \>\"", 
        z\_0\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(z\_1\) = \>\"", 
        z\_1\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) - \!\(z\_0\) = (\>\"", z\_1\ , "\<) - (\>", 
        z\_0, "\<) = \>", z\_1\ \  - \ z\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    f[\!\(z\_0\)] = \>\"", 
        f[z\_0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(\(z\_1 + z\_0\)\/2\)] = \>\"", 
        f[\(z\_1 + z\_0\)\/2]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    f[\!\(z\_1\)] = \>\"", 
        f[z\_1]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<- f[\!\(z\_1\)] + 4f[\!\(\(z\_1 + z\_0\)\/2\)] - \
3f[\!\(z\_0\)] = (\>\"", \(-\ f[z\_1]\), "\<) + 4(\>", 
        f[\(z\_1 + z\_0\)\/2], "\<) - 3(\>", 
        f[z\_0], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<- f[\!\(z\_1\)] + 4f[\!\(\(z\_1 + z\_0\)\/2\)] - \
3f[\!\(z\_0\)] = (\>\"", \(-\ f[z\_1]\), "\<) + (\>", 
        4  f[\(z\_1 + z\_0\)\/2], "\<) - (\>", 
        3  f[z\_0], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<- f[\!\(z\_1\)] + 4f[\!\(\(z\_1 + z\_0\)\/2\)] - \
3f[\!\(z\_0\)] = (\>\"", Re[\(-\ f[z\_1]\)], "\<)+(\>", 
        Re[4  f[\(z\_1 + z\_0\)\/2]], "\<)-(\>", 
        Re[3  f[z\_0]], "\<) + \[ImaginaryI]((\>", 
        Im[\(-\ f[z\_1]\)], "\<)+(\>", 
        Im[4  f[\(z\_1 + z\_0\)\/2]], "\<)-(\>", 
        Im[3  f[z\_0]], "\<))\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<- f[\!\(z\_1\)] + 4f[\!\(\(z\_1 + z\_0\)\/2\)] - \
3f[\!\(z\_0\)] = \>\"", \(-f[z\_1]\) + 4  f[\(z\_1 + z\_0\)\/2] - 
          3  f[z\_0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] \[TildeTilde] \!\(\(\(-f[z\_1]\) + 4  \
f[\(z\_1 + z\_0\)\/2] - 3  f[z\_0]\)\/\(z\_1 - z\_0\)\)\>\""\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] \[TildeTilde] (\>\"", \(-f[z\_1]\) + 
          4  f[\(z\_1 + z\_0\)\/2] - 3  f[z\_0], "\<)/(\>", 
        z\_1 - z\_0, "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] \[TildeTilde] \>\"", 
        NumberForm[\(\(-f[z\_1]\) + 4  f[\(z\_1 + z\_0\)\/2] - 3  f[z\_0]\)\/\
\(z\_1 - z\_0\), 12]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The numerical approximation is\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<f'[\>", z\_0, "\<] \[TildeTilde] \>", 
        NumberForm[\(\(-f[z\_1]\) + 4  f[\(z\_1 + z\_0\)\/2] - 3  f[z\_0]\)\/\
\(z\_1 - z\_0\), 12]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The true solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[\>", 
        z\_0, "\<]  \>", \(f'\)[z\_0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The error in the numerical approximation is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[\!\(z\_0\)] - \!\(\(\(-f[z\_1]\) + 4  f[\(z\_1 + z\_0\
\)\/2] - 3  f[z\_0]\)\/\(z\_1 - z\_0\)\) = \>\"", 
        Chop[\(f'\)[
              z\_0] - \ \(\(-f[z\_1]\) + 4  f[\(z\_1 + z\_0\)\/2] - 3  \
f[z\_0]\)\/\(z\_1 - z\_0\)\ ]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 3.3 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Cauchy-Riemann Equations",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Cauchy-RiemannEquations.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose that  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\) = \(f \((x + \[ImaginaryI]y)\) = 
          u \((x, y)\) + \[ImaginaryI]\ v \((x, y)\)\)\)]],
  "  \n\nis differentiable at the point ",
  Cell[BoxData[
      \(z\_0 = x\_0 + \[ImaginaryI]\ y\_0\)]],
  ".  Then the partial derivatives of  u  and  v  exist at the point ",
  Cell[BoxData[
      \(\((x\_0, y\_0)\)\)]],
  ", and  \n\n",
  StyleBox["(3-14)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f' \((z\_0)\) = \(u\_x\) \((x\_0, 
              y\_0)\) + \[ImaginaryI]\ \(v\_x\) \((x\_0, y\_0)\)\)]],
  ",   and also  \n\n",
  StyleBox["(3-15)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f' \((z\_0)\) = \(v\_y\) \((x\_0, 
              y\_0)\) - \[ImaginaryI]\ \(u\_y\) \((x\_0, y\_0)\)\)]],
  ".  \n\nEquating the real and imaginary parts of Equations ",
  StyleBox["(3-14)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(3-15)",
    FontColor->RGBColor[0, 0, 1]],
  " gives  \n\n",
  StyleBox["(3-16)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(\(u\_x\) \((x\_0, y\_0)\) = \(v\_y\) \((x\_0, y\_0)\)\)]],
  " and ",
  Cell[BoxData[
      \(\(u\_y\) \((x\_0, y\_0)\) = \(-v\_x\) \((x\_0, y\_0)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.3 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Derivation of the Cauchy-Riemann Equations with ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for the Cauchy-Riemann Equations.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[\[CapitalDelta]x, \[CapitalDelta]y, E1, E2, E3, E4, E5, f, L1, 
        L2, u, v, x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(TagSet[x, Im[x], 0];\)\ \), "\[IndentingNewLine]", 
    \(\(TagSet[y, Im[y], 0];\)\ \), "\[IndentingNewLine]", 
    \(\(TagSet[u, Im[u[x, y]], 0];\)\ \), "\[IndentingNewLine]", 
    \(\(TagSet[v, Im[v[x, y]], 0];\)\ \), "\[IndentingNewLine]", 
    \(\(TagSet[x, Re[x], x];\)\ \), "\[IndentingNewLine]", 
    \(\(TagSet[y, Re[y], y];\)\ \), "\[IndentingNewLine]", 
    \(\(TagSet[u, Re[u[x, y]], u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(TagSet[v, Re[v[x, y]], v[x, y]];\)\ \), "\n", 
    \(\(f[x_\  + \ \[ImaginaryI]\ y_]\  := \ 
        u[x, y]\  + \ \[ImaginaryI]\ v[x, y];\)\ \), "\n", 
    \(\(L1\  = \ 
        Limit[\(f[x + \[CapitalDelta]x + \[ImaginaryI]\ y] - f[x + \
\[ImaginaryI]\ y]\)\/\[CapitalDelta]x, \[CapitalDelta]x \[Rule] 0, 
          Analytic \[Rule] True];\)\ \), "\n", 
    \(\(L2\  = \ 
        Limit[\(f[x + \[ImaginaryI] \((y + \[CapitalDelta]y)\)] - f[x + \
\[ImaginaryI]\ y]\)\/\(\[ImaginaryI]\ \[CapitalDelta]y\), \[CapitalDelta]y \
\[Rule] 0, Analytic \[Rule] True];\)\ \), "\n", 
    \(\(Print["\<    f(z) = \>", f[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(Print["\<Re[f(z)] = \>", 
        ComplexExpand[Re[f[x + \[ImaginaryI]\ y]]]];\)\ \), "\n", 
    \(\(Print["\<Im[f(z)] = \>", 
        ComplexExpand[Im[f[x + \[ImaginaryI]\ y]]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(\[CapitalDelta]x \[Rule] 0\)\)  \!\(\
\[CapitalDelta]f\/\[CapitalDelta]x\) = \!\(lim\+\(\[CapitalDelta]x \[Rule] \
0\)\)  \!\(\(f[x + \[CapitalDelta]x + \[ImaginaryI]\\\ y] - f[x + \
\[ImaginaryI]\\\ y]\)\/\[CapitalDelta]x\) = \>\"", L1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(\[CapitalDelta]y \[Rule] 0\)\) \!\(\
\[CapitalDelta]f\/\(\[ImaginaryI]\\\ \[CapitalDelta]y\)\) = \!\(lim\+\(\
\[CapitalDelta]y \[Rule] 0\)\) \!\(\(f[x + \[ImaginaryI] \((y + \
\[CapitalDelta]y)\)] - f[x + \[ImaginaryI]\\\ y]\)\/\(\[ImaginaryI]\\\ \
\[CapitalDelta]y\)\) = \>\"", L2];\)\ \), "\n", 
    \(Print["\<\>"]\), "\n", 
    \(\(E1\  = \ L1\  \[Equal] \ L2;\)\ \), "\n", 
    \(\(Print[E1];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Equate the real and imaginary parts.\>"];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Cauchy-Riemann equations are:\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(E2\  = \ 
        ReplaceAll[
          E1, {\[ImaginaryI] \[Rule] 0, \(-\[ImaginaryI]\) \[Rule] 
              0}];\)\ \), "\n", 
    \(\(Print[E2];\)\ \), "\n", 
    \(\(E3\  = \ Thread[\(-E1\), Equal];\)\ \), "\n", 
    \(\(E4\  = \ Thread[E2 + E3, Equal];\)\ \), "\n", 
    \(\(E5\  = \ 
        ReplaceAll[
          E4, {\[ImaginaryI] \[Rule] 
              1, \(-\[ImaginaryI]\) \[Rule] \(-1\)}];\)\ \), "\n", 
    \(\(Print[E5];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We have used ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to derive the Cauchy-Riemann equations  ",
  Cell[BoxData[
      RowBox[{\(\(u\_x\) \((x\_0, y\_0)\)\), "=", 
        RowBox[{
          RowBox[{\(v\_y\), \((x\_0, y\_0)\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], 
            "  ", \(u\_y\), \((x\_0, y\_0)\)}], 
          "=", \(\(-v\_x\) \((x\_0, y\_0)\)\)}]}]]],
  ".   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tNote some of the important implications of this theorem.\n\t\n",
  StyleBox["(i).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "    If f is differentiable at ",
  Cell[BoxData[
      \(z\_0\)]],
  ", then the Cauchy-Riemann Equations ",
  StyleBox["(3-16)",
    FontColor->RGBColor[0, 0, 1]],
  " will be satisfied at ",
  Cell[BoxData[
      \(z\_0\)]],
  ", and we can use either either Equation ",
  StyleBox["(3-14)",
    FontColor->RGBColor[0, 0, 1]],
  " or ",
  StyleBox["(3-15)",
    FontColor->RGBColor[0, 0, 1]],
  " to evaluate ",
  Cell[BoxData[
      \(f' \((z\_0)\)\)],
    AspectRatioFixed->True],
  ".   \n\t\n",
  StyleBox["(ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   Taking the contrapositive, if Equations ",
  StyleBox["(3-16)",
    FontColor->RGBColor[0, 0, 1]],
  " are not satisfied at ",
  Cell[BoxData[
      \(z\_0\)]],
  ", then we know automatically that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is not differentiable at ",
  Cell[BoxData[
      \(z\_0\)]],
  ". \n\n",
  StyleBox["(iii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Even if Equations ",
  StyleBox["(3-16)",
    FontColor->RGBColor[0, 0, 1]],
  " are satisfied at ",
  Cell[BoxData[
      \(z\_0\)]],
  ", we cannot necessarily conclude that f is differentiable at ",
  Cell[BoxData[
      \(z\_0\)]],
  ".\n\n\tWe now illustrate each of these points."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 3.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  We know that ",
  Cell[BoxData[
      \(f \((z)\) = \(z\^2 = x\^2 - y\^2 + \[ImaginaryI]\ 2\ x\ y\)\)]],
  "  is differentiable and that  ",
  Cell[BoxData[
      \(f' \((z)\) = 2  z\)],
    AspectRatioFixed->True],
  ".  We also have  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\) = \(z\^2 = \(\((x + \[ImaginaryI]\ y)\)\^2 = \((x\^2 - 
                  y\^2)\) + \[ImaginaryI]\ \((2\ x\ y)\)\)\)\)]],
  ".  \n\nIt is easy to verify that Equations ",
  StyleBox["(3-16)",
    FontColor->RGBColor[0, 0, 1]],
  " are indeed satisfied:\n\n\t",
  Cell[BoxData[
      \(\(u\_x\) \((x, y)\) = \(2  x = \(v\_y\) \((x, y)\)\)\)]],
  "   and   ",
  Cell[BoxData[
      \(\(u\_y\) \((x, y)\) = \(\(-2\) y = \(-v\_x\) \((x, y)\)\)\)]],
  ".  \n\nUsing Equations ",
  StyleBox["(3-14)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(3-15)",
    FontColor->RGBColor[0, 0, 1]],
  ", respectively, to compute ",
  Cell[BoxData[
      \(f' \((z)\)\)],
    AspectRatioFixed->True],
  "  gives\n\n\t\t",
  Cell[BoxData[
      \(f' \((z)\)\  = \ \(\(u\_x\) \((x, 
                y)\) + \[ImaginaryI]\ \(v\_x\) \((x, y)\)\  = \ \(2  
                x + \[ImaginaryI]\ 2  y = \(\(2\)  \(z\)\(\ \)\)\)\)\)],
    AspectRatioFixed->True],
  ",   and   \n\n\t\t",
  Cell[BoxData[
      \(f' \((z)\)\  = \ \(\(v\_y\) \((x, 
                y)\) - \[ImaginaryI]\ \(u\_y\) \((x, y)\)\  = \ \(2  
                x - \[ImaginaryI] \((\(-2\) y)\) = 2  z\)\)\)],
    AspectRatioFixed->True],
  ",\nas expected."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 3.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the function f[z] and determine u[x,y] and v[x,y].", "Text"],

Cell[BoxData[{
    \(\(Clear[f, x, y, u, v, w, w1, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^2;\)\ \), "\n", 
    \(\(w\  = \ ComplexExpand[f[x + \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(u[x_, y_] = ComplexExpand[Re[f[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(v[x_, y_] = ComplexExpand[Im[f[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(Print["\<  f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<  f[z] = \>", w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<u[x,y] = \>", u[x, y]];\)\ \), "\n", 
    \(\(Print["\<v[x,y] = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Verify that the Cauchy-Riemann equations hold.", "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<Does \!\(\[PartialD]\_x\) u[x,y] = \!\(\[PartialD]\_y\) \
v[x,y] ?\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Does \>", \[PartialD]\_x\ 
          u[x, y], "\< = \>", \[PartialD]\_y\ 
          v[x, y], "\< ?  \>", \[PartialD]\_x\ 
            u[x, y] \[Equal] \[PartialD]\_y\ 
            v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \!\(\[PartialD]\_y\) u[x,y] = -\!\(\[PartialD]\_x\) \
v[x,y] ?\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Does \>", \[PartialD]\_y\ 
          u[x, y], "\< = \>", \(-\[PartialD]\_x\ 
            v[x, y]\), "\< ?  \>", \[PartialD]\_y\ 
            u[x, y] \[Equal] \(-\[PartialD]\_x\ 
              v[x, y]\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We see that the Cauchy-Riemann equations hold.\n\nVerify that  ",
  Cell[BoxData[
      \(\(f'\)[z] = u\_x[x, y] + \[ImaginaryI]\ v\_x[x, y]\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(w1\  = \ \[PartialD]\_x\ 
            u[x, y]\ \  + \ \ \[ImaginaryI]\ \[PartialD]\_x\ 
              v[x, y];\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", \(f'\)[x + \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", 
        ComplexExpand[\(f'\)[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[z] = \!\(u\_x\)[x,y] + \[ImaginaryI] \
\!\(v\_x\)[x,y]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = (\>", \[PartialD]\_x\ 
          u[x, y], "\<) + \[ImaginaryI](\>", \[PartialD]\_x\ 
          v[x, y], "\<)\>"];\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", w1];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\(\(f \((z)\)\)\(=\)\(\(\(z\)\(\ \)\)\&_\)\(\ \)\)\)]],
  "  is ",
  StyleBox["nowhere",
    FontColor->RGBColor[1, 0, 1]],
  " differentiable."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We have  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(f \((x + \[ImaginaryI]\ y)\)\  = \ \(x - \
\[ImaginaryI]\ y\  = \ u \((x, y)\) + \[ImaginaryI]\ v \((x, y)\)\)\)\)]],
  ",  where  ",
  Cell[BoxData[
      \(u \((x, y)\) = x\)]],
  "  and  ",
  Cell[BoxData[
      \(v \((x, y)\) = \(-y\)\)]],
  ".  Thus, for any point  ",
  Cell[BoxData[
      \(\((x, y)\)\)]],
  ",  ",
  Cell[BoxData[
      \(\(u\_x\) \((x, y)\) = 1\)]],
  "  and  ",
  Cell[BoxData[
      \(\(v\_y\) \((x, y)\) = \(-1\)\)]],
  ".  The Cauchy-Riemann equations are ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " satisfied at any point ",
  Cell[BoxData[
      \(z = \((x, y)\)\)]],
  ", so we conclude that  ",
  Cell[BoxData[
      \(\(\(f \((z)\)\)\(=\)\(\(\(z\)\(\ \)\)\&_\)\(\ \)\)\)]],
  "  is ",
  StyleBox["nowhere",
    FontColor->RGBColor[1, 0, 1]],
  " differentiable."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 3.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the function f[z].", "Text"],

Cell[BoxData[{
    \(\(Clear[f, u, Ux, Ux0, Uy, Uy0, v, Vx, Vx0, Vy, Vy0, w, x, 
        y];\)\ \), "\n", 
    \(\(TagSet[x, Im[x], 0];\)\ \), "\n", 
    \(\(TagSet[y, Im[y], 0];\)\ \), "\n", 
    \(\(TagSet[x, Re[x], x];\)\ \), "\n", 
    \(\(TagSet[y, Re[y], y];\)\ \), "\n", 
    \(\(w\  = \ Conjugate[x + \[ImaginaryI]\ y];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", w];\)\ \), "\n", 
    \(\(w\  = \ 
        ComplexExpand[w, TargetFunctions \[Rule] {Im, Re}];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", w];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Find the real and imaginary parts of  f[z].", "Text"],

Cell[BoxData[{
    \(\(u[x_, y_]\  = \ Together[ComplexExpand[Re[w]]];\)\ \), "\n", 
    \(\(v[x_, y_]\  = \ Together[ComplexExpand[Im[w]]];\)\ \), "\n", 
    \(\(u[0, 0]\  = \ 0;\)\ \), "\n", 
    \(\(v[0, 0]\  = \ 0;\)\ \), "\n", 
    \(\(f[x_, y_]\  = \ u[x, y]\  + \ \[ImaginaryI]\ v[x, y];\)\ \), "\n", 
    \(\(f[0, 0]\  = \ 0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \), "\n", 
    \(\(Print["\<  f[z] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", u[x, y]];\)\ \), "\n", 
    \(\(Print["\<v[x,y] = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Determine if the Cauchy-Riemann equations hold.", "Text"],

Cell[BoxData[{
    \(\(Ux\  = \ Together[\[PartialD]\_x\ u[x, y]];\)\ \), "\n", 
    \(\(Uy\  = \ Together[\[PartialD]\_y\ u[x, y]];\)\ \), "\n", 
    \(\(Vx\  = \ Together[\[PartialD]\_x\ v[x, y]];\)\ \), "\n", 
    \(\(Vy\  = \ Together[\[PartialD]\_y\ v[x, y]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_x\)[x,y] = \>\"", Ux];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_y\)[x,y] = \>\"", Uy];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_x\)[x,y] = \>\"", Vx];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_y\)[x,y] = \>\"", 
        Vy];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_x\)[x,y] - \!\(v\_y\)[x,y] = \>\"", 
        Simplify[Ux - Vy]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_y\)[x,y] + \!\(v\_x\)[x,y] = \>\"", 
        Simplify[Uy + Vx]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Hence the Cauchy-Riemann do not hold at any point.\n\nThus, we have shown \
that  ",
  Cell[BoxData[
      \(\(\(f \((z)\)\)\(=\)\(\ \)\(\(\(z\)\(\ \)\)\&_\)\(\ \)\)\)]],
  "  is ",
  StyleBox["not ",
    FontColor->RGBColor[1, 0, 1]],
  "analytic for any value of  z."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the function defined by\n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(f \((z)\)\), " ", "=", " ", 
        RowBox[{"{", GridBox[{
              {\(\((\ \(\(z\)\(\ \)\)\&_\ )\)\^2\/z\  = \ \(x\^3 - 3\ x\ y\^2\
\)\/\(\(\ \)\(x\^2 + y\^2\)\) + \[ImaginaryI]\ \(y\^3 - 3\ x\^2\ y\)\/\(x\^2 \
+ y\^2\)\), 
                RowBox[{"  ", 
                  RowBox[{
                    RowBox[{
                      RowBox[{
                        StyleBox["when",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          "StrikeThrough"->False}], 
                        StyleBox["   ",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          "StrikeThrough"->False}], "z"}], "\[NotEqual]", 
                      "0"}], 
                    StyleBox[" ",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox[" ",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox["and",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}]}]}]},
              {\(\(\ \ \ \ \ \ \ \ \ \ \ \ \ \)\(0\)\(\ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\), 
                RowBox[{"  ", 
                  RowBox[{
                    RowBox[{
                      StyleBox["when",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], " ", "z"}], "\[NotEqual]", 
                    RowBox[{"0", 
                      StyleBox[" ",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], 
                      StyleBox[".",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], 
                      StyleBox["             ",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}]}]}]}]}
              }], 
          StyleBox["}",
            FontColor->GrayLevel[1]]}]}]]],
  "  \n\nis not differentiable at the point ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  " even though the Cauchy-Riemann equations are satisfied at ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "0"}], ")"}]]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We must use limits to calculate the partial derivatives at ",
  StyleBox["(0,0)",
    FontFamily->"Courier New"],
  ". \n\n\t\t\t",
  Cell[BoxData[
      \(\(u\_x\) \((0, 
            0)\)\  = \ \(lim\+\(x \[Rule] 0\)\ \(u \((x, 0)\) - u \((0, \
0)\)\)\/x\  = \ \(lim\+\(x \[Rule] 0\)\ \(\(x\^3 - 0\)\/\(x\^2 + 0\) - 0\)\/x\
\  = \ \(lim\+\(x \[Rule] 0\)\ x\/x\ \  = \ \ 1\)\)\)\)]],
  ", \n\n\t\t\t",
  Cell[BoxData[
      \(\(u\_y\) \((0, 
            0)\)\  = \ \(lim\+\(y \[Rule] 0\)\ \(u \((0, y)\) - u \((0, \
y)\)\)\/y\  = \ \(lim\+\(y \[Rule] 0\)\ \(\(0 - 0\)\/\(0 + y\^2\) - 0\)\/y\  \
= \ \(lim\+\(y \[Rule] 0\)\ \ 0\/y\  = \ \ 0\)\)\)\)]],
  ",   \n\n\t\t\t",
  Cell[BoxData[
      \(\(v\_x\) \((0, 
            0)\)\  = \ \(lim\+\(x \[Rule] 0\)\ \(v \((x, 0)\) - v \((0, \
0)\)\)\/x\  = \ \(lim\+\(x \[Rule] 0\)\ \(\(0 - 0\)\/\(x\^2 + 0\) - 0\)\/x\  \
= \ \(lim\+\(x \[Rule] 0\)\ 0\/x\  = \ \ 1\)\)\)\)]],
  ", \n\n\t\t\t",
  Cell[BoxData[
      \(\(v\_y\) \((0, 
            0)\)\  = \ \(lim\+\(y \[Rule] 0\)\ \(v \((0, y)\) - v \((0, \
y)\)\)\/y\  = \ \(lim\+\(y \[Rule] 0\)\ \(\(y\^3 - 0\)\/\(0 + y\^2\) - 0\)\/y\
\  = \ \(lim\+\(y \[Rule] 0\)\ y\/y\ \  = \ \ 1\)\)\)\)]],
  ".\n\nThus we have shown that ",
  Cell[BoxData[
      \(\(u\_x\) \((0, 0)\) = 1\)]],
  ", ",
  Cell[BoxData[
      \(\(u\_y\) \((0, 0)\) = 0\)]],
  ", ",
  Cell[BoxData[
      \(\(v\_x\) \((0, 0)\) = 0\)]],
  ", ",
  Cell[BoxData[
      \(\(v\_y\) \((0, 0)\) = 1\)]],
  "\n\nHence the Cauchy-Riemann equations hold at the point ",
  StyleBox["(0,0)",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe now show that ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is not differentiable at ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  ".  Letting ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " approach ",
  StyleBox["0",
    FontFamily->"Courier New"],
  " along the x axis gives \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(lim\+\(\((x, 0)\) \[Rule] \((0, 0)\)\)\ \(f \((x + 0  \
\[ImaginaryI])\) - f \((0)\)\)\/\(x + 0  \[ImaginaryI] - 0\)\  = \ \
\(lim\+\(\((x, 0)\) \[Rule] \((0, 0)\)\)\ \(\(x\^3 - 0\)\/\(\(\ \)\(x\^2 + \
0\)\) + \[ImaginaryI]\ \(0 - 0\)\/\(x\^2 + 0\) - 0\)\/x\  = \ 
          lim\+\(\((x, 0)\) \[Rule] \((0, 0)\)\)\ \(x\^3\/\(\(\ \)\(x\^2\)\) \
+ 0  \[ImaginaryI] - 0\)\/x\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(lim\+\(\((x, 0)\) \[Rule] \
\((0, 0)\)\)\ x\/x\ \  = \ \ 1\)\)\)}]],
  "  \n\nBut if we let ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " approach ",
  StyleBox["0",
    FontFamily->"Courier New"],
  " along the line  ",
  Cell[BoxData[
      \(y = x\)]],
  "  given by the parametric equations  ",
  Cell[BoxData[
      RowBox[{"x", "=", 
        RowBox[{
          RowBox[{"t", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "y"}], "=", "t"}]}]]],
  ",  then  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(lim\+\(\((t, t)\) \[Rule] \((0, 0)\)\)\ \(f \((t + \[ImaginaryI]\ \
t)\) - f \((0)\)\)\/\(t + \[ImaginaryI]\ t - 0\)\  = \ \(lim\+\(\((t, t)\) \
\[Rule] \((0, 0)\)\)\ \(\(t\^3 - 3\ t\^3\)\/\(\(\ \)\(t\^2 + t\^2\)\) + \
\[ImaginaryI]\ \(t\^3 - 3  t\^3\)\/\(t\^2 + t\^2\) - 0\)\/\(t + \[ImaginaryI]\
\ t\)\  = \ 
          lim\+\(\((t, t)\) \[Rule] \((0, 0)\)\)\ \(\(\(-2\)\ t\^3\)\/\(\(\ \
\)\(2\ t\^2\)\) + \[ImaginaryI]\ \(\(-2\) t\^3\)\/\(2  t\^2\)\)\/\(t + \
\[ImaginaryI]\ t\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(lim\+\(\((t, t)\) \[Rule] \
\((0, 0)\)\)\ \(\(-t\) - \[ImaginaryI]\ t\)\/\(t + \[ImaginaryI]\ t\)\ \  = \ \
\ \(-\ 1\)\)\)\)}]],
  "  \n\nThe two limits are distinct, so ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is not differentiable at the origin. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 3.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(u[0, 0] = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(u[x_, 
          y_] = \(x\^3 - 3\ x\ y\^2\)\/\(x\^2 + y\^2\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(v[0, 0] = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(v[x_, 
          y_] = \(y\^3 - 3\ x\^2\ y\)\/\(x\^2 + y\^2\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(f[0, 0] = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(f[x_, y_] = 
        u[x, y] + \[ImaginaryI]\ v[x, y];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  f[z] = \>", f[x, y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", u[x, y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Ux0\  = \ 
        Limit[\(u[x, 0] - u[0, 0]\)\/\(x - 0\), \ x \[Rule] 0, \ 
          Analytic \[Rule] True];\)\ \), "\n", 
    \(\(Vy0\  = \ 
        Limit[\(v[0, y] - v[0, 0]\)\/\(y - 0\), \ y \[Rule] 0, \ 
          Analytic \[Rule] True];\)\ \), "\n", 
    \(\(Uy0\  = \ 
        Limit[\(u[0, y] - u[0, 0]\)\/\(y - 0\), \ y \[Rule] 0, \ 
          Analytic \[Rule] True];\)\ \), "\n", 
    \(\(Vx0\  = \ 
        Limit[\(v[x, 0] - v[0, 0]\)\/\(x - 0\), \ x \[Rule] 0, \ 
          Analytic \[Rule] True];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_x\)[0,0] = \>\"", Ux0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_y\)[0,0] = \>\"", Uy0];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", v[x, y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(v\_x\)[0,0] = \>\"", Vx0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_y\)[0,0] = \>\"", 
        Vy0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_x\)[0,0] =  \!\(v\_y\)[0,0] ?    \>\"", 
        Ux0 \[Equal] Vy0];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_y\)[0,0] = -\!\(v\_x\)[0,0] ?    \>\"", 
        Uy0 \[Equal] \(-Vx0\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Thus the Cauchy-Riemann equations hold at the origin.  ", "Text"],

Cell[BoxData[{
    \(\(Print["\<  f[z] = \>", f[x, y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(limit1\  = \ 
        Limit[\(f[x, 0] - f[0, 0]\)\/\(x - 0\), \ x \[Rule] 0, \ 
          Analytic \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(limit2\  = \ 
        Limit[\(f[t, t] - f[0, 0]\)\/\(t + \[ImaginaryI]\ t - 0\), \ 
          t \[Rule] 0, \ Analytic \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(\((x, 0)\) \[Rule] \((0, 0)\)\)\) \!\(\(f \
\((x + 0  \[ImaginaryI])\) - f \((0)\)\)\/\(x + 0  \[ImaginaryI] - 0\)\) = \>\
\"", \*"\"\<\!\(lim\+\(\((x, 0)\) \[Rule] \((0, 0)\)\)\) \!\(\(x\^3 - \
0\)\/\(x\^2 + 0\)\)+\!\(\(\[ImaginaryI]\\\ \((0)\)\)\/\(x\^2 + 0\)\) = \>\"", 
        limit1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(\((t, t)\) \[Rule] \((0, 0)\)\)\) \!\(\(f \
\((t + \[ImaginaryI]\\\ t)\) - f \((0)\)\)\/\(t + \[ImaginaryI]\\\ t - 0\)\) \
= \>\"", \*"\"\<\!\(lim\+\(\((t, t)\) \[Rule] \((0, 0)\)\)\) \!\(\(t\^3 - \
t\^3\)\/\(t\^2 + t\^2\)\)+\!\(\(\[ImaginaryI]\\\ \((\(-t\^3\) + \
t\^3)\)\)\/\(t\^2 + t\^2\)\) = \>\"", limit2];\)\)}], "Input"],

Cell[TextData[{
  "The two limits are distinct, so ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is not differentiable at the origin. \n\nWe are done!"
}], "Text"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can also explore another solution.\n\nEnter the function f[z]."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, u, Ux, Ux0, Uy, Uy0, v, Vx, Vx0, Vy, Vy0, w, x, 
        y];\)\ \), "\n", 
    \(\(TagSet[x, Im[x], 0];\)\ \), "\n", 
    \(\(TagSet[y, Im[y], 0];\)\ \), "\n", 
    \(\(TagSet[x, Re[x], x];\)\ \), "\n", 
    \(\(TagSet[y, Re[y], y];\)\ \), "\n", 
    \(\(w\  = \ 
        Conjugate[x + \[ImaginaryI]\ y]\^2\/\(x + \[ImaginaryI]\ y\);\)\ \), \
"\n", 
    \(\(Print["\<f[z] = \>", w];\)\ \), "\n", 
    \(\(w\  = \ 
        ComplexExpand[w, TargetFunctions \[Rule] {Im, Re}];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", w];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Find the real and imaginary parts of  f[z].", "Text"],

Cell[BoxData[{
    \(\(u[x_, y_]\  = \ Together[ComplexExpand[Re[w]]];\)\ \), "\n", 
    \(\(v[x_, y_]\  = \ Together[ComplexExpand[Im[w]]];\)\ \), "\n", 
    \(\(u[0, 0]\  = \ 0;\)\ \), "\n", 
    \(\(v[0, 0]\  = \ 0;\)\ \), "\n", 
    \(\(f[x_, y_]\  = \ u[x, y]\  + \ \[ImaginaryI]\ v[x, y];\)\ \), "\n", 
    \(\(f[0, 0]\  = \ 0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \), "\n", 
    \(\(Print["\<  f[z] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", u[x, y]];\)\ \), "\n", 
    \(\(Print["\<v[x,y] = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Determine where the Cauchy-Riemann equations hold.", "Text"],

Cell[BoxData[{
    \(\(Ux\  = \ Together[\[PartialD]\_x\ u[x, y]];\)\ \), "\n", 
    \(\(Uy\  = \ Together[\[PartialD]\_y\ u[x, y]];\)\ \), "\n", 
    \(\(Vx\  = \ Together[\[PartialD]\_x\ v[x, y]];\)\ \), "\n", 
    \(\(Vy\  = \ Together[\[PartialD]\_y\ v[x, y]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_x\)[x,y] = \>\"", Ux];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_y\)[x,y] = \>\"", Uy];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_x\)[x,y] = \>\"", Vx];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_y\)[x,y] = \>\"", 
        Vy];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_x\)[x,y] - \!\(v\_y\)[x,y] = \>\"", 
        Simplify[Ux - Vy]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_y\)[x,y] + \!\(v\_x\)[x,y] = \>\"", 
        Simplify[Uy + Vx]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "These equations are simultaneously zero, only when both  ",
  Cell[BoxData[
      RowBox[{\(\(4\ \((x\^2 - y\^2)\)\)\/\(x\^2 + y\^2\)\), "=", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], 
            "  ", \(\(\(-8\)\ x\ y\)\/\(x\^2 + y\^2\)\)}], "=", "0"}]}]]],
  "  which appears to be only when  ",
  Cell[BoxData[
      RowBox[{\(x\^2 - y\^2\), "=", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], "  ", "x", " ", "y"}], "=", 
          "0"}]}]]],
  "  or at the origin.   But since they are not defined at the point ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "0"}], ")"}]]],
  ", we must use limits to complete our investigation. \n\nLet's check to see \
if the Cauchy-Riemann equations hold at ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "0"}], ")"}]]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Ux0\  = \ 
        Limit[\(u[x, 0] - u[0, 0]\)\/\(x - 0\), \ x \[Rule] 0, \ 
          Analytic \[Rule] True];\)\ \), "\n", 
    \(\(Vy0\  = \ 
        Limit[\(v[0, y] - v[0, 0]\)\/\(y - 0\), \ y \[Rule] 0, \ 
          Analytic \[Rule] True];\)\ \), "\n", 
    \(\(Uy0\  = \ 
        Limit[\(u[0, y] - u[0, 0]\)\/\(y - 0\), \ y \[Rule] 0, \ 
          Analytic \[Rule] True];\)\ \), "\n", 
    \(\(Vx0\  = \ 
        Limit[\(v[x, 0] - v[0, 0]\)\/\(x - 0\), \ x \[Rule] 0, \ 
          Analytic \[Rule] True];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_x\)[0,0] = \>\"", Ux0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_y\)[0,0] = \>\"", Uy0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_x\)[0,0] = \>\"", Vx0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_y\)[0,0] = \>\"", 
        Vy0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_x\)[0,0] =  \!\(v\_y\)[0,0] ?    \>\"", 
        Ux0 \[Equal] Vy0];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_y\)[0,0] = -\!\(v\_x\)[0,0] ?    \>\"", 
        Uy0 \[Equal] \(-Vx0\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We have shown that ",
  Cell[BoxData[
      RowBox[{\(\(u\_x\) \((0, 0)\)\), "=", 
        RowBox[{
          RowBox[{\(v\_y\), \((0, 0)\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], "  ", \(u\_y\), \((0, 0)\)}], 
          "=", \(\(-v\_x\) \((0, 0)\)\)}]}]]],
  ", that is, the Cauchy-Riemann equations do hold at the origin. \n\nBut,  \
f(z)  is ",
  StyleBox["not ",
    FontColor->RGBColor[1, 0, 1]],
  "differentiable at ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "0"}], ")"}]]],
  " because the following two limits are distinct."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dfdx\  = \ 
        Limit[\(f[x, 0] - f[0, 0]\)\/x, x \[Rule] 0, 
          Analytic \[Rule] True];\)\ \), "\n", 
    \(\(dfdt\  = \ 
        Limit[\(f[t, t] - f[0, 0]\)\/\(t + \[ImaginaryI]\ t\), t \[Rule] 0, 
          Analytic \[Rule] True];\)\ \), "\n", 
    \(\(Print["\<Along  the  x-axis we have\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] 0\)\) \!\(df\/dx\) = \!\(lim\+\(x \
\[Rule] 0\)\) \!\(\(f[x, 0] - f[0, 0]\)\/x\)\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] 0\)\) \!\(df\/dx\) = \!\(lim\+\(x \
\[Rule] 0\)\) (\>\"", f[x, 0] - f[0, 0], "\<)/(\>", 
        x, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] 0\)\) \!\(df\/dx\) = \!\(lim\+\(x \
\[Rule] 0\)\) (\>\"", \((f[x, 0] - f[0, 0])\)/
          x, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] 0\)\) \!\(df\/dx\) = \>\"", 
        dfdx];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Along the line y=t, y=t we have\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(t \[Rule] 0\)\) \!\(df\/dt\) = \!\(lim\+\(t \
\[Rule] 0\)\) \!\(\(f[t, t] - f[0, 0]\)\/\(t + \[ImaginaryI]\\\ \
t\)\)\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(t \[Rule] 0\)\) \!\(df\/dt\) = \!\(lim\+\(t \
\[Rule] 0\)\) (\>\"", f[t, t] - f[0, 0], "\<)/(\>", 
        t + \[ImaginaryI]\ t, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(t \[Rule] 0\)\) \!\(df\/dt\) = \!\(lim\+\(t \
\[Rule] 0\)\) (\>\"", \((f[t, t] - 
              f[0, 0])\)/\((t + \[ImaginaryI]\ t)\), "\<)\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(t \[Rule] 0\)\) \!\(df\/dt\) = \>\"", 
        dfdt];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The two limits are distinct, so w",
  "e have shown that  ",
  Cell[BoxData[
      \(f \((z)\) = \((\ \(\(z\)\(\ \)\)\&_\ )\)\^2\/z\)]],
  "  is not differentiable at the point ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  " even though the Cauchy-Riemann equations are satisfied at ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "0"}], ")"}]]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[TextData[{
  "\tExample 3.6 reiterates that the mere satisfaction of the Cauchy-Riemann \
equations is not sufficient to guarantee the differentiability of a function. \
 The following theorem, however, gives conditions that guarantee the \
differentiability of f at ",
  Cell[BoxData[
      \(z\_0\)]],
  ", so that which we can use Equation ",
  StyleBox["(3-14)",
    FontColor->RGBColor[0, 0, 1]],
  " or ",
  StyleBox["(3-15)",
    FontColor->RGBColor[0, 0, 1]],
  " to compute  ",
  Cell[BoxData[
      \(f' \((z\_0)\)\)]],
  ".  They are referred to as the Cauchy-Riemann conditions for \
differentiability."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 3.4 (Cauchy-Riemann conditions for differentiability).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(f \((z)\) = \(f \((x + \[ImaginaryI]\ y)\) = 
          u \((x, y)\) + \[ImaginaryI]\ v \((x, y)\)\)\)]],
  "  be a continuous function that is defined in some neighborhood of the \
point  ",
  Cell[BoxData[
      \(z\_0 = x\_0 + \[ImaginaryI]\ y\_0\)]],
  ". If all the partial derivatives ",
  Cell[BoxData[
      RowBox[{\(u\_x\), ",", \(u\_y\), ",", 
        RowBox[{\(v\_x\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", \(v\_y\)}]}]]],
  " are continuous at the point",
  Cell[BoxData[
      \(\((x\_0, y\_0)\)\)]],
  " and if the Cauchy-Riemann equations ",
  Cell[BoxData[
      \(\(u\_x\) \((x\_0, y\_0)\) = \(v\_y\) \((x\_0, y\_0)\)\)]],
  " and ",
  Cell[BoxData[
      \(\(u\_y\) \((x\_0, y\_0)\) = \(-v\_x\) \((x\_0, y\_0)\)\)]],
  " hold at ",
  Cell[BoxData[
      \(\((x\_0, y\_0)\)\)]],
  ", then  f(z)  is differentiable at  ",
  Cell[BoxData[
      \(z\_0\)]],
  " and the derivative ",
  Cell[BoxData[
      \(f' \((z\_0)\)\)]],
  "can be computed with either formula ",
  StyleBox["(3-14)",
    FontColor->RGBColor[0, 0, 1]],
  " or ",
  StyleBox["(3-15)",
    FontColor->RGBColor[0, 0, 1]],
  ",  i.e.\n\n\t\t\t",
  Cell[BoxData[
      \(f' \((z\_0)\) = \(u\_x\) \((x\_0, 
              y\_0)\) + \[ImaginaryI]\ \(v\_x\) \((x\_0, y\_0)\)\)]],
  ",  or  \n\n\t\t\t",
  Cell[BoxData[
      \(f' \((z\_0)\) = \(v\_y\) \((x\_0, 
              y\_0)\) - \[ImaginaryI]\ \(u\_y\) \((x\_0, y\_0)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.4 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  At the beginning of this section (Equation ",
  StyleBox["(3-13)",
    FontColor->RGBColor[0, 0, 1]],
  ") we defined the function  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(u \((x, y)\)\  + \ \[ImaginaryI]\ v \((x, 
                y)\)\ \  = \ \ x\^3 - 
            3\ x\ y\^2\  + \ \[ImaginaryI]\ \((3\ x\^2\ y - y\^3)\)\)\)]],
  ".   \n\nShow that this function is differentiable for all ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ", and find its derivative."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We compute  ",
  Cell[BoxData[
      \(\(u\_x\) \((x, y)\)\  = \ \(3  x\^3 - 
            3\ y\^2\  = \ \(v\_y\) \((x, y)\)\)\)]],
  "   and   ",
  Cell[BoxData[
      \(\(u\_y\) \((x, 
            y)\)\  = \ \(\(-\ 6\)\ x\ y\  = \ \(-\ v\_x\) \((x, y)\)\)\)]],
  ",  so the Cauchy-Riemann Equations ",
  StyleBox["(3-16)",
    FontColor->RGBColor[0, 0, 1]],
  ", are satisfied.  Moreover,  ",
  Cell[BoxData[
      RowBox[{"u", ",", "v", ",", \(u\_x\), ",", \(u\_y\), ",", 
        RowBox[{\(v\_x\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", \(v\_y\)}]}]]],
  "  are continuous everywhere.  By Theorem 3.4, ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is differentiable everywhere, and, from Equation ",
  StyleBox["(3-14)",
    FontColor->RGBColor[0, 0, 1]],
  ",  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ \(\(u\_x\) \((x, 
                y)\)\  + \ \[ImaginaryI]\ \(v\_x\) \((x, y)\)\ \  = \ \ 3 
               x\^3 - 3\ y\^2\ \  + \ \[ImaginaryI]\ 6\ x\ y\)\)\(\ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(3\ \((x\^2 - y\^2 + 
                2\ \[ImaginaryI]\ x\ y)\)\ \  = \ \ \(3 \((x + \[ImaginaryI]\ \
y)\)\^2\ \ \  = \ \ 3  z\^2\)\)\)\)}],
    AspectRatioFixed->True],
  "  \n\nAlternatively, from Equation ",
  StyleBox["(3-15)",
    FontColor->RGBColor[0, 0, 1]],
  ",\n\n\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ \(\(v\_y\) \((x, 
                y)\)\  - \ \[ImaginaryI]\ \(u\_y\) \((x, y)\)\ \  = \ \ 3 
               x\^3 - 3\ y\^2\ \  - \ \[ImaginaryI] \((\(-\ 
                    6\)\ x\ y)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(3\ \((x\^2 - y\^2 + 
                2\ \[ImaginaryI]\ x\ y)\)\ \  = \ \ \(3 \((x + \[ImaginaryI]\ \
y)\)\^2\ \ \  = \ \ 3  z\^2\)\)\)\)}],
    AspectRatioFixed->True],
  "  \n\nThis result isn't surprising because  ",
  Cell[BoxData[
      \(\((x + \[ImaginaryI]\ y)\)\^3\  = \ 
        x\^3 - 3\ x\ y\^2\  + \ \[ImaginaryI]\ \((3\ x\^2\ y - y\^3)\)\)]],
  "  and so the function ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is really our old friend  ",
  Cell[BoxData[
      \(f \((z)\) = z\^3\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 3.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the function f[z] and determine u[x,y] and v[x,y].", "Text"],

Cell[BoxData[{
    \(\(Clear[f, x, y, u, v, w, w1, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^3;\)\ \), "\n", 
    \(\(w\  = \ ComplexExpand[f[x + \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(u[x_, y_] = ComplexExpand[Re[f[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(v[x_, y_] = ComplexExpand[Im[f[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(Print["\<  f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<  f[z] = \>", w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<u[x,y] = \>", u[x, y]];\)\ \), "\n", 
    \(\(Print["\<v[x,y] = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Verify that the Cauchy-Riemann equations hold.", "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<Does \!\(\[PartialD]\_x\) u[x,y] = \!\(\[PartialD]\_y\) \
v[x,y] ?\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Does \>", \[PartialD]\_x\ 
          u[x, y], "\< = \>", \[PartialD]\_y\ 
          v[x, y], "\< ?  \>", \[PartialD]\_x\ 
            u[x, y] \[Equal] \[PartialD]\_y\ 
            v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \!\(\[PartialD]\_y\) u[x,y] = -\!\(\[PartialD]\_x\) \
v[x,y] ?\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Does \>", \[PartialD]\_y\ 
          u[x, y], "\< = \>", \(-\[PartialD]\_x\ 
            v[x, y]\), "\< ?  \>", \[PartialD]\_y\ 
            u[x, y] \[Equal] \(-\[PartialD]\_x\ 
              v[x, y]\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We see that the Cauchy-Riemann equations hold.\n\nVerify that  ",
  Cell[BoxData[
      \(\(f'\)[z] = u\_x[x, y] + \[ImaginaryI]\ v\_x[x, y]\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(w1\  = \ \[PartialD]\_x\ 
            u[x, y]\ \  + \ \ \[ImaginaryI]\ \[PartialD]\_x\ 
              v[x, y];\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", \(f'\)[x + \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", 
        ComplexExpand[\(f'\)[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[z] = \!\(u\_x\)[x,y] + \[ImaginaryI] \
\!\(v\_x\)[x,y]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = (\>", \[PartialD]\_x\ 
          u[x, y], "\<) + \[ImaginaryI](\>", \[PartialD]\_x\ 
          v[x, y], "\<)\>"];\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", w1];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \ x\^6 - 15\ x\^4\ y\^2 + 15\ x\^2\ y\^4 - 
          y\^6\  + \ \[ImaginaryI]\ \((6\ x\^5\ y - 20\ x\^3\ y\^3 + 
                6\ x\ y\^5)\)\)]],
  ".   \n\nShow that this function is differentiable for all ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ", and find its derivative."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the function f[z] and determine u[x,y] and v[x,y].", "Text"],

Cell[BoxData[{
    \(\(Clear[f, x, y, u, v, w, w1, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^6;\)\ \), "\n", 
    \(\(w\  = \ ComplexExpand[f[x + \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(u[x_, y_] = ComplexExpand[Re[f[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(v[x_, y_] = ComplexExpand[Im[f[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(Print["\<  f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<  f[z] = \>", w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<u[x,y] = \>", u[x, y]];\)\ \), "\n", 
    \(\(Print["\<v[x,y] = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Verify that the Cauchy-Riemann equations hold.", "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<Does \!\(\[PartialD]\_x\) u[x,y] = \!\(\[PartialD]\_y\) \
v[x,y] ?\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Does \>", \[PartialD]\_x\ 
          u[x, y], "\< = \>", \[PartialD]\_y\ 
          v[x, y], "\< ?  \>", \[PartialD]\_x\ 
            u[x, y] \[Equal] \[PartialD]\_y\ 
            v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \!\(\[PartialD]\_y\) u[x,y] = -\!\(\[PartialD]\_x\) \
v[x,y] ?\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Does \>", \[PartialD]\_y\ 
          u[x, y], "\< = \>", \(-\[PartialD]\_x\ 
            v[x, y]\), "\< ?  \>", \[PartialD]\_y\ 
            u[x, y] \[Equal] \(-\[PartialD]\_x\ 
              v[x, y]\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We see that the Cauchy-Riemann equations hold.\n\nVerify that  ",
  Cell[BoxData[
      \(\(f'\)[z] = u\_x[x, y] + \[ImaginaryI]\ v\_x[x, y]\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(w1\  = \ \[PartialD]\_x\ 
            u[x, y]\ \  + \ \ \[ImaginaryI]\ \[PartialD]\_x\ 
              v[x, y];\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", \(f'\)[x + \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", 
        ComplexExpand[\(f'\)[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[z] = \!\(u\_x\)[x,y] + \[ImaginaryI] \
\!\(v\_x\)[x,y]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = (\>", \[PartialD]\_x\ 
          u[x, y], "\<) + \[ImaginaryI](\>", \[PartialD]\_x\ 
          v[x, y], "\<)\>"];\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", w1];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the function  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(f \((x + \[ImaginaryI]\ y)\)\  = \ \
\[ExponentialE]\^\(-y\)\ cos\ x\  + \ \[ImaginaryI]\ \[ExponentialE]\^\(-y\)\ \
sin\ x\)\)]],
  "  is differentiable for all ",
  Cell[BoxData[
      \(z = x + \[ImaginaryI]\ y\)]],
  " and find its derivative."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We first write  ",
  Cell[BoxData[
      RowBox[{\(u \((x, y)\)\), "=", 
        RowBox[{
          RowBox[{\(\[ExponentialE]\^\(-y\)\), " ", "cos", " ", "x", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "v", \((x, y)\)}], " ", "=", 
          " ", \(\[ExponentialE]\^\(-y\)\ sin\ x\)}]}]]],
  "  and then compute the partial derivatives. \n\n\t\t\t",
  Cell[BoxData[
      \(\(u\_x\) \((x, 
            y)\)\  = \ \(\(\(v\_y\) \((x, y)\)\)\(\ \)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \(\(-\ \[ExponentialE]\^\(-y\)\)\ sin\ x\)]],
  ",   and \n\n\t\t\t",
  Cell[BoxData[
      \(\(v\_x\) \((x, 
            y)\)\  = \ \(\(-\ u\_y\) \((x, 
              y)\)\  = \ \[ExponentialE]\^\(-y\)\ cos\ x\)\)]],
  ".  \n\nWe note that  ",
  Cell[BoxData[
      RowBox[{"u", ",", "v", ",", \(u\_x\), ",", \(u\_y\), ",", 
        RowBox[{\(v\_x\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", \(v\_y\)}]}]]],
  "  are continuous functions and that the Cauchy-Riemann equations hold for \
all values of ",
  Cell[BoxData[
      \(\((x, y)\)\)]],
  ".  Hence, using Equation ",
  StyleBox["(3-14)",
    FontColor->RGBColor[0, 0, 1]],
  ", we write  \n\n\t\t\t",
  Cell[BoxData[
      \(f' \((z)\) = \(\(u\_x\) \((x, y)\) + \[ImaginaryI]\ \(v\_x\) \((x, 
                y)\)\  = \ \(-\ \[ExponentialE]\^\(-y\)\)\ sin\ x + \
\[ImaginaryI]\ \[ExponentialE]\^\(-y\)\ cos\ x\)\)]],
  ". \n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  Can you guess the \"complex\" form of  ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  "  ?"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 3.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the function f[z] and determine if the Cauchy-Riemann equations hold.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[f, u, Ux, Uy, v, Vx, Vy, w1, x, y, z];\)\ \), "\n", 
    \(\(u[x_, y_]\  = \ \[ExponentialE]\^\(-y\)\ Cos[x];\)\ \), "\n", 
    \(\(v[x_, y_]\  = \ \(\[ExponentialE]\^\(-y\)\) Sin[x];\)\ \), "\n", 
    \(\(Ux\  = \ Together[\[PartialD]\_x\ u[x, y]];\)\ \), "\n", 
    \(\(Uy\  = \ Together[\[PartialD]\_y\ u[x, y]];\)\ \), "\n", 
    \(\(Vx\  = \ Together[\[PartialD]\_x\ v[x, y]];\)\ \), "\n", 
    \(\(Vy\  = \ 
        Together[\[PartialD]\_y\ v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   f[z] = \>", 
        u[x, y] + \[ImaginaryI]\ v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \), "\n", 
    \(\(Print["\< u[x,y] = \>", u[x, y]];\)\ \), "\n", 
    \(\(Print["\< v[x,y] = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_x\)[x,y] = \>\"", Ux];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_y\)[x,y] = \>\"", Uy];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_x\)[x,y] = \>\"", Vx];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_y\)[x,y] = \>\"", 
        Vy];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_x\)[x,y] =  \!\(v\_y\)[x,y] ?    \>\"", 
        Ux \[Equal] Vy];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_y\)[x,y] = -\!\(v\_x\)[x,y] ?    \>\"", 
        Uy \[Equal] \(-Vx\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The Cauchy-Riemann equations hold everywhere, so that  ",
  Cell[BoxData[
      \(f \((z)\) = \[ExponentialE]\^\(-y\)\ cos \((x)\) + \[ImaginaryI]\ \
\[ExponentialE]\^\(-y\)\ sin \((x)\)\)]],
  " is analytic for all values of  z."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\< f[z] =  f[x + \[ImaginaryI] y] = \>", 
        u[x, y]\  + \ \[ImaginaryI]\ v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[z] = f'[x + \[ImaginaryI] y] = \!\(\[PartialD]\_x\) \
u[x,y] + \[ImaginaryI] \!\(\[PartialD]\_x\) v[x,y]\>\""\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = f'[x + \[ImaginaryI] y] = \>", \[PartialD]\_x\ 
            u[x, y]\  + \ \[ImaginaryI]\ \[PartialD]\_x\ 
              v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can write this function as  ",
  Cell[BoxData[
      \(f \((z)\) = \(\[ExponentialE]\^\(\[ImaginaryI]\ z\) = \(\
\[ExponentialE]\^\(\[ImaginaryI]\ \((x + \[ImaginaryI]\ y)\)\) = \
\[ExponentialE]\^\(\(-y\) + \[ImaginaryI]\ x\)\)\)\)]],
  ",  and investigate  ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_]\  = \ \[ExponentialE]\^\(\[ImaginaryI]\ z\);\)\ \), "\n", 
    \(\(w1\  = \ \[PartialD]\_x\ 
            u[x, y]\ \  + \ \ \[ImaginaryI]\ \[PartialD]\_x\ 
              v[x, y];\)\ \), "\n", 
    \(\(Print["\<    f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\< f[x+\[ImaginaryI]y] = \>", 
        f[x + \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(Print["\< f[x+\[ImaginaryI]y] = \>", 
        ComplexExpand[
          f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[x+\[ImaginaryI]y] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \
\), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<   f'[z] = \>", \(f'\)[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f'[x+\[ImaginaryI]y] = \>", \(f'\)[
          x + \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(Print["\<f'[x+\[ImaginaryI]y] = \>", 
        ComplexExpand[\(f'\)[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<f'[x+\[ImaginaryI]y] = \!\(u\_x\)[x,y]+ \[ImaginaryI] \!\
\(v\_x\)[x,y]\>\""];\)\ \), "\n", 
    \(\(Print["\<f'[x+\[ImaginaryI]y] = \>", 
        w1];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We have shown that  ",
  Cell[BoxData[
      \(f \((z)\) = \(\[ExponentialE]\^\(\[ImaginaryI]\ z\)\  = \ \(\
\[ExponentialE]\^\(\[ImaginaryI] \((x + \[ImaginaryI]\ y)\)\)\  = \ \(\
\[ExponentialE]\^\(\(-y\) + \[ImaginaryI]x\)\  = \ \[ExponentialE]\^\(-y\)\ \
cos\ x + \[ImaginaryI]\ \[ExponentialE]\^\(-y\)\ sin\ x\)\)\)\)]],
  " is differentiable and hence analytic for all ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ".\n\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(\[ExponentialE]\^\(\[ImaginaryI]\ z\)\ \  = \ \ \
\[ExponentialE]\^\(-y\)\ cos\ x\  + \ \[ImaginaryI]\ \[ExponentialE]\^\(-y\)\ \
sin\ x\)\)]],
  "  is an entire function."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the function  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \[ExponentialE]\^\(x\^2 - y\^2\)\ cos \((2\ x\ y)\)\  \
+ \ \[ImaginaryI]\ \[ExponentialE]\^\(x\^2 - y\^2\)\ sin \((2\ x\ y)\)\)]],
  " is differentiable for all  ",
  Cell[BoxData[
      \(z = x + \[ImaginaryI]\ y\)]],
  "  and find its derivative."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the function f[z] and determine if the Cauchy-Riemann equations hold.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[f, u, Ux, Uy, v, Vx, Vy, w1, x, y, z];\)\ \), "\n", 
    \(\(u[x_, 
          y_]\  = \ \[ExponentialE]\^\(x\^2 - y\^2\)\ Cos[
            2\ x\ y];\)\ \), "\n", 
    \(\(v[x_, 
          y_]\  = \ \[ExponentialE]\^\(x\^2 - y\^2\)\ Sin[
            2\ x\ y];\)\ \), "\n", 
    \(\(Ux\  = \ Together[\[PartialD]\_x\ u[x, y]];\)\ \), "\n", 
    \(\(Uy\  = \ Together[\[PartialD]\_y\ u[x, y]];\)\ \), "\n", 
    \(\(Vx\  = \ Together[\[PartialD]\_x\ v[x, y]];\)\ \), "\n", 
    \(\(Vy\  = \ 
        Together[\[PartialD]\_y\ v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   f[z] = \>", 
        u[x, y] + \[ImaginaryI]\ v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \), "\n", 
    \(\(Print["\< u[x,y] = \>", u[x, y]];\)\ \), "\n", 
    \(\(Print["\< v[x,y] = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_x\)[x,y] = \>\"", Ux];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_y\)[x,y] = \>\"", Uy];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_x\)[x,y] = \>\"", Vx];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_y\)[x,y] = \>\"", 
        Vy];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_x\)[x,y] =  \!\(v\_y\)[x,y] ?    \>\"", 
        Ux \[Equal] Vy];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_y\)[x,y] = -\!\(v\_x\)[x,y] ?    \>\"", 
        Uy \[Equal] \(-Vx\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The Cauchy-Riemann equations hold everywhere, so that  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \[ExponentialE]\^\(x\^2 - y\^2\)\ cos \((2\ x\ y)\)\  \
+ \ \[ImaginaryI]\ \[ExponentialE]\^\(x\^2 - y\^2\)\ sin \((2\ x\ y)\)\)]],
  " is analytic for all values of  z."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\< f[z] =  f[x + \[ImaginaryI] y] = \>", 
        u[x, y]\  + \ \[ImaginaryI]\ v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = f'[x + \[ImaginaryI] y] = \>", \[PartialD]\_x\ 
            u[x, y]\  + \ \[ImaginaryI]\ \[PartialD]\_x\ 
              v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can write this function as  ",
  Cell[BoxData[
      \(f \((z)\) = \(\[ExponentialE]\^\(z\^2\) = \(\[ExponentialE]\^\(\((x + \
\[ImaginaryI]\ y)\)\^2\) = \[ExponentialE]\^\(x\^2 - y\^2 + 2\ \[ImaginaryI]\ \
x\ y\)\)\)\)]],
  ",  and investigate  ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_]\  = \ \[ExponentialE]\^\(z\^2\);\)\ \), "\n", 
    \(\(w1\  = \ \[PartialD]\_x\ 
            u[x, y]\ \  + \ \ \[ImaginaryI]\ \[PartialD]\_x\ 
              v[x, y];\)\ \), "\n", 
    \(\(Print["\<    f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\< f[x+\[ImaginaryI]y] = \>", 
        f[x + \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(Print["\< f[x+\[ImaginaryI]y] = \>", 
        ComplexExpand[
          f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[x+\[ImaginaryI]y] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \
\), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<   f'[z] = \>", \(f'\)[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f'[x+\[ImaginaryI]y] = \>", \(f'\)[
          x + \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(Print["\<f'[x+\[ImaginaryI]y] = \>", 
        ComplexExpand[\(f'\)[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<f'[x+\[ImaginaryI]y] = \!\(u\_x\)[x,y]+ \[ImaginaryI] \!\
\(v\_x\)[x,y]\>\""];\)\ \), "\n", 
    \(\(Print["\<f'[x+\[ImaginaryI]y] = \>", 
        w1];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We have shown that  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \[ExponentialE]\^\(x\^2 - y\^2\)\ cos \((2\ x\ y)\)\  \
+ \ \[ImaginaryI]\ \[ExponentialE]\^\(x\^2 - y\^2\)\ sin \((2\ x\ y)\)\)]],
  " is differentiable and hence analytic for all ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ".\n\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(\[ExponentialE]\^\(z\^2\)\ \  = \ \ \[ExponentialE]\
\^\(x\^2 - y\^2\)\ cos \((2\ x\ y)\)\  + \ \[ImaginaryI]\ \
\[ExponentialE]\^\(x\^2 - y\^2\)\ sin \((2\ x\ y)\)\)\)]],
  " is an entire function."
}], "Text"]
}, Closed]],

Cell["\<\
\tThe Cauchy-Riemann conditions are particularly useful in determining the \
set of points for which a function f is differentiable.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 3.9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the function  ",
  Cell[BoxData[
      \(f \((z)\) = 
        x\^3 + 3\ x\ y\^2 + \[ImaginaryI]\ \((3\ x\^2\ y + y\^3)\)\)]],
  "  is differentiable at points that lie on the ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " axes but analytic nowhere."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  Recall (Definition 3.1) that when we say a function is analytic \
at a point ",
  Cell[BoxData[
      \(z\_0\)]],
  " we mean that the function is differentiable not only at ",
  Cell[BoxData[
      \(z\_0\)]],
  ", but also at every point in some  neighborhood of ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  With this in mind, we proceed to determine where the Cauchy-Riemann \
equations are satisfied.  We write  ",
  Cell[BoxData[
      \(u \((x, y)\) = x\^3 + 3\ x\ y\^2\)]],
  "  and  ",
  Cell[BoxData[
      \(v \((x, y)\) = 3\ x\^2\ y + y\^3\)]],
  "  and compute the partial derivatives: \n\n\t\t\t",
  Cell[BoxData[
      \(\(u\_x\) \((x, y)\)\  = \ 3  x\^3 + 3\ y\^2\)]],
  ",   ",
  Cell[BoxData[
      \(\(v\_y\) \((x, y)\)\  = \ 3  x\^3 + 3\ y\^2\)]],
  ",   and  \n\n\t\t\t",
  Cell[BoxData[
      \(\(u\_y\) \((x, y)\)\  = \ \(\(6\)\(\ \)\(x\)\(\ \)\(y\)\(\ \)\)\)]],
  ",   ",
  Cell[BoxData[
      \(\(v\_x\) \((x, y)\)\  = \ \(\(6\)\(\ \)\(x\)\(\ \)\(y\)\(\ \)\)\)]],
  ".  \n\nHere  ",
  Cell[BoxData[
      RowBox[{"u", ",", "v", ",", \(u\_x\), ",", " ", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", \(v\_y\)}]}]]],
  "  are continuous, and  ",
  Cell[BoxData[
      \(\(u\_x\) \((x, y)\) = \(v\_y\) \((x, y)\)\)]],
  "  holds for all  ",
  Cell[BoxData[
      \(\((x, y)\)\)]],
  ".  But  ",
  Cell[BoxData[
      \(\(u\_y\) \((x, y)\)\  = \ \(-\ v\_x\) \((x, y)\)\)]],
  "  iff  ",
  Cell[BoxData[
      \(6\ x\ y = \ \(-\ 6\)\ x\ y\)]],
  ",  which is equivalent to  ",
  Cell[BoxData[
      \(12\ x\ y = \ 0\)]],
  ".  The Cauchy-Riemann equations hold only when  ",
  Cell[BoxData[
      RowBox[{"x", "=", 
        RowBox[{
          RowBox[{"0", "   ", 
            StyleBox["or",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "y"}], "=", " ", "0"}]}]]],
  ",  and according to Theorem 3.4, ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is differentiable only at points that lie on the coordinate axes.  But \
this means that ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is nowhere analytic because any ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  "-neighborhood about a point on either axis contains points that are not on \
those axes."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 3.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the functions u[x,y]  and  v[x,y] and use them to form  f[z].  Then \
determine where the Cauchy-Riemann equations hold.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[u, Ux, Uy, v, Vx, Vy, x, y];\)\ \), "\n", 
    \(\(u[x_, y_]\  = \ x\^3\  + \ 3\ x\ y\^2;\)\ \), "\n", 
    \(\(v[x_, y_]\  = \ y\^3\  + \ 3\ x\^2\ y;\)\ \), "\n", 
    \(\(Ux\  = \ Together[\[PartialD]\_x\ u[x, y]];\)\ \), "\n", 
    \(\(Uy\  = \ Together[\[PartialD]\_y\ u[x, y]];\)\ \), "\n", 
    \(\(Vx\  = \ Together[\[PartialD]\_x\ v[x, y]];\)\ \), "\n", 
    \(\(Vy\  = \ 
        Together[\[PartialD]\_y\ v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   f[z] = \>", 
        u[x, y]\  + \ \[ImaginaryI]\ v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \), "\n", 
    \(\(Print["\< u[x,y] = \>", u[x, y]];\)\ \), "\n", 
    \(\(Print["\< v[x,y] = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_x\)[x,y] = \>\"", Ux];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_y\)[x,y] = \>\"", Uy];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_x\)[x,y] = \>\"", Vx];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_y\)[x,y] = \>\"", 
        Vy];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_x\)[x,y] =  \!\(v\_y\)[x,y] ?      \>\"", 
        Ux \[Equal] Vy];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_y\)[x,y] = -\!\(v\_x\)[x,y] ?      \>\"", 
        Uy \[Equal] \(-Vx\)];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_y\)[x,y] + \!\(v\_x\)[x,y] = 0 ?   \>\"", 
        Uy + Vx \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The Cauchy-Riemann equations hold only if  x y = 0  which occurs along the \
coordinate axes.  Furthermore, all of the partial derivatives  ",
  Cell[BoxData[
      \(\[PartialD]\_x\ u[x, y] = 3\ x\^2 + 3  y\^2\)]],
  ", ",
  Cell[BoxData[
      \(\[PartialD]\_y\ u[x, y] = 6\ x\ y\)]],
  ", ",
  Cell[BoxData[
      \(\[PartialD]\_x\ v[x, y] = 6\ x\ y\)]],
  ", and ",
  Cell[BoxData[
      \(\[PartialD]\_y\ v[x, y] = 3\ x\^2 + 3  y\^2\)]],
  "  are continuous.  Hence,  ",
  Cell[BoxData[
      \(f \((z)\) = 
        x\^3 + 3\ x\ y\^2 + \[ImaginaryI]\ \((3\ x\^2\ y + y\^3)\)\)]],
  " is differentiable only when  ",
  Cell[BoxData[
      RowBox[{"x", "=", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["or",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "y"}], "=", "0"}]}]]],
  ",  which occurs at points that lie on the coordinate axes.  Therefore,  ",
  Cell[BoxData[
      \(f \((z)\) = 
        x\^3 + 3\ x\ y\^2 + \[ImaginaryI]\ \((3\ x\^2\ y + y\^3)\)\)]],
  "  is ",
  StyleBox["nowhere",
    FontColor->RGBColor[1, 0, 1]],
  " analytic."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tWhen polar coordinates ",
  Cell[BoxData[
      \(\((r, \[Theta])\)\)]],
  " are used to locate points in the plane, we use Expression ",
  StyleBox["(2-2)",
    FontColor->RGBColor[0, 0, 1]],
  " for a complex function for convenience;  that is, \n\n\t\t\t",
  Cell[BoxData[{
      \(\ \ \ \ \ \ \ \(\(f \((z)\)\ \  = \ \ u \((x, 
              y)\)\  + \ \[ImaginaryI]\ v \((x, y)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\(\(f \((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\))\)\  = \ \ u \
\((r\ cos\ \[Theta], 
              r\ sin\ \[Theta])\) + \[ImaginaryI]\ v \((r\ cos\ \[Theta], 
              r\ sin\ \[Theta])\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(U \((r, \
\[Theta])\)\ \  + \ \ \[ImaginaryI]\ V \((r, \[Theta])\)\)\)\)}]],
  "  \n\nwhere  ",
  Cell[BoxData[
      RowBox[{"U", \((r, \[Theta])\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "V", \((r, \[Theta])\)}]]],
  "  are real functions of the real variables ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{"r", "  ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", "\[Theta]"}]}]]],
  ".  The polar form of the Cauchy-Riemann equations and a formula for \
finding f'(z) in terms of the partial derivatives of U(r,) and V(r,) are \
given in Theorem 3.5, which we ask you to prove in Exercise 10.  This theorem \
makes use of the validity of the Cauchy-Riemann equations for the functions u \
and v, so the relation between them and the functions ",
  Cell[BoxData[
      RowBox[{"U", \((r, \[Theta])\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "V", \((r, \[Theta])\)}]]],
  "  - namely,  ",
  Cell[BoxData[
      \(u \((x, y)\)\  = \ \(u \((r\ cos\ \[Theta], r\ sin\ \[Theta])\) = 
          U \((r\ , \[Theta])\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(v \((x, y)\)\  = \ \(v \((r\ cos\ \[Theta], r\ sin\ \[Theta])\) = 
          V \((r\ , \[Theta])\)\)\)]],
  "  - is important."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 3.5  (Polar Form of the Cauchy-Riemann equations).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(f \((z)\) = \(f \((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\))\) \
= U \((r, \[Theta])\) + \[ImaginaryI]\ V \((r, \[Theta])\)\)\)]],
  "  be a continuous function that is defined in some neighborhood of the \
point  ",
  Cell[BoxData[
      \(z\_0 = \(r\_0\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\_0\)\)]],
  ".  If all the partial derivatives  ",
  Cell[BoxData[
      RowBox[{"U", ",", "V", ",", \(U\_r\), ",", \(U\_\[Theta]\), ",", 
        RowBox[{\(V\_x\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", \(V\_\[Theta]\)}]}]]],
  "  are continuous at the point ",
  Cell[BoxData[
      \(\((r\_0, \[Theta]\_0)\)\)]],
  " and if the polar form of the Cauchy-Riemann equations, \n\n",
  StyleBox["(3-22)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\(U\_r\) \((r\_0, \[Theta]\_0)\) = \(1\/r\_0\) \(V\_\[Theta]\) \
\((r\_0, \[Theta]\_0)\)\)]],
  "   and   ",
  Cell[BoxData[
      \(\(V\_r\) \((r\_0, \[Theta]\_0)\) = \(\(-1\)\/r\_0\) \(U\_\[Theta]\) \
\((r\_0, \[Theta]\_0)\)\)]],
  ",    \n\nholds, then ",
  Cell[BoxData[
      \(f \((z\_0)\)\)]],
  " is differentiable at  ",
  Cell[BoxData[
      \(z\_0\)]],
  ", and we can compute the derivative ",
  Cell[BoxData[
      \(f \((z\_0)\)\)]],
  " by using either  \n\n",
  StyleBox["(3-23)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f' \((z\_0)\)\  = \ \(f' \((r\_0\ \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\_0\))\)\  = \ \ \ \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\[Theta]\_0\)\) \((\(U\_r\) \((r\_0, \[Theta]\_0)\) + \[ImaginaryI]\ \(V\_r\) \
\((r\_0, \[Theta]\_0)\))\)\)\)]],
  ",    or    \n\n",
  StyleBox["(3-24)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f' \((z\_0)\)\  = \ \(\(f' \((r\_0\ \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\_0\))\)\)\(\ \)\(=\)\(\ \ \)\)\)]],
  Cell[BoxData[
      \(\(1\/r\_0\) \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\_0\)\) \
\((\(V\_\[Theta]\) \((r\_0, \[Theta]\_0)\) - \[ImaginaryI]\ \(U\_\[Theta]\) \
\((r\_0, \[Theta]\_0)\))\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.5 is an exercise in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that, if f is is the principal square root function given by  \n\n\t\
\t\t",
  Cell[BoxData[
      \(f \((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\))\)\  = \ \ \(f \
\((z)\)\  = \ \(z\^\(1\/2\)\  = \ 
            r\^\(1\/2\)\ \((cos  \[Theta]\/2\  + \ \[ImaginaryI]\ sin  \
\[Theta]\/2)\)\)\)\)]],
  "   \n\nwhere the domain is restricted to be  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{"r", " ", 
          
          RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\), ":", " ", 
            
            RowBox[{"r", ">", 
              RowBox[{
                RowBox[{"0", "  ", 
                  StyleBox["and",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}], "  ", "-", "\[Pi]"}], "<", 
              "\[Theta]", "<", "\[Pi]"}]}]}], "}"}]]],
  ",  then the derivative is given by  \n\n\t\t\t",
  Cell[BoxData[
      \(f' \((z)\)\  = \ \(1\/\(2  z\^\(1/2\)\)\  = \ \(1\/2\) 
            r\^\(-\(1\/2\)\)\ \((cos  \[Theta]\/2\  - \ \[ImaginaryI]\ sin  \
\[Theta]\/2)\)\)\)]],
  "  \n\nfor every point in the domain  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{"r", " ", 
          
          RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\), ":", " ", 
            
            RowBox[{"r", ">", 
              RowBox[{
                RowBox[{"0", "  ", 
                  StyleBox["and",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}], "  ", "-", "\[Pi]"}], "<", 
              "\[Theta]", "<", "\[Pi]"}]}]}], "}"}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution. We write  \n\n\t\t\t",
  Cell[BoxData[
      \(U \((r, \[Theta])\)\  = \ r\^\(1\/2\)\ cos  \[Theta]\/2\)]],
  ",   and   \n\t\t\t\n\t\t\t",
  Cell[BoxData[
      \(V \((r, \[Theta])\)\  = \ r\^\(1\/2\)\ sin  \[Theta]\/2\)]],
  ".  \nThus,\n\t\t\t",
  Cell[BoxData[
      \(\(U\_r\) \((r, \[Theta])\)\  = \ \(\(1\/r\) \(V\_\[Theta]\) \((r, \
\[Theta])\)\ \  = \ \ \(1\/2\) r\^\(-\(1\/2\)\)\ cos  \[Theta]\/2\)\)]],
  ",   and   \n\n\t\t\t",
  Cell[BoxData[
      \(\(V\_r\) \((r, \[Theta])\)\  = \ \(\(\(-1\)\/r\) \(U\_\[Theta]\) \
\((r, \[Theta])\)\ \  = \ \ \(1\/2\) 
            r\^\(-\(1\/2\)\)\ sin  \[Theta]\/2\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Since  ",
  Cell[BoxData[
      RowBox[{"U", ",", "V", ",", \(U\_r\), ",", \(U\_\[Theta]\), ",", 
        RowBox[{\(V\_x\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", \(V\_\[Theta]\)}]}]]],
  "  are continuous at every point in the domain (note the strict inequality \
in ",
  Cell[BoxData[
      \(\(-\[Pi]\) < \[Theta] < \[Pi]\)]],
  "), we use Theorem 3.5 and Equation ",
  StyleBox["(3-23)",
    FontColor->RGBColor[0, 0, 1]],
  " to get  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\  = \ \(f' \((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\))\)\ \  = \ \ \ \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\)\
\) \((\(U\_r\) \((r, \[Theta])\) + \[ImaginaryI]\ \(V\_r\) \((r, \[Theta])\))\
\)\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \ \
\)\(\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\)\) \((\(1\/2\) 
                r\^\(-\(1\/2\)\)\ cos  \[Theta]\/2 + \[ImaginaryI]\ \(1\/2\) 
                r\^\(-\(1\/2\)\)\ sin  \
\[Theta]\/2)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \ \
\)\(\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\)\) \((\(1\/2\) 
                r\^\(-\(1\/2\)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\/2\))\)\  = \ \ \ \(1\/2\) 
            r\^\(-\(1\/2\)\)\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\
\/2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \ \)\(1\/\(2  z\^\(1\/2\)\)\ \
\  = \ \ \(\(1\/2\) \(z\^\(-\(1\/2\)\)\)\(\ \ \)\)\)\)\)}]],
  "\n\nNote that ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " is discontinuous on the negative real axis and is undefined at the \
origin.  Using the terminology of Section 2.4, the negative real axis is a \
branch cut, and the origin is a branch point for this function.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 3.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter  ",
  Cell[BoxData[
      RowBox[{\(u[r, \[Theta]]\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman"], "   ", \(v[r, \[Theta]]\)}]]],
  " and use them to form f[z].  Then verify that polar form of the \
Cauchy-Riemann equations hold."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[r, \[Theta], u, v];\)\ \), "\n", 
    \(\(f[z_] = z\^\(1/2\);\)\), "\[IndentingNewLine]", 
    \(\(u[r_, \[Theta]_] = \(r\^\(1/2\)\) Cos[\[Theta]\/2];\)\ \), "\n", 
    \(\(v[r_, \[Theta]_] = \(r\^\(1/2\)\) Sin[\[Theta]\/2];\)\ \), "\n", 
    \(\(Ur\  = \[PartialD]\_r\ u[r, \[Theta]];\)\ \), "\n", 
    \(\(U\[Theta]\  = \[PartialD]\_\[Theta]\ u[r, \[Theta]];\)\ \), "\n", 
    \(\(Vr\  = \[PartialD]\_r\ v[r, \[Theta]];\)\ \), "\n", 
    \(\(V\[Theta]\  = \[PartialD]\_\[Theta]\ 
          v[r, \[Theta]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  f(z) = \>", f[z]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[r,\[Theta]] = \>", 
        u[r, \[Theta]] + \[ImaginaryI]\ v[
              r, \[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[r,\[Theta]] = u[r,\[Theta]] + \[ImaginaryI] \
v[r,\[Theta]]\>"];\)\ \), "\n", 
    \(\(Print["\<u[r,\[Theta]] = \>", u[r, \[Theta]]];\)\ \), "\n", 
    \(\(Print["\<v[r,\[Theta]] = \>", 
        u[r, \[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[PartialD]\_r\) u[r,\[Theta]] = \>\"", \
\[PartialD]\_r\ u[r, \[Theta]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[PartialD]\_\[Theta]\) u[r,\[Theta]] = \>\"", \
\[PartialD]\_\[Theta]\ u[r, \[Theta]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[PartialD]\_r\) v[r,\[Theta]] = \>\"", \
\[PartialD]\_r\ v[r, \[Theta]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[PartialD]\_\[Theta]\) v[r,\[Theta]] = \>\"", \
\[PartialD]\_\[Theta]\ v[r, \[Theta]]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(\[PartialD]\_r\) u[r,\[Theta]] = \!\(1\/r\) \!\(\
\[PartialD]\_\[Theta]\) v[r,\[Theta]] ?   \>\"", \[PartialD]\_r\ 
            u[r, \[Theta]] \[Equal] 
          1\/r\ \[PartialD]\_\[Theta]\ v[r, \[Theta]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(\[PartialD]\_r\) v[r,\[Theta]] = \!\(\(-1\)\/r\) \
\!\(\[PartialD]\_\[Theta]\) u[r,\[Theta]] ?  \>\"", \[PartialD]\_r\ 
            v[r, \[Theta]] \[Equal] \(-1\)\/r\ \[PartialD]\_\[Theta]\ 
              u[r, \[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "  Second, find the derivative using polar formulae  ",
  Cell[BoxData[
      \(f' \((z)\) = \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\)\) \
\((\[PartialD]\_r\ 
                u[r, \[Theta]] + \[ImaginaryI]\ \[PartialD]\_r\ 
                  v[r, \[Theta]])\)\)]],
  "  and  ",
  Cell[BoxData[
      \(f' \((z)\) = \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\)\) \
\((\[PartialD]\_r\ 
                u[r, \[Theta]] + \[ImaginaryI]\ \[PartialD]\_r\ 
                  v[r, \[Theta]])\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\< f(z) = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f(z) = \>", 
        u[r, \[Theta]] + \[ImaginaryI]\ v[
              r, \[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f(z) = u[r,\[Theta]] + \[ImaginaryI] v[r,\[Theta]]\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'(z) = \
\!\(\[ExponentialE]\^\(-\[ImaginaryI]\[Theta]\)\)(\!\(\[PartialD]\_r\) u[r,\
\[Theta]] + \[ImaginaryI] \!\(\[PartialD]\_r\) v[r,\[Theta]])\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f'(z) = \>", \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\[Theta]\)\) \((\[PartialD]\_r\ 
                u[r, \[Theta]] + \[ImaginaryI]\ \[PartialD]\_r\ 
                  v[r, \[Theta]])\)];\)\ \), "\n", 
    \(\(Print["\<f'(z) = \>", 
        ComplexExpand[\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\)] \((\
\[PartialD]\_r\ 
                u[r, \[Theta]] + \[ImaginaryI]\ \[PartialD]\_r\ 
                  v[r, \[Theta]])\)];\)\ \), "\n", 
    \(\(Print["\<f'(z) = \>", 
        Simplify[
          ComplexExpand[\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\)] \
\((\[PartialD]\_r\ 
                  u[r, \[Theta]] + \[ImaginaryI]\ \[PartialD]\_r\ 
                    v[r, \[Theta]])\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f'(z) = \>", \(f'\)[z]];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We have shown that if  ",
  Cell[BoxData[
      \(f \((z)\) = \(z\^\(1/2\) = 
          r\^\(1/2\)\ \((cos \((\[Theta]\/2)\) + \[ImaginaryI]\ sin \((\
\[Theta]\/2)\))\)\)\)]],
  "  where the domain is restricted to be  ",
  Cell[BoxData[
      \(r > 0\ \ and\ \  - \[Pi] < \[Theta] < \[Pi]\)]],
  ",  then the derivative is given by  ",
  Cell[BoxData[
      \(f' \((z)\) = \(1\/\(2  z\^\(1/2\)\) = 
          r\^\(\(-1\)/2\)\/2\ \((cos \((\[Theta]\/2)\) - \[ImaginaryI]\ sin \
\((\[Theta]\/2)\))\)\)\)]],
  "  where  ",
  Cell[BoxData[
      \(r > 0\ \ and\ \  - \[Pi] < \[Theta] < \[Pi]\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell["\<\
\tTwo important consequences of the Cauchy-Riemann equations close this \
section.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 3.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(f\  = \ u + \[ImaginaryI]\ v\)]],
  "  be an analytic function on the domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  Suppose for all  ",
  Cell[BoxData[
      \(z \[Element] D\)]],
  "  that  ",
  Cell[BoxData[
      \(\(\(|\)\(f \((z)\)\)\(|\)\(\(\[Congruent]\)\(\ \)\(K\)\)\)\)]],
  ",  where ",
  StyleBox["K",
    FontFamily->"Courier New"],
  " is a constant.  Then ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is constant on ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.6 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 3.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(f\  = \ u + \[ImaginaryI]\ v\)]],
  "  be an analytic function on the domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".   If  ",
  Cell[BoxData[
      \(f' \((z)\) \[Congruent] 0\)]],
  "  for all  ",
  Cell[BoxData[
      \(z \[Element] D\)]],
  ",  then ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is constant on ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.7 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Analytic Functions",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/AnalyticFunBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Cauchy-Riemann Equations",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/CauchyRiemannBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Polya Vector Field",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/PolyaFieldBib.html"], None},
  
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Entire Functions",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/EntireFunction.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Holomorphic Functions",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/HolomorphicFunBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{979, 646},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[97180, 2532, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[136872, 3586, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[172458, 4546, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[184247, 4859, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[185505, 4910, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 188758, 5007}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 131, 2, 33, "Text"],
Cell[2236, 66, 1121, 30, 147, "Text"],
Cell[3360, 98, 720, 19, 52, "Text"],
Cell[4083, 119, 1270, 43, 90, "Text"],
Cell[5356, 164, 62755, 1703, 251, "Text"],

Cell[CellGroupData[{
Cell[68136, 1871, 101, 2, 33, "Text"],
Cell[68240, 1875, 1364, 26, 336, "Input"],
Cell[69607, 1903, 138, 5, 33, "Text"],
Cell[69748, 1910, 1481, 28, 379, "Input"],
Cell[71232, 1940, 138, 5, 33, "Text"],
Cell[71373, 1947, 1520, 29, 379, "Input"],
Cell[72896, 1978, 384, 14, 33, "Text"]
}, Closed]],
Cell[73295, 1995, 288, 9, 36, "Text"],
Cell[73586, 2006, 1171, 25, 124, "Text"],
Cell[74760, 2033, 1679, 41, 125, "Text"],
Cell[76442, 2076, 1182, 29, 163, "Text"],
Cell[77627, 2107, 1008, 17, 164, "Text"],
Cell[78638, 2126, 19, 0, 33, "Text"],
Cell[78660, 2128, 958, 17, 126, "Text"],
Cell[79621, 2147, 152, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[79798, 2154, 120, 2, 33, "Text"],
Cell[79921, 2158, 2247, 43, 537, "Input"],
Cell[82171, 2203, 2247, 43, 537, "Input"],
Cell[84421, 2248, 2247, 43, 537, "Input"],
Cell[86671, 2293, 295, 6, 80, "Text"],
Cell[86969, 2301, 3593, 64, 807, "Input"],
Cell[90565, 2367, 536, 17, 71, "Text"],
Cell[91104, 2386, 3946, 71, 871, "Input"]
}, Closed]],
Cell[95065, 2460, 1765, 56, 258, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[96855, 2520, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[97003, 2526, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[97180, 2532, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[97540, 2544, 356, 12, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[97921, 2560, 184, 4, 33, "Text",
  Evaluatable->False],
Cell[98108, 2566, 3065, 57, 734, "Input"],
Cell[101176, 2625, 516, 16, 33, "Text",
  Evaluatable->False]
}, Closed]],
Cell[101707, 2644, 1466, 54, 182, "Text"],
Cell[103176, 2700, 1665, 49, 280, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[104866, 2753, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[105029, 2759, 72, 0, 33, "Text"],
Cell[105104, 2761, 785, 14, 270, "Input"],
Cell[105892, 2777, 62, 0, 33, "Text"],
Cell[105957, 2779, 832, 16, 130, "Input"],
Cell[106792, 2797, 212, 6, 71, "Text"],
Cell[107007, 2805, 832, 16, 190, "Input"]
}, Closed]],
Cell[107854, 2824, 349, 13, 30, "Text",
  Evaluatable->False],
Cell[108206, 2839, 909, 33, 52, "Text"],

Cell[CellGroupData[{
Cell[109140, 2876, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[109303, 2882, 40, 0, 33, "Text"],
Cell[109346, 2884, 564, 12, 210, "Input"],
Cell[109913, 2898, 59, 0, 33, "Text"],
Cell[109975, 2900, 739, 13, 250, "Input"],
Cell[110717, 2915, 63, 0, 33, "Text"],
Cell[110783, 2917, 879, 16, 250, "Input"],
Cell[111665, 2935, 348, 11, 71, "Text",
  Evaluatable->False]
}, Closed]],
Cell[112028, 2949, 5306, 123, 130, "Text",
  Evaluatable->False],
Cell[117337, 3074, 1622, 44, 326, "Text"],
Cell[118962, 3120, 2658, 66, 310, "Text"],

Cell[CellGroupData[{
Cell[121645, 3190, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[121808, 3196, 1920, 39, 570, "Input"],
Cell[123731, 3237, 71, 0, 33, "Text"],
Cell[123805, 3239, 1171, 18, 193, "Input"],
Cell[124979, 3259, 172, 5, 71, "Text"],
Cell[125154, 3266, 179, 5, 71, "Text"],
Cell[125336, 3273, 604, 14, 230, "Input"],
Cell[125943, 3289, 59, 0, 33, "Text"],
Cell[126005, 3291, 739, 13, 250, "Input"],
Cell[126747, 3306, 66, 0, 33, "Text"],
Cell[126816, 3308, 879, 16, 250, "Input"],
Cell[127698, 3326, 1594, 45, 98, "Text",
  Evaluatable->False],
Cell[129295, 3373, 1142, 23, 309, "Input"],
Cell[130440, 3398, 953, 28, 71, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[131418, 3430, 1793, 32, 429, "Input"],
Cell[133214, 3464, 723, 23, 38, "Text",
  Evaluatable->False]
}, Open  ]]
}, Closed]],
Cell[133964, 3491, 632, 18, 68, "Text"],
Cell[134599, 3511, 1923, 59, 147, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[136547, 3574, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[136695, 3580, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[136872, 3586, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[137232, 3598, 653, 18, 106, "Text",
  Evaluatable->False],
Cell[137888, 3618, 2569, 66, 277, "Text"],

Cell[CellGroupData[{
Cell[140482, 3688, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[140645, 3694, 72, 0, 33, "Text"],
Cell[140720, 3696, 785, 14, 270, "Input"],
Cell[141508, 3712, 62, 0, 33, "Text"],
Cell[141573, 3714, 832, 16, 130, "Input"],
Cell[142408, 3732, 212, 6, 71, "Text"],
Cell[142623, 3740, 832, 16, 190, "Input"]
}, Closed]],
Cell[143470, 3759, 512, 15, 68, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[144007, 3778, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[144174, 3784, 72, 0, 33, "Text"],
Cell[144249, 3786, 785, 14, 270, "Input"],
Cell[145037, 3802, 62, 0, 33, "Text"],
Cell[145102, 3804, 832, 16, 130, "Input"],
Cell[145937, 3822, 212, 6, 71, "Text"],
Cell[146152, 3830, 832, 16, 190, "Input"]
}, Closed]],
Cell[146999, 3849, 484, 15, 30, "Text",
  Evaluatable->False],
Cell[147486, 3866, 2112, 58, 223, "Text"],

Cell[CellGroupData[{
Cell[149623, 3928, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[149786, 3934, 99, 2, 33, "Text"],
Cell[149888, 3938, 1479, 26, 410, "Input"],
Cell[151370, 3966, 309, 8, 33, "Text",
  Evaluatable->False],
Cell[151682, 3976, 605, 11, 110, "Input"],
Cell[152290, 3989, 474, 15, 33, "Text",
  Evaluatable->False],
Cell[152767, 4006, 1192, 24, 291, "Input"],
Cell[153962, 4032, 771, 20, 71, "Text"]
}, Closed]],
Cell[154748, 4055, 488, 14, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[155261, 4073, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[155428, 4079, 99, 2, 33, "Text"],
Cell[155530, 4083, 1554, 30, 416, "Input"],
Cell[157087, 4115, 347, 8, 33, "Text",
  Evaluatable->False],
Cell[157437, 4125, 382, 7, 70, "Input"],
Cell[157822, 4134, 461, 15, 33, "Text",
  Evaluatable->False],
Cell[158286, 4151, 1180, 24, 293, "Input"],
Cell[159469, 4177, 667, 18, 71, "Text"]
}, Closed]],
Cell[160151, 4198, 156, 3, 30, "Text"],
Cell[160310, 4203, 493, 17, 33, "Text",
  Evaluatable->False],
Cell[160806, 4222, 2719, 82, 223, "Text"],

Cell[CellGroupData[{
Cell[163550, 4308, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[163713, 4314, 150, 3, 33, "Text"],
Cell[163866, 4319, 1545, 27, 430, "Input"],
Cell[165414, 4348, 1385, 41, 71, "Text",
  Evaluatable->False]
}, Closed]],
Cell[166814, 4392, 2733, 66, 239, "Text"],
Cell[169550, 4460, 2546, 70, 216, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[172121, 4534, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[172269, 4540, 186, 4, 33, "Text",
  Evaluatable->False],
Cell[172458, 4546, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[172818, 4558, 2187, 57, 196, "Text",
  Evaluatable->False],
Cell[175008, 4617, 671, 17, 213, "Text"],
Cell[175682, 4636, 2125, 48, 295, "Text"],

Cell[CellGroupData[{
Cell[177832, 4688, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[177996, 4694, 295, 8, 33, "Text"],
Cell[178294, 4704, 2149, 37, 506, "Input"],
Cell[180446, 4743, 544, 14, 33, "Text"],
Cell[180993, 4759, 1430, 28, 218, "Input"],
Cell[182426, 4789, 632, 18, 59, "Text"]
}, Closed]],
Cell[183073, 4810, 106, 3, 30, "Text"],
Cell[183182, 4815, 715, 28, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[183922, 4847, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[184070, 4853, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[184247, 4859, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[184607, 4871, 548, 23, 30, "Text"],

Cell[CellGroupData[{
Cell[185180, 4898, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[185328, 4904, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[185505, 4910, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[185865, 4922, 290, 7, 30, "Text"],
Cell[186158, 4931, 287, 7, 33, "Text"],
Cell[186448, 4940, 295, 7, 33, "Text"],
Cell[186746, 4949, 284, 7, 33, "Text"],
Cell[187033, 4958, 285, 7, 33, "Text"],
Cell[187321, 4967, 293, 7, 33, "Text"],
Cell[187617, 4976, 257, 5, 33, "Text"],
Cell[187877, 4983, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

