(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    895157,      22824]*)
(*NotebookOutlinePosition[    896198,      22861]*)
(*  CellTagsIndexPosition[    896120,      22855]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Section 3.3  Harmonic Functions",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tLet  ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  "  be a real-valued function of the two real variables x and y defined on a \
domain D.  (Recall that a domain is a connected open set.)  The partial \
differential equation \n\n",
  StyleBox["(3-26)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\(\[Phi]\_xx\) \((x, y)\) + \(\[Phi]\_yy\) \((x, y)\) = 0\)]],
  "  \n\nis known as ",
  StyleBox[ButtonBox["Laplace's equation",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LaplacesEquation.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " and is sometimes referred to as the potential equation.  If ",
  Cell[BoxData[
      RowBox[{
      "\[Phi]", ",", \(\[Phi]\_x\), ",", \(\[Phi]\_y\), ",", \(\[Phi]\_xx\), 
        ",", \(\[Phi]\_xy\), ",", 
        RowBox[{\(\[Phi]\_yx\), 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", \(\[Phi]\_yy\)}]}]]],
  " are all continuous and if ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  " satisfies ",
  StyleBox[ButtonBox["Laplace's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Laplace.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " equation, then ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  " is called a ",
  StyleBox[ButtonBox["harmonic function",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/HarmonicFunction.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ". "
}], "Text"],

Cell[TextData[{
  "\tHarmonic functions are important in the areas of applied mathematics, \
engineering, and mathematical physics.  In calculus we might have been asked \
to show that the functions ",
  Cell[BoxData[
      \(x\^3 - 3\ x\ y\^2\)]],
  " and  ",
  Cell[BoxData[
      \(3\ x\^2\ y - y\^3\)]],
  " are harmonic (and also that the functions  ",
  Cell[BoxData[
      \(\[ExponentialE]\^x\ cos\ y\)]],
  "  and  ",
  Cell[BoxData[
      \(\[ExponentialE]\^x\ sin\ y\)]],
  "  are harmonic).  Harmonic functions are used to solve problems involving \
steady state temperatures, two-dimensional electrostatics, and ideal fluid \
flow.  In Chapter 11 we will see how complex analysis techniques can be used \
to solve some problems involving harmonic functions.  For example, the \
function  ",
  Cell[BoxData[
      \(\[Phi] \((x, 
            y)\)\  = \(1\/\[Pi]\) \((arctan  y\/\(x - 1\)\  - \ 
              arctan  y\/\(x + 1\))\)\)]],
  "  is harmonic in the upper half plane and takes on the boundary values   \
",
  Cell[BoxData[
      RowBox[{\(\[Phi] \((x, 0)\)\), "=", 
        RowBox[{
          RowBox[{"1", "  ", 
            StyleBox["when",
              FontFamily->"Times New Roman"]}], " ", "|", "x", 
          "|", \(\(<\)\(1\)\)}]}]]],
  "  and   ",
  Cell[BoxData[
      RowBox[{\(\[Phi] \((x, 0)\)\), "=", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["when",
              FontFamily->"Times New Roman"]}], " ", "|", "x", 
          "|", \(\(>\)\(1\)\)}]}]]],
  ",  as shown in Figure 3.A. "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.192308 0.00961519 0.192308 [
[.11538 -0.0125 -6 -9 ]
[.11538 -0.0125 6 0 ]
[.30769 -0.0125 -6 -9 ]
[.30769 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -3 -9 ]
[.69231 -0.0125 3 0 ]
[.88462 -0.0125 -3 -9 ]
[.88462 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00962 -6 -4.5 ]
[-0.0125 .00962 0 4.5 ]
[-0.0125 .10577 -18 -4.5 ]
[-0.0125 .10577 0 4.5 ]
[-0.0125 .20192 -6 -4.5 ]
[-0.0125 .20192 0 4.5 ]
[-0.0125 .29808 -18 -4.5 ]
[-0.0125 .29808 0 4.5 ]
[-0.0125 .39423 -6 -4.5 ]
[-0.0125 .39423 0 4.5 ]
[-0.0125 .49038 -18 -4.5 ]
[-0.0125 .49038 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .5 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-2)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-1)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(1)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(2)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00962 m
.00625 .00962 L
s
[(0)] -0.0125 .00962 1 0 Mshowa
0 .10577 m
.00625 .10577 L
s
[(0.5)] -0.0125 .10577 1 0 Mshowa
0 .20192 m
.00625 .20192 L
s
[(1)] -0.0125 .20192 1 0 Mshowa
0 .29808 m
.00625 .29808 L
s
[(1.5)] -0.0125 .29808 1 0 Mshowa
0 .39423 m
.00625 .39423 L
s
[(2)] -0.0125 .39423 1 0 Mshowa
0 .49038 m
.00625 .49038 L
s
[(2.5)] -0.0125 .49038 1 0 Mshowa
.125 Mabswid
0 .02885 m
.00375 .02885 L
s
0 .04808 m
.00375 .04808 L
s
0 .06731 m
.00375 .06731 L
s
0 .08654 m
.00375 .08654 L
s
0 .125 m
.00375 .125 L
s
0 .14423 m
.00375 .14423 L
s
0 .16346 m
.00375 .16346 L
s
0 .18269 m
.00375 .18269 L
s
0 .22115 m
.00375 .22115 L
s
0 .24038 m
.00375 .24038 L
s
0 .25962 m
.00375 .25962 L
s
0 .27885 m
.00375 .27885 L
s
0 .31731 m
.00375 .31731 L
s
0 .33654 m
.00375 .33654 L
s
0 .35577 m
.00375 .35577 L
s
0 .375 m
.00375 .375 L
s
0 .41346 m
.00375 .41346 L
s
0 .43269 m
.00375 .43269 L
s
0 .45192 m
.00375 .45192 L
s
0 .47115 m
.00375 .47115 L
s
.25 Mabswid
0 0 m
0 .5 L
s
.11538 .49375 m
.11538 .5 L
s
.30769 .49375 m
.30769 .5 L
s
.5 .49375 m
.5 .5 L
s
.69231 .49375 m
.69231 .5 L
s
.88462 .49375 m
.88462 .5 L
s
.125 Mabswid
.15385 .49625 m
.15385 .5 L
s
.19231 .49625 m
.19231 .5 L
s
.23077 .49625 m
.23077 .5 L
s
.26923 .49625 m
.26923 .5 L
s
.34615 .49625 m
.34615 .5 L
s
.38462 .49625 m
.38462 .5 L
s
.42308 .49625 m
.42308 .5 L
s
.46154 .49625 m
.46154 .5 L
s
.53846 .49625 m
.53846 .5 L
s
.57692 .49625 m
.57692 .5 L
s
.61538 .49625 m
.61538 .5 L
s
.65385 .49625 m
.65385 .5 L
s
.73077 .49625 m
.73077 .5 L
s
.76923 .49625 m
.76923 .5 L
s
.80769 .49625 m
.80769 .5 L
s
.84615 .49625 m
.84615 .5 L
s
.07692 .49625 m
.07692 .5 L
s
.03846 .49625 m
.03846 .5 L
s
.92308 .49625 m
.92308 .5 L
s
.96154 .49625 m
.96154 .5 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.99375 .00962 m
1 .00962 L
s
.99375 .10577 m
1 .10577 L
s
.99375 .20192 m
1 .20192 L
s
.99375 .29808 m
1 .29808 L
s
.99375 .39423 m
1 .39423 L
s
.99375 .49038 m
1 .49038 L
s
.125 Mabswid
.99625 .02885 m
1 .02885 L
s
.99625 .04808 m
1 .04808 L
s
.99625 .06731 m
1 .06731 L
s
.99625 .08654 m
1 .08654 L
s
.99625 .125 m
1 .125 L
s
.99625 .14423 m
1 .14423 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .18269 m
1 .18269 L
s
.99625 .22115 m
1 .22115 L
s
.99625 .24038 m
1 .24038 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .27885 m
1 .27885 L
s
.99625 .31731 m
1 .31731 L
s
.99625 .33654 m
1 .33654 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .375 m
1 .375 L
s
.99625 .41346 m
1 .41346 L
s
.99625 .43269 m
1 .43269 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .47115 m
1 .47115 L
s
.25 Mabswid
1 0 m
1 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 .951 0 r
.01923 .49038 m
.98077 .49038 L
.98077 .00962 L
.01923 .00962 L
F
0 g
.5 Mabswid
1 .366 0 r
.01923 .20633 m
.0301 .19344 L
.04277 .1793 L
.04751 .17423 L
.05627 .16516 L
.07063 .15102 L
.07579 .14614 L
.08598 .13688 L
.1024 .12274 L
.10407 .12135 L
.12011 .1086 L
.13235 .09936 L
.13919 .09446 L
.1599 .08032 L
.16063 .07983 L
.18272 .06618 L
.18891 .06248 L
.20803 .05204 L
.21719 .04711 L
.23675 .0379 L
.24548 .03356 L
.27002 .02376 L
.27376 .02188 L
.30204 .01209 L
.30523 .00962 L
.01923 .00962 L
F
0 g
.01923 .20633 m
.0301 .19344 L
.04277 .1793 L
.04751 .17423 L
.05627 .16516 L
.07063 .15102 L
.07579 .14614 L
.08598 .13688 L
.1024 .12274 L
.10407 .12135 L
.12011 .1086 L
.13235 .09936 L
.13919 .09446 L
.1599 .08032 L
.16063 .07983 L
.18272 .06618 L
.18891 .06248 L
.20803 .05204 L
.21719 .04711 L
.23675 .0379 L
.24548 .03356 L
.27002 .02376 L
.27376 .02188 L
.30204 .01209 L
.30523 .00962 L
s
.463 1 0 r
.25433 .49038 m
.24548 .47988 L
.24258 .47624 L
.23209 .4621 L
.22272 .44796 L
.21719 .43881 L
.21435 .43382 L
.2069 .41968 L
.2003 .40554 L
.1945 .3914 L
.18945 .37726 L
.18891 .37564 L
.18511 .36312 L
.18146 .34898 L
.17848 .33484 L
.17614 .3207 L
.17442 .30656 L
.17333 .29242 L
.17286 .27828 L
.17299 .26414 L
.17374 .25 L
.1751 .23586 L
.17709 .22172 L
.17972 .20758 L
.18299 .19344 L
.18693 .1793 L
.18891 .17291 L
.19158 .16516 L
.19697 .15102 L
.20314 .13688 L
.21011 .12274 L
.21719 .10978 L
.2179 .1086 L
.22681 .09446 L
.23675 .08032 L
.24548 .06869 L
.24765 .06618 L
.26075 .05204 L
.27376 .03796 L
.27384 .0379 L
.28596 .02376 L
.30204 .01515 L
.30815 .00962 L
.98077 .00962 L
.98077 .49038 L
F
0 g
.25433 .49038 m
.24548 .47988 L
.24258 .47624 L
.23209 .4621 L
.22272 .44796 L
.21719 .43881 L
.21435 .43382 L
.2069 .41968 L
.2003 .40554 L
.1945 .3914 L
.18945 .37726 L
.18891 .37564 L
.18511 .36312 L
.18146 .34898 L
.17848 .33484 L
.17614 .3207 L
.17442 .30656 L
.17333 .29242 L
.17286 .27828 L
.17299 .26414 L
.17374 .25 L
.1751 .23586 L
.17709 .22172 L
.17972 .20758 L
.18299 .19344 L
.18693 .1793 L
.18891 .17291 L
.19158 .16516 L
.19697 .15102 L
.20314 .13688 L
.21011 .12274 L
.21719 .10978 L
.2179 .1086 L
.22681 .09446 L
.23675 .08032 L
.24548 .06869 L
.24765 .06618 L
.26075 .05204 L
.27376 .03796 L
.27384 .0379 L
.28596 .02376 L
.30204 .01515 L
.30815 .00962 L
s
0 1 .122 r
.6891 .00962 m
.69796 .01932 L
.70375 .02376 L
.70746 .0379 L
.71622 .05204 L
.72256 .06618 L
.72624 .07617 L
.72742 .08032 L
.73119 .09446 L
.73411 .1086 L
.73616 .12274 L
.73734 .13688 L
.73767 .15102 L
.73716 .16516 L
.7358 .1793 L
.73357 .19344 L
.73046 .20758 L
.72642 .22172 L
.72624 .22226 L
.7214 .23586 L
.71534 .25 L
.70815 .26414 L
.69969 .27828 L
.69796 .28092 L
.68983 .29242 L
.6783 .30656 L
.66968 .3158 L
.66476 .3207 L
.64866 .33484 L
.6414 .34041 L
.6291 .34898 L
.61312 .3584 L
.60411 .36312 L
.58484 .37138 L
.56814 .37726 L
.55656 .38021 L
.52828 .38535 L
.5 .38704 L
.47172 .38535 L
.44344 .38021 L
.43186 .37726 L
.41516 .37138 L
.39589 .36312 L
.38688 .3584 L
.3709 .34898 L
.3586 .34041 L
.35134 .33484 L
.33524 .3207 L
.33032 .3158 L
.3217 .30656 L
.31017 .29242 L
.30204 .28092 L
.30031 .27828 L
.29185 .26414 L
.28466 .25 L
.2786 .23586 L
.27376 .22226 L
.27358 .22172 L
.26954 .20758 L
.26643 .19344 L
.2642 .1793 L
.26284 .16516 L
.26233 .15102 L
.26266 .13688 L
.26384 .12274 L
.26589 .1086 L
.26881 .09446 L
.27258 .08032 L
.27376 .07617 L
.27744 .06618 L
.28378 .05204 L
.29254 .0379 L
.29625 .02376 L
.30204 .01932 L
.3109 .00962 L
F
0 g
.6891 .00962 m
.69796 .01932 L
.70375 .02376 L
.70746 .0379 L
.71622 .05204 L
.72256 .06618 L
.72624 .07617 L
.72742 .08032 L
.73119 .09446 L
.73411 .1086 L
.73616 .12274 L
.73734 .13688 L
.73767 .15102 L
.73716 .16516 L
.7358 .1793 L
.73357 .19344 L
.73046 .20758 L
.72642 .22172 L
.72624 .22226 L
.7214 .23586 L
.71534 .25 L
.70815 .26414 L
.69969 .27828 L
.69796 .28092 L
.68983 .29242 L
.6783 .30656 L
.66968 .3158 L
.66476 .3207 L
.64866 .33484 L
.6414 .34041 L
.6291 .34898 L
.61312 .3584 L
.60411 .36312 L
.58484 .37138 L
.56814 .37726 L
.55656 .38021 L
.52828 .38535 L
.5 .38704 L
.47172 .38535 L
.44344 .38021 L
.43186 .37726 L
.41516 .37138 L
.39589 .36312 L
.38688 .3584 L
.3709 .34898 L
.3586 .34041 L
.35134 .33484 L
.33524 .3207 L
.33032 .3158 L
.3217 .30656 L
Mistroke
.31017 .29242 L
.30204 .28092 L
.30031 .27828 L
.29185 .26414 L
.28466 .25 L
.2786 .23586 L
.27376 .22226 L
.27358 .22172 L
.26954 .20758 L
.26643 .19344 L
.2642 .1793 L
.26284 .16516 L
.26233 .15102 L
.26266 .13688 L
.26384 .12274 L
.26589 .1086 L
.26881 .09446 L
.27258 .08032 L
.27376 .07617 L
.27744 .06618 L
.28378 .05204 L
.29254 .0379 L
.29625 .02376 L
.30204 .01932 L
.3109 .00962 L
Mfstroke
0 1 .707 r
.68644 .00962 m
.69589 .02376 L
.69796 .02761 L
.69876 .0379 L
.70087 .05204 L
.70196 .06618 L
.70197 .08032 L
.70094 .09446 L
.69888 .1086 L
.69796 .1133 L
.69577 .12274 L
.69156 .13688 L
.68619 .15102 L
.67954 .16516 L
.67145 .1793 L
.66968 .18207 L
.66179 .19344 L
.65014 .20758 L
.6414 .21664 L
.63607 .22172 L
.61867 .23586 L
.61312 .2397 L
.59633 .25 L
.58484 .25564 L
.56378 .26414 L
.55656 .26623 L
.52828 .27232 L
.5 .2743 L
.47172 .27232 L
.44344 .26623 L
.43622 .26414 L
.41516 .25564 L
.40367 .25 L
.38688 .2397 L
.38133 .23586 L
.36393 .22172 L
.3586 .21664 L
.34986 .20758 L
.33821 .19344 L
.33032 .18207 L
.32855 .1793 L
.32046 .16516 L
.31381 .15102 L
.30844 .13688 L
.30423 .12274 L
.30204 .1133 L
.30112 .1086 L
.29906 .09446 L
.29803 .08032 L
.29804 .06618 L
.29913 .05204 L
.30124 .0379 L
.30204 .02761 L
.30411 .02376 L
.31356 .00962 L
F
0 g
.68644 .00962 m
.69589 .02376 L
.69796 .02761 L
.69876 .0379 L
.70087 .05204 L
.70196 .06618 L
.70197 .08032 L
.70094 .09446 L
.69888 .1086 L
.69796 .1133 L
.69577 .12274 L
.69156 .13688 L
.68619 .15102 L
.67954 .16516 L
.67145 .1793 L
.66968 .18207 L
.66179 .19344 L
.65014 .20758 L
.6414 .21664 L
.63607 .22172 L
.61867 .23586 L
.61312 .2397 L
.59633 .25 L
.58484 .25564 L
.56378 .26414 L
.55656 .26623 L
.52828 .27232 L
.5 .2743 L
.47172 .27232 L
.44344 .26623 L
.43622 .26414 L
.41516 .25564 L
.40367 .25 L
.38688 .2397 L
.38133 .23586 L
.36393 .22172 L
.3586 .21664 L
.34986 .20758 L
.33821 .19344 L
.33032 .18207 L
.32855 .1793 L
.32046 .16516 L
.31381 .15102 L
.30844 .13688 L
.30423 .12274 L
.30204 .1133 L
.30112 .1086 L
.29906 .09446 L
.29803 .08032 L
.29804 .06618 L
Mistroke
.29913 .05204 L
.30124 .0379 L
.30204 .02761 L
.30411 .02376 L
.31356 .00962 L
Mfstroke
0 .707 1 r
.68382 .00962 m
.68977 .02376 L
.69128 .0379 L
.68796 .05204 L
.68398 .06618 L
.67893 .08032 L
.6726 .09446 L
.66968 .10011 L
.66495 .1086 L
.65562 .12274 L
.6442 .13688 L
.6414 .13995 L
.63047 .15102 L
.61312 .16513 L
.61309 .16516 L
.59065 .1793 L
.58484 .1822 L
.55656 .19342 L
.55649 .19344 L
.52828 .19983 L
.5 .20192 L
.47172 .19983 L
.44351 .19344 L
.44344 .19342 L
.41516 .1822 L
.40935 .1793 L
.38691 .16516 L
.38688 .16513 L
.36953 .15102 L
.3586 .13995 L
.3558 .13688 L
.34438 .12274 L
.33505 .1086 L
.33032 .10011 L
.3274 .09446 L
.32107 .08032 L
.31602 .06618 L
.31204 .05204 L
.30872 .0379 L
.31023 .02376 L
.31618 .00962 L
F
0 g
.68382 .00962 m
.68977 .02376 L
.69128 .0379 L
.68796 .05204 L
.68398 .06618 L
.67893 .08032 L
.6726 .09446 L
.66968 .10011 L
.66495 .1086 L
.65562 .12274 L
.6442 .13688 L
.6414 .13995 L
.63047 .15102 L
.61312 .16513 L
.61309 .16516 L
.59065 .1793 L
.58484 .1822 L
.55656 .19342 L
.55649 .19344 L
.52828 .19983 L
.5 .20192 L
.47172 .19983 L
.44351 .19344 L
.44344 .19342 L
.41516 .1822 L
.40935 .1793 L
.38691 .16516 L
.38688 .16513 L
.36953 .15102 L
.3586 .13995 L
.3558 .13688 L
.34438 .12274 L
.33505 .1086 L
.33032 .10011 L
.3274 .09446 L
.32107 .08032 L
.31602 .06618 L
.31204 .05204 L
.30872 .0379 L
.31023 .02376 L
.31618 .00962 L
s
0 .122 1 r
.68121 .00962 m
.68374 .02376 L
.68213 .0379 L
.67304 .05204 L
.66968 .05709 L
.66386 .06618 L
.65242 .08032 L
.6414 .09167 L
.63862 .09446 L
.6219 .1086 L
.61312 .11473 L
.60061 .12274 L
.58484 .13067 L
.57075 .13688 L
.55656 .14126 L
.52828 .14735 L
.5 .14933 L
.47172 .14735 L
.44344 .14126 L
.42925 .13688 L
.41516 .13067 L
.39939 .12274 L
.38688 .11473 L
.3781 .1086 L
.36138 .09446 L
.3586 .09167 L
.34758 .08032 L
.33614 .06618 L
.33032 .05709 L
.32696 .05204 L
.31787 .0379 L
.31626 .02376 L
.31879 .00962 L
F
0 g
.68121 .00962 m
.68374 .02376 L
.68213 .0379 L
.67304 .05204 L
.66968 .05709 L
.66386 .06618 L
.65242 .08032 L
.6414 .09167 L
.63862 .09446 L
.6219 .1086 L
.61312 .11473 L
.60061 .12274 L
.58484 .13067 L
.57075 .13688 L
.55656 .14126 L
.52828 .14735 L
.5 .14933 L
.47172 .14735 L
.44344 .14126 L
.42925 .13688 L
.41516 .13067 L
.39939 .12274 L
.38688 .11473 L
.3781 .1086 L
.36138 .09446 L
.3586 .09167 L
.34758 .08032 L
.33614 .06618 L
.33032 .05709 L
.32696 .05204 L
.31787 .0379 L
.31626 .02376 L
.31879 .00962 L
s
.463 0 1 r
.67855 .00962 m
.67747 .02376 L
.66968 .03631 L
.66811 .0379 L
.65367 .05204 L
.6414 .06096 L
.6346 .06618 L
.61312 .07896 L
.61079 .08032 L
.58484 .09194 L
.57881 .09446 L
.55656 .10077 L
.52828 .10591 L
.5 .1076 L
.47172 .10591 L
.44344 .10077 L
.42119 .09446 L
.41516 .09194 L
.38921 .08032 L
.38688 .07896 L
.3654 .06618 L
.3586 .06096 L
.34633 .05204 L
.33189 .0379 L
.33032 .03631 L
.32253 .02376 L
.32145 .00962 L
F
0 g
.67855 .00962 m
.67747 .02376 L
.66968 .03631 L
.66811 .0379 L
.65367 .05204 L
.6414 .06096 L
.6346 .06618 L
.61312 .07896 L
.61079 .08032 L
.58484 .09194 L
.57881 .09446 L
.55656 .10077 L
.52828 .10591 L
.5 .1076 L
.47172 .10591 L
.44344 .10077 L
.42119 .09446 L
.41516 .09194 L
.38921 .08032 L
.38688 .07896 L
.3654 .06618 L
.3586 .06096 L
.34633 .05204 L
.33189 .0379 L
.33032 .03631 L
.32253 .02376 L
.32145 .00962 L
s
1 0 .951 r
.67579 .00962 m
.67045 .02376 L
.66968 .0246 L
.64565 .0379 L
.6414 .03996 L
.61312 .05192 L
.61286 .05204 L
.58484 .06091 L
.5626 .06618 L
.55656 .06717 L
.52828 .07087 L
.5 .0721 L
.47172 .07087 L
.44344 .06717 L
.4374 .06618 L
.41516 .06091 L
.38714 .05204 L
.38688 .05192 L
.3586 .03996 L
.35435 .0379 L
.33032 .0246 L
.32955 .02376 L
.32421 .00962 L
F
0 g
.67579 .00962 m
.67045 .02376 L
.66968 .0246 L
.64565 .0379 L
.6414 .03996 L
.61312 .05192 L
.61286 .05204 L
.58484 .06091 L
.5626 .06618 L
.55656 .06717 L
.52828 .07087 L
.5 .0721 L
.47172 .07087 L
.44344 .06717 L
.4374 .06618 L
.41516 .06091 L
.38714 .05204 L
.38688 .05192 L
.3586 .03996 L
.35435 .0379 L
.33032 .0246 L
.32955 .02376 L
.32421 .00962 L
s
1 0 .366 r
.67288 .00962 m
.66968 .01718 L
.64205 .02376 L
.6414 .0238 L
.61312 .0297 L
.58484 .03426 L
.55656 .0375 L
.5521 .0379 L
.52828 .03943 L
.5 .04007 L
.47172 .03943 L
.4479 .0379 L
.44344 .0375 L
.41516 .03426 L
.38688 .0297 L
.3586 .0238 L
.35795 .02376 L
.33032 .01718 L
.32712 .00962 L
F
0 g
.67288 .00962 m
.66968 .01718 L
.64205 .02376 L
.6414 .0238 L
.61312 .0297 L
.58484 .03426 L
.55656 .0375 L
.5521 .0379 L
.52828 .03943 L
.5 .04007 L
.47172 .03943 L
.4479 .0379 L
.44344 .0375 L
.41516 .03426 L
.38688 .0297 L
.3586 .0238 L
.35795 .02376 L
.33032 .01718 L
.32712 .00962 L
s
1 .951 0 r
.74567 .49038 m
.75452 .47988 L
.75742 .47624 L
.76791 .4621 L
.77728 .44796 L
.78281 .43881 L
.78565 .43382 L
.7931 .41968 L
.7997 .40554 L
.8055 .3914 L
.81055 .37726 L
.81109 .37564 L
.81489 .36312 L
.81854 .34898 L
.82152 .33484 L
.82386 .3207 L
.82558 .30656 L
.82667 .29242 L
.82714 .27828 L
.82701 .26414 L
.82626 .25 L
.8249 .23586 L
.82291 .22172 L
.82028 .20758 L
.81701 .19344 L
.81307 .1793 L
.81109 .17291 L
.80842 .16516 L
.80303 .15102 L
.79686 .13688 L
.78989 .12274 L
.78281 .10978 L
.7821 .1086 L
.77319 .09446 L
.76325 .08032 L
.75452 .06869 L
.75235 .06618 L
.73925 .05204 L
.72624 .03796 L
.72616 .0379 L
.71404 .02376 L
.69796 .01515 L
.69185 .00962 L
.98077 .00962 L
.98077 .49038 L
F
0 g
.74567 .49038 m
.75452 .47988 L
.75742 .47624 L
.76791 .4621 L
.77728 .44796 L
.78281 .43881 L
.78565 .43382 L
.7931 .41968 L
.7997 .40554 L
.8055 .3914 L
.81055 .37726 L
.81109 .37564 L
.81489 .36312 L
.81854 .34898 L
.82152 .33484 L
.82386 .3207 L
.82558 .30656 L
.82667 .29242 L
.82714 .27828 L
.82701 .26414 L
.82626 .25 L
.8249 .23586 L
.82291 .22172 L
.82028 .20758 L
.81701 .19344 L
.81307 .1793 L
.81109 .17291 L
.80842 .16516 L
.80303 .15102 L
.79686 .13688 L
.78989 .12274 L
.78281 .10978 L
.7821 .1086 L
.77319 .09446 L
.76325 .08032 L
.75452 .06869 L
.75235 .06618 L
.73925 .05204 L
.72624 .03796 L
.72616 .0379 L
.71404 .02376 L
.69796 .01515 L
.69185 .00962 L
s
1 .366 0 r
.98077 .20633 m
.9699 .19344 L
.95723 .1793 L
.95249 .17423 L
.94373 .16516 L
.92937 .15102 L
.92421 .14614 L
.91402 .13688 L
.8976 .12274 L
.89593 .12135 L
.87989 .1086 L
.86765 .09936 L
.86081 .09446 L
.8401 .08032 L
.83937 .07983 L
.81728 .06618 L
.81109 .06248 L
.79197 .05204 L
.78281 .04711 L
.76325 .0379 L
.75452 .03356 L
.72998 .02376 L
.72624 .02188 L
.69796 .01209 L
.69477 .00962 L
.98077 .00962 L
F
0 g
.98077 .20633 m
.9699 .19344 L
.95723 .1793 L
.95249 .17423 L
.94373 .16516 L
.92937 .15102 L
.92421 .14614 L
.91402 .13688 L
.8976 .12274 L
.89593 .12135 L
.87989 .1086 L
.86765 .09936 L
.86081 .09446 L
.8401 .08032 L
.83937 .07983 L
.81728 .06618 L
.81109 .06248 L
.79197 .05204 L
.78281 .04711 L
.76325 .0379 L
.75452 .03356 L
.72998 .02376 L
.72624 .02188 L
.69796 .01209 L
.69477 .00962 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 144},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`00>03oool4000002d0oooo1@00000[0?ooo`800000;P3oool5000002d0oooo1000000Q0?oo
o`00>03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3o
ool00000;`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0280oooo000i0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0:P3oool010000000oooo0?ooo`00000_0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool08@3oool00380oooo100000040?ooo`03
0000003oool0oooo02H0oooo100000040?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3o
ool00000;`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0200oooo000h0?ooo`04
0000003oool0oooo000002l0oooo00<000000?ooo`3oool0:P3oool010000000oooo0?ooo`00000_
0?ooo`030000003oool0oooo02d0oooo00@000000?ooo`3oool000008@3oool003T0oooo0P00000_
0?ooo`800000;@3oool2000002l0oooo0P00000`0?ooo`8000008P3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00180
oooo0P0000050?ooool000000`0000050?ooo`004@3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`00
4@3oool010000000oooo0?ooo`0000040?ooo`800000C03oool7000005P0oooo1`00001<0?ooo`80
00001@3oool00140oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooodP0
oed02000001G0?l0G@80000000<0MP3o0000000000001@0000160?mM00D0oooo00<000000?ooo`3o
ool00`3oool00140oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oood@0
oed02@0000000`007ol0000000000002000005@0o`1M1P0000001@00ok@00000000000000000oo<0
00@00000@P3oG@050?ooo`030000003oool0oooo00<0oooo000B0?ooo`8000001@3oool00`000000
oooo0?ooo`020?oood40oed00`0000020?oc0080000000<0M_l00000000000000P0000000`007ol0
0000000000020?l0l`@00000C03o05d4000000050?l0l`000000MP3o000000007ol00`0000001000
oal000000000000000030?oc00800000@03oG@050?ooo`030000003oool0oooo00<0oooo000I0?oo
o`030000003oool0oooo0080oooo?`3oG@02000000<0oo<00P0000001@1fo`000000000000000000
0?nd0080000000@001oo0000001f0?l000001@3o0?<500000480o`1M1@0000050?l0l`040000001f
0?l00000000Oo`80000000D00?nd00000000oal0000007Ko0002000000<0oo<00P00000n0?mM00D0
oooo00<000000?ooo`3oool00`3oool001T0oooo0P0000030?oooc`0oed00`0000040?oc00080000
001fo`00M_l007Ko000000000?lO00000000ok@20000008001oo00@0000007H0o`0000000000203o
0?<5000003P0o`1M1@0000080?l0l`80000000@0MP3o000000007ol001oo0P000002003o]0800000
0`1fo`000`000000oo<00?oc00020?oc00<00000>`3oG@040?ooo`8000001@3oool001T0oooo00<0
00000?ooo`3oool00P3ooolj0?mM008000001P3ol`002@000000M_l007Ko001fo`000000003o7`00
00000?nd00000002002do`03000000007ol0000000<0MP3o0P00000;0?l0l`@00000<03o05d40000
00/0o`3c0P00000307H0o`03000000007ol0000000800;Co00D00000003o]00000000?lO00000003
07Ko00030000003ol`00oo<000@0oo<00P00000i0?mM00D0oooo00<000000?ooo`3oool00`3oool0
01T0oooo00<000000?ooo`3oool00P3ooolh0?mM008000001`3ol`02000000<0M_l000D00000003o
7`0000000?nd00000002002do`04000000007ol001oo000000@0MP3o0P00000=0?l0l`d000005P3o
05d=000000d0o`3c0P00000407H0o`04000000007ol001oo000000800;Co00D00000003o]0000000
0?lO0000000407Ko00030000003ol`00oo<000D0oo<00P00000g0?mM00D0oooo00<000000?ooo`3o
ool00`3oool001T0oooo00<000000?ooo`3oool00P3ooolf0?mM00800000203ol`000`000000M_l0
07Ko000207Ko000600000000oal00?lO00000000ok@000000P00]?l01@00000001oo000Oo`007ol0
000000D0MP3o0P00000H0?l0laH00000603o0?<2000000D0MP3o00@00000000Oo`007ol000000`00
]?l01@0000000?nd00000000oal0000000D0M_l000<000000?oc003ol`001P3ol`02000003D0oed0
1@3oool00`000000oooo0?ooo`030?ooo`006@3oool00`000000oooo0?ooo`020?oooc@0oed00P00
00090?oc00030000001fo`00M_l000<0M_l000H00000003o7`00oal00000003o]0000003002do`05
000000007ol001oo000Oo`0000001P1f0?l200000480o`3c0P00000607H0o`05000000007ol001oo
000Oo`0000000P00]?l0100000000?nd003o]0000002003o7`030000001fo`00M_l00080M_l000<0
00000?oc003ol`00203ol`02000003<0oed01@3oool00`000000oooo0?ooo`030?ooo`006@3oool2
000000<0oooo<P3oG@02000000/0oo<000<0000007Ko001fo`000P1fo`001@0000000?lO003o7`00
oal0000000800?nd00@00000002do`00]?l0000010007ol00`000000MP3o07H0o`0507H0o`800000
?P3o0?<2000000L0MP3o00D00000000Oo`007ol001oo00000003002do`0400000000ok@00?nd0000
00800?lO00<0000007Ko001fo`000`1fo`000`000000oo<00?oc00090?oc00800000<@3oG@040?oo
o`8000001@3oool001T0oooo00<000000?ooo`3oool00P3oool`0?mM00800000303ol`000`000000
M_l007Ko000307Ko000500000000oal00?lO003o7`0000000P00ok@01@0000000;Co002do`00]?l0
000000@001oo00<0000007H0o`1f0?l01P1f0?l3000003P0o`3c0`00000807H0o`03000000007ol0
01oo008001oo00D00000002do`00]?l00;Co00000002003o]00500000000oal00?lO003o7`000000
1@1fo`000`000000oo<00?oc000:0?oc00800000;`3oG@050?ooo`030000003oool0oooo00<0oooo
000I0?ooo`030000003oool0oooo0080oooo;P3oG@02000000d0oo<000<0000007Ko001fo`000`1f
o`000`0000000?lO003o7`02003o7`0400000000ok@00?nd000000@00;Co00<00000000Oo`007ol0
0P007ol2000000T0MP3o1000000`0?l0l`@000002@1f0?l2000000@001oo00<00000002do`00]?l0
0P00]?l0100000000?nd003o]0000003003o7`030000001fo`00M_l000@0M_l000<000000?oc003o
l`002`3ol`02000002d0oed01@3oool00`000000oooo0?ooo`030?ooo`006@3oool00`000000oooo
0?ooo`020?ooob`0oed00P00000>0?oc00030000001fo`00M_l000@0M_l000<00000003o7`00oal0
0P00oal0100000000?nd003o]0000004002do`03000000007ol001oo00@001oo00<0000007H0o`1f
0?l02P1f0?l4000002P0o`3c1000000<07H0o`03000000007ol001oo00@001oo00D00000002do`00
]?l00;Co00000003003o]00300000000oal00?lO00800?lO00<0000007Ko001fo`00101fo`000`00
0000oo<00?oc000<0?oc00800000:`3oG@050?ooo`030000003oool0oooo00<0oooo000I0?ooo`03
0000003oool0oooo0080oooo:`3oG@000`000000oo<00?oc000>0?oc00030000001fo`00M_l000<0
M_l000<00000003o7`00oal00`00oal01@0000000?nd003o]000ok@0000000@00;Co00<00000000O
o`007ol010007ol00`000000MP3o07H0o`0=07H0o`800000903o0?<2000000l0MP3o00<00000000O
o`007ol010007ol00`0000000;Co002do`02002do`0300000000ok@00?nd00800?nd00D00000003o
7`00oal00?lO0000000707Ko00030000003ol`00oo<000d0oo<000<000000?mM003oG@00:03oG@05
0?ooo`030000003oool0oooo00<0oooo000I0?ooo`8000000`3ooolZ0?mM00030000003ol`00oo<0
00d0oo<00P00000607Ko000300000000oal00?lO00<00?lO00D00000003o]000ok@00?nd00000004
002do`03000000007ol001oo00D001oo00<0000007H0o`1f0?l03P1f0?l7000001H0o`3c1`00000@
07H0o`03000000007ol001oo00D001oo00<00000002do`00]?l00P00]?l00`0000000?nd003o]002
003o]00300000000oal00?lO00800?lO00<0000007Ko001fo`001@1fo`000`000000oo<00?oc000=
0?oc00030000003oG@00oed002L0oed0103oool2000000D0oooo000I0?ooo`030000003oool0oooo
0080oooo:03oG@02000000l0oo<000<0000007Ko001fo`001@1fo`000`0000000?lO003o7`04003o
7`0500000000ok@00?nd003o]00000001@00]?l00`00000001oo000Oo`05000Oo`8000005@1f0?lF
000001D0MP3o0P000007000Oo`0300000000]?l00;Co00<00;Co00<00000003o]000ok@00P00ok@0
0`0000000?lO003o7`02003o7`030000001fo`00M_l000H0M_l000<000000?oc003ol`003@3ol`02
000002L0oed01@3oool00`000000oooo0?ooo`030?ooo`006@3oool00`000000oooo0?ooo`020?oo
obH0oed00P00000A0?oc00030000001fo`00M_l000D0M_l000<00000003o7`00oal01000oal00`00
00000?nd003o]002003o]00300000000]?l00;Co00<00;Co00<00000000Oo`007ol01P007ol20000
03`0MP3o0P000008000Oo`0300000000]?l00;Co00<00;Co00<00000003o]000ok@00`00ok@00`00
00000?lO003o7`03003o7`030000001fo`00M_l000D0M_l000<000000?oc003ol`003`3ol`020000
02D0oed01@3oool00`000000oooo0?ooo`030?ooo`006@3oool00`000000oooo0?ooo`020?ooob@0
oed00P00000B0?oc00030000001fo`00M_l000H0M_l000<00000003o7`00oal01000oal00`000000
0?nd003o]002003o]00300000000]?l00;Co00@00;Co00<00000000Oo`007ol01`007ol3000003H0
MP3o0`000009000Oo`0300000000]?l00;Co00@00;Co00<00000003o]000ok@00`00ok@00`000000
0?lO003o7`03003o7`030000001fo`00M_l000H0M_l000<000000?oc003ol`00403ol`02000002<0
oed01@3oool00`000000oooo0?ooo`030?ooo`006@3oool00`000000oooo0?ooo`020?ooob<0oed0
00<000000?oc003ol`004@3ol`000`000000M_l007Ko000707Ko000300000000oal00?lO00@00?lO
00<00000003o]000ok@00P00ok@00`0000000;Co002do`05002do`03000000007ol001oo00T001oo
0P00000b07H0o`8000002`007ol00`0000000;Co002do`04002do`0300000000ok@00?nd00@00?nd
00<00000003o7`00oal00`00oal00`000000M_l007Ko000707Ko00030000003ol`00oo<00140oo<0
00<000000?mM003oG@00803oG@050?ooo`030000003oool0oooo00<0oooo000I0?ooo`8000000`3o
oolQ0?mM008000004`3ol`000`000000M_l007Ko000707Ko000300000000oal00?lO00D00?lO00<0
0000003o]000ok@00`00ok@00`0000000;Co002do`05002do`03000000007ol001oo00X001oo0P00
000^07H0o`80000030007ol00`0000000;Co002do`05002do`0300000000ok@00?nd00<00?nd00<0
0000003o7`00oal01000oal00`000000M_l007Ko000707Ko00030000003ol`00oo<00180oo<00P00
000P0?mM00@0oooo0P0000050?ooo`006@3oool00`000000oooo0?ooo`020?ooob00oed000<00000
0?oc003ol`004`3ol`000`000000M_l007Ko000707Ko000300000000oal00?lO00D00?lO00<00000
003o]000ok@00`00ok@00`0000000;Co002do`06002do`03000000007ol001oo00/001oo0P00000Z
07H0o`8000003@007ol00`0000000;Co002do`05002do`0300000000ok@00?nd00@00?nd00<00000
003o7`00oal01@00oal00`000000M_l007Ko000707Ko00030000003ol`00oo<001<0oo<000<00000
0?mM003oG@007@3oG@050?ooo`030000003oool0oooo00<0oooo000I0?ooo`030000003oool0oooo
0080oooo7`3oG@000`000000oo<00?oc000C0?oc00030000001fo`00M_l000P0M_l000<00000003o
7`00oal01@00oal00`0000000?nd003o]004003o]00300000000]?l00;Co00H00;Co00<00000000O
o`007ol030007ol2000002H0MP3o0P00000>000Oo`0300000000]?l00;Co00H00;Co00<00000003o
]000ok@01000ok@00`0000000?lO003o7`05003o7`030000001fo`00M_l000P0M_l000<000000?oc
003ol`004`3ol`000`000000oed00?mM000L0?mM00D0oooo00<000000?ooo`3oool00`3oool000H0
oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool00P3ooolM0?mM0080
00005@3ol`000`000000M_l007Ko000907Ko000300000000oal00?lO00D00?lO00<00000003o]000
ok@01@00ok@00`0000000;Co002do`06002do`03000000007ol001oo00d001oo0`00000P07H0o`<0
00003`007ol00`0000000;Co002do`06002do`0300000000ok@00?nd00D00?nd00<00000003o7`00
oal01@00oal00`000000M_l007Ko000807Ko00030000003ol`00oo<001@0oo<00P00000L0?mM00D0
oooo00<000000?ooo`3oool00`3oool000D0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo703oG@000`000000oo<00?oc000E0?oc
00030000001fo`00M_l000P0M_l000<00000003o7`00oal01P00oal00`0000000?nd003o]005003o
]00300000000]?l00;Co00L00;Co00<00000000Oo`007ol03`007ol5000001H0MP3o1@00000A000O
o`0300000000]?l00;Co00L00;Co00<00000003o]000ok@01@00ok@00`0000000?lO003o7`05003o
7`030000001fo`00M_l000T0M_l000<000000?oc003ol`005@3ol`000`000000oed00?mM000I0?mM
00D0oooo00<000000?ooo`3oool00`3oool000D0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`020?ooo`8000000`3ooolK0?mM00030000003ol`00oo<001D0oo<000<0000007Ko
001fo`002@1fo`000`0000000?lO003o7`06003o7`0300000000ok@00?nd00H00?nd00<00000002d
o`00]?l01`00]?l00`00000001oo000Oo`0C000OoaH000005@007ol00`0000000;Co002do`07002d
o`0300000000ok@00?nd00H00?nd00<00000003o7`00oal01P00oal00`000000M_l007Ko000807Ko
00030000003ol`00oo<001H0oo<000<000000?mM003oG@00603oG@040?ooo`8000001@3oool000D0
oooo00@000000?ooo`3oool000002@3oool2000000D0oooo00<000000?ooo`3oool00P3ooolJ0?mM
00030000003ol`00oo<001H0oo<000<0000007Ko001fo`002@1fo`000`0000000?lO003o7`06003o
7`0300000000ok@00?nd00H00?nd00<00000002do`00]?l02000]?l00`00000001oo000Oo`0l000O
o`0300000000]?l00;Co00P00;Co00<00000003o]000ok@01P00ok@00`0000000?lO003o7`06003o
7`030000001fo`00M_l000T0M_l000<000000?oc003ol`005P3ol`000`000000oed00?mM000G0?mM
00D0oooo00<000000?ooo`3oool00`3oool000D0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo6@3oG@000`000000oo<00?oc000F0?oc
00030000001fo`00M_l000X0M_l000<00000003o7`00oal01`00oal00`0000000?nd003o]006003o
]00300000000]?l00;Co00P00;Co0P00000j000Oo`8000002P00]?l00`0000000?nd003o]007003o
]00300000000oal00?lO00H00?lO00<0000007Ko001fo`002P1fo`000`000000oo<00?oc000F0?oc
008000005`3oG@050?ooo`030000003oool0oooo00<0oooo00060?ooo`8000002P3oool3000000@0
oooo00<000000?ooo`3oool00P3ooolG0?mM008000006@3ol`000`000000M_l007Ko000:07Ko0003
00000000oal00?lO00L00?lO00<00000003o]000ok@01P00ok@00`0000000;Co002do`0:002do`80
0000=P007ol2000000`00;Co00<00000003o]000ok@01P00ok@00`0000000?lO003o7`07003o7`03
0000001fo`00M_l000X0M_l000<000000?oc003ol`00603ol`02000001D0oed01@3oool00`000000
oooo0?ooo`030?ooo`006@3oool00`000000oooo0?ooo`020?oooaD0oed00P00000J0?oc00030000
001fo`00M_l000/0M_l000<00000003o7`00oal01`00oal00`0000000?nd003o]007003o]0030000
0000]?l00;Co00/00;Co0P00000b000Oo`8000003@00]?l00`0000000?nd003o]007003o]0030000
0000oal00?lO00L00?lO00<0000007Ko001fo`002`1fo`000`000000oo<00?oc000I0?oc00030000
003oG@00oed00180oed01@3oool00`000000oooo0?ooo`030?ooo`006@3oool2000000<0oooo503o
G@000`000000oo<00?oc000I0?oc00030000001fo`00M_l000`0M_l000<00000003o7`00oal01`00
oal00`0000000?nd003o]008003o]00300000000]?l00;Co00`00;Co0P00000^000Oo`8000003P00
]?l00`0000000?nd003o]008003o]00300000000oal00?lO00L00?lO00<0000007Ko001fo`002`1f
o`000`000000oo<00?oc000J0?oc00030000003oG@00oed00140oed0103oool2000000D0oooo000I
0?ooo`030000003oool0oooo0080oooo4`3oG@000`000000oo<00?oc000J0?oc00030000001fo`00
M_l000/0M_l000<00000003o7`00oal02000oal00`0000000?nd003o]008003o]00300000000]?l0
0;Co00h00;Co0P00000Z000Oo`8000003`00]?l00`0000000?nd003o]008003o]00300000000oal0
0?lO00P00?lO00<0000007Ko001fo`00301fo`000`000000oo<00?oc000J0?oc00030000003oG@00
oed00100oed01@3oool00`000000oooo0?ooo`030?ooo`006@3oool00`000000oooo0?ooo`020?oo
oa80oed000<000000?oc003ol`006P3ol`000`000000M_l007Ko000<07Ko000300000000oal00?lO
00T00?lO00<00000003o]000ok@02000ok@00`0000000;Co002do`0?002do`8000009P007ol20000
01400;Co00<00000003o]000ok@02000ok@00`0000000?lO003o7`09003o7`030000001fo`00M_l0
00/0M_l000<000000?oc003ol`006`3ol`000`000000oed00?mM000?0?mM00D0oooo00<000000?oo
o`3oool00`3oool001T0oooo00<000000?ooo`3oool00P3ooolA0?mM00030000003ol`00oo<001/0
oo<000<0000007Ko001fo`00301fo`000`0000000?lO003o7`09003o7`0300000000ok@00?nd00T0
0?nd00<00000002do`00]?l04000]?l20000028001oo0P00000B002do`0300000000ok@00?nd00T0
0?nd00<00000003o7`00oal02@00oal00`000000M_l007Ko000<07Ko00030000003ol`00oo<001/0
oo<000<000000?mM003oG@003P3oG@050?ooo`030000003oool0oooo00<0oooo000I0?ooo`030000
003oool0oooo0080oooo3`3oG@02000001h0oo<000<0000007Ko001fo`00301fo`000`0000000?lO
003o7`09003o7`0300000000ok@00?nd00X00?nd00<00000002do`00]?l04@00]?l4000001X001oo
1000000C002do`0300000000ok@00?nd00T00?nd00<00000003o7`00oal02P00oal00`000000M_l0
07Ko000<07Ko00030000003ol`00oo<001`0oo<00P00000>0?mM00D0oooo00<000000?ooo`3oool0
0`3oool001T0oooo0P0000030?ooo`h0oed000<000000?oc003ol`007@3ol`000`000000M_l007Ko
000=07Ko000300000000oal00?lO00X00?lO00<00000003o]000ok@02P00ok@00`0000000;Co002d
o`0D002do`@000004P007ol4000001H00;Co00<00000003o]000ok@02P00ok@00`0000000?lO003o
7`0:003o7`030000001fo`00M_l000d0M_l000<000000?oc003ol`007@3ol`000`000000oed00?mM
000;0?mM00@0oooo0P0000050?ooo`006@3oool00`000000oooo0?ooo`020?ooo`d0oed000<00000
0?oc003ol`007P3ol`000`000000M_l007Ko000=07Ko000300000000oal00?lO00X00?lO00<00000
003o]000ok@02`00ok@00`0000000;Co002do`0G002doa8000006@00]?l00`0000000?nd003o]00:
003o]00300000000oal00?lO00/00?lO00<0000007Ko001fo`003@1fo`000`000000oo<00?oc000M
0?oc00030000003oG@00oed000/0oed01@3oool00`000000oooo0?ooo`030?ooo`006@3oool00`00
0000oooo0?ooo`020?ooo`d0oed000<000000?oc003ol`007P3ol`000`000000M_l007Ko000=07Ko
000300000000oal00?lO00/00?lO00<00000003o]000ok@02`00ok@00`0000000;Co002do`10002d
o`0300000000ok@00?nd00/00?nd00<00000003o7`00oal02`00oal00`000000M_l007Ko000>07Ko
00030000003ol`00oo<001d0oo<000<000000?mM003oG@002P3oG@050?ooo`030000003oool0oooo
00<0oooo000I0?ooo`030000003oool0oooo0080oooo303oG@000`000000oo<00?oc000N0?oc0003
0000001fo`00M_l000h0M_l000<00000003o7`00oal02`00oal00`0000000?nd003o]00<003o]003
00000000]?l00;Co03h00;Co00<00000003o]000ok@03000ok@00`0000000?lO003o7`0;003o7`03
0000001fo`00M_l000h0M_l000<000000?oc003ol`007P3ol`000`000000oed00?mM00090?mM00D0
oooo00<000000?ooo`3oool00`3oool001T0oooo00<000000?ooo`3oool00P3oool:0?mM00800000
8@3ol`000`000000M_l007Ko000>07Ko000300000000oal00?lO00`00?lO00<00000003o]000ok@0
3000ok@2000003`00;Co0P00000>003o]00300000000oal00?lO00`00?lO00<0000007Ko001fo`00
3`1fo`000`000000oo<00?oc000N0?oc008000002@3oG@050?ooo`030000003oool0oooo00<0oooo
000I0?ooo`8000000`3oool90?mM00030000003ol`00oo<00200oo<000<0000007Ko001fo`003`1f
o`000`0000000?lO003o7`0<003o7`0300000000ok@00?nd00h00?nd0P00000i002do`0300000000
ok@00?nd00h00?nd00<00000003o7`00oal03000oal00`000000M_l007Ko000?07Ko00030000003o
l`00oo<00200oo<000<000000?mM003oG@001P3oG@040?ooo`8000001@3oool001T0oooo00<00000
0?ooo`3oool00P3oool80?mM00030000003ol`00oo<00200oo<000<0000007Ko001fo`00401fo`00
0`0000000?lO003o7`0<003o7`0300000000ok@00?nd00l00?nd0P00000f002do`8000004000ok@0
0`0000000?lO003o7`0=003o7`030000001fo`00M_l000l0M_l000<000000?oc003ol`008@3ol`00
0`000000oed00?mM00050?mM00D0oooo00<000000?ooo`3oool00`3oool001T0oooo00<000000?oo
o`3oool00P3oool80?mM00030000003ol`00oo<00200oo<000<0000007Ko001fo`00401fo`000`00
00000?lO003o7`0=003o7`0300000000ok@00?nd01000?nd00<00000002do`00]?l0<P00]?l00`00
00000?nd003o]00@003o]00300000000oal00?lO00`00?lO00<0000007Ko001fo`004@1fo`000`00
0000oo<00?oc000P0?oc00030000003oG@00oed000D0oed01@3oool00`000000oooo0?ooo`030?oo
o`006@3oool00`000000oooo0?ooo`020?ooo`L0oed000<000000?oc003ol`008@3ol`000`000000
M_l007Ko000A07Ko000300000000oal00?lO00`00?lO00<00000003o]000ok@04@00ok@200000300
0;Co0P00000B003o]00300000000oal00?lO00d00?lO00<0000007Ko001fo`004@1fo`000`000000
oo<00?oc000Q0?oc00030000003oG@00oed000@0oed01@3oool00`000000oooo0?ooo`030?ooo`00
6@3oool00`000000oooo0?ooo`020?ooo`H0oed000<000000?oc003ol`008P3ol`000`000000M_l0
07Ko000A07Ko000300000000oal00?lO00d00?lO00<00000003o]000ok@04P00ok@00`0000000;Co
002do`0/002do`0300000000ok@00?nd01800?nd00<00000003o7`00oal03@00oal00`000000M_l0
07Ko000A07Ko00030000003ol`00oo<00280oo<000<000000?mM003oG@000`3oG@050?ooo`030000
003oool0oooo00<0oooo000I0?ooo`8000000`3oool50?mM00030000003ol`00oo<002<0oo<000<0
000007Ko001fo`004@1fo`000`0000000?lO003o7`0>003o7`0300000000ok@00?nd01800?nd0`00
000X002do`<000005000ok@00`0000000?lO003o7`0>003o7`030000001fo`00M_l00140M_l000<0
00000?oc003ol`008`3ol`000`000000oed00?mM00020?mM00@0oooo0P0000050?ooo`006@3oool0
0`000000oooo0?ooo`020?ooo`@0oed000<000000?oc003ol`008`3ol`000`000000M_l007Ko000B
07Ko000300000000oal00?lO00l00?lO00<00000003o]000ok@05000ok@2000002@00;Co0P00000F
003o]00300000000oal00?lO00l00?lO00<0000007Ko001fo`004@1fo`000`000000oo<00?oc000T
0?oc00040000003oG@00oed00?mM00D0oooo00<000000?ooo`3oool00`3oool001T0oooo00<00000
0?ooo`3oool00P3oool40?mM00030000003ol`00oo<002<0oo<000<0000007Ko001fo`004P1fo`00
0`0000000?lO003o7`0?003o7`0300000000ok@00?nd01H00?nd0P00000N002do`0400000000]?l0
0000000001P00?nd00<00000003o7`00oal03`00oal00`000000M_l007Ko000B07Ko00030000003o
l`00oo<002@0oo<000<000000?mM003oG@001@3oool00`000000oooo0?ooo`030?ooo`004@3oool5
000000<0oooo00<000000?ooo`3oool00P3oool30?mM00030000003ol`00oo<002@0oo<000<00000
07Ko001fo`004P1fo`000`0000000?lO003o7`0@003o7`0300000000ok@00?nd01L00?nd1@00000F
002do`D000006@00ok@00`0000000?lO003o7`0@003o7`030000001fo`00M_l00180M_l000<00000
0?oc003ol`009@3ol`000`000000oed00?ooo`040?ooo`030000003oool0oooo00<0oooo000C0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool20?mM00030000003ol`00oo<0
02D0oo<000<0000007Ko001fo`004P1fo`000`0000000?lO003o7`0A003o7`0300000000ok@00?nd
01/00?nd1`000008002do`L000007@00ok@00`0000000?lO003o7`0A003o7`030000001fo`00M_l0
0180M_l000<000000?oc003ol`009P3ol`000`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo000C0?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`030?mM00000000oo<002H0
oo<000<0000007Ko001fo`00501fo`000`0000000?lO003o7`0A003o7`0300000000ok@00?nd0240
0?nd2000000S003o]00300000000oal00?lO01400?lO00<0000007Ko001fo`00501fo`000`000000
oo<00?oc000U0?oc00030000003oool0oooo0080oooo0P0000050?ooo`004`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oc003ol`009P3ol`000`000000M_l0
07Ko000D07Ko000300000000oal00?lO01800?lO00<00000003o]000ok@0BP00ok@00`0000000?lO
003o7`0B003o7`030000001fo`00M_l001@0M_l000<000000?oc003ol`009P3ol`000`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo000C0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3ooolY0?oc00030000001fo`00M_l001@0M_l000<00000003o7`00oal04`00
oal00`0000000?nd003o]018003o]00300000000oal00?lO01<00?lO00<0000007Ko001fo`00501f
o`000`000000oo<00?oc000V0?oc00D0oooo00<000000?ooo`3oool00`3oool00180oooo0P000005
0?ooo`030000003oool0oooo0080oooo:03ol`000`000000M_l007Ko000E07Ko000300000000oal0
0?lO01<00?lO00<00000003o]000ok@0B000ok@00`0000000?lO003o7`0B003o7`030000001fo`00
M_l001D0M_l000<000000?oc003ol`009P3ol`050?ooo`030000003oool0oooo00<0oooo000I0?oo
o`030000003oool0oooo0080oooo:03ol`000`000000M_l007Ko000F07Ko000300000000oal00?lO
01<00?lO00<00000003o]000ok@0AP00ok@00`0000000?lO003o7`0C003o7`030000001fo`00M_l0
01H0M_l000<000000?oc003ol`009@3ol`050?ooo`030000003oool0oooo00<0oooo000I0?ooo`80
00000`3ooolX0?oc00030000001fo`00M_l001H0M_l000<00000003o7`00oal05000oal2000004D0
0?nd00<00000003o7`00oal05000oal00`000000M_l007Ko000F07Ko00030000003ol`00oo<002D0
oo<0103oool2000000D0oooo000I0?ooo`030000003oool0oooo0080oooo:03ol`000`000000M_l0
07Ko000G07Ko000300000000oal00?lO01D00?lO00<00000003o]000ok@0@000ok@2000001L00?lO
00<0000007Ko001fo`005P1fo`000`000000oo<00?oc000U0?oc00D0oooo00<000000?ooo`3oool0
0`3oool001T0oooo00<000000?ooo`3oool00P3ooolX0?oc00030000001fo`00M_l001L0M_l000<0
0000003o7`00oal05P00oal2000003h00?nd0P00000H003o7`030000001fo`00M_l001L0M_l000<0
00000?oc003ol`009@3ol`050?ooo`030000003oool0oooo00<0oooo000I0?ooo`030000003oool0
oooo0080oooo:03ol`000`000000M_l007Ko000H07Ko000300000000oal00?lO01L00?lO00<00000
003o]000ok@0>P00ok@00`0000000?lO003o7`0H003o7`030000001fo`00M_l001L0M_l000<00000
0?oc003ol`009@3ol`050?ooo`030000003oool0oooo00<0oooo000I0?ooo`030000003oool0oooo
0080oooo:03ol`000`000000M_l007Ko000H07Ko000300000000oal00?lO01P00?lO00<00000003o
]000ok@0>000ok@00`0000000?lO003o7`0H003o7`030000001fo`00M_l001P0M_l000<000000?oc
003ol`009@3ol`050?ooo`030000003oool0oooo00<0oooo000I0?ooo`8000000`3ooolX0?oc0003
0000001fo`00M_l001P0M_l000<00000003o7`00oal06@00oal2000003H00?nd0P00000K003o7`03
0000001fo`00M_l001P0M_l000<000000?oc003ol`009@3ol`040?ooo`8000001@3oool001T0oooo
00<000000?ooo`3oool00P3ooolX0?oc00030000001fo`00M_l001T0M_l000<00000003o7`00oal0
6P00oal2000003800?nd0P00000L003o7`030000001fo`00M_l001X0M_l000<000000?oc003ol`00
903ol`050?ooo`030000003oool0oooo00<0oooo000I0?ooo`030000003oool0oooo0080oooo:03o
l`000`000000M_l007Ko000I07Ko000300000000oal00?lO01`00?lO00<00000003o]000ok@0;P00
ok@00`0000000?lO003o7`0L003o7`030000001fo`00M_l001X0M_l000<000000?oc003ol`00903o
l`050?ooo`030000003oool0oooo00<0oooo000I0?ooo`030000003oool0oooo0080oooo:03ol`00
0`000000M_l007Ko000I07Ko000300000000oal00?lO01d00?lO0P00000/003o]08000007P00oal0
0`000000M_l007Ko000K07Ko00030000003ol`00oo<002@0oo<01@3oool00`000000oooo0?ooo`03
0?ooo`006@3oool00`000000oooo0?ooo`020?ooobL0oo<000<0000007Ko001fo`006`1fo`000`00
00000?lO003o7`0N003o7`800000:000ok@2000002000?lO00<0000007Ko001fo`006`1fo`000`00
0000oo<00?oc000T0?oc00D0oooo00<000000?ooo`3oool00`3oool001T0oooo0P0000030?ooobL0
oo<000<0000007Ko001fo`006`1fo`000`0000000?lO003o7`0P003o7`8000009000ok@200000240
0?lO00<0000007Ko001fo`00701fo`000`000000oo<00?oc000T0?oc00@0oooo0P0000050?ooo`00
6@3oool00`000000oooo0?ooo`020?ooobL0oo<000<0000007Ko001fo`00701fo`000`0000000?lO
003o7`0Q003o7`D000006P00ok@5000002<00?lO00<0000007Ko001fo`00701fo`000`000000oo<0
0?oc000T0?oc00D0oooo00<000000?ooo`3oool00`3oool001T0oooo00<000000?ooo`3oool00P3o
oolW0?oc00030000001fo`00M_l001d0M_l000<00000003o7`00oal09@00oal4000001800?nd1000
000W003o7`030000001fo`00M_l001d0M_l000<000000?oc003ol`00903ol`050?ooo`030000003o
ool0oooo00<0oooo000I0?ooo`030000003oool0oooo0080oooo9`3ol`000`000000M_l007Ko000M
07Ko000300000000oal00?lO02T00?lO4P00000[003o7`030000001fo`00M_l001d0M_l000<00000
0?oc003ol`00903ol`050?ooo`030000003oool0oooo00<0oooo000I0?ooo`030000003oool0oooo
0080oooo9`3ol`000`000000M_l007Ko000N07Ko000300000000oal00?lO06@00?lO00<0000007Ko
001fo`007P1fo`000`000000oo<00?oc000T0?oc00D0oooo00<000000?ooo`3oool00`3oool001T0
oooo0P0000030?ooobL0oo<000<0000007Ko001fo`007`1fo`000`0000000?lO003o7`1S003o7`03
0000001fo`00M_l001h0M_l000<000000?oc003ol`00903ol`040?ooo`8000001@3oool001T0oooo
00<000000?ooo`3oool00P3ooolW0?oc00030000001fo`00M_l00200M_l000<00000003o7`00oal0
H@00oal00`000000M_l007Ko000O07Ko00030000003ol`00oo<002@0oo<01@3oool00`000000oooo
0?ooo`030?ooo`001@3oool500000080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?oo
o`020?ooobL0oo<000<0000007Ko001fo`00801fo`000`0000000?lO003o7`1P003o7`030000001f
o`00M_l00200M_l000<000000?oc003ol`00903ol`050?ooo`030000003oool0oooo00<0oooo0007
0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`020?ooobL0oo<000<0000007Ko001fo`008@1fo`000`0000000?lO003o7`1N003o7`030000001f
o`00M_l00240M_l000<000000?oc003ol`00903ol`050?ooo`030000003oool0oooo00<0oooo0007
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo9`3ol`00
0`000000M_l007Ko000R07Ko000300000000oal00?lO05`00?lO00<0000007Ko001fo`008P1fo`00
0`000000oo<00?oc000T0?oc00@0oooo0P0000050?ooo`001`3oool00`000000oooo0?ooo`080?oo
o`8000001@3oool00`000000oooo0?ooo`020?ooobL0oo<000<0000007Ko001fo`008P1fo`000`00
00000?lO003o7`1K003o7`030000001fo`00M_l00280M_l000<000000?oc003ol`009@3ol`050?oo
o`030000003oool0oooo00<0oooo00070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooobP0oo<000<0000007Ko001fo`008P1fo`000`000000
0?lO003o7`1J003o7`030000001fo`00M_l00280M_l000<000000?oc003ol`009@3ol`050?ooo`03
0000003oool0oooo00<0oooo00060?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool0
0P3ooolX0?oc00030000001fo`00M_l002<0M_l000<00000003o7`00oal0F000oal00`000000M_l0
07Ko000S07Ko00030000003ol`00oo<002D0oo<01@3oool00`000000oooo0?ooo`030?ooo`006@3o
ool00`000000oooo0?ooo`020?ooobP0oo<000<0000007Ko001fo`00901fo`000`0000000?lO003o
7`1F003o7`030000001fo`00M_l002@0M_l000<000000?oc003ol`009@3ol`050?ooo`030000003o
ool0oooo00<0oooo000I0?ooo`8000000`3ooolX0?oc00030000001fo`00M_l002D0M_l000<00000
003o7`00oal0E000oal00`000000M_l007Ko000U07Ko00030000003ol`00oo<002D0oo<0103oool2
000000D0oooo000I0?ooo`030000003oool0oooo0080oooo:03ol`000`000000M_l007Ko000V07Ko
000300000000oal00?lO05800?lO00<0000007Ko001fo`009P1fo`000`000000oo<00?oc000U0?oc
00D0oooo00<000000?ooo`3oool00`3oool001T0oooo00<000000?ooo`3oool00P3ooolX0?oc0003
0000001fo`00M_l002L0M_l000<00000003o7`00oal0D000oal00`000000M_l007Ko000W07Ko0003
0000003ol`00oo<002D0oo<01@3oool00`000000oooo0?ooo`030?ooo`006@3oool00`000000oooo
0?ooo`020?ooobP0oo<000<0000007Ko001fo`00:01fo`000`0000000?lO003o7`1>003o7`030000
001fo`00M_l002L0M_l000<000000?oc003ol`009P3ol`050?ooo`030000003oool0oooo00<0oooo
000I0?ooo`030000003oool0oooo0080oooo:@3ol`000`000000M_l007Ko000X07Ko000300000000
oal00?lO04`00?lO00<0000007Ko001fo`00:01fo`000`000000oo<00?oc000V0?oc00D0oooo00<0
00000?ooo`3oool00`3oool001T0oooo0P0000030?ooobT0oo<000<0000007Ko001fo`00:@1fo`00
0`0000000?lO003o7`1:003o7`030000001fo`00M_l002T0M_l000<000000?oc003ol`009P3ol`04
0?ooo`8000001@3oool001T0oooo00<000000?ooo`3oool00P3ooolY0?oc00030000001fo`00M_l0
02X0M_l00P000018003o7`800000;01fo`000`000000oo<00?oc000V0?oc00D0oooo00<000000?oo
o`3oool00`3oool001T0oooo00<000000?ooo`3oool00P3ooolY0?oc00030000001fo`00M_l002`0
M_l000<00000003o7`00oal0A000oal00`000000M_l007Ko000/07Ko00030000003ol`00oo<002H0
oo<01@3oool00`000000oooo0?ooo`030?ooo`006@3oool00`000000oooo0?ooo`020?ooobX0oo<0
00<0000007Ko001fo`00;01fo`000`0000000?lO003o7`12003o7`030000001fo`00M_l002d0M_l0
00<000000?oc003ol`009P3ol`050?ooo`030000003oool0oooo00<0oooo000I0?ooo`030000003o
ool0oooo0080oooo:P3ol`000`000000M_l007Ko000]07Ko000300000000oal00?lO04000?lO00<0
000007Ko001fo`00;P1fo`000`000000oo<00?oc000V0?oc00D0oooo00<000000?ooo`3oool00`3o
ool001T0oooo0P0000030?ooobX0oo<000<0000007Ko001fo`00;P1fo`02000003h00?lO0P00000a
07Ko00030000003ol`00oo<002H0oo<0103oool2000000D0oooo000I0?ooo`030000003oool0oooo
0080oooo:P3ol`000`000000M_l007Ko000`07Ko00<00000>000oal300000380M_l000<000000?oc
003ol`009`3ol`050?ooo`030000003oool0oooo00<0oooo000I0?ooo`030000003oool0oooo0080
oooo:P3ol`000`000000M_l007Ko000c07Ko00<00000<P00oal3000003D0M_l000<000000?oc003o
l`009`3ol`050?ooo`030000003oool0oooo00<0oooo000I0?ooo`030000003oool0oooo0080oooo
:P3ol`000`000000M_l007Ko000f07Ko00800000;P00oal2000003P0M_l000<000000?oc003ol`00
9`3ol`050?ooo`030000003oool0oooo00<0oooo000I0?ooo`030000003oool0oooo0080oooo:`3o
l`000`000000M_l007Ko000g07Ko00800000:P00oal2000003T0M_l000<000000?oc003ol`00:03o
l`050?ooo`030000003oool0oooo00<0oooo000I0?ooo`8000000`3oool[0?oc00030000001fo`00
M_l003T0M_l00P00000V003o7`800000>`1fo`000`000000oo<00?oc000X0?oc00@0oooo0P000005
0?ooo`006@3oool00`000000oooo0?ooo`020?ooob`0oo<000<0000007Ko001fo`00>P1fo`030000
02000?lO0`00000m07Ko00030000003ol`00oo<002P0oo<01@3oool00`000000oooo0?ooo`030?oo
o`006@3oool00`000000oooo0?ooo`020?ooob`0oo<000<0000007Ko001fo`00?@1fo`05000001H0
0?lO1@00000o07Ko00030000003ol`00oo<002T0oo<01@3oool00`000000oooo0?ooo`030?ooo`00
4@3oool4000000@0oooo00<000000?ooo`3oool00P3oool/0?oc00030000001fo`00M_l00480M_l0
5P00001407Ko00030000003ol`00oo<002T0oo<01@3oool00`000000oooo0?ooo`030?ooo`004@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo;@3ol`000`000000M_l007Ko
002J07Ko00030000003ol`00oo<002X0oo<01@3oool00`000000oooo0?ooo`030?ooo`004P3oool0
0`000000oooo0?ooo`040?ooo`8000000`3oool]0?oc00030000001fo`00M_l009X0M_l000<00000
0?oc003ol`00:P3ol`040?ooo`8000001@3oool001<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooobd0oo<000<0000007Ko001fo`00VP1fo`000`000000oo<00?oc000Z0?oc
00D0oooo00<000000?ooo`3oool00`3oool00140oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`020?ooobh0oo<000<0000007Ko001fo`00V01fo`000`000000oo<00?oc000[0?oc
00D0oooo00<000000?ooo`3oool00`3oool00180oooo0P0000050?ooo`030000003oool0oooo0080
oooo;P3ol`000`000000M_l007Ko002H07Ko00030000003ol`00oo<002/0oo<01@3oool00`000000
oooo0?ooo`030?ooo`006@3oool00`000000oooo0?ooo`020?ooobh0oo<000<0000007Ko001fo`00
U`1fo`000`000000oo<00?oc000/0?oc00D0oooo00<000000?ooo`3oool00`3oool001T0oooo0P00
00030?ooobl0oo<000<0000007Ko001fo`00UP1fo`000`000000oo<00?oc000/0?oc00@0oooo0P00
00050?ooo`006@3oool00`000000oooo0?ooo`020?ooobl0oo<000<0000007Ko001fo`00U@1fo`00
0`000000oo<00?oc000]0?oc00D0oooo00<000000?ooo`3oool00`3oool001T0oooo00<000000?oo
o`3oool00P3oool`0?oc00030000001fo`00M_l009@0M_l000<000000?oc003ol`00;@3ol`050?oo
o`030000003oool0oooo00<0oooo000I0?ooo`030000003oool0oooo0080oooo<@3ol`000`000000
M_l007Ko002B07Ko00030000003ol`00oo<002h0oo<01@3oool00`000000oooo0?ooo`030?ooo`00
6@3oool00`000000oooo0?ooo`020?oooc40oo<000<0000007Ko001fo`00TP1fo`000`000000oo<0
0?oc000^0?oc00D0oooo00<000000?ooo`3oool00`3oool001T0oooo0P0000030?oooc80oo<000<0
000007Ko001fo`00T01fo`000`000000oo<00?oc000_0?oc00@0oooo0P0000050?ooo`006@3oool0
0`000000oooo0?ooo`020?oooc80oo<000<0000007Ko001fo`00S`1fo`000`000000oo<00?oc000`
0?oc00D0oooo00<000000?ooo`3oool00`3oool001T0oooo00<000000?ooo`3oool00P3ooolc0?oc
00030000001fo`00M_l008h0M_l000<000000?oc003ol`00<03ol`050?ooo`030000003oool0oooo
00<0oooo000I0?ooo`030000003oool0oooo0080oooo<`3ol`000`000000M_l007Ko002=07Ko0003
0000003ol`00oo<00340oo<01@3oool00`000000oooo0?ooo`030?ooo`006@3oool00`000000oooo
0?ooo`020?oooc@0oo<000<0000007Ko001fo`00S01fo`000`000000oo<00?oc000a0?oc00D0oooo
00<000000?ooo`3oool00`3oool001T0oooo0P0000030?ooocD0oo<000<0000007Ko001fo`00RP1f
o`000`000000oo<00?oc000b0?oc00@0oooo0P0000050?ooo`006@3oool00`000000oooo0?ooo`02
0?ooocD0oo<000<0000007Ko001fo`00RP1fo`000`000000oo<00?oc000b0?oc00D0oooo00<00000
0?ooo`3oool00`3oool001T0oooo00<000000?ooo`3oool00P3ooolf0?oc00030000001fo`00M_l0
08P0M_l000<000000?oc003ol`00<`3ol`050?ooo`030000003oool0oooo00<0oooo000I0?ooo`03
0000003oool0oooo0080oooo=`3ol`000`000000M_l007Ko002707Ko00030000003ol`00oo<003<0
oo<01@3oool00`000000oooo0?ooo`030?ooo`006@3oool00`000000oooo0?ooo`020?ooocP0oo<0
00<0000007Ko001fo`00Q@1fo`000`000000oo<00?oc000d0?oc00D0oooo00<000000?ooo`3oool0
0`3oool001T0oooo0P0000030?ooocP0oo<000<0000007Ko001fo`00Q01fo`000`000000oo<00?oc
000e0?oc00@0oooo0P0000050?ooo`006@3oool00`000000oooo0?ooo`020?ooocT0oo<000<00000
07Ko001fo`00PP1fo`000`000000oo<00?oc000f0?oc00D0oooo00<000000?ooo`3oool00`3oool0
01T0oooo00<000000?ooo`3oool00P3ooolj0?oc00030000001fo`00M_l00800M_l000<000000?oc
003ol`00=`3ol`050?ooo`030000003oool0oooo00<0oooo00050?ooo`@000000`3oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo0080oooo>`3ol`000`000000M_l007Ko001n07Ko0003
0000003ol`00oo<003P0oo<01@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo
0?ooo`090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3ooolk0?oc0003
0000001fo`00M_l007h0M_l000<000000?oc003ol`00>03ol`050?ooo`030000003oool0oooo00<0
oooo00060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool2000000<0oooo
?03ol`000`000000M_l007Ko001l07Ko00030000003ol`00oo<003T0oo<0103oool2000000D0oooo
00070?ooo`030000003oool0oooo00P0oooo0P0000050?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo0005
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103ooooo000000<000001@3o
ool000H0oooo0P00000:0?ooo`<00000o`3oool<0?ooo`00o`3ooolQ0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 287}, {143, 0}} -> {-3, 0, 0, 0}}],
  StyleBox["     ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .57775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.06865e-017 1.00535 -0.195673 1.00535 [
[.05728 .13356 -5.87166 -9 ]
[.05728 .13356 6.12834 0 ]
[.1604 .10256 -5.90122 -9 ]
[.1604 .10256 6.09878 0 ]
[.26623 .07075 -2.96583 -9 ]
[.26623 .07075 3.03417 0 ]
[.37489 .03809 -2.9815 -9 ]
[.37489 .03809 3.0185 0 ]
[.48649 .00455 -2.99765 -9 ]
[.48649 .00455 3.00235 0 ]
[.26695 .00792 -4.94305 -12.5625 ]
[.26695 .00792 5.05695 0 ]
[.73174 .06537 -3.03311 -9 ]
[.73174 .06537 2.96689 0 ]
[.90881 .13864 -3.0585 -9 ]
[.90881 .13864 2.9415 0 ]
[.77619 .02128 -5.06604 -12.5625 ]
[.77619 .02128 4.93396 0 ]
[-0.01183 .42036 -6 -5.92278 ]
[-0.01183 .42036 0 3.07722 ]
[ 0 0 0 0 ]
[ 1 .57775 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00641 .16132 m
.54345 0 L
s
.05701 .14612 m
.05688 .1524 L
s
[(-2)] .05728 .13356 -0.02139 1 Mshowa
.16019 .11513 m
.16009 .12141 L
s
[(-1)] .1604 .10256 -0.01646 1 Mshowa
.26609 .08332 m
.26602 .0896 L
s
[(0)] .26623 .07075 -0.01139 1 Mshowa
.37481 .05066 m
.37477 .05694 L
s
[(1)] .37489 .03809 -0.00617 1 Mshowa
.48648 .01711 m
.48647 .0234 L
s
[(2)] .48649 .00455 -0.00078 1 Mshowa
gsave
.26695 .00792 -65.943 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.54345 0 m
.99372 .18623 L
s
.73188 .07793 m
.73195 .08422 L
s
[(1)] .73174 .06537 .01104 1 Mshowa
.90905 .15121 m
.90917 .15749 L
s
[(2)] .90881 .13864 .0195 1 Mshowa
gsave
.77619 .02128 -66.066 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00641 .16132 m
0 .43064 L
s
.00015 .42415 m
.00615 .42604 L
s
[(1)] -0.01183 .42036 1 .31617 Mshowa
0 0 m
1 0 L
1 .57775 L
0 .57775 L
closepath
clip
newpath
.5 Mabswid
1 .909 0 r
.43831 .35237 .46708 .36234 .4795 .36066 .45074 .35079 Metetra
1 .948 0 r
.45074 .35079 .4795 .36066 .49197 .35902 .46322 .34928 Metetra
1 .989 0 r
.46322 .34928 .49197 .35902 .50446 .35744 .47573 .34783 Metetra
.969 1 0 r
.47573 .34783 .50446 .35744 .517 .3559 .48828 .34645 Metetra
.925 1 0 r
.48828 .34645 .517 .3559 .52958 .35439 .50087 .34511 Metetra
.881 1 0 r
.50087 .34511 .52958 .35439 .5422 .35289 .51351 .34381 Metetra
.836 1 0 r
.51351 .34381 .5422 .35289 .55486 .35141 .52618 .34253 Metetra
.791 1 0 r
.52618 .34253 .55486 .35141 .56756 .34991 .53889 .34125 Metetra
.746 1 0 r
.53889 .34125 .56756 .34991 .5803 .34838 .55165 .33996 Metetra
.702 1 0 r
.55165 .33996 .5803 .34838 .59308 .3468 .56445 .33861 Metetra
.66 1 0 r
.56445 .33861 .59308 .3468 .6059 .34515 .57728 .3372 Metetra
.619 1 0 r
.57728 .3372 .6059 .34515 .61876 .3434 .59016 .33568 Metetra
.581 1 0 r
.59016 .33568 .61876 .3434 .63166 .34153 .60308 .33403 Metetra
.545 1 0 r
.60308 .33403 .63166 .34153 .6446 .33952 .61604 .33222 Metetra
.514 1 0 r
.61604 .33222 .6446 .33952 .65758 .33734 .62904 .33022 Metetra
.487 1 0 r
.62904 .33022 .65758 .33734 .6706 .33497 .64208 .328 Metetra
.465 1 0 r
.64208 .328 .6706 .33497 .68366 .3324 .65516 .32554 Metetra
.447 1 0 r
.65516 .32554 .68366 .3324 .69676 .32961 .66828 .32283 Metetra
.436 1 0 r
.66828 .32283 .69676 .32961 .70989 .32659 .68144 .31984 Metetra
.43 1 0 r
.68144 .31984 .70989 .32659 .72307 .32332 .69463 .31657 Metetra
.43 1 0 r
.69463 .31657 .72307 .32332 .73628 .31982 .70787 .31301 Metetra
.436 1 0 r
.70787 .31301 .73628 .31982 .74953 .31607 .72114 .30918 Metetra
.447 1 0 r
.72114 .30918 .74953 .31607 .76282 .31209 .73445 .30506 Metetra
.465 1 0 r
.73445 .30506 .76282 .31209 .77615 .30788 .7478 .30068 Metetra
.487 1 0 r
.7478 .30068 .77615 .30788 .78951 .30345 .76119 .29605 Metetra
.514 1 0 r
.76119 .29605 .78951 .30345 .80291 .29884 .77461 .29119 Metetra
.545 1 0 r
.77461 .29119 .80291 .29884 .81635 .29404 .78807 .28614 Metetra
.581 1 0 r
.78807 .28614 .81635 .29404 .82983 .28909 .80157 .2809 Metetra
.619 1 0 r
.80157 .2809 .82983 .28909 .84334 .28401 .81511 .27553 Metetra
.66 1 0 r
.81511 .27553 .84334 .28401 .8569 .27882 .82868 .27003 Metetra
.702 1 0 r
.82868 .27003 .8569 .27882 .87049 .27354 .84229 .26446 Metetra
.746 1 0 r
.84229 .26446 .87049 .27354 .88412 .2682 .85595 .25882 Metetra
.791 1 0 r
.85595 .25882 .88412 .2682 .89779 .26282 .86964 .25314 Metetra
.836 1 0 r
.86964 .25314 .89779 .26282 .9115 .25742 .88337 .24746 Metetra
.881 1 0 r
.88337 .24746 .9115 .25742 .92525 .25201 .89715 .24179 Metetra
.925 1 0 r
.89715 .24179 .92525 .25201 .93905 .24661 .91096 .23614 Metetra
.969 1 0 r
.91096 .23614 .93905 .24661 .95288 .24123 .92482 .23053 Metetra
1 .989 0 r
.92482 .23053 .95288 .24123 .96676 .23589 .93872 .22498 Metetra
1 .948 0 r
.93872 .22498 .96676 .23589 .98068 .23058 .95267 .21948 Metetra
1 .909 0 r
.95267 .21948 .98068 .23058 .99464 .22532 .96665 .21404 Metetra
1 .912 0 r
.40927 .34217 .43831 .35237 .45074 .35079 .42171 .3407 Metetra
1 .954 0 r
.42171 .3407 .45074 .35079 .46322 .34928 .4342 .33931 Metetra
1 .999 0 r
.4342 .33931 .46322 .34928 .47573 .34783 .44672 .33802 Metetra
.955 1 0 r
.44672 .33802 .47573 .34783 .48828 .34645 .45929 .33681 Metetra
.907 1 0 r
.45929 .33681 .48828 .34645 .50087 .34511 .47189 .33567 Metetra
.858 1 0 r
.47189 .33567 .50087 .34511 .51351 .34381 .48454 .33459 Metetra
.807 1 0 r
.48454 .33459 .51351 .34381 .52618 .34253 .49723 .33356 Metetra
.756 1 0 r
.49723 .33356 .52618 .34253 .53889 .34125 .50996 .33254 Metetra
.705 1 0 r
.50996 .33254 .53889 .34125 .55165 .33996 .52272 .33152 Metetra
.655 1 0 r
.52272 .33152 .55165 .33996 .56445 .33861 .53554 .33047 Metetra
.605 1 0 r
.53554 .33047 .56445 .33861 .57728 .3372 .54839 .32934 Metetra
.558 1 0 r
.54839 .32934 .57728 .3372 .59016 .33568 .56128 .32811 Metetra
.513 1 0 r
.56128 .32811 .59016 .33568 .60308 .33403 .57422 .32673 Metetra
.472 1 0 r
.57422 .32673 .60308 .33403 .61604 .33222 .5872 .32517 Metetra
.435 1 0 r
.5872 .32517 .61604 .33222 .62904 .33022 .60022 .3234 Metetra
.403 1 0 r
.60022 .3234 .62904 .33022 .64208 .328 .61328 .32137 Metetra
.377 1 0 r
.61328 .32137 .64208 .328 .65516 .32554 .62638 .31906 Metetra
.357 1 0 r
.62638 .31906 .65516 .32554 .66828 .32283 .63952 .31645 Metetra
.343 1 0 r
.63952 .31645 .66828 .32283 .68144 .31984 .6527 .31351 Metetra
.336 1 0 r
.6527 .31351 .68144 .31984 .69463 .31657 .66592 .31024 Metetra
.336 1 0 r
.66592 .31024 .69463 .31657 .70787 .31301 .67918 .30664 Metetra
.343 1 0 r
.67918 .30664 .70787 .31301 .72114 .30918 .69247 .30269 Metetra
.357 1 0 r
.69247 .30269 .72114 .30918 .73445 .30506 .7058 .29841 Metetra
.377 1 0 r
.7058 .29841 .73445 .30506 .7478 .30068 .71918 .29383 Metetra
.403 1 0 r
.71918 .29383 .7478 .30068 .76119 .29605 .73258 .28895 Metetra
.435 1 0 r
.73258 .28895 .76119 .29605 .77461 .29119 .74603 .28381 Metetra
.472 1 0 r
.74603 .28381 .77461 .29119 .78807 .28614 .75951 .27844 Metetra
.513 1 0 r
.75951 .27844 .78807 .28614 .80157 .2809 .77303 .27287 Metetra
.558 1 0 r
.77303 .27287 .80157 .2809 .81511 .27553 .78659 .26714 Metetra
.605 1 0 r
.78659 .26714 .81511 .27553 .82868 .27003 .80018 .26129 Metetra
.655 1 0 r
.80018 .26129 .82868 .27003 .84229 .26446 .81382 .25535 Metetra
.705 1 0 r
.81382 .25535 .84229 .26446 .85595 .25882 .82749 .24937 Metetra
.756 1 0 r
.82749 .24937 .85595 .25882 .86964 .25314 .84121 .24336 Metetra
.807 1 0 r
.84121 .24336 .86964 .25314 .88337 .24746 .85496 .23736 Metetra
.858 1 0 r
.85496 .23736 .88337 .24746 .89715 .24179 .86876 .23139 Metetra
.907 1 0 r
.86876 .23139 .89715 .24179 .91096 .23614 .8826 .22547 Metetra
.955 1 0 r
.8826 .22547 .91096 .23614 .92482 .23053 .89648 .21961 Metetra
1 .999 0 r
.89648 .21961 .92482 .23053 .93872 .22498 .9104 .21382 Metetra
1 .954 0 r
.9104 .21382 .93872 .22498 .95267 .21948 .92437 .20812 Metetra
1 .912 0 r
.92437 .20812 .95267 .21948 .96665 .21404 .93838 .2025 Metetra
1 .91 0 r
.37996 .3317 .40927 .34217 .42171 .3407 .39241 .33033 Metetra
1 .956 0 r
.39241 .33033 .42171 .3407 .4342 .33931 .40491 .32909 Metetra
.996 1 0 r
.40491 .32909 .4342 .33931 .44672 .33802 .41744 .32796 Metetra
.945 1 0 r
.41744 .32796 .44672 .33802 .45929 .33681 .43002 .32694 Metetra
.891 1 0 r
.43002 .32694 .45929 .33681 .47189 .33567 .44264 .32603 Metetra
.836 1 0 r
.44264 .32603 .47189 .33567 .48454 .33459 .4553 .32521 Metetra
.779 1 0 r
.4553 .32521 .48454 .33459 .49723 .33356 .46799 .32446 Metetra
.721 1 0 r
.46799 .32446 .49723 .33356 .50996 .33254 .48074 .32375 Metetra
.663 1 0 r
.48074 .32375 .50996 .33254 .52272 .33152 .49352 .32307 Metetra
.605 1 0 r
.49352 .32307 .52272 .33152 .53554 .33047 .50635 .32236 Metetra
.547 1 0 r
.50635 .32236 .53554 .33047 .54839 .32934 .51921 .32159 Metetra
.492 1 0 r
.51921 .32159 .54839 .32934 .56128 .32811 .53213 .32071 Metetra
.44 1 0 r
.53213 .32071 .56128 .32811 .57422 .32673 .54508 .31967 Metetra
.391 1 0 r
.54508 .31967 .57422 .32673 .5872 .32517 .55808 .31844 Metetra
.347 1 0 r
.55808 .31844 .5872 .32517 .60022 .3234 .57111 .31695 Metetra
.31 1 0 r
.57111 .31695 .60022 .3234 .61328 .32137 .58419 .31516 Metetra
.278 1 0 r
.58419 .31516 .61328 .32137 .62638 .31906 .59731 .31305 Metetra
.254 1 0 r
.59731 .31305 .62638 .31906 .63952 .31645 .61048 .31057 Metetra
.238 1 0 r
.61048 .31057 .63952 .31645 .6527 .31351 .62368 .30771 Metetra
.229 1 0 r
.62368 .30771 .6527 .31351 .66592 .31024 .63692 .30445 Metetra
.229 1 0 r
.63692 .30445 .66592 .31024 .67918 .30664 .6502 .30078 Metetra
.238 1 0 r
.6502 .30078 .67918 .30664 .69247 .30269 .66351 .2967 Metetra
.254 1 0 r
.66351 .2967 .69247 .30269 .7058 .29841 .67687 .29224 Metetra
.278 1 0 r
.67687 .29224 .7058 .29841 .71918 .29383 .69026 .2874 Metetra
.31 1 0 r
.69026 .2874 .71918 .29383 .73258 .28895 .70369 .28222 Metetra
.347 1 0 r
.70369 .28222 .73258 .28895 .74603 .28381 .71716 .27673 Metetra
.391 1 0 r
.71716 .27673 .74603 .28381 .75951 .27844 .73066 .27098 Metetra
.44 1 0 r
.73066 .27098 .75951 .27844 .77303 .27287 .74421 .265 Metetra
.492 1 0 r
.74421 .265 .77303 .27287 .78659 .26714 .75778 .25885 Metetra
.547 1 0 r
.75778 .25885 .78659 .26714 .80018 .26129 .7714 .25257 Metetra
.605 1 0 r
.7714 .25257 .80018 .26129 .81382 .25535 .78506 .24622 Metetra
.663 1 0 r
.78506 .24622 .81382 .25535 .82749 .24937 .79875 .23982 Metetra
.721 1 0 r
.79875 .23982 .82749 .24937 .84121 .24336 .81249 .23343 Metetra
.779 1 0 r
.81249 .23343 .84121 .24336 .85496 .23736 .82627 .22707 Metetra
.836 1 0 r
.82627 .22707 .85496 .23736 .86876 .23139 .84009 .22076 Metetra
.891 1 0 r
.84009 .22076 .86876 .23139 .8826 .22547 .85395 .21454 Metetra
.945 1 0 r
.85395 .21454 .8826 .22547 .89648 .21961 .86785 .20841 Metetra
.996 1 0 r
.86785 .20841 .89648 .21961 .9104 .21382 .8818 .20238 Metetra
1 .956 0 r
.8818 .20238 .9104 .21382 .92437 .20812 .89579 .19647 Metetra
1 .91 0 r
.89579 .19647 .92437 .20812 .93838 .2025 .90982 .19066 Metetra
1 .904 0 r
.35037 .32091 .37996 .3317 .39241 .33033 .36284 .31965 Metetra
1 .953 0 r
.36284 .31965 .39241 .33033 .40491 .32909 .37534 .31855 Metetra
.994 1 0 r
.37534 .31855 .40491 .32909 .41744 .32796 .38789 .31759 Metetra
.938 1 0 r
.38789 .31759 .41744 .32796 .43002 .32694 .40047 .31679 Metetra
.879 1 0 r
.40047 .31679 .43002 .32694 .44264 .32603 .4131 .31612 Metetra
.818 1 0 r
.4131 .31612 .44264 .32603 .4553 .32521 .42577 .31559 Metetra
.753 1 0 r
.42577 .31559 .4553 .32521 .46799 .32446 .43848 .31517 Metetra
.687 1 0 r
.43848 .31517 .46799 .32446 .48074 .32375 .45123 .31484 Metetra
.62 1 0 r
.45123 .31484 .48074 .32375 .49352 .32307 .46403 .31456 Metetra
.553 1 0 r
.46403 .31456 .49352 .32307 .50635 .32236 .47687 .31428 Metetra
.486 1 0 r
.47687 .31428 .50635 .32236 .51921 .32159 .48975 .31395 Metetra
.421 1 0 r
.48975 .31395 .51921 .32159 .53213 .32071 .50268 .31351 Metetra
.359 1 0 r
.50268 .31351 .53213 .32071 .54508 .31967 .51565 .31291 Metetra
.301 1 0 r
.51565 .31291 .54508 .31967 .55808 .31844 .52866 .31207 Metetra
.249 1 0 r
.52866 .31207 .55808 .31844 .57111 .31695 .54172 .31095 Metetra
.204 1 0 r
.54172 .31095 .57111 .31695 .58419 .31516 .55481 .30948 Metetra
.167 1 0 r
.55481 .30948 .58419 .31516 .59731 .31305 .56795 .30761 Metetra
.138 1 0 r
.56795 .30761 .59731 .31305 .61048 .31057 .58114 .30531 Metetra
.118 1 0 r
.58114 .30531 .61048 .31057 .62368 .30771 .59436 .30254 Metetra
.108 1 0 r
.59436 .30254 .62368 .30771 .63692 .30445 .60762 .2993 Metetra
.108 1 0 r
.60762 .2993 .63692 .30445 .6502 .30078 .62092 .29556 Metetra
.118 1 0 r
.62092 .29556 .6502 .30078 .66351 .2967 .63427 .29134 Metetra
.138 1 0 r
.63427 .29134 .66351 .2967 .67687 .29224 .64764 .28664 Metetra
.167 1 0 r
.64764 .28664 .67687 .29224 .69026 .2874 .66106 .2815 Metetra
.204 1 0 r
.66106 .2815 .69026 .2874 .70369 .28222 .67451 .27595 Metetra
.249 1 0 r
.67451 .27595 .70369 .28222 .71716 .27673 .688 .27004 Metetra
.301 1 0 r
.688 .27004 .71716 .27673 .73066 .27098 .70153 .26381 Metetra
.359 1 0 r
.70153 .26381 .73066 .27098 .74421 .265 .71509 .25734 Metetra
.421 1 0 r
.71509 .25734 .74421 .265 .75778 .25885 .72869 .25067 Metetra
.486 1 0 r
.72869 .25067 .75778 .25885 .7714 .25257 .74233 .24388 Metetra
.553 1 0 r
.74233 .24388 .7714 .25257 .78506 .24622 .75601 .23702 Metetra
.62 1 0 r
.75601 .23702 .78506 .24622 .79875 .23982 .76973 .23015 Metetra
.687 1 0 r
.76973 .23015 .79875 .23982 .81249 .23343 .78348 .2233 Metetra
.753 1 0 r
.78348 .2233 .81249 .23343 .82627 .22707 .79728 .21653 Metetra
.818 1 0 r
.79728 .21653 .82627 .22707 .84009 .22076 .81112 .20986 Metetra
.879 1 0 r
.81112 .20986 .84009 .22076 .85395 .21454 .825 .2033 Metetra
.938 1 0 r
.825 .2033 .85395 .21454 .86785 .20841 .83893 .19688 Metetra
.994 1 0 r
.83893 .19688 .86785 .20841 .8818 .20238 .8529 .1906 Metetra
1 .953 0 r
.8529 .1906 .8818 .20238 .89579 .19647 .86691 .18447 Metetra
1 .904 0 r
.86691 .18447 .89579 .19647 .90982 .19066 .88097 .17847 Metetra
1 .892 0 r
.32051 .30976 .35037 .32091 .36284 .31965 .33298 .3086 Metetra
1 .945 0 r
.33298 .3086 .36284 .31965 .37534 .31855 .3455 .30763 Metetra
.998 1 0 r
.3455 .30763 .37534 .31855 .38789 .31759 .35805 .30685 Metetra
.937 1 0 r
.35805 .30685 .38789 .31759 .40047 .31679 .37065 .30627 Metetra
.872 1 0 r
.37065 .30627 .40047 .31679 .4131 .31612 .38328 .30588 Metetra
.803 1 0 r
.38328 .30588 .4131 .31612 .42577 .31559 .39596 .30568 Metetra
.731 1 0 r
.39596 .30568 .42577 .31559 .43848 .31517 .40868 .30565 Metetra
.656 1 0 r
.40868 .30565 .43848 .31517 .45123 .31484 .42144 .30575 Metetra
.578 1 0 r
.42144 .30575 .45123 .31484 .46403 .31456 .43425 .30595 Metetra
.5 1 0 r
.43425 .30595 .46403 .31456 .47687 .31428 .4471 .30619 Metetra
.421 1 0 r
.4471 .30619 .47687 .31428 .48975 .31395 .45999 .30642 Metetra
.344 1 0 r
.45999 .30642 .48975 .31395 .50268 .31351 .47293 .30654 Metetra
.271 1 0 r
.47293 .30654 .50268 .31351 .51565 .31291 .48592 .30648 Metetra
.202 1 0 r
.48592 .30648 .51565 .31291 .52866 .31207 .49895 .30616 Metetra
.139 1 0 r
.49895 .30616 .52866 .31207 .54172 .31095 .51202 .3055 Metetra
.085 1 0 r
.51202 .3055 .54172 .31095 .55481 .30948 .52514 .30443 Metetra
.04 1 0 r
.52514 .30443 .55481 .30948 .56795 .30761 .5383 .30288 Metetra
.005 1 0 r
.5383 .30288 .56795 .30761 .58114 .30531 .5515 .30081 Metetra
0 1 .019 r
.5515 .30081 .58114 .30531 .59436 .30254 .56474 .29818 Metetra
0 1 .031 r
.56474 .29818 .59436 .30254 .60762 .2993 .57803 .29496 Metetra
0 1 .031 r
.57803 .29496 .60762 .2993 .62092 .29556 .59135 .29114 Metetra
0 1 .019 r
.59135 .29114 .62092 .29556 .63427 .29134 .60472 .28674 Metetra
.005 1 0 r
.60472 .28674 .63427 .29134 .64764 .28664 .61812 .28176 Metetra
.04 1 0 r
.61812 .28176 .64764 .28664 .66106 .2815 .63156 .27625 Metetra
.085 1 0 r
.63156 .27625 .66106 .2815 .67451 .27595 .64503 .27024 Metetra
.139 1 0 r
.64503 .27024 .67451 .27595 .688 .27004 .65855 .2638 Metetra
.202 1 0 r
.65855 .2638 .688 .27004 .70153 .26381 .6721 .25699 Metetra
.271 1 0 r
.6721 .25699 .70153 .26381 .71509 .25734 .68568 .2499 Metetra
.344 1 0 r
.68568 .2499 .71509 .25734 .72869 .25067 .6993 .2426 Metetra
.421 1 0 r
.6993 .2426 .72869 .25067 .74233 .24388 .71296 .23518 Metetra
.5 1 0 r
.71296 .23518 .74233 .24388 .75601 .23702 .72666 .22772 Metetra
.578 1 0 r
.72666 .22772 .75601 .23702 .76973 .23015 .7404 .22028 Metetra
.656 1 0 r
.7404 .22028 .76973 .23015 .78348 .2233 .75418 .21292 Metetra
.731 1 0 r
.75418 .21292 .78348 .2233 .79728 .21653 .768 .20568 Metetra
.803 1 0 r
.768 .20568 .79728 .21653 .81112 .20986 .78186 .19859 Metetra
.872 1 0 r
.78186 .19859 .81112 .20986 .825 .2033 .79577 .19168 Metetra
.937 1 0 r
.79577 .19168 .825 .2033 .83893 .19688 .80972 .18495 Metetra
.998 1 0 r
.80972 .18495 .83893 .19688 .8529 .1906 .82371 .17841 Metetra
1 .945 0 r
.82371 .17841 .8529 .1906 .86691 .18447 .83775 .17206 Metetra
1 .892 0 r
.83775 .17206 .86691 .18447 .88097 .17847 .85183 .16588 Metetra
1 .874 0 r
.29036 .29818 .32051 .30976 .33298 .3086 .30285 .29711 Metetra
1 .93 0 r
.30285 .29711 .33298 .3086 .3455 .30763 .31537 .29626 Metetra
1 .99 0 r
.31537 .29626 .3455 .30763 .35805 .30685 .32794 .29566 Metetra
.943 1 0 r
.32794 .29566 .35805 .30685 .37065 .30627 .34054 .2953 Metetra
.872 1 0 r
.34054 .2953 .37065 .30627 .38328 .30588 .35318 .29521 Metetra
.795 1 0 r
.35318 .29521 .38328 .30588 .39596 .30568 .36587 .29537 Metetra
.714 1 0 r
.36587 .29537 .39596 .30568 .40868 .30565 .37859 .29577 Metetra
.628 1 0 r
.37859 .29577 .40868 .30565 .42144 .30575 .39136 .29639 Metetra
.538 1 0 r
.39136 .29639 .42144 .30575 .43425 .30595 .40418 .29718 Metetra
.447 1 0 r
.40418 .29718 .43425 .30595 .4471 .30619 .41704 .29807 Metetra
.354 1 0 r
.41704 .29807 .4471 .30619 .45999 .30642 .42994 .29898 Metetra
.262 1 0 r
.42994 .29898 .45999 .30642 .47293 .30654 .44289 .29982 Metetra
.174 1 0 r
.44289 .29982 .47293 .30654 .48592 .30648 .45589 .30046 Metetra
.091 1 0 r
.45589 .30046 .48592 .30648 .49895 .30616 .46893 .3008 Metetra
.015 1 0 r
.46893 .3008 .49895 .30616 .51202 .3055 .48202 .30074 Metetra
0 1 .051 r
.48202 .30074 .51202 .3055 .52514 .30443 .49515 .30018 Metetra
0 1 .106 r
.49515 .30018 .52514 .30443 .5383 .30288 .50833 .29904 Metetra
0 1 .148 r
.50833 .29904 .5383 .30288 .5515 .30081 .52155 .29726 Metetra
0 1 .177 r
.52155 .29726 .5515 .30081 .56474 .29818 .53482 .2948 Metetra
0 1 .192 r
.53482 .2948 .56474 .29818 .57803 .29496 .54813 .29162 Metetra
0 1 .192 r
.54813 .29162 .57803 .29496 .59135 .29114 .56147 .28772 Metetra
0 1 .177 r
.56147 .28772 .59135 .29114 .60472 .28674 .57486 .28309 Metetra
0 1 .148 r
.57486 .28309 .60472 .28674 .61812 .28176 .58829 .27778 Metetra
0 1 .106 r
.58829 .27778 .61812 .28176 .63156 .27625 .60175 .2718 Metetra
0 1 .051 r
.60175 .2718 .63156 .27625 .64503 .27024 .61525 .26522 Metetra
.015 1 0 r
.61525 .26522 .64503 .27024 .65855 .2638 .62879 .25811 Metetra
.091 1 0 r
.62879 .25811 .65855 .2638 .6721 .25699 .64236 .25058 Metetra
.174 1 0 r
.64236 .25058 .6721 .25699 .68568 .2499 .65597 .24271 Metetra
.262 1 0 r
.65597 .24271 .68568 .2499 .6993 .2426 .66962 .23463 Metetra
.354 1 0 r
.66962 .23463 .6993 .2426 .71296 .23518 .6833 .22644 Metetra
.447 1 0 r
.6833 .22644 .71296 .23518 .72666 .22772 .69702 .21824 Metetra
.538 1 0 r
.69702 .21824 .72666 .22772 .7404 .22028 .71078 .21013 Metetra
.628 1 0 r
.71078 .21013 .7404 .22028 .75418 .21292 .72458 .20216 Metetra
.714 1 0 r
.72458 .20216 .75418 .21292 .768 .20568 .73842 .19439 Metetra
.795 1 0 r
.73842 .19439 .768 .20568 .78186 .19859 .7523 .18685 Metetra
.872 1 0 r
.7523 .18685 .78186 .19859 .79577 .19168 .76623 .17956 Metetra
.943 1 0 r
.76623 .17956 .79577 .19168 .80972 .18495 .7802 .17253 Metetra
1 .99 0 r
.7802 .17253 .80972 .18495 .82371 .17841 .79422 .16573 Metetra
1 .93 0 r
.79422 .16573 .82371 .17841 .83775 .17206 .80828 .15917 Metetra
1 .874 0 r
.80828 .15917 .83775 .17206 .85183 .16588 .82239 .15283 Metetra
1 .847 0 r
.25994 .28612 .29036 .29818 .30285 .29711 .27243 .2851 Metetra
1 .905 0 r
.27243 .2851 .30285 .29711 .31537 .29626 .28496 .28435 Metetra
1 .97 0 r
.28496 .28435 .31537 .29626 .32794 .29566 .29753 .2839 Metetra
.959 1 0 r
.29753 .2839 .32794 .29566 .34054 .2953 .31014 .28376 Metetra
.881 1 0 r
.31014 .28376 .34054 .2953 .35318 .29521 .32279 .28396 Metetra
.797 1 0 r
.32279 .28396 .35318 .29521 .36587 .29537 .33548 .28451 Metetra
.705 1 0 r
.33548 .28451 .36587 .29537 .37859 .29577 .34822 .28541 Metetra
.607 1 0 r
.34822 .28541 .37859 .29577 .39136 .29639 .36099 .28664 Metetra
.503 1 0 r
.36099 .28664 .39136 .29639 .40418 .29718 .37381 .28814 Metetra
.395 1 0 r
.37381 .28814 .40418 .29718 .41704 .29807 .38667 .28983 Metetra
.285 1 0 r
.38667 .28983 .41704 .29807 .42994 .29898 .39958 .29162 Metetra
.175 1 0 r
.39958 .29162 .42994 .29898 .44289 .29982 .41254 .29336 Metetra
.068 1 0 r
.41254 .29336 .44289 .29982 .45589 .30046 .42555 .29491 Metetra
0 1 .033 r
.42555 .29491 .45589 .30046 .46893 .3008 .4386 .29612 Metetra
0 1 .126 r
.4386 .29612 .46893 .3008 .48202 .30074 .4517 .29683 Metetra
0 1 .207 r
.4517 .29683 .48202 .30074 .49515 .30018 .46485 .29693 Metetra
0 1 .274 r
.46485 .29693 .49515 .30018 .50833 .29904 .47805 .29631 Metetra
0 1 .325 r
.47805 .29631 .50833 .29904 .52155 .29726 .49129 .2949 Metetra
0 1 .361 r
.49129 .2949 .52155 .29726 .53482 .2948 .50458 .29265 Metetra
0 1 .378 r
.50458 .29265 .53482 .2948 .54813 .29162 .51791 .28953 Metetra
0 1 .378 r
.51791 .28953 .54813 .29162 .56147 .28772 .53128 .28552 Metetra
0 1 .361 r
.53128 .28552 .56147 .28772 .57486 .28309 .54469 .28064 Metetra
0 1 .325 r
.54469 .28064 .57486 .28309 .58829 .27778 .55814 .2749 Metetra
0 1 .274 r
.55814 .2749 .58829 .27778 .60175 .2718 .57163 .26835 Metetra
0 1 .207 r
.57163 .26835 .60175 .2718 .61525 .26522 .58516 .26105 Metetra
0 1 .126 r
.58516 .26105 .61525 .26522 .62879 .25811 .59872 .25311 Metetra
0 1 .033 r
.59872 .25311 .62879 .25811 .64236 .25058 .61232 .24464 Metetra
.068 1 0 r
.61232 .24464 .64236 .25058 .65597 .24271 .62595 .2358 Metetra
.175 1 0 r
.62595 .2358 .65597 .24271 .66962 .23463 .63962 .22672 Metetra
.285 1 0 r
.63962 .22672 .66962 .23463 .6833 .22644 .65333 .21757 Metetra
.395 1 0 r
.65333 .21757 .6833 .22644 .69702 .21824 .66707 .20847 Metetra
.503 1 0 r
.66707 .20847 .69702 .21824 .71078 .21013 .68085 .19955 Metetra
.607 1 0 r
.68085 .19955 .71078 .21013 .72458 .20216 .69467 .19089 Metetra
.705 1 0 r
.69467 .19089 .72458 .20216 .73842 .19439 .70854 .18254 Metetra
.797 1 0 r
.70854 .18254 .73842 .19439 .7523 .18685 .72244 .17452 Metetra
.881 1 0 r
.72244 .17452 .7523 .18685 .76623 .17956 .73639 .16684 Metetra
.959 1 0 r
.73639 .16684 .76623 .17956 .7802 .17253 .75039 .1595 Metetra
1 .97 0 r
.75039 .1595 .7802 .17253 .79422 .16573 .76443 .15247 Metetra
1 .905 0 r
.76443 .15247 .79422 .16573 .80828 .15917 .77851 .14573 Metetra
1 .847 0 r
.77851 .14573 .80828 .15917 .82239 .15283 .79265 .13926 Metetra
1 .81 0 r
.22924 .27352 .25994 .28612 .27243 .2851 .24174 .2725 Metetra
1 .87 0 r
.24174 .2725 .27243 .2851 .28496 .28435 .25427 .2718 Metetra
1 .938 0 r
.25427 .2718 .28496 .28435 .29753 .2839 .26685 .27145 Metetra
.987 1 0 r
.26685 .27145 .29753 .2839 .31014 .28376 .27946 .2715 Metetra
.903 1 0 r
.27946 .2715 .31014 .28376 .32279 .28396 .29212 .27198 Metetra
.81 1 0 r
.29212 .27198 .32279 .28396 .33548 .28451 .30481 .27293 Metetra
.707 1 0 r
.30481 .27293 .33548 .28451 .34822 .28541 .31755 .27437 Metetra
.595 1 0 r
.31755 .27437 .34822 .28541 .36099 .28664 .33032 .27629 Metetra
.475 1 0 r
.33032 .27629 .36099 .28664 .37381 .28814 .34314 .27865 Metetra
.347 1 0 r
.34314 .27865 .37381 .28814 .38667 .28983 .35601 .28135 Metetra
.215 1 0 r
.35601 .28135 .38667 .28983 .39958 .29162 .36892 .28427 Metetra
.082 1 0 r
.36892 .28427 .39958 .29162 .41254 .29336 .38188 .2872 Metetra
0 1 .049 r
.38188 .2872 .41254 .29336 .42555 .29491 .39489 .28994 Metetra
0 1 .174 r
.39489 .28994 .42555 .29491 .4386 .29612 .40795 .29227 Metetra
0 1 .287 r
.40795 .29227 .4386 .29612 .4517 .29683 .42106 .29399 Metetra
0 1 .387 r
.42106 .29399 .4517 .29683 .46485 .29693 .43422 .29492 Metetra
0 1 .469 r
.43422 .29492 .46485 .29693 .47805 .29631 .44744 .29496 Metetra
0 1 .532 r
.44744 .29496 .47805 .29631 .49129 .2949 .4607 .29401 Metetra
0 1 .575 r
.4607 .29401 .49129 .2949 .50458 .29265 .47401 .29202 Metetra
0 1 .597 r
.47401 .29202 .50458 .29265 .51791 .28953 .48736 .28898 Metetra
0 1 .597 r
.48736 .28898 .51791 .28953 .53128 .28552 .50076 .28486 Metetra
0 1 .575 r
.50076 .28486 .53128 .28552 .54469 .28064 .5142 .27966 Metetra
0 1 .532 r
.5142 .27966 .54469 .28064 .55814 .2749 .52768 .27342 Metetra
0 1 .469 r
.52768 .27342 .55814 .2749 .57163 .26835 .54119 .26616 Metetra
0 1 .387 r
.54119 .26616 .57163 .26835 .58516 .26105 .55475 .25797 Metetra
0 1 .287 r
.55475 .25797 .58516 .26105 .59872 .25311 .56834 .24896 Metetra
0 1 .174 r
.56834 .24896 .59872 .25311 .61232 .24464 .58196 .2393 Metetra
0 1 .049 r
.58196 .2393 .61232 .24464 .62595 .2358 .59562 .22917 Metetra
.082 1 0 r
.59562 .22917 .62595 .2358 .63962 .22672 .60931 .21881 Metetra
.215 1 0 r
.60931 .21881 .63962 .22672 .65333 .21757 .62304 .20844 Metetra
.347 1 0 r
.62304 .20844 .65333 .21757 .66707 .20847 .63681 .19824 Metetra
.475 1 0 r
.63681 .19824 .66707 .20847 .68085 .19955 .65061 .18836 Metetra
.595 1 0 r
.65061 .18836 .68085 .19955 .69467 .19089 .66446 .1789 Metetra
.707 1 0 r
.66446 .1789 .69467 .19089 .70854 .18254 .67834 .16991 Metetra
.81 1 0 r
.67834 .16991 .70854 .18254 .72244 .17452 .69227 .1614 Metetra
.903 1 0 r
.69227 .1614 .72244 .17452 .73639 .16684 .70625 .15335 Metetra
.987 1 0 r
.70625 .15335 .73639 .16684 .75039 .1595 .72027 .14574 Metetra
1 .938 0 r
.72027 .14574 .75039 .1595 .76443 .15247 .73433 .13851 Metetra
1 .87 0 r
.73433 .13851 .76443 .15247 .77851 .14573 .74844 .13164 Metetra
1 .81 0 r
.74844 .13164 .77851 .14573 .79265 .13926 .7626 .12508 Metetra
1 .762 0 r
.19825 .2603 .22924 .27352 .24174 .2725 .21076 .25923 Metetra
1 .822 0 r
.21076 .25923 .24174 .2725 .25427 .2718 .2233 .2585 Metetra
1 .891 0 r
.2233 .2585 .25427 .2718 .26685 .27145 .23588 .25818 Metetra
1 .97 0 r
.23588 .25818 .26685 .27145 .27946 .2715 .2485 .25834 Metetra
.941 1 0 r
.2485 .25834 .27946 .2715 .29212 .27198 .26116 .25904 Metetra
.84 1 0 r
.26116 .25904 .29212 .27198 .30481 .27293 .27385 .26036 Metetra
.727 1 0 r
.27385 .26036 .30481 .27293 .31755 .27437 .28659 .26236 Metetra
.6 1 0 r
.28659 .26236 .31755 .27437 .33032 .27629 .29936 .26506 Metetra
.46 1 0 r
.29936 .26506 .33032 .27629 .34314 .27865 .31217 .26844 Metetra
.308 1 0 r
.31217 .26844 .34314 .27865 .35601 .28135 .32503 .27242 Metetra
.148 1 0 r
.32503 .27242 .35601 .28135 .36892 .28427 .33794 .27681 Metetra
0 1 .016 r
.33794 .27681 .36892 .28427 .38188 .2872 .3509 .28134 Metetra
0 1 .178 r
.3509 .28134 .38188 .2872 .39489 .28994 .36391 .28568 Metetra
0 1 .333 r
.36391 .28568 .39489 .28994 .40795 .29227 .37697 .28951 Metetra
0 1 .475 r
.37697 .28951 .40795 .29227 .42106 .29399 .39009 .29253 Metetra
0 1 .598 r
.39009 .29253 .42106 .29399 .43422 .29492 .40326 .29453 Metetra
0 1 .699 r
.40326 .29453 .43422 .29492 .44744 .29496 .41649 .29536 Metetra
0 1 .776 r
.41649 .29536 .44744 .29496 .4607 .29401 .42977 .29496 Metetra
0 1 .828 r
.42977 .29496 .4607 .29401 .47401 .29202 .4431 .29328 Metetra
0 1 .854 r
.4431 .29328 .47401 .29202 .48736 .28898 .45647 .29033 Metetra
0 1 .854 r
.45647 .29033 .48736 .28898 .50076 .28486 .4699 .28608 Metetra
0 1 .828 r
.4699 .28608 .50076 .28486 .5142 .27966 .48337 .28054 Metetra
0 1 .776 r
.48337 .28054 .5142 .27966 .52768 .27342 .49688 .27371 Metetra
0 1 .699 r
.49688 .27371 .52768 .27342 .54119 .26616 .51042 .2656 Metetra
0 1 .598 r
.51042 .2656 .54119 .26616 .55475 .25797 .52401 .2563 Metetra
0 1 .475 r
.52401 .2563 .55475 .25797 .56834 .24896 .53763 .24591 Metetra
0 1 .333 r
.53763 .24591 .56834 .24896 .58196 .2393 .55128 .23467 Metetra
0 1 .178 r
.55128 .23467 .58196 .2393 .59562 .22917 .56497 .22285 Metetra
0 1 .016 r
.56497 .22285 .59562 .22917 .60931 .21881 .57869 .21079 Metetra
.148 1 0 r
.57869 .21079 .60931 .21881 .62304 .20844 .59244 .19883 Metetra
.308 1 0 r
.59244 .19883 .62304 .20844 .63681 .19824 .60623 .18725 Metetra
.46 1 0 r
.60623 .18725 .63681 .19824 .65061 .18836 .62006 .17624 Metetra
.6 1 0 r
.62006 .17624 .65061 .18836 .66446 .1789 .63393 .1659 Metetra
.727 1 0 r
.63393 .1659 .66446 .1789 .67834 .16991 .64784 .15625 Metetra
.84 1 0 r
.64784 .15625 .67834 .16991 .69227 .1614 .66179 .14727 Metetra
.941 1 0 r
.66179 .14727 .69227 .1614 .70625 .15335 .67579 .13891 Metetra
1 .97 0 r
.67579 .13891 .70625 .15335 .72027 .14574 .68983 .13109 Metetra
1 .891 0 r
.68983 .13109 .72027 .14574 .73433 .13851 .70392 .12375 Metetra
1 .822 0 r
.70392 .12375 .73433 .13851 .74844 .13164 .71806 .11683 Metetra
1 .762 0 r
.71806 .11683 .74844 .13164 .7626 .12508 .73224 .11025 Metetra
1 .701 0 r
.16698 .24643 .19825 .2603 .21076 .25923 .17949 .2452 Metetra
1 .76 0 r
.17949 .2452 .21076 .25923 .2233 .2585 .19204 .24434 Metetra
1 .828 0 r
.19204 .24434 .2233 .2585 .23588 .25818 .20463 .24394 Metetra
1 .907 0 r
.20463 .24394 .23588 .25818 .2485 .25834 .21725 .24408 Metetra
1 .999 0 r
.21725 .24408 .2485 .25834 .26116 .25904 .22991 .24488 Metetra
.894 1 0 r
.22991 .24488 .26116 .25904 .27385 .26036 .24261 .24647 Metetra
.77 1 0 r
.24261 .24647 .27385 .26036 .28659 .26236 .25534 .24896 Metetra
.628 1 0 r
.25534 .24896 .28659 .26236 .29936 .26506 .26811 .25248 Metetra
.466 1 0 r
.26811 .25248 .29936 .26506 .31217 .26844 .28091 .25706 Metetra
.285 1 0 r
.28091 .25706 .31217 .26844 .32503 .27242 .29376 .26265 Metetra
.09 1 0 r
.29376 .26265 .32503 .27242 .33794 .27681 .30665 .26903 Metetra
0 1 .115 r
.30665 .26903 .33794 .27681 .3509 .28134 .31959 .27577 Metetra
0 1 .321 r
.31959 .27577 .3509 .28134 .36391 .28568 .33259 .28236 Metetra
0 1 .517 r
.33259 .28236 .36391 .28568 .37697 .28951 .34564 .28823 Metetra
0 1 .695 r
.34564 .28823 .37697 .28951 .39009 .29253 .35876 .29295 Metetra
0 1 .848 r
.35876 .29295 .39009 .29253 .40326 .29453 .37194 .29624 Metetra
0 1 .972 r
.37194 .29624 .40326 .29453 .41649 .29536 .38518 .298 Metetra
0 .935 1 r
.38518 .298 .41649 .29536 .42977 .29496 .39848 .29819 Metetra
0 .874 1 r
.39848 .29819 .42977 .29496 .4431 .29328 .41183 .29684 Metetra
0 .843 1 r
.41183 .29684 .4431 .29328 .45647 .29033 .42523 .29398 Metetra
0 .843 1 r
.42523 .29398 .45647 .29033 .4699 .28608 .43868 .28961 Metetra
0 .874 1 r
.43868 .28961 .4699 .28608 .48337 .28054 .45218 .28371 Metetra
0 .935 1 r
.45218 .28371 .48337 .28054 .49688 .27371 .46572 .27624 Metetra
0 1 .972 r
.46572 .27624 .49688 .27371 .51042 .2656 .47931 .26718 Metetra
0 1 .848 r
.47931 .26718 .51042 .2656 .52401 .2563 .49293 .25651 Metetra
0 1 .695 r
.49293 .25651 .52401 .2563 .53763 .24591 .50658 .24436 Metetra
0 1 .517 r
.50658 .24436 .53763 .24591 .55128 .23467 .52027 .23098 Metetra
0 1 .321 r
.52027 .23098 .55128 .23467 .56497 .22285 .53399 .21682 Metetra
0 1 .115 r
.53399 .21682 .56497 .22285 .57869 .21079 .54774 .20243 Metetra
.09 1 0 r
.54774 .20243 .57869 .21079 .59244 .19883 .56152 .18837 Metetra
.285 1 0 r
.56152 .18837 .59244 .19883 .60623 .18725 .57534 .17505 Metetra
.466 1 0 r
.57534 .17505 .60623 .18725 .62006 .17624 .58919 .16272 Metetra
.628 1 0 r
.58919 .16272 .62006 .17624 .63393 .1659 .60308 .15145 Metetra
.77 1 0 r
.60308 .15145 .63393 .1659 .64784 .15625 .61702 .1412 Metetra
.894 1 0 r
.61702 .1412 .64784 .15625 .66179 .14727 .631 .13186 Metetra
1 .999 0 r
.631 .13186 .66179 .14727 .67579 .13891 .64502 .1233 Metetra
1 .907 0 r
.64502 .1233 .67579 .13891 .68983 .13109 .65909 .11541 Metetra
1 .828 0 r
.65909 .11541 .68983 .13109 .70392 .12375 .6732 .10808 Metetra
1 .76 0 r
.6732 .10808 .70392 .12375 .71806 .11683 .68736 .1012 Metetra
1 .701 0 r
.68736 .1012 .71806 .11683 .73224 .11025 .70157 .0947 Metetra
1 .626 0 r
.13542 .23186 .16698 .24643 .17949 .2452 .14794 .23036 Metetra
1 .681 0 r
.14794 .23036 .17949 .2452 .19204 .24434 .1605 .22924 Metetra
1 .746 0 r
.1605 .22924 .19204 .24434 .20463 .24394 .1731 .22858 Metetra
1 .823 0 r
.1731 .22858 .20463 .24394 .21725 .24408 .18573 .22852 Metetra
1 .914 0 r
.18573 .22852 .21725 .24408 .22991 .24488 .19839 .2292 Metetra
.977 1 0 r
.19839 .2292 .22991 .24488 .24261 .24647 .21109 .23082 Metetra
.847 1 0 r
.21109 .23082 .24261 .24647 .25534 .24896 .22382 .23362 Metetra
.691 1 0 r
.22382 .23362 .25534 .24896 .26811 .25248 .23657 .23785 Metetra
.506 1 0 r
.23657 .23785 .26811 .25248 .28091 .25706 .24936 .24373 Metetra
.291 1 0 r
.24936 .24373 .28091 .25706 .29376 .26265 .26218 .25136 Metetra
.048 1 0 r
.26218 .25136 .29376 .26265 .30665 .26903 .27504 .26049 Metetra
0 1 .214 r
.27504 .26049 .30665 .26903 .31959 .27577 .28795 .27049 Metetra
0 1 .481 r
.28795 .27049 .31959 .27577 .33259 .28236 .30092 .28036 Metetra
0 1 .735 r
.30092 .28036 .33259 .28236 .34564 .28823 .31395 .2891 Metetra
0 1 .961 r
.31395 .2891 .34564 .28823 .35876 .29295 .32706 .29601 Metetra
0 .85 1 r
.32706 .29601 .35876 .29295 .37194 .29624 .34025 .3008 Metetra
0 .7 1 r
.34025 .3008 .37194 .29624 .38518 .298 .3535 .30348 Metetra
0 .591 1 r
.3535 .30348 .38518 .298 .39848 .29819 .36681 .30421 Metetra
0 .52 1 r
.36681 .30421 .39848 .29819 .41183 .29684 .38018 .30312 Metetra
0 .485 1 r
.38018 .30312 .41183 .29684 .42523 .29398 .39361 .30033 Metetra
0 .485 1 r
.39361 .30033 .42523 .29398 .43868 .28961 .40709 .29586 Metetra
0 .52 1 r
.40709 .29586 .43868 .28961 .45218 .28371 .42063 .28968 Metetra
0 .591 1 r
.42063 .28968 .45218 .28371 .46572 .27624 .4342 .28166 Metetra
0 .7 1 r
.4342 .28166 .46572 .27624 .47931 .26718 .44782 .27162 Metetra
0 .85 1 r
.44782 .27162 .47931 .26718 .49293 .25651 .46149 .25941 Metetra
0 1 .961 r
.46149 .25941 .49293 .25651 .50658 .24436 .47519 .245 Metetra
0 1 .735 r
.47519 .245 .50658 .24436 .52027 .23098 .48892 .22866 Metetra
0 1 .481 r
.48892 .22866 .52027 .23098 .53399 .21682 .50268 .21108 Metetra
0 1 .214 r
.50268 .21108 .53399 .21682 .54774 .20243 .51646 .1933 Metetra
.048 1 0 r
.51646 .1933 .54774 .20243 .56152 .18837 .53028 .17632 Metetra
.291 1 0 r
.53028 .17632 .56152 .18837 .57534 .17505 .54412 .16083 Metetra
.506 1 0 r
.54412 .16083 .57534 .17505 .58919 .16272 .558 .14707 Metetra
.691 1 0 r
.558 .14707 .58919 .16272 .60308 .15145 .57192 .13497 Metetra
.847 1 0 r
.57192 .13497 .60308 .15145 .61702 .1412 .58588 .12431 Metetra
.977 1 0 r
.58588 .12431 .61702 .1412 .631 .13186 .59989 .11484 Metetra
1 .914 0 r
.59989 .11484 .631 .13186 .64502 .1233 .61394 .10632 Metetra
1 .823 0 r
.61394 .10632 .64502 .1233 .65909 .11541 .62803 .09856 Metetra
1 .746 0 r
.62803 .09856 .65909 .11541 .6732 .10808 .64217 .09139 Metetra
1 .681 0 r
.64217 .09139 .6732 .10808 .68736 .1012 .65635 .08471 Metetra
1 .626 0 r
.65635 .08471 .68736 .1012 .70157 .0947 .67058 .0784 Metetra
1 .538 0 r
.10357 .21662 .13542 .23186 .14794 .23036 .11611 .21472 Metetra
1 .586 0 r
.11611 .21472 .14794 .23036 .1605 .22924 .12868 .21316 Metetra
1 .643 0 r
.12868 .21316 .1605 .22924 .1731 .22858 .14129 .21204 Metetra
1 .712 0 r
.14129 .21204 .1731 .22858 .18573 .22852 .15393 .2115 Metetra
1 .797 0 r
.15393 .2115 .18573 .22852 .19839 .2292 .1666 .21171 Metetra
1 .901 0 r
.1666 .21171 .19839 .2292 .21109 .23082 .1793 .21296 Metetra
.969 1 0 r
.1793 .21296 .21109 .23082 .22382 .23362 .19203 .21559 Metetra
.807 1 0 r
.19203 .21559 .22382 .23362 .23657 .23785 .20478 .22011 Metetra
.602 1 0 r
.20478 .22011 .23657 .23785 .24936 .24373 .21755 .2271 Metetra
.349 1 0 r
.21755 .2271 .24936 .24373 .26218 .25136 .23033 .23711 Metetra
.043 1 0 r
.23033 .23711 .26218 .25136 .27504 .26049 .24313 .25024 Metetra
0 1 .303 r
.24313 .25024 .27504 .26049 .28795 .27049 .25597 .26546 Metetra
0 1 .664 r
.25597 .26546 .28795 .27049 .30092 .28036 .26888 .28061 Metetra
0 .996 1 r
.26888 .28061 .30092 .28036 .31395 .2891 .28187 .2935 Metetra
0 .705 1 r
.28187 .2935 .31395 .2891 .32706 .29601 .29497 .30305 Metetra
0 .474 1 r
.29497 .30305 .32706 .29601 .34025 .3008 .30815 .30924 Metetra
0 .301 1 r
.30815 .30924 .34025 .3008 .3535 .30348 .32141 .31256 Metetra
0 .179 1 r
.32141 .31256 .3535 .30348 .36681 .30421 .33475 .31351 Metetra
0 .102 1 r
.33475 .31351 .36681 .30421 .38018 .30312 .34814 .31248 Metetra
0 .065 1 r
.34814 .31248 .38018 .30312 .39361 .30033 .3616 .30969 Metetra
0 .065 1 r
.3616 .30969 .39361 .30033 .40709 .29586 .37511 .30521 Metetra
0 .102 1 r
.37511 .30521 .40709 .29586 .42063 .28968 .38868 .29896 Metetra
0 .179 1 r
.38868 .29896 .42063 .28968 .4342 .28166 .40229 .29069 Metetra
0 .301 1 r
.40229 .29069 .4342 .28166 .44782 .27162 .41596 .28 Metetra
0 .474 1 r
.41596 .28 .44782 .27162 .46149 .25941 .42967 .26635 Metetra
0 .705 1 r
.42967 .26635 .46149 .25941 .47519 .245 .44342 .24923 Metetra
0 .996 1 r
.44342 .24923 .47519 .245 .48892 .22866 .45721 .22862 Metetra
0 1 .664 r
.45721 .22862 .48892 .22866 .50268 .21108 .47102 .20559 Metetra
0 1 .303 r
.47102 .20559 .50268 .21108 .51646 .1933 .48486 .18239 Metetra
.043 1 0 r
.48486 .18239 .51646 .1933 .53028 .17632 .49871 .16123 Metetra
.349 1 0 r
.49871 .16123 .53028 .17632 .54412 .16083 .51259 .14318 Metetra
.602 1 0 r
.51259 .14318 .54412 .16083 .558 .14707 .5265 .12818 Metetra
.807 1 0 r
.5265 .12818 .558 .14707 .57192 .13497 .54045 .11568 Metetra
.969 1 0 r
.54045 .11568 .57192 .13497 .58588 .12431 .55444 .1051 Metetra
1 .901 0 r
.55444 .1051 .58588 .12431 .59989 .11484 .56846 .09592 Metetra
1 .797 0 r
.56846 .09592 .59989 .11484 .61394 .10632 .58254 .08779 Metetra
1 .712 0 r
.58254 .08779 .61394 .10632 .62803 .09856 .59665 .08044 Metetra
1 .643 0 r
.59665 .08044 .62803 .09856 .64217 .09139 .61082 .07367 Metetra
1 .586 0 r
.61082 .07367 .64217 .09139 .65635 .08471 .62503 .06735 Metetra
1 .538 0 r
.62503 .06735 .65635 .08471 .67058 .0784 .63928 .06137 Metetra
1 .436 0 r
.07143 .20076 .10357 .21662 .11611 .21472 .08398 .19833 Metetra
1 .474 0 r
.08398 .19833 .11611 .21472 .12868 .21316 .09657 .19616 Metetra
1 .519 0 r
.09657 .19616 .12868 .21316 .14129 .21204 .1092 .19434 Metetra
1 .575 0 r
.1092 .19434 .14129 .21204 .15393 .2115 .12186 .19298 Metetra
1 .645 0 r
.12186 .19298 .15393 .2115 .1666 .21171 .13455 .19228 Metetra
1 .735 0 r
.13455 .19228 .1666 .21171 .1793 .21296 .14726 .19251 Metetra
1 .85 0 r
.14726 .19251 .1793 .21296 .19203 .21559 .16001 .19412 Metetra
.996 1 0 r
.16001 .19412 .19203 .21559 .20478 .22011 .17276 .19783 Metetra
.788 1 0 r
.17276 .19783 .20478 .22011 .21755 .2271 .18552 .2048 Metetra
.504 1 0 r
.18552 .2048 .21755 .2271 .23033 .23711 .19826 .21679 Metetra
.12 1 0 r
.19826 .21679 .23033 .23711 .24313 .25024 .21096 .23566 Metetra
0 1 .363 r
.21096 .23566 .24313 .25024 .25597 .26546 .22365 .26062 Metetra
0 1 .89 r
.22365 .26062 .25597 .26546 .26888 .28061 .23642 .28563 Metetra
0 .633 1 r
.23642 .28563 .26888 .28061 .28187 .2935 .24934 .30453 Metetra
0 .26 1 r
.24934 .30453 .28187 .2935 .29497 .30305 .26241 .3164 Metetra
.007 0 1 r
.26241 .3164 .29497 .30305 .30815 .30924 .27561 .32296 Metetra
.191 0 1 r
.27561 .32296 .30815 .30924 .32141 .31256 .28889 .32593 Metetra
.312 0 1 r
.28889 .32593 .32141 .31256 .33475 .31351 .30226 .32641 Metetra
.385 0 1 r
.30226 .32641 .33475 .31351 .34814 .31248 .31568 .32503 Metetra
.42 0 1 r
.31568 .32503 .34814 .31248 .3616 .30969 .32917 .32212 Metetra
.42 0 1 r
.32917 .32212 .3616 .30969 .37511 .30521 .34271 .31776 Metetra
.385 0 1 r
.34271 .31776 .37511 .30521 .38868 .29896 .35631 .31185 Metetra
.312 0 1 r
.35631 .31185 .38868 .29896 .40229 .29069 .36996 .30405 Metetra
.191 0 1 r
.36996 .30405 .40229 .29069 .41596 .28 .38367 .29371 Metetra
.007 0 1 r
.38367 .29371 .41596 .28 .42967 .26635 .39743 .27969 Metetra
0 .26 1 r
.39743 .27969 .42967 .26635 .44342 .24923 .41125 .2602 Metetra
0 .633 1 r
.41125 .2602 .44342 .24923 .45721 .22862 .42512 .23345 Metetra
0 1 .89 r
.42512 .23345 .45721 .22862 .47102 .20559 .43902 .2003 Metetra
0 1 .363 r
.43902 .2003 .47102 .20559 .48486 .18239 .45293 .16703 Metetra
.12 1 0 r
.45293 .16703 .48486 .18239 .49871 .16123 .46684 .13987 Metetra
.504 1 0 r
.46684 .13987 .49871 .16123 .51259 .14318 .48076 .11967 Metetra
.788 1 0 r
.48076 .11967 .51259 .14318 .5265 .12818 .4947 .10458 Metetra
.996 1 0 r
.4947 .10458 .5265 .12818 .54045 .11568 .50867 .09281 Metetra
1 .85 0 r
.50867 .09281 .54045 .11568 .55444 .1051 .52268 .08318 Metetra
1 .735 0 r
.52268 .08318 .55444 .1051 .56846 .09592 .53673 .07495 Metetra
1 .645 0 r
.53673 .07495 .56846 .09592 .58254 .08779 .55083 .06768 Metetra
1 .575 0 r
.55083 .06768 .58254 .08779 .59665 .08044 .56497 .06107 Metetra
1 .519 0 r
.56497 .06107 .59665 .08044 .61082 .07367 .57915 .05494 Metetra
1 .474 0 r
.57915 .05494 .61082 .07367 .62503 .06735 .59338 .04917 Metetra
1 .436 0 r
.59338 .04917 .62503 .06735 .63928 .06137 .60766 .04366 Metetra
1 .324 0 r
.039 .18438 .07143 .20076 .08398 .19833 .05157 .18131 Metetra
1 .348 0 r
.05157 .18131 .08398 .19833 .09657 .19616 .06418 .17838 Metetra
1 .377 0 r
.06418 .17838 .09657 .19616 .1092 .19434 .07682 .17564 Metetra
1 .414 0 r
.07682 .17564 .1092 .19434 .12186 .19298 .08951 .17316 Metetra
1 .461 0 r
.08951 .17316 .12186 .19298 .13455 .19228 .10223 .17106 Metetra
1 .522 0 r
.10223 .17106 .13455 .19228 .14726 .19251 .11498 .16954 Metetra
1 .605 0 r
.11498 .16954 .14726 .19251 .16001 .19412 .12775 .16892 Metetra
1 .721 0 r
.12775 .16892 .16001 .19412 .17276 .19783 .14055 .16984 Metetra
1 .891 0 r
.14055 .16984 .17276 .19783 .18552 .2048 .15334 .17362 Metetra
.843 1 0 r
.15334 .17362 .18552 .2048 .19826 .21679 .16609 .18337 Metetra
.402 1 0 r
.16609 .18337 .19826 .21679 .21096 .23566 .17868 .20704 Metetra
0 1 .325 r
.17868 .20704 .21096 .23566 .22365 .26062 .19098 .25591 Metetra
0 .777 1 r
.19098 .25591 .22365 .26062 .23642 .28563 .20337 .30514 Metetra
0 .054 1 r
.20337 .30514 .23642 .28563 .24934 .30453 .21622 .32927 Metetra
.38 0 1 r
.21622 .32927 .24934 .30453 .26241 .3164 .22933 .33926 Metetra
.635 0 1 r
.22933 .33926 .26241 .3164 .27561 .32296 .24258 .34305 Metetra
.789 0 1 r
.24258 .34305 .27561 .32296 .28889 .32593 .25592 .34374 Metetra
.884 0 1 r
.25592 .34374 .28889 .32593 .30226 .32641 .26932 .34266 Metetra
.94 0 1 r
.26932 .34266 .30226 .32641 .31568 .32503 .28279 .34039 Metetra
.965 0 1 r
.28279 .34039 .31568 .32503 .32917 .32212 .29631 .33718 Metetra
.965 0 1 r
.29631 .33718 .32917 .32212 .34271 .31776 .30988 .33312 Metetra
.94 0 1 r
.30988 .33312 .34271 .31776 .35631 .31185 .32351 .32811 Metetra
.884 0 1 r
.32351 .32811 .35631 .31185 .36996 .30405 .33719 .3219 Metetra
.789 0 1 r
.33719 .3219 .36996 .30405 .38367 .29371 .35093 .31387 Metetra
.635 0 1 r
.35093 .31387 .38367 .29371 .39743 .27969 .36472 .30268 Metetra
.38 0 1 r
.36472 .30268 .39743 .27969 .41125 .2602 .37859 .28513 Metetra
0 .054 1 r
.37859 .28513 .41125 .2602 .42512 .23345 .39257 .25306 Metetra
0 .777 1 r
.39257 .25306 .42512 .23345 .43902 .2003 .40667 .19513 Metetra
0 1 .325 r
.40667 .19513 .43902 .2003 .45293 .16703 .42074 .13726 Metetra
.402 1 0 r
.42074 .13726 .45293 .16703 .46684 .13987 .43471 .10502 Metetra
.843 1 0 r
.43471 .10502 .46684 .13987 .48076 .11967 .44865 .08698 Metetra
1 .891 0 r
.44865 .08698 .48076 .11967 .4947 .10458 .46261 .07506 Metetra
1 .721 0 r
.46261 .07506 .4947 .10458 .50867 .09281 .47659 .06605 Metetra
1 .605 0 r
.47659 .06605 .50867 .09281 .52268 .08318 .49062 .05862 Metetra
1 .522 0 r
.49062 .05862 .52268 .08318 .53673 .07495 .50469 .05211 Metetra
1 .461 0 r
.50469 .05211 .53673 .07495 .55083 .06768 .5188 .04619 Metetra
1 .414 0 r
.5188 .04619 .55083 .06768 .56497 .06107 .53296 .04065 Metetra
1 .377 0 r
.53296 .04065 .56497 .06107 .57915 .05494 .54717 .03539 Metetra
1 .348 0 r
.54717 .03539 .57915 .05494 .59338 .04917 .56142 .03032 Metetra
1 .324 0 r
.56142 .03032 .59338 .04917 .60766 .04366 .57573 .02538 Metetra
1 .204 0 r
.00626 .16765 .039 .18438 .05157 .18131 .01885 .16388 Metetra
1 .212 0 r
.01885 .16388 .05157 .18131 .06418 .17838 .03149 .1601 Metetra
1 .222 0 r
.03149 .1601 .06418 .17838 .07682 .17564 .04416 .1563 Metetra
1 .235 0 r
.04416 .1563 .07682 .17564 .08951 .17316 .05688 .15249 Metetra
1 .252 0 r
.05688 .15249 .08951 .17316 .10223 .17106 .06963 .14867 Metetra
1 .274 0 r
.06963 .14867 .10223 .17106 .11498 .16954 .08243 .14483 Metetra
1 .304 0 r
.08243 .14483 .11498 .16954 .12775 .16892 .09527 .14099 Metetra
1 .349 0 r
.09527 .14099 .12775 .16892 .14055 .16984 .10815 .13713 Metetra
1 .417 0 r
.10815 .13713 .14055 .16984 .15334 .17362 .12107 .13326 Metetra
1 .535 0 r
.12107 .13326 .15334 .17362 .16609 .18337 .13403 .12938 Metetra
1 .763 0 r
.13403 .12938 .16609 .18337 .17868 .20704 .14704 .12548 Metetra
.08 1 0 r
.14704 .12548 .17868 .20704 .19098 .25591 .15795 .25125 Metetra
0 .071 1 r
.15795 .25125 .19098 .25591 .20337 .30514 .16904 .379 Metetra
1 0 .915 r
.16904 .379 .20337 .30514 .21622 .32927 .18233 .37545 Metetra
1 0 .69 r
.18233 .37545 .21622 .32927 .22933 .33926 .19566 .37189 Metetra
1 0 .576 r
.19566 .37189 .22933 .33926 .24258 .34305 .20904 .36832 Metetra
1 0 .513 r
.20904 .36832 .24258 .34305 .25592 .34374 .22247 .36473 Metetra
1 0 .476 r
.22247 .36473 .25592 .34374 .26932 .34266 .23593 .36113 Metetra
1 0 .455 r
.23593 .36113 .26932 .34266 .28279 .34039 .24945 .35752 Metetra
1 0 .446 r
.24945 .35752 .28279 .34039 .29631 .33718 .26301 .35389 Metetra
1 0 .446 r
.26301 .35389 .29631 .33718 .30988 .33312 .27661 .35026 Metetra
1 0 .455 r
.27661 .35026 .30988 .33312 .32351 .32811 .29026 .34661 Metetra
1 0 .476 r
.29026 .34661 .32351 .32811 .33719 .3219 .30395 .34295 Metetra
1 0 .513 r
.30395 .34295 .33719 .3219 .35093 .31387 .3177 .33928 Metetra
1 0 .576 r
.3177 .33928 .35093 .31387 .36472 .30268 .33148 .33559 Metetra
1 0 .69 r
.33148 .33559 .36472 .30268 .37859 .28513 .34532 .33189 Metetra
1 0 .915 r
.34532 .33189 .37859 .28513 .39257 .25306 .3592 .32818 Metetra
0 .071 1 r
.3592 .32818 .39257 .25306 .40667 .19513 .37395 .19 Metetra
.08 1 0 r
.37395 .19 .40667 .19513 .42074 .13726 .38857 .05312 Metetra
1 .763 0 r
.38857 .05312 .42074 .13726 .43471 .10502 .40242 .04897 Metetra
1 .535 0 r
.40242 .04897 .43471 .10502 .44865 .08698 .41631 .04481 Metetra
1 .417 0 r
.41631 .04481 .44865 .08698 .46261 .07506 .43025 .04063 Metetra
1 .349 0 r
.43025 .04063 .46261 .07506 .47659 .06605 .44423 .03644 Metetra
1 .304 0 r
.44423 .03644 .47659 .06605 .49062 .05862 .45826 .03224 Metetra
1 .274 0 r
.45826 .03224 .49062 .05862 .50469 .05211 .47234 .02802 Metetra
1 .252 0 r
.47234 .02802 .50469 .05211 .5188 .04619 .48647 .02379 Metetra
1 .235 0 r
.48647 .02379 .5188 .04619 .53296 .04065 .50065 .01954 Metetra
1 .222 0 r
.50065 .01954 .53296 .04065 .54717 .03539 .51487 .01528 Metetra
1 .212 0 r
.51487 .01528 .54717 .03539 .56142 .03032 .52914 .011 Metetra
1 .204 0 r
.52914 .011 .56142 .03032 .57573 .02538 .54346 .00671 Metetra
0 g
.25 Mabswid
.00641 .16132 m
.54345 0 L
s
.05701 .14612 m
.05688 .1524 L
s
[(-2)] .05728 .13356 -0.02139 1 Mshowa
.16019 .11513 m
.16009 .12141 L
s
[(-1)] .1604 .10256 -0.01646 1 Mshowa
.26609 .08332 m
.26602 .0896 L
s
[(0)] .26623 .07075 -0.01139 1 Mshowa
.37481 .05066 m
.37477 .05694 L
s
[(1)] .37489 .03809 -0.00617 1 Mshowa
.48648 .01711 m
.48647 .0234 L
s
[(2)] .48649 .00455 -0.00078 1 Mshowa
gsave
.26695 .00792 -65.943 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{249.25, 144},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003i0000T2000`400?l00000o`00003on@3oool0
0?T0oooo003i0?ooo`00n@3oool007/0oooo1000001j0?ooo`00B03oool2000000030?ooo`000000
000002h0oooo00<000000?ooo`3oool0N`3oool004T0oooo00<000000?ooo`000000<03oool00`00
0000oooo0?ooo`0n0?ooo`800000>P3oool004X0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo03P0oooo00180?ooo`80000000<0oooo000000000000
;P3oool010000000oooo0?ooo`0000100?ooo`030000003oool0oooo03L0oooo001l0?ooo`800000
@03oool00`000000oooo0000000h0?ooo`00_@3oool010000000oooo0?ooo`00000h0?ooo`00R@3o
ool300000300oooo0`0000000`3oool000000000000g0?ooo`00H@3oool500000200oooo0`000003
0?ooo`800000J`3oool006<0oooo00<000000?ooo`3oool0703oool4000000<0oooo0P0000030?oo
o`800000J@3oool006<0oooo00<000000?ooo`3oool06@3oool3000000@0oooo0`0000020?ld0080
00000`3oool3000006H0oooo001S0?ooo`030000003oool0oooo01H0oooo0`0000030?ooo`@00000
0P3o=P02000000<0oc@00P0000040?ooo`800000I03oool006<0oooo00<000000?ooo`3oool04P3o
ool4000000030?ooo`000000oooo00<000000P3o>002000000@0ocH00P0000030?ld00800000103o
ool300000640oooo001R0?ooo`8000004@3oool3000000@0oooo0`0000020?ll008000000`3o>002
000000@0ocH00P0000020?ld008000001P3oool2000005l0oooo001b0?ooo`<00000103oool30000
0080od000P0000030?ll00030000003o>000ocP00080ocP00P0000030?lf00<000000P3oDP020000
00H0oooo0P00000G0?ooo`D00000@@3oool004T0oooo0P00000S0?ooo`@000000`3oool400000080
odH00P0000030?m000040000003o?000oc`00?ll00800000103o>00300000080oeT00P0000030?mB
008000001P3oool3000001H0oooo00<000000?ooo`3oool0@@3oool004P0oooo00@000000?ooo`3o
ool000007`3oool3000000@0oooo0`0000020?m=00030000003oAP00odH000<0odH000D000000?m0
003o@000od00000000040?ll0080000000@0ocP0000000000000of000P0000030?mI00030000003o
DP00oe800080oe800P0000070?ooo`800000503oool00`000000oooo0?ooo`110?ooo`00B03oool0
10000000oooo0?ooo`00000L0?ooo`<00000103oool300000080oeT000@000000?m=003oC@00odd0
0P0000040?m600040000003o@000od000?m0008000000`3o?002000000D0of0000D000000?mI003o
F@00oeT0000000050?mB008000001`3oool300000140oooo00<000000?ooo`3oool0@@3oool004P0
oooo00@000000?ooo`3oool00000603oool4000000030?ooo`000000000000@000000P3oJP001000
0000oeT00?mI003oF@02000000<0odd000<000000?m6003oAP000P3oAP0200000080od0010000002
0?mY00800000103oH00010000000oeT00?mI003oF@0200000080oe800P0000000`3oK`0000000000
00080?ooo`8000003`3oool00`000000oooo0?ooo`110?ooo`00B03oool010000000oooo0?ooo`00
000E0?ooo`<000000P3oool300000080ol<000@000000?n8003oR00000000`3oJP000`000000oeT0
0?mI00020?mI00050000003oC@00odd00?m=000000001@3oAP0200000080ogH00P0000040?mY0080
00000`3oH00200000080oeT00`0000050?m_00800000203oool2000000`0oooo0P0000130?ooo`00
B@3oool2000001<0oooo0`0000020?ooo`040000003oool0oooo000000@0ol<000D000000?n8003o
R000ohP0000000030?mZ00030000003oF@00oeT00080oeT000@000000?m=003oC@00odd00P000000
103oAP0000000000003oQ@02000000<0ogH000<000000?mY003oJ@000`3oJ@0200000080of000`00
00020?mi008000001P3oK`02000000P0oooo0`00001>0?ooo`00FP3oool4000000P0oooo0P000004
0?o300040000003oR000ohP0000000@0ofX000<000000?mI003oF@000P3oF@0200000080odd00P00
00050?n500040000003oMP00ogH00?mf008000001@3oJ@0200000080oh@00P0000030?mi00800000
1P3oK`000`000000oooo0?ooo`080?ooo`800000C03oool005L0oooo0`00000<0?ooo`800000103o
``001@000000ohP00?n8003oR000000000@0ofX000<000000?mI003oF@000`3oF@0200000080oiX0
0P0000040?n500030000003oMP00ogH00080ogH00P000000103oJ@0000000000003oT`02000000<0
oh@00P0000030?mi008000000P3oK`02000000030?n900000000000000X0oooo0`0000190?ooo`00
<`3oool5000001`0oooo0`00000?0?ooo`030000000Do`00000000@0ol<000D000000?n8003oR000
ohP0000000040?mZ00030000003oF@00oeT00080000000<0okP00000003oVP000`3oVP000`000000
ohD00?n500020?n5008000000`3oMP02000000D0oi<000<000000?n4003oQ0000P3oQ002000000<0
ogT00P0000050?n9008000002`3oool2000004L0oooo000e0?ooo`030000003oool0oooo01P0oooo
1000000B0?ooo`030000000Do`00000000@0ol<000<000000?n8003oR0000P3oR0000`000000ofX0
0?mZ00020?mZ00800000103o^0000`000000oiX00?nJ00020?nJ00030000003oQ@00ohD000<0ohD0
0`0000020?nU00800000103oT`000`000000oh@00?n400030?n400<000000P3oUP02000000D0ohT0
0P00000;0?ooo`800000A@3oool003D0oooo00<000000?ooo`3oool05@3oool3000001D0oooo00@0
000001Co000Do`0000001@3o``001@000000ohP00?n8003oR000000000<0ofX000<000000?oT0000
00001@3o^002000000<0oiX00P000000103oQ@0000000000003o_002000000@0ojD00P0000030?nC
0080000000@0oh@0000000000000oj@00P0000040?nF008000001@3oR@000`000000oooo0?ooo`0:
0?ooo`<00000@P3oool002d0oooo100000040?ooo`030000003oool0oooo0180oooo0`00000H0?oo
o`050000000Do`005?l001Co00000000103o``000`000000ohP00?n800020?n800030000003oJP00
000000<0on@000<000000?nh003o^000103o^0000`000000oiX00?nJ00020?nJ00030000003o_000
ok`000<0ok`000<000000?nU003oY@000`3oY@0200000080oi<00P0000050?nT00800000103oUP02
000000040?n90000000000000?nP008000002`3oool010000000oooo0000000000100?ooo`00=@3o
ool00`000000oooo0?ooo`0>0?ooo`D000006P3oool01@0000005?l001Co000Do`00000000D0ol<0
00<000000?n8003oR0000P3oR0000`000000on@00?oT00030?oT00030000003o^000okP000@0okP0
00D000000?nJ0000000000000?oI0002000000@0ok`00P0000050?nU008000000P3o]P02000000D0
oj@00P0000030?nF00<00000103oX002000000T0oooo00@000000?ooo`3oool0oooo0`00000m0?oo
o`00=03oool2000000d0oooo0`0000040?ooo`030000003oool0oooo01P0oooo00<0000001Co000D
o`000P0Do`000`000000ol<00?o300020?o300070000003oR000ohP00?n800000000eol000000005
0?oT008000001@3o^0000`000000omT00?oI00030?oI00030000003o_000ok`000<0ok`00P000000
103oY@0000000000003oc002000000<0okH00P0000050?nT00<000000`3o[P02000000@0oj000P00
000>0?ooo`800000>`3oool00400oooo0`00000R0?ooo`030000000Do`005?l000805?l000<00000
0?o3003o``000`3o``000`000000ohP0000000030=Oo00030000003oi000on@000@0on@000L00000
0?nh003o^000okP00000003no`00000000D0omT000<000000?nl003o_000103o_0000`000000ol`0
0?o<00030?o<00030000003o]P00okH00080okH00P0000020?nT0080000000<0okh0000000000000
103o[P02000000<0oj000`00000>0?ooo`800000>@3oool001`0oooo1000000L0?ooo`@000009@3o
ool00`0000005?l001Co000201Co00030000003o``00ol<000<0ol<000<000000?n800000000103G
o`000`000000on@00?oT00040?oT00030000003o^000000000<0o_l000<000000?oI003of@000`3o
f@0200000080ok`00P0000000`3oiP000000000000040?o<00030000003o]P00okH000<0okH00P00
00050?nn00800000103o[P03000000<0ok<00P00000>0?ooo`<00000=P3oool001`0oooo00<00000
0?ooo`3oool06P3oool3000002T0oooo00<0000001Co000Do`000`0Do`000`000000ol<00?o30003
0?o300030000003Go`00eol000@0eol000<000000?oT003oi000103oi0000`000000o_l00?ko0003
0?ko008000001@3of@02000000D0onH000<000000?o<003oc0000P3oc002000000040?nf00000000
00000?oB008000001P3o_P02000000040?n^0000000000000?o200800000103o/`02000000l0oooo
0P00000F0?ooo`@000006P3oool001d0oooo00<000000?ooo`3oool05P3oool3000002`0oooo00<0
000001Co000Do`000`0Do`000`000000ol<00?o300030?o3008000001P3Go`000`000000on@00?oT
00020?oT000300000039o`00000000H0o_l000H000000?oI003of@00omT00000003ho`02000000D0
onH000<000000?o<003oc0000`3oc002000000@0om800P0000060?nn00030000003o`P00ol8000<0
ol800P0000040?nc008000003`3oool3000001<0oooo00<000000?ooo`3oool06`3oool001H0oooo
100000040?ooo`030000003oool0oooo0140oooo1000000_0?ooo`030000000Do`005?l000@05?l0
00D000000?o3003o``00ol<00000000206Ko00030000003Go`00eol000@0eol000@000000?oT003o
i00000000`39o`000`000000o_l00?ko00040?ko00030000003of@00000000@0n?l000<000000?oV
003oiP000`3oiP02000000030?o<0000000000000080onT00P0000040?oB008000000P3o_P020000
00030?oC00000000000000D0ol800P000000103o/`0000000000003o``0200000100oooo0P00000B
0?ooo`030000003oool0oooo01X0oooo000L0?ooo`040000003oool0oooo000000l0oooo1000000b
0?ooo`030000000Do`005?l000@05?l000D000000?o3003o``00ol<00000000306Ko00030000003G
o`00eol000@0eol000<000000?oT000000001039o`02000000D0o_l000<000000?So003ho`00103h
o`02000000D0onH00P0000050?oY008000000`3odP03000000D0om<00P0000050?o200800000103o
``0200000100oooo0P00000A0?ooo`030000003oool0oooo01T0oooo000M0?ooo`8000003@3oool3
000000<0oooo00<000000?ooo`3oool0;`3oool00`0000005?l001Co000501Co00040000003o``00
ol<0000000@0I_l000<000000=Oo003Go`001@3Go`000`000000bOl00<Wo00050<Wo00060000003n
o`00o_l00?ko00000000c_l00P0000060?So0080000000<0onH00000000000000P3jo`02000000D0
onT00`0000030?oX008000001@3od`02000000030?o20000000000000080om800P0000040?o30080
0000403oool3000000`0oooo00@000000?ooo`3oool000006P3oool002P0oooo100000020?ooo`80
0000=03oool00`0000005?l001Co000601Co00030000003o``00000000D0I_l000<000000=Oo003G
o`000`3Go`0010000000POl00000000000060<Wo00030000003no`00000000@0c_l00P0000060?So
00030000003jo`00n_l000@0n_l00P0000020?oY0080000000<0ool0000000000000103oj0020000
00@0om<00`0000050?oB008000000`3o``0300000140oooo0P00000;0?ooo`8000006`3oool002D0
oooo0`0000030?ooo`<0000000<0ol<00000003oool0<`3oool00`0000005?l001Co000601Co0003
0000003o``00000000H0I_l000D000000=Oo003Go`00eol000000004087o000300000039o`00bOl0
00@0bOl000<000000<ko003>o`001@3>o`0200000080n?l00P0000000`3Ho`000000000000060?[o
008000001@3oo`02000000@0onP0100000030?oT008000001@3odP03000000<0oll00P00000A0?oo
o`<000009@3oool00280oooo0`0000030?ooo`<000000P3oR00010000000ol<000000000000c0?oo
o`030000000Do`005?l000L05?l000<0000006Ko001Vo`001P1Vo`000`000000eol000000006087o
000300000039o`00bOl00080bOl000@0000009[o0000000000001`3>o`02000000D0f?l00P000004
0?[o00040000003To`000000000000D0ool00P000000103oj00000000000003on002000000D0on@0
0P0000020?oB0080000000<0omh0000000000000103oc`0200000180oooo0P00000S0?ooo`007P3o
ool4000000<0oooo0`0000020?mZ00050000003oR000ohP00000003o``000P00000c0?ooo`030000
000Do`005?l000L05?l000<0000006Ko001Vo`001`1Vo`000`000000POl0087o0006087o00800000
00<0bOl00000002Jo`000`2Jo`02000000@0c_l000@000000;3o0000000000001P3Ho`0200000003
0?[o00000000i?l000<0i?l00P0000050?oo00800000103on002000000D0on@00`0000040?oN0080
0000103oc`0300000140oooo0P00000Q0?ooo`006`3oool3000000030?ooo`000000000000@00000
0P3oF@001@000000ofX00?mZ003oJP0000000080ohP00`00000c0?ooo`030000000Do`005?l000L0
5?l00P00000706Ko00040000000No`000000000000P0POl000<0000009[o002Jo`001@2Jo`020000
00030<ko00000000/?l000<0/?l00P0000060=So008000001P3To`02000000030?oo000000000000
0080l?l00P0000040?oh008000000P3oi00200000080oo000P0000040?oN0080000000<0oll00000
000000000P3of00200000140oooo0`00000N0?ooo`00603oool4000000030?ooo`00000000000080
odH000@000000?m=003oC@0000000`3oF@001@000000ofX00?mZ003oJP0000000080ohP00`00000b
0?ooo`030000000Do`005?l000L05?l000<00000003oD`0000001P1Vo`001@0000007_l001ko000N
o`00000000H0POl000@0000005Wo0000000000001`2Jo`02000000H0/?l00P0000020=So00800000
0P35o`02000000H0i?l00P0000050?3o008000000`3on003000000H0oo000P0000030?oN00<00000
1@3of00200000180oooo0P00000L0?ooo`00503oool400000080oooo0`0000000`3o@00000000000
00020?m60080000000<0odd00000000000000P3oF@001P000000ofX00?mZ003oJP0000000?n800<0
0000<P3oool00`0000005?l001Co000601Co000400000000oe<00?mC003oD`8000000`1Vo`000`00
00007_l001ko000301ko008000000`21o`000`000000FOl005Wo000205Wo00800000102Jo`000`00
0000POl0087o0002000000H0/?l00`0000050<Go008000000P3To`0200000080eol00P0000050?3o
00<000000`3lo`02000000H0oo000`0000030?oW008000001@3of00300000140oooo0`00000I0?oo
o`004@3oool3000000<0oooo0`0000020?ll008000000P3o@0001@000000odH00?m6003oAP000000
0080odd000<000000?mI003oF@000P0000001`3oJP0000000?n8003oR000000001Co00000000<@3o
ool00`0000005?l001Co000601Co000300000000oe<00?mC00<00?mC00@0000006Ko001Vo`000000
1`0No`0200000003087o00000000FOl000D0FOl00P0000000`2Jo`000000087o0004087o00800000
0`2`o`0200000080X?l00P0000050<Go00<000001@3Go`0200000080l?l00P0000020>Oo00800000
0`3lo`02000000<0oo000P0000000`3on0000000000000040?oW008000000P3of00200000080oml0
0P00000@0?ooo`040000003oool00000000001L0oooo000?0?ooo`8000000`3oool300000080ocP0
0P0000030?ll00030000003o@000od00008000000P3oAP0010000000odd00?m=000000030?mI0007
0000003oJP0000000?n8000000005?l00000000a0?ooo`030000000Do`005?l000H05?l000<00000
003oD`00oe<01000oe<2000000X07_l000<0000005Wo001Io`001`1Io`02000000L0POl00`000006
0:3o008000000P35o`0200000080^_l00P0000050=Oo00<000001@3Wo`02000000<0o?l00`000005
0?oh00800000103oi`02000000H0oml00P00000B0?ooo`8000005@3oool000l0oooo00<000000?oo
o`0000000P0000020?lf008000000`3o>00200000080oc`000@000000?m0003o@000od000P000000
103oAP0000000000003oC@0200000080oeT000H000000?mZ00000000000001Co0000000a0?ooo`03
0000000Do`005?l000H05?l000<00000003oD`00oe<01@00oe<00`0000007_l001ko000701ko0004
0000000;o`000000000000H0FOl000<0000004[o001:o`000P000005087o00040000001go`000000
000000L0X?l00`0000050;[o008000000P3Go`0200000080col00P0000050>Oo00<000000`3eo`02
000000D0ooP0100000020?o^008000001P3og`0200000180oooo0`00000B0?ooo`003`3oool20000
0080oc@00P0000030?lf008000000`3o>002000000030?ll0000000000000080od003@00000201Co
00030000003oool0oooo02d0oooo00<0000001Co000Do`001P0Do`000`0000000?mC003oD`06003o
D`<000001`0No`00100000002ol000_o000;o`02000000<0FOl000<0000004[o001:o`000`1:o`02
00000080POl000<0000007Oo001go`000P1go`02000000D0X?l000<0000009Wo002Io`000P000005
0;[o00<000001@3?o`0200000080iol00P0000020>7o008000000`3eo`0200000080ooP00P000002
0?om008000000`3okP02000000<0oml00P0000000`3oi00000000000000C0?ooo`800000403oool0
00l0oooo00@000000?ooo`00000000000P3o=002000000<0ocH00P0000020?lh00H000000P3oMP02
000000050?n50000000000000?nJ000000000P3o^002000000805?l000<000000?ooo`3oool0;@3o
ool00`0000005?l001Co000601Co000300000000oe<00?mC00D00?mC00@00000003oG000oe`00?mL
0P00000401ko00030000000;o`002ol000@02ol00P0000000`1Io`00000004[o000604[o00<00000
1P1go`02000000030:3o00000000000000D0VOl00P0000020;[o008000000P2do`02000000D0col0
0`0000050>7o008000000`3eo`03000000D0ood00P0000030?o^00<000001@3oi002000001<0oooo
0`00000=0?ooo`003`3oool010000000oooo0?ooo`3oool200000080oc@00P0000020?lf00<00000
0P3oH002000000030?mY00000000000000<0ogH000H000000?n5003oQ@0000000?nJ000000020?nh
00040000000Do`005?l0000002l0oooo00<0000001Co000Do`001P0Do`000`0000000?mC003oD`05
003oD`0300000000oe`00?mL00<00?mL0P00000201ko00030000000;o`002ol000H02ol00P000007
04[o000300000018o`00B?l0008000001P1go`02000000P0VOl00`0000050;Co008000000P3?o`02
00000080c?l00P0000050>7o00<000000`3ao`02000000D0ood00`0000030?oa00@000000`3oi003
000001<0oooo0P00000;0?ooo`003`3oool00`000000oooo0?ooo`030?ooo`H000000P3oF@020000
00<0of0000<000000?mY003oJ@000P0000020?mf00050000003oQ@00ohD00000003oVP000`000003
01Co00030000003oool0oooo02`0oooo00<0000001Co000Do`001P0Do`000`0000000?mC003oD`04
003oD`0300000000oe`00?mL00H00?mL0`00000700_o00030000000<o`003?l000@000000P1:o`00
0`000000B?l004So000304So008000000P1go`0200000080MOl01000000309Wo008000000P2Ho`02
000000D0]?l00`0000050<co008000000P3Qo`0200000080gol00P0000030?7o008000000P3oo@02
00000080ool00P0000050?oa00<000000`3oi`02000001<0oooo0P0000090?ooo`003`3oool00`00
0000oooo0?ooo`050?ooo`80000000<0oe800000000000000`3oF@0200000080of000P0000020?mY
0080000000@0ogH0000000000000ohD00P0000000`3oVP00000001Co000201Co00800000;@3oool0
0`0000005?l001Co000501Co000300000000oe<00?mC00D00?mC00<00000003oG000oe`01P00oe`0
0`0000000?m=003oC@04000000802ol000<0000000co000<o`001@0<o`03000000L0B?l00`000007
07Go00<000001P2Ho`0200000080]?l00P0000020;Co008000001@3<o`02000000H0gol00P000003
0?7o00<000001@3oo`0200000080oo400P0000020?oc008000000`3oi`02000001<0oooo0P000007
0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`80000000<0oe800000000000000`3oF@020000
0080of000P0000020?mY00T000000`0Do`02000002`0oooo1000000401Co000300000000oe<00?mC
00D00?mC00<00000003oG000oe`01@00oe`00`0000000?m=003oC@05003oC@<000001`0<o`000`00
00005ol001Oo0002000000D0B?l000<0000004ko001>o`000P00000507Go00030000001io`00NOl0
008000001P2Ho`02000000H0]?l00P0000020<co0080000000<0bol00000000000001P3Oo`030000
00<0kol0100000030?oo008000001P3ol`02000000<0onL00P00000J0?ooo`003`3oool00`000000
oooo0?ooo`090?ooo`80000000<0oe800000000000000`3oF@06000000040?nC0000000000000?nU
0080000000<0ok`00000000000000`0Do`000`000000I_l00000000[0?ooo`04000000004_l001;o
000Bo`P000000`00oe<00`0000000?mL003oG006003oG00300000000odd00?m=00D00?m=00<00000
003o=P00ocH00P00000400co00030000000Go`005ol000<05ol00P00000204So00030000001>o`00
C_l000<0C_l00P00000207Go00030000001io`00NOl000<0NOl00P00000309So0080000000<0Vol0
0000000000001P2do`03000000@0bol00P0000030=oo0080000000<0gol00000000000001P3_o`03
00000080o_l00P0000060?oc00<000000P3oj002000001P0oooo000?0?ooo`030000003oool0oooo
00/0oooo1P0000020?mi0080000000<0oh@00000000000000P3oT`001P000000ojD00?nU00000000
ok`0000000<05?l000<0000006Ko00000000:`3oool00`00000001;o000Bo`05000Bo`0400000000
a_l00<Ko0036o`L000001000oe`00`0000000?m=003oC@06003oC@0300000000ocH00?lf00800?lf
0P00000200co00030000000Go`005ol000D05ol00`00000704ko00<000001`1io`03000000D0Vol0
0P0000030;Co008000000P2fo`03000000<0bol00`0000050=oo008000000`3_o`02000000030?3o
00000000000000<0o_l00P0000030?oc0080000000<0oo@00000000000000`3oj002000001H0oooo
000?0?ooo`030000003oool0oooo00d0oooo0P0000020?m_008000000P3oN@02000000040?n40000
000000000?nC0080000000<0ojD0000000000000100Do`000`000000I_l00000000Z0?ooo`030000
00004_l001;o00@001;o00<000000036o`00a_l01@00a_l0100000000?oS003oh`00on<5000000L0
0?m=00<00000003o=P00ocH01@00ocH5000000@05ol00P00000202Go00@000000P1>o`0200000080
F?l01000000207Wo008000000P20o`04000000<0Vol00`0000070;Ko00<000000`3=o`04000000<0
gol00`0000050?3o008000000`3no`03000000D0oo@00P0000030?oX00<000004`3oool000l0oooo
00<000000?ooo`3oool03`3oool200000080ofl00P0000020?mi0080000000@0oh@0000000000000
oi<00`00000401Co00030000001Vo`00I_l000800000:03oool00`00000001;o000Bo`04000Bo`03
00000000a_l00<Ko00@00<Ko00<00000003oh`00on<01000on<00`0000000?nY003oZ@04000000<0
0?m=00<00000003o=P00ocH01@00ocH00`0000000?lM003o7@02003o7@D000001`0Uo`03000000L0
F?l00`000007083o00<000000`2Po`0400000080]_l00P0000020;_o008000001@3=o`03000000<0
hOl0100000030?3o00<000000`3no`04000000<0oo@00`0000030?oY00@000003`3oool000l0oooo
00<000000?ooo`3oool04@3oool200000080ofl02`00000401Co008000000P1Vo`02000002L0oooo
00<00000000Bo`004_l010004_l00`0000000<Ko0036o`040036o`0300000000on<00?oS00@00?oS
00<00000003oZ@00ojT01000ojT6000000@00?lf00<00000003o7@00oad01@00oad00`0000000?l4
003o1004000000809Ol00P00000203Oo00@000000P1Ho`0200000080IOl010000002083o00800000
0P29o`02000000D0X?l00`0000050;_o008000000P3=o`0200000080dOl00P0000050>7o00<00000
0`3ao`02000000D0o_l00`0000030?od00@000000`3oj@02000000d0oooo000?0?ooo`030000003o
ool0oooo01<0oooo0P0000020?n90080000000@0oiH0000000000000oj@00`00000501Co00<00000
00<0I_l00000000000009@3oool00`00000001;o000Bo`04000Bo`0300000000a_l00<Ko00@00<Ko
00<00000003oh`00on<01000on<00`0000000?nY003oZ@06003oZ@0300000000og/00?mk00800?mk
1`000004003o7@0300000000o`@00?l400D00?l40`00000703Oo00<000001`1Uo`03000000D0ROl0
0P0000020:3o008000000P2Wo`04000000<0^ol00`0000050=7o008000000P3Qo`0200000080i?l0
0P0000030?7o008000000P3no`02000000030?oo00000000000000H0oo@00`0000020?oX00800000
2`3oool000l0oooo00<000000?ooo`3oool05@3oool200000080ohT00P0000001@3oUP0000000000
003oY000000000D05?l000D00000003oD`00oe<0000006Ko0003000002<0oooo00<00000000Bo`00
4_l010004_l00`0000000<Ko0036o`040036o`0300000000on<00?oS00@00?oS00<00000003oZ@00
ojT01@00ojT00`0000000?mk003oN`05003oN`0300000000oe800?mB00800?mB1@000007003o1003
0000000Do`005?l000@000000P0go`0200000080B?l01000000206Go008000000P1bo`04000000<0
ROl00`0000070:Oo00<000000`30o`04000000<0dOl00`0000050>Co008000000`3ao`03000000@0
ool00P0000030?od0080000000<0oo800000000000000`3oj002000000T0oooo000?0?ooo`030000
003oool0oooo01L0oooo0`000000103oR@0000000000003oUP02000000D05?l000@00000003oD`00
oe<00?mC0P0000000`0No`0000000000000R0?ooo`03000000004_l001;o00@001;o00<000000036
o`00a_l01000a_l00`0000000?oS003oh`03003oh`0300000000ojT00?nY00D00?nY00<00000003o
N`00og/01@00og/00`0000000?mB003oDP05003oDP0300000000obd00?l]00@000000P00o`@00`00
00005?l001Co000501Co00<000001`18o`03000000L0L_l00`00000309?o00@000000P2Wo`020000
0080[ol00P0000050<3o00<000000`3Fo`03000000@0i?l00`0000030?Co00<000000`3oo`030000
00D0oo800P0000030?oX008000001`3oool000l0oooo00<000000?ooo`3oool06P3oool6000000D0
5?l000<00000003oD`00oe<00P00oe<20000000401ko00000000000000000200oooo00<00000000B
o`004_l010004_l00`0000000<Ko0036o`030036o`0400000000on<00?oS003ohaH000001000oe80
0`0000000?l]003o;@05003o;@D00000100Do`0200000080;?l01000000204So008000000P1Jo`04
00000080L_l00P00000207oo008000001@2Co`03000000D0[ol00P0000020<3o0080000000<0aol0
0000000000001@3Fo`04000000<0j?l00`0000030?Co00<000000`3oo@04000000<0oo800`000009
0?ooo`003`3oool00`000000oooo0?ooo`0L0?ooo`80000000<0oj000000000000001@0Do`000`00
00000?mC003oD`03003oD`030000000No`00000000<000007P3oool00`00000001;o000Bo`03000B
o`0300000000a_l00<Ko00@00<Ko10000002002Ro`0300000000o_l00?ko00@00?ko00<00000003o
_000ok`01@00ok`00`0000000?n4003oQ002003oQ0L000001000obd2000000@00?l<1@00000702co
00<000001`1Jo`03000000D0Ool00P00000209?o008000000P2No`03000000@0[ol00`0000040<Oo
008000000P3Fo`0200000080fol00P0000050>So00<000000`3ho`04000000<0ood00`00000<0?oo
o`003`3oool00`000000oooo0?ooo`0N0?ooo`<000001@0Do`000`0000000?mC003oD`03003oD`<0
000000<07_l00000000000000P00000L0?ooo`03000000004_l001;o00<001;o00<000000036o`00
a_l00P00a_l2000000D00:;o00<00000003no`00o_l01000o_l00`0000000?nl003o_004003o_080
00001`00oh@00`0000000?mE003oE@02003oE@L000001000o``2000000804Ol01000000202co0080
00000P13o`0400000080F_l00P00000206_o00<00000101oo`03000000H0W_l0100000030;So00<0
00000`37o`03000000D0fol00P0000020>So0080000000<0k?l00000000000001P3ho`03000000l0
oooo000?0?ooo`030000003oool0oooo0200oooo00<0000001Co000Do`000`0Do`000`0000000?mC
003oD`04003oD`0300000000oe`0000000L000006@3oool00`00000001;o000Bo`03000Bo`030000
0000a_l00<Ko0080000000<000go00000000X_l01000X_l00`0000000?ko003no`0>000000D00?n4
00<00000003oE@00oeD01000oeD2000000@00?l/1@000007017o00@000001P13o`03000000H0Jol0
1000000308go00<000000P2No`0200000080ZOl0100000030;So00<000000`3>o`04000000<0fol0
0`0000040>co008000000`3ho`0200000140oooo000?0?ooo`030000003oool0oooo0200oooo00<0
000001Co000Do`000`0Do`000`0000000?mC003oD`04003oD`0400000000oe`00?mL003oG0800000
00<02ol00000000000000`00000G0?ooo`03000000004_l001;o008001;o00@000000036o`000000
00000P003Ol00`0000000:;o002Ro`02002Ro`D000000P00]?l00`0000000?of003omP04003omP03
00000000ok400?na00800?na3`000004003o;08000000P00o`P4000000804Ol00P00000302co00H0
00000`1Ho`0300000080Jol00P00000207co00@000000`2=o`03000000L0ZOl00`0000030<7o00@0
00000`3>o`03000000<0hOl00`0000030>co00<000004`3oool000l0oooo00<000000?ooo`3oool0
803oool4000000<05?l000<00000003oD`00oe<01000oe<00`0000000?mL003oG002003oG0800000
0P0;o`04000001D0oooo00<00000000Bo`004_l00P004_l2000000@000go00<00000002Ro`00X_l0
0`000005002do`0300000000ooH00?of00@00?of00<00000003o/@00ok401@00ok42000000D00?mi
0P000004003oB@H000001P00o`P4000000@0;?l00P00000204Go00@000000`1Ho`03000000L0O?l0
0`00000309[o00@000000P2Yo`0200000080]?l00`0000040<7o00<000000`3Fo`03000000<0hOl0
0`00000F0?ooo`003`3oool00`000000oooo0?ooo`0P0?ooo`04000000004_l001;o000Bo`L00000
0`00oe<00`0000000?mL003oG003003oG0X000004P3oool00`00000001;o000Bo`02000Bo`030000
00003Ol000go008000go00H00000002Ro`00000000000012o`000006002do`0300000000ooH00?of
01D000001@00odT2000000<00?lP1P00000401Oo00D000001`15o`03000000<0Jol01000000207co
008000000P2<o`04000000<0V_l00`0000060;Co00@000000`3:o`03000000<0e_l00`00000I0?oo
o`003`3oool00`000000oooo0?ooo`0P0?ooo`03000000004_l001;o00@001;o00@000000036o`00
a_l00<Ko20000002003oG00400000000odd00?m=003oC@<000000P0<o`03000000h0oooo00<00000
000Bo`004_l00P004_l00`00000000go000=o`03000=o`8000000`00@_l00`0000000;Co002do`07
00000003003Io`000000000000D00?oI0P000006003oV@8000000`00of<7000000@00?lP0P000002
00?o00@000000P0Go`0200000080<ol01000000204Go008000000P1Ko`04000000<0Jol01@000005
08co00<000000`2Wo`0300000080]?l00P0000020;ko008000001@3:o`03000001`0oooo000?0?oo
o`030000003oool0oooo0200oooo00<00000000Bo`004_l01@004_l00`0000000<Ko0036o`040036
o`0400000000on<00?oS003oh`L0000000<00?m=0000000000001P00000<0?ooo`03000000004_l0
01;o008001;o00<00000000=o`003Ol00P003Ol01000000004;o0012o`00@_l500000004001io`00
00000000003IoaD000001000of<2000000@00?ld1`00000500?o00D000001@0co`05000000D0Fol0
0`00000507go00D000000`2Jo`03000000<0Yol00`0000050;ko008000000P3:o`02000001h0oooo
000?0?ooo`030000003oool0oooo0200oooo00<00000000Bo`004_l01@004_l00`0000000<Ko0036
o`050036o`0300000000on<00?oS00@00?oS00<00000003oZ@00ojT0300000090?ooo`0500000000
4_l001;o000Bo`0000000`003Ol20000008004;o0`000003001io`D0000000<00;?o000000000000
1@00ooP2000000D00?nb0P000004003oN0h000000`00o`d7000000<08ol01@00000504go00D00000
0`1`o`03000000<0OOl00P00000208ko00<000000`2Jo`03000000<0/ol0100000030;ko00800000
803oool000l0oooo00<000000?ooo`3oool0803oool00`00000001;o000Bo`05000Bo`0300000000
a_l00<Ko00D00<Ko00<00000003oh`00on<01@00on<00`0000000?nY003oZ@03003oZ@80000000<0
0?mk0000000000001P0000060?ooo`05000000004_l001;o000Bo`0000000P003Ol00`000000H@3o
00000002000000030040o`000000000000@000000`00/olJ000000@00?m60P000004003o6`D00000
1@0Eo`05000000<0?ol01000000204go008000000P1To`03000000<0L?l00`00000708ko00<00000
0`2Xo`04000000<0/ol00`00000R0?ooo`003`3oool00`000000oooo0?ooo`0P0?ooo`0300000000
4_l001;o00D001;o00<000000036o`00a_l01P00a_l00`0000000?oS003oh`04003oh``000000P00
og/700000080oooo00P00000000Bo`004_l001;o000000003Ol000000640o`80000000@00@3o0000
0000000000000`00COl600000003003_o`000000000001<000000`00oe<7000000@00?lK0P000002
00[o00@000000P0Eo`0200000080=?l01000000303oo00@000001@1To`03000000<0Pol010000002
08ko008000000P2No`04000000<0Z?l00`00000U0?ooo`003`3oool00`000000oooo0?ooo`0P0?oo
o`03000000004_l001;o00H001;o00<000000036o`00a_l01@00a_l00`0000000?oS003oh`040000
00800:;o00<00000003no`00o_l01000o_l200000003003o_0000000000000X000000P004_l30000
00030640o`0000000@3o00<000000`00COl300000003002Go`000000000000<0000000@00=oo0000
000000000?oC1`000004003oT`8000001000oe`7000000<00?lU1`00000500[o00D000001@0do`04
000000<0F?l01@00000307So00@000000`23o`04000000H0W_l00`00000X0?ooo`003`3oool00`00
0000oooo0?ooo`0Q0?ooo`03000000004_l001;o00D001;o00<000000036o`00a_l01P00a_l20000
00L00:;o00<00000003no`00o_l00P00o_l@0000008001;o00<000000640o`0000000`0000000`0`
0?l000000000000800000003003Oo`000000000000T000000`00oiP>000000<00?l]1`000003007o
00H00000100Zo`05000000@0Col01@00000306oo00@000000`1ho`03000000@0U?l01P00000[0?oo
o`003`3oool00`000000oooo0?ooo`0Q0?ooo`03000000004_l001;o00D001;o00<000000036o`00
a_l01000a_l200000003000=o`0000000:;o00H00:;o1@000004002do`8000001@00ooH500000003
000Bo`000000H@3o008000000P0`0?l300000003000]o`0000000000020000000`00oc47000000<0
0?l41P00000302?o00H000000`17o`0300000080Col00P00000206Oo00@000000`1_o`03000000<0
Rol00`00000209Co00800000;P3oool000h0oooo00<000000?ooo`3oool08P3oool00`00000001;o
000Bo`05000Bo`0300000000a_l00<Ko00800<Ko0P000003000=o`0300000000X_l00:;o00<00:;o
0P0000020012o`0300000000]?l00;Co00D00;Co1P000003003Io`80000000<001;o000000000000
0P0`0?lU000000<00?la1`000003003o1`H000000`0No`05000000<0@Ol01000000304Oo00D00000
1@1Wo`03000000<0Pol00`00000308_o00800000<03oool000h0oooo00<000000?ooo`3oool08P3o
ool00`00000001;o000Bo`06000Bo`0400000000a_l00000000000H000go00<00000002Ro`00X_l0
0P0000050012o`0300000000]?l00;Co00@000000`00NOl600000003002co`000000000002<00000
0`00obD:000000<00?l71P00000301_o00L0000000<0??l00000000000000P000003047o00D00000
0`1Po`05000000<0O?l00`00000308?o00<00000<P3oool000h0oooo00<000000?ooo`3oool08P3o
ool00`00000001;o000Bo`06000Bo`8000002@003Ol2000000L004;o0`000003001io`@000000`00
COl400000003000Bo`000000000002T000000`01o`09000000<06ol01`00000303[o00X000000`1K
o`05000000<0Mol00`00000307co00<00000=@3oool000h0oooo00<000000?ooo`3oool08P3oool0
0`00000001;o000Bo`06000Bo`03000000003Ol000go00L000go00<000000640o`0000001@00@_l2
000000<00@3o0`000003001=o`P0000000<001;o0000000000000P000000103Oo`0000000000003=
o`0L0000000302?o00000000000000X000000`0So`0:000000<0>_l01@00000305Ko00@0000000<0
Eol00000000000000`00000307;o00<000000`1go`03000003P0oooo000>0?ooo`030000003oool0
oooo0280oooo00<00000000Bo`004_l01@004_l00`000000o`3Z00000006000=o`8000000`1Q0?l0
0`00000004;o0012o`02000000<00@3o0P0000030300o``0000000@0ool0000000000000kol00P00
00000`3Oo`000000000000030<go01`000000P0oo`030000000303Co00000000000000P0000000<0
@Ol00000000000000P0000000`0lo`000000000000050000000305Ko000000000000008000000`1F
o`0400000080Kol00`00000307;o00<00000>`3oool000h0oooo00<000000?ooo`3oool08P3oool0
0`00000001;o000Bo`05000Bo`030000003o0>X0000000D000go00<000000640o`1Q0?l0101Q0?l2
000000<00@3o0P0000030300o`80000000@0C`3o000000000000HP3o500000030=7o0080000000@0
`?l0000000000000[ol03`0000000`1Ko`0000000000000;0000000304oo00000000000000800000
00<0Aol00000000000002000000305Oo00T000000`1^o`08000003h0oooo000>0?ooo`030000003o
ool0oooo0280oooo00<00000000Bo`004_l010004_l01@000000o`3Z0?l0jP3o0>X0000000<000go
00<000000640o`1Q0?l00`1Q0?l200000080XP3o0`0000030300o`80000000@0C`3o000000000000
HP3o1`0000000`3o0>X000000?oW0002000000040?oc0000000000000?ko00X0000000@0dOl00000
00000000`?l00P0000030:oo0100000000<0L?l00000000000001@0000000`1Ho`00000000000008
00000004063o00000000000000000080Fol01@00000306oo00<0000000<0K_l00000000000000`00
00140?ooo`003P3oool00`000000oooo0?ooo`0R0?ooo`03000000004_l001;o00@001;o00H00000
0?l0jP3o0>X0o`3Z000000003Ol2000000D0H@3o00@000000:80o`2R0?l0XP3o0P0000020<T0o`d0
00000P3o0;08000000030?oc00000000000000<0o_l03`0000030;So00`0000000<0OOl000000000
00002`0000000`1_o`000000000000020000000306Oo00000000000000L000000P1bo`03000000<0
Kol00`0000170?ooo`003P3oool00`000000oooo0?ooo`0R0?ooo`03000000004_l001;o00<001;o
00<000000?l0jP3o0>X00`3o0>X00`000000H@3o0640o`030640o`8000000`2R0?l010000000b@3o
0<T0o`390?l2000000030>80o`000000000000P0000000@0o`2`00000000000000001@3oool80000
00<0o_l00P0000000`3ao`0000000000000:000000<0^?l03P0000000`2>o`000000000000050000
000307So00000000000000L000000P1lo`030000000307Oo00000000000000H00000BP3oool000h0
oooo00<000000?ooo`3oool08P3oool00`00000001;o000Bo`03000Bo`030000003o0>X0o`3Z0080
o`3Z00D000000?l0/000000000000640o`02000000<0XP3o0P0000020<T0o`80000000<0hP3o0000
000000002`00000:0?ooo`80000000<0onP00000000000001@0000000`3no`000000000000030?7o
00/000000`31o`0:0000000309[o00000000000000X000000P2;o`030000000308?o000000000000
00H00000D03oool000h0oooo00<000000?ooo`3oool08P3oool00`00000001;o000Bo`02000Bo`03
0000003o0>X0o`3Z0080o`3Z00<000000?l0/03o0;000P3o0;0200000080XP3o0P0000020<T0o`80
000000<0hP3o0000000000002@00000@0?ooo`8000000`3oj00900000080m?l00P0000020>So00T0
00000`31o`09000000<0Z?l01P0000000`2Do`00000000000006000005H0oooo000>0?ooo`030000
003oool0oooo0280oooo00<00000000Bo`004_l00P004_l00`000000o`3Z0?l0jP020?l0jP050000
003o0;00o`2`0?l0/00000000P3o09<A000001D0oooo0`0000030?oY0080000000<0oo@000000000
0000100000000`3do`000000000000030>So00T000000`3:o`09000000<0Z?l01P00001L0?ooo`00
3P3oool00`000000oooo0?ooo`0S0?ooo`04000000004_l001;o000000@0o`3Z00D000000?l0/03o
0;00o`2`000000030?l0T`050000003o08<000000000003o07T02@00000K0?ooo`@0000000<0onT0
0000000000000`3om008000000<0k?l02P0000020<[o00T00000HP3oool000h0oooo00<000000?oo
o`3oool08`3oool01000000001;o000Bo`0000030?l0jP050000003o0;00o`2`0?l0/00000000P3o
09<2000000030?l0P`000000o`1i00D000009@3oool6000000<0oo802@0000030>co00T00000JP3o
ool000h0oooo00<000000?ooo`3oool08`3oool00`00000001;o000000030?l0jP030000003o0;00
o`2`008000000P3o09<00`000000o`2300000005000002/0oooo1P0000030?ob00T00000L`3oool0
00h0oooo00<000000?ooo`3oool08`3oool00`00000001;o000000020?l0jP040000003o0;00o`2`
000000<0o`2C1P00000a0?ooo`H00000O03oool000h0oooo00<000000?ooo`3oool08`3oool20000
00<0o`3Z00<000000?l0/00000000P3o09<500000;H0oooo000>0?ooo`030000003oool0oooo02<0
oooo0P0000020?l0jPL00000^P3oool000h0oooo00<000000?ooo`3oool08`3oool00`000000o`3Z
0000000200000<00oooo000>0?ooo`030000003oool0oooo02<0oooo0P0000330?ooo`003P3oool0
0`000000oooo0?ooo`3X0?ooo`003P3oool00`000000oooo0?ooo`3X0?ooo`003P3oool00`000000
oooo0?ooo`3X0?ooo`003P3oool00`000000oooo0?ooo`3X0?ooo`003P3oool00`000000oooo0?oo
o`3X0?ooo`001P3oool5000000<0oooo00<000000?ooo`3oool0j03oool000P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`3X0?ooo`00203oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0>P0oooo00080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
j03oool000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3X0?ooo`001`3oool2
000000D0oooo0P00003Y0?ooo`003P3oool00`000000oooo0?ooo`3X0?ooo`00n@3oool00?T0oooo
003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0
oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool0
0?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3o
ool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 248.25}, {143, 0}} -> {0, 0, 0, 0}}],
  StyleBox["\n\t\tFigure 3.A",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The harmonic function  ",
  Cell[BoxData[
      \(\[Phi] \((x, 
            y)\)\  = \(1\/\[Pi]\) \((arctan  y\/\(x - 1\)\  - \ 
              arctan  y\/\(x + 1\))\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\(\(ExploreHarmonic\  := \ 
        Module[{}, \[IndentingNewLine]\[Phi]\_x\  = \ 
            Together[\[PartialD]\_x\ \[Phi][x, 
                  y]]; \ \[IndentingNewLine]\[Phi]\_xx\  = \ 
            Together[\[PartialD]\_\(x, x\)\ \[Phi][x, 
                  y]]; \ \ \[IndentingNewLine]\[Phi]\_y\  = \ 
            Together[\[PartialD]\_y\ \[Phi][x, 
                  y]]; \ \[IndentingNewLine]\[Phi]\_yy\  = \ 
            Together[\[PartialD]\_\(y, y\)\ \[Phi][x, 
                  y]]; \ \[IndentingNewLine]Print["\<  \[Phi][x,y] = \>"\ , \
\[Phi][x, 
              y]\ ]; \[IndentingNewLine]Print[\*"\"\< \!\(\[Phi]\_x\)[x,y] = \
\>\""\ , \[Phi]\_x\ ]; \[IndentingNewLine]Print[\*"\"\<\!\(\[Phi]\_xx\)[x,y] \
= \>\""\ , \[Phi]\_xx\ ]; \[IndentingNewLine]Print[\*"\"\< \
\!\(\[Phi]\_y\)[x,y] = \>\""\ , \[Phi]\_y\ ]; \
\[IndentingNewLine]Print[\*"\"\<\!\(\[Phi]\_yy\)[x,y] = \>\""\ , \[Phi]\_yy\ \
]; \[IndentingNewLine]Print[\*"\"\<\!\(\[Phi]\_xx\)[x,y] + \
\!\(\[Phi]\_yy\)[x,y] = (\>\""\ , \[Phi]\_xx, "\<) + (\>", \[Phi]\_yy\ , "\<)\
\>"]; \[IndentingNewLine]Print[\*"\"\<\!\(\[Phi]\_xx\)[x,y] + \
\!\(\[Phi]\_yy\)[x,y] = \>\""\ , \[Phi]\_xx\  + \ \[Phi]\_yy\ ];\ ];\)\(\ \
\)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[BoxData[{
    \(\(\[Phi][x_, y_]\  = \ x\^3 - 3\ x\ y\^2;\)\), "\[IndentingNewLine]", 
    \(ExploreHarmonic\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(\[Phi][x_, y_]\  = \ 3\ x\^2\ y - y\^3;\)\), "\[IndentingNewLine]", 
    \(ExploreHarmonic\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(\[Phi][x_, 
          y_]\  = \ \[ExponentialE]\^x\ Cos[y];\)\), "\[IndentingNewLine]", 
    \(ExploreHarmonic\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(\[Phi][x_, 
          y_]\  = \ \[ExponentialE]\^x\ Sin[y];\)\), "\[IndentingNewLine]", 
    \(ExploreHarmonic\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(\[Phi][x_, 
          y_]\  = \(1\/\[Pi]\) \((ArcTan[y\/\(x - 1\)] - 
              ArcTan[y\/\(x + 1\)])\);\)\), "\[IndentingNewLine]", 
    \(ExploreHarmonic\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell["\<\
These pairs of functions are not chosen at random, and there is an intimate \
relationship between them.  We begin with an important theorem relating \
analytic and harmonic functions.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 3.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      RowBox[{\(f \((z)\)\), "=", 
        RowBox[{\(f \((x + iy)\)\), "=", " ", 
          RowBox[{
            RowBox[{"u", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", "v", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}]}]}]}]]],
  "  be an analytic function on a domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  Then both  ",
  Cell[BoxData[
      RowBox[{"u", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{"v", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  are harmonic functions on ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  In other words, the real and imaginary parts of an analytic function \
are harmonic."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Proof.  In Corollary 6.3 we will show that, if f(z) is analytic, then all \
partial derivatives of u and v are continuous.  Using that result here, we \
see that, as ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is analytic, ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " satisfy the Cauchy-Riemann equations \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_x\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        RowBox[{\(v\_y\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  "   and   ",
  Cell[BoxData[
      RowBox[{\(\(u\_y\) \((x, y)\)\), "=", 
        RowBox[{\(-v\_x\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  ".  \n\nTaking the partial derivative with respect to ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " of each side of these equations gives  \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_xx\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        RowBox[{\(v\_yx\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  "   and   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_yx\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        RowBox[{\(-v\_xx\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  ".  \n\n\nSimilarly, taking the partial derivative of each side with \
respect to ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " yields  \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_xy\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        RowBox[{\(v\_yy\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  "   and   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_yy\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        RowBox[{\(-v\_xy\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  ".  \n\n\nThe partial derivatives ",
  Cell[BoxData[
      RowBox[{\(u\_xy\), ",", \(u\_yx\), ",", 
        RowBox[{\(v\_xy\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", \(v\_yx\)}]}]]],
  " are all continuous, so we use a theorem from the calculus of real \
functions that states that the mixed partial derivatives are equal; that is,  \
\n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_xy\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        RowBox[{\(u\_yx\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  "   and   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(v\_xy\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        RowBox[{\(v\_yx\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  ".  \n\n\nCombining all these results finally gives \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(u\_xx\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "+", 
          RowBox[{\(u\_yy\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}], " ", "=", " ", 
        RowBox[{
          RowBox[{
            RowBox[{\(v\_yx\), 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], "-", 
            RowBox[{\(v\_xy\), 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}]}], " ", "=", " ",
           "0"}]}]]],
  ",  and  \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(v\_xx\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "+", 
          RowBox[{\(v\_yy\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}], " ", "=", " ", 
        RowBox[{
          RowBox[{
            RowBox[{\(-\ u\_yx\), 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], "+", " ", 
            RowBox[{\(u\_xy\), 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}]}], " ", "=", " ",
           "0"}]}]]],
  ".  \n\nTherefore both ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " are harmonic functions on ",
  StyleBox["D",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.8 is also in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  "\tIf we have a function ",
  Cell[BoxData[
      RowBox[{"u", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " that is harmonic on the domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " and if we can find another harmonic function ",
  Cell[BoxData[
      RowBox[{"v", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " such that the partial derivatives for ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " satisfy the Cauchy-Riemann equations throughout ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", then we say that ",
  Cell[BoxData[
      RowBox[{"v", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "is a harmonic conjugate of ",
  Cell[BoxData[
      RowBox[{"u", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ".  It then follows that the function  ",
  Cell[BoxData[
      RowBox[{\(f \((z)\)\), "=", " ", 
        RowBox[{
          RowBox[{"u", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "v", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  "  is analytic on ",
  StyleBox["D",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 3.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  If  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"u", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        "=", \(x\^2 - y\^2\)}]]],
  ",  then  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(u\_xx\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "+", 
          RowBox[{\(u\_yy\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}], 
        "=", \(2 - 2 = 0\)}]]],
  ";   hence u is a harmonic function for all ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ".  We find that ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"v", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        "=", \(2\ x\ y\)}]]],
  " is also a harmonic function and that \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_x\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        RowBox[{
          RowBox[{\(v\_y\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(2  x\)}]}]]],
  ",   and   \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_y\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        RowBox[{
          RowBox[{\(-\ v\_x\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(\(-\ 2\) y\)}]}]]],
  ".\n\nTherefore ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " is a harmonic conjugate of ",
  StyleBox["u",
    FontFamily->"Courier New"],
  ", and the function ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " given by  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\ \  = \ \ x\^2 - 
          y\^2\  + \ \[ImaginaryI]\ 2\ x\ y\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(\((x + \[ImaginaryI]\ y)\)\^2\ \
\  = \ \ z\^2\)\)\)}]],
  "  \n\nis an analytic function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 3.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the functions u[x,y] and v[x,y] and show that the Cauchy-Riemann \
equations hold.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[u, Ux, Uy, v, Vx, Vy, w, x, y, z, Z];\)\ \), "\n", 
    \(\(TagSet[x, Im[x], 0];\)\ \), "\n", 
    \(\(TagSet[y, Im[y], 0];\)\ \), "\n", 
    \(\(TagSet[x, Re[x], x];\)\ \), "\n", 
    \(\(TagSet[y, Re[y], y];\)\ \), "\n", 
    \(\(u[x_, y_]\  = \ x\^2 - y\^2;\)\ \), "\n", 
    \(\(v[x_, y_]\  = \ 2\ x\ y;\)\ \), "\n", 
    \(\(Ux\  = \ \[PartialD]\_x\ u[x, y];\)\ \), "\n", 
    \(\(Uy\  = \ \[PartialD]\_y\ u[x, y];\)\ \), "\n", 
    \(\(Vx\  = \ \[PartialD]\_x\ v[x, y];\)\ \), "\n", 
    \(\(Vy\  = \ \[PartialD]\_y\ v[x, y];\)\ \), "\n", 
    \(\(Print["\< u[x,y] = \>", u[x, y]];\)\ \), "\n", 
    \(\(Print["\< v[x,y] = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_x\)[x,y] = \>\"", Ux];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_y\)[x,y] = \>\"", Uy];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_x\)[x,y] = \>\"", Vx];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_y\)[x,y] = \>\"", 
        Vy];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_x\)[x,y] =  \!\(v\_y\)[x,y] ?      \>\"", 
        Ux \[Equal] Vy];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_y\)[x,y] = -\!\(v\_x\)[x,y] ?      \>\"", 
        Uy \[Equal] \(-Vx\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The Cauchy-Riemann equations hold, therefore  ",
  Cell[BoxData[
      \(f \((x + \[ImaginaryI]\ y)\) = 
        u \((x, y)\) + \[ImaginaryI]\ v \((x, y)\)\)]],
  "  is analytic.  It follows that both  ",
  Cell[BoxData[
      \(u \((x, y)\) = \(Re[f \((x + \[ImaginaryI]\ y)\)] = \ 
          x\^2 - y\^2\)\)]],
  "  and   ",
  Cell[BoxData[
      \(v \((x, y)\) = \(Im[f \((x + \[ImaginaryI]\ y)\)] = \ 2\ x\ y\)\)]],
  " are harmonic functions.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The underlying complex function is  ",
  Cell[BoxData[
      \(f[z] = z\^2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_] = z\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(Z\  = \ x\  + \ \[ImaginaryI]\ y;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  w = f[z] = \>", f[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  w = f[z] = \>", 
        ComplexExpand[f[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  f[\>", 
        Z, "\<] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<  f[\>", Z, "\<] = (\>", 
        u[x, y], "\<) + \[ImaginaryI](\>", \ 
        v[x, y], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  f[\>", Z, "\<] = \>", 
        u[x, y] + \[ImaginaryI]\ v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell["\<\
\tTheorem 3.8 makes the construction of harmonic functions from known \
analytic functions an easy task.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 3.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " The function  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(z\^3\  = \ 
          x\^3 - 3\ x\ y\^2 + \[ImaginaryI]\ \((3\ x\^2\ y - y\^3)\)\)\)]],
  "  is analytic for all values of z, hence it follows that  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"u", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
        " ", \(Re[f \((z)\)]\  = \ x\^3 - 3\ x\ y\^2\)}]]],
  "  \nis harmonic, and\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"v", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
        " ", \(Im[f \((z)\)]\  = \ 3\ x\^2\ y - y\^3\)}]]],
  "  \n\t\t\nis a harmonic conjugate of u(x,y)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 3.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the functions u[x,y] and v[x,y] and show that the Cauchy-Riemann \
equations hold.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[u, Ux, Uy, v, Vx, Vy, w, x, y, z, Z];\)\ \), "\n", 
    \(\(TagSet[x, Im[x], 0];\)\ \), "\n", 
    \(\(TagSet[y, Im[y], 0];\)\ \), "\n", 
    \(\(TagSet[x, Re[x], x];\)\ \), "\n", 
    \(\(TagSet[y, Re[y], y];\)\ \), "\n", 
    \(\(u[x_, y_]\  = \ x\^3 - 3\ x\ y\^2;\)\ \), "\n", 
    \(\(v[x_, y_]\  = \ 3\ x\^2\ y - y\^3;\)\ \), "\n", 
    \(\(Ux\  = \ \[PartialD]\_x\ u[x, y];\)\ \), "\n", 
    \(\(Uy\  = \ \[PartialD]\_y\ u[x, y];\)\ \), "\n", 
    \(\(Vx\  = \ \[PartialD]\_x\ v[x, y];\)\ \), "\n", 
    \(\(Vy\  = \ \[PartialD]\_y\ v[x, y];\)\ \), "\n", 
    \(\(Print["\< u[x,y] = \>", u[x, y]];\)\ \), "\n", 
    \(\(Print["\< v[x,y] = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_x\)[x,y] = \>\"", Ux];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_y\)[x,y] = \>\"", Uy];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_x\)[x,y] = \>\"", Vx];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_y\)[x,y] = \>\"", 
        Vy];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_x\)[x,y] =  \!\(v\_y\)[x,y] ?      \>\"", 
        Ux \[Equal] Vy];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_y\)[x,y] = -\!\(v\_x\)[x,y] ?      \>\"", 
        Uy \[Equal] \(-Vx\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The Cauchy-Riemann equations hold, therefore  ",
  Cell[BoxData[
      \(f \((x + \[ImaginaryI]\ y)\) = \(u \((x, 
                y)\) + \[ImaginaryI]\ v \((x, y)\) = \ 
          x\^3 - 3\ x\ y\^2 + \[ImaginaryI] \((3\ x\^2\ y - y\^3)\)\)\)]],
  "  is analytic.  It follows that both  ",
  Cell[BoxData[
      \(u \((x, y)\) = \(Re[f \((x + \[ImaginaryI]\ y)\)] = \ 
          x\^3 - 3\ x\ y\^2\)\)]],
  "  and   ",
  Cell[BoxData[
      \(v \((x, y)\) = \(Im[f \((x + \[ImaginaryI]\ y)\)] = \ 
          3\ x\^2\ y - y\^3\)\)]],
  " are harmonic functions.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The underlying complex function is  ",
  Cell[BoxData[
      \(f[z] = z\^3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_] = z\^3;\)\ \), "\[IndentingNewLine]", 
    \(\(Z\  = \ x\  + \ \[ImaginaryI]\ y;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  w = f[z] = \>", f[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  w = f[z] = \>", 
        ComplexExpand[f[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[\>", 
        Z, "\<] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[\>", Z, "\<] = (\>", u[x, y], "\<) + \[ImaginaryI](\>", \ 
        v[x, y], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[\>", Z, "\<] = \>", 
        u[x, y] + \[ImaginaryI]\ v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tFigures 3.2 and 3.3 show the graphs of these two functions.  The partial \
derivatives are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_x\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        "=", \(3\ x\^2 - 3\ y\^2\)}]]],
  ",   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_y\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        "=", \(\(-6\)\ x\ y\)}]]],
  ",   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(v\_x\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        "=", \(6\ x\ y\)}]]],
  ",  and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(v\_y\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        "=", \(3\ x\^2 - 3\ y\^2\)}]]],
  ".  They satisfy the Cauchy-Riemann equations because they are the real and \
imaginary parts of an analytic function.  At the point ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}], "=", 
        RowBox[{"(", 
          RowBox[{"2", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(-1\)}], ")"}]}]]],
  ",  we have  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_x\), 
          RowBox[{"(", 
            RowBox[{"2", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(-1\)}], ")"}]}], " ", "=", " ", 
        RowBox[{
          RowBox[{\(v\_y\), 
            RowBox[{"(", 
              RowBox[{"2", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(-1\)}], ")"}]}], "=", 
          "9"}]}]]],
  ",  and these partial derivatives appear along the edges of the surfaces \
for u and v where ",
  Cell[BoxData[
      RowBox[{"x", "=", 
        RowBox[{
          RowBox[{"2", " ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", "y"}], "=", \(-1\)}]}]]],
  ".  Similarly,  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_y\), 
          RowBox[{"(", 
            RowBox[{"2", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(-1\)}], ")"}]}], " ", "=", 
        "12"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(v\_x\), 
          RowBox[{"(", 
            RowBox[{"2", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(-1\)}], ")"}]}], 
        "=", \(-12\)}]]],
  "  also appear along the edges of the surfaces for ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " where ",
  Cell[BoxData[
      RowBox[{"x", "=", 
        RowBox[{
          RowBox[{"2", " ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", "y"}], "=", \(-1\)}]}]]],
  "."
}], "Text"],

Cell[TextData[{
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83604 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.29597e-017 1.0317 -0.068013 1.0317 [
[.17348 .16592 -11.0614 -9 ]
[.17348 .16592 .9386 0 ]
[.33816 .10893 -5.35223 -9 ]
[.33816 .10893 .64777 0 ]
[.50828 .05007 -5.17376 -9 ]
[.50828 .05007 .82624 0 ]
[.29838 .05818 -8.92039 -12.5625 ]
[.29838 .05818 1.07961 0 ]
[.70343 -0.00421 0 -6.05261 ]
[.70343 -0.00421 12 2.94739 ]
[.85696 .22678 0 -5.93481 ]
[.85696 .22678 6 3.06519 ]
[.9924 .43055 0 -5.83362 ]
[.9924 .43055 6 3.16638 ]
[.9184 .20719 0 -8.284 ]
[.9184 .20719 16 4.2785 ]
[.00631 .27685 -12 -2.96564 ]
[.00631 .27685 0 6.03436 ]
[-0.00068 .34832 -6 -2.99676 ]
[-0.00068 .34832 0 6.00324 ]
[-0.00786 .42182 -6 -3.02881 ]
[-0.00786 .42182 0 5.97119 ]
[-0.06184 .36875 -10 -4.18298 ]
[-0.06184 .36875 0 8.37952 ]
[ 0 0 0 0 ]
[ 1 .83604 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0226 .2307 m
.69124 0 L
s
.18179 .17577 m
.18595 .1807 L
s
[(-1)] .17348 .16592 .84357 1 Mshowa
.34612 .11908 m
.3501 .12415 L
s
[(0)] .33816 .10893 .78408 1 Mshowa
.51585 .06052 m
.51963 .06574 L
s
[(1)] .50828 .05007 .72459 1 Mshowa
gsave
.29838 .05818 -69.9204 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.69124 0 m
.98003 .43421 L
s
.69124 0 m
.68515 .0021 L
s
[(-1)] .70343 -0.00421 -1 .34502 Mshowa
.84468 .2307 m
.83853 .23266 L
s
[(0)] .85696 .22678 -1 .31885 Mshowa
.98003 .43421 m
.97385 .43604 L
s
[(1)] .9924 .43055 -1 .29636 Mshowa
gsave
.9184 .20719 -61 -12.284 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.0226 .2307 m
0 .46297 L
s
.01852 .27268 m
.02462 .2706 L
s
[(-5)] .00631 .27685 1 -0.34097 Mshowa
.01155 .34423 m
.01767 .34219 L
s
[(0)] -0.00068 .34832 1 -0.33405 Mshowa
.00439 .41781 m
.01052 .41581 L
s
[(5)] -0.00786 .42182 1 -0.32693 Mshowa
gsave
-0.06184 .36875 -71 -8.18298 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.0226 .2307 m
0 .46297 L
s
0 .46297 m
.36381 .83604 L
s
.36381 .83604 m
.36973 .61508 L
s
.36973 .61508 m
.0226 .2307 L
s
.69124 0 m
.98003 .43421 L
s
.98003 .43421 m
1 .66097 L
s
1 .66097 m
.69984 .23724 L
s
.69984 .23724 m
.69124 0 L
s
.0226 .2307 m
0 .46297 L
s
0 .46297 m
.69984 .23724 L
s
.69984 .23724 m
.69124 0 L
s
.69124 0 m
.0226 .2307 L
s
.36973 .61508 m
.98003 .43421 L
s
.98003 .43421 m
1 .66097 L
s
1 .66097 m
.36381 .83604 L
s
.36381 .83604 m
.36973 .61508 L
s
0 0 m
1 0 L
1 .83604 L
0 .83604 L
closepath
clip
newpath
.5 Mabswid
.835 .888 .835 r
.34567 .64984 .36756 .6959 .40894 .71277 .38695 .66948 Metetra
.866 .921 .866 r
.38695 .66948 .40894 .71277 .45124 .71822 .42924 .67781 Metetra
.886 .941 .886 r
.42924 .67781 .45124 .71822 .49419 .71392 .47228 .67645 Metetra
.898 .954 .898 r
.47228 .67645 .49419 .71392 .53759 .7017 .51585 .66719 Metetra
.907 .964 .907 r
.51585 .66719 .53759 .7017 .58129 .68348 .55979 .65194 Metetra
.913 .971 .913 r
.55979 .65194 .58129 .68348 .62518 .66122 .60399 .63263 Metetra
.919 .976 .919 r
.60399 .63263 .62518 .66122 .66922 .63689 .64842 .61124 Metetra
.922 .98 .922 r
.64842 .61124 .66922 .63689 .71345 .61246 .69308 .58974 Metetra
.925 .982 .925 r
.69308 .58974 .71345 .61246 .75794 .58988 .73805 .57009 Metetra
.923 .98 .923 r
.73805 .57009 .75794 .58988 .80285 .57109 .78349 .55424 Metetra
.909 .965 .909 r
.78349 .55424 .80285 .57109 .84841 .55802 .82963 .54417 Metetra
.855 .908 .855 r
.82963 .54417 .84841 .55802 .89491 .55268 .87674 .5419 Metetra
.66 .701 .66 r
.87674 .5419 .89491 .55268 .94272 .55715 .92521 .54959 Metetra
.168 .178 .168 r
.92521 .54959 .94272 .55715 .99232 .57369 .97553 .56954 Metetra
.82 .871 .82 r
.32349 .60671 .34567 .64984 .38695 .66948 .36467 .62867 Metetra
.86 .913 .86 r
.36467 .62867 .38695 .66948 .42924 .67781 .40695 .63939 Metetra
.883 .938 .883 r
.40695 .63939 .42924 .67781 .47228 .67645 .45007 .64048 Metetra
.897 .953 .897 r
.45007 .64048 .47228 .67645 .51585 .66719 .49381 .6337 Metetra
.906 .963 .906 r
.49381 .6337 .51585 .66719 .55979 .65194 .53798 .62092 Metetra
.913 .97 .913 r
.53798 .62092 .55979 .65194 .60399 .63263 .58248 .60409 Metetra
.917 .975 .917 r
.58248 .60409 .60399 .63263 .64842 .61124 .62726 .58516 Metetra
.92 .978 .92 r
.62726 .58516 .64842 .61124 .69308 .58974 .67232 .56612 Metetra
.921 .979 .921 r
.67232 .56612 .69308 .58974 .73805 .57009 .71774 .54893 Metetra
.918 .975 .918 r
.71774 .54893 .73805 .57009 .78349 .55424 .76367 .53556 Metetra
.903 .959 .903 r
.76367 .53556 .78349 .55424 .82963 .54417 .81032 .52802 Metetra
.852 .906 .852 r
.81032 .52802 .82963 .54417 .87674 .5419 .85799 .52837 Metetra
.69 .733 .69 r
.85799 .52837 .87674 .5419 .92521 .54959 .90706 .5388 Metetra
.281 .299 .281 r
.90706 .5388 .92521 .54959 .97553 .56954 .95801 .5617 Metetra
.799 .849 .799 r
.30096 .56649 .32349 .60671 .36467 .62867 .34205 .59031 Metetra
.851 .904 .851 r
.34205 .59031 .36467 .62867 .40695 .63939 .38435 .60296 Metetra
.879 .934 .879 r
.38435 .60296 .40695 .63939 .45007 .64048 .42755 .60601 Metetra
.895 .951 .895 r
.42755 .60601 .45007 .64048 .49381 .6337 .47145 .60121 Metetra
.905 .962 .905 r
.47145 .60121 .49381 .6337 .53798 .62092 .51585 .59043 Metetra
.912 .969 .912 r
.51585 .59043 .53798 .62092 .58248 .60409 .56063 .57558 Metetra
.916 .973 .916 r
.56063 .57558 .58248 .60409 .62726 .58516 .60574 .55864 Metetra
.918 .976 .918 r
.60574 .55864 .62726 .58516 .67232 .56612 .65117 .54157 Metetra
.918 .976 .918 r
.65117 .54157 .67232 .56612 .71774 .54893 .697 .52636 Metetra
.914 .971 .914 r
.697 .52636 .71774 .54893 .76367 .53556 .74337 .515 Metetra
.898 .954 .898 r
.74337 .515 .76367 .53556 .81032 .52802 .79049 .50952 Metetra
.851 .905 .851 r
.79049 .50952 .81032 .52802 .85799 .52837 .83866 .51201 Metetra
.717 .762 .717 r
.83866 .51201 .85799 .52837 .90706 .5388 .88825 .5247 Metetra
.388 .413 .388 r
.88825 .5247 .90706 .5388 .95801 .5617 .93977 .55003 Metetra
.77 .818 .77 r
.27803 .52914 .30096 .56649 .34205 .59031 .31907 .55438 Metetra
.84 .893 .84 r
.31907 .55438 .34205 .59031 .38435 .60296 .36138 .56849 Metetra
.875 .929 .875 r
.36138 .56849 .38435 .60296 .42755 .60601 .40469 .57303 Metetra
.894 .949 .894 r
.40469 .57303 .42755 .60601 .47145 .60121 .44874 .56974 Metetra
.904 .961 .904 r
.44874 .56974 .47145 .60121 .51585 .59043 .49337 .56045 Metetra
.911 .968 .911 r
.49337 .56045 .51585 .59043 .56063 .57558 .53843 .5471 Metetra
.915 .972 .915 r
.53843 .5471 .56063 .57558 .60574 .55864 .58385 .53165 Metetra
.917 .974 .917 r
.58385 .53165 .60574 .55864 .65117 .54157 .62963 .51608 Metetra
.916 .973 .916 r
.62963 .51608 .65117 .54157 .697 .52636 .67584 .50237 Metetra
.91 .967 .91 r
.67584 .50237 .697 .52636 .74337 .515 .72261 .49254 Metetra
.894 .95 .894 r
.72261 .49254 .74337 .515 .79049 .50952 .77015 .48863 Metetra
.852 .905 .852 r
.77015 .48863 .79049 .50952 .83866 .51201 .81876 .49276 Metetra
.742 .789 .742 r
.81876 .49276 .83866 .51201 .88825 .5247 .86881 .5072 Metetra
.483 .513 .483 r
.86881 .5072 .88825 .5247 .93977 .55003 .9208 .53442 Metetra
.731 .777 .731 r
.25466 .49465 .27803 .52914 .31907 .55438 .29567 .52087 Metetra
.826 .878 .826 r
.29567 .52087 .31907 .55438 .36138 .56849 .33802 .53598 Metetra
.87 .924 .87 r
.33802 .53598 .36138 .56849 .40469 .57303 .38144 .54154 Metetra
.892 .948 .892 r
.38144 .54154 .40469 .57303 .44874 .56974 .42567 .53926 Metetra
.904 .96 .904 r
.42567 .53926 .44874 .56974 .49337 .56045 .47052 .53099 Metetra
.91 .967 .91 r
.47052 .53099 .49337 .56045 .53843 .5471 .51585 .51865 Metetra
.914 .971 .914 r
.51585 .51865 .53843 .5471 .58385 .53165 .56158 .5042 Metetra
.915 .972 .915 r
.56158 .5042 .58385 .53165 .62963 .51608 .60769 .48963 Metetra
.914 .971 .914 r
.60769 .48963 .62963 .51608 .67584 .50237 .65426 .47693 Metetra
.907 .964 .907 r
.65426 .47693 .67584 .50237 .72261 .49254 .70139 .46813 Metetra
.892 .947 .892 r
.70139 .46813 .72261 .49254 .77015 .48863 .74931 .46529 Metetra
.854 .908 .854 r
.74931 .46529 .77015 .48863 .81876 .49276 .7983 .47055 Metetra
.765 .812 .765 r
.7983 .47055 .81876 .49276 .86881 .5072 .84874 .4862 Metetra
.563 .598 .563 r
.84874 .4862 .86881 .5072 .9208 .53442 .90113 .51477 Metetra
.678 .72 .678 r
.2308 .463 .25466 .49465 .29567 .52087 .2718 .48977 Metetra
.809 .86 .809 r
.2718 .48977 .29567 .52087 .33802 .53598 .31422 .50544 Metetra
.865 .919 .865 r
.31422 .50544 .33802 .53598 .38144 .54154 .35777 .51154 Metetra
.891 .946 .891 r
.35777 .51154 .38144 .54154 .42567 .53926 .4022 .50979 Metetra
.904 .96 .904 r
.4022 .50979 .42567 .53926 .47052 .53099 .44728 .50204 Metetra
.91 .967 .91 r
.44728 .50204 .47052 .53099 .51585 .51865 .49288 .49021 Metetra
.914 .971 .914 r
.49288 .49021 .51585 .51865 .56158 .5042 .53891 .47627 Metetra
.914 .971 .914 r
.53891 .47627 .56158 .5042 .60769 .48963 .58535 .4622 Metetra
.912 .969 .912 r
.58535 .4622 .60769 .48963 .65426 .47693 .63224 .45001 Metetra
.906 .962 .906 r
.63224 .45001 .65426 .47693 .70139 .46813 .67972 .44174 Metetra
.891 .946 .891 r
.67972 .44174 .70139 .46813 .74931 .46529 .72797 .43945 Metetra
.858 .911 .858 r
.72797 .43945 .74931 .46529 .7983 .47055 .77729 .44532 Metetra
.784 .833 .784 r
.77729 .44532 .7983 .47055 .84874 .4862 .82806 .46164 Metetra
.629 .668 .629 r
.82806 .46164 .84874 .4862 .90113 .51477 .88077 .49098 Metetra
.608 .646 .608 r
.20639 .43421 .2308 .463 .2718 .48977 .24742 .4611 Metetra
.788 .837 .788 r
.24742 .4611 .2718 .48977 .31422 .50544 .28994 .47686 Metetra
.86 .913 .86 r
.28994 .47686 .31422 .50544 .35777 .51154 .33366 .48303 Metetra
.89 .946 .89 r
.33366 .48303 .35777 .51154 .4022 .50979 .37829 .48133 Metetra
.904 .961 .904 r
.37829 .48133 .4022 .50979 .44728 .50204 .42363 .4736 Metetra
.911 .968 .911 r
.42363 .4736 .44728 .50204 .49288 .49021 .46952 .46178 Metetra
.914 .971 .914 r
.46952 .46178 .49288 .49021 .53891 .47627 .51585 .44783 Metetra
.914 .971 .914 r
.51585 .44783 .53891 .47627 .58535 .4622 .5626 .43376 Metetra
.911 .968 .911 r
.5626 .43376 .58535 .4622 .63224 .45001 .60981 .42158 Metetra
.905 .961 .905 r
.60981 .42158 .63224 .45001 .67972 .44174 .65759 .41332 Metetra
.891 .946 .891 r
.65759 .41332 .67972 .44174 .72797 .43945 .70615 .41108 Metetra
.862 .916 .862 r
.70615 .41108 .72797 .43945 .77729 .44532 .75575 .41701 Metetra
.802 .852 .802 r
.75575 .41701 .77729 .44532 .82806 .46164 .80679 .43346 Metetra
.682 .724 .682 r
.80679 .43346 .82806 .46164 .88077 .49098 .85975 .46297 Metetra
.519 .552 .519 r
.18137 .40829 .20639 .43421 .24742 .4611 .22247 .43486 Metetra
.763 .811 .763 r
.22247 .43486 .24742 .4611 .28994 .47686 .26514 .45025 Metetra
.854 .908 .854 r
.26514 .45025 .28994 .47686 .33366 .48303 .30905 .45601 Metetra
.89 .946 .89 r
.30905 .45601 .33366 .48303 .37829 .48133 .35393 .45386 Metetra
.905 .962 .905 r
.35393 .45386 .37829 .48133 .42363 .4736 .39955 .44566 Metetra
.912 .969 .912 r
.39955 .44566 .42363 .4736 .46952 .46178 .44573 .43335 Metetra
.915 .972 .915 r
.44573 .43335 .46952 .46178 .51585 .44783 .49237 .4189 Metetra
.914 .971 .914 r
.49237 .4189 .51585 .44783 .5626 .43376 .53943 .40432 Metetra
.911 .968 .911 r
.53943 .40432 .5626 .43376 .60981 .42158 .58694 .39162 Metetra
.905 .961 .905 r
.58694 .39162 .60981 .42158 .65759 .41332 .63502 .38287 Metetra
.892 .947 .892 r
.63502 .38287 .65759 .41332 .70615 .41108 .68385 .38013 Metetra
.866 .92 .866 r
.68385 .38013 .70615 .41108 .75575 .41701 .7337 .3856 Metetra
.817 .868 .817 r
.7337 .3856 .75575 .41701 .80679 .43346 .78495 .40159 Metetra
.724 .769 .724 r
.78495 .40159 .80679 .43346 .85975 .46297 .83808 .43069 Metetra
.416 .442 .416 r
.15566 .38526 .18137 .40829 .22247 .43486 .1969 .41107 Metetra
.736 .782 .736 r
.1969 .41107 .22247 .43486 .26514 .45025 .23976 .42564 Metetra
.85 .903 .85 r
.23976 .42564 .26514 .45025 .30905 .45601 .28392 .4305 Metetra
.891 .947 .891 r
.28392 .4305 .30905 .45601 .35393 .45386 .32908 .42741 Metetra
.907 .964 .907 r
.32908 .42741 .35393 .45386 .39955 .44566 .375 .41822 Metetra
.914 .971 .914 r
.375 .41822 .39955 .44566 .44573 .43335 .4215 .4049 Metetra
.916 .973 .916 r
.4215 .4049 .44573 .43335 .49237 .4189 .46847 .38944 Metetra
.915 .972 .915 r
.46847 .38944 .49237 .4189 .53943 .40432 .51585 .37383 Metetra
.912 .969 .912 r
.51585 .37383 .53943 .40432 .58694 .39162 .56366 .36011 Metetra
.905 .962 .905 r
.56366 .36011 .58694 .39162 .63502 .38287 .61202 .35033 Metetra
.893 .949 .893 r
.61202 .35033 .63502 .38287 .68385 .38013 .66109 .34658 Metetra
.871 .926 .871 r
.66109 .34658 .68385 .38013 .7337 .3856 .71115 .35102 Metetra
.831 .883 .831 r
.71115 .35102 .7337 .3856 .78495 .40159 .76256 .366 Metetra
.757 .804 .757 r
.76256 .366 .78495 .40159 .83808 .43069 .81581 .39407 Metetra
.305 .324 .305 r
.12922 .36516 .15566 .38526 .1969 .41107 .17064 .38978 Metetra
.706 .75 .706 r
.17064 .38978 .1969 .41107 .23976 .42564 .21375 .40303 Metetra
.847 .9 .847 r
.21375 .40303 .23976 .42564 .28392 .4305 .25821 .40651 Metetra
.894 .949 .894 r
.25821 .40651 .28392 .4305 .32908 .42741 .3037 .40196 Metetra
.91 .967 .91 r
.3037 .40196 .32908 .42741 .375 .41822 .34997 .39129 Metetra
.916 .974 .916 r
.34997 .39129 .375 .41822 .4215 .4049 .39682 .37644 Metetra
.918 .975 .918 r
.39682 .37644 .4215 .4049 .46847 .38944 .44413 .35944 Metetra
.917 .974 .917 r
.44413 .35944 .46847 .38944 .51585 .37383 .49184 .34229 Metetra
.913 .97 .913 r
.49184 .34229 .51585 .37383 .56366 .36011 .53996 .32703 Metetra
.907 .963 .907 r
.53996 .32703 .56366 .36011 .61202 .35033 .58859 .3157 Metetra
.895 .951 .895 r
.58859 .3157 .61202 .35033 .66109 .34658 .63789 .31039 Metetra
.876 .931 .876 r
.63789 .31039 .66109 .34658 .71115 .35102 .68812 .31327 Metetra
.842 .895 .842 r
.68812 .31327 .71115 .35102 .76256 .366 .73965 .32666 Metetra
.783 .832 .783 r
.73965 .32666 .76256 .366 .81581 .39407 .79295 .3531 Metetra
.198 .211 .198 r
.10195 .34805 .12922 .36516 .17064 .38978 .14363 .37101 Metetra
.678 .72 .678 r
.14363 .37101 .17064 .38978 .21375 .40303 .18706 .38247 Metetra
.847 .9 .847 r
.18706 .38247 .21375 .40303 .25821 .40651 .23187 .38405 Metetra
.897 .954 .897 r
.23187 .38405 .25821 .40651 .3037 .40196 .27775 .37754 Metetra
.914 .971 .914 r
.27775 .37754 .3037 .40196 .34997 .39129 .32441 .36485 Metetra
.919 .977 .919 r
.32441 .36485 .34997 .39129 .39682 .37644 .37166 .34796 Metetra
.92 .978 .92 r
.37166 .34796 .39682 .37644 .44413 .35944 .41935 .32889 Metetra
.918 .976 .918 r
.41935 .32889 .44413 .35944 .49184 .34229 .46741 .30967 Metetra
.915 .972 .915 r
.46741 .30967 .49184 .34229 .53996 .32703 .51585 .29234 Metetra
.908 .965 .908 r
.51585 .29234 .53996 .32703 .58859 .3157 .56474 .27894 Metetra
.898 .954 .898 r
.56474 .27894 .58859 .3157 .63789 .31039 .61426 .27154 Metetra
.881 .936 .881 r
.61426 .27154 .63789 .31039 .68812 .31327 .66464 .27231 Metetra
.852 .905 .852 r
.66464 .27231 .68812 .31327 .73965 .32666 .71626 .28354 Metetra
.804 .855 .804 r
.71626 .28354 .73965 .32666 .79295 .3531 .76956 .30774 Metetra
.106 .112 .106 r
.07378 .334 .10195 .34805 .14363 .37101 .1158 .35481 Metetra
.653 .694 .653 r
.1158 .35481 .14363 .37101 .18706 .38247 .15962 .36398 Metetra
.849 .902 .849 r
.15962 .36398 .18706 .38247 .23187 .38405 .20486 .36316 Metetra
.903 .959 .903 r
.20486 .36316 .23187 .38405 .27775 .37754 .25119 .35415 Metetra
.919 .976 .919 r
.25119 .35415 .27775 .37754 .32441 .36485 .29831 .33891 Metetra
.923 .98 .923 r
.29831 .33891 .32441 .36485 .37166 .34796 .346 .31944 Metetra
.923 .98 .923 r
.346 .31944 .37166 .34796 .41935 .32889 .39411 .29778 Metetra
.92 .978 .92 r
.39411 .29778 .41935 .32889 .46741 .30967 .44255 .27596 Metetra
.916 .974 .916 r
.44255 .27596 .46741 .30967 .51585 .29234 .49132 .25604 Metetra
.91 .967 .91 r
.49132 .25604 .51585 .29234 .56474 .27894 .54049 .24003 Metetra
.9 .957 .9 r
.54049 .24003 .56474 .27894 .61426 .27154 .59022 .23002 Metetra
.885 .94 .885 r
.59022 .23002 .61426 .27154 .66464 .27231 .64074 .22814 Metetra
.861 .914 .861 r
.64074 .22814 .66464 .27231 .71626 .28354 .6924 .23664 Metetra
.821 .873 .821 r
.6924 .23664 .71626 .28354 .76956 .30774 .74566 .25802 Metetra
.04462 .32307 .07378 .334 .1158 .35481 .08707 .34126 Metetra
.637 .677 .637 r
.08707 .34126 .1158 .35481 .15962 .36398 .13137 .34762 Metetra
.855 .908 .855 r
.13137 .34762 .15962 .36398 .20486 .36316 .17713 .34385 Metetra
.909 .966 .909 r
.17713 .34385 .20486 .36316 .25119 .35415 .22398 .3318 Metetra
.923 .981 .923 r
.22398 .3318 .25119 .35415 .29831 .33891 .27163 .31347 Metetra
.926 .984 .926 r
.27163 .31347 .29831 .33891 .346 .31944 .31982 .29087 Metetra
.925 .983 .925 r
.31982 .29087 .346 .31944 .39411 .29778 .36839 .26608 Metetra
.922 .98 .922 r
.36839 .26608 .39411 .29778 .44255 .27596 .41726 .24114 Metetra
.918 .975 .918 r
.41726 .24114 .44255 .27596 .49132 .25604 .46639 .21809 Metetra
.912 .969 .912 r
.46639 .21809 .49132 .25604 .54049 .24003 .51585 .19897 Metetra
.903 .959 .903 r
.51585 .19897 .54049 .24003 .59022 .23002 .56579 .18582 Metetra
.889 .944 .889 r
.56579 .18582 .59022 .23002 .64074 .22814 .61644 .18074 Metetra
.868 .922 .868 r
.61644 .18074 .64074 .22814 .6924 .23664 .66813 .18598 Metetra
.835 .887 .835 r
.66813 .18598 .6924 .23664 .74566 .25802 .7213 .20396 Metetra
.013 .014 .013 r
.01436 .31538 .04462 .32307 .08707 .34126 .05735 .33042 Metetra
.631 .67 .631 r
.05735 .33042 .08707 .34126 .13137 .34762 .10224 .33343 Metetra
.863 .917 .863 r
.10224 .33343 .13137 .34762 .17713 .34385 .14861 .32616 Metetra
.916 .973 .916 r
.14861 .32616 .17713 .34385 .22398 .3318 .19608 .31051 Metetra
.928 .986 .928 r
.19608 .31051 .22398 .3318 .27163 .31347 .24433 .28852 Metetra
.93 .988 .93 r
.24433 .28852 .27163 .31347 .31982 .29087 .29309 .26225 Metetra
.928 .986 .928 r
.29309 .26225 .31982 .29087 .36839 .26608 .34219 .23378 Metetra
.924 .982 .924 r
.34219 .23378 .36839 .26608 .41726 .24114 .39152 .20518 Metetra
.92 .977 .92 r
.39152 .20518 .41726 .24114 .46639 .21809 .44105 .17849 Metetra
.913 .97 .913 r
.44105 .17849 .46639 .21809 .51585 .19897 .49083 .15573 Metetra
.905 .961 .905 r
.49083 .15573 .51585 .19897 .56579 .18582 .54099 .13892 Metetra
.892 .948 .892 r
.54099 .13892 .56579 .18582 .61644 .18074 .59176 .13014 Metetra
.874 .928 .874 r
.59176 .13014 .61644 .18074 .66813 .18598 .64346 .13158 Metetra
.846 .899 .846 r
.64346 .13158 .66813 .18598 .7213 .20396 .69652 .1456 Metetra
0 g
.25 Mabswid
.69124 0 m
.98003 .43421 L
s
.98003 .43421 m
1 .66097 L
s
1 .66097 m
.69984 .23724 L
s
.69984 .23724 m
.69124 0 L
s
.0226 .2307 m
0 .46297 L
s
0 .46297 m
.69984 .23724 L
s
.69984 .23724 m
.69124 0 L
s
.69124 0 m
.0226 .2307 L
s
.0226 .2307 m
.69124 0 L
s
.18179 .17577 m
.18595 .1807 L
s
[(-1)] .17348 .16592 .84357 1 Mshowa
.34612 .11908 m
.3501 .12415 L
s
[(0)] .33816 .10893 .78408 1 Mshowa
.51585 .06052 m
.51963 .06574 L
s
[(1)] .50828 .05007 .72459 1 Mshowa
gsave
.29838 .05818 -69.9204 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{257, 214.813},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000410000eR000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00_`3oool5
000003d0oooo00310?ooo`030000003oool0oooo03d0oooo00310?ooo`030000003oool0oooo03d0
oooo002i0?ooo`@00000103oool00`000000oooo0?ooo`0m0?ooo`00`@3oool00`000000oooo0?oo
o`0m0?ooo`00]03oool2000000X0oooo0P00000o0?ooo`00/@3oool3000000030?ooo`0000000000
04X0oooo002^0?ooo`<00000103oool2000004X0oooo00270?ooo`D000007`3oool3000000L0oooo
00<000000?ooo`000000B@3oool008T0oooo00<000000?ooo`3oool0703oool3000000X0oooo00@0
00000?ooo`3oool00000B03oool005D0oooo0P0000000`3oool000000000000_0?ooo`030000003o
ool0oooo01T0oooo0`00000=0?ooo`040000003oool0oooo000004P0oooo001F0?ooo`030000003o
ool000000300oooo00<000000?ooo`3oool05`3oool200000100oooo00D000000?ooo`3oool0oooo
000000170?ooo`00E`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01@0oooo0`00
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A03oool005D0oooo0P000000
0`3oool000000000000^0?ooo`8000004`3oool3000001D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`140?ooo`00VP3oool3000001P0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`130?ooo`00U`3oool3000001/0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`120?ooo`00U03oool3000001h0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`120?ooo`00T@3oool300000240oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`110?ooo`00SP3oool3000002@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`10
0?ooo`00R`3oool3000002P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`100?oo
o`00R03oool3000000<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo03l0oooo00250?ooo`<00000;P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo03h0oooo001Q0?ooo`8000007`3oool300000340oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0n0?ooo`00H03oool010000000oooo0?ooo`00000K0?ooo`<00000=03o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03d0oooo001P0?ooo`040000003oool0
oooo000001T0oooo0P00000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?03o
ool00600oooo00@000000?ooo`3oool000005P3oool3000003T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0l0?ooo`00H03oool010000000oooo0?ooo`00000C0?ooo`<00000?03o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03/0oooo001Q0?ooo`8000004@3oool3
000003l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0j0?ooo`00L@3oool30000
0480oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0j0?ooo`00KP3oool3000004D0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0i0?ooo`00J`3oool3000004P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0h0?ooo`00J03oool3000004/0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0h0?ooo`00I@3oool3000004h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0g0?ooo`00HP3oool300000080oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03H0oooo001O0?ooo`<0
0000E03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03H0oooo000k0?ooo`D00000
703oool3000003d0oooo4000000:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
=@3oool003d0oooo00<000000?ooo`3oool06@3oool3000003X0oooo1P0000030>Cbi0030000003O
kMl0gngO00P0gngO00<000000=SVf00000000`0000060?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0=03oool003d0oooo00<000000?ooo`3oool05`3oool2000003T0oooo10000009
0>Cbi0030000003OkMl0gngO00T0gngO00<000000=SVf03Hi]P00P3Hi]P400000080oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0d0?ooo`00=@3oool4000000@0oooo00<000000?oo
o`3oool0503oool3000003L0oooo100000000`3Wm^L000000>Cbi00;0>Cbi0030000003OkMl0gngO
00P0gngO00<000000=SVf03Hi]P01P3Hi]P3000001@0oooo00<000000?ooo`3oool0<`3oool003d0
oooo00<000000?ooo`3oool04@3oool3000003H0oooo100000060>Ofi`030000003Tl^@0i?;T00T0
i?;T00<000000=o]g`3OkMl02@3OkMl00`000000f>KH0=SVf0070=SVf0030000003oool0oooo01<0
oooo00<000000?ooo`3oool0<P3oool003`0oooo0P00000@0?ooo`<00000=P3oool3000000X0ioKW
00<000000>Cbi03Tl^@02P3Tl^@00`000000gngO0=o]g`080=o]g`030000003Hi]P0f>KH00L0f>KH
0P00000D0?ooo`030000003oool0oooo0380oooo001;0?ooo`<00000=`3oool2000000030>Whj@00
0000ioKW00/0ioKW00<000000>Cbi03Tl^@02@3Tl^@00`000000gngO0=o]g`090=o]g`030000003H
i]P0f>KH00H0f>KH0P00000E0?ooo`030000003oool0oooo0340oooo00180?ooo`<00000>03oool2
000000<0jOSY00<000000>Ofi`3Wm^L02P3Wm^L00`000000i?;T0>Cbi00:0>Cbi0030000003OkMl0
gngO00P0gngO00<000000=SVf03Hi]P01P3Hi]P00`000000f>KH0000000E0?ooo`030000003oool0
oooo0300oooo00150?ooo`<00000>@3oool2000000H0jOSY00<000000>Ofi`3Wm^L02P3Wm^L00`00
0000i?;T0>Cbi0090>Cbi0030000003OkMl0gngO00T0gngO00<000000=SVf03Hi]P01@3Hi]P00`00
0000f>KH0000000E0?ooo`030000003oool0oooo0300oooo00120?ooo`<00000>P3oool2000000P0
jOSY00<000000>Ofi`3Wm^L02P3Wm^L00`000000i?;T0>Cbi00:0>Cbi0030000003OkMl0gngO00P0
gngO00<000000=SVf03Hi]P01@3Hi]P010000000f>KH0=SVf000000E0?ooo`030000003oool0oooo
02l0oooo000o0?ooo`<00000>`3oool2000000/0jOSY00<000000>Ofi`3Wm^L02P3Wm^L00`000000
i?;T0>Cbi0090>Cbi0030000003OkMl0gngO00T0gngO00<000000=SVf03Hi]P0103Hi]P010000000
f>KH0=SVf000000F0?ooo`030000003oool0oooo02h0oooo000l0?ooo`<000000`3oool00`000000
oooo0?ooo`0g0?ooo`030000003Yn>T0jOSY00`0jOSY00<000000>Ofi`3Wm^L02@3Wm^L00`000000
i?;T0>Cbi0050>Cbi0/000001@3OkMl00`000000f>KH0=SVf0050=SVf0040000003Hi]P0f>KH0000
01D0oooo00<000000?ooo`3oool0;P3oool003T0oooo0`00000n0?ooo`80000000<0jo[[0000003Y
n>T0303Yn>T00`000000ioKW0>Ofi`090>Ofi`P000001@3SlN<00`000000g^cN0=k/gP030=k/gPP0
00001@3Hi]P010000000f>KH0=SVf000000F0?ooo`030000003oool0oooo01h0oooo0P00000=0?oo
o`00=P3oool3000003l0oooo0P0000030>_jj`030000003Yn>T0jOSY00`0jOSY00<000000>Ofi`3W
m^L0103Wm^L400000080ioGW00<000000>?ah`3SlN<02@3SlN<00`000000g^cN0=k/gP080=k/gP03
0000003EhmD00000008000000P3Hi]P01@000000f>KH0=SVf03Hi]P0000001H0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0;0?ooo`00<`3oool300000400oooo0P0000060>_jj`03
0000003Yn>T0jOSY00/0jOSY00<000000>Ofi`3Wm^L0100000060>Oei`030000003SlN<0ho7S00T0
ho7S00<000000=k/gP3Nk=h02@3Nk=h010000000eN?E0=GSe@3EhmD3000000<0f>KH00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00X0oooo000a0?ooo`80
0000@@3oool2000000T0jo[[00<000000>Whj@3Yn>T02P3Yn>T3000000/0ioGW00<000000>?ah`3S
lN<02@3SlN<00`000000g^cN0=k/gP080=k/gP030000003EhmD0eN?E00<0eN?E100000000`3Hi]P0
00000?ooo`0E0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`0000002`3oool002h0oooo
0`0000110?ooo`8000002`3[n^/00`000000jOSY0>Whj@080>Whj@8000000P3Yn>T00`000000ioGW
0>Oei`090>Oei`030000003SlN<0ho7S00T0ho7S00<000000=k/gP3Nk=h02@3Nk=h00`000000eN?E
0=GSe@020=GSe@040000003EhmD0eN?E0=GSe@8000005`3oool00`000000oooo0?ooo`0K0?ooo`04
0000003oool0oooo000000/0oooo000[0?ooo`<00000@`3oool00`000000jo[[0>_jj`0<0>_jj`03
0000003Yn>T0jOSY00D0jOSY0P0000040>Whj@030000003WmNL0ioGW00X0ioGW00<000000>?ah`3S
lN<02@3SlN<00`000000g^cN0=k/gP080=k/gP030000003EhmD0eN?E0080eN?E00<000000=GSe@3E
hmD00P3EhmD00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo0`0000000`3oool0
00000000000:0?ooo`00:03oool3000004@0oooo0P0000000`3/nn`000000>_jj`0=0>_jj`030000
003Yn>T0jOSY0080jOSY0P0000070>Whj@030000003WmNL0ioGW00X0ioGW00<000000>?ah`3SlN<0
203SlN<00`000000g^cN0=k/gP080=k/gP030000003EhmD0eN?E0080eN?E00<000000=GSe@3EhmD0
0`3EhmD00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo0P00000R0?ooo`009@3o
ool3000004D0oooo0P0000030>ckk0030000003[n^/0jo[[00`0jo[[00<000000>Whj@3Yn>T00P00
00090>Whj@030000003WmNL0ioGW00X0ioGW00<000000>?ah`3SlN<02@3SlN<00`000000g^cN0=k/
gP080=k/gP050000003EhmD0eN?E0=GSe@0000001@3EhmD00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000008@3oool00280oooo0`0000160?ooo`800000
1P3/nn`00`000000jo[[0>_jj`0;0>_jj`<00000303Yn>T00`000000ioGW0>Oei`0:0>Oei`030000
003SlN<0ho7S00P0ho7S00<000000=k/gP3Nk=h0203Nk=h01@000000eN?E0=GSe@3EhmD0000000H0
eN?E00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0240oooo000O0?ooo`<00000A`3oool2000000T0k?_/00<000000>_jj`3[n^/0203[n^/200000080
joW[00<000000>Whj@3Yn>T02`3Yn>T00`000000ioGW0>Oei`090>Oei`030000003SlN<0ho7S00T0
ho7S00<000000=k/gP3Nk=h0203Nk=h010000000eN?E0=GSe@0000060=GSe@030000003oool0oooo
01H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000Q0?ooo`007@3oool20000
04P0oooo0P00000<0>ckk0030000003[n^/0jo[[00D0jo[[0P0000040>_ij`030000003Yn>T0jOSY
00/0jOSY00<000000>Oei`3WmNL02@3WmNL?000000P0g^cN00@000000=GSe@3EhmD000001P3EhmD0
0`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0O0?ooo`007@3oool2000004H0oooo0P00000>0>ckk0030000003[n^/0jo[[00<0jo[[0P000007
0>_ij`030000003Yn>T0jOSY00/0jOSY00<000000>Oei`3WmNL0103WmNL4000000030>KdiP000000
h_3R00X0h_3R00<000000=cYg00000001@0000030=k/gP030000003EhmD0000000L0eN?E00<00000
0?ooo`3oool0503oool3000000@0oooo0P00000R0?ooo`007@3oool00`000000oooo000000130?oo
o`80000000<0kOc]0000003/nn`03P3/nn`00`000000jo[[0>_jj`02000000T0joW[00<000000>Wh
j@3Yn>T02`3Yn>T00`000000ioGW0>Oei`04000000H0i_CV00<000000>;`hP3Rl>80203Rl>800`00
0000g>WL0=cYg0050=cYg0H000001`3EhmD00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
02D0oooo000M0?ooo`040000003oool0oooo00000440oooo00D000000>glk@3]o>d0kOc]0000000@
0>ckk0800000303[nN/00`000000jOSY0>Whj@0:0>Whj@<000002P3Vm>H00`000000h_3R0>;`hP09
0>;`hP030000003LjM`0g>WL00D0g>WL1P0000060=GSe@030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0903oool001d0oooo00D000000?ooo`3oool0oooo0000000n0?ooo`8000001@3]o>d0
0`000000k?_/0>ckk00;0>ckk080000000<0k?[/0000003[nN/0303[nN/00`000000jOSY0>Whj@05
0>Whj@@000000P3XmnP00`000000i_CV0>KdiP090>KdiP030000003Rl>80h_3R00P0h_3R00<00000
0=cYg03LjM`00P3LjM`3000000<0g>WL00<000000=;OdP0000000P0000050=GSe@030000003oool0
oooo01L0oooo00<000000?ooo`3oool0903oool001d0oooo00D000000?ooo`3oool0oooo0000000l
0?ooo`800000203]o>d00`000000k?_/0>ckk0080>ckk08000000`3/n^`00`000000joW[0>_ij`0;
0>_ij`040000003Yn>T0jOSY0>Whj@@000001P3XmnP00`000000i_CV0>KdiP090>KdiP030000003R
l>80h_3R00T0h_3R100000070=cYg0040000003Bgm8000000=;OdP<000000P3EhmD00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo02<0oooo000L0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0>03oool00`000000kOc]0>glk@090>glk@030000003/nn`0k?_/00D0k?_/0P00
00060>cjk0030000003[nN/0joW[00X0joW[1000000;0>Sgj0030000003Vm>H0i_CV00T0i_CV00<0
00000>;`hP3Rl>801@3Rl>85000000T0g>WL00@000000=;OdP3Bgm8000000`3Bgm82000000030=GS
e@000000oooo01T0oooo00<000000?ooo`3oool08P3oool001`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0e0?ooo`800000303]o>d00`000000k?_/0>ckk0030>ckk0800000203/
n^`00`000000joW[0>_ij`080>_ij`8000000P3ZnNX00`000000j?OX0>Sgj00:0>Sgj0030000003V
m>H0i_CV00T0i_CV00<000000>;`hP3Rl>800P3Rl>83000000@0h_3R00<000000=cYg03LjM`0203L
jM`010000000d]oB0=;OdP0000040=;OdP8000006P3oool00`000000oooo0?ooo`0R0?ooo`00703o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03<0oooo00<000000>glk@3]o>d03@3]
o>d00`000000k?_/0>ckk002000000/0k?[/00<000000>_ij`3[nN/01@3[nN/2000000@0j_WZ00<0
00000>Sgj03XmnP02`3XmnP00`000000i_CV0>KdiP090>KdiP@00000203Rl>800`000000g>WL0=cY
g0080=cYg0030000003Bgm80000000H0d]oB00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0Q0?ooo`00703oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0300oooo0P000000
0`3^o>h000000>glk@0=0>glk@<000003P3/n^`00`000000joW[0>_ij`020>_ij`8000001`3ZnNX0
0`000000j?OX0>Sgj00;0>Sgj0030000003Vm>H0i_CV00H0i_CV0`00000;0>;`hP030000003LjM`0
g>WL00P0g>WL00@000000=;OdP3Bgm8000001@3Bgm800`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo0200oooo000L0?ooo`800000203oool00`000000oooo0?ooo`0]0?ooo`800000103^o>h0
0`000000kOc]0>glk@090>glk@8000000P3/nn`00`000000k?[/0>cjk00<0>cjk0030000003[nN/0
joW[008000002P3ZnNX00`000000j?OX0>Sgj00:0>Sgj0030000003Vm>H0i_CV00<0i_CV5@000008
0=cYg0040000003Bgm80d]oB000000D0d]oB00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0P0?ooo`005@3oool2000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Z
0?ooo`8000001`3^o>h00`000000kOc]0>glk@060>glk@8000001@3/nn`00`000000k?[/0>cjk00;
0>cjk0<000003@3ZnNX00`000000j?OX0>Sgj0090>Sgj0L000001P3Um>D00`000000hNoQ0>7_h@09
0>7_h@030000003JimX0000000D000000P3LjM`010000000d]oB0=;OdP0000050=;OdP030000003o
ool0oooo01T0oooo00<000000?ooo`3oool07`3oool001@0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo0P00000:0>klkP030000003]
o>d0kOc]00<0kOc]0P0000080>ckk0030000003/n^`0k?[/00P0k?[/0P0000020>_jj`030000003Z
nNX0j_WZ00/0j_WZ00<000000>Sgj03XmnP01@3XmnP7000000X0iOCU00<000000>7_h@3Qkn402@3Q
kn400`000000f^OJ0=[WfP050=[WfP@000000P3Bgm800`000000d]oB0=;OdP030=;OdP030000003o
ool0oooo01T0oooo00<000000?ooo`3oool07P3oool001L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02@0oooo0P00000=0>klkP030000003]o>d0
kOc]008000002P3/nn`00`000000k?[/0>cjk0060>cjk08000001@3[n^/00`000000j_WZ0>[ijP0;
0>[ijP030000003XmnP0j?OX00@0000000@0j?OX00000000000000000P3XmnP00`000000iOCU0>Gd
i@090>Gdi@030000003Qkn40hNoQ00T0hNoQ00<000000=[WfP3JimX01`3JimX3000000030=;OdP00
0000d]oB00<0d]oB00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0N0?ooo`003P3oool4
000000<0oooo0P0000050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08@3oool2
000000l0k_c^0`00000=0>ckk0030000003/n^`0k?[/00<0k?[/0P0000080>_jj`030000003ZnNX0
j_WZ00X0j_WZ0`0000020>Sgj0<000001P3XmnP00`000000iOCU0>Gdi@090>Gdi@030000003Qkn40
hNoQ00P0hNoQ00<000000=[WfP3JimX0203JimX010000000cM[=0000000000050=;OdP030000003o
ool0oooo01T0oooo00<000000?ooo`3oool07@3oool001D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01l0oooo0P0000020>glk@030000003^o>h0
k_c^00X0k_c^0P0000020>gkk@030000003/nn`0k?_/00`0k?_/00<000000>cjk03/n^`00P00000:
0>_jj`030000003ZnNX0j_WZ00L0j_WZ0`0000000`3Zn>X0000000000002000000X0j?OX00<00000
0>Gdi@3Um>D0203Um>D00`000000hNoQ0>7_h@090>7_h@030000003JimX0f^OJ00L0f^OJ00@00000
0<gJc@3=f/d0cM[=0P0000030=;OdP030000003oool0oooo01X0oooo00<000000?ooo`3oool0703o
ool001D0oooo0`0000030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0703oool2
000000D0kOc]00<000000>klkP3^o>h01`3^o>h2000000D0kO_]00<000000>ckk03/nn`02`3/nn`3
000000d0jo[[00<000000>[ijP3ZnNX0103ZnNX2000000060>[hjP00000000000000003Zn>X00000
303XmnP00`000000iOCU0>Gdi@090>Gdi@030000003Qkn40hNoQ00P0hNoQ00<000000=[WfP3JimX0
203JimX010000000cM[=0<gJc@3=f/d300000080d]oB00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0L0?ooo`006`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo
0P0000080>glk@8000001@3^o>h2000000P0kO_]00<000000>ckk03/nn`0203/nn`200000080k?[/
00<000000>_jj`3[n^/0303[n^/00`000000j_WZ0>[ijP06000000D0j_SZ00<000000>Sgj03XmnP0
2P3XmnP00`000000iOCU0>Gdi@090>Gdi@030000003Qkn40hNoQ00P0hNoQ00<000000=[WfP3JimX0
1`3JimX00`000000cM[=0<gJc@020<gJc@030000003=f/d0000000800000703oool00`000000oooo
0?ooo`0K0?ooo`006`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01H0oooo0P00
000<0>glk@030000003^o>h0k_c^008000002P3]nnd00`000000k?_/0>ckk0060>ckk08000001@3/
n^`00`000000jo[[0>_jj`0;0>_jj`H000002@3Zn>X00`000000j?OX0>Sgj00:0>Sgj0030000003U
m>D0iOCU00P0iOCU00<000000>7_h@3Qkn40203Qkn400`000000f^OJ0=[WfP080=[WfP050000003=
f/d0cM[=0<gJc@0000000`3=f/d2000001`0oooo00<000000?ooo`3oool06P3oool001/0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`<000003P3]o>d3000000d0kO_]00<0
00000>ckk03/nn`00`3/nn`2000000P0k?[/00<000000>_jj`3[n^/0203[n^/5000000d0j_SZ00<0
00000>Sgj03XmnP02@3XmnP00`000000iOCU0>Gdi@040>GdiA800000203JimX00`000000cM[=0<gJ
c@020<gJc@050000003=f/d0cM[=0<gJc@000000703oool00`000000oooo0?ooo`0J0?ooo`006`3o
ool400000100oooo00<000000?ooo`3oool03@3oool400000080j_WZ0P00000;0>glk@8000000P3/
nn`00`000000kO_]0>gkk@0<0>gkk@030000003/nn`0k?_/008000002P3/n^`00`000000jo[[0>_j
j`060>_jj`@000000P3[nN/00`000000j_SZ0>[hjP0;0>[hjP030000003XmnP0j?OX00P0j?OX2000
00060>Gci@030000003Pk^00h>kP00P0h>kP1@0000050=[WfP030000003=f/d0cM[=0080cM[=00D0
00000<gJc@3=f/d0cM[=0000000L0?ooo`030000003oool0oooo01T0oooo000K0?ooo`030000003o
ool0000000D000003@3oool00`000000oooo0?ooo`080?ooo`@00000203ZnNX2000000H0kOc]0`00
00050>ckk0030000003]nnd0kO_]00/0kO_]0`00000=0>cjk0030000003[n^/0jo[[00<0jo[[0`00
00060>_ij`030000003Zn>X0j_SZ00/0j_SZ00@000000>Sgj03XmnP0j?OX1P0000030>Sfj0030000
003UlnD0iO?U00P0iO?U00<000000>3^h03Pk^00203Pk^000`000000enGG0=OUe`020=OUe`@00000
00<0f^OJ0000003=f/d00`3=f/d01@000000cM[=0<gJc@3=f/d0000001d0oooo00<000000?ooo`3o
ool0603oool001/0oooo00<000000?ooo`3oool00P3oool5000000`0oooo00<000000?ooo`3oool0
0`3oool4000000h0j_WZ0P0000020>glk@8000002@3/nn`00`000000kO_]0>gkk@070>gkk@<00000
0P3/n^`00`000000k?[/0>cjk00<0>cjk0030000003[n^/00000008000002P3[nN/00`000000j_SZ
0>[hjP0:0>[hjP@000002@3Xm^P00`000000iO?U0>Gci@090>Gci@030000003Pk^00h>kP00P0h>kP
00<000000=OUe`3GiML01@3GiML3000000@0cM[=00D000000<gJc@3=f/d0cM[=0000000L0?ooo`03
0000003oool0oooo01P0oooo000K0?ooo`030000003oool0oooo00H0oooo1P0000080?ooo`D00000
0`3Lj]`2000000h0j_WZ0`00000<0>ckk0030000003]nnd0kO_]00@0kO_]0P0000060>cjk0030000
003/n^`0k?[/00T0k?[/1@00000=0>_ij`030000003Zn>X0j_SZ00H0j_SZ0`0000020>Whj@030000
003Xm^P0j?KX00T0j?KX00<000000>Gci@3UlnD0203UlnD00`000000h>kP0>3^h0080>3^h0030000
003GiML0enGG00P0enGG0P0000030<gJc@040000003=f/d0cM[=000001d0oooo00<000000?ooo`3o
ool05`3oool001/0oooo00<000000?ooo`3oool0203oool200000080XJ^Q2000000:0=cZg0800000
203ZnNX400000080j?OX00<000000>ckk03/nn`02`3/nn`00`000000kO_]0>gkk@03000000T0k?[/
00<000000>cjk03/n^`01@3/n^`500000080jo[[00<000000>_ij`3[nN/02`3[nN/00`000000j_SZ
0>[hjP040>[hjP8000001@3Yn>T00`000000j?KX0>Sfj0090>Sfj0030000003UlnD0iO?U00T0iO?U
00<000000>3^h03Pk^00203Pk^000`000000enGG0=OUe`070=OUe`0400000038e<P0000000000080
cM[=00@000000<gJc@3=f/d000007@3oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000
oooo0?ooo`0:0?ooo`8000001P2QZj42000000`0g>[L0P0000020>[ijP@000001`3XmnP00`000000
k?_/0>ckk00:0>ckk0<000003@3/n^`010000000k?[/0>cjk03/n^`5000000H0jo[[00<000000>_i
j`3[nN/02`3[nN/00`000000j_SZ0>[hjP03000000P0jOSY00<000000>Sfj03Xm^P02@3Xm^P00`00
0000iO?U0>Gci@090>Gci@030000003Pk^00h>kP00L0h>kP00<000000=OUe`3GiML0203GiML00`00
0000b=C80<SDb00300000080cM[=00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0F0?oo
o`006P3oool3000000d0oooo1P0000020:6[X@8000001`3Lj]`7000000`0j?OX00<000000>ckk03/
nn`01`3/nn`200000080joW[00<000000>cjk03/n^`0303/n^`6000000T0jo[[00<000000>_ij`3[
nN/02P3[nN/3000000/0jOSY00<000000>Sfj03Xm^P02P3Xm^P00`000000iO?U0>Gci@080>Gci@03
0000003Pk^00h>kP00P0h>kP00<000000=OUe`3GiML01`3GiML00`000000b=C80<SDb0020<SDb080
00000P3=f/d00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01D0oooo000C0?ooo`800000
1@3oool00`000000oooo0?ooo`0@0?ooo`80000000<0XjfS0000000000002@0000060=[XfP030000
003XmnP0j?OX00/0j?OX00<000000>ckk03/nn`00`3/nn`3000000D0joW[00<000000>cjk03/n^`0
203/n^`6000000`0jo[[00<000000>_ij`3[nN/01`3[nN/300000080j_WZ00<000000>Whj@3Yn>T0
2P3Yn>T00`000000j?KX0>Sfj0090>Sfj0030000003UlnD0iO?U00@0iO?U2`0000040>3^h0030000
003GiML0enGG00P0enGG00<000000<SDb038e<P00`38e<P3000001h0oooo00<000000?ooo`3oool0
503oool00180oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0B0?ooo`800000
1@2S[J<2000000X0f^SJ00<000000>Sgj03XmnP02`3XmnP00`000000k?_/0>ckk002000000T0joW[
00<000000>cjk03/n^`0103/n^`600000080jo[[00<000000>_jj`3[n^/02`3[n^/00`000000joW[
0>_ij`040>_ij`8000001@3ZnNX00`000000jOSY0>Whj@0;0>Whj@030000003Xm^P0j?KX00L0j?KX
200000060>Cbi0030000003NkMh0g^gN0080g^gN1`0000080=OUe`0300000038e<P0b=C800<0b=C8
00@000000<SDb000000000007@3oool00`000000oooo0?ooo`0D0?ooo`004P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo01@0oooo100000030:>]X`8000002@3Jj=X2000000X0
j?OX1000000<0>_ij`030000003/n^`0k?[/00<0000000<0k?[/0000000000001P3[n^/00`000000
jo[[0>_jj`0;0>_jj`030000003[nN/0joW[00<00000203ZnNX00`000000jOSY0>Whj@0:0>Whj@04
0000003Xm^P0j?KX0>Sfj0H000000`3Wm^L00`000000i?;T0>Cbi0080>Cbi0030000003NkMh0g^gN
00P0g^gN1@0000050=OUe`0300000038e<P0b=C800<0b=C800<000000<SDb00000007P3oool00`00
0000oooo0?ooo`0C0?ooo`004P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
01H0oooo2@0000090=[XfP040000003XmnP0j?OX0>Sgj0H000000`3WmNL00`000000joW[0>_ij`0:
0>_ij`<0000000@0k?[/00000000000000002@3[n^/00`000000jo[[0>_jj`0:0>_jj`<00000303Z
nNX00`000000jOSY0>Whj@090>Whj@@000002@3Wm^L00`000000i?;T0>Cbi0090>Cbi0030000003N
kMh0g^gN00L0g^gN00<000000=CRe03Dh]@00P3Dh]@4000000030=OUe`000000b=C800D0b=C800<0
00000<SDb00000007P3oool00`000000oooo0?ooo`0B0?ooo`004P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo01P0oooo0P0000030:NaY`l000002P3WmNL00`000000joW[0>_i
j`060>_ij`<0000000@0joW[0000000000000000303[n^/00`000000jo[[0>_jj`070>_jj`<00000
0P3[nN/00`000000j_WZ0>[ijP0;0>[ijP030000003Yn>T0jOSY00@0jOSY100000020>Whj@030000
003Wm^L0ioKW00T0ioKW00<000000>Cbi03Tl^@02@3Tl^@00`000000g^gN0=k]gP070=k]gP030000
003Dh]@0e>;D00D0e>;D0`0000060<SDb08000007P3oool00`000000oooo0?ooo`0B0?ooo`00103o
ool4000000/0oooo0P0000050?ooo`030000003oool0oooo01T0oooo100000030:NaY`800000203I
i]T2000000/0ioGW0P0000020>_ij`@0000000@0joW[00000000000000000P3Yn>T00`000000jo[[
0>_jj`0;0>_jj`030000003[n^/0jo[[00@0jo[[0P0000050>_ij`030000003ZnNX0j_WZ00/0j_WZ
00<000000>Whj@3Yn>T0100000060>Whj@030000003Wm^L0ioKW00X0ioKW00<000000>Cbi03Tl^@0
2@3Tl^@00`000000g^gN0=k]gP070=k]gP030000003Dh]@0e>;D00L0e>;D0P0000040<SDb0030000
0038e<P0000001h0oooo00<000000?ooo`3oool04@3oool000<0oooo00@000000?ooo`3oool00000
4`3oool00`000000oooo0?ooo`0J0?ooo`H000000P2W/JL00`000000fNKI0=WVf@070=WVf@030000
003WmNL0ioGW00T0ioGW0`0000000`3[nN/0000000000002000000H0jOSY00<000000>_jj`3[n^/0
2`3[n^/00`000000jo[[0>_jj`03000000P0joW[00<000000>[ijP3ZnNX02P3ZnNX3000000/0jOSY
00<000000>Ofi`3Wm^L02P3Wm^L00`000000i?;T0>Cbi0080>Cbi0030000003NkMh0g^gN00P0g^gN
00<000000=CRe03Dh]@01P3Dh]@010000000`Lg10000000000030<SDb08000007`3oool00`000000
oooo0?ooo`0@0?ooo`000`3oool010000000oooo0?ooo`00000C0?ooo`030000003oool0oooo01/0
oooo0`0000020:fh[@D00000203Ii]T2000000H0ioGW1`00000;0>Whj@030000003[n^/0jo[[00X0
jo[[0`00000<0>_ij`030000003ZnNX0j_WZ00H0j_WZ0`0000020>[hjP030000003Yn>T0jOSY00X0
jOSY00<000000>Ofi`3Wm^L02@3Wm^L00`000000i?;T0>Cbi0040>Cbi0P000001`3NkMh00`000000
e>;D0=CRe0070=CRe00400000031cL40`Lg1000000<0b=C80P00000N0?ooo`030000003oool0oooo
0100oooo00020?ooo`80000000<0oooo0000000000004`3oool00`000000oooo0?ooo`0M0?ooo`<0
0000102]^:dA000000H0iOCU00<000000>Whj@3Yn>T02P3Yn>T00`000000jo[[0>_jj`050>_jj`@0
00000P3ZnNX00`000000joW[0>_ij`0;0>_ij`030000003ZnNX0j_WZ00<0j_WZ0P0000050>[hjP03
0000003Yn>T0jOSY00/0jOSY00<000000>Ofi`3Wm^L01`3Wm^L8000000H0i?;T00<000000=g[g@00
00001@0000020=k]gP030000003Dh]@0e>;D00H0e>;D00@000000<7=`@31cL40`Lg10P0000000`38
e<P000000000000O0?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo01h0
oooo0`0000050:fh[@030000003Hi]P0f>KH00H0f>KH0`00000:0>Gdi@030000003Yn>T0jOSY00X0
jOSY00<000000>_jj`3[n^/0100000070>[ijP030000003[nN/0joW[00X0joW[00<000000>[ijP3Z
nNX00`0000080>[hjP030000003Yn>T0jOSY00X0jOSY00@000000>Ofi`3Wm^L0ioKW1P0000030>Of
i`030000003Tl^@0i?;T00P0i?;T00<000000=g[g@3Mjmd01@3Mjmd5000000L0e>;D00<000000<7=
`@31cL400P31cL44000001l0oooo00<000000?ooo`3oool03P3oool001X0oooo00<000000?ooo`3o
ool07`3oool4000000@0[KR]00<000000=SVf03Hi]P00P3Hi]P300000080f>KH00<000000>Gdi@3U
m>D02@3Um>D2000000T0jOSY1000000<0>[ijP030000003[nN/0joW[00T0joW[0`00000<0>[hjP03
0000003Yn>T0jOSY00T0jOSY100000090>Ofi`030000003Tl^@0i?;T00T0i?;T00<000000=g[g@3M
jmd0203Mjmd5000000@0e>;D00<000000<7=`@31cL400`31cL42000001l0oooo00<000000?ooo`3o
ool03P3oool001T0oooo00<000000?ooo`3oool08@3oool600000080[KR]100000060=SVf0800000
2`3Um>D010000000jOSY0>Whj@3Yn>T5000000<0j?OX00<000000>[ijP3ZnNX02`3ZnNX00`000000
joW[0>_ij`050>_ij`<000000P3ZnNX00`000000j_SZ0>[hjP0;0>[hjP030000003Yn>T0jOSY00@0
jOSY100000020>Wgj@030000003Wm^L0ioKW00T0ioKW00<000000>Cbi03Tl^@0203Tl^@00`000000
gN_M0=g[g@080=g[g@030000003Ag]40dMkA0080dMkA1@0000060<7=`@8000007`3oool00`000000
oooo0?ooo`0=0?ooo`006@3oool00`000000oooo0?ooo`0R0?ooo`<000000P2d_k@5000000T0f>KH
00<000000>Gdi@3Um>D0103Um>D8000000T0j?OX00<000000>[ijP3ZnNX02`3ZnNX00`000000joW[
0>_ij`04000000H0j_WZ00<000000>[hjP3Zn>X02P3Zn>X00`000000jOSY0>Whj@04000000H0jOOY
00<000000>Ofi`3Wm^L02P3Wm^L00`000000i?;T0>Cbi0080>Cbi0030000003Mjmd0gN_M00P0gN_M
00<000000=7Nd@3Ag]401@3Ag]42000000H0`Lg10P00000O0?ooo`030000003oool0oooo00`0oooo
000I0?ooo`030000003oool0oooo02<0oooo100000040;Bo]14000001P3Tl^@00`000000j?OX0>Sg
j0090>Sgj0030000003ZnNX0j_WZ00X0j_WZ0`00000;0>[ijP030000003Zn>X0j_SZ00T0j_SZ0`00
000;0>Wgj@030000003Wm^L0ioKW00X0ioKW00<000000>Cbi03Tl^@0203Tl^@00`000000gN_M0=g[
g@080=g[g@030000003Ag]40dMkA00H0dMkA0P0000050<7=`@030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0303oool001T0oooo00<000000?ooo`3oool0803oool300000080oooo0`000005
0;Bo]0030000003Hi]P0f>KH00L0f>KH00<000000>Cbi03Tl^@02@3Tl^@00`000000j?OX0>Sgj009
0>Sgj0030000003ZnNX0j_WZ00D0j_WZ100000020>Whj@030000003ZnNX0j_WZ00X0j_WZ00<00000
0>[hjP3Zn>X01@3Zn>X300000080jOSY00<000000>Wgj@3YmnT02P3YmnT00`000000ioKW0>Ofi`09
0>Ofi`030000003Tl^@0i?;T00P0i?;T00<000000=g[g@3Mjmd02@3Mjmd00`000000dMkA0=7Nd@05
0=7Nd@040000002ia;T00000000000@0`Lg100<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0;0?ooo`006@3oool00`000000oooo0?ooo`0M0?ooo`<000001P3oool4000000@0];nd00<00000
0=SVf03Hi]P01`3Hi]P00`000000i?;T0>Cbi0080>Cbi0030000003XmnP0j?OX00X0j?OX00<00000
0>[ijP3ZnNX0100000060>Whj@030000003ZnNX0j_WZ00/0j_WZ00<000000>[hjP3Zn>X010000006
0>Whj@030000003YmnT0jOOY00X0jOOY00<000000>Ofi`3Wm^L01`3Wm^LC000000D0gN_M00<00000
0=7Nd@3Ag]401P3Ag]4010000000^LBi0;W4^@0000030<7=`@030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0103oool500000040oooo000I0?ooo`8000006`3oool3000000X0oooo1P000002
0;Bo]0800000203Hi]P00`000000i?;T0>Cbi0080>Cbi0030000003XmnP0j?OX00P0j?OX1000000;
0>Whj@030000003ZnNX0j_WZ00X0j_WZ0`00000;0>Whj@030000003YmnT0jOOY00T0jOOY00@00000
0>Ofi`3Wm^L0ioKW1P0000030>Ofi`030000003Tl^@0i?;T00P0i?;T00<000000=cZg03Lj]`00P3L
j]`8000000H0dMkA00@000000;W4^@2ia;T0^LBi0P0000020<7=`@030000003oool0oooo01d0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`010?ooo`004P3oool2000000D0oooo00<0
00000?ooo`3oool05`3oool3000000h0oooo0`0000020;c8_0D00000203Hi]P00`000000i?;T0>Cb
i0080>Cbi0040000003XmnP0j?OX0>Sgj0H000000`3Xm^P00`000000jOSY0>Whj@0:0>Whj@030000
003ZnNX0j_WZ00H0j_WZ0`0000020>[hjP030000003Yn>T0jOSY00T0jOSY00<000000>Wgj@3YmnT0
2@3YmnT4000000X0ioKW00<000000>Cbi03Tl^@0203Tl^@00`000000g>[L0=cZg0080=cZg0@00000
103Ag]400`000000^LBi0;W4^@020;W4^@80000000<0`Lg10000003oool07P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0040oooo000A0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0503oool300000180oooo00@0000008B=Q00000000000102lb;`6000000@0
f>KH00<000000>Cbi03Tl^@0103Tl^@7000000X0j?KX00<000000>Whj@3Yn>T02P3Yn>T00`000000
j_WZ0>[ijP030>[ijP8000001@3Zn>X00`000000jOSY0>Whj@0:0>Whj@030000003YmnT0jOOY00D0
jOOY0`0000020>Wgj@030000003Wm^L0ioKW00T0ioKW00<000000>Cbi03Tl^@0203Tl^@00`000000
g>[L0=cZg0090=cZg0030000003=f/d0cM[=008000000`3Ag]400`000000^LBi0;W4^@030;W4^@80
0000803oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo000D0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04@3oool3000001H0oooo00@0000008B=Q0000000
00001@2lb;`010000000fNOI0=WWf@3IimT;000000D0i?;T00<000000>Sfj03Xm^P02P3Xm^P00`00
0000jOSY0>Whj@090>Whj@030000003ZnNX0j_WZ00<00000203Zn>X00`000000jOSY0>Whj@0:0>Wh
j@030000003YmnT0jOOY00@000001P3YmnT00`000000ioKW0>Ofi`090>Ofi`030000003Tl^@0i?;T
00P0i?;T00<000000=cZg03Lj]`0203Lj]`00`000000cM[=0<gJc@020<gJc@@000001`2ia;T00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool00180
oooo0P0000050?ooo`030000003oool0oooo00h0oooo0`00000J0?ooo`0300000024SH@0Q8f40080
0000102lb;`00`000000fNOI0=WWf@060=WWf@030000003Tl^@0i?;T00P0i?;T00<000000>Sfj03X
m^P02P3Xm^P00`000000jOSY0>Whj@070>Whj@@00000303Zn>X00`000000jOSY0>Whj@090>Whj@<0
00002`3YmnT00`000000ioKW0>Ofi`090>Ofi`030000003Tl^@0i?;T00P0i?;T00<000000=cZg03L
j]`0203Lj]`00`000000cM[=0<gJc@040<gJc@8000001`2ia;T00`000000oooo0?ooo`0K0?ooo`<0
0000103oool2000000<0oooo000B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
303oool3000001h0oooo0P0000000`24SH@000000000000200000080_<Rl0P0000070=WWf@030000
003Tl^@0i?;T00P0i?;T00<000000>Sfj03Xm^P02P3Xm^P010000000jOSY0>Whj@3Yn>T5000000<0
jOSY00<000000>[hjP3Zn>X02`3Zn>X00`000000jOSY0>Whj@040>Whj@@000000P3Yn>T00`000000
jOOY0>Wgj@0:0>Wgj@030000003Wm^L0ioKW00L0ioKW4`0000050=cZg0030000003=f/d0cM[=00D0
cM[=0P0000050;W4^@8000006@3oool4000000030?ooo`000000oooo00P0oooo000B0?ooo`<00000
0`3oool00`000000oooo0?ooo`080?ooo`@000008P3oool20000000408B=Q0000000`lo30<??``D0
00001`3IimT00`000000i?;T0>Cbi0080>Cbi0030000003Xm^P0j?KX00P0j?KX1@0000090>Whj@03
0000003Zn>X0j_SZ00X0j_SZ00<000000>Whj@3Yn>T0100000070>Whj@030000003YmnT0jOOY00X0
jOOY00@000000>Ofi`3Wm^L0ioKW1@0000030>Ofi`030000003Tl^@0i?;T00P0i?;T00<000000=_Y
f`3KjM/00P3KjM/8000000H0cM[=0`0000040;W4^@030000003oool0oooo01@0oooo0`0000050?oo
o`030000003oool0oooo00L0oooo000H0?ooo`030000003oool0oooo00D0oooo0`00000V0?ooo`03
0000002KYI/00000008000001@33cl<4000000D0fNOI00<000000>Cbi03Tl^@0203Tl^@010000000
j?KX0>Sfj03Xm^P6000000<0ioKW00<000000>Whj@3Yn>T0203Yn>T00`000000j_SZ0>[hjP0:0>[h
jP<000002`3Yn>T00`000000jOOY0>Wgj@0:0>Wgj@@00000203Wm^L00`000000i?;T0>Cbi0090>Cb
i0030000003KjM/0fnWK00P0fnWK100000030<gJc@030000002^^Jh0[[V^008000000`2ia;T00`00
0000oooo0?ooo`0@0?ooo`<00000203oool00`000000oooo0?ooo`070?ooo`00603oool00`000000
oooo0?ooo`020?ooo`<00000:P3oool00`000000VjFK09^UV`02000000H0`lo300<000000=[XfP00
0000100000000`3IimT000000>Cbi0050>Cbi0L000002@3Wm^L00`000000jOSY0>Whj@090>Whj@03
0000003Zn>X0j_SZ00D0j_SZ100000020>Whj@030000003Yn>T0jOSY00X0jOSY00<000000>Wgj@3Y
mnT01@3YmnT400000080jOSY00<000000>Ofi`3Wm^L0203Wm^L00`000000i?;T0>Cbi0080>Cbi003
0000003KjM/0fnWK00P0fnWK00@000000<SEb038eLP0b=G80P0000020<gJc@040000002^^Jh0[[V^
0:ji[P8000000P2ia;T00`000000oooo0?ooo`0;0?ooo`@000002`3oool00`000000oooo0?ooo`07
0?ooo`00603oool00`000000oooo00000002000002h0oooo00<0000009^UV`2KYI/00P0000060<??
``030000003Jj=X0f^SJ00<0f^SJ200000050>?bh`030000003Wm^L0ioKW00T0ioKW00<000000>Wh
j@3Yn>T02@3Yn>T00`000000j_SZ0>[hjP04000000L0jOSY00<000000>Whj@3Yn>T02P3Yn>T00`00
0000jOOY0>Wgj@04000000H0jOSY00<000000>Ofi`3Wm^L02@3Wm^L00`000000i?;T0>Cbi0080>Cb
i0030000003KjM/0fnWK00P0fnWK00<000000<SEb038eLP00P38eLP4000000@0[[V^0`00000:0?oo
o`<000003`3oool00`000000oooo0?ooo`070?ooo`00603oool200000380oooo00@0000009^UV`2K
YI/0VjFK0P0000050<??``030000003Jj=X0f^SJ00D0f^SJ00<000000>?bh`3Sl^<0203Sl^<00`00
0000ioKW0>Ofi`090>Ofi`030000003Yn>T0jOSY00P0jOSY0`00000;0>Whj@030000003Yn>T0jOSY
00X0jOSY0`00000;0>Whj@030000003Wm^L0ioKW00T0ioKW00<000000>Cbi03Tl^@0203Tl^@00`00
0000fnWK0=_Yf`080=_Yf`0300000038eLP0b=G800@0b=G80P0000050:ji[P8000001@3oool40000
0180oooo00<000000?ooo`3oool01`3oool001T0oooo00<000000?ooo`3oool0<@3oool200000080
VjFK100000030<??``030000003Jj=X0f^SJ00D0f^SJ00<000000>?bh`3Sl^<0203Sl^<00`000000
ioKW0>Ofi`090>Ofi`030000003Yn>T0jOSY00@0jOSY0`0000020>Wgj@030000003Yn>T0jOSY00X0
jOSY00<000000>Whj@3Yn>T01@3Yn>T400000080jOSY00<000000>Whj@3Yn>T02P3Yn>T00`000000
ioKW0>Ofi`080>Ofi`030000003Tl^@0i?;T00@0i?;T2`0000040=_Yf`0300000038eLP0b=G800H0
b=G80P0000050:ji[P030000003oool00000008000005`3oool00`000000oooo0?ooo`060?ooo`00
6P3oool00`000000oooo0?ooo`0`0?ooo`030000002]^:d000000080VjFK00<000000<WFb@39e/T0
1@0000070=[XfP030000003Sl^<0ho;S00L0ho;S00<000000>Ofi`3Wm^L02@3Wm^L00`000000jOSY
0>Whj@04000000H0jOOY00<000000>Whj@3Yn>T02P3Yn>T00`000000jOSY0>Whj@04000000L0jOSY
00<000000>Whj@3Yn>T02P3Yn>T00`000000ioKW0>Ofi`060>Ofi`P000001P3Tl^@00`000000f^SJ
0=[XfP020=[XfPL000001`38eLP3000000<0[[V^0P00000J0?ooo`030000003oool0oooo00H0oooo
000K0?ooo`030000003oool0oooo0300oooo00<000000:fh[@0000000P0000060<WFb@@000001@3J
j=X00`000000ho;S0>?bh`070>?bh`030000003Wm^L0ioKW00L0ioKW1000000;0>Wgj@030000003Y
n>T0jOSY00T0jOSY0`00000;0>Whj@030000003Yn>T0jOSY00X0jOSY00@000000>Ofi`3Wm^L0ioKW
1@0000030>Sfj0030000003Tl^@0i?;T00T0i?;T00<000000=[XfP3Jj=X01`3Jj=X4000000@0b=G8
00@000000:6[X@2QZj4000000`2^^Jh00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0
oooo000L0?ooo`030000003oool0oooo0300oooo00<000000:fh[@2]^:d00P0000070<WFb@030000
003LjM`0000000@0000000<0f^SJ0000003Sl^<0203Sl^<010000000ioKW0>Ofi`3Wm^L5000000<0
ioKW00<000000>Wgj@3YmnT02@3YmnT00`000000jOSY0>Whj@070>Whj@8000000P3Yn>T00`000000
jOSY0>Whj@0:0>Whj@030000003Yn>T0jOSY00P0jOSY1@0000090>Sfj0030000003Tl^@0i?;T00T0
i?;T00<000000=[XfP3Jj=X01`3Jj=X00`000000`lo30<??``0300000080b=G800<000000:6[X@2Q
Zj400P0000020:ji[P030000003oool0oooo01L0oooo00<000000?ooo`3oool01P3oool001d0oooo
00<000000?ooo`3oool0<03oool00`000000[KR]0:fh[@02000000H0bMK900<000000=cYg03LjM`0
103LjM`?000000T0ioKW00<000000>Wgj@3YmnT02@3YmnT00`000000jOSY0>Whj@030>Whj@<00000
103Yn>T00`000000jOSY0>Whj@0;0>Whj@040000003Yn>T0jOSY0>Whj@H000000`3Yn>T00`000000
j?KX0>Sfj0090>Sfj0030000003Tl^@0i?;T00T0i?;T00<000000=[XfP3Jj=X01`3Jj=X00`000000
`lo30<??``020<??``@000000`2QZj42000000030:ji[P000000oooo01L0oooo00<000000?ooo`3o
ool01P3oool001h0oooo00<000000?ooo`3oool0;`3oool00`000000[KR]0:fh[@020:fh[@800000
1@39e/T00`000000g>WL0=cYg0060=cYg0030000003Sl^<0ho;S00L0ho;S00<000000>Ofi`3Wm^L0
203Wm^L00`000000jOOY0>Wgj@0:0>Wgj@030000003Yn>T0jOSY00800000203Yn>T00`000000jOSY
0>Whj@0:0>Whj@@000002P3Yn>T00`000000j?KX0>Sfj0090>Sfj0030000003Tl^@0i?;T00@0i?;T
2`0000040=[XfP0300000033cl<0`lo300@0`lo30P0000040:6[X@800000603oool00`000000oooo
0?ooo`060?ooo`007`3oool00`000000oooo0?ooo`0_0?ooo`030000002]^:d0[KR]0080[KR]0`00
00040<WFb@030000003LjM`0g>WL00H0g>WL00<000000>?bh`3Sl^<01`3Sl^<00`000000ioKW0>Of
i`080>Ofi`030000003YmnT0jOOY00P0jOOY1000000;0>Whj@030000003Yn>T0jOSY00H0jOSY0`00
00020>[hjP030000003Yn>T0jOSY00T0jOSY00<000000>Sfj03Xm^P0203Xm^P8000000H0i??T00<0
00000=[WfP3JimX00P3JimX7000000H0`lo30P0000040:6[X@030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01P3oool00200oooo00<000000?ooo`3oool0;`3oool01@000000[KR]0:fh[@2]
^:d000000080cmc?0`0000020<WFb@030000003LjM`0g>WL00D0g>WL00<000000>?bh`3Sl^<01`3S
l^<00`000000ioKW0>Ofi`090>Ofi`040000003YmnT0jOOY0>Wgj@H000000`3XmnP00`000000jOSY
0>Whj@0:0>Whj@030000003Yn>T0jOSY00<0jOSY0P0000060>[hjP030000003Yn>T0jOSY00T0jOSY
00@000000>Sfj03Xm^P0j?KX1P0000030>Sgj0030000003Tln@0i??T00T0i??T00<000000=[WfP3J
imX01`3JimX5000000<0`lo30`0000030:6[X@030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01P3oool00240oooo00<000000?ooo`3oool0;`3oool200000080[KR]00<000000<oLc`3?g<l0
0P3?g<l3000000P0g>WL00<000000>?bh`3Sl^<01`3Sl^<00`000000ioKW0>Ofi`070>Ofi`D00000
2P3XmnP00`000000jOSY0>Whj@090>Whj@030000003Yn>T0jOSY00<00000203Zn>X00`000000jOSY
0>Whj@090>Whj@@000002P3XmnP00`000000i??T0>Cci0090>Cci0030000003JimX0f^OJ00L0f^OJ
0P0000020;g9_@D0000000@0T9V@000000000000XJ^Q0P00000E0?ooo`030000003oool0oooo00H0
oooo000R0?ooo`030000003oool0oooo02h0oooo00<000000;_6^`0000000P2]^:d00`000000cmc?
0<oLc`030<oLc`H00000103LjM`00`000000ho;S0>?bh`070>?bh`040000003Wm^L0ioKW0>Ofi`D0
00000`3WmNL00`000000j?OX0>Sgj0090>Sgj0030000003Yn>T0jOSY00T0jOSY0`00000<0>[hjP03
0000003Yn>T0jOSY00D0jOSY0`0000020>[ijP030000003XmnP0j?OX00X0j?OX00<000000>Cci03T
ln@02@3Tln@00`000000f^OJ0=[WfP080=[WfP030000002mbKd0_LVm00<0_LVm0P000002092IT0@0
0000503oool00`000000oooo0?ooo`060?ooo`008`3oool00`000000oooo0?ooo`0^0?ooo`060000
002ka[/000000000002]^:d000001P3?g<l010000000gN_M0=g[g@3MjmdB000000T0ioGW00<00000
0>Sgj03XmnP02@3XmnP00`000000jOSY0>Whj@050>Whj@<000000P3Yn>T00`000000j_SZ0>[hjP0;
0>[hjP030000003Yn>T0jOSY00@000001P3ZnNX00`000000j?OX0>Sgj00:0>Sgj0030000003Tln@0
i??T00@0i??T4P0000050;g9_@8000000P2@VI03000001<0oooo00<000000?ooo`3oool01P3oool0
02@0oooo00<000000?ooo`3oool0;P3oool00`000000^lJk0;_6^`02000000L0cmc?00<000000=g[
g@3Mjmd01P3Mjmd00`000000i?;T0>Cbi0070>Cbi0030000003WmNL0ioGW00T0ioGW00<000000>Sg
j03XmnP02@3XmnP00`000000jOSY0>Whj@04000000H0jOSY00<000000>[hjP3Zn>X02P3Zn>X30000
00X0j_WZ00<000000>Sgj03XmnP02P3XmnP7000000H0iOCU00<000000=WWf@3IimT0203IimT50000
0080_LVm0`000002092IT08000004P3oool00`000000oooo0?ooo`060?ooo`009@3oool00`000000
oooo0?ooo`0^0?ooo`030000002ka[/0^lJk008000001`3?g<l00`000000gN_M0=g[g@050=g[g@03
0000003Tl^@0i?;T00L0i?;T00<000000>Oei`3WmNL02@3WmNL00`000000j?OX0>Sgj0090>Sgj0<0
00002P3Yn>T00`000000j_SZ0>[hjP070>[hjP<000000P3ZnNX00`000000j_WZ0>[ijP090>[ijP03
0000003XmnP0j?OX00D0j?OX100000020>Whj@030000003Um>D0iOCU00T0iOCU00<000000=WWf@3I
imT0203IimT010000000]l>g0;O3]`2g`kL600000004092IT0000000T9V@00000140oooo00<00000
0?ooo`3oool01P3oool002H0oooo00<000000?ooo`3oool0;@3oool00`000000^lJk0;_6^`020;_6
^`8000001@3?g<l00`000000gN_M0=g[g@060=g[g@030000003Tl^@0i?;T00L0i?;T00<000000>Oe
i`3WmNL02@3WmNL00`000000j?OX0>Sgj0050>Sgj0<000000P3XmnP00`000000jOSY0>Whj@090>Wh
j@030000003Zn>X0j_SZ00@0j_SZ0P0000060>[ijP030000003ZnNX0j_WZ00T0j_WZ00<000000>Sg
j03XmnP0100000070>Whj@030000003Um>D0iOCU00T0iOCU00<000000=WWf@3IimT0203IimT00`00
0000]l>g0;O3]`040;O3]`D0000000<0T9V@0000003oool0403oool00`000000oooo0?ooo`050?oo
o`009P3oool00`000000oooo0?ooo`0^0?ooo`030000002ka[/0^lJk0080^lJk100000030<oLc`03
0000003Mjmd0gN_M00H0gN_M00<000000>Cbi03Tl^@01`3Tl^@00`000000ioGW0>Oei`090>Oei`03
0000003XmnP0j?OX00@000001P3XmnP00`000000jOSY0>Whj@090>Whj@030000003Zn>X0j_SZ00<0
0000203ZnNX00`000000j_WZ0>[ijP090>[ijP<000002`3Yn>T00`000000iOCU0>Gdi@080>Gdi@l0
00001P2g`kL500000140oooo00<000000?ooo`3oool01@3oool002L0oooo00<000000?ooo`3oool0
;P3oool200000080^lJk00@000000=?Pd`3Ch=<0dn3C1@0000080=g[g@030000003Tl^@0i?;T00L0
i?;T00<000000>Oei`3WmNL01`3WmNL4000000X0j?OX00<000000>Whj@3Yn>T02@3Yn>T3000000`0
j_WZ00<000000>[ijP3ZnNX01@3ZnNX300000080joW[00<000000>Whj@3Yn>T02P3Yn>T010000000
iOCU0>Gdi@3Um>D6000000<0ioGW00<000000=[WfP3JimX0203JimX5000000<0]l>g1@00000@0?oo
o`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo02d0oooo00<000000<GAa@00
00000P2ka[/00`000000dn3C0=?Pd`040=?Pd`H000000`3Mjmd00`000000i?;T0>Cbi0070>Cbi004
0000003WmNL0ioGW0>Oei`H000000`3WmNL00`000000j?OX0>Sgj0090>Sgj0030000003Yn>T0jOSY
00D0jOSY0`0000020>[hjP030000003ZnNX0j_WZ00/0j_WZ00<000000>[ijP3ZnNX0100000060>_i
j`030000003Yn>T0jOSY00T0jOSY1000000:0>Oei`030000003JimX0f^OJ00P0f^OJ0P0000020;2k
/0D0000000@0HfUS00000000000000003`3oool00`000000oooo0?ooo`050?ooo`00:@3oool00`00
0000oooo0?ooo`0]0?ooo`0600000035dLD000000000002ka[/000001`3Ch=<010000000g^cN0=k/
gP3Nk=hA000000T0ioGW00<000000>Sgj03XmnP02P3XmnP00`000000jOSY0>Whj@04000000H0j_SZ
00<000000>[ijP3ZnNX02P3ZnNX3000000/0joW[00<000000>Whj@3Yn>T01@3Yn>T300000080joW[
00<000000>Oei`3WmNL02P3WmNL00`000000f^OJ0=[WfP040=[WfPP000000`2`^k07000000d0oooo
00<000000?ooo`3oool01@3oool002X0oooo00<000000?ooo`3oool0;03oool01`000000aM750<GA
a@35dLD000000;_6^`0000001P3Ch=<00`000000g^cN0=k/gP060=k/gP030000003Tl^@0i?;T00L0
i?;T00<000000>Oei`3WmNL02@3WmNL00`000000j?OX0>Sgj0090>Sgj0<000002P3Zn>X00`000000
j_WZ0>[ijP070>[ijP<000000P3[nN/00`000000joW[0>_ij`0:0>_ij`030000003Yn>T0jOSY00@0
00001P3[nN/2000000T0ioGW200000060=[XfP030000002X/jP0000000L0000000@0HfUS00000000
000000002`3oool00`000000oooo0?ooo`050?ooo`00:`3oool00`000000oooo0?ooo`0/0?ooo`04
00000035dLD0aM750<GAa@8000001`3Ch=<00`000000g^cN0=k/gP060=k/gP030000003Tl^@0i?;T
00L0i?;T00<000000>Oei`3WmNL02@3WmNL00`000000j?OX0>Sgj0060>Sgj08000000P3YmnT00`00
0000j_SZ0>[hjP090>[hjP030000003ZnNX0j_WZ00@0j_WZ0P0000060>_ij`030000003[nN/0joW[
00T0joW[0`00000<0>_ij`040000003WmNL0ioGW0>Oei`D000000`3XmnP2000000X0f^SJ0P000005
0:RcZ0@0000000<0HfUS0000000000002P3oool00`000000oooo0?ooo`050?ooo`00;03oool00`00
0000oooo0?ooo`0[0?ooo`0300000035dLD0aM7500<0aM750P0000060=?Pd`030000003Nk=h0g^cN
00H0g^cN00<000000>Cbi03Tl^@01`3Tl^@00`000000ioGW0>Oei`090>Oei`030000003XmnP0j?OX
0080j?OX0`0000040>Wgj@030000003Zn>X0j_SZ00X0j_SZ00<000000>[ijP3ZnNX00`0000080>_i
j`030000003[nN/0joW[00L0joW[0P0000020>_jj`030000003[nN/0joW[00X0joW[1000000:0>Sg
j08000001P3Jj=X:000000030:RcZ0000000000000@000002@3oool00`000000oooo0?ooo`050?oo
o`00;@3oool00`000000oooo0?ooo`0[0?ooo`0300000035dLD0aM7500<0aM75100000040=?Pd`03
0000003Nk=h0g^cN00D0g^cN00<000000>Cbi03Tl^@01`3Tl^@00`000000ioGW0>Oei`090>Oei`03
0000003XmnP0j?OX00800000203YmnT00`000000j_SZ0>[hjP090>[hjP<00000303[nN/00`000000
joW[0>_ij`030>_ij`<000001@3[n^/00`000000joW[0>_ij`070>_ij`8000000P3/n^`00`000000
j?OX0>Sgj00:0>Sgj0L000002P3oool9000000L0oooo00<000000?ooo`3oool01@3oool002h0oooo
00<000000?ooo`3oool0:P3oool00`000000aM750<GAa@030<GAa@040000003Gi=L0enCG0=OTe`D0
0000203Nk=h00`000000i?;T0>Cbi0070>Cbi0030000003WmNL0ioGW00L0ioGW1000000;0>Wgj@03
0000003Zn>X0j_SZ00H0j_SZ0P0000020>[ijP030000003[nN/0joW[00/0joW[00<000000>_ij`3[
nN/00P0000090>_jj`030000003[nN/0joW[00<0joW[0`0000050>cjk0030000003XmnP0j?OX00D0
j?OX1000000C0?ooo`030000003oool0oooo0080oooo0`0000060?ooo`030000003oool0oooo00D0
oooo000_0?ooo`030000003oool0oooo02X0oooo00<000000<GAa@35dLD00`35dLD00`000000enCG
0=OTe`040=OTe`H00000103Nk=h00`000000i?;T0>Cbi0070>Cbi0040000003WmNL0ioGW0>Oei`D0
00000`3Wm^L00`000000jOOY0>Wgj@0:0>Wgj@030000003Zn>X0j_SZ0080j_SZ0`0000050>[ijP03
0000003[nN/0joW[00X0joW[0`00000<0>_jj`030000003[nN/0joW[008000002@3/n^`00`000000
j?OX0>Sgj004000001P0oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3o
ool01@3oool00300oooo00<000000?ooo`3oool0:P3oool2000000<0aM7500<000000=OTe`3Gi=L0
1P3Gi=L010000000gngO0=o]g`3OkMlB000000T0ioKW00<000000>Wgj@3YmnT02@3YmnT00`000000
j_SZ0>[hjP02000000P0j_WZ00<000000>_ij`3[nN/01`3[nN/300000080jo[[00<000000>_jj`3[
n^/02P3[n^/3000000/0k?[/0`00000M0?ooo`030000003oool0oooo00D0oooo0`0000000`3oool0
00000?ooo`060?ooo`00<@3oool00`000000oooo0?ooo`0Y0?ooo`040000003<fL`0000000000080
aM7500<000000=OTe`3Gi=L01@3Gi=L00`000000gngO0=o]g`070=o]g`030000003Tl^@0i?;T00L0
i?;T00<000000>Ofi`3Wm^L0203Wm^L00`000000jOOY0>Wgj@090>Wgj@<000002`3ZnNX00`000000
joW[0>_ij`040>_ij`8000001P3[n^/00`000000jo[[0>_jj`060>_jj`<000000P3/nn`00`000000
k?[/0>cjk0070>cjk08000008@3oool00`000000oooo0?ooo`070?ooo`<000001P3oool00380oooo
00<000000?ooo`3oool0:@3oool00`000000c=W<0<cIc002000000030<GAa@000000enCG00H0enCG
00<000000=o]g`3OkMl01P3OkMl00`000000i?;T0>Cbi0070>Cbi0030000003Wm^L0ioKW00T0ioKW
00<000000>Wgj@3YmnT01@3YmnT300000080jOSY00<000000>[ijP3ZnNX02P3ZnNX00`000000joW[
0>_ij`03000000P0jo[[00<000000>_jj`3[n^/0103[n^/2000000H0k?_/00<000000>cjk03/n^`0
0`3/n^`3000002<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`00<`3o
ool00`000000oooo0?ooo`0X0?ooo`030000003<fL`0c=W<0080c=W<0P0000070=OTe`030000003O
kMl0gngO00L0gngO00<000000>Cbi03Tl^@01`3Tl^@00`000000ioKW0>Ofi`090>Ofi`030000003Y
mnT0jOOY00@000001P3Yn>T00`000000j_WZ0>[ijP090>[ijP<00000303[n^/00`000000jo[[0>_j
j`03000000T0k?_/00<000000>cjk03/n^`00P00000W0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0103oool003@0oooo00<000000?ooo`3oool0:03oool00`000000c=W<0<cIc003
0<cIc08000001P3Gi=L00`000000gngO0=o]g`060=o]g`030000003Tl^@0i?;T00P0i?;T00<00000
0>Ofi`3Wm^L0203Wm^L3000000X0jOSY00<000000>[ijP3ZnNX01`3ZnNX200000080j_WZ00<00000
0>_jj`3[n^/02`3[n^/2000000d0k?_/0P00000Z0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0103oool003D0oooo00<000000?ooo`3oool09`3oool00`000000c=W<0<cIc0040<cI
c0@00000103Gi=L00`000000gngO0=o]g`060=o]g`030000003Tl^@0i?;T00P0i?;T00<000000>Of
i`3Wm^L0103Wm^L300000080ioKW00<000000>Whj@3Yn>T02@3Yn>T00`000000j_WZ0>[ijP030>[i
jP<000001@3ZnNX00`000000jo[[0>_jj`080>_jj`80000000<0k?[/0000003/nn`02P3/nn`20000
02`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`00=P3oool00`000000
oooo0?ooo`0W0?ooo`030000003<fL`0c=W<00<0c=W<00@000000=WWf@3IimT0fNOI1@0000090=o]
g`030000003Tl^@0i?;T00L0i?;T00<000000>Ofi`3Wm^L0100000050>Ofi`030000003Yn>T0jOSY
00X0jOSY00<000000>[ijP3ZnNX00P0000080>[ijP030000003[n^/0jo[[00H0jo[[0P0000040>cj
k0030000003/nn`0k?_/00H0k?_/0P00000_0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool003L0oooo00<000000?ooo`3oool09P3oool00`000000c=W<0<cIc0040<cIc003
0000003IimT0fNOI00@0fNOI1P0000040=o]g`030000003Tl^@0i?;T00@0i?;T1P00000:0>Ofi`03
0000003Yn>T0jOSY00T0jOSY0`00000;0>[ijP030000003[n^/0jo[[00<0jo[[0P0000070>cjk003
0000003/nn`0k?_/00<0k?_/0P00000b0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool003P0oooo00<000000?ooo`3oool09P3oool00`000000c=W<0<cIc0040<cIc0030000
003IimT0fNOI00D0fNOI00@000000>7_h@3Qkn40hNoQ2`0000050>Gci@030000003Wm^L0ioKW00T0
ioKW00<000000>Whj@3Yn>T01P3Yn>T200000080jOSY00<000000>[ijP3ZnNX02P3ZnNX00`000000
jo[[0>_jj`02000000X0k?[/00<000000>ckk03/nn`00P00000d0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool003T0oooo00<000000?ooo`3oool09@3oool3000000@0c=W<
00<000000=WWf@3IimT01@3IimT00`000000hNoQ0>7_h@070>7_h@030000003UlnD0iO?U00L0iO?U
00<000000>Ofi`3Wm^L02P3Wm^L00`000000jOSY0>Whj@020>Whj@<00000103Yn>T00`000000j_WZ
0>[ijP0;0>[ijP8000003@3/n^`2000003L0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`00>P3oool00`000000oooo0?ooo`0U0?ooo`040000003Ag]400000000000<0c=W<
00<000000=WWf@3IimT01@3IimT00`000000hNoQ0>7_h@060>7_h@030000003UlnD0iO?U00P0iO?U
00<000000>Ofi`3Wm^L02@3Wm^L00`000000jOSY0>Whj@02000000P0jOSY00<000000>[ijP3ZnNX0
203ZnNX2000000030>_ij`000000k?[/00X0k?[/0P00000j0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool003/0oooo00<000000?ooo`3oool0903oool010000000dMkA0=7N
d@3Ag]4200000080c=W<00<000000=WWf@3IimT0103IimT00`000000hNoQ0>7_h@070>7_h@030000
003UlnD0iO?U00P0iO?U00<000000>Ofi`3Wm^L0203Wm^L3000000/0jOSY00<000000>[ijP3ZnNX0
1@3ZnNX2000000@0joW[00<000000>cjk03/n^`01P3/n^`2000003d0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`00?03oool00`000000oooo0?ooo`0T0?ooo`030000003A
g]40dMkA0080dMkA0`0000070=WWf@030000003Qkn40hNoQ00H0hNoQ00<000000>Gci@3UlnD02@3U
lnD00`000000ioKW0>Ofi`040>Ofi`<000000P3Wm^L00`000000jOSY0>Whj@0:0>Whj@030000003Z
nNX0j_WZ0080j_WZ0P0000060>_ij`030000003/n^`0k?[/00D0k?[/00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0
oooo02<0oooo00<000000=7Nd@3Ag]40103Ag]44000000D0fNOI00<000000>7_h@3Qkn401P3Qkn40
0`000000iO?U0>Gci@080>Gci@030000003Wm^L0ioKW00@000001@3Wm^L00`000000jOSY0>Whj@0:
0>Whj@030000003ZnNX0j_WZ008000002@3[nN/00`000000k?[/0>cjk0020>cjk0800000@@3oool0
1@000000oooo0?ooo`3oool0000000H0oooo000n0?ooo`030000003oool0oooo02<0oooo00<00000
0=7Nd@3Ag]401@3Ag]400`000000g>WL00000003000000030=WWf@000000hNoQ00P0hNoQ00<00000
0>Gci@3UlnD01P3UlnD4000000X0ioKW00<000000>Whj@3Yn>T02@3Yn>T3000000`0joW[00@00000
0>cjk00000000000A03oool01@000000oooo0?ooo`3oool0000000D0oooo000o0?ooo`030000003o
ool0oooo0280oooo00<000000=7Nd@3Ag]401@3Ag]400`000000g>WL0=cYg0030=cYg0L00000103Q
kn4010000000iO?U0>Gci@3UlnD5000000<0iO?U00<000000>Ofi`3Wm^L02@3Wm^L00`000000jOSY
0>Whj@060>Whj@8000000P3Yn>T00`000000joW[0>_ij`0;0>_ij`030000003oool0oooo04@0oooo
00D000000?ooo`3oool0oooo000000050?ooo`00@03oool00`000000oooo0?ooo`0R0?ooo`030000
003Ag]40dMkA00D0dMkA00<000000=cYg03LjM`01@3LjM`010000000h_3R0>;`hP3Rl>88000000P0
iO?U00<000000>Ofi`3Wm^L02P3Wm^L00`000000jOSY0>Whj@020>Whj@<000001@3Yn>T00`000000
joW[0>_ij`080>_ij`800000B03oool010000000oooo0?ooo`0000050?ooo`00@@3oool00`000000
oooo0?ooo`0Q0?ooo`030000003Ag]40dMkA00D0dMkA00<000000=cYg03LjM`01@3LjM`00`000000
h_3R0>;`hP070>;`hP030000003UlnD0iO?U00P0iO?U00<000000>Ofi`3Wm^L02@3Wm^L00`000000
jOSY0>Whj@02000000P0jOSY00<000000>_ij`3[nN/01P3[nN/2000004/0oooo00<000000?ooo`00
00001@3oool00440oooo00<000000?ooo`3oool08P3oool2000000H0dMkA00<000000=cYg03LjM`0
1@3LjM`00`000000h_3R0>;`hP060>;`hP030000003UlnD0iO?U00P0iO?U00<000000>Ofi`3Wm^L0
2@3Wm^L3000000/0jOSY00<000000>_ij`3[nN/00`3[nN/2000004h0oooo0P0000050?ooo`00@P3o
ool00`000000oooo0?ooo`0Q0?ooo`040000003EhmD00000000000@0dMkA00<000000=cYg03LjM`0
1@3LjM`00`000000h_3R0>;`hP070>;`hP030000003UlnD0iO?U00P0iO?U00<000000>Ofi`3Wm^L0
1P3Wm^L200000080j?KX00<000000>Whj@3Yn>T02P3Yn>T00`000000joW[0>_ij`0200000500oooo
0P0000050?ooo`00@`3oool00`000000oooo0?ooo`0Q0?ooo`030000003EhmD0eN?E00<000000P3A
g]400`000000g>WL0=cYg0050=cYg0030000003Rl>80h_3R00H0h_3R00<000000>Gci@3UlnD02@3U
lnD00`000000ioKW0>Ofi`020>Ofi`<00000103Xm^P00`000000jOSY0>Whj@0;0>Whj@800000DP3o
ool2000000D0oooo00140?ooo`030000003oool0oooo0200oooo00<000000=GSe@3EhmD00`3EhmD3
000000L0g>WL00<000000>;`hP3Rl>801`3Rl>800`000000iO?U0>Gci@080>Gci@030000003Wm^L0
ioKW00800000203Xm^P00`000000jOSY0>Whj@080>Whj@800000D03oool4000000L0oooo00150?oo
o`030000003oool0oooo0200oooo00<000000=GSe@3EhmD0103EhmD4000000D0g>WL00<000000>;`
hP3Rl>801`3Rl>800`000000iO?U0>Gci@060>Gci@@000002P3Xm^P00`000000jOSY0>Whj@060>Wh
j@800000CP3oool4000000/0oooo00160?ooo`030000003oool0oooo01l0oooo00<000000=GSe@3E
hmD01@3EhmD00`000000gN_M0=g[g@04000000030=cYg0000000h_3R00P0h_3R00@000000>Gci@3U
lnD0iO?U1@0000030>Gdi@030000003Xm^P0j?KX00T0j?KX00<000000>Whj@3Yn>T0103Yn>T00`00
0000oooo0?ooo`1;0?ooo`<000003`3oool004L0oooo00<000000?ooo`3oool07`3oool00`000000
eN?E0=GSe@050=GSe@030000003Mjmd0gN_M00<0gN_M3`0000080>Gdi@030000003Xm^P0j?KX00X0
j?KX00@000000>Whj@3Yn>T0jOSY0P00001:0?ooo`@000004P3oool004P0oooo00<000000?ooo`3o
ool07P3oool00`000000eN?E0=GSe@050=GSe@030000003Mjmd0gN_M00H0gN_M00<000000>;`hP3R
l>801`3Rl>800`000000iOCU0>Gdi@080>Gdi@030000003Xm^P0j?KX00T0j?KX00@000000>Whj@00
00000000B@3oool3000001H0oooo00190?ooo`030000003oool0oooo01h0oooo00<000000=GSe@3E
hmD01@3EhmD00`000000gN_M0=g[g@050=g[g@030000003Rl>80h_3R00L0h_3R00<000000>Gdi@3U
m>D0203Um>D00`000000j?KX0>Sfj0090>Sfj0800000A`3oool4000001T0oooo001:0?ooo`030000
003oool0oooo01d0oooo00<000000=GSe@3EhmD01@3EhmD00`000000gN_M0=g[g@060=g[g@030000
003Rl>80h_3R00L0h_3R00<000000>Gdi@3Um>D0203Um>D00`000000j?KX0>Sfj0060>Sfj0800000
A@3oool4000001d0oooo001;0?ooo`030000003oool0oooo01d0oooo0P0000060=GSe@030000003M
jmd0gN_M00D0gN_M00<000000>;`hP3Rl>801`3Rl>800`000000iOCU0>Gdi@090>Gdi@030000003X
m^P0j?KX0080j?KX0`0000140?ooo`<000008@3oool004`0oooo00<000000?ooo`3oool0703oool0
10000000oooo0000000000040=GSe@030000003Mjmd0gN_M00H0gN_M00<000000>;`hP3Rl>801`3R
l>800`000000iOCU0>Gdi@080>Gdi@030000003Xm^P0j?KX00800000@`3oool4000002@0oooo001=
0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`3oool0oooo0`0000020=GSe@030000003M
jmd0gN_M00D0gN_M00<000000>;`hP3Rl>80203Rl>800`000000iOCU0>Gdi@060>Gdi@@00000@@3o
ool4000002P0oooo001>0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0103oool3
000000P0gN_M00<000000>;`hP3Rl>801`3Rl>8010000000iOCU0>Gdi@3Um>D500000480oooo0`00
000/0?ooo`00C`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo1P000003
0=g[g@030000003Rl>80h_3R00@0h_3R1`0000130?ooo`@00000;`3oool00500oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0<0?ooo`X00000A`3oool3000003<0oooo001A0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0F@3oool4000003H0oooo001B0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0E@3oool4000003X0oooo001C0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo001D0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0CP3oool400000440oooo001E0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0BP3oool4000004D0oooo001F0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0A`3oool3000004T0oooo001G0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0@`3oool4000004`0oooo001H0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0@03oool300000500oooo001I0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0?03oool4000005<0oooo001J0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0>03oool4000005L0oooo001K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0=@3oool3000005/0oooo001L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
<@3oool4000005h0oooo001L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0;@3o
ool400000680oooo001M0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0:P3oool3
000006H0oooo001N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool40000
06T0oooo001O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0903oool3000006d0
oooo001P0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0803oool400000700oooo
001Q0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0703oool4000007@0oooo001R
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool3000007P0oooo001S0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool4000007/0oooo001T0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool4000007l0oooo001U0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03P3oool3000008<0oooo001V0?ooo`050000003o
ool0oooo0?ooo`000000303oool4000008H0oooo001W0?ooo`040000003oool0oooo000000T0oooo
0`00002:0?ooo`00J03oool00`000000oooo000000050?ooo`@00000S@3oool006T0oooo0P000000
0`3oool000000000000200000940oooo001Z0?ooo`800000U@3oool00?l0oooo0P3oool00?l0oooo
0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo0P3oool00?l0oooo
0P3oool00?l0oooo0P3oool00001\
\>"],
    ImageRangeCache->{{{0, 256}, {213.813, 0}} -> {0, 0, 0, 0}}],
  StyleBox["     ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1984e-017 1.04977 -0.0679587 1.04977 [
[.17646 .18758 -11.7989 -9 ]
[.17646 .18758 .20112 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -5.27396 -9 ]
[.50253 .05935 .72604 0 ]
[.29165 .07573 -9.31117 -12.5625 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 12 2.73794 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.41865 ]
[.91861 .21225 16 4.14385 ]
[.01529 .3204 -12 -2.78907 ]
[.01529 .3204 0 6.21093 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00166 .42665 -6 -2.87938 ]
[-0.00166 .42665 0 6.12062 ]
[-0.05457 .39542 -10 -3.95494 ]
[-0.05457 .39542 0 8.60756 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.18558 .19702 m
.19014 .20174 L
s
[(-1)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(1)] .50253 .05935 .75799 1 Mshowa
gsave
.29165 .07573 -70.3112 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-1)] .70096 -0.00478 -1 .39157 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
gsave
.91861 .21225 -61 -12.4187 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03716 .25514 m
0 .48963 L
s
.02756 .31573 m
.03369 .3134 L
s
[(-5)] .01529 .3204 1 -0.38021 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01068 .4222 m
.01686 .41998 L
s
[(5)] -0.00166 .42665 1 -0.36014 Mshowa
gsave
-0.05457 .39542 -71 -7.95494 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.925 .983 .925 r
.375 .77837 .39787 .81114 .43762 .76848 .41503 .73996 Metetra
.93 .988 .93 r
.41503 .73996 .43762 .76848 .47715 .73086 .45493 .7058 Metetra
.933 .991 .933 r
.45493 .7058 .47715 .73086 .51665 .69812 .49485 .67578 Metetra
.934 .992 .934 r
.49485 .67578 .51665 .69812 .55627 .67013 .53493 .64981 Metetra
.93 .988 .93 r
.53493 .64981 .55627 .67013 .59617 .64682 .57532 .62784 Metetra
.922 .98 .922 r
.57532 .62784 .59617 .64682 .63653 .62814 .61618 .60983 Metetra
.908 .965 .908 r
.61618 .60983 .63653 .62814 .67752 .61408 .65765 .59579 Metetra
.889 .945 .889 r
.65765 .59579 .67752 .61408 .71934 .60468 .69991 .58575 Metetra
.867 .921 .867 r
.69991 .58575 .71934 .60468 .76218 .60001 .74313 .57977 Metetra
.844 .896 .844 r
.74313 .57977 .76218 .60001 .80625 .60019 .7875 .57794 Metetra
.822 .873 .822 r
.7875 .57794 .80625 .60019 .85179 .60538 .83323 .58039 Metetra
.803 .854 .803 r
.83323 .58039 .85179 .60538 .89906 .6158 .88055 .58729 Metetra
.789 .838 .789 r
.88055 .58729 .89906 .6158 .94836 .63172 .9297 .59885 Metetra
.778 .827 .778 r
.9297 .59885 .94836 .63172 1 .6535 .98097 .61534 Metetra
.922 .98 .922 r
.35174 .74388 .375 .77837 .41503 .73996 .39198 .70975 Metetra
.927 .985 .927 r
.39198 .70975 .41503 .73996 .45493 .7058 .43219 .67908 Metetra
.93 .988 .93 r
.43219 .67908 .45493 .7058 .49485 .67578 .47249 .65181 Metetra
.93 .989 .93 r
.47249 .65181 .49485 .67578 .53493 .64981 .51301 .62788 Metetra
.927 .985 .927 r
.51301 .62788 .53493 .64981 .57532 .62784 .55387 .60726 Metetra
.92 .978 .92 r
.55387 .60726 .57532 .62784 .61618 .60983 .59521 .58993 Metetra
.909 .966 .909 r
.59521 .58993 .61618 .60983 .65765 .59579 .63715 .5759 Metetra
.894 .95 .894 r
.63715 .5759 .65765 .59579 .69991 .58575 .67985 .5652 Metetra
.878 .933 .878 r
.67985 .5652 .69991 .58575 .74313 .57977 .72346 .55786 Metetra
.861 .915 .861 r
.72346 .55786 .74313 .57977 .7875 .57794 .76814 .55397 Metetra
.846 .899 .846 r
.76814 .55397 .7875 .57794 .83323 .58039 .81407 .55362 Metetra
.833 .885 .833 r
.81407 .55362 .83323 .58039 .88055 .58729 .86144 .55694 Metetra
.822 .873 .822 r
.86144 .55694 .88055 .58729 .9297 .59885 .91046 .56407 Metetra
.813 .863 .813 r
.91046 .56407 .9297 .59885 .98097 .61534 .96138 .5752 Metetra
.919 .977 .919 r
.3281 .70786 .35174 .74388 .39198 .70975 .36848 .67799 Metetra
.924 .982 .924 r
.36848 .67799 .39198 .70975 .43219 .67908 .40894 .65084 Metetra
.927 .985 .927 r
.40894 .65084 .43219 .67908 .47249 .65181 .44958 .62634 Metetra
.927 .985 .927 r
.44958 .62634 .47249 .65181 .51301 .62788 .4905 .60447 Metetra
.924 .982 .924 r
.4905 .60447 .51301 .62788 .55387 .60726 .5318 .58521 Metetra
.918 .976 .918 r
.5318 .58521 .55387 .60726 .59521 .58993 .5736 .56856 Metetra
.909 .966 .909 r
.5736 .56856 .59521 .58993 .63715 .5759 .61601 .55453 Metetra
.898 .954 .898 r
.61601 .55453 .63715 .5759 .67985 .5652 .65916 .54314 Metetra
.886 .942 .886 r
.65916 .54314 .67985 .5652 .72346 .55786 .70316 .53441 Metetra
.875 .929 .875 r
.70316 .53441 .72346 .55786 .76814 .55397 .74816 .52842 Metetra
.864 .918 .864 r
.74816 .52842 .76814 .55397 .81407 .55362 .7943 .52521 Metetra
.855 .909 .855 r
.7943 .52521 .81407 .55362 .86144 .55694 .84174 .52488 Metetra
.847 .9 .847 r
.84174 .52488 .86144 .55694 .91046 .56407 .89067 .52752 Metetra
.839 .892 .839 r
.89067 .52752 .91046 .56407 .96138 .5752 .94127 .53327 Metetra
.916 .973 .916 r
.30405 .67044 .3281 .70786 .36848 .67799 .34451 .64485 Metetra
.92 .977 .92 r
.34451 .64485 .36848 .67799 .40894 .65084 .38516 .62121 Metetra
.923 .98 .923 r
.38516 .62121 .40894 .65084 .44958 .62634 .4261 .5995 Metetra
.923 .981 .923 r
.4261 .5995 .44958 .62634 .4905 .60447 .46738 .57971 Metetra
.921 .978 .921 r
.46738 .57971 .4905 .60447 .5318 .58521 .50911 .56183 Metetra
.916 .973 .916 r
.50911 .56183 .5318 .58521 .5736 .56856 .55136 .54586 Metetra
.909 .966 .909 r
.55136 .54586 .5736 .56856 .61601 .55453 .59423 .53181 Metetra
.901 .957 .901 r
.59423 .53181 .61601 .55453 .65916 .54314 .63782 .5197 Metetra
.893 .949 .893 r
.63782 .5197 .65916 .54314 .70316 .53441 .68223 .50956 Metetra
.885 .941 .885 r
.68223 .50956 .70316 .53441 .74816 .52842 .72756 .5014 Metetra
.879 .934 .879 r
.72756 .5014 .74816 .52842 .7943 .52521 .77394 .49528 Metetra
.873 .927 .873 r
.77394 .49528 .7943 .52521 .84174 .52488 .82148 .49125 Metetra
.867 .921 .867 r
.82148 .49125 .84174 .52488 .89067 .52752 .87033 .48937 Metetra
.86 .914 .86 r
.87033 .48937 .89067 .52752 .94127 .53327 .92064 .48972 Metetra
.911 .968 .911 r
.2796 .63181 .30405 .67044 .34451 .64485 .32007 .61047 Metetra
.915 .972 .915 r
.32007 .61047 .34451 .64485 .38516 .62121 .36086 .59035 Metetra
.918 .975 .918 r
.36086 .59035 .38516 .62121 .4261 .5995 .40203 .57144 Metetra
.918 .976 .918 r
.40203 .57144 .4261 .5995 .46738 .57971 .44365 .55374 Metetra
.917 .974 .917 r
.44365 .55374 .46738 .57971 .50911 .56183 .48577 .53724 Metetra
.913 .97 .913 r
.48577 .53724 .50911 .56183 .55136 .54586 .52847 .52195 Metetra
.908 .965 .908 r
.52847 .52195 .55136 .54586 .59423 .53181 .5718 .50788 Metetra
.903 .959 .903 r
.5718 .50788 .59423 .53181 .63782 .5197 .61584 .49503 Metetra
.898 .954 .898 r
.61584 .49503 .63782 .5197 .68223 .50956 .66066 .48342 Metetra
.894 .95 .894 r
.66066 .48342 .68223 .50956 .72756 .5014 .70635 .47307 Metetra
.89 .946 .89 r
.70635 .47307 .72756 .5014 .77394 .49528 .75298 .46399 Metetra
.886 .942 .886 r
.75298 .46399 .77394 .49528 .82148 .49125 .80066 .45622 Metetra
.882 .937 .882 r
.80066 .45622 .82148 .49125 .87033 .48937 .84947 .44978 Metetra
.877 .932 .877 r
.84947 .44978 .87033 .48937 .92064 .48972 .89953 .4447 Metetra
.905 .961 .905 r
.25474 .59211 .2796 .63181 .32007 .61047 .29513 .57501 Metetra
.909 .966 .909 r
.29513 .57501 .32007 .61047 .36086 .59035 .336 .55841 Metetra
.912 .969 .912 r
.336 .55841 .36086 .59035 .40203 .57144 .37737 .54231 Metetra
.913 .97 .913 r
.37737 .54231 .40203 .57144 .44365 .55374 .41928 .52671 Metetra
.912 .969 .912 r
.41928 .52671 .44365 .55374 .48577 .53724 .46178 .5116 Metetra
.91 .967 .91 r
.46178 .5116 .48577 .53724 .52847 .52195 .5049 .49698 Metetra
.907 .964 .907 r
.5049 .49698 .52847 .52195 .5718 .50788 .54869 .48287 Metetra
.905 .961 .905 r
.54869 .48287 .5718 .50788 .61584 .49503 .59319 .46926 Metetra
.902 .959 .902 r
.59319 .46926 .61584 .49503 .66066 .48342 .63844 .45616 Metetra
.901 .957 .901 r
.63844 .45616 .66066 .48342 .70635 .47307 .68451 .44356 Metetra
.899 .956 .899 r
.68451 .44356 .70635 .47307 .75298 .46399 .73143 .43148 Metetra
.898 .954 .898 r
.73143 .43148 .75298 .46399 .80066 .45622 .77927 .41992 Metetra
.895 .951 .895 r
.77927 .41992 .80066 .45622 .84947 .44978 .82809 .40889 Metetra
.891 .946 .891 r
.82809 .40889 .84947 .44978 .89953 .4447 .87794 .39839 Metetra
.896 .952 .896 r
.22944 .55152 .25474 .59211 .29513 .57501 .26969 .53863 Metetra
.901 .958 .901 r
.26969 .53863 .29513 .57501 .336 .55841 .31056 .52554 Metetra
.905 .961 .905 r
.31056 .52554 .336 .55841 .37737 .54231 .35208 .51225 Metetra
.907 .963 .907 r
.35208 .51225 .37737 .54231 .41928 .52671 .39426 .49875 Metetra
.907 .964 .907 r
.39426 .49875 .41928 .52671 .46178 .5116 .43711 .48503 Metetra
.907 .963 .907 r
.43711 .48503 .46178 .5116 .5049 .49698 .48064 .47109 Metetra
.906 .963 .906 r
.48064 .47109 .5049 .49698 .54869 .48287 .52489 .45693 Metetra
.906 .963 .906 r
.52489 .45693 .54869 .48287 .59319 .46926 .56985 .44253 Metetra
.906 .963 .906 r
.56985 .44253 .59319 .46926 .63844 .45616 .61556 .4279 Metetra
.907 .963 .907 r
.61556 .4279 .63844 .45616 .68451 .44356 .66203 .41302 Metetra
.907 .964 .907 r
.66203 .41302 .68451 .44356 .73143 .43148 .70928 .39789 Metetra
.907 .963 .907 r
.70928 .39789 .73143 .43148 .77927 .41992 .75733 .38251 Metetra
.905 .961 .905 r
.75733 .38251 .77927 .41992 .82809 .40889 .80619 .36687 Metetra
.901 .958 .901 r
.80619 .36687 .82809 .40889 .87794 .39839 .8559 .35095 Metetra
.886 .941 .886 r
.20368 .51018 .22944 .55152 .26969 .53863 .24371 .50148 Metetra
.891 .947 .891 r
.24371 .50148 .26969 .53863 .31056 .52554 .28453 .49189 Metetra
.896 .952 .896 r
.28453 .49189 .31056 .52554 .35208 .51225 .32614 .48141 Metetra
.899 .955 .899 r
.32614 .48141 .35208 .51225 .39426 .49875 .36854 .47002 Metetra
.901 .958 .901 r
.36854 .47002 .39426 .49875 .43711 .48503 .41171 .4577 Metetra
.903 .96 .903 r
.41171 .4577 .43711 .48503 .48064 .47109 .45566 .44443 Metetra
.905 .962 .905 r
.45566 .44443 .48064 .47109 .52489 .45693 .50036 .4302 Metetra
.907 .964 .907 r
.50036 .4302 .52489 .45693 .56985 .44253 .54581 .41499 Metetra
.91 .966 .91 r
.54581 .41499 .56985 .44253 .61556 .4279 .592 .39879 Metetra
.912 .969 .912 r
.592 .39879 .61556 .4279 .66203 .41302 .6389 .38159 Metetra
.914 .971 .914 r
.6389 .38159 .66203 .41302 .70928 .39789 .68651 .36338 Metetra
.914 .971 .914 r
.68651 .36338 .70928 .39789 .75733 .38251 .73481 .34414 Metetra
.913 .97 .913 r
.73481 .34414 .75733 .38251 .80619 .36687 .78378 .32386 Metetra
.91 .967 .91 r
.78378 .32386 .80619 .36687 .8559 .35095 .8334 .30255 Metetra
.871 .926 .871 r
.17743 .46827 .20368 .51018 .24371 .50148 .21715 .46371 Metetra
.878 .933 .878 r
.21715 .46371 .24371 .50148 .28453 .49189 .25785 .45761 Metetra
.885 .94 .885 r
.25785 .45761 .28453 .49189 .32614 .48141 .2995 .44995 Metetra
.89 .946 .89 r
.2995 .44995 .32614 .48141 .36854 .47002 .34208 .44067 Metetra
.895 .951 .895 r
.34208 .44067 .36854 .47002 .41171 .4577 .38556 .42974 Metetra
.899 .955 .899 r
.38556 .42974 .41171 .4577 .45566 .44443 .4299 .41713 Metetra
.904 .96 .904 r
.4299 .41713 .45566 .44443 .50036 .4302 .47507 .40282 Metetra
.908 .965 .908 r
.47507 .40282 .50036 .4302 .54581 .41499 .52102 .38678 Metetra
.913 .97 .913 r
.52102 .38678 .54581 .41499 .592 .39879 .56771 .36898 Metetra
.916 .974 .916 r
.56771 .36898 .592 .39879 .6389 .38159 .6151 .34942 Metetra
.919 .977 .919 r
.6151 .34942 .6389 .38159 .68651 .36338 .66312 .32808 Metetra
.92 .978 .92 r
.66312 .32808 .68651 .36338 .73481 .34414 .71173 .30495 Metetra
.92 .977 .92 r
.71173 .30495 .73481 .34414 .78378 .32386 .76086 .28003 Metetra
.917 .975 .917 r
.76086 .28003 .78378 .32386 .8334 .30255 .81046 .25333 Metetra
.851 .905 .851 r
.15064 .42592 .17743 .46827 .21715 .46371 .18998 .42547 Metetra
.861 .915 .861 r
.18998 .42547 .21715 .46371 .25785 .45761 .23049 .42286 Metetra
.871 .925 .871 r
.23049 .42286 .25785 .45761 .2995 .44995 .27213 .418 Metetra
.879 .934 .879 r
.27213 .418 .2995 .44995 .34208 .44067 .31485 .41084 Metetra
.887 .942 .887 r
.31485 .41084 .34208 .44067 .38556 .42974 .35861 .40131 Metetra
.895 .951 .895 r
.35861 .40131 .38556 .42974 .4299 .41713 .40334 .38937 Metetra
.902 .958 .902 r
.40334 .38937 .4299 .41713 .47507 .40282 .44898 .37496 Metetra
.909 .966 .909 r
.44898 .37496 .47507 .40282 .52102 .38678 .49545 .35805 Metetra
.915 .973 .915 r
.49545 .35805 .52102 .38678 .56771 .36898 .54268 .33862 Metetra
.921 .978 .921 r
.54268 .33862 .56771 .36898 .6151 .34942 .59058 .31666 Metetra
.924 .982 .924 r
.59058 .31666 .6151 .34942 .66312 .32808 .63907 .29214 Metetra
.926 .984 .926 r
.63907 .29214 .66312 .32808 .71173 .30495 .68805 .26509 Metetra
.925 .983 .925 r
.68805 .26509 .71173 .30495 .76086 .28003 .73741 .23551 Metetra
.923 .981 .923 r
.73741 .23551 .76086 .28003 .81046 .25333 .78707 .20344 Metetra
.825 .876 .825 r
.12328 .38329 .15064 .42592 .18998 .42547 .16215 .38692 Metetra
.839 .891 .839 r
.16215 .38692 .18998 .42547 .23049 .42286 .20239 .38777 Metetra
.852 .905 .852 r
.20239 .38777 .23049 .42286 .27213 .418 .24396 .38573 Metetra
.865 .919 .865 r
.24396 .38573 .27213 .418 .31485 .41084 .28678 .38069 Metetra
.878 .932 .878 r
.28678 .38069 .31485 .41084 .35861 .40131 .3308 .37257 Metetra
.889 .945 .889 r
.3308 .37257 .35861 .40131 .40334 .38937 .37591 .36128 Metetra
.9 .956 .9 r
.37591 .36128 .40334 .38937 .44898 .37496 .42203 .34676 Metetra
.91 .967 .91 r
.42203 .34676 .44898 .37496 .49545 .35805 .46905 .32896 Metetra
.918 .975 .918 r
.46905 .32896 .49545 .35805 .54268 .33862 .51685 .30786 Metetra
.924 .982 .924 r
.51685 .30786 .54268 .33862 .59058 .31666 .56532 .28345 Metetra
.928 .986 .928 r
.56532 .28345 .59058 .31666 .63907 .29214 .61433 .25572 Metetra
.93 .988 .93 r
.61433 .25572 .63907 .29214 .68805 .26509 .66375 .2247 Metetra
.93 .988 .93 r
.66375 .2247 .68805 .26509 .73741 .23551 .71342 .19045 Metetra
.927 .985 .927 r
.71342 .19045 .73741 .23551 .78707 .20344 .76322 .15303 Metetra
.787 .836 .787 r
.09529 .34052 .12328 .38329 .16215 .38692 .13359 .3482 Metetra
.808 .858 .808 r
.13359 .3482 .16215 .38692 .20239 .38777 .17349 .35251 Metetra
.828 .88 .828 r
.17349 .35251 .20239 .38777 .24396 .38573 .21492 .35328 Metetra
.848 .9 .848 r
.21492 .35328 .24396 .38573 .28678 .38069 .25781 .35038 Metetra
.866 .92 .866 r
.25781 .35038 .28678 .38069 .3308 .37257 .30205 .34366 Metetra
.883 .938 .883 r
.30205 .34366 .3308 .37257 .37591 .36128 .34754 .33302 Metetra
.898 .954 .898 r
.34754 .33302 .37591 .36128 .42203 .34676 .39415 .31838 Metetra
.91 .967 .91 r
.39415 .31838 .42203 .34676 .46905 .32896 .44174 .29967 Metetra
.92 .978 .92 r
.44174 .29967 .46905 .32896 .51685 .30786 .49017 .27685 Metetra
.927 .985 .927 r
.49017 .27685 .51685 .30786 .56532 .28345 .53927 .24994 Metetra
.932 .99 .932 r
.53927 .24994 .56532 .28345 .61433 .25572 .58887 .21895 Metetra
.934 .992 .934 r
.58887 .21895 .61433 .25572 .66375 .2247 .6388 .18393 Metetra
.933 .992 .933 r
.6388 .18393 .66375 .2247 .71342 .19045 .68887 .14499 Metetra
.931 .989 .931 r
.68887 .14499 .71342 .19045 .76322 .15303 .7389 .10224 Metetra
.735 .781 .735 r
.06661 .29776 .09529 .34052 .13359 .3482 .10425 .30946 Metetra
.766 .813 .766 r
.10425 .30946 .13359 .3482 .17349 .35251 .14372 .31722 Metetra
.796 .846 .796 r
.14372 .31722 .17349 .35251 .21492 .35328 .18495 .32082 Metetra
.825 .876 .825 r
.18495 .32082 .21492 .35328 .25781 .35038 .22785 .32006 Metetra
.852 .905 .852 r
.22785 .32006 .25781 .35038 .30205 .34366 .2723 .31475 Metetra
.875 .93 .875 r
.2723 .31475 .30205 .34366 .34754 .33302 .31816 .30477 Metetra
.895 .951 .895 r
.31816 .30477 .34754 .33302 .39415 .31838 .36527 .28998 Metetra
.911 .968 .911 r
.36527 .28998 .39415 .31838 .44174 .29967 .41347 .27032 Metetra
.922 .98 .922 r
.41347 .27032 .44174 .29967 .49017 .27685 .46257 .24575 Metetra
.93 .988 .93 r
.46257 .24575 .49017 .27685 .53927 .24994 .51236 .21629 Metetra
.935 .993 .935 r
.51236 .21629 .53927 .24994 .58887 .21895 .56263 .18198 Metetra
.937 .995 .937 r
.56263 .18198 .58887 .21895 .6388 .18393 .61316 .14292 Metetra
.936 .994 .936 r
.61316 .14292 .6388 .18393 .68887 .14499 .66372 .09926 Metetra
.933 .991 .933 r
.66372 .09926 .68887 .14499 .7389 .10224 .71408 .05119 Metetra
.664 .705 .664 r
.03716 .25514 .06661 .29776 .10425 .30946 .07403 .27083 Metetra
.708 .753 .708 r
.07403 .27083 .10425 .30946 .14372 .31722 .11299 .28205 Metetra
.753 .8 .753 r
.11299 .28205 .14372 .31722 .18495 .32082 .15395 .28849 Metetra
.796 .845 .796 r
.15395 .28849 .18495 .32082 .22785 .32006 .19681 .28988 Metetra
.834 .886 .834 r
.19681 .28988 .22785 .32006 .2723 .31475 .24144 .28601 Metetra
.866 .92 .866 r
.24144 .28601 .2723 .31475 .31816 .30477 .28766 .27667 Metetra
.891 .947 .891 r
.28766 .27667 .31816 .30477 .36527 .28998 .3353 .26173 Metetra
.911 .967 .911 r
.3353 .26173 .36527 .28998 .41347 .27032 .38414 .24109 Metetra
.924 .982 .924 r
.38414 .24109 .41347 .27032 .46257 .24575 .43396 .21471 Metetra
.933 .991 .933 r
.43396 .21471 .46257 .24575 .51236 .21629 .48452 .18264 Metetra
.937 .996 .937 r
.48452 .18264 .51236 .21629 .56263 .18198 .53554 .14495 Metetra
.939 .997 .939 r
.53554 .14495 .56263 .18198 .61316 .14292 .58677 .1018 Metetra
.938 .996 .938 r
.58677 .1018 .61316 .14292 .66372 .09926 .63793 .05339 Metetra
.935 .993 .935 r
.63793 .05339 .66372 .09926 .71408 .05119 .68874 0 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.18558 .19702 m
.19014 .20174 L
s
[(-1)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(1)] .50253 .05935 .75799 1 Mshowa
gsave
.29165 .07573 -70.3112 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{257, 214.813},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000410000eR000`400?l00000o`00003oo`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool2
0?ooo`00_`3oool5000003d0oooo00310?ooo`030000003oool0oooo03d0oooo00310?ooo`030000
003oool0oooo03d0oooo002i0?ooo`@00000103oool00`000000oooo0?ooo`0m0?ooo`00`@3oool0
0`000000oooo0?ooo`0m0?ooo`00]@3oool2000000T0oooo0P00000o0?ooo`00/`3oool5000004T0
oooo002`0?ooo`<0000000<0oooo0000003_o^l00P0000190?ooo`00[P3oool2000000<0oooo00<0
00000>onk`3_o^l00`0000180?ooo`00Z`3oool3000000@0oooo00H000000>onk`3_o^l0kok_0000
003_o^l2000004L0oooo002X0?ooo`<000001P3oool00`000000kok_0>onk`020>onk`040000003_
o^l00000000004L0oooo00260?ooo`D000006`3oool2000000P0oooo00<000000>onk`3_o^l00`3_
o^l01@000000kok_0000003oool0000004H0oooo00280?ooo`030000003oool0oooo01P0oooo0`00
000:0?ooo`030000003_o^l0kok_00<0kok_00H000000>onk`3_o^l000000?ooo`0000150?ooo`00
R03oool00`000000oooo0?ooo`0F0?ooo`800000303oool00`000000kok_0>onk`040>onk`060000
003_o^l0kok_0000003oool00000A@3oool008P0oooo00<000000?ooo`3oool04`3oool3000000d0
oooo00<000000>onk`3_o^l01@3_o^l01`000000kok_0>onk`3_o^l000000?ooo`000000A03oool0
0580oooo0P0000000`3oool000000000000a0?ooo`030000003oool0oooo0140oooo0P00000?0?oo
o`030000003_o^l0kok_00L0kok_00H000000>onk`3_o^l000000?ooo`0000140?ooo`00D`3oool0
0`000000oooo0000000a0?ooo`800000403oool300000100oooo00<000000>onk`3_o^l0203_o^l0
1`000000kok_0>onk`3_o^l000000?ooo`000000@`3oool005@0oooo00<000000?ooo`3oool0@03o
ool200000180oooo00<000000>onk`3_o^l02@3_o^l01@000000kok_0>onk`3_o^l000000080oooo
00<000000?ooo`3oool0@03oool00580oooo0P0000000`3oool000000000000m0?ooo`<000004`3o
ool00`000000kok_0>onk`0:0>onk`030000003_o^l0kok_008000000P3oool00`000000oooo0?oo
o`100?ooo`00T@3oool3000001D0oooo00<000000?3nl00000002`3_o^l00`000000kok_00000002
0>kmkP040000003oool0oooo00000440oooo002?0?ooo`8000005`3oool010000000l?k`0?3nl000
000;0>onk`8000000`3^oNh01@000000oooo0?ooo`3oool000000400oooo002<0?ooo`<00000603o
ool00`000000l?k`0?3nl0020?3nl0030000003_o^l0kok_00P0kok_00<000000>kmkP3^oNh00`3^
oNh010000000oooo0?ooo`0000100?ooo`00RP3oool3000001T0oooo00<000000?3nl03`o_000`3`
o_000`000000kok_0>onk`070>onk`8000001@3^oNh01@000000oooo0?ooo`3oool0000003l0oooo
00270?ooo`<000000`3oool00`000000oooo0?ooo`0E0?ooo`030000003`o_00l?k`00D0l?k`00<0
00000>onk`3_o^l01@3_o^l00`000000k_g^000000060>kmkP050000003oool0oooo0?ooo`000000
?P3oool008D0oooo0P00000L0?ooo`8000002@3`o_000`000000kok_0>onk`030>onk`040000003^
oNh0k_g^000000H0k_g^00D000000?ooo`3oool0oooo0000000n0?ooo`00PP3oool3000001d0oooo
00<000000?3nl03`o_002@3`o_000`000000kok_0>onk`020>onk`050000003^oNh0k_g^0>kmkP00
00001`3^oNh01@000000oooo0?ooo`3oool0000003d0oooo001P0?ooo`8000007@3oool3000001l0
oooo00<000000?3nl03`o_002`3`o_0010000000kok_0>onk`0000040>kmkP030000003^oNh0k_g^
00D0k_g^00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0j0?ooo`00G`3oool010000000
oooo0?ooo`00000J0?ooo`8000008@3oool00`000000l?k`0?3nl00<0?3nl0030000003_o^l00000
00D0k_g^00<000000>kmkP3^oNh01P3^oNh01@000000oooo0?ooo`3oool0000003`0oooo001O0?oo
o`040000003oool0oooo000001L0oooo0`00000R0?ooo`030000003`o_00l?k`00h0l?k`00<00000
0>kmkP3^oNh0103^oNh00`000000k_g^0>kmkP060>kmkP030000003oool0oooo0080oooo00<00000
0?ooo`3oool0>@3oool005l0oooo00@000000?ooo`3oool000005@3oool2000002@0oooo00<00000
0?3nl03`o_003P3`o_000`000000kok_000000050>kmkP030000003^oNh0k_g^00L0k_g^00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0h0?ooo`00G`3oool010000000oooo0?ooo`00000B
0?ooo`<000009@3oool00`000000l?o`0000000>0?3nl0040000003_o^l0kok_000000D0k_g^00<0
00000>kmkP3^oNh01P3^oNh2000000@0oooo00<000000?ooo`3oool0>03oool00600oooo0P00000A
0?ooo`8000009`3oool010000000l?o`0?3ol000000<0?3nl0800000103_o^l00`000000k_g^0>km
kP020>kmkP030000003^oNh0k_g^00D0k_g^00@000000>kmkP3^oNh00000103oool00`000000oooo
0?ooo`0g0?ooo`00L03oool3000002L0oooo0P0000040?3ol0030000003`o_00l?k`00P0l?k`00<0
00000>onk`3_o^l0103_o^l00`000000k_g^0>kmkP020>kmkP030000003^oNh0k_g^00@0k_g^00D0
00000>kmkP3^oNh0k_g^000000050?ooo`030000003oool0oooo03H0oooo001^0?ooo`800000:@3o
ool00`000000l?o`0?3ol0050?3ol0030000003`o_00l?k`00H0l?k`00<000000>onk`3_o^l01P3_
o^l01@000000k_g^0>kmkP3^oNh0000000D0k_g^00<000000>kmkP3^oNh00`3^oNh00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03H0oooo001[0?ooo`<00000:P3oool00`000000l?o`0?3o
l0060?3ol0030000003`o_00l?k`00D0l?k`00<000000>onk`3_o^l01`3_o^l00`000000k_g^0>km
kP020>kmkP030000003^oNh0k_g^008000001P3^oNh00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03D0oooo001X0?ooo`<00000;03oool00`000000l?o`0?3ol0080?3ol0030000003`o_00
l?k`00<0l?k`00<000000>onk`3_o^l02@3_o^l01`000000k_g^0>kmkP3^oNh000000>kmkP000000
2@3^oNh00`000000oooo0?ooo`020?ooo`030000003oool0oooo03D0oooo001V0?ooo`800000;P3o
ool00`000000l?o`0?3ol00:0?3ol0030000003`o_00l?k`00800000303_o^l010000000k_g^0>km
kP3^oNh2000000X0k_g^00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`00H`3o
ool4000002d0oooo0P00000=0?3ol0030000003`o_00000000l0kok_00@000000>kmkP3^oNh00000
303^oNh00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo001Q0?ooo`800000103o
ool00`000000oooo0?ooo`0Y0?ooo`030000003`oo00l?o`00h0l?o`00<000000>onk`3_o^l03P3_
o^l010000000k_g^00000000000<0>kmkP030000003oool0oooo00<0oooo00<000000?ooo`3oool0
<`3oool005h0oooo0`00000a0?ooo`030000003`oo00l?o`00h0l?o`00<000000>onk`000000403_
o^l00`000000k_g^0000000=0>kmkP030000003oool0oooo00<0oooo00<000000?ooo`3oool0<P3o
ool005`0oooo0P00000c0?ooo`030000003_o^l0000000h0l?o`00@000000>onk`3_o^l000003`3_
o^l2000000030>kmkP000000k_g^00`0k_g^00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0a0?ooo`00>P3oool5000001X0oooo0`00000c0?ooo`8000000P3_o^l00`000000l?o`0?3ol00:
0?3ol0800000103_o^l00`000000kok_0>onk`0:0>onk`8000000P3^oNh2000000h0k_g^00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0a0?ooo`00?03oool00`000000oooo0?ooo`0H0?oo
o`800000=@3oool00`000000kok_0>onk`030>onk`030000003`oo00l?o`00P0l?o`00<000000>on
k`3_o^l0103_o^l00`000000kok_0>onk`090>onk`030000003^oNh0k_g^0080k_g^0P00000<0>km
kP<000001P3oool00`000000oooo0?ooo`0`0?ooo`00?03oool00`000000oooo0?ooo`0E0?ooo`<0
0000=P3oool00`000000kok_0>onk`050>onk`030000003`oo00l?o`00H0l?o`00<000000>onk`3_
o^l01P3_o^l00`000000kok_0>onk`070>onk`030000003^oNh0k_g^00@0k_g^00<000000>kmkP3^
oNh02@3^oNh01@000000kOc]0>glk@3]o>d0000000H0oooo00<000000?ooo`3oool0;`3oool003@0
oooo100000040?ooo`030000003oool0oooo0180oooo0`00000g0?ooo`800000203_o^l00`000000
l?o`0?3ol0050?3ol0030000003_o^l0kok_00P0kok_00<000000>onk`3_o^l0103_o^l2000000L0
k_g^00<000000>kmkP3^oNh01`3^oNh2000000@0kOc]00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0_0?ooo`00?03oool00`000000oooo0?ooo`0@0?ooo`800000>@3oool00`000000kok_
0>onk`090>onk`030000003`oo00l?o`00<0l?o`00<000000>onk`3_o^l02@3_o^l00`000000kok_
0>onk`030>onk`030000003^oNh0k_g^00L0k_g^0P0000070>kmkP030000003]o>d0kOc]00D0kOc]
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0^0?ooo`00>`3oool2000000l0oooo0`00
000j0?ooo`030000003_o^l0kok_00/0kok_00<000000?3ol03`oo000P00000=0>onk`050000003_
o^l0kok_0>onk`0000002P3^oNh2000000D0k_g^0P0000080>glk@030000003oool0oooo00D0oooo
00<000000?ooo`3oool0;@3oool004X0oooo0P00000k0?ooo`8000003P3_o^l00`000000l?o`0000
000?0>onk`040000003_o^l00000000000/0k_g^00<000000>kmkP0000000`3^oNh00`000000kOc]
0>glk@090>glk@030000003oool0oooo00@0oooo00<000000?ooo`3oool0;@3oool004L0oooo0`00
000l0?ooo`030000003_o^l0kok_00l0kok_00<000000>onk`3_o^l03`3_o^l00`000000k_g^0>km
kP0;0>kmkP040000003^oNh000000>kmkP800000303]o>d00`000000oooo0?ooo`050?ooo`030000
003oool0oooo02`0oooo00150?ooo`800000?@3oool2000000030>kmkP000000kok_00d0kok_0P00
00000`3_o^l000000>onk`0=0>onk`80000000<0kog_0000003^oNh02`3^oNh010000000k_g^0>km
kP00000?0>glk@030000003oool0oooo00D0oooo00<000000?ooo`3oool07P3oool2000000/0oooo
00120?ooo`<00000?P3oool00`000000k_g^0>kmkP020>kmkP030000003_o^l0kok_00X0kok_00D0
00000>onk`3_o^l0kok_0000000=0>onk`050000003_oNl0kog_0>omk`000000303^oNh300000003
0>klkP000000kOc]00d0kOc]00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00T0oooo000o0?ooo`<00000?`3oool2000000H0k_g^00<000000>onk`3_o^l0
1`3_o^l2000000D0kok_00<000000>onk`3_o^l0203_o^l2000000D0kog_00<000000>kmkP3^oNh0
2@3^oNh01@000000k_c^0>klkP3^o>h0000000l0kOc]00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo000m0?ooo`8000000`3oool00`000000oooo
0?ooo`0j0?ooo`8000002@3^oNh00`000000kok_0>onk`040>onk`800000203_o^l00`000000kok_
0>onk`060>onk`030000003_oNl0kog_00H0kog_00<000000>kmkP3^oNh01`3^oNh2000000@0k_c^
00<000000>glk@3]o>d0303]o>d00`000000oooo0?ooo`060?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`0000002@3oool003X0oooo0`0000110?ooo`030000003^oNh0k_g^00X0k_g^00<0
00000>onk`3_o^l00P3_o^l00`000000kok_0>onk`090>onk`030000003_o^l0kok_00<0kok_0P00
00090>omk`030000003^oNh0k_g^00D0k_g^0P0000020>klkP050000003^o>h0k_c^0>klkP000000
303]o>d3000000P0oooo00<000000?ooo`3oool0703oool010000000oooo0?ooo`0000090?ooo`00
>03oool200000480oooo0P00000>0>kmkP040000003_o^l00000000000`0kok_00<000000>onk`3_
o^l00P3_o^l00`000000kog_0>omk`0:0>omk`030000003^oNh0k_g^00<0k_g^00<000000>klkP3^
o>h00P3^o>h00`000000k_c^0>klkP020>klkP030000003]o>d0kOc]00P0kOc]00D000000>ckk03/
nn`0k?_/000000080?ooo`030000003oool0oooo01X0oooo0`0000000`3oool00000000000080?oo
o`00=@3oool3000004<0oooo00<000000>kmkP3^oNh03`3^oNh00`000000kok_0>onk`0=0>onk`04
0000003_o^l00000000000h0kog_00D000000>kmkP3^oNh0k_g^000000050>klkP030000003^o>h0
k_c^0080k_c^00<000000>glk@3]o>d01`3]o>d00`000000k?_/0>ckk0020>ckk0030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool200000240oooo000c0?ooo`800000A03oool20000
00030>ckk0000000k_g^00d0k_g^0P0000000`3^o>h000000>onk`0>0>onk`030000003_oNl0kog_
00h0kog_00@000000>kmkP00000000001P3^o>h00`000000k_c^0>klkP030>klkP030000003]o>d0
kOc]00@0kOc]0P0000060>ckk0030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`00000P0?ooo`00<03oool3000004@0oooo0P0000040>ckk0030000003^oNh0
k_g^00T0k_g^0P0000030>klkP030000003_o^l0kok_00/0kok_0P0000000`3^oNh000000>omk`0?
0>omk`030000003^o>h0k_c^00H0k_c^00<000000>klkP3^o>h00`3^o>h00`000000kOc]0>glk@03
0>glk@030000003/nn`0k?_/00H0k?_/00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000200oooo000^0?ooo`800000A@3oool2000000L0k?_/00<00000
0>kmkP3^oNh01`3^oNh00`000000k_c^0>klkP040>klkP030000003_o^l0kok_00T0kok_00D00000
0>kmkP3^oNh0k_g^0000000>0>omk`<00000203^o>h00`000000k_c^0>klkP040>klkP050000003]
o>d0kOc]0>glk@0000002P3/nn`00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000803oool002/0oooo0`0000150?ooo`8000002@3/nn`00`000000k_g^
0>kmkP050>kmkP800000203^o>h00`000000kok_0>onk`060>onk`8000001@3^oNh00`000000kog_
0>omk`0:0>omk`050000003^o>h0k_c^0>klkP0000001`3^o>h00`000000k_c^0>klkP040>klkP04
0000003]o>d00000000000/0k?_/00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool07P3oool002P0oooo0`0000160?ooo`800000303/nn`00`00
0000k_g^0>kmkP020>kmkP8000002`3^o>h00`000000kok_0>onk`030>onk`800000203^oNh00`00
0000kog_0>omk`070>omk`800000103^o>h00`000000k_c^0>klkP050>klkP030000003^o>h0k_c^
00D0k_c^00<000000>ckk03/nn`0303/nn`00`000000oooo0?ooo`070?ooo`040000003oool0oooo
0?ooo`8000008@3oool002H0oooo0P0000160?ooo`<000003`3/nn`010000000k_g^00000000000=
0>klkP030000003_o^l0kok_0080kok_00<000000>kmkP3^oNh0203^oNh00`000000kog_0>omk`06
0>omk`030000003^o>h0k_c^00D0k_c^00<000000>klkP3^o>h0103^o>h00`000000k_c^0>klkP03
0>klkP<000003P3/nn`00`000000oooo0?ooo`050?ooo`<000009P3oool002<0oooo0`0000160?oo
o`8000000P3YmnT00`000000k?_/0>ckk00>0>ckk0030000003^o>h0k_c^00h0k_c^00@000000>on
k`0000000000303^oNh00`000000kog_0>omk`030>omk`800000203^o>h00`000000k_c^0>klkP03
0>klkP8000000`3^o>h2000000<0k?_/00<000000>ckk03/nn`0303/nn`00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo02<0oooo000Q0?ooo`800000A`3oool2000000D0jOOY00<000000>ck
k03/nn`02`3/nn`2000000030>cjk0000000k_c^00l0k_c^00<000000>kmkP3^oNh03@3^oNh01@00
0000kog_0>omk`3_oNl0000000/0k_c^00<000000>klkP0000000P0000020>klkP030000003^o>h0
000000D0k?_/00<000000>ckk03/nn`0303/nn`00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0280oooo000O0?ooo`800000A`3oool2000000P0jOOY00<000000>ckk03/nn`0203/nn`20000
00@0k?[/00<000000>klkP3^o>h02`3^o>h2000000030>glk@000000k_g^00d0k_g^00@000000>om
k`00000000002`3^o>h3000000D0k_c^0P0000070>ckk0030000003/nn`0k?_/00`0k?_/00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0R0?ooo`007`3oool3000004@0oooo0P00000;0>Wg
j@030000003/nn`0k?_/00D0k?_/0P0000070>cjk0030000003^o>h0k_c^00P0k_c^0P0000030>gl
k@030000003^oNh0k_g^00d0k_g^00<000000>klkP3^o>h0203^o>h300000080k_c^00@000000>kl
kP3^o>h0k_c^0P0000000`3/nn`000000>ckk0060>ckk0030000003/nn`0k?_/00X0k?_/0`00000:
0?ooo`030000003oool0oooo0240oooo000O0?ooo`80000000<0ZKBY000000000000?`3oool30000
00h0jOOY00<000000>ckk03/nn`00P3/nn`2000000X0k?[/00<000000>klkP3^o>h01@3^o>h20000
00H0kOc]00<000000>kmkP3^oNh02P3^oNh2000000030>glk@000000k_c^00H0k_c^0P0000050>kl
kP040000003^o>h00000000000@0k?_/00<000000>ckk03/nn`01@3/nn`00`000000k?_/0>ckk007
0>ckk08000000`3ZnNX00`000000oooo0?ooo`080?ooo`030000003oool0oooo0200oooo000O0?oo
o`030000003oool000000080ZKBY0P00000i0?ooo`@000000P3Tl^@00`000000jOOY0>Wgj@0=0>Wg
j@040000003/nn`00000000000d0k?[/00<000000>klkP3^o>h00P3^o>h2000000T0kOc]00<00000
0>kmkP3^oNh01`3^oNh2000000<0kOc]00<000000>klkP3^o>h00P3^o>h3000000P0k_c^00<00000
0>ckk03/nn`01@3/nn`00`000000k?_/0>ckk0040>ckk0030000003/nn`0k?_/00D0k?_/0P000005
0>[ijP030000003oool0oooo00P0oooo00<000000?ooo`3oool0803oool001h0oooo00D000000?oo
o`3oool0oooo000000030:VdZ@<00000<P3oool4000000L0i?;T00<000000>Wgj@3YmnT0303YmnT2
00000100k?[/00@000000>klkP0000000000303]o>d00`000000k_g^0>kmkP040>kmkP8000001P3]
o>d4000000T0k_c^0P0000000`3]nnd000000>ckk0050>ckk0030000003/nn`0k?_/00D0k?_/00<0
00000>ckk03/nn`00P3/nn`2000000P0j_WZ00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0O0?ooo`007P3oool01@000000oooo0?ooo`3oool0000000D0ZKBY1000000/0?ooo`<00000303T
l^@00`000000jOOY0>Wgj@090>Wgj@8000000P3YmnT00`000000k?[/0>cjk00>0>cjk0030000003]
o>d0kOc]00`0kOc]00<000000>kmkP3^oNh00P3^oNh2000000H0kOc]100000090>klkP8000000`3]
nnd00`000000k?_/0>ckk0050>ckk0030000003/nn`0k?_/00@0k?_/00<000000>ckk03/nn`00P00
000:0>[ijP030000003oool0oooo00T0oooo00<000000?ooo`3oool07P3oool001h0oooo00<00000
0?ooo`3oool00P3oool00`000000ZKBY0:VdZ@030:VdZ@030000002e`;D0]L2e00<000009@3oool4
00000080gN_M00<000000>Cbi03Tl^@02`3Tl^@00`000000jOOY0>Wgj@060>Wgj@8000001@3YmnT0
0`000000k?[/0>cjk00;0>cjk080000000<0jo[[0000003]o>d03@3]o>d010000000k_g^00000000
00050>glk@<00000103]o>d00`000000k_c^0>klkP040>klkP8000001P3]nnd00`000000k?_/0>ck
k0050>ckk0030000003/nn`0k?_/00@0k?_/0P00000=0>[ijP030000003oool0oooo00P0oooo00<0
00000?ooo`3oool07P3oool001h0oooo00<000000?ooo`3oool00`3oool00`000000ZKBY0:VdZ@02
0:VdZ@030000002e`;D0]L2e00<0]L2e1P00000K0?ooo`@000001`3Mjmd00`000000i?;T0>Cbi00;
0>Cbi0030000003YmnT0jOOY00<0jOOY0P0000080>Wgj@030000003/n^`0k?[/00P0k?[/0P000003
0>_jj`030000003]o>d0kOc]00d0kOc]00<000000>glk@3]o>d00P3]o>d3000000L0kOc]00<00000
0>klkP3^o>h00P3^o>h2000000T0kO_]00<000000>ckk03/nn`01@3/nn`010000000k?_/0>ckk03/
nn`2000000030>_jj`000000j_WZ00`0j_WZ00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0M0?ooo`007P3oool00`000000oooo0?ooo`040?ooo`030000002Y]:T0ZKBY0080ZKBY00<00000
0;G0]@2e`;D0102e`;D010000000`<c00<3<`030c<0K000000`0gN_M00<000000>Cbi03Tl^@02`3T
l^@00`000000jOOY0>Wgj@02000000X0jOOY00<000000>cjk03/n^`01P3/n^`2000000H0jo[[00<0
00000>glk@3]o>d02P3]o>d2000000030>ckk00000000000008000002`3]o>d010000000k_c^0000
0000000;0>gkk@030000003/nn`0k?_/00D0k?_/00@000000>ckk000000000000`3[n^/00`000000
j_WZ0>[ijP0<0>[ijP030000003oool0oooo00T0oooo00<000000?ooo`3oool0703oool001h0oooo
00<000000?ooo`3oool0103oool00`000000ZKBY0:VdZ@030:VdZ@030000002e`;D0]L2e00@0]L2e
00<000000<3<`030c<001P30c<000`000000bmS;0<_Hb`070<_Hb`030000003Eh]D0eN;E00L0eN;E
00<000000=g[g@3Mjmd02`3Mjmd00`000000i?;T0>Cbi00:0>Cbi0<000003@3YmnT00`000000k?[/
0>cjk0030>cjk08000002@3[n^/00`000000kOc]0>glk@070>glk@8000000P3/nn`2000000l0kOc]
00<000000>gkk@3]nnd0303]nnd00`000000k?_/0>ckk0040>ckk08000001P3[n^/00`000000j_WZ
0>[ijP0;0>[ijP030000003oool0oooo00T0oooo00<000000?ooo`3oool0703oool001d0oooo00<0
00000?ooo`3oool01P3oool2000000@0ZKBY00<000000;G0]@2e`;D0102e`;D00`000000`<c00<3<
`0060<3<`0030000003;f</0bmS;00L0bmS;00<000000=GRe@3Eh]D01`3Eh]D00`000000gN_M0=g[
g@0;0=g[g@030000003Tl^@0i?;T00D0i?;T100000020>Gci@030000003YmnT0jOOY00`0jOOY00<0
00000>cjk03/n^`00P00000<0>_jj`030000003]o>d0kOc]00@0kOc]0P000000103/nn`000000000
000000020>ckk0030000003]o>d0kOc]00X0kOc]0P0000000`3/nn`000000>gkk@0=0>gkk@040000
003/nn`0k?_/0>ckk08000000P3[n^/00`000000jo[[0>_jj`030>_jj`030000003ZnNX0j_WZ00`0
j_WZ00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0K0?ooo`007@3oool00`000000oooo
0?ooo`070?ooo`<000000P2Y]:T00`000000]L2e0;G0]@040;G0]@0300000030c<00`<c000L0`<c0
00<000000<_Hb`3;f</01`3;f</00`000000eN;E0=GRe@070=GRe@800000303Mjmd00`000000i?;T
0>Cbi004000000L0iO?U00<000000>Wgj@3YmnT02`3YmnT3000000h0jo[[00<000000>glk@3]o>d0
0P3]o>d5000000H0k?_/00<000000>glk@3]o>d01`3]o>d2000000<0k?_/00<000000>gkk@3]nnd0
303]nnd010000000k?_/0000000000040>_jj`030000003[n^/0jo[[00@0jo[[00<000000>[ijP3Z
nNX02P3ZnNX2000000/0oooo00<000000?ooo`3oool06`3oool001d0oooo00<000000?ooo`3oool0
1`3oool00`000000_<Nl0;c7_004000000H0]L2e00<000000<3<`030c<001P30c<000`000000bmS;
0<_Hb`080<_Hb`030000003Eh]D0eN;E00P0eN;E00<000000=g[g@3Mjmd0203Mjmd4000000`0iO?U
00<000000>Wgj@3YmnT01`3YmnT300000080j?OX00<000000>_jj`3[n^/03@3[n^/00`000000kOc]
00000003000000X0k?_/00<000000>glk@3]o>d0103]o>d2000000H0k?_/00<000000>gkk@3]nnd0
2`3]nnd2000000L0jo[[00<000000>_jj`3[n^/0103[n^/00`000000j_WZ0>[ijP070>[ijP800000
00<0j?OX0000003oool02`3oool00`000000oooo0?ooo`0J0?ooo`007@3oool00`000000oooo0?oo
o`080?ooo`030000002lak`0_<Nl0080_<Nl100000040;G0]@0300000030c<00`<c000H0`<c000<0
00000<_Hb`3;f</0203;f</00`000000eN;E0=GRe@080=GRe@040000003Mjmd0gN_M0=g[g@H00000
0`3Ok]l00`000000iO?U0>Gci@0;0>Gci@030000003YmnT0jOOY00@0jOOY0P0000060>Sgj0030000
003[n^/0jo[[00`0jo[[0`00000=0>ckk0030000003]o>d0kOc]0080kOc]0P0000090>ckk0030000
003]nnd0kO_]00P0kO_]0P0000020>_jj`030000003[n^/0jo[[00D0jo[[00<000000>_jj`3[n^/0
0`3[n^/00`000000j_WZ0>[ijP050>[ijP800000103XmnP00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo01T0oooo000M0?ooo`8000002@3oool00`000000_<Nl0;c7_0040;c7_00300000034
d<@0000000<0000000<0]L2e00000030c<001`30c<000`000000bmS;0<_Hb`080<_Hb`030000003E
h]D0eN;E00@0eN;E1`00000:0=o^g`030000003UlnD0iO?U00/0iO?U00<000000>Wgj@3YmnT00`00
00090>Sgj0030000003[n^/0jo[[00P0jo[[0`0000020>_ij`030000003/nn`0k?_/00`0k?_/00@0
00000>glk@0000000000303/nn`00`000000kO_]0>gkk@050>gkk@800000103[n^/00`000000jo[[
0>_jj`060>_jj`030000003[n^/0jo[[00<0jo[[00<000000>[ijP3ZnNX00P3ZnNX2000000H0j?OX
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`000000oooo0?oo
o`090?ooo`030000002lak`0_<Nl00@0_<Nl00<000000<C@a034d<@00P34d<@7000000@0`<c000<0
00000<_Hb`3;f</0103;f</:000000D0f^OJ00<000000=o^g`3Ok]l02P3Ok]l2000000/0iO?U0`00
000=0>Sgj0030000003[n^/0jo[[00@0jo[[100000050>_ij`030000003/nn`0k?_/00/0k?_/0P00
000>0>ckk0030000003]nnd0kO_]00<0kO_]0P0000070>_jj`030000003[n^/0jo[[00D0jo[[00<0
00000>_jj`3[n^/00`3[n^/00`000000j_WZ0>[ijP02000000T0j?OX00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0H0?ooo`005P3oool2000000@0oooo00<000000?ooo`3oool02`3oool0
0`000000_<Nl0;c7_0030;c7_00300000034d<@0a=3400D0a=3400@000000<_Hb`3;f</0bmS;2`00
00050=?Pd`030000003JimX0f^OJ00P0f^OJ00<000000=o^g`3Ok]l02`3Ok]l00`000000iO?U0>Gc
i@050>Gci@<000000P3Um>D00`000000j?OX0>Sgj00<0>Sgj0040000003[n^/0jo[[0>_jj`@00000
203[nN/00`000000k?_/0>ckk0080>ckk08000000P3[n^/00`000000k?_/0>ckk00<0>ckk0030000
003]nnd0kO_]008000002@3[n^/00`000000jo[[0>_jj`060>_jj`030000003[n^/0jo[[0080jo[[
0`00000;0>Sgj0030000003oool0oooo00/0oooo00<000000?ooo`3oool05`3oool001D0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0;0?ooo`030000002lak`0_<Nl00@0_<Nl
00<000000<C@a034d<@01@34d<@00`000000bmS;0<_Hb`060<_Hb`030000003Ch=<0dn3C00P0dn3C
00<000000=[WfP3JimX0203JimX00`000000gnkO0=o^g`0;0=o^g`030000003UlnD0iO?U00@00000
1P3Um>D00`000000j?OX0>Sgj00<0>Sgj0D000002P3[nN/00`000000k?_/0>ckk0060>ckk0800000
1@3[n^/00`000000k?_/0>ckk00;0>ckk0<00000303[n^/00`000000jo[[0>_jj`060>_jj`060000
003[n^/000000000003Yn>T00000303XmnP00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01L0oooo000H0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000_<Nl0;c7_0040;c7
_00300000034d<@0a=3400D0a=3400<000000<_Hb`3;f</01P3;f</00`000000dn3C0=?Pd`080=?P
d`030000003JimX0f^OJ00P0f^OJ00<000000=o^g`3Ok]l02P3Ok]l3000000/0iOCU00<000000>Sg
j03XmnP0203XmnP6000000d0joW[00<000000>ckk03/nn`00`3/nn`2000000P0jo[[00<000000>ck
k03/nn`0203/nn`200000080jo[[00<000000>_jj`3[n^/02P3[n^/00`000000jo[[0>_jj`060>_j
j`800000103Yn>T00`000000j?OX0>Sgj00:0>Sgj0030000003oool0oooo00/0oooo00<000000?oo
o`3oool05P3oool000l0oooo100000030?ooo`800000103oool00`000000oooo0?ooo`0<0?ooo`03
0000002lak`0_<Nl00D0_<Nl00<000000<C@a034d<@01034d<@00`000000bmS;0<_Hb`070<_Hb`03
0000003Ch=<0dn3C00P0dn3C00<000000=[WfP3JimX0203JimX00`000000gnkO0=o^g`050=o^g`@0
00000P3Rl>800`000000iOCU0>Gdi@0:0>Gdi@030000003XmnP0j?OX00@0j?OX1P0000020>Sgj003
0000003[nN/0joW[00`0joW[00<000000>ckk03/nn`00P00000:0>_jj`030000003/nn`0k?_/00H0
k?_/0P0000040>_jj`030000003[n^/0jo[[00/0jo[[00<000000>_jj`3[n^/00P3[n^/300000003
0>Whj@000000jOSY00<0jOSY00<000000>Sgj03XmnP02P3XmnP00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01D0oooo000F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3@3oool3000000@0_<Nl00<000000<C@a034d<@01@34d<@00`000000bmS;0<_Hb`070<_Hb`030000
003Ch=<0dn3C00P0dn3C00<000000=[WfP3JimX0203JimX00`000000gnkO0=o^g`04000000L0h_3R
00<000000>Gdi@3Um>D02P3Um>D00`000000j?OX0>Sgj003000000030>Sgj0000000000000H0j?OX
00<000000>_ij`3[nN/02`3[nN/3000000d0jo[[00<000000>ckk03/nn`00`3/nn`2000000L0jo[[
00<000000>_jj`3[n^/02P3[n^/00`000000jo[[0>_jj`02000000D0jOSY00<000000>Whj@3Yn>T0
0P3Yn>T00`000000j?OX0>Sgj00:0>Sgj0030000003oool0oooo00/0oooo00<000000?ooo`3oool0
5@3oool001H0oooo0`0000030?ooo`030000003oool0oooo00h0oooo00<000000<WFb@0000000`00
00000`2lak`000000<C@a0060<C@a0030000003;f</0bmS;00L0bmS;00<000000=?Pd`3Ch=<0203C
h=<00`000000f^OJ0=[WfP040=[WfPH00000303Rl>800`000000iOCU0>Gdi@090>Gdi@<0000000@0
j?OX00000000000000002@3XmnP00`000000joW[0>_ij`070>_ij`<000000P3ZnNX00`000000jo[[
0>_jj`0<0>_jj`030000003/nn`0k?_/008000002@3[n^/00`000000jo[[0>_jj`0:0>_jj`<00000
203Yn>T01@000000jOSY0>Whj@3Yn>T0000000`0j?OX00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0D0?ooo`006`3oool00`000000oooo0?ooo`0?0?ooo`0300000039e/T0bMK900<0bMK9
1`0000030<C@a0030000003;f</0bmS;00L0bmS;00<000000=?Pd`3Ch=<0103Ch=<:000000D0gN_M
00<000000>;`hP3Rl>802P3Rl>800`000000iOCU0>Gdi@060>Gdi@<0000000@0iOCU000000000000
00003@3XmnP00`000000joW[0>_ij`040>_ij`8000001P3ZnNX00`000000jo[[0>_jj`0;0>_jj`<0
0000303[n^/00`000000jo[[0>_jj`070>_jj`8000000P3Yn>T00`000000jOSY0>Whj@060>Whj@03
0000003Yn>T0jOSY0080jOSY00<000000>Sgj03XmnP02P3XmnP00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01<0oooo000K0?ooo`030000003oool0oooo0100oooo00<000000<WFb@39e/T0
1@39e/T010000000c]_>0<kKcP3>flhD000000D0fNKI00<000000=g[g@3Mjmd0203Mjmd00`000000
h_3R0>;`hP0:0>;`hP030000003Um>D0iOCU00<0iOCU1P0000020>KdiP030000003XmnP0j?OX00`0
j?OX00<000000>_ij`3[nN/00`0000090>[ijP030000003[n^/0jo[[00P0jo[[0P0000020>[ijP03
0000003[n^/0jo[[00X0jo[[00<000000>_jj`3[n^/01@3[n^/2000000@0jOSY00<000000>Whj@3Y
n>T01`3Yn>T01@000000jOSY0>Whj@3Yn>T0000000/0j?OX0P00000>0?ooo`030000003oool0oooo
01<0oooo000K0?ooo`030000003oool0oooo0140oooo00<000000<WFb@39e/T01@39e/T00`000000
c]_>0<kKcP050<kKcP030000003ChM<0dn7C00L0dn7C00<000000=WVf@3Ii]T0203Ii]T00`000000
gN_M0=g[g@080=g[g@030000003Rl>80h_3R00X0h_3R00<000000>Gdi@000000100000070>KdiP03
0000003XmnP0j?OX00/0j?OX0`00000<0>[ijP030000003[n^/0jo[[00H0jo[[0P0000040>[ijP03
0000003[n^/0jo[[00/0jo[[00<000000>_jj`3[n^/00P3[n^/2000000L0jOSY00<000000>Whj@3Y
n>T01`3Yn>T01@000000jOSY0>Whj@3Yn>T0000000H0j?OX100000000`3VmNH000000?ooo`0>0?oo
o`030000003oool0oooo0180oooo000K0?ooo`030000003oool0oooo0140oooo00<000000<WFb@39
e/T01@39e/T00`000000c]_>0<kKcP060<kKcP030000003ChM<0dn7C00L0dn7C00<000000=WVf@3I
i]T0203Ii]T00`000000gN_M0=g[g@080=g[g@030000003Rl>80h_3R00P0h_3R1000000<0>KdiP03
0000003XmnP0j?OX00L0j?OX0`0000020>Sgj0030000003ZnNX0j_WZ00/0j_WZ00<000000>_jj`3[
n^/00`3[n^/2000000L0j_WZ00<000000>_jj`3[n^/02P3[n^/00`000000jo[[0>_jj`02000000T0
jOSY00<000000>Whj@3Yn>T0203Yn>T010000000jOSY0>Whj@0000020>Sgj0@000001P3VmNH00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo000K0?ooo`8000004`3oool00`000000
bMK90<WFb@050<WFb@030000003>flh0c]_>00H0c]_>00<000000=?Qd`3ChM<01`3ChM<00`000000
fNKI0=WVf@070=WVf@030000003Mjmd0gN_M00T0gN_M00<000000>;`hP3Rl>80103Rl>8400000080
ho7S00<000000>KdiP3Vm>H02`3Vm>H00`000000j?OX0>Sgj0040>Sgj08000001P3XmnP00`000000
j_WZ0>[ijP0;0>[ijP030000003[n^/0jo[[008000002@3ZnNX00`000000jo[[0>_jj`0:0>_jj`<0
0000303Yn>T00`000000jOSY0>Whj@070>Whj@030000003Yn>T0jOSY00<000002P3VmNH00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo000K0?ooo`030000003oool0oooo01<0oooo
00<000000<WFb@39e/T01@39e/T00`000000c]_>0<kKcP050<kKcP030000003ChM<0dn7C00L0dn7C
00<000000=WVf@3Ii]T0203Ii]T00`000000gN_M0=g[g@090=g[g@030000003Rl>80h_3R00@00000
1P3SlN<00`000000i_CV0>KdiP0;0>KdiP030000003XmnP0j?OX00<000002@3XmnP00`000000j_WZ
0>[ijP0:0>[ijP<00000303ZnNX00`000000jo[[0>_jj`060>_jj`<000000P3Yn>T00`000000jOSY
0>Whj@0:0>Whj@030000003Yn>T0jOSY00L0jOSY0`0000000`3Wm^L000000>KeiP0;0>KeiP030000
003oool0oooo00d0oooo00<000000?ooo`3oool0403oool001@0oooo0P0000040?ooo`030000003o
ool0oooo01D0oooo00<000000<WFb@39e/T01@39e/T00`000000c]_>0<kKcP050<kKcP030000003C
hM<0dn7C00L0dn7C00<000000=WVf@3Ii]T0203Ii]T00`000000gN_M0=g[g@070=g[g@@000002`3S
lN<00`000000i_CV0>KdiP0:0>KdiP<00000303XmnP00`000000j_WZ0>[ijP070>[ijP<000000P3Y
n>T00`000000j_WZ0>[ijP0;0>[ijP030000003[n^/0jo[[00<0jo[[0P0000050>Whj@030000003Y
n>T0jOSY00/0jOSY00<000000>Whj@3Yn>T00`3Yn>T300000080ioKW00@000000>Ofi`3Wm^L00000
2`3VmNH00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo000C0?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool05@3oool00`000000bMK90<WFb@050<WFb@030000
003>flh0c]_>00H0c]_>00<000000=?Qd`3ChM<01`3ChM<00`000000fNKI0=WVf@080=WVf@040000
003Mjmd0gN_M0=g[g@H000000P3Pk^000`000000ho7S0>?ah`0:0>?ah`030000003Vm>H0i_CV00L0
i_CV0P0000020>KeiP030000003XmnP0j?OX00/0j?OX00<000000>[ijP3ZnNX0103ZnNX2000000D0
jOSY00<000000>[ijP3ZnNX02`3ZnNX00`000000jo[[0>_jj`03000000P0jOSY00<000000>Whj@3Y
n>T02P3Yn>T00`000000jOSY0>Whj@03000000H0ioKW00<000000>Ofi`000000303VmNH00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo000C0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool05P3oool5000000<0bMK900<000000<kKcP3>flh01P3>flh00`000000
dn7C0=?Qd`070=?Qd`030000003Ii]T0fNKI00@0fNKI1`0000000`3Pk^000000000000060>3^h003
0000003SlN<0ho7S00X0ho7S00<000000>KdiP3Vm>H00`3Vm>H3000000D0i_GV00<000000>Sgj03X
mnP02`3XmnP00`000000j_WZ0>[ijP03000000P0jOSY00<000000>[ijP3ZnNX02P3ZnNX3000000`0
jOSY00<000000>Whj@3Yn>T02@3Yn>T3000000T0ioKW00@000000>Ofi`3Wm^L000002`3VmNH00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo000C0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool05`3oool010000000dn3C0=?Pd`3Ch=<M000000D0gN_M0`000009
0>3^h0030000003SlN<0ho7S00X0ho7S00<000000>KdiP3Vm>H00P0000090>KeiP030000003XmnP0
j?OX00X0j?OX0`00000<0>Whj@030000003ZnNX0j_WZ00H0j_WZ0`0000020>Whj@030000003Yn>T0
jOSY00/0jOSY00<000000>Whj@3Yn>T0103Yn>T400000080j?KX00<000000>Ofi`3Wm^L0203Wm^L0
0`000000ioKW0000000<0>KeiP030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool0
01<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0G0?ooo`030000003Ch=<0
dn3C00H0dn3C00<000000=KTeP3Fi=H01P3Fi=H00`000000f^OJ0=[WfP070=[WfP030000003Mjmd0
gN_M00@0gN_M0`0000000`3Mjmd000000>3^h00:0>3^h0030000003SlN<0ho7S00P0ho7S1000000;
0>KeiP030000003XmnP0j?OX00L0j?OX0`0000020>Sgj0030000003Yn>T0jOSY00/0jOSY00<00000
0>[ijP3ZnNX00`3ZnNX2000000D0jOSY00<000000>Whj@3Yn>T02`3Yn>T00`000000jOSY0>Whj@04
000000H0j?KX00<000000>Ofi`3Wm^L02@3Wm^L00`000000ioKW0000000;0>KeiP030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool001@0oooo0P0000040?ooo`030000003oool0oooo
01P0oooo00<000000=?Pd`3Ch=<01@3Ch=<00`000000e^CF0=KTeP070=KTeP030000003JimX0f^OJ
00L0f^OJ00<000000=g[g@3Mjmd00`0000050=g[g@030000003Pk^00h>kP00T0h>kP00@000000>?a
h`3SlN<0ho7S1P0000030>Gci@030000003VmNH0i_GV00X0i_GV00<000000>Sgj03XmnP0103XmnP2
000000H0j?OX00<000000>Whj@3Yn>T02P3Yn>T00`000000j_WZ0>[ijP03000000P0jOSY00<00000
0>Whj@3Yn>T02P3Yn>T3000000/0j?KX00<000000>Ofi`3Wm^L0203Wm^L00`000000ioKW0000000<
0>KeiP030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool000@0oooo0P00000C0?oo
o`030000003oool0oooo01T0oooo00<000000=?Pd`3Ch=<01P3Ch=<00`000000e^CF0=KTeP070=KT
eP030000003JimX0f^OJ00H0f^OJ0`0000090=g[g@030000003Pk^00h>kP00L0h>kP1@00000:0>Gc
i@030000003VmNH0i_GV00X0i_GV00<000000>Sgj03XmnP00`0000090>Sgj0030000003Yn>T0jOSY
00T0jOSY0`00000<0>Whj@030000003Yn>T0jOSY00H0jOSY0`0000020>Sfj0030000003Xm^P0j?KX
00X0j?KX00<000000>Ofi`3Wm^L0203Wm^L00`000000ioKW000000090>KeiP<00000403oool00`00
0000oooo0?ooo`0<0?ooo`00103oool2000001<0oooo00<000000?ooo`3oool06P3oool00`000000
dn3C0=?Pd`060=?Pd`030000003Fi=H0e^CF00H0e^CF00<000000=[WfP3JimX00`3JimX300000003
0=[WfP000000gN_M00X0gN_M00@000000>3^h03Pk^00h>kP1@0000030>?ah`030000003UlnD0iO?U
00X0iO?U00<000000>KeiP3VmNH02@3VmNH3000000d0j?OX00<000000>Whj@3Yn>T01@3Yn>T30000
0080j?OX00<000000>Whj@3Yn>T02`3Yn>T00`000000jOSY0>Whj@030>Whj@8000001@3Xm^P00`00
0000j?KX0>Sfj00:0>Sfj0030000003Wm^L0ioKW00T0ioKW0P0000030>KeiPH000000P3Tl^@00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00030?ooo`040000003oool0oooo0000
0180oooo00<000000?ooo`3oool06`3oool00`000000dn3C0=?Pd`050=?Pd`030000003Fi=H0e^CF
00L0e^CF00<000000=[WfP0000000P0000050=[WfP030000003Mjmd0gN_M00L0gN_M1@0000090>?a
h`030000003UlnD0iO?U00X0iO?U00<000000>KeiP3VmNH01@3VmNH300000080ioGW00<000000>Sg
j03XmnP0303XmnP00`000000jOSY0>Whj@04000000H0j?OX00<000000>Whj@3Yn>T02P3Yn>T00`00
0000jOSY0>Whj@03000000P0j?KX00<000000>Sfj03Xm^P02P3Xm^P00`000000ioKW0>Ofi`090>Of
i`@000002@3Tl^@00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo1@0000010?oo
o`000P3oool200000080oooo0P00000A0?ooo`030000003oool0oooo01/0oooo00<000000=?Pd`3C
h=<01P3Ch=<00`000000e^CF0=KTeP060=KTeP8000002@3JimX010000000gN_M0=g[g@3Mjmd50000
00<0hNoQ00<000000>?ah`3SlN<02@3SlN<00`000000iO?U0>Gci@0:0>Gci@030000003VmNH0i_GV
00@000001P3WmNL00`000000j?OX0>Sgj00;0>Sgj0<000002`3XmnP00`000000jOSY0>Whj@090>Wh
j@<00000303Xm^P00`000000j?KX0>Sfj00:0>Sfj0030000003Wm^L0ioKW00@0ioKW1P00000;0>Cb
i0030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`010?oo
o`006@3oool00`000000oooo0?ooo`0L0?ooo`030000003Ch=<0dn3C00H0dn3C00<000000=KTeP3F
i=H00P3Fi=H300000080e^CF00<000000=[WfP3JimX00`3JimX7000000T0hNoQ00<000000>?ah`3S
lN<0203SlN<00`000000iO?U0>Gci@0:0>Gci@<000002`3WmNL00`000000j?OX0>Sgj0070>Sgj0<0
00000P3Xm^P00`000000j?OX0>Sgj00:0>Sgj0030000003Yn>T0jOSY00D0jOSY0`0000020>Sfj003
0000003Xm^P0j?KX00/0j?KX00<000000>Sfj03Xm^P02@3Xm^P00`000000ioKW0>Ofi`04000000D0
iO?U0P00000;0>Cbi0030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`010?ooo`006@3oool2000001d0oooo00<000000=?Pd`3Ch=<01P3Ch=<00`000000e^CF
0000000200000080e^CF2@0000050=k/gP030000003Qkn40hNoQ00T0hNoQ00<000000>?ah`3SlN<0
203SlN<00`000000iO?U0>Gci@050>Gci@@000000P3Vm>H00`000000ioGW0>Oei`0:0>Oei`030000
003XmnP0j?OX00@0j?OX0P0000050>Sfj0030000003XmnP0j?OX00/0j?OX00<000000>Whj@3Yn>T0
100000060>Sfj0030000003Xm^P0j?KX00X0j?KX00<000000>Sfj03Xm^P0203Xm^P4000000X0iO?U
00<000000>Cbi03Tl^@02@3Tl^@00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00@3oool00180oooo0P0000040?ooo`030000003oool0oooo01h0oooo3`00
00050=cZg0030000003Nk=h0g^cN00H0g^cN00<000000>7_h@3Qkn402@3Qkn400`000000ho7S0>?a
h`090>?ah`030000003UlnD0iO?U00@000001`3Vm>H00`000000ioGW0>Oei`0:0>Oei`030000003X
mnP0j?OX00<00000203Xm^P00`000000j?OX0>Sgj00:0>Sgj0<000002`3Xm^P00`000000j?KX0>Sf
j00:0>Sfj0040000003Xm^P0j?KX0>Sfj0H000000`3Um>D00`000000iO?U0>Gci@090>Gci@030000
003Tl^@0i?;T00T0i?;T00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0040oooo000A0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
7`3oool00`000000fNOI0=WWf@03000000<0fNOI00<000000=cZg03Lj]`01`3Lj]`00`000000g^cN
0=k/gP070=k/gP030000003Qkn40hNoQ00T0hNoQ00<000000>?ah`3SlN<01`3SlN<4000000`0i_CV
00<000000>Oei`3WmNL02@3WmNL3000000`0j?KX00<000000>Sgj03XmnP01P3XmnP300000080ioKW
00<000000>Sfj03Xm^P02@3Xm^P00`000000j?KX0>Sfj00:0>Sfj0@000002@3Um>D00`000000iO?U
0>Gci@090>Gci@030000003Tl^@0i?;T00T0i?;T00<000000?ooo`3oool03P3oool3000000@0oooo
0P0000030?ooo`00503oool01@000000oooo0?ooo`3oool000000240oooo0`0000060=WWf@030000
003Lj]`0g>[L00P0g>[L00<000000=k/gP3Nk=h01`3Nk=h00`000000hNoQ0>7_h@090>7_h@040000
003SlN<0ho7S0>?ah`D000000`3UlnD00`000000i_CV0>KdiP0;0>KdiP030000003WmNL0ioGW00D0
ioGW0`0000020>Ofi`030000003Xm^P0j?KX00/0j?KX00<000000>Sgj03XmnP00`3XmnP2000000D0
ioKW00<000000>Sfj03Xm^P02P3Xm^P00`000000j?KX0>Sfj0050>Sfj0@0000000<0i_CV0000003U
m>D02`3Um>D00`000000iO?U0>Gci@090>Gci@030000003Tl^@0i?;T00T0i?;T00<000000?ooo`3o
ool02P3oool4000000030?ooo`000000oooo00P0oooo000B0?ooo`800000103oool00`000000oooo
0?ooo`0L0?ooo`<0000000<0oooo0000003IimT01`3IimT00`000000g>[L0=cZg0080=cZg0030000
003Nk=h0g^cN00L0g^cN00<000000>7_h@3Qkn40203Qkn44000000T0iO?U00<000000>KdiP3Vm>H0
2`3Vm>H00`000000ioGW0>Oei`04000000H0ioKW00<000000>Sfj03Xm^P02P3Xm^P00`000000j?OX
0>Sgj003000000P0ioKW00<000000>Sfj03Xm^P02P3Xm^P00`000000j?KX0>Sfj004000000H0i_CV
00<000000>Gdi@3Um>D02@3Um>D00`000000iO?U0>Gci@090>Gci@8000002P3Tl^@00`000000oooo
0?ooo`070?ooo`<000001@3oool00`000000oooo0?ooo`070?ooo`004P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01X0oooo0P0000040?ooo`030000003IimT0fNOI00L0fNOI00<0
00000=cZg03Lj]`0203Lj]`00`000000g^cN0=k/gP060=k/gP030000003Qkn40hNoQ00D0hNoQ0`00
00020>?bh`030000003UlnD0iO?U00T0iO?U00<000000>KdiP3Vm>H02P3Vm>H3000000/0ioKW00<0
00000>Sfj03Xm^P02@3Xm^P3000000`0ioKW00<000000>Sfj03Xm^P02@3Xm^P3000000X0i_CV00<0
00000>Gdi@3Um>D02P3Um>D00`000000iO?U0>Gci@090>Gci@030000003Tl^@0i?;T00L0i?;T0`00
00050?ooo`<00000203oool00`000000oooo0?ooo`070?ooo`004P3oool3000000<0oooo00<00000
0?ooo`3oool05`3oool3000000L0oooo00<000000=WWf@3IimT01P3IimT00`000000g>[L0=cZg008
0=cZg0030000003Nk=h0g^cN00L0g^cN00<000000>7_h@3Qkn40100000060>?bh`030000003UlnD0
iO?U00T0iO?U00<000000>KdiP3Vm>H01@3Vm>H400000080ioGW00<000000>Ofi`3Wm^L02P3Wm^L0
0`000000j?KX0>Sfj0050>Sfj0<000000P3Wm^L00`000000ioKW0>Ofi`0;0>Ofi`030000003Xm^P0
j?KX00@0j?KX100000020>KdiP030000003Vm>H0i_CV00T0i_CV00<000000>Gdi@3Um>D02P3Um>D0
0`000000iO?U0>Gci@080>Gci@8000000P3Tl^@600000080h>kP00<000000?ooo`0000000`00000<
0?ooo`030000003oool0oooo00H0oooo000G0?ooo`030000003oool0oooo01D0oooo0`00000;0?oo
o`030000003IimT0fNOI00H0fNOI00<000000=cZg03Lj]`0203Lj]`00`000000g^cN0=k/gP030=k/
gPH000002`3Sl^<00`000000iO?U0>Gci@090>Gci@030000003Vm>H0i_CV00@000001`3WmNL00`00
0000ioKW0>Ofi`0:0>Ofi`030000003Xm^P0j?KX00@000001P3Wm^L00`000000ioKW0>Ofi`0:0>Of
i`030000003Xm^P0j?KX00@000001P3Vm>H00`000000i_CV0>KdiP090>KdiP030000003Um>D0iOCU
00X0iOCU00<000000>Gci@3UlnD0103UlnD8000000T0h>kP00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`060?ooo`005`3oool00`000000oooo0?ooo`0B0?ooo`<000003P3oool00`000000
fNOI0=WWf@070=WWf@030000003Lj]`0g>[L00H0g>[L1`0000050>;`hP030000003Sl^<0ho;S00T0
ho;S00<000000>Gci@3UlnD02@3UlnD3000000/0ioGW00<000000>Ofi`3Wm^L02P3Wm^L3000000X0
ioKW00<000000>Ofi`3Wm^L02P3Wm^L3000000/0i_CV00<000000>KdiP3Vm>H02@3Vm>H00`000000
iOCU0>Gdi@080>Gdi@P000001P3Qkn42000000T0h>kP00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`060?ooo`005`3oool00`000000oooo0?ooo`0?0?ooo`<000004P3oool00`000000fNOI
0=WWf@060=WWf@040000003Lj]`0g>[L0=cZg0D000000`3Pk^000`000000h_3R0>;`hP070>;`hP03
0000003Sl^<0ho;S00T0ho;S00<000000>Gci@3UlnD01@3UlnD300000080i_GV00<000000>Oei`3W
mNL02P3WmNL00`000000ioKW0>Ofi`050>Ofi`@000000P3Wm^L00`000000ioKW0>Ofi`090>Ofi`03
0000003Wm^L0ioKW00D0ioKW100000020>KeiP030000003Vm>H0i_CV00X0i_CV00<000000>KdiP3V
m>H0203Vm>H00`000000iOCU0>Gdi@020>Gdi@H000000P3RlN800`000000hNoQ0>7_h@090>7_h@80
00002P3Pk^000`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo000G0?ooo`030000
003oool0oooo00`0oooo0`00000E0?ooo`030000003IimT0fNOI00<0fNOI1`0000080>3^h0030000
003Rl>80h_3R00P0h_3R00<000000>?bh`3Sl^<02@3Sl^<00`000000iO?U0>Gci@04000000H0i_GV
00<000000>Oei`3WmNL02P3WmNL00`000000ioKW0>Ofi`04000000L0ioKW00<000000>Ofi`3Wm^L0
2@3Wm^L00`000000ioKW0>Ofi`04000000L0i_GV00<000000>KdiP3Vm>H02P3Vm>H00`000000i_CV
0>KdiP060>KdiPH000002@3RlN800`000000hNoQ0>7_h@090>7_h@8000002@3Pk^000`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00H0oooo000G0?ooo`030000003oool0oooo00T0oooo0`00
000I0?ooo`D000001@3NkMh00`000000h>kP0>3^h0080>3^h0030000003Rl>80h_3R00P0h_3R00<0
00000>?bh`3Sl^<0203Sl^<3000000/0i_GV00<000000>Oei`3WmNL02@3WmNL3000000/0ioKW00<0
00000>Ofi`3Wm^L02@3Wm^L3000000/0i_GV00<000000>KdiP3Vm>H02P3Vm>H010000000i_CV0>Kd
iP3Vm>H5000000<0ho;S00<000000>;ahP3RlN802@3RlN800`000000hNoQ0>7_h@090>7_h@030000
003Pk^00000000T0h>kP00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`005`3o
ool00`000000oooo0?ooo`070?ooo`8000007@3oool00`000000g^gN0=k]gP070=k]gP030000003P
k^00h>kP00P0h>kP00<000000>;`hP3Rl>80203Rl>800`000000ho;S0>?bh`040>?bh`<000000P3V
m>H00`000000i_GV0>KeiP090>KeiP030000003WmNL0ioGW00L0ioGW0P0000020>Sfj0030000003W
m^L0ioKW00X0ioKW00<000000>Ofi`3Wm^L01@3Wm^L300000080ioKW00<000000>KeiP3VmNH02P3V
mNH00`000000i_CV0>KdiP080>KdiPD00000203Sl^<00`000000h_7R0>;ahP0:0>;ahP030000003Q
kn40hNoQ00T0hNoQ0P0000090>3^h0030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3o
ool001H0oooo00<000000?ooo`3oool01@3oool3000001l0oooo00<000000=k]gP3NkMh0203NkMh0
0`000000h>kP0>3^h0080>3^h0030000003Rl>80h_3R00P0h_3R00<000000>?bh`3Sl^<00`000006
0>KdiP030000003VmNH0i_GV00T0i_GV00<000000>Oei`3WmNL00`3WmNL3000000D0j?KX00<00000
0>Ofi`3Wm^L02P3Wm^L00`000000ioKW0>Ofi`04000000H0ioKW00<000000>KeiP3VmNH02P3VmNH0
10000000i_CV0>KdiP3Vm>H6000000<0i??T00<000000>?bh`3Sl^<0203Sl^<00`000000h_7R0>;a
hP090>;ahP030000003Qkn40hNoQ00T0hNoQ00<000000>3^h00000002@3Pk^000`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00H0oooo000F0?ooo`030000003oool0oooo0080oooo0`00000S
0?ooo`030000003NkMh0g^gN00L0g^gN00<000000>3^h03Pk^00203Pk^000`000000h_3R0>;`hP07
0>;`hP@000002P3Vm>H00`000000i_GV0>KeiP090>KeiP030000003WmNL0ioGW008000002@3Xm^P0
0`000000ioKW0>Ofi`090>Ofi`<000002`3Wm^L00`000000i_GV0>KeiP090>KeiP@000002P3Tln@0
0`000000ho;S0>?bh`080>?bh`030000003RlN80h_7R00T0h_7R00<000000>7_h@3Qkn402@3Qkn40
0`000000h>kP000000080>3^h0030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool0
01H0oooo00<000000?ooo`0000000P00000W0?ooo`030000003NkMh0g^gN00L0g^gN00<000000>3^
h03Pk^00203Pk^0010000000h_3R0>;`hP3Rl>85000000<0iO?U00<000000>KdiP3Vm>H0203Vm>H0
0`000000i_GV0>KeiP090>KeiP<00000303Xm^P00`000000ioKW0>Ofi`050>Ofi`<000000P3Xm^P0
0`000000ioKW0>Ofi`0:0>Ofi`030000003VmNH0i_GV00D0i_GV0`0000020>Gdi@030000003Tln@0
i??T00T0i??T00<000000>?bh`3Sl^<02@3Sl^<00`000000h_7R0>;ahP080>;ahP030000003Qkn40
hNoQ00T0hNoQ00@000000>3^h03Pk^000000203Pk^000`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00D0oooo000F0?ooo`800000:P3oool00`000000g^gN0=k]gP080=k]gP030000003Pk^00
h>kP00H0h>kP1@0000090>Gci@030000003Vm>H0i_CV00P0i_CV00<000000>KeiP3VmNH01@3VmNH3
00000080j?KX00<000000>Sfj03Xm^P02`3Xm^P00`000000ioKW0>Ofi`04000000H0j?KX00<00000
0>Ofi`3Wm^L02P3Wm^L00`000000i_GV0>KeiP04000000H0iOCU00<000000>Cci03Tln@02@3Tln@0
0`000000ho;S0>?bh`080>?bh`030000003RlN80h_7R00@0h_7R7@00000=0?ooo`030000003oool0
oooo00D0oooo000G0?ooo`030000003oool0oooo02T0oooo00<000000=k]gP3NkMh0203NkMh01000
0000h>kP0>3^h03Pk^04000000<0i?;T00<000000>Gci@3UlnD02@3UlnD00`000000i_CV0>KdiP08
0>KdiP030000003VmNH0i_GV00@000001P3Xm^P00`000000j?KX0>Sfj00:0>Sfj0<000002`3Xm^P0
0`000000ioKW0>Ofi`090>Ofi`<000002P3Um>D00`000000i??T0>Cci00:0>Cci0030000003Sl^<0
ho;S00@0ho;S2P0000060=o]g`030000003Mjmd0gN_M00P0gN_M00@000000=cYg03LjM`000001`3L
jM`00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo000H0?ooo`800000:P3oool0
0`000000g^gN0=k]gP060=k]gPD000001`3Tl^@00`000000iO?U0>Gci@090>Gci@030000003Vm>H0
i_CV00P0i_CV0`00000;0>Sfj0030000003Xm^P0j?KX00L0j?KX0P0000020>Sgj0030000003Xm^P0
j?KX00X0j?KX00<000000>Ofi`3Wm^L01@3Wm^L300000080ioGW00<000000>Gdi@3Um>D02@3Um>D0
0`000000i??T0>Cci0080>Cci0P000001@3Qkn400`000000gngO0=o]g`080=o]g`030000003Mjmd0
gN_M00T0gN_M00@000000=cYg03LjM`000001`3LjM`00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00D0oooo000J0?ooo`030000003oool0oooo02L0oooo00@000000=k]gP3NkMh0g^gN1@00
00030>;`hP030000003Tl^@0i?;T00L0i?;T00<000000>Gci@3UlnD02@3UlnD00`000000i_CV0>Kd
iP040>KdiP<000000P3Xm^P00`000000j?KX0>Sfj00:0>Sfj0030000003Xm^P0j?KX00<0j?KX0`00
00050>Sgj0030000003Xm^P0j?KX00X0j?KX00<000000>Ofi`3Wm^L0100000060>Oei`030000003U
m>D0iOCU00T0iOCU00@000000>Cci03Tln@0i??T1P0000030>;`hP030000003Qkn40hNoQ00L0hNoQ
00<000000=o]g`3OkMl02@3OkMl00`000000gN_M0=g[g@080=g[g@050000003LjM`0g>WL0=cYg000
00001P3LjM`00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo000K0?ooo`030000
003oool0oooo02L0oooo0`0000080>;`hP030000003Tl^@0i?;T00P0i?;T00<000000>Gci@3UlnD0
2@3UlnD00`000000i_CV0>KdiP03000000H0j?KX00<000000>Sfj03Xm^P02P3Xm^P00`000000j?KX
0>Sfj002000000T0j?OX00<000000>Sfj03Xm^P02@3Xm^P3000000X0ioGW00<000000>Gdi@3Um>D0
2@3Um>D4000000T0h_3R00<000000>7_h@3Qkn40203Qkn400`000000gngO0=o]g`080=o]g`030000
003Mjmd0gN_M00T0gN_M00@000000=cYg03LjM`000001`3LjM`00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00D0oooo000L0?ooo`030000003oool0oooo02L0oooo00<000000>;`hP3Rl>80
203Rl>800`000000i?;T0>Cbi0080>Cbi0030000003UlnD0iO?U00P0iO?U0`00000:0>Sfj0030000
003Xm^P0j?KX00T0j?KX0`00000<0>Sgj0030000003Xm^P0j?KX00D0j?KX0`0000020>Sgj0030000
003WmNL0ioGW00T0ioGW00<000000>Gdi@3Um>D01@3Um>D300000080i?;T00<000000>;`hP3Rl>80
2@3Rl>800`000000hNoQ0>7_h@080>7_h@030000003OkMl0gngO00P0gngO00<000000=g[g@3Mjmd0
203Mjmd01@000000g>WL0=cYg03LjM`0000000H0g>WL00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`040?ooo`007@3oool2000002L0oooo00<000000>;`hP3Rl>802@3Rl>800`000000i?;T
0>Cbi0070>Cbi0030000003UlnD0iO?U00D0iO?U0`0000020>Ofi`030000003Xm^P0j?KX00T0j?KX
00<000000>Sfj03Xm^P01@3Xm^P300000080jOSY00<000000>Sgj03XmnP02`3XmnP00`000000j?KX
0>Sfj004000000H0j?OX00<000000>Oei`3WmNL02@3WmNL00`000000iOCU0>Gdi@04000000H0i?;T
00<000000>;`hP3Rl>80203Rl>800`000000hNoQ0>7_h@090>7_h@030000003OkMl0gngO00P0gngO
00<000000=g[g@3Mjmd0203Mjmd01@000000g>WL0=cYg03LjM`0000000H0g>WL00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`040?ooo`007`3oool00`000000oooo0?ooo`0U0?ooo`030000
003Rl>80h_3R00P0h_3R00<000000>Cbi03Tl^@0203Tl^@00`000000iO?U0>Gci@04000000H0ioKW
00<000000>Sfj03Xm^P02@3Xm^P00`000000j?KX0>Sfj004000000H0jOSY00<000000>Sgj03XmnP0
2P3XmnP3000000X0j?OX00<000000>Oei`3WmNL02@3WmNL3000000X0i?;T00<000000>;`hP3Rl>80
2@3Rl>800`000000hNoQ0>7_h@080>7_h@030000003OkMl0gngO00P0gngO00<000000=g[g@3Mjmd0
203Mjmd01@000000g>WL0=cYg03LjM`0000000H0g>WL00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`040?ooo`00803oool00`000000oooo0?ooo`0T0?ooo`030000003Rl>80h_3R00T0h_3R
00<000000>Cbi03Tl^@01`3Tl^@3000000/0ioKW00<000000>Sfj03Xm^P0203Xm^P3000000/0jOSY
00<000000>Sgj03XmnP01`3XmnP200000080jOSY00<000000>Sgj03XmnP02@3XmnP00`000000ioGW
0>Oei`050>Oei`<000000P3Vm>H00`000000i?;T0>Cbi0090>Cbi0030000003Rl>80h_3R00P0h_3R
00<000000>7_h@3Qkn40103Qkn4F000000D0gN_M00D000000=cYg03LjM`0g>WL000000060=cYg003
0000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00240oooo00<000000?ooo`3oool0
903oool00`000000h_3R0>;`hP090>;`hP030000003Tl^@0i?;T00<0i?;T0`0000020>KeiP030000
003Wm^L0ioKW00T0ioKW00<000000>Sfj03Xm^P01P3Xm^P200000080jOSY00<000000>Whj@3Yn>T0
2P3Yn>T00`000000j?OX0>Sgj0030>Sgj0<000001@3Yn>T00`000000j?OX0>Sgj0090>Sgj0030000
003WmNL0ioGW00@000001P3Vm>H00`000000i?;T0>Cbi0090>Cbi0030000003Rl>80h_3R00@0h_3R
2P0000060=g[g@030000003Jj=X0f^SJ00P0f^SJ00<000000=SVf03Hi]P00P3Hi]P;000000D0g>WL
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`008P3oool2000002D0oooo00<0
00000>;`hP3Rl>80203Rl>800`000000i?;T0>Cbi003000000D0i_GV00<000000>Ofi`3Wm^L02P3W
m^L00`000000j?KX0>Sfj0030>Sfj08000001@3Yn>T00`000000jOSY0>Whj@0:0>Whj@030000003X
mnP0j?OX00800000203Yn>T00`000000j?OX0>Sgj0090>Sgj0<000002`3Vm>H00`000000i?;T0>Cb
i0070>Cbi0P000001@3OkMl00`000000gN_M0=g[g@080=g[g@030000003Jj=X0f^SJ00P0f^SJ00<0
00000=SVf03Hi]P0203Hi]P00`000000e^CF0=KTeP020=KTePL000002@3oool00`000000oooo0?oo
o`040?ooo`00903oool00`000000oooo0?ooo`0R0?ooo`030000003Rl>80h_3R00P0h_3R0`000009
0>KeiP030000003Wm^L0ioKW00X0ioKW00<000000>Sfj03Xm^P00P0000080>Whj@030000003Yn>T0
jOSY00T0jOSY0`00000;0>Whj@030000003XmnP0j?OX00D0j?OX0`0000020>Sgj0030000003Vm>H0
i_CV00X0i_CV00@000000>Cbi03Tl^@0i?;T1@0000030>;ahP030000003OkMl0gngO00P0gngO00<0
00000=g[g@3Mjmd0203Mjmd00`000000f^SJ0=[XfP080=[XfP030000003Hi]P0f>KH00L0f>KH00<0
00000=KTeP3Fi=H00P3Fi=H00`000000e^CF0=KTeP030=KTeP030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0103oool002D0oooo00<000000?ooo`3oool08P3oool00`000000h_3R0>;`hP04
0>;`hP<000000P3UlnD00`000000i_GV0>KeiP080>KeiP030000003Wm^L0ioKW00T0ioKW0`00000:
0>Whj@030000003Yn>T0jOSY00L0jOSY0P0000020>[ijP030000003Yn>T0jOSY00X0jOSY00<00000
0>Sgj03XmnP0100000060>Sgj0030000003Vm>H0i_CV00T0i_CV100000090>;ahP030000003OkMl0
gngO00L0gngO00<000000=g[g@3Mjmd02@3Mjmd00`000000f^SJ0=[XfP080=[XfP030000003Hi]P0
f>KH00L0f>KH00<000000=KTeP3Fi=H00P3Fi=H00`000000e^CF0=KTeP030=KTeP030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool002H0oooo00<000000?ooo`3oool08@3oool00`00
0000h_3R0>;`hP04000000D0iO?U00<000000>KeiP3VmNH02@3VmNH00`000000ioKW0>Ofi`060>Of
i`8000000P3Yn>T00`000000jOSY0>Whj@090>Whj@030000003Yn>T0jOSY00<0jOSY0`0000050>[i
jP030000003Yn>T0jOSY00T0jOSY0`00000;0>Sgj0030000003Vm>H0i_CV00D0i_CV0`0000020>Gd
i@030000003RlN80h_7R00P0h_7R00<000000=o]g`3OkMl0203OkMl00`000000gN_M0=g[g@090=g[
g@030000003Jj=X0f^SJ00P0f^SJ00<000000=SVf03Hi]P01P3Hi]P00`000000e^CF0=KTeP030=KT
eP030000003Fi=H0e^CF0080e^CF00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`009`3oool200000280oooo0P00000:0>Gci@030000003VmNH0i_GV00P0i_GV00<000000>Ofi`3W
m^L00`3Wm^L3000000@0jOSY00<000000>Whj@3Yn>T02P3Yn>T00`000000jOSY0>Whj@02000000T0
j_WZ00<000000>Whj@3Yn>T01@3Yn>T300000080j_WZ00<000000>Sgj03XmnP02P3XmnP00`000000
i_CV0>KdiP04000000H0iOCU00<000000>;ahP3RlN80203RlN800`000000gngO0=o]g`080=o]g`03
0000003Mjmd0gN_M00P0gN_M00<000000=[XfP3Jj=X0203Jj=X00`000000f>KH0=SVf0070=SVf003
0000003Fi=H0e^CF00<0e^CF00<000000=KTeP3Fi=H00P3Fi=H00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo000Y0?ooo`030000003oool0oooo0200oooo00<000000>Gci@3UlnD0
203UlnD00`000000i_GV0>KeiP090>KeiP030000003Wm^L0ioKW00800000203Yn>T00`000000jOSY
0>Whj@090>Whj@<00000303ZnNX00`000000jOSY0>Whj@04000000H0j_WZ00<000000>Sgj03XmnP0
2@3XmnP3000000/0iOCU00<000000>;ahP3RlN80203RlN800`000000gngO0=o]g`040=o]gad00000
1`3Hi]P00`000000e^CF0=KTeP020=KTeP030000003Fi=H0e^CF0080e^CF00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`00:P3oool00`000000oooo0?ooo`0O0?ooo`030000003U
lnD0iO?U00T0iO?U00<000000>KeiP3VmNH0203VmNH3000000/0jOSY00<000000>Whj@3Yn>T01P3Y
n>T200000080joW[00<000000>[ijP3ZnNX02`3ZnNX2000000/0j_WZ00<000000>Sgj03XmnP01@3X
mnP300000080j?OX00<000000>Gdi@3Um>D02P3Um>D00`000000h_7R0>;ahP040>;ahPX000001@3L
j]`00`000000f>KH0=SVf0080=SVf0030000003Eh]D0eN;E00P0eN;E00<000000=;OdP0000001@00
00000`3Hi]P000000=KTeP040=KTeP030000003Fi=H0e^CF0080e^CF00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`00:`3oool00`000000oooo0?ooo`0O0?ooo`030000003UlnD0
iO?U00P0iO?U00<000000>KeiP3VmNH01P3VmNH200000080j?OX00<000000>Whj@3Yn>T02P3Yn>T0
0`000000jOSY0>Whj@020>Whj@<000001@3[nN/00`000000j_WZ0>[ijP080>[ijP80000000<0jo[[
0000003ZnNX02`3ZnNX00`000000j?OX0>Sgj004000000H0j?OX00<000000>Gdi@3Um>D02@3Um>D7
000000D0h>kP00<000000=cZg03Lj]`0203Lj]`00`000000f>KH0=SVf0070=SVf0030000003Eh]D0
eN;E00P0eN;E00<000000=;OdP3Bgm801@3Bgm84000000@0e^CF00D000000=KTeP3Fi=H0e^CF0000
00070?ooo`030000003oool0oooo00<0oooo000/0?ooo`030000003oool0oooo01l0oooo00<00000
0>Gci@3UlnD0203UlnD00`000000i_GV0>KeiP020>KeiP<000001@3XmnP00`000000jOSY0>Whj@09
0>Whj@030000003Yn>T0jOSY00800000203[nN/00`000000j_WZ0>[ijP060>[ijP800000103[n^/0
0`000000j_WZ0>[ijP090>[ijP<000002`3XmnP00`000000iOCU0>Gdi@050>Gdi@<000000P3Tln@0
0`000000h>kP0>3^h0080>3^h0030000003Lj]`0g>[L00L0g>[L00<000000=SVf03Hi]P0203Hi]P0
0`000000eN;E0=GRe@080=GRe@030000003Bgm80d]oB00H0d]oB00<000000=3Ld000000010000004
0=KTeP030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool002d0oooo0P00000O0?oo
o`030000003UlnD0iO?U00P0iO?U00<000000>KeiP3VmNH00P0000090>Sgj0030000003Yn>T0jOSY
00P0jOSY0`00000;0>_ij`030000003ZnNX0j_WZ00<0j_WZ0P0000060>_jj`030000003ZnNX0j_WZ
00L0j_WZ0P0000020>_ij`030000003XmnP0j?OX00X0j?OX00<000000>Gdi@3Um>D0100000060>Cc
i0030000003Pk^00h>kP00L0h>kP00<000000=cZg03Lj]`0203Lj]`00`000000f>KH0=SVf0080=SV
f0030000003Eh]D0eN;E00L0eN;E00<000000=;OdP3Bgm801`3Bgm800`000000d=c@0=3Ld0020=3L
d0@0000000<0e^CF0000003oool01@3oool00`000000oooo0?ooo`030?ooo`00;`3oool00`000000
oooo0?ooo`0M0?ooo`030000003UlnD0iO?U00L0iO?U0`00000;0>Sgj0030000003Yn>T0jOSY00H0
jOSY0P0000020>_ij`030000003[nN/0joW[00X0joW[00<000000>[ijP3ZnNX00P0000090>_jj`03
0000003ZnNX0j_WZ00<0j_WZ0`0000050>_ij`030000003XmnP0j?OX00T0j?OX0`00000:0>Cci003
0000003Pk^00h>kP00P0h>kP00<000000=cZg03Lj]`0103Lj]`:000000@0f>KH00<000000=GRe@3E
h]D0203Eh]D00`000000d]oB0=;OdP060=;OdP030000003@g=00d=c@00@0d=c@00<000000=3Ld000
00000P0000060?ooo`030000003oool0oooo0080oooo000`0?ooo`030000003oool0oooo01d0oooo
00<000000>Gci@3UlnD00`3UlnD300000080ioKW00<000000>Sgj03XmnP02P3XmnP00`000000jOSY
0>Whj@030>Whj@8000001@3[nN/00`000000joW[0>_ij`090>_ij`<00000303[n^/00`000000j_WZ
0>[ijP02000000T0joW[00<000000>Sgj03XmnP01@3XmnP300000080j?OX00<000000>Cci03Tln@0
2@3Tln@00`000000h>kP0>3^h0040>3^h0X000001@3HiMP00`000000d]oB0=;OdP020=;OdP/00000
103Eh]D00`000000d]oB0=;OdP070=;OdP030000003@g=00d=c@00@0d=c@00@000000=3Ld03@g=00
00001P3oool00`000000oooo0?ooo`020?ooo`00<@3oool00`000000oooo0?ooo`0L0?ooo`030000
003UlnD0iO?U00<000001@3Wm^L00`000000j?OX0>Sgj00;0>Sgj0030000003Yn>T0jOSY00800000
203[nN/00`000000joW[0>_ij`060>_ij`8000000P3/nn`00`000000jo[[0>_jj`0:0>_jj`<00000
303[nN/00`000000j?OX0>Sgj004000000H0j?OX00<000000>Cci03Tln@01`3Tln@8000000D0gN_M
00<000000=SUf03HiMP0203HiMP00`000000d]oB0=;OdP070=;OdP030000003=f/d0cM[=0080cM[=
1`0000070=;OdP030000003@g=00d=c@00@0d=c@00D000000=3Ld03@g=00d=c@000000050?ooo`03
0000003oool0oooo0080oooo000b0?ooo`8000007@3oool2000000T0ioKW00<000000>Sgj03XmnP0
2`3XmnP2000000/0joW[00<000000>_ij`3[nN/00`3[nN/2000000D0k?_/00<000000>_jj`3[n^/0
1`3[n^/200000080k?_/00<000000>_ij`3[nN/02P3[nN/3000000/0j?OX00@000000>Cci03Tln@0
i??T1@0000030>?ah`030000003Mjmd0gN_M00P0gN_M0P0000090=SUf0030000003Bgm80d]oB00H0
d]oB00<000000<gJc@3=f/d0203=f/d5000000@0d]oB00<000000=3Ld03@g=00103@g=0010000000
d=c@0=3Ld00000050?ooo`030000003oool0oooo0080oooo000d0?ooo`030000003oool0oooo01/0
oooo00<000000>Ofi`3Wm^L0203Wm^L00`000000j?OX0>Sgj0080>Sgj080000000<0j_SZ0000003[
nN/02`3[nN/00`000000joW[0>_ij`02000000P0k?_/0P0000050>_jj`8000001@3/nn`00`000000
joW[0>_ij`070>_ij`8000000P3[n^/00`000000j?OX0>Sgj0090>Sgj0@000002@3SlN<2000000X0
gN_M00<000000=SUf03HiMP01`3HiMP00`000000d]oB0=;OdP060=;OdP030000003=f/d0cM[=00L0
cM[=00<000000<WFb@39e/T00P39e/T5000000L0d=c@00@000000=3Ld03@g=000000103oool00`00
0000oooo0?ooo`020?ooo`00=@3oool00`000000oooo0?ooo`0J0?ooo`030000003Wm^L0ioKW00T0
ioKW00<000000>Sgj03XmnP01@3XmnP2000000<0j_SZ00<000000>_ij`3[nN/02`3[nN/2000000`0
k?_/00<000000>_jj`3[n^/00P0000080>ckk0030000003[nN/0joW[00<0joW[0`0000050>_jj`03
0000003XmnP0j?OX00H0j?OX0P0000020>Sgj0030000003SlN<0ho7S00X0ho7S00<000000=g[g@3M
jmd0103MjmdA000000H0d]oB00<000000<gJc@3=f/d01`3=f/d00`000000bMK90<WFb@050<WFb@<0
00001P3@g=000`000000d=c@000000040?ooo`030000003oool0oooo0080oooo000f0?ooo`030000
003oool0oooo01X0oooo00<000000>Ofi`3Wm^L0203Wm^L00`000000j?OX0>Sgj0030>Sgj0800000
1P3Zn>X00`000000joW[0>_ij`080>_ij`80000000<0k?[/0000003/nn`0303/nn`2000000/0k?_/
00<000000>_ij`3[nN/00P0000090>_jj`030000003XmnP0j?OX00<0j?OX0P0000050>Sgj0030000
003SlN<0ho7S00T0ho7S1`00000A0?ooo`D0000000<0d]oB0000003=f/d0203=f/d00`000000bMK9
0<WFb@070<WFb@@000000`3@g=0010000000d=c@0=3Ld00000030?ooo`030000003oool0oooo0080
oooo000g0?ooo`8000006P3oool00`000000ioKW0>Ofi`090>Ofi`030000003XmnP0j?OX00800000
2@3Zn>X00`000000joW[0>_ij`050>_ij`800000103/n^`00`000000k?_/0>ckk0080>ckk0800000
00<0kOc]0000003/nn`02`3/nn`2000000`0jo[[00<000000>Sgj03XmnP00P0000080>Sgj0030000
003SlN<0ho7S00D0ho7S0`00000M0?ooo`D000001`3=f/d00`000000bMK90<WFb@060<WFb@040000
0037dlL0am?70<OCa`<0000000@0d=c@0000003@g=000000103oool00`000000oooo0?ooo`010?oo
o`00>@3oool00`000000oooo0?ooo`0H0?ooo`030000003Wm^L0ioKW00T0ioKW0P00000<0>[hjP03
0000003[nN/0joW[0080joW[0P0000060>cjk0030000003/nn`0k?_/00H0k?_/0P0000040>glk@03
0000003/nn`0k?_/00L0k?_/0P0000000`3]o>d000000>_jj`0;0>_jj`<000002`3XmnP00`000000
ho7S0>?ah`04000002D0oooo1P0000000`3=f/d000000<WFb@080<WFb@0300000037dlL0am?700<0
am?70`0000000`3@g=0000000?ooo`020?ooo`030000003oool0oooo0040oooo000j0?ooo`030000
003oool0oooo01P0oooo00<000000>Ofi`3Wm^L01P3Wm^L2000000030>Wgj@000000j_SZ00/0j_SZ
00<000000>_ij`3[nN/00P0000090>cjk0030000003/nn`0k?_/00<0k?_/0P0000060>glk@030000
003/nn`0k?_/00D0k?_/0P0000040>glk@030000003[n^/0jo[[00L0jo[[0P0000020>cjk0030000
003XmnP0j?OX00T0j?OX0`00000_0?ooo`@000001`39e/T00`000000am?70<OCa`050<OCa`<00000
0`3oool00`000000oooo0?ooo`010?ooo`00>`3oool00`000000oooo0?ooo`0G0?ooo`030000003W
m^L0ioKW00@0ioKW0P0000030>Wgj@030000003Zn>X0j_SZ00/0j_SZ0P00000<0>cjk0030000003/
nn`0k?_/008000002@3]o>d00`000000k?_/0>ckk0020>ckk08000001`3]o>d00`000000jo[[0>_j
j`030>_jj`<000001@3/n^`2000000H0j?OX0`00000f0?ooo`<000001@39e/T00`000000am?70<OC
a`050<OCa`0300000037dlL000000080oooo00<000000?ooo`3oool00@3oool003`0oooo0P00000H
0?ooo`040000003Wm^L0ioKW0>Ofi`8000001P3YmnT00`000000j_SZ0>[hjP080>[hjP80000000<0
jo[[0000003/n^`0303/n^`2000000`0kOc]00@000000>ckk000000000002P3]o>d00`000000jo[[
0>_jj`02000000X0k?[/00<000000>Sgj03XmnP00`00000l0?ooo`<000000`39e/T00`000000am?7
0<OCa`050<OCa`8000000P3oool00`000000oooo0?ooo`010?ooo`00?P3oool00`000000oooo0?oo
o`0E0?ooo`040000003Wm^L00000000000T0jOOY00<000000>[hjP3Zn>X01P3Zn>X00`000000jo[[
0>_jj`020>_jj`030000003/n^`0k?[/00P0k?[/0P0000000`3]o>d000000>glk@0<0>glk@030000
003]o>d0kOc]00/0kOc]0P00000<0>cjk0<00000@P3oool4000000P0am?70P0000000`3oool00000
0?ooo`020?ooo`00?`3oool00`000000oooo0?ooo`0E0?ooo`030000003YmnT0jOOY00X0jOOY00<0
00000>[hjP3Zn>X00`3Zn>X2000000H0jo[[00<000000>cjk03/n^`01P3/n^`00`000000kOc]0>gl
k@020>glk@030000003]o>d0kOc]00P0kOc]0P0000000`3^oNh000000>glk@090>glk@80000000<0
k_c^0000003/n^`02@3/n^`2000004P0oooo0`0000060<OCa`80000000<0oooo0000003oool00P3o
ool00400oooo00<000000?ooo`3oool05@3oool00`000000jOOY0>Wgj@090>Wgj@030000003Zn>X0
j_SZ0080j_SZ00<000000>_jj`3[n^/01P3[n^/00`000000k?[/0>cjk0040>cjk08000001P3]o>d0
0`000000kOc]0>glk@050>glk@800000103^oNh00`000000kOc]0>glk@050>glk@800000103^o>h2
000000D0k?[/0`00001=0?ooo`8000001@37dlL3000000<0oooo00110?ooo`8000005@3oool00`00
0000jOOY0>Wgj@0:0>Wgj@040000003Zn>X00000000000X0jo[[00<000000>cjk03/n^`00P3/n^`0
0`000000kOc]0>glk@070>glk@030000003]o>d0kOc]0080kOc]0P0000070>kmkP030000003]o>d0
kOc]0080kOc]0P0000080>klkP030000003/n^`0k?[/00800000DP3oool2000000@0am?700<00000
0?ooo`0000000P3oool004<0oooo00<000000?ooo`3oool04`3oool00`000000jOOY0>Wgj@0:0>Wg
j@030000003[n^/0jo[[00/0jo[[00@000000>cjk000000000002`3]o>d010000000kOc]00000000
000:0>kmkP040000003]o>d00000000000/0k_c^0P00001F0?ooo`<000000P37dlL200000080oooo
00140?ooo`030000003oool0oooo01<0oooo00<000000>Wgj@3YmnT01`3YmnT2000000030>[ijP00
0000jo[[00`0jo[[00<000000>glk@3]o>d0303]o>d00`000000k_g^0>kmkP0;0>kmkP030000003^
o>h0k_c^00T0k_c^0P00001K0?ooo`@000000P3oool004D0oooo00<000000?ooo`3oool04P3oool0
0`000000jOOY0>Wgj@060>Wgj@050000003ZnNX0j_WZ0>[ijP0000002`3[n^/2000000030>ckk000
0000kOc]00X0kOc]0P0000000`3^o>h000000>kmkP090>kmkP80000000<0kog_0000003^o>h0203^
o>h00`000000oooo0?ooo`1M0?ooo`8000000P3oool004H0oooo0P00000C0?ooo`030000003YmnT0
jOOY00<0jOOY0P0000050>[ijP030000003[n^/0jo[[00H0jo[[0P0000030>ckk0030000003]o>d0
kOc]00P0kOc]00<000000>klkP3^o>h00P3^o>h00`000000k_g^0>kmkP060>kmkP030000003_oNl0
kog_0080kog_00<000000>klkP3^o>h0103^o>h2000005`0oooo100000040?ooo`00B03oool00`00
0000oooo0?ooo`0A0?ooo`050000003YmnT0jOOY0>Wgj@000000203ZnNX00`000000jo[[0>_jj`04
0>_jj`030000003/nn`0k?_/00@0k?_/00<000000>glk@3]o>d01P3]o>d00`000000k_c^0>klkP03
0>klkP030000003^oNh0k_g^00@0k_g^0P0000060>omk`030000003^o>h0k_c^0080k_c^00<00000
0?ooo`3oool0F03oool4000000P0oooo00190?ooo`030000003oool0oooo0100oooo00@000000>Wg
j@00000000002P3ZnNX010000000jo[[0>_jj`3[n^/2000000P0k?_/00<000000>glk@3]o>d00`3]
o>d2000000L0k_c^00<000000>kmkP3^oNh00P3^oNh00`000000kog_0>omk`070>omk`040000003^
o>h00000000005L0oooo1000000<0?ooo`00BP3oool00`000000oooo0?ooo`0@0?ooo`030000003Z
nNX0j_WZ00X0j_WZ00@000000>_jj`00000000002`3/nn`01@000000kOc]0>glk@3]o>d0000000X0
k_c^00@000000>kmkP00000000002`3_oNl00`000000oooo0?ooo`1C0?ooo`@00000403oool004/0
oooo0P00000A0?ooo`030000003ZnNX0j_WZ00X0j_WZ00<000000>ckk03/nn`02`3/nn`010000000
kOc]00000000000<0>klkP030000003_oNl0kog_00T0kog_0P00001B0?ooo`@00000503oool004d0
oooo00<000000?ooo`3oool03P3oool00`000000j_WZ0>[ijP090>[ijP030000003[n^/0000000d0
k?_/00<000000>klkP3^o>h02P3^o>h2000000030>kmkP000000kog_00P0kog_00<000000?ooo`3o
ool0CP3oool4000001P0oooo001>0?ooo`030000003oool0oooo00h0oooo00<000000>[ijP3ZnNX0
1P3ZnNX200000080jo[[00<000000>ckk03/nn`02P3/nn`00`000000kOc]0000000:0>klkP030000
003^oNh0k_g^0080k_g^00<000000>omk`3_oNl0103_oNl2000004d0oooo1000000L0?ooo`00C`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003ZnNX0j_WZ00D0j_WZ00<000000>_jj`3[n^/00`3[
n^/00`000000k?_/0>ckk0070>ckk08000000`3]o>d00`000000k_c^0>klkP060>klkP030000003^
oNh0k_g^00@0k_g^00<000000>omk`3_oNl00P3_oNl00`000000oooo0?ooo`190?ooo`@00000803o
ool00500oooo0P00000>0?ooo`030000003ZnNX0j_WZ00<0j_WZ00<000000>_jj`3[n^/01@3[n^/0
0`000000k?_/0>ckk0050>ckk0030000003]o>d0kOc]00<0kOc]00<000000>klkP3^o>h0103^o>h2
000000P0k_g^00@000000>omk`0000000000B@3oool3000002@0oooo001B0?ooo`030000003oool0
oooo00`0oooo00<000000>[ijP3ZnNX00P0000090>_jj`030000003/nn`0k?_/00<0k?_/00<00000
0>glk@3]o>d01@3]o>d00`000000k_c^0>klkP020>klkP030000003^oNh0k_g^00T0k_g^00<00000
0?ooo`3oool0A@3oool4000002L0oooo001C0?ooo`030000003oool0oooo00/0oooo00<000000>[i
jP0000002`3[n^/010000000k?_/0>ckk03/nn`2000000T0kOc]00@000000>klkP00000000002`3^
oNh00`000000oooo0?ooo`120?ooo`@00000:`3oool005@0oooo00<000000?ooo`3oool02`3oool0
0`000000jo[[0>_jj`0;0>_jj`030000003/nn`0000000`0kOc]00<000000>kmkP3^oNh02P3^oNh0
0`000000oooo0?ooo`0o0?ooo`@00000;`3oool005D0oooo0P00000<0?ooo`030000003[n^/0jo[[
00/0jo[[00<000000>glk@3]o>d02P3]o>d00`000000k_c^0000000:0>kmkP030000003oool0oooo
03`0oooo1000000c0?ooo`00E`3oool00`000000oooo0?ooo`090?ooo`030000003[n^/0jo[[00X0
jo[[00<000000>cjk00000002P3]o>d01@000000k_c^0>klkP3^o>h0000000L0k_g^0P00000k0?oo
o`@00000=`3oool005P0oooo00<000000?ooo`3oool02@3oool00`000000jo[[0>_jj`080>_jj`04
0000003/n^`0k?[/000000T0kOc]00<000000>klkP3^o>h00`3^o>h00`000000k_g^0>kmkP030>km
kP030000003oool0oooo03L0oooo1000000k0?ooo`00F@3oool00`000000oooo0?ooo`090?ooo`03
0000003[n^/0jo[[00H0jo[[00<000000>cjk03/n^`00P3/n^`00`000000kOc]0>glk@040>glk@80
00001`3^o>h01@000000k_g^0>kmkP3^oNh0000003H0oooo1000000o0?ooo`00FP3oool00`000000
oooo0?ooo`080?ooo`030000003[n^/0jo[[00@0jo[[0P0000060>cjk0030000003]o>d0kOc]0080
kOc]00<000000>klkP3^o>h0203^o>h00`000000k_g^0000000c0?ooo`@00000@`3oool005/0oooo
0P0000090?ooo`030000003[n^/0jo[[0080jo[[00<000000>cjk03/n^`01`3/n^`010000000kOc]
0>glk@00000<0>klkP030000003oool0oooo02l0oooo0`0000170?ooo`00G@3oool00`000000oooo
0?ooo`070?ooo`040000003[n^/0jo[[000000X0k?[/00<000000>glk@000000303^o>h00`000000
oooo0?ooo`0/0?ooo`@00000BP3oool005h0oooo00<000000?ooo`3oool01P3oool00`000000jo[[
0000000<0>cjk0030000003^o>h0k_c^00T0k_c^0P00000[0?ooo`@00000CP3oool005l0oooo00<0
00000?ooo`3oool01P3oool00`000000k?[/0>cjk00:0>cjk0030000003/nn`0000000T0k_c^00<0
00000?ooo`3oool09`3oool400000580oooo001P0?ooo`8000001`3oool00`000000k?[/0>cjk008
0>cjk0050000003/nn`0k?_/0>ckk00000001`3^o>h00`000000oooo0?ooo`0T0?ooo`@00000EP3o
ool00680oooo00<000000?ooo`3oool0103oool00`000000k?[/0>cjk0070>cjk0030000003/nn`0
k?_/0080k?_/00<000000>klkP3^o>h0103^o>h00`000000oooo0?ooo`0Q0?ooo`@00000FP3oool0
06<0oooo00<000000?ooo`3oool0103oool00`000000k?[/0>cjk0050>cjk0030000003/nn`0k?_/
00@0k?_/00@000000>klkP3^o>h0k_c^0P00000P0?ooo`@00000GP3oool006@0oooo00<000000?oo
o`3oool00`3oool00`000000k?[/0>cjk0040>cjk0030000003/nn`0k?_/00H0k?_/00<000000>kl
kP0000007P3oool400000680oooo001U0?ooo`800000103oool00`000000k?[/0>cjk0020>cjk003
0000003/nn`0k?_/00P0k?_/00<000000?ooo`3oool06@3oool4000006H0oooo001W0?ooo`030000
003oool0oooo0080oooo00@000000>cjk03/n^`000002P3/nn`00`000000oooo0?ooo`0G0?ooo`<0
0000JP3oool006P0oooo00L000000?ooo`3oool0oooo0000003/n^`0000000X0k?_/00<000000?oo
o`3oool0503oool4000006d0oooo001Y0?ooo`050000003oool0oooo0?ooo`0000002P3/nn`00`00
0000oooo0?ooo`0A0?ooo`@00000L@3oool006X0oooo0P0000020?ooo`030000003/nn`0k?_/00H0
k?_/00<000000?ooo`3oool03P3oool4000007D0oooo001/0?ooo`030000003oool0000000L0k?_/
00<000000?ooo`3oool02`3oool4000007T0oooo001]0?ooo`030000003oool0000000H0k?_/00<0
00000?ooo`3oool01`3oool4000007d0oooo001^0?ooo`030000003oool0000000@0k?_/00<00000
0?ooo`3oool0103oool400000840oooo001_0?ooo`<000000P3/nn`010000000oooo0?ooo`3oool4
000008D0oooo001a0?ooo`030000003/nn`0000000@00000R@3oool00780oooo0P00002=0?ooo`00
o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00
o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00o`3oool20?ooo`00\
\>"],
    ImageRangeCache->{{{0, 256}, {213.813, 0}} -> {0, 0, 0, 0}}],
  "  ",
  StyleBox["\n\tFigure 3.2",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"u", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        "=", \(x\^3 - 3\ x\ y\^2\)}]]],
  ".  \t\t\t",
  StyleBox["Figure 3.3",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"v", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        "=", \(3\ x\^2\ y - y\^3\)}]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe can use complex analysis to show easily that certain combinations of \
harmonic functions are harmonic.  For example, if ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " is a harmonic conjugate of ",
  StyleBox["u",
    FontFamily->"Courier New"],
  ", then their product  ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\  = u \((x, y)\) v \((x, y)\)\)]],
  " is a harmonic function. This can be verified directly by computing the \
partial derivatives and showing that Laplace's equation ",
  StyleBox["(3-26)",
    FontColor->RGBColor[0, 0, 1]],
  " holds, but the details are tedious.  If we use complex variable \
techniques instead, we can start with the fact that ",
  Cell[BoxData[
      \(f \((z)\) = u \((x, y)\) + \[ImaginaryI]\ v \((x, y)\)\)]],
  " is an analytic function.  Then we observe that the square of ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is also an analytic function, which is\n\n\t\t",
  Cell[BoxData[
      \(\([f \((z)\)]\)\^2 = \([u \((x, y)\)]\)\^2 - \([v \((x, y)\)]\)\^2 + \
\[ImaginaryI]\ 2\ u \((x, y)\) v \((x, y)\)\)]],
  ".  \n\n\tWe then know immediately that the imaginary part,  ",
  Cell[BoxData[
      \(2\ u \((x, y)\) v \((x, y)\)\)]],
  ",   is a harmonic function by Theorem 3.8.   Since a constant multiple of \
a harmonic function is harmonic, it follows that ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\  = u \((x, y)\) v \((x, y)\)\)]],
  " is harmonic.  It is left as an exercise to show that if ",
  Cell[BoxData[
      \(\(u\_1\) \((x, y)\)\)]],
  " and ",
  Cell[BoxData[
      \(\(u\_2\) \((x, y)\)\)]],
  " are two harmonic functions that are ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " related in the preceding fashion, then their product need ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " be harmonic. "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 3.9 (Construction of a Conjugate).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(u \((x, y)\)\)]],
  "  be harmonic in an ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  "-neighborhood of the point ",
  Cell[BoxData[
      \(\((x\_0, y\_0)\)\)]],
  ".  Then there exists a conjugate harmonic function  ",
  Cell[BoxData[
      \(v \((x, y)\)\)]],
  "  defined in this neighborhood such that  ",
  Cell[BoxData[
      \(f \((z)\) = u \((x, y)\) + i\ v \((x, y)\)\)]],
  " is an analytic function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Proof.  A conjugate harmonic function ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " will satisfy the Cauchy-Riemann equations ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_x\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        RowBox[{\(v\_y\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_y\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        RowBox[{\(-v\_x\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  ".  Assuming that such a function exists, we determine what it would have \
to look like by using a two-step process.  First, we integrate ",
  Cell[BoxData[
      RowBox[{\(v\_y\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " (which should equal ",
  Cell[BoxData[
      RowBox[{\(u\_x\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ") with respect to y and get \n\n",
  StyleBox["(3-27)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"v", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", "  ", 
          RowBox[{
            RowBox[{"\[Integral]", " ", 
              RowBox[{\(v\_y\), 
                RowBox[{"(", 
                  RowBox[{"x", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "y"}], 
                  ")"}], \(\[DifferentialD]y\)}]}], " ", "+", 
            " ", \(C \((x)\)\)}]}], " ", "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{"v", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", "  ", 
        RowBox[{
          RowBox[{"\[Integral]", " ", 
            RowBox[{\(u\_x\), 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], 
                ")"}], \(\[DifferentialD]y\)}]}], " ", "+", 
          " ", \(C \((x)\)\)}]}]}]],
  " \n\nwhere ",
  Cell[BoxData[
      \(C \((x)\)\)]],
  " is a function of ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " alone that is yet to be determined.  Second, we compute ",
  Cell[BoxData[
      \(C' \((x)\)\)]],
  " by differentiating both sides of this equation with respect to ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " and replacing  ",
  Cell[BoxData[
      RowBox[{\(v\_x\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  with  ",
  Cell[BoxData[
      RowBox[{\(-u\_y\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  on the left side, which gives  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{"    ", 
        RowBox[{
          RowBox[{\(v\_x\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", " ", 
          RowBox[{
            RowBox[{\(d\/dx\), " ", 
              RowBox[{"\[Integral]", " ", 
                RowBox[{\(u\_x\), 
                  RowBox[{"(", 
                    RowBox[{"x", 
                      StyleBox[",",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], "y"}], 
                    ")"}], \(\[DifferentialD]y\)}]}]}], " ", "+", 
            " ", \(C' \((x)\)\)}]}], "\[IndentingNewLine]"}], "\n", 
      RowBox[{
        RowBox[{\(-\ u\_y\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", " ", 
        RowBox[{
          RowBox[{\(d\/dx\), " ", 
            RowBox[{"\[Integral]", " ", 
              RowBox[{\(u\_x\), 
                RowBox[{"(", 
                  RowBox[{"x", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "y"}], 
                  ")"}], \(\[DifferentialD]y\)}]}]}], " ", "+", 
          " ", \(C' \((x)\)\)}]}]}]],
  "\n\nIt can be shown (we omit the details) that because u is harmonic, all \
terms except those involving x in the last equation will cancel, revealing a \
formula for ",
  Cell[BoxData[
      \(C' \((x)\)\)]],
  " involving ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " alone.  Elementary integration of the single-variable function ",
  Cell[BoxData[
      \(C' \((x)\)\)]],
  " can then be used to discover ",
  Cell[BoxData[
      \(C \((x)\)\)]],
  " .  We finally observe that the function ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " so created indeed has the properties we seek."
}], "Text"],

Cell[TextData[{
  "\tThe functions  ",
  Cell[BoxData[
      \(C \((x)\)\)]],
  " and ",
  Cell[BoxData[
      RowBox[{"v", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " are computed with the formulas:\n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(C \((x)\)\), " ", "=", " ", 
        RowBox[{"\[Integral]", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(-\ u\_y\), 
                  RowBox[{"(", 
                    RowBox[{"x", 
                      StyleBox[",",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], "y"}], ")"}]}], " ", "-", 
                " ", 
                RowBox[{\(d\/dx\), 
                  RowBox[{"(", 
                    RowBox[{"\[Integral]", " ", 
                      RowBox[{\(u\_x\), 
                        RowBox[{"(", 
                          RowBox[{"x", 
                            StyleBox[",",
                              FontFamily->"Times New Roman",
                              FontSize->12,
                              FontWeight->"Plain",
                              FontSlant->"Plain",
                              FontColor->GrayLevel[0],
                              FontVariations->{"Underline"->False,
                              "StrikeThrough"->False}], "y"}], 
                          ")"}], \(\[DifferentialD]y\)}]}], ")"}]}]}], 
              ")"}], \(\[DifferentialD]x\)}]}]}]]],
  ",   and     \n\t\t\t\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"v", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", "  ", 
        RowBox[{
          RowBox[{"\[Integral]", " ", 
            RowBox[{\(u\_x\), 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], 
                ")"}], \(\[DifferentialD]y\)}]}], " ", "+", 
          " ", \(C \((x)\)\)}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.9 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\<\
\tTechnically we should always specify the domain of function when defining \
it.  When no such specification is given, it is assumed that the domain is \
the entire complex plane, or the largest set for which the expression \
defining the function makes sense.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Method.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->18,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Construction of the Harmonic Conjugate of u(x,y).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Execute this cell to activate the",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["construction of the harmonic conjugate subroutine.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(u = \(v = \(x = \(y = 0\)\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[con, lap, u, v, v1, v2, v3, x, y];\)\ \), "\n", 
    \(\(con[u0_]\  := \ 
        Module[{}, \[IndentingNewLine]lap\  = \ 
            Simplify[\[PartialD]\_\(x, x\)u[x, 
                    y]\  + \ \[PartialD]\_\(y, y\)u[x, 
                    y]]; \ \[IndentingNewLine]If[lap =!= 0, 
            Print["\<u[x,y] was NOT harmonic\>"]; \ \
\[IndentingNewLine]Print["\<u(x,y) = \>", 
              u[x, y]]; \ \[IndentingNewLine]Print[\*"\"\<\!\(u\_xx\) + \!\(u\
\_yy\) = \>\""]; \ \ \[IndentingNewLine]Return[
              Print[Expand[
                  lap]]]]; \ \[IndentingNewLine]v1\  = \[Integral]\[PartialD]\
\_x\ u[x, 
                    y] \[DifferentialD]y; \ \[IndentingNewLine]v2\  = \ \(-\ \
\[PartialD]\_y\ u[x, y]\)\  - \ \[PartialD]\_x\ 
                v1; \ \[IndentingNewLine]v3\  = \[Integral]v2 \
\[DifferentialD]x; \ \[IndentingNewLine]Return[
            v1\  + \ v3];\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.13.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(u \((x, y)\) = x\ y\^3 - x\^3\ y\)]],
  "  is a harmonic function and find the harmonic conjugate  ",
  Cell[BoxData[
      \(v \((x, y)\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We follow the construction process of Theorem 3.9.  The first \
partial derivatives are\n\n",
  StyleBox["(3-28)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_x\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        "=", \(y\^3 - 3\ x\^2\ y\)}]]],
  "   and   ",
  Cell[BoxData[
      \(\(u\_y\) \((x, y)\) = 3\ x\ y\^2 - x\^3\)]],
  ".  \n\nTo verify that ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " is harmonic, we compute the second partial derivatives and note that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(u\_xx\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "+", 
          RowBox[{\(u\_yy\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}], " ", "=", 
        " ", \(\(-6\)\ x\ y + 6\ x\ y\  = \ 0\)}]]],
  ",  so ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " satisfies Laplace's Equation ",
  StyleBox["(3-26)",
    FontColor->RGBColor[0, 0, 1]],
  ".  To construct ",
  StyleBox["v",
    FontFamily->"Courier New"],
  ", we start with Equation ",
  StyleBox["(3-27)",
    FontColor->RGBColor[0, 0, 1]],
  " and the first of Equations ",
  StyleBox["(3-28)",
    FontColor->RGBColor[0, 0, 1]],
  " to get  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"v", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
          "  ", \(\[Integral]\ \((y\^3 - 
                    3\ x\^2\ y)\) \[DifferentialD]y\  + \ C \((x)\)\)}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "                  ", \(\(=\)\(\ \ \)\(\(1\/4\) y\^4 - \(3\/2\) 
              x\^2\ y\^2 + \ C \((x)\)\)\)}]}]]
}], "Text"],

Cell[TextData[{
  "Differentiating the left and right sides of this equation with respect to \
x and using  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(-u\_y\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        RowBox[{\(v\_x\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  "  and Equations ",
  StyleBox["(3-28)",
    FontColor->RGBColor[0, 0, 1]],
  " on the left side yields\n\n\t\t\t",
  Cell[BoxData[
      \(\(-\ 3\)\ x\ y\^2 + x\^3\  = \ 
        0\  - \ 3  x\ y\^2\  + \ \ C' \((x)\)\)]],
  "\n\nwhich implies that\n\n\t\t\t",
  Cell[BoxData[
      \(C' \((x)\)\ \  = \ \ x\^3\)]],
  ",  \n\nthen an easy integration yields  ",
  Cell[BoxData[
      \(C \((x)\)\ \  = \ \ \(1\/4\) x\^4 + C\)]],
  ",  where C is a constant.  Now we substitute ",
  Cell[BoxData[
      \(C \((x)\)\)]],
  " and obtain the desired solution \n\n\t\t\t",
  Cell[BoxData[
      \(v \((x, y)\)\ \  = \ \ \(1\/4\) x\^4 + \ \(1\/4\) y\^4 - \(3\/2\) 
            x\^2\ y\^2 + \ C\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 3.13.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the function u[x,y], do a step by step construction.", "Text"],

Cell[BoxData[{
    \(\(u[x_, y_]\  = \ x\ y\^3\  - \ x\^3\ y;\)\ \), "\[IndentingNewLine]", 
    \(\(c[
          x_] = \[Integral]\((\(-\ \[PartialD]\_y\ 
                    u[x, y]\)\  - \ \[PartialD]\_x\ \ \((\[Integral]\
\[PartialD]\_x\ u[x, 
                            y] \[DifferentialD]y)\))\) \
\[DifferentialD]x;\)\), "\[IndentingNewLine]", 
    \(\(v[x_, 
          y_]\  = \ \[Integral]\[PartialD]\_x u[x, y] \[DifferentialD]y\  + \ 
          c[x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< u[x,y] = \>", u[x, y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(u\_x\)[x,y] = \>\"", \[PartialD]\_x u[x, 
            y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(u\_y\)[x,y] = \>\"", \[PartialD]\_y u[x, 
            y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Construct the function c[x]\>"];\)\), "\[IndentingNewLine]", \

    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<c[x] = \[Integral](- \!\(\[PartialD]\_y\)u[x,y] - \!\(\
\[PartialD]\_x\)(\[Integral]\!\(\[PartialD]\_x\) u[x,y]\[DifferentialD]y))\
\[DifferentialD]x\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<c[x] = \[Integral](- \!\(\[PartialD]\_y\)(\>\"", 
        u[x, y], \*"\"\<) - \
\!\(\[PartialD]\_x\)(\[Integral]\!\(\[PartialD]\_x\)(\>\"", 
        u[x, y], "\<)\[DifferentialD]y))\[DifferentialD]x\>"\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<c[x] = \[Integral](- (\>", \[PartialD]\_y u[x, 
            y], \*"\"\<) - \!\(\[PartialD]\_x\)(\>\"", \[Integral]\((\
\[PartialD]\_x u[x, 
                  y])\) \[DifferentialD]y, "\<))\[DifferentialD]x\>"\ ];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<c[x] = \[Integral](\>", \(-\ \[PartialD]\_y u[x, 
              y]\), "\< - (\>", \
\[PartialD]\_x\((\[Integral]\[PartialD]\_x\((u[x, 
                      y])\) \[DifferentialD]y)\)\ , "\<))\[DifferentialD]x\>"\
\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<c[x] = \[Integral](\>", \(-\ \[PartialD]\_y u[x, 
                y]\)\  - \ \[PartialD]\_x\((\[Integral]\[PartialD]\_x\ 
                    u[x, 
                      y] \[DifferentialD]y)\), "\<)\[DifferentialD]x\>"\ ];\)\
\), "\[IndentingNewLine]", 
    \(\(Print["\<c[x] = \>", \[Integral]\((\(-\ \[PartialD]\_y u[x, 
                      y]\)\  - \ \[PartialD]\_x\((\[Integral]\[PartialD]\_x\ 
                          u[x, y] \[DifferentialD]y)\))\) \[DifferentialD]x\ \
];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Now construct v[x,y]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<v[x,y] = \[Integral]\!\(\[PartialD]\_y\)v[x,y]\
\[DifferentialD]y + c[x]\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<v[x,y] = \[Integral]\!\(\[PartialD]\_x\)u[x,y]\
\[DifferentialD]y + c[x]\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<v[x,y] = \[Integral]\!\(\[PartialD]\_x\)(\>\"", 
        u[x, y], "\<)\[DifferentialD]y + (\>", 
        c[x], "\<)\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \[Integral](\>", \[PartialD]\_x u[x, 
            y], "\<)\[DifferentialD]y + (\>", 
        c[x], "\<)\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = (\>", \[Integral]\[PartialD]\_x u[x, 
                y] \[DifferentialD]y, "\<) + (\>", 
        c[x], "\<)\>", "\<+ C\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", \[Integral]\[PartialD]\_x u[x, 
                  y] \[DifferentialD]y\  + \ 
          c[x], "\<+ C\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(gr1 = 
        ContourPlot[u[x, y], {x, \(-2.5\), 2.5}, {y, \(-2.5\), 2.5}, 
          PlotPoints \[Rule] 35, 
          Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0, 2, 1]}, 
          AspectRatio \[Rule] 1, 
          ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<u[x,y] = \>", 
        u[x, y], "\< = C\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(gr2 = 
        ContourPlot[v[x, y], {x, \(-2.5\), 2.5}, {y, \(-2.5\), 2.5}, 
          PlotPoints \[Rule] 35, 
          Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0, 2, 1]}, 
          AspectRatio \[Rule] 1, 
          ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<v[x,y] = \>", v[x, y], "\< = C\>"];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(gr3 = 
        ContourPlot[u[x, y], {x, \(-2.5\), 2.5}, {y, \(-2.5\), 2.5}, 
          PlotPoints \[Rule] 35, ContourShading \[Rule] False, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr4 = 
        ContourPlot[v[x, y], {x, \(-2.5\), 2.5}, {y, \(-2.5\), 2.5}, 
          PlotPoints \[Rule] 35, ContourShading \[Rule] False, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr4, Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0, 2, 1]}, 
        AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        u[x, y], "\< = C,  and\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", v[x, y], "\< = C\>"];\)\ \)}], "Input"],

Cell[TextData[{
  "We are done!\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can also construct v[x,y] by the following alternative method."
}], "Text"],

Cell["\<\
Enter the function u[x,y], and determine if it is a harmonic function.  If \
so, proceed with the construction of the harmonic conjugate v[x,y].\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[f, F, u, v, x, y];\)\ \), "\[IndentingNewLine]", 
    \(\(u[x_, y_]\  = \ x\ y\^3\  - \ x\^3\ y;\)\ \), "\n", 
    \(\(v[x_, y_]\  = \ con[u[x, y]];\)\ \), "\n", 
    \(\(Print["\<u(x,y) = \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Using the subroutine to construct\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<the harmonic conjugate we get:\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<v(x,y) = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Form the analytic function  f[z] = u[x,y]+ i v[x,y]  and verify that the \
Cauchy-Riemann equations hold.\
\>", "Text"],

Cell[BoxData[{
    \(\(Ux\  = \ \[PartialD]\_x\ u[x, y];\)\ \), "\n", 
    \(\(Uy\  = \ \[PartialD]\_y\ u[x, y];\)\ \), "\n", 
    \(\(Vx\  = \ \[PartialD]\_x\ v[x, y];\)\ \), "\n", 
    \(\(Vy\  = \ \[PartialD]\_y\ v[x, y];\)\ \), "\[IndentingNewLine]", 
    \(\(f[x_, y_] = u[x, y]\  + \ \[ImaginaryI]\ v[x, y];\)\ \), "\n", 
    \(\(Print["\<   f[z] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< u[x,y] = \>", u[x, y]];\)\ \), "\n", 
    \(\(Print["\< v[x,y] = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_x\)[x,y] = \>\"", Ux];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_y\)[x,y] = \>\"", Uy];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_x\)[x,y] = \>\"", Vx];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_y\)[x,y] = \>\"", 
        Vy];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_x\)[x,y] =  \!\(v\_y\)[x,y] ?      \>\"", 
        Ux \[Equal] Vy];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_y\)[x,y] = -\!\(v\_x\)[x,y] ?      \>\"", 
        Uy \[Equal] \(-Vx\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Therefore  ",
  Cell[BoxData[
      \(v[x, y] = x\^4\/4 - \(3\ x\^2\ y\^2\)\/2 + y\^4\/4\)]],
  " is the harmonic conjugate of  ",
  Cell[BoxData[
      \(u[x, y] = \(-x\^3\)\ y + x\ y\^3\)]],
  ".  \n",
  StyleBox["\nAside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to get the standard form of an analytic function.  "
}], "Text"],

Cell[BoxData[{
    \(\(F[z_] = 
        ReplaceAll[
          f[x, y], {x \[Rule] \(z + Conjugate[z]\)\/2, 
            y \[Rule] \(z - Conjugate[z]\)\/\(2  \[ImaginaryI]\)}];\)\ \), "\
\[IndentingNewLine]", 
    \(\(F[z_] = ComplexExpand[F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(W = 
        ReplaceAll[
          f[x, y], {x \[Rule] \(z + \(\(z\)\(\ \)\)\&_\)\/2, 
            y \[Rule] \(z - \(\(z\)\(\ \)\)\&_\)\/\(2  \[ImaginaryI]\)}];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", W];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tContour plots for the families of curves  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(u \((x, y)\)\), "=", 
          RowBox[{"C", ":", " ", 
            RowBox[{
              StyleBox["C",
                FontSize->14], "  ", 
              StyleBox["is",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["a",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["real",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["constant",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}], "}"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(v \((x, y)\)\), "=", 
          RowBox[{
            StyleBox["C",
              FontSize->14], ":", " ", 
            RowBox[{
              StyleBox["C",
                FontSize->14], "  ", 
              StyleBox["is",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["a",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["real",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["constant",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}], "}"}]]],
  "  are shown in Figures 3.B.  "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.192308 0.5 0.192308 [
[.11538 -0.0125 -6 -9 ]
[.11538 -0.0125 6 0 ]
[.30769 -0.0125 -6 -9 ]
[.30769 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -3 -9 ]
[.69231 -0.0125 3 0 ]
[.88462 -0.0125 -3 -9 ]
[.88462 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11538 -12 -4.5 ]
[-0.0125 .11538 0 4.5 ]
[-0.0125 .30769 -12 -4.5 ]
[-0.0125 .30769 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .69231 -6 -4.5 ]
[-0.0125 .69231 0 4.5 ]
[-0.0125 .88462 -6 -4.5 ]
[-0.0125 .88462 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-2)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-1)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(1)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(2)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11538 m
.00625 .11538 L
s
[(-2)] -0.0125 .11538 1 0 Mshowa
0 .30769 m
.00625 .30769 L
s
[(-1)] -0.0125 .30769 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .69231 m
.00625 .69231 L
s
[(1)] -0.0125 .69231 1 0 Mshowa
0 .88462 m
.00625 .88462 L
s
[(2)] -0.0125 .88462 1 0 Mshowa
.125 Mabswid
0 .15385 m
.00375 .15385 L
s
0 .19231 m
.00375 .19231 L
s
0 .23077 m
.00375 .23077 L
s
0 .26923 m
.00375 .26923 L
s
0 .34615 m
.00375 .34615 L
s
0 .38462 m
.00375 .38462 L
s
0 .42308 m
.00375 .42308 L
s
0 .46154 m
.00375 .46154 L
s
0 .53846 m
.00375 .53846 L
s
0 .57692 m
.00375 .57692 L
s
0 .61538 m
.00375 .61538 L
s
0 .65385 m
.00375 .65385 L
s
0 .73077 m
.00375 .73077 L
s
0 .76923 m
.00375 .76923 L
s
0 .80769 m
.00375 .80769 L
s
0 .84615 m
.00375 .84615 L
s
0 .07692 m
.00375 .07692 L
s
0 .03846 m
.00375 .03846 L
s
0 .92308 m
.00375 .92308 L
s
0 .96154 m
.00375 .96154 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11538 m
1 .11538 L
s
.99375 .30769 m
1 .30769 L
s
.99375 .5 m
1 .5 L
s
.99375 .69231 m
1 .69231 L
s
.99375 .88462 m
1 .88462 L
s
.125 Mabswid
.99625 .15385 m
1 .15385 L
s
.99625 .19231 m
1 .19231 L
s
.99625 .23077 m
1 .23077 L
s
.99625 .26923 m
1 .26923 L
s
.99625 .34615 m
1 .34615 L
s
.99625 .38462 m
1 .38462 L
s
.99625 .42308 m
1 .42308 L
s
.99625 .46154 m
1 .46154 L
s
.99625 .53846 m
1 .53846 L
s
.99625 .57692 m
1 .57692 L
s
.99625 .61538 m
1 .61538 L
s
.99625 .65385 m
1 .65385 L
s
.99625 .73077 m
1 .73077 L
s
.99625 .76923 m
1 .76923 L
s
.99625 .80769 m
1 .80769 L
s
.99625 .84615 m
1 .84615 L
s
.99625 .07692 m
1 .07692 L
s
.99625 .03846 m
1 .03846 L
s
.99625 .92308 m
1 .92308 L
s
.99625 .96154 m
1 .96154 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 1 1 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
0 1 .879 r
.01923 .49923 m
.04751 .49908 L
.07579 .49888 L
.10407 .49862 L
.13235 .49828 L
.16063 .49781 L
.18891 .49716 L
.21719 .49623 L
.24548 .49482 L
.27376 .49263 L
.30204 .489 L
.33032 .48243 L
.3534 .47172 L
.3586 .47064 L
.37525 .44344 L
.37516 .41516 L
.36298 .38688 L
.3586 .37724 L
.34431 .3586 L
.33032 .3377 L
.32167 .33032 L
.30204 .30697 L
.29651 .30204 L
.27376 .27719 L
.27004 .27376 L
.24548 .24795 L
.24286 .24548 L
.21719 .21902 L
.21529 .21719 L
.18891 .1903 L
.18748 .18891 L
.16063 .16171 L
.15953 .16063 L
.13235 .1332 L
.13149 .13235 L
.10407 .10475 L
.10338 .10407 L
.07579 .07635 L
.07523 .07579 L
.04751 .04797 L
.04705 .04751 L
.01923 .01963 L
F
0 g
.01923 .49923 m
.04751 .49908 L
.07579 .49888 L
.10407 .49862 L
.13235 .49828 L
.16063 .49781 L
.18891 .49716 L
.21719 .49623 L
.24548 .49482 L
.27376 .49263 L
.30204 .489 L
.33032 .48243 L
.3534 .47172 L
.3586 .47064 L
.37525 .44344 L
.37516 .41516 L
.36298 .38688 L
.3586 .37724 L
.34431 .3586 L
.33032 .3377 L
.32167 .33032 L
.30204 .30697 L
.29651 .30204 L
.27376 .27719 L
.27004 .27376 L
.24548 .24795 L
.24286 .24548 L
.21719 .21902 L
.21529 .21719 L
.18891 .1903 L
.18748 .18891 L
.16063 .16171 L
.15953 .16063 L
.13235 .1332 L
.13149 .13235 L
.10407 .10475 L
.10338 .10407 L
.07579 .07635 L
.07523 .07579 L
.04751 .04797 L
.04705 .04751 L
.01923 .01963 L
s
0 .879 1 r
.01923 .98037 m
.04705 .95249 L
.04751 .95203 L
.07523 .92421 L
.07579 .92365 L
.10338 .89593 L
.10407 .89525 L
.13149 .86765 L
.13235 .8668 L
.15953 .83937 L
.16063 .83829 L
.18748 .81109 L
.18891 .8097 L
.21529 .78281 L
.21719 .78098 L
.24286 .75452 L
.24548 .75205 L
.27004 .72624 L
.27376 .72281 L
.29651 .69796 L
.30204 .69303 L
.32167 .66968 L
.33032 .6623 L
.34431 .6414 L
.3586 .62276 L
.36298 .61312 L
.37516 .58484 L
.37525 .55656 L
.3586 .52936 L
.3534 .52828 L
.33032 .51757 L
.30204 .511 L
.27376 .50737 L
.24548 .50518 L
.21719 .50377 L
.18891 .50284 L
.16063 .50219 L
.13235 .50172 L
.10407 .50138 L
.07579 .50112 L
.04751 .50092 L
.01923 .50077 L
F
0 g
.01923 .98037 m
.04705 .95249 L
.04751 .95203 L
.07523 .92421 L
.07579 .92365 L
.10338 .89593 L
.10407 .89525 L
.13149 .86765 L
.13235 .8668 L
.15953 .83937 L
.16063 .83829 L
.18748 .81109 L
.18891 .8097 L
.21529 .78281 L
.21719 .78098 L
.24286 .75452 L
.24548 .75205 L
.27004 .72624 L
.27376 .72281 L
.29651 .69796 L
.30204 .69303 L
.32167 .66968 L
.33032 .6623 L
.34431 .6414 L
.3586 .62276 L
.36298 .61312 L
.37516 .58484 L
.37525 .55656 L
.3586 .52936 L
.3534 .52828 L
.33032 .51757 L
.30204 .511 L
.27376 .50737 L
.24548 .50518 L
.21719 .50377 L
.18891 .50284 L
.16063 .50219 L
.13235 .50172 L
.10407 .50138 L
.07579 .50112 L
.04751 .50092 L
.01923 .50077 L
s
0 1 .537 r
.01923 .48769 m
.04751 .48522 L
.07579 .48205 L
.10407 .4779 L
.13235 .47232 L
.13493 .47172 L
.16063 .46464 L
.18891 .45356 L
.2071 .44344 L
.21719 .43643 L
.23784 .41516 L
.24548 .40545 L
.25185 .38688 L
.25572 .3586 L
.25221 .33032 L
.24548 .30829 L
.24293 .30204 L
.22876 .27376 L
.21719 .25377 L
.21115 .24548 L
.19074 .21719 L
.18891 .2147 L
.16819 .18891 L
.16063 .17957 L
.14423 .16063 L
.13235 .14685 L
.11922 .13235 L
.10407 .11549 L
.09343 .10407 L
.07579 .08498 L
.06706 .07579 L
.04751 .05503 L
.04037 .04751 L
.01923 .02566 L
F
0 g
.01923 .48769 m
.04751 .48522 L
.07579 .48205 L
.10407 .4779 L
.13235 .47232 L
.13493 .47172 L
.16063 .46464 L
.18891 .45356 L
.2071 .44344 L
.21719 .43643 L
.23784 .41516 L
.24548 .40545 L
.25185 .38688 L
.25572 .3586 L
.25221 .33032 L
.24548 .30829 L
.24293 .30204 L
.22876 .27376 L
.21719 .25377 L
.21115 .24548 L
.19074 .21719 L
.18891 .2147 L
.16819 .18891 L
.16063 .17957 L
.14423 .16063 L
.13235 .14685 L
.11922 .13235 L
.10407 .11549 L
.09343 .10407 L
.07579 .08498 L
.06706 .07579 L
.04751 .05503 L
.04037 .04751 L
.01923 .02566 L
s
0 .537 1 r
.01923 .97434 m
.04037 .95249 L
.04751 .94497 L
.06706 .92421 L
.07579 .91502 L
.09343 .89593 L
.10407 .88451 L
.11922 .86765 L
.13235 .85315 L
.14423 .83937 L
.16063 .82043 L
.16819 .81109 L
.18891 .7853 L
.19074 .78281 L
.21115 .75452 L
.21719 .74623 L
.22876 .72624 L
.24293 .69796 L
.24548 .69171 L
.25221 .66968 L
.25572 .6414 L
.25185 .61312 L
.24548 .59455 L
.23784 .58484 L
.21719 .56357 L
.2071 .55656 L
.18891 .54644 L
.16063 .53536 L
.13493 .52828 L
.13235 .52768 L
.10407 .5221 L
.07579 .51795 L
.04751 .51478 L
.01923 .51231 L
F
0 g
.01923 .97434 m
.04037 .95249 L
.04751 .94497 L
.06706 .92421 L
.07579 .91502 L
.09343 .89593 L
.10407 .88451 L
.11922 .86765 L
.13235 .85315 L
.14423 .83937 L
.16063 .82043 L
.16819 .81109 L
.18891 .7853 L
.19074 .78281 L
.21115 .75452 L
.21719 .74623 L
.22876 .72624 L
.24293 .69796 L
.24548 .69171 L
.25221 .66968 L
.25572 .6414 L
.25185 .61312 L
.24548 .59455 L
.23784 .58484 L
.21719 .56357 L
.2071 .55656 L
.18891 .54644 L
.16063 .53536 L
.13493 .52828 L
.13235 .52768 L
.10407 .5221 L
.07579 .51795 L
.04751 .51478 L
.01923 .51231 L
s
.061 0 1 r
.01923 .96058 m
.02653 .95249 L
.04751 .92794 L
.05062 .92421 L
.07386 .89593 L
.07579 .89357 L
.09579 .86765 L
.10407 .85666 L
.11611 .83937 L
.13235 .81464 L
.13445 .81109 L
.15019 .78281 L
.16063 .7608 L
.16292 .75452 L
.17188 .72624 L
.17652 .69796 L
.17595 .66968 L
.16904 .6414 L
.16063 .62295 L
.15389 .61312 L
.13235 .58956 L
.1266 .58484 L
.10407 .56961 L
.07752 .55656 L
.07579 .55584 L
.04751 .54567 L
.01923 .53792 L
F
0 g
.01923 .96058 m
.02653 .95249 L
.04751 .92794 L
.05062 .92421 L
.07386 .89593 L
.07579 .89357 L
.09579 .86765 L
.10407 .85666 L
.11611 .83937 L
.13235 .81464 L
.13445 .81109 L
.15019 .78281 L
.16063 .7608 L
.16292 .75452 L
.17188 .72624 L
.17652 .69796 L
.17595 .66968 L
.16904 .6414 L
.16063 .62295 L
.15389 .61312 L
.13235 .58956 L
.1266 .58484 L
.10407 .56961 L
.07752 .55656 L
.07579 .55584 L
.04751 .54567 L
.01923 .53792 L
s
.061 1 0 r
.01923 .46208 m
.04751 .45433 L
.07579 .44416 L
.07752 .44344 L
.10407 .43039 L
.1266 .41516 L
.13235 .41044 L
.15389 .38688 L
.16063 .37705 L
.16904 .3586 L
.17595 .33032 L
.17652 .30204 L
.17188 .27376 L
.16292 .24548 L
.16063 .2392 L
.15019 .21719 L
.13445 .18891 L
.13235 .18536 L
.11611 .16063 L
.10407 .14334 L
.09579 .13235 L
.07579 .10643 L
.07386 .10407 L
.05062 .07579 L
.04751 .07206 L
.02653 .04751 L
.01923 .03942 L
F
0 g
.01923 .46208 m
.04751 .45433 L
.07579 .44416 L
.07752 .44344 L
.10407 .43039 L
.1266 .41516 L
.13235 .41044 L
.15389 .38688 L
.16063 .37705 L
.16904 .3586 L
.17595 .33032 L
.17652 .30204 L
.17188 .27376 L
.16292 .24548 L
.16063 .2392 L
.15019 .21719 L
.13445 .18891 L
.13235 .18536 L
.11611 .16063 L
.10407 .14334 L
.09579 .13235 L
.07579 .10643 L
.07386 .10407 L
.05062 .07579 L
.04751 .07206 L
.02653 .04751 L
.01923 .03942 L
s
.915 1 0 r
.01923 .42095 m
.02955 .41516 L
.04751 .40335 L
.06713 .38688 L
.07579 .37799 L
.09054 .3586 L
.10407 .33216 L
.10473 .33032 L
.11204 .30204 L
.1139 .27376 L
.11117 .24548 L
.10451 .21719 L
.10407 .21556 L
.09436 .18891 L
.08125 .16063 L
.07579 .15 L
.06558 .13235 L
.04778 .10407 L
.04751 .10366 L
.02824 .07579 L
.01923 .06358 L
F
0 g
.01923 .42095 m
.02955 .41516 L
.04751 .40335 L
.06713 .38688 L
.07579 .37799 L
.09054 .3586 L
.10407 .33216 L
.10473 .33032 L
.11204 .30204 L
.1139 .27376 L
.11117 .24548 L
.10451 .21719 L
.10407 .21556 L
.09436 .18891 L
.08125 .16063 L
.07579 .15 L
.06558 .13235 L
.04778 .10407 L
.04751 .10366 L
.02824 .07579 L
.01923 .06358 L
s
.915 0 1 r
.01923 .93642 m
.02824 .92421 L
.04751 .89634 L
.04778 .89593 L
.06558 .86765 L
.07579 .85 L
.08125 .83937 L
.09436 .81109 L
.10407 .78444 L
.10451 .78281 L
.11117 .75452 L
.1139 .72624 L
.11204 .69796 L
.10473 .66968 L
.10407 .66784 L
.09054 .6414 L
.07579 .62201 L
.06713 .61312 L
.04751 .59665 L
.02955 .58484 L
.01923 .57905 L
F
0 g
.01923 .93642 m
.02824 .92421 L
.04751 .89634 L
.04778 .89593 L
.06558 .86765 L
.07579 .85 L
.08125 .83937 L
.09436 .81109 L
.10407 .78444 L
.10451 .78281 L
.11117 .75452 L
.1139 .72624 L
.11204 .69796 L
.10473 .66968 L
.10407 .66784 L
.09054 .6414 L
.07579 .62201 L
.06713 .61312 L
.04751 .59665 L
.02955 .58484 L
.01923 .57905 L
s
1 0 0 r
.01923 .35749 m
.03831 .33032 L
.04751 .31157 L
.0509 .30204 L
.05775 .27376 L
.05983 .24548 L
.05782 .21719 L
.05223 .18891 L
.04751 .17119 L
.04349 .16063 L
.03198 .13235 L
.01923 .10652 L
F
0 g
.01923 .35749 m
.03831 .33032 L
.04751 .31157 L
.0509 .30204 L
.05775 .27376 L
.05983 .24548 L
.05782 .21719 L
.05223 .18891 L
.04751 .17119 L
.04349 .16063 L
.03198 .13235 L
.01923 .10652 L
s
1 0 0 r
.01923 .89348 m
.03198 .86765 L
.04349 .83937 L
.04751 .82881 L
.05223 .81109 L
.05782 .78281 L
.05983 .75452 L
.05775 .72624 L
.0509 .69796 L
.04751 .68843 L
.03831 .66968 L
.01923 .64251 L
F
0 g
.01923 .89348 m
.03198 .86765 L
.04349 .83937 L
.04751 .82881 L
.05223 .81109 L
.05782 .78281 L
.05983 .75452 L
.05775 .72624 L
.0509 .69796 L
.04751 .68843 L
.03831 .66968 L
.01923 .64251 L
s
0 .879 1 r
.49923 .01923 m
.49908 .04751 L
.49888 .07579 L
.49862 .10407 L
.49828 .13235 L
.49781 .16063 L
.49716 .18891 L
.49623 .21719 L
.49482 .24548 L
.49263 .27376 L
.489 .30204 L
.48243 .33032 L
.47172 .3534 L
.47064 .3586 L
.44344 .37525 L
.41516 .37516 L
.38688 .36298 L
.37724 .3586 L
.3586 .34431 L
.3377 .33032 L
.33032 .32167 L
.30697 .30204 L
.30204 .29651 L
.27719 .27376 L
.27376 .27004 L
.24795 .24548 L
.24548 .24286 L
.21902 .21719 L
.21719 .21529 L
.1903 .18891 L
.18891 .18748 L
.16171 .16063 L
.16063 .15953 L
.1332 .13235 L
.13235 .13149 L
.10475 .10407 L
.10407 .10338 L
.07635 .07579 L
.07579 .07523 L
.04797 .04751 L
.04751 .04705 L
.01963 .01923 L
F
0 g
.49923 .01923 m
.49908 .04751 L
.49888 .07579 L
.49862 .10407 L
.49828 .13235 L
.49781 .16063 L
.49716 .18891 L
.49623 .21719 L
.49482 .24548 L
.49263 .27376 L
.489 .30204 L
.48243 .33032 L
.47172 .3534 L
.47064 .3586 L
.44344 .37525 L
.41516 .37516 L
.38688 .36298 L
.37724 .3586 L
.3586 .34431 L
.3377 .33032 L
.33032 .32167 L
.30697 .30204 L
.30204 .29651 L
.27719 .27376 L
.27376 .27004 L
.24795 .24548 L
.24548 .24286 L
.21902 .21719 L
.21719 .21529 L
.1903 .18891 L
.18891 .18748 L
.16171 .16063 L
.16063 .15953 L
.1332 .13235 L
.13235 .13149 L
.10475 .10407 L
.10407 .10338 L
.07635 .07579 L
.07579 .07523 L
.04797 .04751 L
.04751 .04705 L
.01963 .01923 L
s
0 1 .879 r
.49923 .98077 m
.49908 .95249 L
.49888 .92421 L
.49862 .89593 L
.49828 .86765 L
.49781 .83937 L
.49716 .81109 L
.49623 .78281 L
.49482 .75452 L
.49263 .72624 L
.489 .69796 L
.48243 .66968 L
.47172 .6466 L
.47064 .6414 L
.44344 .62475 L
.41516 .62484 L
.38688 .63702 L
.37724 .6414 L
.3586 .65569 L
.3377 .66968 L
.33032 .67833 L
.30697 .69796 L
.30204 .70349 L
.27719 .72624 L
.27376 .72996 L
.24795 .75452 L
.24548 .75714 L
.21902 .78281 L
.21719 .78471 L
.1903 .81109 L
.18891 .81252 L
.16171 .83937 L
.16063 .84047 L
.1332 .86765 L
.13235 .86851 L
.10475 .89593 L
.10407 .89662 L
.07635 .92421 L
.07579 .92477 L
.04797 .95249 L
.04751 .95295 L
.01963 .98077 L
F
0 g
.49923 .98077 m
.49908 .95249 L
.49888 .92421 L
.49862 .89593 L
.49828 .86765 L
.49781 .83937 L
.49716 .81109 L
.49623 .78281 L
.49482 .75452 L
.49263 .72624 L
.489 .69796 L
.48243 .66968 L
.47172 .6466 L
.47064 .6414 L
.44344 .62475 L
.41516 .62484 L
.38688 .63702 L
.37724 .6414 L
.3586 .65569 L
.3377 .66968 L
.33032 .67833 L
.30697 .69796 L
.30204 .70349 L
.27719 .72624 L
.27376 .72996 L
.24795 .75452 L
.24548 .75714 L
.21902 .78281 L
.21719 .78471 L
.1903 .81109 L
.18891 .81252 L
.16171 .83937 L
.16063 .84047 L
.1332 .86765 L
.13235 .86851 L
.10475 .89593 L
.10407 .89662 L
.07635 .92421 L
.07579 .92477 L
.04797 .95249 L
.04751 .95295 L
.01963 .98077 L
s
0 .537 1 r
.48769 .01923 m
.48522 .04751 L
.48205 .07579 L
.4779 .10407 L
.47232 .13235 L
.47172 .13493 L
.46464 .16063 L
.45356 .18891 L
.44344 .2071 L
.43643 .21719 L
.41516 .23784 L
.40545 .24548 L
.38688 .25185 L
.3586 .25572 L
.33032 .25221 L
.30829 .24548 L
.30204 .24293 L
.27376 .22876 L
.25377 .21719 L
.24548 .21115 L
.21719 .19074 L
.2147 .18891 L
.18891 .16819 L
.17957 .16063 L
.16063 .14423 L
.14685 .13235 L
.13235 .11922 L
.11549 .10407 L
.10407 .09343 L
.08498 .07579 L
.07579 .06706 L
.05503 .04751 L
.04751 .04037 L
.02566 .01923 L
F
0 g
.48769 .01923 m
.48522 .04751 L
.48205 .07579 L
.4779 .10407 L
.47232 .13235 L
.47172 .13493 L
.46464 .16063 L
.45356 .18891 L
.44344 .2071 L
.43643 .21719 L
.41516 .23784 L
.40545 .24548 L
.38688 .25185 L
.3586 .25572 L
.33032 .25221 L
.30829 .24548 L
.30204 .24293 L
.27376 .22876 L
.25377 .21719 L
.24548 .21115 L
.21719 .19074 L
.2147 .18891 L
.18891 .16819 L
.17957 .16063 L
.16063 .14423 L
.14685 .13235 L
.13235 .11922 L
.11549 .10407 L
.10407 .09343 L
.08498 .07579 L
.07579 .06706 L
.05503 .04751 L
.04751 .04037 L
.02566 .01923 L
s
0 1 .537 r
.48769 .98077 m
.48522 .95249 L
.48205 .92421 L
.4779 .89593 L
.47232 .86765 L
.47172 .86507 L
.46464 .83937 L
.45356 .81109 L
.44344 .7929 L
.43643 .78281 L
.41516 .76216 L
.40545 .75452 L
.38688 .74815 L
.3586 .74428 L
.33032 .74779 L
.30829 .75452 L
.30204 .75707 L
.27376 .77124 L
.25377 .78281 L
.24548 .78885 L
.21719 .80926 L
.2147 .81109 L
.18891 .83181 L
.17957 .83937 L
.16063 .85577 L
.14685 .86765 L
.13235 .88078 L
.11549 .89593 L
.10407 .90657 L
.08498 .92421 L
.07579 .93294 L
.05503 .95249 L
.04751 .95963 L
.02566 .98077 L
F
0 g
.48769 .98077 m
.48522 .95249 L
.48205 .92421 L
.4779 .89593 L
.47232 .86765 L
.47172 .86507 L
.46464 .83937 L
.45356 .81109 L
.44344 .7929 L
.43643 .78281 L
.41516 .76216 L
.40545 .75452 L
.38688 .74815 L
.3586 .74428 L
.33032 .74779 L
.30829 .75452 L
.30204 .75707 L
.27376 .77124 L
.25377 .78281 L
.24548 .78885 L
.21719 .80926 L
.2147 .81109 L
.18891 .83181 L
.17957 .83937 L
.16063 .85577 L
.14685 .86765 L
.13235 .88078 L
.11549 .89593 L
.10407 .90657 L
.08498 .92421 L
.07579 .93294 L
.05503 .95249 L
.04751 .95963 L
.02566 .98077 L
s
.061 0 1 r
.46208 .01923 m
.45433 .04751 L
.44416 .07579 L
.44344 .07752 L
.43039 .10407 L
.41516 .1266 L
.41044 .13235 L
.38688 .15389 L
.37705 .16063 L
.3586 .16904 L
.33032 .17595 L
.30204 .17652 L
.27376 .17188 L
.24548 .16292 L
.2392 .16063 L
.21719 .15019 L
.18891 .13445 L
.18536 .13235 L
.16063 .11611 L
.14334 .10407 L
.13235 .09579 L
.10643 .07579 L
.10407 .07386 L
.07579 .05062 L
.07206 .04751 L
.04751 .02653 L
.03942 .01923 L
F
0 g
.46208 .01923 m
.45433 .04751 L
.44416 .07579 L
.44344 .07752 L
.43039 .10407 L
.41516 .1266 L
.41044 .13235 L
.38688 .15389 L
.37705 .16063 L
.3586 .16904 L
.33032 .17595 L
.30204 .17652 L
.27376 .17188 L
.24548 .16292 L
.2392 .16063 L
.21719 .15019 L
.18891 .13445 L
.18536 .13235 L
.16063 .11611 L
.14334 .10407 L
.13235 .09579 L
.10643 .07579 L
.10407 .07386 L
.07579 .05062 L
.07206 .04751 L
.04751 .02653 L
.03942 .01923 L
s
.061 1 0 r
.46208 .98077 m
.45433 .95249 L
.44416 .92421 L
.44344 .92248 L
.43039 .89593 L
.41516 .8734 L
.41044 .86765 L
.38688 .84611 L
.37705 .83937 L
.3586 .83096 L
.33032 .82405 L
.30204 .82348 L
.27376 .82812 L
.24548 .83708 L
.2392 .83937 L
.21719 .84981 L
.18891 .86555 L
.18536 .86765 L
.16063 .88389 L
.14334 .89593 L
.13235 .90421 L
.10643 .92421 L
.10407 .92614 L
.07579 .94938 L
.07206 .95249 L
.04751 .97347 L
.03942 .98077 L
F
0 g
.46208 .98077 m
.45433 .95249 L
.44416 .92421 L
.44344 .92248 L
.43039 .89593 L
.41516 .8734 L
.41044 .86765 L
.38688 .84611 L
.37705 .83937 L
.3586 .83096 L
.33032 .82405 L
.30204 .82348 L
.27376 .82812 L
.24548 .83708 L
.2392 .83937 L
.21719 .84981 L
.18891 .86555 L
.18536 .86765 L
.16063 .88389 L
.14334 .89593 L
.13235 .90421 L
.10643 .92421 L
.10407 .92614 L
.07579 .94938 L
.07206 .95249 L
.04751 .97347 L
.03942 .98077 L
s
.915 0 1 r
.42095 .01923 m
.41516 .02955 L
.40335 .04751 L
.38688 .06713 L
.37799 .07579 L
.3586 .09054 L
.33216 .10407 L
.33032 .10473 L
.30204 .11204 L
.27376 .1139 L
.24548 .11117 L
.21719 .10451 L
.21556 .10407 L
.18891 .09436 L
.16063 .08125 L
.15 .07579 L
.13235 .06558 L
.10407 .04778 L
.10366 .04751 L
.07579 .02824 L
.06358 .01923 L
F
0 g
.42095 .01923 m
.41516 .02955 L
.40335 .04751 L
.38688 .06713 L
.37799 .07579 L
.3586 .09054 L
.33216 .10407 L
.33032 .10473 L
.30204 .11204 L
.27376 .1139 L
.24548 .11117 L
.21719 .10451 L
.21556 .10407 L
.18891 .09436 L
.16063 .08125 L
.15 .07579 L
.13235 .06558 L
.10407 .04778 L
.10366 .04751 L
.07579 .02824 L
.06358 .01923 L
s
.915 1 0 r
.42095 .98077 m
.41516 .97045 L
.40335 .95249 L
.38688 .93287 L
.37799 .92421 L
.3586 .90946 L
.33216 .89593 L
.33032 .89527 L
.30204 .88796 L
.27376 .8861 L
.24548 .88883 L
.21719 .89549 L
.21556 .89593 L
.18891 .90564 L
.16063 .91875 L
.15 .92421 L
.13235 .93442 L
.10407 .95222 L
.10366 .95249 L
.07579 .97176 L
.06358 .98077 L
F
0 g
.42095 .98077 m
.41516 .97045 L
.40335 .95249 L
.38688 .93287 L
.37799 .92421 L
.3586 .90946 L
.33216 .89593 L
.33032 .89527 L
.30204 .88796 L
.27376 .8861 L
.24548 .88883 L
.21719 .89549 L
.21556 .89593 L
.18891 .90564 L
.16063 .91875 L
.15 .92421 L
.13235 .93442 L
.10407 .95222 L
.10366 .95249 L
.07579 .97176 L
.06358 .98077 L
s
1 0 0 r
.35749 .01923 m
.33032 .03831 L
.31157 .04751 L
.30204 .0509 L
.27376 .05775 L
.24548 .05983 L
.21719 .05782 L
.18891 .05223 L
.17119 .04751 L
.16063 .04349 L
.13235 .03198 L
.10652 .01923 L
F
0 g
.35749 .01923 m
.33032 .03831 L
.31157 .04751 L
.30204 .0509 L
.27376 .05775 L
.24548 .05983 L
.21719 .05782 L
.18891 .05223 L
.17119 .04751 L
.16063 .04349 L
.13235 .03198 L
.10652 .01923 L
s
1 0 0 r
.35749 .98077 m
.33032 .96169 L
.31157 .95249 L
.30204 .9491 L
.27376 .94225 L
.24548 .94017 L
.21719 .94218 L
.18891 .94777 L
.17119 .95249 L
.16063 .95651 L
.13235 .96802 L
.10652 .98077 L
F
0 g
.35749 .98077 m
.33032 .96169 L
.31157 .95249 L
.30204 .9491 L
.27376 .94225 L
.24548 .94017 L
.21719 .94218 L
.18891 .94777 L
.17119 .95249 L
.16063 .95651 L
.13235 .96802 L
.10652 .98077 L
s
0 1 .879 r
.98037 .01923 m
.95249 .04705 L
.95203 .04751 L
.92421 .07523 L
.92365 .07579 L
.89593 .10338 L
.89525 .10407 L
.86765 .13149 L
.8668 .13235 L
.83937 .15953 L
.83829 .16063 L
.81109 .18748 L
.8097 .18891 L
.78281 .21529 L
.78098 .21719 L
.75452 .24286 L
.75205 .24548 L
.72624 .27004 L
.72281 .27376 L
.69796 .29651 L
.69303 .30204 L
.66968 .32167 L
.6623 .33032 L
.6414 .34431 L
.62276 .3586 L
.61312 .36298 L
.58484 .37516 L
.55656 .37525 L
.52936 .3586 L
.52828 .3534 L
.51757 .33032 L
.511 .30204 L
.50737 .27376 L
.50518 .24548 L
.50377 .21719 L
.50284 .18891 L
.50219 .16063 L
.50172 .13235 L
.50138 .10407 L
.50112 .07579 L
.50092 .04751 L
.50077 .01923 L
F
0 g
.98037 .01923 m
.95249 .04705 L
.95203 .04751 L
.92421 .07523 L
.92365 .07579 L
.89593 .10338 L
.89525 .10407 L
.86765 .13149 L
.8668 .13235 L
.83937 .15953 L
.83829 .16063 L
.81109 .18748 L
.8097 .18891 L
.78281 .21529 L
.78098 .21719 L
.75452 .24286 L
.75205 .24548 L
.72624 .27004 L
.72281 .27376 L
.69796 .29651 L
.69303 .30204 L
.66968 .32167 L
.6623 .33032 L
.6414 .34431 L
.62276 .3586 L
.61312 .36298 L
.58484 .37516 L
.55656 .37525 L
.52936 .3586 L
.52828 .3534 L
.51757 .33032 L
.511 .30204 L
.50737 .27376 L
.50518 .24548 L
.50377 .21719 L
.50284 .18891 L
.50219 .16063 L
.50172 .13235 L
.50138 .10407 L
.50112 .07579 L
.50092 .04751 L
.50077 .01923 L
s
0 .879 1 r
.98037 .98077 m
.95249 .95295 L
.95203 .95249 L
.92421 .92477 L
.92365 .92421 L
.89593 .89662 L
.89525 .89593 L
.86765 .86851 L
.8668 .86765 L
.83937 .84047 L
.83829 .83937 L
.81109 .81252 L
.8097 .81109 L
.78281 .78471 L
.78098 .78281 L
.75452 .75714 L
.75205 .75452 L
.72624 .72996 L
.72281 .72624 L
.69796 .70349 L
.69303 .69796 L
.66968 .67833 L
.6623 .66968 L
.6414 .65569 L
.62276 .6414 L
.61312 .63702 L
.58484 .62484 L
.55656 .62475 L
.52936 .6414 L
.52828 .6466 L
.51757 .66968 L
.511 .69796 L
.50737 .72624 L
.50518 .75452 L
.50377 .78281 L
.50284 .81109 L
.50219 .83937 L
.50172 .86765 L
.50138 .89593 L
.50112 .92421 L
.50092 .95249 L
.50077 .98077 L
F
0 g
.98037 .98077 m
.95249 .95295 L
.95203 .95249 L
.92421 .92477 L
.92365 .92421 L
.89593 .89662 L
.89525 .89593 L
.86765 .86851 L
.8668 .86765 L
.83937 .84047 L
.83829 .83937 L
.81109 .81252 L
.8097 .81109 L
.78281 .78471 L
.78098 .78281 L
.75452 .75714 L
.75205 .75452 L
.72624 .72996 L
.72281 .72624 L
.69796 .70349 L
.69303 .69796 L
.66968 .67833 L
.6623 .66968 L
.6414 .65569 L
.62276 .6414 L
.61312 .63702 L
.58484 .62484 L
.55656 .62475 L
.52936 .6414 L
.52828 .6466 L
.51757 .66968 L
.511 .69796 L
.50737 .72624 L
.50518 .75452 L
.50377 .78281 L
.50284 .81109 L
.50219 .83937 L
.50172 .86765 L
.50138 .89593 L
.50112 .92421 L
.50092 .95249 L
.50077 .98077 L
s
0 1 .537 r
.97434 .01923 m
.95249 .04037 L
.94497 .04751 L
.92421 .06706 L
.91502 .07579 L
.89593 .09343 L
.88451 .10407 L
.86765 .11922 L
.85315 .13235 L
.83937 .14423 L
.82043 .16063 L
.81109 .16819 L
.7853 .18891 L
.78281 .19074 L
.75452 .21115 L
.74623 .21719 L
.72624 .22876 L
.69796 .24293 L
.69171 .24548 L
.66968 .25221 L
.6414 .25572 L
.61312 .25185 L
.59455 .24548 L
.58484 .23784 L
.56357 .21719 L
.55656 .2071 L
.54644 .18891 L
.53536 .16063 L
.52828 .13493 L
.52768 .13235 L
.5221 .10407 L
.51795 .07579 L
.51478 .04751 L
.51231 .01923 L
F
0 g
.97434 .01923 m
.95249 .04037 L
.94497 .04751 L
.92421 .06706 L
.91502 .07579 L
.89593 .09343 L
.88451 .10407 L
.86765 .11922 L
.85315 .13235 L
.83937 .14423 L
.82043 .16063 L
.81109 .16819 L
.7853 .18891 L
.78281 .19074 L
.75452 .21115 L
.74623 .21719 L
.72624 .22876 L
.69796 .24293 L
.69171 .24548 L
.66968 .25221 L
.6414 .25572 L
.61312 .25185 L
.59455 .24548 L
.58484 .23784 L
.56357 .21719 L
.55656 .2071 L
.54644 .18891 L
.53536 .16063 L
.52828 .13493 L
.52768 .13235 L
.5221 .10407 L
.51795 .07579 L
.51478 .04751 L
.51231 .01923 L
s
0 .537 1 r
.97434 .98077 m
.95249 .95963 L
.94497 .95249 L
.92421 .93294 L
.91502 .92421 L
.89593 .90657 L
.88451 .89593 L
.86765 .88078 L
.85315 .86765 L
.83937 .85577 L
.82043 .83937 L
.81109 .83181 L
.7853 .81109 L
.78281 .80926 L
.75452 .78885 L
.74623 .78281 L
.72624 .77124 L
.69796 .75707 L
.69171 .75452 L
.66968 .74779 L
.6414 .74428 L
.61312 .74815 L
.59455 .75452 L
.58484 .76216 L
.56357 .78281 L
.55656 .7929 L
.54644 .81109 L
.53536 .83937 L
.52828 .86507 L
.52768 .86765 L
.5221 .89593 L
.51795 .92421 L
.51478 .95249 L
.51231 .98077 L
F
0 g
.97434 .98077 m
.95249 .95963 L
.94497 .95249 L
.92421 .93294 L
.91502 .92421 L
.89593 .90657 L
.88451 .89593 L
.86765 .88078 L
.85315 .86765 L
.83937 .85577 L
.82043 .83937 L
.81109 .83181 L
.7853 .81109 L
.78281 .80926 L
.75452 .78885 L
.74623 .78281 L
.72624 .77124 L
.69796 .75707 L
.69171 .75452 L
.66968 .74779 L
.6414 .74428 L
.61312 .74815 L
.59455 .75452 L
.58484 .76216 L
.56357 .78281 L
.55656 .7929 L
.54644 .81109 L
.53536 .83937 L
.52828 .86507 L
.52768 .86765 L
.5221 .89593 L
.51795 .92421 L
.51478 .95249 L
.51231 .98077 L
s
.061 1 0 r
.96058 .01923 m
.95249 .02653 L
.92794 .04751 L
.92421 .05062 L
.89593 .07386 L
.89357 .07579 L
.86765 .09579 L
.85666 .10407 L
.83937 .11611 L
.81464 .13235 L
.81109 .13445 L
.78281 .15019 L
.7608 .16063 L
.75452 .16292 L
.72624 .17188 L
.69796 .17652 L
.66968 .17595 L
.6414 .16904 L
.62295 .16063 L
.61312 .15389 L
.58956 .13235 L
.58484 .1266 L
.56961 .10407 L
.55656 .07752 L
.55584 .07579 L
.54567 .04751 L
.53792 .01923 L
F
0 g
.96058 .01923 m
.95249 .02653 L
.92794 .04751 L
.92421 .05062 L
.89593 .07386 L
.89357 .07579 L
.86765 .09579 L
.85666 .10407 L
.83937 .11611 L
.81464 .13235 L
.81109 .13445 L
.78281 .15019 L
.7608 .16063 L
.75452 .16292 L
.72624 .17188 L
.69796 .17652 L
.66968 .17595 L
.6414 .16904 L
.62295 .16063 L
.61312 .15389 L
.58956 .13235 L
.58484 .1266 L
.56961 .10407 L
.55656 .07752 L
.55584 .07579 L
.54567 .04751 L
.53792 .01923 L
s
.061 0 1 r
.96058 .98077 m
.95249 .97347 L
.92794 .95249 L
.92421 .94938 L
.89593 .92614 L
.89357 .92421 L
.86765 .90421 L
.85666 .89593 L
.83937 .88389 L
.81464 .86765 L
.81109 .86555 L
.78281 .84981 L
.7608 .83937 L
.75452 .83708 L
.72624 .82812 L
.69796 .82348 L
.66968 .82405 L
.6414 .83096 L
.62295 .83937 L
.61312 .84611 L
.58956 .86765 L
.58484 .8734 L
.56961 .89593 L
.55656 .92248 L
.55584 .92421 L
.54567 .95249 L
.53792 .98077 L
F
0 g
.96058 .98077 m
.95249 .97347 L
.92794 .95249 L
.92421 .94938 L
.89593 .92614 L
.89357 .92421 L
.86765 .90421 L
.85666 .89593 L
.83937 .88389 L
.81464 .86765 L
.81109 .86555 L
.78281 .84981 L
.7608 .83937 L
.75452 .83708 L
.72624 .82812 L
.69796 .82348 L
.66968 .82405 L
.6414 .83096 L
.62295 .83937 L
.61312 .84611 L
.58956 .86765 L
.58484 .8734 L
.56961 .89593 L
.55656 .92248 L
.55584 .92421 L
.54567 .95249 L
.53792 .98077 L
s
.915 1 0 r
.93642 .01923 m
.92421 .02824 L
.89634 .04751 L
.89593 .04778 L
.86765 .06558 L
.85 .07579 L
.83937 .08125 L
.81109 .09436 L
.78444 .10407 L
.78281 .10451 L
.75452 .11117 L
.72624 .1139 L
.69796 .11204 L
.66968 .10473 L
.66784 .10407 L
.6414 .09054 L
.62201 .07579 L
.61312 .06713 L
.59665 .04751 L
.58484 .02955 L
.57905 .01923 L
F
0 g
.93642 .01923 m
.92421 .02824 L
.89634 .04751 L
.89593 .04778 L
.86765 .06558 L
.85 .07579 L
.83937 .08125 L
.81109 .09436 L
.78444 .10407 L
.78281 .10451 L
.75452 .11117 L
.72624 .1139 L
.69796 .11204 L
.66968 .10473 L
.66784 .10407 L
.6414 .09054 L
.62201 .07579 L
.61312 .06713 L
.59665 .04751 L
.58484 .02955 L
.57905 .01923 L
s
.915 0 1 r
.93642 .98077 m
.92421 .97176 L
.89634 .95249 L
.89593 .95222 L
.86765 .93442 L
.85 .92421 L
.83937 .91875 L
.81109 .90564 L
.78444 .89593 L
.78281 .89549 L
.75452 .88883 L
.72624 .8861 L
.69796 .88796 L
.66968 .89527 L
.66784 .89593 L
.6414 .90946 L
.62201 .92421 L
.61312 .93287 L
.59665 .95249 L
.58484 .97045 L
.57905 .98077 L
F
0 g
.93642 .98077 m
.92421 .97176 L
.89634 .95249 L
.89593 .95222 L
.86765 .93442 L
.85 .92421 L
.83937 .91875 L
.81109 .90564 L
.78444 .89593 L
.78281 .89549 L
.75452 .88883 L
.72624 .8861 L
.69796 .88796 L
.66968 .89527 L
.66784 .89593 L
.6414 .90946 L
.62201 .92421 L
.61312 .93287 L
.59665 .95249 L
.58484 .97045 L
.57905 .98077 L
s
0 .879 1 r
.98077 .49923 m
.95249 .49908 L
.92421 .49888 L
.89593 .49862 L
.86765 .49828 L
.83937 .49781 L
.81109 .49716 L
.78281 .49623 L
.75452 .49482 L
.72624 .49263 L
.69796 .489 L
.66968 .48243 L
.6466 .47172 L
.6414 .47064 L
.62475 .44344 L
.62484 .41516 L
.63702 .38688 L
.6414 .37724 L
.65569 .3586 L
.66968 .3377 L
.67833 .33032 L
.69796 .30697 L
.70349 .30204 L
.72624 .27719 L
.72996 .27376 L
.75452 .24795 L
.75714 .24548 L
.78281 .21902 L
.78471 .21719 L
.81109 .1903 L
.81252 .18891 L
.83937 .16171 L
.84047 .16063 L
.86765 .1332 L
.86851 .13235 L
.89593 .10475 L
.89662 .10407 L
.92421 .07635 L
.92477 .07579 L
.95249 .04797 L
.95295 .04751 L
.98077 .01963 L
F
0 g
.98077 .49923 m
.95249 .49908 L
.92421 .49888 L
.89593 .49862 L
.86765 .49828 L
.83937 .49781 L
.81109 .49716 L
.78281 .49623 L
.75452 .49482 L
.72624 .49263 L
.69796 .489 L
.66968 .48243 L
.6466 .47172 L
.6414 .47064 L
.62475 .44344 L
.62484 .41516 L
.63702 .38688 L
.6414 .37724 L
.65569 .3586 L
.66968 .3377 L
.67833 .33032 L
.69796 .30697 L
.70349 .30204 L
.72624 .27719 L
.72996 .27376 L
.75452 .24795 L
.75714 .24548 L
.78281 .21902 L
.78471 .21719 L
.81109 .1903 L
.81252 .18891 L
.83937 .16171 L
.84047 .16063 L
.86765 .1332 L
.86851 .13235 L
.89593 .10475 L
.89662 .10407 L
.92421 .07635 L
.92477 .07579 L
.95249 .04797 L
.95295 .04751 L
.98077 .01963 L
s
0 1 .879 r
.98077 .98037 m
.95295 .95249 L
.95249 .95203 L
.92477 .92421 L
.92421 .92365 L
.89662 .89593 L
.89593 .89525 L
.86851 .86765 L
.86765 .8668 L
.84047 .83937 L
.83937 .83829 L
.81252 .81109 L
.81109 .8097 L
.78471 .78281 L
.78281 .78098 L
.75714 .75452 L
.75452 .75205 L
.72996 .72624 L
.72624 .72281 L
.70349 .69796 L
.69796 .69303 L
.67833 .66968 L
.66968 .6623 L
.65569 .6414 L
.6414 .62276 L
.63702 .61312 L
.62484 .58484 L
.62475 .55656 L
.6414 .52936 L
.6466 .52828 L
.66968 .51757 L
.69796 .511 L
.72624 .50737 L
.75452 .50518 L
.78281 .50377 L
.81109 .50284 L
.83937 .50219 L
.86765 .50172 L
.89593 .50138 L
.92421 .50112 L
.95249 .50092 L
.98077 .50077 L
F
0 g
.98077 .98037 m
.95295 .95249 L
.95249 .95203 L
.92477 .92421 L
.92421 .92365 L
.89662 .89593 L
.89593 .89525 L
.86851 .86765 L
.86765 .8668 L
.84047 .83937 L
.83937 .83829 L
.81252 .81109 L
.81109 .8097 L
.78471 .78281 L
.78281 .78098 L
.75714 .75452 L
.75452 .75205 L
.72996 .72624 L
.72624 .72281 L
.70349 .69796 L
.69796 .69303 L
.67833 .66968 L
.66968 .6623 L
.65569 .6414 L
.6414 .62276 L
.63702 .61312 L
.62484 .58484 L
.62475 .55656 L
.6414 .52936 L
.6466 .52828 L
.66968 .51757 L
.69796 .511 L
.72624 .50737 L
.75452 .50518 L
.78281 .50377 L
.81109 .50284 L
.83937 .50219 L
.86765 .50172 L
.89593 .50138 L
.92421 .50112 L
.95249 .50092 L
.98077 .50077 L
s
1 0 0 r
.89348 .01923 m
.86765 .03198 L
.83937 .04349 L
.82881 .04751 L
.81109 .05223 L
.78281 .05782 L
.75452 .05983 L
.72624 .05775 L
.69796 .0509 L
.68843 .04751 L
.66968 .03831 L
.64251 .01923 L
F
0 g
.89348 .01923 m
.86765 .03198 L
.83937 .04349 L
.82881 .04751 L
.81109 .05223 L
.78281 .05782 L
.75452 .05983 L
.72624 .05775 L
.69796 .0509 L
.68843 .04751 L
.66968 .03831 L
.64251 .01923 L
s
1 0 0 r
.89348 .98077 m
.86765 .96802 L
.83937 .95651 L
.82881 .95249 L
.81109 .94777 L
.78281 .94218 L
.75452 .94017 L
.72624 .94225 L
.69796 .9491 L
.68843 .95249 L
.66968 .96169 L
.64251 .98077 L
F
0 g
.89348 .98077 m
.86765 .96802 L
.83937 .95651 L
.82881 .95249 L
.81109 .94777 L
.78281 .94218 L
.75452 .94017 L
.72624 .94225 L
.69796 .9491 L
.68843 .95249 L
.66968 .96169 L
.64251 .98077 L
s
0 .537 1 r
.98077 .48769 m
.95249 .48522 L
.92421 .48205 L
.89593 .4779 L
.86765 .47232 L
.86507 .47172 L
.83937 .46464 L
.81109 .45356 L
.7929 .44344 L
.78281 .43643 L
.76216 .41516 L
.75452 .40545 L
.74815 .38688 L
.74428 .3586 L
.74779 .33032 L
.75452 .30829 L
.75707 .30204 L
.77124 .27376 L
.78281 .25377 L
.78885 .24548 L
.80926 .21719 L
.81109 .2147 L
.83181 .18891 L
.83937 .17957 L
.85577 .16063 L
.86765 .14685 L
.88078 .13235 L
.89593 .11549 L
.90657 .10407 L
.92421 .08498 L
.93294 .07579 L
.95249 .05503 L
.95963 .04751 L
.98077 .02566 L
F
0 g
.98077 .48769 m
.95249 .48522 L
.92421 .48205 L
.89593 .4779 L
.86765 .47232 L
.86507 .47172 L
.83937 .46464 L
.81109 .45356 L
.7929 .44344 L
.78281 .43643 L
.76216 .41516 L
.75452 .40545 L
.74815 .38688 L
.74428 .3586 L
.74779 .33032 L
.75452 .30829 L
.75707 .30204 L
.77124 .27376 L
.78281 .25377 L
.78885 .24548 L
.80926 .21719 L
.81109 .2147 L
.83181 .18891 L
.83937 .17957 L
.85577 .16063 L
.86765 .14685 L
.88078 .13235 L
.89593 .11549 L
.90657 .10407 L
.92421 .08498 L
.93294 .07579 L
.95249 .05503 L
.95963 .04751 L
.98077 .02566 L
s
0 1 .537 r
.98077 .97434 m
.95963 .95249 L
.95249 .94497 L
.93294 .92421 L
.92421 .91502 L
.90657 .89593 L
.89593 .88451 L
.88078 .86765 L
.86765 .85315 L
.85577 .83937 L
.83937 .82043 L
.83181 .81109 L
.81109 .7853 L
.80926 .78281 L
.78885 .75452 L
.78281 .74623 L
.77124 .72624 L
.75707 .69796 L
.75452 .69171 L
.74779 .66968 L
.74428 .6414 L
.74815 .61312 L
.75452 .59455 L
.76216 .58484 L
.78281 .56357 L
.7929 .55656 L
.81109 .54644 L
.83937 .53536 L
.86507 .52828 L
.86765 .52768 L
.89593 .5221 L
.92421 .51795 L
.95249 .51478 L
.98077 .51231 L
F
0 g
.98077 .97434 m
.95963 .95249 L
.95249 .94497 L
.93294 .92421 L
.92421 .91502 L
.90657 .89593 L
.89593 .88451 L
.88078 .86765 L
.86765 .85315 L
.85577 .83937 L
.83937 .82043 L
.83181 .81109 L
.81109 .7853 L
.80926 .78281 L
.78885 .75452 L
.78281 .74623 L
.77124 .72624 L
.75707 .69796 L
.75452 .69171 L
.74779 .66968 L
.74428 .6414 L
.74815 .61312 L
.75452 .59455 L
.76216 .58484 L
.78281 .56357 L
.7929 .55656 L
.81109 .54644 L
.83937 .53536 L
.86507 .52828 L
.86765 .52768 L
.89593 .5221 L
.92421 .51795 L
.95249 .51478 L
.98077 .51231 L
s
.061 1 0 r
.98077 .96058 m
.97347 .95249 L
.95249 .92794 L
.94938 .92421 L
.92614 .89593 L
.92421 .89357 L
.90421 .86765 L
.89593 .85666 L
.88389 .83937 L
.86765 .81464 L
.86555 .81109 L
.84981 .78281 L
.83937 .7608 L
.83708 .75452 L
.82812 .72624 L
.82348 .69796 L
.82405 .66968 L
.83096 .6414 L
.83937 .62295 L
.84611 .61312 L
.86765 .58956 L
.8734 .58484 L
.89593 .56961 L
.92248 .55656 L
.92421 .55584 L
.95249 .54567 L
.98077 .53792 L
F
0 g
.98077 .96058 m
.97347 .95249 L
.95249 .92794 L
.94938 .92421 L
.92614 .89593 L
.92421 .89357 L
.90421 .86765 L
.89593 .85666 L
.88389 .83937 L
.86765 .81464 L
.86555 .81109 L
.84981 .78281 L
.83937 .7608 L
.83708 .75452 L
.82812 .72624 L
.82348 .69796 L
.82405 .66968 L
.83096 .6414 L
.83937 .62295 L
.84611 .61312 L
.86765 .58956 L
.8734 .58484 L
.89593 .56961 L
.92248 .55656 L
.92421 .55584 L
.95249 .54567 L
.98077 .53792 L
s
.061 0 1 r
.98077 .46208 m
.95249 .45433 L
.92421 .44416 L
.92248 .44344 L
.89593 .43039 L
.8734 .41516 L
.86765 .41044 L
.84611 .38688 L
.83937 .37705 L
.83096 .3586 L
.82405 .33032 L
.82348 .30204 L
.82812 .27376 L
.83708 .24548 L
.83937 .2392 L
.84981 .21719 L
.86555 .18891 L
.86765 .18536 L
.88389 .16063 L
.89593 .14334 L
.90421 .13235 L
.92421 .10643 L
.92614 .10407 L
.94938 .07579 L
.95249 .07206 L
.97347 .04751 L
.98077 .03942 L
F
0 g
.98077 .46208 m
.95249 .45433 L
.92421 .44416 L
.92248 .44344 L
.89593 .43039 L
.8734 .41516 L
.86765 .41044 L
.84611 .38688 L
.83937 .37705 L
.83096 .3586 L
.82405 .33032 L
.82348 .30204 L
.82812 .27376 L
.83708 .24548 L
.83937 .2392 L
.84981 .21719 L
.86555 .18891 L
.86765 .18536 L
.88389 .16063 L
.89593 .14334 L
.90421 .13235 L
.92421 .10643 L
.92614 .10407 L
.94938 .07579 L
.95249 .07206 L
.97347 .04751 L
.98077 .03942 L
s
.915 0 1 r
.98077 .42095 m
.97045 .41516 L
.95249 .40335 L
.93287 .38688 L
.92421 .37799 L
.90946 .3586 L
.89593 .33216 L
.89527 .33032 L
.88796 .30204 L
.8861 .27376 L
.88883 .24548 L
.89549 .21719 L
.89593 .21556 L
.90564 .18891 L
.91875 .16063 L
.92421 .15 L
.93442 .13235 L
.95222 .10407 L
.95249 .10366 L
.97176 .07579 L
.98077 .06358 L
F
0 g
.98077 .42095 m
.97045 .41516 L
.95249 .40335 L
.93287 .38688 L
.92421 .37799 L
.90946 .3586 L
.89593 .33216 L
.89527 .33032 L
.88796 .30204 L
.8861 .27376 L
.88883 .24548 L
.89549 .21719 L
.89593 .21556 L
.90564 .18891 L
.91875 .16063 L
.92421 .15 L
.93442 .13235 L
.95222 .10407 L
.95249 .10366 L
.97176 .07579 L
.98077 .06358 L
s
.915 1 0 r
.98077 .93642 m
.97176 .92421 L
.95249 .89634 L
.95222 .89593 L
.93442 .86765 L
.92421 .85 L
.91875 .83937 L
.90564 .81109 L
.89593 .78444 L
.89549 .78281 L
.88883 .75452 L
.8861 .72624 L
.88796 .69796 L
.89527 .66968 L
.89593 .66784 L
.90946 .6414 L
.92421 .62201 L
.93287 .61312 L
.95249 .59665 L
.97045 .58484 L
.98077 .57905 L
F
0 g
.98077 .93642 m
.97176 .92421 L
.95249 .89634 L
.95222 .89593 L
.93442 .86765 L
.92421 .85 L
.91875 .83937 L
.90564 .81109 L
.89593 .78444 L
.89549 .78281 L
.88883 .75452 L
.8861 .72624 L
.88796 .69796 L
.89527 .66968 L
.89593 .66784 L
.90946 .6414 L
.92421 .62201 L
.93287 .61312 L
.95249 .59665 L
.97045 .58484 L
.98077 .57905 L
s
1 0 0 r
.98077 .35749 m
.96169 .33032 L
.95249 .31157 L
.9491 .30204 L
.94225 .27376 L
.94017 .24548 L
.94218 .21719 L
.94777 .18891 L
.95249 .17119 L
.95651 .16063 L
.96802 .13235 L
.98077 .10652 L
F
0 g
.98077 .35749 m
.96169 .33032 L
.95249 .31157 L
.9491 .30204 L
.94225 .27376 L
.94017 .24548 L
.94218 .21719 L
.94777 .18891 L
.95249 .17119 L
.95651 .16063 L
.96802 .13235 L
.98077 .10652 L
s
1 0 0 r
.98077 .89348 m
.96802 .86765 L
.95651 .83937 L
.95249 .82881 L
.94777 .81109 L
.94218 .78281 L
.94017 .75452 L
.94225 .72624 L
.9491 .69796 L
.95249 .68843 L
.96169 .66968 L
.98077 .64251 L
F
0 g
.98077 .89348 m
.96802 .86765 L
.95651 .83937 L
.95249 .82881 L
.94777 .81109 L
.94218 .78281 L
.94017 .75452 L
.94225 .72624 L
.9491 .69796 L
.95249 .68843 L
.96169 .66968 L
.98077 .64251 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{222, 222},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003N0000gR000`400?l00000o`00003ogP3oool0
0=h0oooo003N0?ooo`009`3oool4000002@0oooo1@00000P0?ooo`8000009@3oool5000002<0oooo
1000000G0?ooo`009`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01l0oooo00@0
00000?ooo`3oool000009P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo
000X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool07`3oool010000000oooo0?oo
o`00000V0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool05`3oool00240oooo1000
00040?ooo`030000003oool0oooo01d0oooo100000040?ooo`030000003oool0oooo01l0oooo00@0
00000?ooo`3oool000009P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01H0oooo
000W0?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool07`3oool010000000oooo
0?ooo`00000V0?ooo`030000003oool0oooo02<0oooo00@000000?ooo`3oool000005`3oool002P0
oooo0P00000V0?ooo`8000008P3oool2000002H0oooo0P00000V0?ooo`800000603oool00=h0oooo
003N0?ooo`00gP3oool00=h0oooo003N0?ooo`003P3oooo?00000040oooo000>0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0D0?ooo`4000000@3o
ool000h0oooo00<000000?ooo`3oool0b`3oool100000040oooo000>0?ooo`030000003oool0oooo
0</0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool200000080oooo00<000000?oo
o`3oool00P3oool2000000L0oooo0P00000b0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0;`3oool2000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020000
00<0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool30000008008Wo0P00000400l0
o`8000001`3Z0?l2000002h0o`000P00000<0>X0o`030000000?0?l03`3o00H03`3o00<000000029
o`00ROl00`00ROl00`0000000>7o00000002003oh@0300000000ohT00?n900800?n900<0000000oo
000?o`001P0?o`000`000000j_l00>[o000;0>[o00030000003o0000o`0002`0o`000P0000080>[o
00800000100?o`000`0000000?n9003oR@03000000<0oooo0@0000010?ooo`003P3oool01@000000
oooo0?ooo`3oool00?n900@000000P00ROl00`0000003`3o00l0o`0300l0o`030000003Z0?l0jP3o
00H0jP3o0P00000[0?l000030000003Z0?l0jP3o00`0jP3o00<0000000l0o`0?0?l01P0?0?l00`00
000008Wo0029o`030029o`0300000000hOl0000000800?oQ00<00000003oR@00ohT00`00ohT00`00
00003ol000oo000600oo00030000003Zo`00j_l000/0j_l00P00000Z0?l000800000203Zo`020000
00D03ol000<00000003oR@00ohT00`0000040?ooo`4000000@3oool000h0oooo00@000000?ooo`3o
ool0oooo0P00ohT40000008008Wo0P00000400l0o`800000203Z0?l2000002L0o`000P00000>0>X0
o`030000000?0?l03`3o00H03`3o00<000000029o`00ROl00`00ROl0100000000>7o003Qo`000002
003oh@0300000000ohT00?n900<00?n900<0000000oo000?o`001`0?o`000`000000j_l00>[o000<
0>[o00030000003o0000o`0002D0o`000P0000090>[o00030000000?o`003ol000<03ol00P000002
003oR@<0000000<008Wo0?ooo`3oool00P3oool100000040oooo000>0?ooo`8000000P3oool01@00
00000?n9003oR@0000000?oQ008000000`00ROl00`0000003`3o00l0o`0300l0o`030000003Z0?l0
jP3o00L0jP3o0P00000S0?l0008000003`3Z0?l00`0000003`3o00l0o`0700l0o`0300000000ROl0
08Wo00<008Wo00@00000003Qo`00hOl000000P00on400`0000000?n9003oR@04003oR@030000000?
o`003ol000H03ol000<000000>[o003Zo`003@3Zo`02000002<0o`000P0000090>[o008000001@0?
o`00100000000?n9003oR@00ohT30000008008Wo00D000000?ooo`3oool0oooo000000010?ooo`00
3P3oool01@000000oooo0?ooo`3oool03ol00080000000<00?n900000000on400P0000030029o`03
0000000?0?l03`3o00<03`3o0P0000090>X0o`D000006`3o000300000100jP3o00<0000000l0o`0?
0?l0200?0?l00`00000008Wo0029o`030029o`0400000000hOl00>7o000000800?oQ00<00000003o
R@00ohT01000ohT00`0000003ol000oo000700oo00030000003Zo`00j_l000h0j_l00`00000K0?l0
00D000002P3Zo`000`0000003ol000oo000400oo000300000000ohT00?n900@000000P00ROl00`00
0000oooo0?ooo`020?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo0`0?o`000`00
00000?n900000003000000<008Wo00<0000000l0o`0?0?l0100?0?l00`000000jP3o0>X0o`0;0>X0
o`@00000503o000300000180jP3o00<0000000l0o`0?0?l02@0?0?l00`00000008Wo0029o`030029
o`0400000000hOl00>7o000000800?oQ00<00000003oR@00ohT01000ohT00`0000003ol000oo0008
00oo00030000003Zo`00j_l00100j_l00`00000D0?l000@000003@3Zo`02000000H03ol000<00000
003oR@00ohT00P0000001P00ool000000029o`00ROl0000000l0o`@0oooo0@0000010?ooo`003P3o
ool010000000oooo0?ooo`3oool300oo000300000000ohT00?n900D000000P00ROl00`0000003`3o
00l0o`0400l0o`8000003`3Z0?l3000000l0o`000P00000D0>X0o`030000000?0?l03`3o00T03`3o
00<000000029o`00ROl01000ROl0100000000>7o003Qo`000002003oh@0300000000ohT00?n900D0
0?n900<0000000oo000?o`00200?o`000`000000j_l00>[o000B0>[o00<000003`3o000200000100
j_l000<0000000oo000?o`001@0?o`000`0000000?n9003oR@0200000003003oo`00000000000080
08Wo00<0000000l0o`3oool00`3oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`@0
3ol000<00000003oR@00ohT00`0000001@00hOl000000029o`00ROl0000000L03`3o00<000000>X0
o`3Z0?l03`3Z0?l?000001H0jP3o00<0000000l0o`0?0?l02@0?0?l00`00000008Wo0029o`040029
o`0400000000hOl00>7o000000800?oQ00<00000003oR@00ohT01@00ohT00`0000003ol000oo0009
00oo00030000003Zo`00j_l001@0j_l03`00000@0>[o008000001`0?o`000`0000000?n9003oR@02
00000003003oo`0000000000008008Wo00<0000000l0o`0?0?l0103oool100000040oooo000>0?oo
o`050000003oool0oooo0?ooo`000000100?o`000`0000000?n9003oR@0300000004003Qo`000000
08Wo0029o`8000001P0?0?l00`000000jP3o0>X0o`0b0>X0o`030000000?0?l03`3o00X03`3o00<0
00000029o`00ROl01000ROl0100000000>7o003Qo`000003003oh@0300000000ohT00?n900@00?n9
00<0000000oo000?o`002P0?o`000`000000j_l00>[o000a0>[o00030000000?o`003ol000D03ol0
0P000002003oR@0300000000on400000008000000P00ROl01@0000003`3o00l0o`0?0?l0000000<0
oooo0@0000010?ooo`003P3oool01P000000oooo0?ooo`3oool0j_l0000000<03ol000T00000003o
R@00ohT00?n900000000on400000003Qo`0000000`00ROl00`0000003`3o00l0o`0400l0o`800000
<@3Z0?l00`0000003`3o00l0o`0:00l0o`0300000000ROl008Wo00D008Wo00@00000003Qo`00hOl0
00000`00on400`0000000?n9003oR@05003oR@030000000?o`003ol000T03ol000<000000>[o003Z
o`00;`3Zo`02000000L03ol000T00000003oR@00ohT00?n900000000on400000003Qo`0000000`00
ROl0100000003`3o00l0o`0000040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo
0P3Zo`00100000003ol000oo000?o`02000000800?n900D00000003oh@0000000>7o000000030029
o`030000000?0?l03`3o00D03`3o0P00000^0>X0o`030000000?0?l03`3o00/03`3o00<000000029
o`00ROl01@00ROl0100000000>7o003Qo`000003003oh@0300000000ohT00?n900D00?n900<00000
00oo000?o`002P0?o`000`000000j_l00>[o000/0>[o008000001`0?o`02000000<00?n900D00000
003oh@0000000>7o000000020029o`8000000`0?0?l00`000000oooo0?ooo`020?ooo`4000000@3o
ool000h0oooo0P0000020?ooo`<0j_l000<0000000oo000?o`000P0?o`00200000000?n9003oR@00
00000?oQ00000000hOl000000`00ROl00`0000003`3o00l0o`0600l0o`800000:`3Z0?l00`000000
3`3o00l0o`0<00l0o`0300000000ROl008Wo00D008Wo00@00000003Qo`00hOl000000`00on400`00
00000?n9003oR@05003oR@030000000?o`003ol000/03ol000<000000>[o003Zo`00:@3Zo`020000
00P03ol000<00000003oR@00ohT00P00ohT01@0000000?oQ00000000hOl00000008008Wo00<00000
00l0o`0?0?l00P0?0?l00`000000jP3o0?ooo`030?ooo`4000000@3oool000h0oooo00@000000?oo
o`3oool0oooo0`3Zo`000`0000003ol000oo000200oo000900000000ohT00?n9003oR@0000000?oQ
00000000hOl0000000<008Wo0P00000800l0o`8000009`3Z0?l2000000h03`3o00<000000029o`00
ROl01P00ROl0100000000>7o003Qo`000003003oh@0300000000ohT00?n900H00?n900<0000000oo
000?o`002`0?o`02000002L0j_l00P00000800oo008000001000ohT01@0000000?oQ00000000hOl0
0000008008Wo00<0000000l0o`0?0?l00`0?0?l00`000000jP3o0?ooo`030?ooo`4000000@3oool0
00h0oooo00@000000?ooo`3oool0oooo103Zo`000`0000003ol000oo000200oo000400000000ohT0
0?n9003oR@<0000000<00>7o00000000ROl00`00ROl00`0000003`3o00l0o`0700l0o`800000903Z
0?l00`0000003`3o00l0o`0>00l0o`0300000000ROl008Wo00D008Wo00D00000003Qo`00hOl00>7o
00000003003oh@0300000000ohT00?n900H00?n900<0000000oo000?o`003@0?o`000`000000j_l0
0>[o000R0>[o008000002@0?o`000`0000000?n9003oR@03003oR@0500000000on400000003Qo`00
00000P00ROl00`0000003`3o00l0o`0300l0o`030000003Z0?l0jP3o00@0oooo0@0000010?ooo`00
3P3oool010000000oooo0?ooo`3oool50>[o00030000000?o`003ol000803ol000D00000003oR@00
ohT00000003oh@0200000003003Qo`00000008Wo00<008Wo00<0000000l0o`0?0?l0200?0?l30000
01l0jP3o0P00000@00l0o`0300000000ROl008Wo00H008Wo00@00000003Qo`00hOl00>7o0P000003
003oh@0300000000ohT00?n900H00?n900<0000000oo000?o`003@0?o`02000001l0j_l00`00000:
00oo000300000000ohT00?n900<00?n900D00000003oh@0000000>7o000000030029o`030000000?
0?l03`3o00803`3o00@000000>X0o`3Z0?l0jP3o103oool100000040oooo000>0?ooo`040000003o
ool0oooo0?ooo`D0j_l000<0000000oo000?o`000P0?o`001P0000000?n9003oR@00ohT00000003o
h@80000000<00>7o00000000ROl00`00ROl2000000/03`3o0`00000J0>X0o`8000004P0?0?l00`00
000008Wo0029o`060029o`0400000000hOl00>7o003Qo`8000000`00on400`0000000?n9003oR@06
003oR@030000000?o`003ol000l03ol00P00000K0>[o00800000300?o`000`0000000?n9003oR@03
003oR@0500000000on400000003Qo`0000000`00ROl00`0000003`3o00l0o`0300l0o`040000003Z
0?l0jP3o0>X0o`@0oooo0@0000010?ooo`001`3oool4000000<0oooo00@000000?ooo`3oool0oooo
1P3Zo`000`0000003ol000oo000200oo000600000000ohT00?n9003oR@0000000?oQ0P0000000`00
hOl000000029o`040029o`030000000?0?l03`3o00/03`3o0`00000D0>X0o`<000004`0?0?l00`00
000008Wo0029o`070029o`0400000000hOl00>7o003Qo`8000000`00on400`0000000?n9003oR@07
003oR@030000000?o`003ol001003ol00`00000E0>[o00<000003@0?o`000`0000000?n9003oR@03
003oR@0500000000on400000003Qo`0000000`00ROl00`0000003`3o00l0o`0300l0o`030000003Z
0?l0jP3o0080jP3o103oool100000040oooo00070?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo000000060>[o00030000000?o`003ol000803ol000@00000003oR@00ohT00?n9
0P0000001000on400000003Qo`0000050029o`030000000?0?l03`3o00d03`3o0`00000>0>X0o`<0
00005@0?0?l00`00000008Wo0029o`080029o`0400000000hOl00>7o003Qo`8000000`00on400`00
00000?n9003oR@08003oR@030000000?o`003ol001803ol00`00000?0>[o00<000003`0?o`000`00
00000?n9003oR@03003oR@0500000000on400000003Qo`0000001000ROl00`0000003`3o00l0o`02
00l0o`030000003Z0?l0jP3o00<0jP3o00D000000?ooo`3oool0oooo000000010?ooo`00203oool0
0`000000oooo0?ooo`030?ooo`8000000P3oool00`3o000000000>[o00040>[o00030000000?o`00
3ol000<03ol000<00000003oR@00ohT00P00ohT01@0000000?oQ00000000hOl0000000D008Wo00<0
000000l0o`0?0?l03`0?0?l>000001P03`3o00<000000029o`00ROl02000ROl0100000000>7o003Q
o`00hOl2000000<00?oQ00<00000003oR@00ohT02000ohT00`0000003ol000oo000E00oo00l00000
400?o`02000000@00?n90P0000001000on400000003Qo`0000040029o`030000000?0?l03`3o00<0
3`3o00<000000>X0o`3Z0?l00`3Z0?l00`000000oooo0?ooo`0200000040oooo00000`3oool00000
00000002000000@0oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`3oool0o`000000
00H0j_l000<0000000oo000?o`000`0?o`000`0000000?n9003oR@02003oR@8000000P00hOl00`00
000008Wo0029o`030029o`030000000?0?l03`3o03<03`3o00<000000029o`00ROl02000ROl00`00
00000>7o003Qo`02003Qo`8000000`00on400`0000000?n9003oR@09003oR@030000000?o`003ol0
03803ol000<00000003oR@00ohT00`00ohT01P0000000?oQ003oh@0000000>7o000000@008Wo00<0
000000l0o`0?0?l00`0?0?l00`000000jP3o0>X0o`030>X0o`030000003oool0oooo0080oooo0@00
00010?ooo`001`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo0?ooo`80o`00
00<000000>[o003Zo`00103Zo`000`0000003ol000oo000200oo000300000000ohT00?n900800?n9
00<00000003oh@0000000P00hOl00`00000008Wo0029o`030029o`800000<`0?0?l00`00000008Wo
0029o`080029o`0300000000hOl00>7o00800>7o0P000004003oh@0300000000ohT00?n900P00?n9
00<0000000oo000?o`00<00?o`02000000D00?n900H00000003oh@00on400000003Qo`0000050029
o`030000000?0?l03`3o00803`3o00<000000>X0o`3Z0?l0103Z0?l00`000000oooo0?ooo`020?oo
o`4000000@3oool000P0oooo0P0000040?ooo`040000003oool0oooo0?ooo`80o`0000<000000>[o
003Zo`00103Zo`000`0000003ol000oo000300oo000300000000ohT00?n900800?n900<00000003o
h@0000000P00hOl00`00000008Wo0029o`040029o`800000<00?0?l00`00000008Wo0029o`090029
o`0300000000hOl00>7o00800>7o0P000004003oh@0300000000ohT00?n900T00?n900<0000000oo
000?o`00;@0?o`02000000H00?n900@00000003oh@00on4000000P00hOl00`00000008Wo0029o`02
0029o`030000000?0?l03`3o00<03`3o00<000000>X0o`3Z0?l00`3Z0?l00`000000o`000?ooo`03
0?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo0`3o00000`000000j_l00>[o0004
0>[o00030000000?o`003ol000<03ol000<00000003oR@00ohT00P00ohT01P0000000?oQ00000000
00000>7o000000L008Wo0P00000]00l0o`0300000000ROl008Wo00T008Wo0P000004003Qo`800000
1000on400`0000000?n9003oR@0:003oR@030000000?o`003ol002X03ol00P000007003oR@040000
0000on400?oQ000000800>7o00<000000029o`00ROl00P00ROl00`0000003`3o00l0o`0300l0o`03
0000003Z0?l0jP3o00@0jP3o00<000000?l0003oool00`3oool100000040oooo000>0?ooo`040000
003oool0oooo0?ooo`<0o`0000<000000>[o003Zo`00103Zo`000`0000003ol000oo000400oo0003
00000000ohT00?n900800?n900D00000003oh@0000000000003Qo`02000000L008Wo0P00000Z00l0
o`0300000000ROl008Wo00X008Wo00<00000003Qo`00hOl00`00hOl2000000@00?oQ00<00000003o
R@00ohT02`00ohT00`0000003ol000oo000X00oo000300000000ohT00?n900D00?n90P000002003o
h@0400000000hOl00>7o000000@008Wo00<0000000l0o`0?0?l00`0?0?l00`000000jP3o0>X0o`04
0>X0o`030000003o0000o`0000@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool4
0?l000030000003Zo`00j_l000@0j_l000<0000000oo000?o`00100?o`001@0000000?n9003oR@00
ohT0000000800?oQ0P000002003Qo`0300000000ROl008Wo00H008Wo00<0000000l0o`0?0?l09@0?
0?l2000000d008Wo00<00000003Qo`00hOl00`00hOl2000000D00?oQ00<00000003oR@00ohT02`00
ohT2000002H03ol00P000007003oR@0500000000on400?oQ003oh@0000000P00hOl00`00000008Wo
0029o`020029o`030000000?0?l03`3o00@03`3o00<000000>X0o`3Z0?l0103Z0?l00`000000o`00
0?l000040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo103o00000`000000j_l0
0>[o00040>[o00030000000?o`003ol000@03ol000<00000003oR@00ohT00P00ohT0100000000?oQ
003oh@000003003Qo`0300000000ROl008Wo00H008Wo0P00000T00l0o`0300000000ROl008Wo00`0
08Wo00<00000003Qo`00hOl01000hOl2000000D00?oQ00<00000003oR@00ohT03@00ohT00`000000
3ol000oo000R00oo000300000000ohT00?n900H00?n900D00000003oh@00on400?oQ00000002003Q
o`0300000000ROl008Wo008008Wo00<0000000l0o`0?0?l0100?0?l00`000000jP3o0>X0o`040>X0
o`040000003o0000o`000?l000@0oooo0@0000010?ooo`003P3oool200000080oooo103o00000`00
0000j_l00>[o00050>[o00030000000?o`003ol000@03ol000<00000003oR@00ohT00P00ohT01000
00000?oQ003oh@000003003Qo`0300000000ROl008Wo00L008Wo00<0000000l0o`0?0?l0800?0?l0
0`00000008Wo0029o`0=0029o`0300000000hOl00>7o00@00>7o0P000005003oh@0300000000ohT0
0?n900h00?n900<0000000oo000?o`007`0?o`02000000P00?n900D00000003oh@00on400?oQ0000
0002003Qo`0300000000ROl008Wo008008Wo00<0000000l0o`0?0?l01@0?0?l00`000000jP3o0>X0
o`040>X0o`040000003o0000o`000?l000@0oooo0@0000010?ooo`003P3oool010000000oooo0?oo
o`3oool50?l000030000003Zo`00j_l000@0j_l000<0000000oo000?o`00100?o`000`0000000?n9
003oR@03003oR@0400000000on400?oQ000000<00>7o00<000000029o`00ROl01`00ROl2000001l0
3`3o00<000000029o`00ROl03P00ROl00`0000000>7o003Qo`04003Qo`8000001P00on400`000000
0?n9003oR@0>003oR@030000000?o`003ol001`03ol00P000009003oR@0500000000on400?oQ003o
h@0000000`00hOl00`00000008Wo0029o`020029o`030000000?0?l03`3o00@03`3o00<000000>X0
o`3Z0?l0103Z0?l00`000000o`000?l000020?l000@0oooo0@0000010?ooo`003P3oool010000000
oooo0?ooo`3oool50?l000030000003Zo`00j_l000D0j_l000<0000000oo000?o`00100?o`000`00
00000?n9003oR@03003oR@0400000000on400?oQ000000<00>7o00<000000029o`00ROl02000ROl5
000001T03`3o00<000000029o`00ROl03`00ROl00`0000000>7o003Qo`04003Qo`8000001P00on40
0`0000000?n9003oR@0?003oR@030000000?o`003ol001L03ol01000000:003oR@0500000000on40
0?oQ003oh@0000000`00hOl00`00000008Wo0029o`020029o`030000000?0?l03`3o00D03`3o00<0
00000>X0o`3Z0?l0103Z0?l00`000000o`000?l000020?l000@0oooo0@0000010?ooo`003P3oool0
10000000oooo0?ooo`3oool50?l000030000003Zo`00j_l000D0j_l000<0000000oo000?o`001@0?
o`000`0000000?n9003oR@03003oR@0400000000on400?oQ000000<00>7o0P00000=0029o`<00000
500?0?l20000018008Wo00<00000003Qo`00hOl01000hOl2000000H00?oQ00<00000003oR@00ohT0
4000ohT2000001@03ol00`00000<003oR@8000000`00on401@0000000>7o003Qo`00hOl0000000@0
08Wo00<0000000l0o`0?0?l01@0?0?l00`000000jP3o0>X0o`050>X0o`030000003o0000o`000080
o`00103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`H0o`0000<000000>[o003Z
o`001@3Zo`000`0000003ol000oo000400oo000300000000ohT00?n900<00?n900D00000003oh@00
on400?oQ00000004003Qo`0300000000ROl008Wo00d008Wo1000000<00l0o`@000004`00ROl00`00
00000>7o003Qo`05003Qo`8000001`00on400`0000000?n9003oR@0A003oR@<000003@0?o`040000
00h00?n900<00000003oh@00on400P00on401@0000000>7o003Qo`00hOl0000000D008Wo00<00000
00l0o`0?0?l01@0?0?l00`000000jP3o0>X0o`050>X0o`030000003o0000o`000080o`00103oool1
00000040oooo000>0?ooo`040000003oool0oooo0?ooo`H0o`0000<000000>[o003Zo`001@3Zo`00
0`0000003ol000oo000500oo000300000000ohT00?n900<00?n900@00000003oh@00on400?oQ0P00
0003003Qo`0300000000ROl008Wo010008Wo3000000G0029o`0300000000hOl00>7o00D00>7o0P00
0007003oh@0300000000ohT00?n901@00?n93@00000A003oR@0400000000on400?oQ003oh@800000
0`00hOl00`00000008Wo0029o`030029o`030000000?0?l03`3o00D03`3o00<000000>X0o`3Z0?l0
1P3Z0?l00`000000o`000?l000020?l000@0oooo0@0000010?ooo`003P3oool010000000oooo0?oo
o`3oool60?l000030000003Zo`00j_l000H0j_l000<0000000oo000?o`00100?o`000`0000000?n9
003oR@04003oR@0400000000on400?oQ003oh@8000000`00hOl00`00000008Wo0029o`0b0029o`03
00000000hOl00>7o00D00>7o0P000007003oh@0300000000ohT00?n903400?n900L00000003oh@00
on400?oQ00000000ool0000000800>7o00<000000029o`00ROl01000ROl00`0000003`3o00l0o`05
00l0o`030000003Z0?l0jP3o00D0jP3o00<000000?l0003o00000`3o00040?ooo`4000000@3oool0
00h0oooo00@000000?ooo`3oool0oooo1`3o00000`000000j_l00>[o00050>[o00030000000?o`00
3ol000D03ol000<00000003oR@00ohT01000ohT0100000000?oQ003oh@00on42000000<00>7o00<0
00000029o`00ROl0<000ROl00`0000000>7o003Qo`06003Qo`8000002000on400`0000000?n9003o
R@0_003oR@0700000000on400?oQ003oh@0000000?oo00000002003Qo`0300000000ROl008Wo00@0
08Wo00<0000000l0o`0?0?l01@0?0?l00`000000jP3o0>X0o`060>X0o`030000003o0000o`0000<0
o`00103oool100000040oooo000>0?ooo`8000000P3oool70?l000030000003Zo`00j_l000H0j_l0
00<0000000oo000?o`001@0?o`000`0000000?n9003oR@04003oR@0500000000on400?oQ003oh@00
00001000hOl20000030008Wo00<00000003Qo`00hOl01P00hOl2000000P00?oQ00<00000003oR@00
ohT0;P00ohT00`0000000?oQ003oh@02003oh@8000000`00hOl00`00000008Wo0029o`040029o`03
0000000?0?l03`3o00D03`3o00<000000>X0o`3Z0?l01P3Z0?l00`000000o`000?l000030?l000@0
oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool70?l000030000003Zo`00j_l000H0
j_l000<0000000oo000?o`001P0?o`000`0000000?n9003oR@04003oR@0500000000on400?oQ003o
h@0000001@00hOl2000002d008Wo00<00000003Qo`00hOl01`00hOl2000000T00?oQ00<00000003o
R@00ohT0:`00ohT2000000@00?oQ00<00000003Qo`00hOl00P00hOl00`00000008Wo0029o`040029
o`030000000?0?l03`3o00H03`3o00<000000>X0o`3Z0?l01P3Z0?l00`000000o`000?l000030?l0
00@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool70?l000030000003Zo`00j_l0
00L0j_l000<0000000oo000?o`001@0?o`000`0000000?n9003oR@05003oR@0500000000on400?oQ
003oh@0000001P00hOl00`00000008Wo0029o`0Z0029o`0300000000hOl00>7o00L00>7o0P000009
003oh@0300000000ohT00?n902X00?n900<00000003oh@00on400`00on400`0000000>7o003Qo`02
003Qo`0300000000ROl008Wo00@008Wo00<0000000l0o`0?0?l01P0?0?l00`000000jP3o0>X0o`06
0>X0o`030000003o0000o`0000@0o`00103oool100000040oooo000>0?ooo`040000003oool0oooo
0?ooo`P0o`0000<000000>[o003Zo`001P3Zo`000`0000003ol000oo000600oo000300000000ohT0
0?n900@00?n900<00000003oh@00on400P00on42000000D00>7o0P00000Y0029o`0300000000hOl0
0>7o00L00>7o00<00000003oo`0000002P00on400`0000000?n9003oR@0W003oR@8000001@00on40
0`0000000>7o003Qo`02003Qo`0300000000ROl008Wo00D008Wo00<0000000l0o`0?0?l01P0?0?l0
0`000000jP3o0>X0o`060>X0o`030000003o0000o`0000@0o`00103oool100000040oooo000>0?oo
o`040000003oool0oooo0?ooo`P0o`0000<000000>[o003Zo`001`3Zo`000`0000003ol000oo0005
00oo000300000000ohT00?n900D00?n900<00000003oh@00on400P00on42000000H00>7o00<00000
0029o`00ROl09@00ROl00`0000000>7o003Qo`08003Qo`0300000000ool0000000X00?oQ00<00000
003oR@00ohT09P00ohT00`0000000?oQ003oh@04003oh@0300000000hOl00>7o00800>7o00<00000
0029o`00ROl01@00ROl00`0000003`3o00l0o`0600l0o`030000003Z0?l0jP3o00H0jP3o00<00000
0?l0003o00001@3o00040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo203o0000
0`000000j_l00>[o00070>[o00030000000?o`003ol000H03ol000<00000003oR@00ohT01@00ohT0
0`0000000?oQ003oh@02003oh@8000001P00hOl00`00000008Wo0029o`0S0029o`0300000000hOl0
0>7o00T00>7o00<00000003oo`0000002`00on400`0000000?n9003oR@0S003oR@8000001@00on42
000000@00>7o00<000000029o`00ROl01@00ROl00`0000003`3o00l0o`0700l0o`030000003Z0?l0
jP3o00H0jP3o00<000000?l0003o00001@3o00040?ooo`4000000@3oool000h0oooo00@000000?oo
o`3oool0oooo203o00000`000000j_l00>[o00070>[o00030000000?o`003ol000H03ol000<00000
003oR@00ohT01P00ohT00`0000000?oQ003oh@02003oh@8000001P00hOl20000028008Wo00<00000
003Qo`00hOl02P00hOl00`0000000?oo0000000<003oh@0300000000ohT00?n902400?n900<00000
003oh@00on401000on400`0000000?oo00000003003Qo`0300000000ROl008Wo00H008Wo00<00000
00l0o`0?0?l01`0?0?l00`000000jP3o0>X0o`060>X0o`030000003o0000o`0000D0o`00103oool1
00000040oooo000>0?ooo`040000003oool0oooo0?ooo`P0o`0000<000000>[o003Zo`001`3Zo`00
0`0000003ol000oo000700oo000300000000ohT00?n900H00?n900<00000003oh@00on400P00on42
000000L00>7o0P00000O0029o`0300000000hOl00>7o00/00>7o00<00000003oo`0000003@00on40
0`0000000?n9003oR@0N003oR@8000001P00on400`0000000?oo00000004003Qo`0300000000ROl0
08Wo00D008Wo00<0000000l0o`0?0?l01`0?0?l00`000000jP3o0>X0o`070>X0o`030000003o0000
o`0000D0o`00103oool100000040oooo000>0?ooo`8000000P3oool80?l000030000003Zo`00j_l0
00L0j_l000<0000000oo000?o`001`0?o`000`0000000?n9003oR@06003oR@0300000000on400?oQ
00<00?oQ0P000008003Qo`0300000000ROl008Wo01`008Wo00<00000003Qo`00hOl02`00hOl00`00
00000?oo0000000>003oh@0300000000ohT00?n901`00?n900<00000003oh@00on401@00on400`00
00000?oo00000004003Qo`0300000000ROl008Wo00H008Wo00<0000000l0o`0?0?l01`0?0?l00`00
0000jP3o0>X0o`070>X0o`030000003o0000o`0000D0o`00103oool100000040oooo000>0?ooo`04
0000003oool0oooo0?ooo`P0o`0000<000000>[o003Zo`00203Zo`000`0000003ol000oo000700oo
000300000000ohT00?n900H00?n900<00000003oh@00on400`00on42000000P00>7o0P00000K0029
o`0300000000hOl00>7o00`00>7o00<00000003oo`0000003`00on400`0000000?n9003oR@0I003o
R@8000002000on42000000@00>7o00<000000029o`00ROl01P00ROl00`0000003`3o00l0o`0800l0
o`030000003Z0?l0jP3o00L0jP3o00<000000?l0003o00001@3o00040?ooo`4000000@3oool000h0
oooo00@000000?ooo`3oool0oooo203o00000`000000j_l00>[o00080>[o00030000000?o`003ol0
00L03ol000<00000003oR@00ohT01`00ohT00`0000000?oQ003oh@03003oh@8000002@00hOl20000
01P008Wo00<00000003Qo`00hOl03@00hOl00`0000000?oo0000000@003oh@0300000000ohT00?n9
01H00?n90P000009003oh@0300000000hOl00>7o00@00>7o00<000000029o`00ROl01P00ROl00`00
00003`3o00l0o`0700l0o`030000003Z0?l0jP3o00P0jP3o00<000000?l0003o00001@3o00040?oo
o`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo203o00000`000000j_l00>[o00080>[o
00030000000?o`003ol000P03ol000<00000003oR@00ohT01`00ohT00`0000000?oQ003oh@03003o
h@8000002P00hOl3000001<008Wo0P00000@003Qo`0300000000ool0000001400?oQ0P00000B003o
R@@000002@00on42000000H00>7o00<000000029o`00ROl01`00ROl00`0000003`3o00l0o`0700l0
o`030000003Z0?l0jP3o00P0jP3o00<000000?l0003o00001@3o00040?ooo`4000000@3oool000h0
oooo00@000000?ooo`3oool0oooo203o00000`000000j_l00>[o00080>[o00030000000?o`003ol0
00P03ol000<00000003oR@00ohT01`00ohT00`0000000?oQ003oh@04003oh@8000003000hOl20000
00l008Wo0P00000B003Qo`0300000000ool0000001<00?oQ0P00000>003oR@8000003000on400`00
00000?oo00000005003Qo`0300000000ROl008Wo00P008Wo00<0000000l0o`0?0?l01`0?0?l00`00
0000jP3o0>X0o`080>X0o`030000003o0000o`0000D0o`00103oool100000040oooo000>0?ooo`04
0000003oool0oooo0?ooo`P0o`0000<000000>[o003Zo`00203Zo`000`0000003ol000oo000900oo
000300000000ohT00?n900L00?n900<00000003oh@00on401000on42000000d00>7o3`00000D003Q
o`0300000000ool0000001D00?oQ3P00000=003oh@0300000000ool0000000H00>7o00<000000029
o`00ROl01`00ROl00`0000003`3o00l0o`0800l0o`030000003Z0?l0jP3o00P0jP3o00<000000?l0
003o00001@3o00040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo203o00000`00
0000j_l00>[o00080>[o00030000000?o`003ol000T03ol000<00000003oR@00ohT01`00ohT00`00
00000?oQ003oh@05003oh@<00000;P00hOl00`0000000?oo0000000_003oh@0300000000ool00000
00H00>7o00<000000029o`00ROl02000ROl00`0000003`3o00l0o`0800l0o`030000003Z0?l0jP3o
00P0jP3o00<000000?l0003o00001@3o00040?ooo`4000000@3oool000h0oooo00@000000?ooo`3o
ool0oooo203o00000`000000j_l00>[o00090>[o00030000000?o`003ol000P03ol000<00000003o
R@00ohT02000ohT00`0000000?oQ003oh@05003oh@0300000000ool0000002d00>7o00@00000003o
o`00ool00000;@00on400`0000000?oo00000006003Qo`0300000000ROl008Wo00T008Wo00<00000
00l0o`0?0?l0200?0?l00`000000jP3o0>X0o`080>X0o`030000003o0000o`0000D0o`00103oool1
00000040oooo000>0?ooo`8000000P3oool80?l000030000003Zo`00j_l000T0j_l000<0000000oo
000?o`002@0?o`000`0000000?n9003oR@07003oR@0300000000on400?oQ00H00?oQ00<00000003o
o`000000;000hOl0100000000?oo003oo`00000/003oh@0300000000ool0000000L00>7o00<00000
0029o`00ROl02000ROl00`0000003`3o00l0o`0900l0o`030000003Z0?l0jP3o00P0jP3o00<00000
0?l0003o00001@3o00040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo203o0000
0`000000j_l00>[o00090>[o00030000000?o`003ol000T03ol000<00000003oR@00ohT02000ohT0
0`0000000?oQ003oh@06003oh@800000;000hOl0100000000?oo003oo`00000[003oh@0300000000
ool0000000L00>7o00<000000029o`00ROl02@00ROl00`0000003`3o00l0o`0900l0o`030000003Z
0?l0jP3o00P0jP3o00<000000?l0003o00001@3o00040?ooo`4000000@3oool000h0oooo00@00000
0?ooo`3oool0oooo203o00000`000000j_l00>[o00090>[o00030000000?o`003ol000T03ol000<0
0000003oR@00ohT02000ohT00`0000000?oQ003oh@07003oh@800000:`00hOl0100000000?oo003o
o`00000Z003oh@0300000000ool0000000L00>7o00<000000029o`00ROl02P00ROl00`0000003`3o
00l0o`0900l0o`030000003Z0?l0jP3o00P0jP3o00<000000?l0003o00001@3o00040?ooo`400000
0@3oool000h0oooo00@000000?ooo`3oool0oooo203o00000`000000j_l00>[o00090>[o00030000
000?o`003ol000T03ol000<00000003oR@00ohT02@00ohT00`0000000?oQ003oh@07003oh@800000
:P00hOl0100000000?oo003oo`00000Y003oh@0300000000ool0000000P00>7o00<000000029o`00
ROl02P00ROl00`0000003`3o00l0o`0900l0o`030000003Z0?l0jP3o00T0jP3o00<000000?l0003o
0000103o00040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo1`3o00000`000000
j_l00>[o00090>[o00030000000?o`003ol000X03ol000<00000003oR@00ohT02@00ohT00`000000
0?oQ003oh@08003oh@800000:000hOl01@0000000?oo003oo`00ool0000002P00?oQ00<00000003o
o`0000002000hOl00`00000008Wo0029o`0:0029o`030000000?0?l03`3o00X03`3o00<000000>X0
o`3Z0?l02@3Z0?l00`000000o`000?l000040?l000@0oooo0@0000010?ooo`003P3oool010000000
oooo0?ooo`3oool70?l000030000003Zo`00j_l000T0j_l000<0000000oo000?o`002P0?o`000`00
00000?n9003oR@0:003oR@0300000000on400?oQ00L00?oQ00<00000003oo`0000009`00hOl01@00
00000?oo003oo`00ool0000002L00?oQ00<00000003oo`0000002@00hOl00`00000008Wo0029o`0:
0029o`030000000?0?l03`3o00X03`3o00<000000>X0o`3Z0?l02@3Z0?l00`000000o`000?l00004
0?l000@0oooo0@0000010?ooo`001`3oool500000080oooo00@000000?ooo`3oool0oooo1`3o0000
0`000000j_l00>[o00090>[o00030000000?o`003ol000X03ol000<00000003oR@00ohT02P00ohT0
0`0000000?oQ003oh@08003oh@0300000000ool0000002H00>7o00D00000003oo`00ool00?oo0000
000V003oh@0300000000ool0000000T00>7o00<000000029o`00ROl02`00ROl00`0000003`3o00l0
o`0:00l0o`030000003Z0?l0jP3o00X0jP3o00<000000?l0003o00000`3o00040?ooo`4000000@3o
ool000T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool70?l000030000003Z
o`00j_l000T0j_l000<0000000oo000?o`002P0?o`000`0000000?n9003oR@0;003oR@0300000000
on400?oQ00P00?oQ00<00000003oo`0000009@00hOl01@0000000?oo003oo`00ool0000002D00?oQ
00<00000003oo`0000002P00hOl00`00000008Wo0029o`0;0029o`030000000?0?l03`3o00X03`3o
00<000000>X0o`3Z0?l02P3Z0?l00`000000o`000?l000030?l000@0oooo0@0000010?ooo`002@3o
ool00`000000oooo0?ooo`020?ooo`8000000P3oool60?l000030000003Zo`00j_l000X0j_l000<0
000000oo000?o`002P0?o`000`0000000?n9003oR@0<003oR@0300000000on400?oQ00P00?oQ00<0
0000003oo`0000009000hOl01@0000000?oo003oo`00ool0000002@00?oQ00<00000003oo`000000
2`00hOl00`00000008Wo0029o`0;0029o`030000000?0?l03`3o00X03`3o00<000000>X0o`3Z0?l0
2P3Z0?l00`000000o`000?l000030?l000<0oooo0P0000010?ooo`0000<0oooo0000000000000P00
00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo1P3o00000`000000j_l0
0>[o000:0>[o00030000000?o`003ol000X03ol000<00000003oR@00ohT03000ohT00`0000000?oQ
003oh@09003oh@0400000000ool00000000002800>7o00<00000003oo`00ool00P00ool00`000000
0?oQ003oh@0O003oh@80000000<00?oo00000000hOl02`00hOl00`00000008Wo0029o`0;0029o`03
0000000?0?l03`3o00/03`3o00<000000>X0o`3Z0?l02P3Z0?l00`000000o`000?l000020?l000@0
oooo0@0000010?ooo`002@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`D0
o`0000<000000>[o003Zo`002P3Zo`000`0000003ol000oo000;00oo000300000000ohT00?n900`0
0?n900<00000003oh@00on402P00on40100000000?oo003oo`00000P003Qo`0300000000ool00?oo
00<00?oo00<00000003oh@00on407P00on40100000000?oo003oo`00000<003Qo`0300000000ROl0
08Wo00`008Wo00<0000000l0o`0?0?l02`0?0?l00`000000jP3o0>X0o`0:0>X0o`030000003o0000
o`000080o`00103oool100000040oooo00080?ooo`800000103oool010000000oooo0?ooo`3oool5
0?l000030000003Zo`00j_l000X0j_l000<0000000oo000?o`002`0?o`000`0000000?n9003oR@0=
003oR@0300000000on400?oQ00T00?oQ00D00000003oo`00ool00?oo0000000O003Qo`0300000000
ool00?oo00<00?oo00<00000003oh@00on407@00on401@0000000?oo003oo`00ool0000000`00>7o
00<000000029o`00ROl03000ROl00`0000003`3o00l0o`0;00l0o`030000003Z0?l0jP3o00X0jP3o
00<000000?l0003o00000P3o00040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo
103o00000`000000j_l00>[o000;0>[o00030000000?o`003ol000/03ol000<00000003oR@00ohT0
3@00ohT00`0000000?oQ003oh@0:003oh@0500000000ool00?oo003oo`0000007P00hOl00`000000
0?oo003oo`04003oo`0300000000on400?oQ01/00?oQ00D00000003oo`00ool00?oo0000000<003Q
o`0300000000ROl008Wo00d008Wo00<0000000l0o`0?0?l0300?0?l00`000000jP3o0>X0o`0:0>X0
o`040000003o0000o`000?l000@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool4
0?l000030000003Zo`00j_l000/0j_l000<0000000oo000?o`002`0?o`000`0000000?n9003oR@0=
003oR@0300000000on400?oQ00/00?oQ00D00000003oo`00ool00?oo0000000M003Qo`0300000000
ool00?oo00@00?oo00<00000003oh@00on406`00on40100000000?oo003oo`00000=003Qo`030000
0000ROl008Wo00d008Wo00<0000000l0o`0?0?l0300?0?l00`000000jP3o0>X0o`0:0>X0o`040000
003o0000o`000?l000@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool30?l00003
0000003Zo`00j_l000/0j_l000<0000000oo000?o`00300?o`000`0000000?n9003oR@0=003oR@03
00000000on400?oQ00`00?oQ0P000002003oo`0300000000hOl00>7o01T00>7o00<00000003oo`00
ool01@00ool00`0000000?oQ003oh@0I003oh@80000000<00?oo0000000000003P00hOl00`000000
08Wo0029o`0=0029o`030000000?0?l03`3o00`03`3o00<000000>X0o`3Z0?l02`3Z0?l00`000000
o`000?l000040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo0P3o00000`000000
j_l00>[o000<0>[o00030000000?o`003ol000`03ol000<00000003oR@00ohT03@00ohT00`000000
0?oQ003oh@0>003oh@0300000000ool00?oo008000006@00hOl00`0000000?oo003oo`06003oo`03
00000000on400?oQ01H00?oQ0P000002003oo`0300000000hOl00>7o00h00>7o00<000000029o`00
ROl03P00ROl00`0000003`3o00l0o`0<00l0o`030000003Z0?l0jP3o00/0jP3o00<000000?l0003o
ool00`3oool100000040oooo000>0?ooo`8000000P3oool20?l000030000003Zo`00j_l000/0j_l0
00<0000000oo000?o`00300?o`000`0000000?n9003oR@0>003oR@0300000000on400?oQ00h00?oQ
00<00000003oo`00ool00P00ool00`0000000>7o003Qo`0E003Qo`0300000000ool00?oo00L00?oo
00<00000003oh@00on405@00on400`0000000?oo003oo`02003oo`0300000000hOl00>7o00h00>7o
00<000000029o`00ROl03P00ROl00`0000003`3o00l0o`0<00l0o`030000003Z0?l0jP3o00/0jP3o
00<000000?l0003oool00`3oool100000040oooo000>0?ooo`060000003oool0oooo0?ooo`3o0000
00003P3Zo`000`0000003ol000oo000<00oo000300000000ohT00?n900l00?n900<00000003oh@00
on403P00on400`0000000?oo003oo`02003oo`0300000000hOl00>7o01@00>7o00<00000003oo`00
ool02000ool00`0000000?oQ003oh@0C003oh@0300000000ool00?oo00800?oo00<00000003Qo`00
hOl03`00hOl00`00000008Wo0029o`0>0029o`030000000?0?l03`3o00d03`3o00<000000>X0o`3Z
0?l02`3Z0?l00`000000oooo0?ooo`020?ooo`4000000@3oool000h0oooo00D000000?ooo`3oool0
oooo0000000>0>[o00030000000?o`003ol000d03ol000<00000003oR@00ohT03`00ohT00`000000
0?oQ003oh@0>003oh@0300000000ool00?oo00<00?oo0P00000C003Qo`0300000000ool00?oo00T0
0?oo00<00000003oh@00on404P00on400`0000000?oo003oo`03003oo`0300000000hOl00>7o00l0
0>7o00<000000029o`00ROl03`00ROl00`0000003`3o00l0o`0<00l0o`030000003Z0?l0jP3o00`0
jP3o00D000000?ooo`3oool0oooo000000010?ooo`003P3oool010000000oooo0?ooo`3oool?0>[o
00030000000?o`003ol000d03ol000<00000003oR@00ohT03`00ohT00`0000000?oQ003oh@0?003o
h@0300000000ool00?oo00@00?oo00<00000003Qo`00hOl04000hOl00`0000000?oo003oo`09003o
o`0300000000on400?oQ01400?oQ00<00000003oo`00ool00`00ool00`0000000>7o003Qo`0@003Q
o`0300000000ROl008Wo00l008Wo00<0000000l0o`0?0?l03@0?0?l00`000000jP3o0>X0o`0;0>X0
o`@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool>0>[o00030000000?o`003ol0
00d03ol000<00000003oR@00ohT04000ohT00`0000000?oQ003oh@0@003oh@0300000000ool00?oo
00@00?oo0`00000=003Qo`8000003@00ool2000000h00?oQ0`000005003oo`0300000000hOl00>7o
01400>7o00<000000029o`00ROl03`00ROl00`0000003`3o00l0o`0>00l0o`030000003Z0?l0jP3o
00X0jP3o103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`d0j_l000<0000000oo
000?o`003P0?o`000`0000000?n9003oR@0@003oR@0300000000on400?oQ01400?oQ00<00000003o
o`00ool01P00ool3000000P00>7o0P00000A003oo`8000002@00on43000000L00?oo00<00000003Q
o`00hOl04P00hOl00`00000008Wo0029o`0@0029o`030000000?0?l03`3o00d03`3o00<000000>X0
o`3Z0?l02P3Z0?l40?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo3@3Zo`000`00
00003ol000oo000=00oo000300000000ohT00?n901000?n900<00000003oh@00on404`00on400`00
00000?oo003oo`08003oo`P000005@00ool9000000T00?oo00<00000003Qo`00hOl04`00hOl00`00
000008Wo0029o`0@0029o`030000000?0?l03`3o00h03`3o00<000000>X0o`3Z0?l02@3Z0?l40?oo
o`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo303Zo`000`0000003ol000oo000=00oo
000300000000ohT00?n901400?n900<00000003oh@00on404`00on400`0000000?oo003oo`0f003o
o`0300000000hOl00>7o01@00>7o00<000000029o`00ROl04@00ROl00`0000003`3o00l0o`0>00l0
o`030000003Z0?l0jP3o00P0jP3o103oool100000040oooo000>0?ooo`8000000P3oool:0>[o0080
0000400?o`000`0000000?n9003oR@0A003oR@0300000000on400?oQ01@00?oQ00<00000003oo`00
ool0=@00ool00`0000000>7o003Qo`0D003Qo`0300000000ROl008Wo018008Wo00<0000000l0o`0?
0?l03P0?0?l2000000P0jP3o103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`T0
j_l000<0000000oo000?o`003`0?o`000`0000000?n9003oR@0B003oR@0300000000on400?oQ01@0
0?oQ00<00000003oo`00ool0=@00ool00`0000000>7o003Qo`0D003Qo`0300000000ROl008Wo01<0
08Wo00<0000000l0o`0?0?l03`0?0?l00`000000jP3o0>X0o`050>X0o`@0oooo0@0000010?ooo`00
3P3oool010000000oooo0?ooo`3oool80>[o00030000000?o`003ol000l03ol000<00000003oR@00
ohT04P00ohT00`0000000?oQ003oh@0F003oh@0300000000ool00?oo03<00?oo00<00000003Qo`00
hOl05P00hOl00`00000008Wo0029o`0C0029o`030000000?0?l03`3o00l03`3o00<000000>X0o`3Z
0?l0103Z0?l40?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo1`3Zo`000`000000
3ol000oo000?00oo000300000000ohT00?n901<00?n900<00000003oh@00on405P00on400`000000
0?oo003oo`0c003oo`0300000000hOl00>7o01H00>7o00<000000029o`00ROl04`00ROl00`000000
3`3o00l0o`0@00l0o`030000003Z0?l0jP3o00<0jP3o103oool100000040oooo000>0?ooo`040000
003oool0oooo0?ooo`H0j_l000<0000000oo000?o`003`0?o`000`0000000?n9003oR@0D003oR@03
00000000on400?oQ01H00?oQ00<00000003oo`00ool0<`00ool00`0000000>7o003Qo`0G003Qo`03
00000000ROl008Wo01<008Wo00<0000000l0o`0?0?l0400?0?l00`000000jP3o0>X0o`020>X0o`@0
oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool40>[o008000004@0?o`000`000000
0?n9003oR@0D003oR@0300000000on400?oQ01P00?oQ00<00000003oo`00ool0<@00ool00`000000
0>7o003Qo`0H003Qo`0300000000ROl008Wo01@008Wo00<0000000l0o`0?0?l0400?0?l200000080
jP3o103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`80j_l00P00000B00oo0003
00000000ohT00?n901@00?n900<00000003oh@00on406@00on400`0000000?oo003oo`0a003oo`03
00000000hOl00>7o01T00>7o00<000000029o`00ROl05000ROl00`0000003`3o00l0o`0A00l0o`03
0000003Z0?l0oooo00<0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool2000001<0
3ol000<00000003oR@00ohT05000ohT00`0000000?oQ003oh@0J003oh@0300000000ool00?oo0340
0?oo00<00000003Qo`00hOl06P00hOl00`00000008Wo0029o`0D0029o`8000004P0?0?l2000000<0
oooo0@0000010?ooo`003P3oool200000080oooo4`0?o`02000001H00?n900<00000003oh@00on40
6`00on400`0000000?oo003oo`0a003oo`0300000000hOl00>7o01/00>7o00<000000029o`00ROl0
5@00ROl2000001403`3o103oool100000040oooo000>0?ooo`040000003oool0oooo0?oooa803ol0
00<00000003oR@00ohT05P00ohT00`0000000?oQ003oh@0K003oh@0300000000ool00?oo03400?oo
00<00000003Qo`00hOl07000hOl00`00000008Wo0029o`0F0029o`030000000?0?l03`3o00h03`3o
103oool100000040oooo000>0?ooo`040000003oool0oooo0?oooa003ol00P00000H003oR@030000
0000on400?oQ01`00?oQ00<00000003oo`00ool0<@00ool00`0000000>7o003Qo`0M003Qo`030000
0000ROl008Wo01H008Wo0P00000>00l0o`@0oooo0@0000010?ooo`003P3oool010000000oooo0?oo
o`3oool>00oo008000006@00ohT00`0000000?oQ003oh@0M003oh@0300000000ool00?oo03400?oo
00<00000003Qo`00hOl07P00hOl00`00000008Wo0029o`0G0029o`800000300?0?l40?ooo`400000
0@3oool000h0oooo00@000000?ooo`3oool0oooo2`0?o`03000001T00?n90P00000P003oh@030000
0000ool00?oo03400?oo00<00000003Qo`00hOl07`00hOl2000001T008Wo0`00000900l0o`@0oooo
0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool800oo00<000006P00ohT2000002400?oQ
00<00000003oo`00ool0<P00ool00`0000000>7o003Qo`0Q003Qo`8000006P00ROl3000000H03`3o
103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`D03ol00`00000J003oR@<00000
8`00on400`0000000?oo003oo`0c003oo`0300000000hOl00>7o02800>7o0P00000K0029o`<00000
0`0?0?l40?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo0P0?o`03000001X00?n9
0`00000U003oh@0300000000ool00?oo03@00?oo00<00000003Qo`00hOl09000hOl3000001/008Wo
0P0000000`0?0?l0oooo0?ooo`020?ooo`4000000@3oool000h0oooo0P0000020?ooo`8000006P00
ohT3000002P00?oQ00<00000003oo`00ool0=@00ool00`0000000>7o003Qo`0V003Qo`<000006P00
ROl2000000<0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3ooolJ003oR@800000:P00
on400`0000000?oo003oo`0f003oo`0300000000hOl00>7o02T00>7o0`00000H0029o`@0oooo0@00
00010?ooo`003P3oool010000000oooo0?ooo`3ooolE003oR@D00000:P00on43000003T00?oo0`00
000[003Qo`@000005000ROl40?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo4000
ohT5000002d00?oQ0P00000o003oo`800000;@00hOl6000000h008Wo103oool100000040oooo000>
0?ooo`040000003oool0oooo0?ooo`X00?n91P00000_003oh@<00000@`00ool3000003000>7o1P00
00080029o`@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool:000003800?oQ0`00
0019003oo`<00000<`00hOl9000000<0oooo0@0000010?ooo`00203oool2000000@0oooo00@00000
0?ooo`3oool0oooo<`00on49000004l00?oo2P00000a003Qo`@0oooo0@0000010?ooo`001`3oool0
10000000oooo0?ooo`0000030?ooo`040000003oool0oooo0?oooaD00?oQ7P00001R003ooad00000
5000hOl40?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool000000`3oool200000080oooo
9P00001k003oobH000000P3oool200000040oooo00070?ooo`040000003oool0oooo000000<0oooo
00@000000?ooo`3oool0oooo9P00hOlB000005P00?oo4@00000U003oh@@0oooo0@0000010?ooo`00
1`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo0?ooo`<00000=@00hOl50000
04d00?oo1P00000d003oh@<000000`3oool100000040oooo00080?ooo`800000103oool010000000
oooo0?ooo`3oool30029o``00000;P00hOl4000004D00?oo1000000_003oh@/000000P00ohT40?oo
o`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo3`00ROl6000002`00>7o0P000011003o
o`800000;@00on46000000d00?n9103oool100000040oooo000>0?ooo`040000003oool0oooo0?oo
oaD008Wo0`00000[003Qo`800000?@00ool2000002/00?oQ1000000C003oR@@0oooo0@0000010?oo
o`003P3oool010000000oooo0?ooo`3ooolH0029o`<00000:P00hOl2000003T00?oo0P00000[003o
h@<000005P00ohT40?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo6`00ROl40000
02P00>7o00<00000003oo`00ool0=@00ool00`0000000?oQ003oh@0V003oh@D000006@00ohT40?oo
o`4000000@3oool000h0oooo0P0000020?ooo`<000007000ROl3000002D00>7o00<00000003oo`00
ool0=@00ool00`0000000?oQ003oh@0S003oh@<000007000ohT3000000<0oooo0@0000010?ooo`00
3P3oool010000000oooo0?ooo`3oool300l0o`D000006P00ROl2000002@00>7o00<00000003oo`00
ool0<`00ool00`0000000?oQ003oh@0R003oh@8000006`00ohT4000000803ol0103oool100000040
oooo000>0?ooo`040000003oool0oooo0?ooo`P03`3o0`00000I0029o`8000008P00hOl00`000000
0?oo003oo`0c003oo`0300000000on400?oQ02000?oQ0P00000J003oR@<000001P0?o`040?ooo`40
00000@3oool000h0oooo00@000000?ooo`3oool0oooo2`0?0?l2000001T008Wo0P00000Q003Qo`03
00000000ool00?oo03400?oo00<00000003oh@00on408000on400`0000000?n9003oR@0G003oR@<0
00002@0?o`040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo3@0?0?l2000001T0
08Wo00<00000003Qo`00hOl07P00hOl00`0000000?oo003oo`0a003oo`0300000000on400?oQ01l0
0?oQ00<00000003oR@00ohT05P00ohT2000000`03ol0103oool100000040oooo000>0?ooo`040000
003oool0oooo0?ooo`l03`3o0P00000H0029o`0300000000hOl00>7o01d00>7o00<00000003oo`00
ool0<@00ool00`0000000?oQ003oh@0N003oh@0300000000ohT00?n901D00?n90P00000>00oo00@0
oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3ooolA00l0o`8000005`00ROl00`000000
0>7o003Qo`0L003Qo`0300000000ool00?oo03400?oo00<00000003oh@00on407@00on400`000000
0?n9003oR@0E003oR@030000000?o`003ol000h03ol0103oool100000040oooo000>0?ooo`040000
003oool0oooo0?oooa<03`3o00<000000029o`00ROl05@00ROl00`0000000>7o003Qo`0K003Qo`03
00000000ool00?oo03400?oo00<00000003oh@00on406`00on42000001H00?n90P00000A00oo00@0
oooo0@0000010?ooo`003P3oool200000080oooo00<0000000l0o`0?0?l04@0?0?l2000001H008Wo
00<00000003Qo`00hOl06P00hOl00`0000000?oo003oo`0a003oo`0300000000on400?oQ01X00?oQ
00<00000003oR@00ohT05000ohT2000001<03ol000D000000?ooo`3oool0oooo000000010?ooo`00
3P3oool01@000000oooo0?ooo`3oool0jP3o008000004`0?0?l00`00000008Wo0029o`0D0029o`03
00000000hOl00>7o01T00>7o00<00000003oo`00ool0<@00ool00`0000000?oQ003oh@0I003oh@03
00000000ohT00?n901@00?n900<0000000oo000?o`004@0?o`02000000@0oooo0@0000010?ooo`00
3P3oool010000000oooo0?ooo`3oool30>X0o`030000000?0?l03`3o01403`3o00<000000029o`00
ROl05000ROl00`0000000>7o003Qo`0H003Qo`0300000000ool00?oo03400?oo00<00000003oh@00
on406000on400`0000000?n9003oR@0D003oR@030000000?o`003ol001403ol000<000000>[o003Z
o`00103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`@0jP3o0P00000B00l0o`03
00000000ROl008Wo01@008Wo00<00000003Qo`00hOl05P00hOl00`0000000?oo003oo`0c003oo`03
00000000on400?oQ01L00?oQ00<00000003oR@00ohT04`00ohT00`0000003ol000oo000A00oo0004
0000003Zo`00j_l00>[o00@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool60>X0
o`030000000?0?l03`3o01003`3o00<000000029o`00ROl04`00ROl00`0000000>7o003Qo`0F003Q
o`0300000000ool00?oo03<00?oo00<00000003oh@00on405P00on400`0000000?n9003oR@0C003o
R@030000000?o`003ol001403ol000<000000>[o003Zo`000P3Zo`040?ooo`4000000@3oool000h0
oooo00@000000?ooo`3oool0oooo1`3Z0?l00`0000003`3o00l0o`0@00l0o`0300000000ROl008Wo
018008Wo00<00000003Qo`00hOl05P00hOl00`0000000?oo003oo`0c003oo`0300000000on400?oQ
01H00?oQ00<00000003oR@00ohT04`00ohT00`0000003ol000oo000@00oo00030000003Zo`00j_l0
00<0j_l0103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`P0jP3o0P00000A00l0
o`0300000000ROl008Wo018008Wo00<00000003Qo`00hOl05000hOl00`0000000?oo003oo`0e003o
o`0300000000on400?oQ01@00?oQ00<00000003oR@00ohT04`00ohT00`0000003ol000oo000?00oo
008000001P3Zo`040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo2P3Z0?l00`00
00003`3o00l0o`0?00l0o`0300000000ROl008Wo014008Wo00<00000003Qo`00hOl05000hOl00`00
00000?oo003oo`0e003oo`0300000000on400?oQ01@00?oQ00<00000003oR@00ohT04P00ohT00`00
00003ol000oo000?00oo00030000003Zo`00j_l000H0j_l0103oool100000040oooo000>0?ooo`80
00000P3oool;0>X0o`030000000?0?l03`3o00h03`3o00<000000029o`00ROl04@00ROl00`000000
0>7o003Qo`0C003Qo`0300000000ool00?oo03H00?oo00<00000003oh@00on405000on400`000000
0?n9003oR@0A003oR@030000000?o`003ol000l03ol000<000000>[o003Zo`001`3Zo`040?ooo`40
00000@3oool000h0oooo00@000000?ooo`3oool0oooo303Z0?l00`0000003`3o00l0o`0>00l0o`03
00000000ROl008Wo010008Wo00<00000003Qo`00hOl04`00hOl00`0000000?oo003oo`0g003oo`03
00000000on400?oQ01<00?oQ00<00000003oR@00ohT04000ohT00`0000003ol000oo000?00oo0003
0000003Zo`00j_l000P0j_l0103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`d0
jP3o00<0000000l0o`0?0?l03@0?0?l00`00000008Wo0029o`0@0029o`0300000000hOl00>7o0180
0>7o00<00000003oo`00ool02@00ool8000001H00?oo2000000:003oo`0300000000on400?oQ0180
0?oQ00<00000003oR@00ohT04000ohT00`0000003ol000oo000>00oo00030000003Zo`00j_l000T0
j_l0103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`d0jP3o00<0000000l0o`0?
0?l03P0?0?l00`00000008Wo0029o`0@0029o`0300000000hOl00>7o01000>7o00<00000003oo`00
ool01`00ool3000000P00?oQ0P00000B003oo`8000002000hOl3000000L00?oo00<00000003oh@00
on404P00on400`0000000?n9003oR@0?003oR@030000000?o`003ol000h03ol000<000000>[o003Z
o`002P3Zo`040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo3P3Z0?l00`000000
3`3o00l0o`0=00l0o`0300000000ROl008Wo010008Wo00<00000003Qo`00hOl04000hOl00`000000
0?oo003oo`05003oo`8000003@00on42000000h00?oo0P00000=003Qo`8000001P00ool00`000000
0?oQ003oh@0A003oh@0300000000ohT00?n900l00?n900<0000000oo000?o`003P0?o`000`000000
j_l00>[o000:0>[o00@0oooo0@0000010?ooo`003P3oool01@000000oooo0?ooo`3oool0000000h0
jP3o00<0000000l0o`0?0?l03@0?0?l00`00000008Wo0029o`0?0029o`0300000000hOl00>7o00l0
0>7o00<00000003oo`00ool01000ool2000001400?oQ00<00000003oo`00ool02@00ool200000140
0>7o0P000005003oo`0300000000on400?oQ01000?oQ00<00000003oR@00ohT03`00ohT00`000000
3ol000oo000=00oo00030000003Zo`00j_l000/0j_l000D000000?ooo`3oool0oooo000000010?oo
o`003P3oool01P000000oooo0?ooo`3oool0o`00000000h0jP3o00<0000000l0o`0?0?l0300?0?l0
0`00000008Wo0029o`0?0029o`0300000000hOl00>7o00h00>7o00<00000003oo`00ool01000ool0
0`0000000?oQ003oh@0A003oh@0300000000ool00?oo00T00?oo00<00000003Qo`00hOl04P00hOl0
0`0000000?oo003oo`03003oo`0300000000on400?oQ00l00?oQ00<00000003oR@00ohT03`00ohT0
0`0000003ol000oo000<00oo00030000003Zo`00j_l000/0j_l000<000000?ooo`3oool00P3oool1
00000040oooo000>0?ooo`060000003oool0oooo0?ooo`3o000000003P3Z0?l00`0000003`3o00l0
o`0<00l0o`0300000000ROl008Wo00l008Wo00<00000003Qo`00hOl03@00hOl00`0000000?oo003o
o`03003oo`8000005@00on400`0000000?oo003oo`08003oo`0300000000hOl00>7o01<00>7o00<0
0000003oo`00ool00P00ool00`0000000?oQ003oh@0?003oh@0300000000ohT00?n900h00?n900<0
000000oo000?o`003@0?o`000`000000j_l00>[o000;0>[o00030000003oool0oooo0080oooo0@00
00010?ooo`003P3oool200000080oooo0P3o00000`000000jP3o0>X0o`0<0>X0o`030000000?0?l0
3`3o00/03`3o00<000000029o`00ROl03P00ROl00`0000000>7o003Qo`0>003Qo`0300000000ool0
0?oo00800?oo00<00000003oh@00on405@00on400`0000000?oo003oo`07003oo`0300000000hOl0
0>7o01D00>7o00<00000003oo`00ool00P00ool00`0000000?oQ003oh@0>003oh@0300000000ohT0
0?n900h00?n900<0000000oo000?o`00300?o`000`000000j_l00>[o000;0>[o00030000003o0000
oooo00<0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool30?l000030000003Z0?l0
jP3o00/0jP3o00<0000000l0o`0?0?l0300?0?l00`00000008Wo0029o`0=0029o`0300000000hOl0
0>7o00d00>7o00<00000003oo`00ool00P00ool00`0000000?oQ003oh@0G003oh@0300000000ool0
0?oo00H00?oo00<00000003Qo`00hOl05P00hOl2000000<00?oo00<00000003oh@00on403@00on40
0`0000000?n9003oR@0>003oR@030000000?o`003ol000`03ol000<000000>[o003Zo`002P3Zo`00
0`000000o`000?l000040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo0`3o0000
0`000000jP3o0>X0o`0<0>X0o`030000000?0?l03`3o00/03`3o00<000000029o`00ROl03@00ROl0
0`0000000>7o003Qo`0<003Qo`0400000000ool00?oo003oo`8000006P00on400`0000000?oo003o
o`05003oo`0300000000hOl00>7o01T00>7o0P000002003oo`0300000000on400?oQ00`00?oQ00<0
0000003oR@00ohT03@00ohT00`0000003ol000oo000<00oo00030000003Zo`00j_l000/0j_l000<0
00000?l0003o0000103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`@0o`0000<0
00000>X0o`3Z0?l02`3Z0?l00`0000003`3o00l0o`0;00l0o`0300000000ROl008Wo00d008Wo00<0
0000003Qo`00hOl02`00hOl01@0000000?oo003oo`00ool0000001d00?oQ00<00000003oo`00ool0
1000ool00`0000000>7o003Qo`0K003Qo`0400000000ool00?oo000000d00?oQ00<00000003oR@00
ohT03@00ohT00`0000003ol000oo000<00oo00030000003Zo`00j_l000X0j_l000@000000?l0003o
0000o`00103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`@0o`0000<000000>X0
o`3Z0?l02`3Z0?l00`0000003`3o00l0o`0;00l0o`0300000000ROl008Wo00d008Wo00<00000003Q
o`00hOl02P00hOl01@0000000?oo003oo`00ool0000001h00?oQ00<00000003oo`00ool01000ool0
0`0000000>7o003Qo`0K003Qo`0500000000ool00?oo003oo`0000003000on400`0000000?n9003o
R@0=003oR@030000000?o`003ol000`03ol000<000000>[o003Zo`002P3Zo`0010000000o`000?l0
003o00040?ooo`4000000@3oool000L0oooo1@0000020?ooo`040000003oool0oooo0?ooo`D0o`00
00<000000>X0o`3Z0?l02P3Z0?l00`0000003`3o00l0o`0;00l0o`0300000000ROl008Wo00`008Wo
00<00000003Qo`00hOl02P00hOl01@0000000?oo003oo`00ool0000001l00?oQ00<00000003oo`00
ool00`00ool00`0000000>7o003Qo`0M003Qo`0500000000ool00?oo003oo`0000003000on400`00
00000?n9003oR@0<003oR@030000000?o`003ol000/03ol000<000000>[o003Zo`002P3Zo`000`00
0000o`000?l000020?l000@0oooo0@0000010?ooo`002@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo0?ooo`D0o`0000<000000>X0o`3Z0?l02P3Z0?l00`0000003`3o00l0o`0;00l0
o`0300000000ROl008Wo00`008Wo00<00000003Qo`00hOl02P00hOl0100000000?oo003oo`00000P
003oh@0300000000ool00?oo00<00?oo00<00000003Qo`00hOl07P00hOl0100000000?oo003oo`00
000<003oh@0300000000ohT00?n900`00?n900<0000000oo000?o`002`0?o`000`000000j_l00>[o
000:0>[o00030000003o0000o`000080o`00103oool100000040oooo00090?ooo`030000003oool0
oooo0080oooo0P0000020?ooo`H0o`0000<000000>X0o`3Z0?l02P3Z0?l00`0000003`3o00l0o`0:
00l0o`0300000000ROl008Wo00`008Wo00<00000003Qo`00hOl02@00hOl0100000000?oo00000000
000R003oh@0300000000ool00?oo00800?oo00<00000003Qo`00hOl07`00hOl200000003003oo`00
00000?oQ00/00?oQ00<00000003oR@00ohT02`00ohT00`0000003ol000oo000;00oo00030000003Z
o`00j_l000X0j_l000<000000?l0003o00000P3o00030?ooo`8000000@3oool000T0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`3oool60?l000030000003Z0?l0jP3o00X0jP3o00<0
000000l0o`0?0?l02P0?0?l00`00000008Wo0029o`0;0029o`0300000000hOl00>7o00T00>7o00<0
0000003oo`0000009000on401@0000000?oo003oo`00ool0000002@00>7o00<00000003oo`000000
2`00on400`0000000?n9003oR@0;003oR@030000000?o`003ol000X03ol000<000000>[o003Zo`00
2P3Zo`000`000000o`000?l000030?l000@0oooo0@0000010?ooo`002@3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo0?ooo`L0o`0000<000000>X0o`3Z0?l02@3Z0?l00`0000003`3o
00l0o`0:00l0o`0300000000ROl008Wo00/008Wo00<00000003Qo`00hOl02000hOl00`0000000?oo
0000000U003oh@0500000000ool00?oo003oo`0000009@00hOl00`0000000?oo0000000:003oh@03
00000000ohT00?n900/00?n900<0000000oo000?o`002P0?o`000`000000j_l00>[o000:0>[o0003
0000003o0000o`0000<0o`00103oool100000040oooo00080?ooo`800000103oool010000000oooo
0?ooo`3oool70?l000030000003Z0?l0jP3o00T0jP3o00<0000000l0o`0?0?l02P0?0?l00`000000
08Wo0029o`0:0029o`0300000000hOl00>7o00P00>7o00<00000003oo`0000009P00on401@000000
0?oo003oo`00ool0000002H00>7o00<00000003oo`0000002P00on400`0000000?n9003oR@0:003o
R@030000000?o`003ol000X03ol000<000000>[o003Zo`002P3Zo`000`000000o`000?l000030?l0
00@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool70?l000030000003Z0?l0jP3o
00T0jP3o00<0000000l0o`0?0?l02P0?0?l00`00000008Wo0029o`0:0029o`0300000000hOl00>7o
00L00>7o00<00000003oo`0000009`00on401@0000000?oo003oo`00ool0000002L00>7o00<00000
003oo`0000002@00on400`0000000?n9003oR@0:003oR@030000000?o`003ol000X03ol000<00000
0>[o003Zo`002@3Zo`000`000000o`000?l000040?l000@0oooo0@0000010?ooo`003P3oool01000
0000oooo0?ooo`3oool80?l000030000003Z0?l0jP3o00T0jP3o00<0000000l0o`0?0?l02@0?0?l0
0`00000008Wo0029o`090029o`0300000000hOl00>7o00P00>7o0P00000Y003oh@0400000000ool0
0?oo000002P00>7o0`000009003oh@0300000000ohT00?n900X00?n900<0000000oo000?o`002@0?
o`000`000000j_l00>[o00090>[o00030000003o0000o`0000@0o`00103oool100000040oooo000>
0?ooo`040000003oool0oooo0?ooo`P0o`0000<000000>X0o`3Z0?l02@3Z0?l00`0000003`3o00l0
o`0900l0o`0300000000ROl008Wo00T008Wo00<00000003Qo`00hOl01`00hOl00`0000000?oQ003o
h@0Y003oh@0400000000ool00?oo000002X00>7o0P000008003oh@0300000000ohT00?n900X00?n9
00<0000000oo000?o`002@0?o`000`000000j_l00>[o00080>[o00030000003o0000o`0000D0o`00
103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`P0o`0000<000000>X0o`3Z0?l0
2@3Z0?l00`0000003`3o00l0o`0900l0o`0300000000ROl008Wo00P008Wo00<00000003Qo`00hOl0
1P00hOl2000002`00?oQ00@00000003oo`00ool00000:`00hOl3000000L00?oQ00<00000003oR@00
ohT02@00ohT00`0000003ol000oo000900oo00030000003Zo`00j_l000P0j_l000<000000?l0003o
00001@3o00040?ooo`4000000@3oool000h0oooo0P0000020?ooo`P0o`0000<000000>X0o`3Z0?l0
2@3Z0?l00`0000003`3o00l0o`0900l0o`0300000000ROl008Wo00P008Wo00<00000003Qo`00hOl0
1@00hOl00`0000000?oo0000000/003oh@0400000000ool00?oo000002`00>7o00<00000003oo`00
00001`00on400`0000000?n9003oR@08003oR@030000000?o`003ol000T03ol000<000000>[o003Z
o`00203Zo`000`000000o`000?l000050?l000@0oooo0@0000010?ooo`003P3oool010000000oooo
0?ooo`3oool80?l000030000003Z0?l0jP3o00T0jP3o00<0000000l0o`0?0?l0200?0?l00`000000
08Wo0029o`080029o`0300000000hOl00>7o00D00>7o00<00000003oo`000000;@00on4010000000
0?oo003oo`00000]003Qo`0300000000ool0000000H00?oQ00<00000003oR@00ohT02@00ohT00`00
00003ol000oo000800oo00030000003Zo`00j_l000P0j_l000<000000?l0003o00001@3o00040?oo
o`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo203o00000`000000jP3o0>X0o`080>X0
o`030000000?0?l03`3o00T03`3o00<000000029o`00ROl02000ROl00`0000000>7o003Qo`04003Q
o`0300000000ool0000002h00?oQ00<00000003oo`000000;`00hOl2000000L00?oQ00<00000003o
R@00ohT02000ohT00`0000003ol000oo000800oo00030000003Zo`00j_l000P0j_l000<000000?l0
003o00001@3o00040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo203o00000`00
0000jP3o0>X0o`080>X0o`030000000?0?l03`3o00T03`3o00<000000029o`00ROl01`00ROl00`00
00000>7o003Qo`05003Qo`8000004@00on45000001T00?oQ00<00000003oo`0000006@00hOl50000
01800>7o0P000006003oh@0300000000ohT00?n900P00?n900<0000000oo000?o`00200?o`000`00
0000j_l00>[o00080>[o00030000003o0000o`0000D0o`00103oool100000040oooo000>0?ooo`04
0000003oool0oooo0?ooo`P0o`0000<000000>X0o`3Z0?l0203Z0?l00`0000003`3o00l0o`0800l0
o`0300000000ROl008Wo00P008Wo00<00000003Qo`00hOl01000hOl00`0000000?oQ003oh@0<003o
h@D000001@00ohT5000001@00?oQ00<00000003oo`0000005@00hOl4000000D008Wo1P00000=003Q
o`8000001P00on400`0000000?n9003oR@08003oR@030000000?o`003ol000L03ol000<000000>[o
003Zo`00203Zo`000`000000o`000?l000050?l000@0oooo0@0000010?ooo`003P3oool010000000
oooo0?ooo`3oool80?l000030000003Z0?l0jP3o00P0jP3o00<0000000l0o`0?0?l0200?0?l00`00
000008Wo0029o`070029o`0300000000hOl00>7o00<00>7o0P00000<003oh@<000003`00ohT30000
01400?oQ00<00000003oo`0000004P00hOl3000000l008Wo0`00000;003Qo`8000001P00on400`00
00000?n9003oR@07003oR@030000000?o`003ol000L03ol000<000000>[o003Zo`00203Zo`000`00
0000o`000?l000050?l000@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool80?l0
00030000003Z0?l0jP3o00P0jP3o00<0000000l0o`0?0?l01`0?0?l00`00000008Wo0029o`070029
o`0300000000hOl00>7o00<00>7o00<00000003oo`0000002P00on42000001D00?n900<00000003o
h@00on403P00on400`0000000?oo0000000A003Qo`0300000000ROl008Wo01<008Wo00<00000003Q
o`00hOl02@00hOl2000000H00?oQ00<00000003oR@00ohT01P00ohT00`0000003ol000oo000700oo
00030000003Zo`00j_l000P0j_l000<000000?l0003o00001@3o00040?ooo`4000000@3oool000h0
oooo00@000000?ooo`3oool0oooo203o00000`000000jP3o0>X0o`080>X0o`030000000?0?l03`3o
00L03`3o00<000000029o`00ROl01P00ROl00`0000000>7o003Qo`03003Qo`0300000000ool00000
00T00?oQ0P00000H003oR@0300000000on400?oQ00d00?oQ00<00000003oo`0000004000hOl00`00
000008Wo0029o`0E0029o`8000002P00hOl2000000D00?oQ00<00000003oR@00ohT01P00ohT00`00
00003ol000oo000800oo00030000003Zo`00j_l000L0j_l000<000000?l0003o00001@3o00040?oo
o`4000000@3oool000h0oooo0P0000020?ooo`P0o`0000<000000>X0o`3Z0?l01`3Z0?l00`000000
3`3o00l0o`0700l0o`0300000000ROl008Wo00H008Wo00<00000003Qo`00hOl00`00hOl00`000000
0?oo00000008003oh@8000006`00ohT00`0000000?oQ003oh@0<003oh@0300000000ool0000000l0
0>7o00<000000029o`00ROl06000ROl2000000T00>7o0P000005003oh@0300000000ohT00?n900D0
0?n900<0000000oo000?o`00200?o`000`000000j_l00>[o00070>[o00030000003o0000o`0000D0
o`00103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`P0o`0000<000000>X0o`3Z
0?l01`3Z0?l00`0000003`3o00l0o`0700l0o`0300000000ROl008Wo00H008Wo00<00000003Qo`00
hOl00`00hOl2000000L00?oQ0P00000N003oR@0300000000on400?oQ00/00?oQ00<00000003oo`00
00003@00hOl2000001d008Wo0P000008003Qo`8000001@00on400`0000000?n9003oR@05003oR@03
0000000?o`003ol000L03ol000<000000>[o003Zo`001`3Zo`000`000000o`000?l000050?l000@0
oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool80?l000030000003Z0?l0jP3o00L0
jP3o00<0000000l0o`0?0?l01P0?0?l00`00000008Wo0029o`060029o`0300000000hOl00>7o00<0
0>7o00<00000003oh@00on401@00on42000002400?n900<00000003oh@00on402P00on400`000000
0?oo0000000<003Qo`0300000000ROl008Wo01l008Wo0P000007003Qo`8000001000on400`000000
0?n9003oR@05003oR@030000000?o`003ol000P03ol000<000000>[o003Zo`001P3Zo`000`000000
o`000?l000050?l000@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool80?l00003
0000003Z0?l0jP3o00L0jP3o00<0000000l0o`0?0?l01P0?0?l00`00000008Wo0029o`050029o`03
00000000hOl00>7o00800>7o0P000006003oh@8000009000ohT00`0000000?oQ003oh@09003oh@03
00000000ool0000000/00>7o00<000000029o`00ROl08P00ROl2000000H00>7o0P000004003oh@03
00000000ohT00?n900D00?n900<0000000oo000?o`001`0?o`000`000000j_l00>[o00060>[o0003
0000003o0000o`0000D0o`00103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`P0
o`0000<000000>X0o`3Z0?l01`3Z0?l00`0000003`3o00l0o`0500l0o`0300000000ROl008Wo00H0
08Wo00L00000003Qo`00hOl00>7o00000000ool0000000D00?oQ00<00000003oR@00ohT09@00ohT0
0`0000000?oQ003oh@08003oh@0300000000ool0000000X00>7o00<000000029o`00ROl09@00ROl2
000000D00>7o0P000003003oh@0300000000ohT00?n900H00?n900<0000000oo000?o`001P0?o`00
0`000000j_l00>[o00060>[o00030000003o0000o`0000D0o`00103oool100000040oooo000>0?oo
o`040000003oool0oooo0?ooo`P0o`0000<000000>X0o`3Z0?l01P3Z0?l00`0000003`3o00l0o`06
00l0o`0300000000ROl008Wo00D008Wo00L00000003Qo`00hOl00>7o00000000ool0000000D00?oQ
00<00000003oR@00ohT09`00ohT00`0000000?oQ003oh@07003oh@0300000000ool0000000X00>7o
00<000000029o`00ROl09`00ROl00`0000000>7o003Qo`03003Qo`8000000`00on400`0000000?n9
003oR@05003oR@030000000?o`003ol000L03ol000<000000>[o003Zo`001P3Zo`000`000000o`00
0?l000040?l000@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool70?l000030000
003Z0?l0jP3o00L0jP3o00<0000000l0o`0?0?l01@0?0?l00`00000008Wo0029o`050029o`070000
0000hOl00>7o003Qo`0000000?oo00000005003oh@0300000000ohT00?n902P00?n900<00000003o
h@00on401`00on400`0000000?oo00000009003Qo`0300000000ROl008Wo02T008Wo00<00000003Q
o`00hOl00`00hOl00`0000000?oQ003oh@02003oh@0300000000ohT00?n900D00?n900<0000000oo
000?o`001P0?o`000`000000j_l00>[o00060>[o00030000003o0000o`0000@0o`00103oool10000
0040oooo000>0?ooo`040000003oool0oooo0?ooo`L0o`0000<000000>X0o`3Z0?l01`3Z0?l00`00
00003`3o00l0o`0500l0o`0300000000ROl008Wo00D008Wo00@00000003Qo`00hOl00>7o0P000004
003oh@800000;000ohT00`0000000?oQ003oh@07003oh@8000002@00hOl00`00000008Wo0029o`0Z
0029o`8000001000hOl00`0000000?oQ003oh@02003oh@0300000000ohT00?n900D00?n900<00000
00oo000?o`001@0?o`000`000000j_l00>[o00060>[o00030000003o0000o`0000@0o`00103oool1
00000040oooo000>0?ooo`8000000P3oool70?l000030000003Z0?l0jP3o00H0jP3o00<0000000l0
o`0?0?l01@0?0?l00`00000008Wo0029o`050029o`0500000000hOl00>7o003Qo`0000001@00on40
0`0000000?n9003oR@0/003oR@0300000000on400?oQ00L00?oQ0P000008003Qo`0300000000ROl0
08Wo02d008Wo00<00000003Qo`00hOl00P00hOl00`0000000?oQ003oh@02003oh@0300000000ohT0
0?n900@00?n900<0000000oo000?o`001P0?o`000`000000j_l00>[o00060>[o00030000003o0000
o`0000<0o`00103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`L0o`0000<00000
0>X0o`3Z0?l01P3Z0?l00`0000003`3o00l0o`0500l0o`0300000000ROl008Wo00@008Wo00D00000
003Qo`00hOl00>7o00000004003oh@800000<000ohT00`0000000?oQ003oh@06003oh@8000002000
hOl00`00000008Wo0029o`0^0029o`0300000000hOl00>7o00800>7o0P000003003oh@0300000000
ohT00?n900@00?n900<0000000oo000?o`001@0?o`000`000000j_l00>[o00060>[o00030000003o
0000o`0000<0o`00103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`L0o`0000<0
00000>X0o`3Z0?l01@3Z0?l00`0000003`3o00l0o`0500l0o`0300000000ROl008Wo00@008Wo00D0
0000003Qo`00hOl00>7o00000004003oh@0300000000ohT00?n903000?n900<00000003oh@00on40
1P00on42000000P00>7o00<000000029o`00ROl0;`00ROl00`0000000>7o003Qo`02003Qo`800000
0P00on400`0000000?n9003oR@04003oR@030000000?o`003ol000D03ol000<000000>[o003Zo`00
1P3Zo`000`000000o`000?l000030?l000@0oooo0@0000010?ooo`003P3oool010000000oooo0?oo
o`3oool60?l000030000003Z0?l0jP3o00H0jP3o00<0000000l0o`0?0?l0100?0?l00`00000008Wo
0029o`040029o`0500000000hOl00>7o003Qo`0000000`00on42000003@00?n900<00000003oh@00
on401@00on42000000L00>7o00<000000029o`00ROl0<@00ROl2000000<00>7o0P000002003oh@03
00000000ohT00?n900@00?n900<0000000oo000?o`001@0?o`000`000000j_l00>[o00050>[o0003
0000003o0000o`0000<0o`00103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`H0
o`0000<000000>X0o`3Z0?l01@3Z0?l00`0000003`3o00l0o`0500l0o`0300000000ROl008Wo00<0
08Wo00D00000003Qo`00hOl00>7o00000003003oh@0300000000ohT00?n900d00?n93`00000H003o
R@0300000000on400?oQ00D00?oQ0P000007003Qo`0300000000ROl008Wo01D008Wo4000000>0029
o`0500000000hOl00>7o003Qo`0000000`00on400`0000000?n9003oR@03003oR@030000000?o`00
3ol000D03ol000<000000>[o003Zo`001P3Zo`000`000000o`000?l000020?l000@0oooo0@000001
0?ooo`003P3oool010000000oooo0?ooo`3oool60?l000030000003Z0?l0jP3o00D0jP3o00<00000
00l0o`0?0?l0100?0?l00`00000008Wo0029o`030029o`0500000000hOl00>7o003Qo`0000000`00
on400`0000000?n9003oR@0;003oR@<000003`0?o`04000001@00?n900<00000003oh@00on401@00
on42000000L00>7o00<000000029o`00ROl04@00ROl4000001003`3o0`00000<0029o`0500000000
hOl00>7o003Qo`0000000`00on400`0000000?n9003oR@03003oR@030000000?o`003ol000D03ol0
00<000000>[o003Zo`001@3Zo`000`000000o`000?l000020?l000@0oooo0@0000010?ooo`003P3o
ool010000000oooo0?ooo`3oool50?l000030000003Z0?l0jP3o00D0jP3o00<0000000l0o`0?0?l0
1@0?0?l00`00000008Wo0029o`030029o`0400000000hOl00>7o000000<00?oQ00<00000003oR@00
ohT02P00ohT2000001H03ol00P00000C003oR@0300000000on400?oQ00@00?oQ0P000006003Qo`03
00000000ROl008Wo010008Wo0P00000G00l0o`8000002`00ROl01@0000000>7o003Qo`00hOl00000
00<00?oQ00<00000003oR@00ohT00P00ohT00`0000003ol000oo000500oo00030000003Zo`00j_l0
00D0j_l000<000000?l0003o00000P3o00040?ooo`4000000@3oool000h0oooo00@000000?ooo`3o
ool0oooo1@3o00000`000000jP3o0>X0o`050>X0o`030000000?0?l03`3o00@03`3o00<000000029
o`00ROl00`00ROl0100000000>7o003Qo`000003003oh@0300000000ohT00?n900T00?n90P00000J
00oo008000004@00ohT00`0000000?oQ003oh@04003oh@8000001P00hOl00`00000008Wo0029o`0?
0029o`030000000?0?l03`3o01T03`3o0P00000:0029o`0500000000hOl00>7o003Qo`0000000`00
on400`0000000?n9003oR@02003oR@030000000?o`003ol000D03ol000<000000>[o003Zo`00103Z
o`000`000000o`000?l000020?l000@0oooo0@0000010?ooo`003P3oool200000080oooo1@3o0000
0`000000jP3o0>X0o`040>X0o`030000000?0?l03`3o00@03`3o00<000000029o`00ROl00`00ROl0
100000000>7o003Qo`000003003oh@0300000000ohT00?n900P00?n90P00000N00oo008000003`00
ohT00`0000000?oQ003oh@04003oh@8000001P00hOl00`00000008Wo0029o`0=0029o`8000007P0?
0?l2000000T008Wo00D00000003Qo`00hOl00>7o00000003003oh@0300000000ohT00?n900800?n9
00<0000000oo000?o`00100?o`000`000000j_l00>[o00040>[o00030000003o0000o`000080o`00
103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`@0o`0000<000000>X0o`3Z0?l0
1@3Z0?l00`0000003`3o00l0o`0400l0o`0300000000ROl008Wo008008Wo00@00000003Qo`00hOl0
00000P00on42000000T00?n90P00000R00oo000300000000ohT00?n900`00?n900<00000003oh@00
on401000on42000000D00>7o00<000000029o`00ROl03@00ROl00`0000003`3o00l0o`0P00l0o`80
00002000ROl2000000800>7o00@00000003oh@00on4000001@00ohT00`0000003ol000oo000400oo
00030000003Zo`00j_l000@0j_l000@000000?l0003o0000o`00103oool100000040oooo000>0?oo
o`040000003oool0oooo0?ooo`@0o`0000<000000>X0o`3Z0?l0103Z0?l00`0000003`3o00l0o`04
00l0o`0300000000ROl008Wo008008Wo00@00000003Qo`00000000000P00on400`0000000?n9003o
R@07003oR@8000009@0?o`000`0000000?n9003oR@0<003oR@0300000000on400?oQ00<00?oQ0P00
0005003Qo`0300000000ROl008Wo00`008Wo00<0000000l0o`0?0?l08`0?0?l2000000P008Wo00<0
0000003Qo`00hOl00P0000000`00on400000003oR@04003oR@030000000?o`003ol000<03ol000<0
00000>[o003Zo`00103Zo`0010000000o`000?l0003o00040?ooo`4000000@3oool000h0oooo00@0
00000?ooo`3oool0oooo103o00000`000000jP3o0>X0o`040>X0o`030000000?0?l03`3o00<03`3o
00<000000029o`00ROl00P00ROl01`0000000>7o00000000ool00000003oh@0000002000ohT20000
02P03ol000<00000003oR@00ohT02`00ohT00`0000000?oQ003oh@03003oh@8000001000hOl00`00
000008Wo0029o`0<0029o`030000000?0?l03`3o02H03`3o0P0000070029o`0300000000hOl00>7o
0080000000<00?oQ00000000ohT01000ohT00`0000003ol000oo000300oo00030000003Zo`00j_l0
00@0j_l000<000000?l0003o0000103oool100000040oooo000>0?ooo`040000003oool0oooo0?oo
o`<0o`0000<000000>X0o`3Z0?l0103Z0?l00`0000003`3o00l0o`0400l0o`0300000000ROl008Wo
008008Wo0P0000001000ool00000003oh@000007003oR@800000:`0?o`000`0000000?n9003oR@0:
003oR@0300000000on400?oQ00<00?oQ0P000004003Qo`0300000000ROl008Wo00/008Wo00<00000
00l0o`0?0?l0:@0?0?l00`00000008Wo0029o`050029o`0300000000hOl00>7o0080000000<00?oQ
00000000ohT00`00ohT00`0000003ol000oo000300oo00030000003Zo`00j_l000@0j_l000<00000
0?l0003o0000103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`<0o`0000<00000
0>X0o`3Z0?l0103Z0?l00`0000003`3o00l0o`0300l0o`0300000000ROl008Wo008008Wo00H00000
003Qo`0000000000003oh@000007003oR@030000000?o`003ol002`03ol000<00000003oR@00ohT0
2P00ohT00`0000000?oQ003oh@02003oh@8000001000hOl00`00000008Wo0029o`0:0029o`030000
000?0?l03`3o02/03`3o00<000000029o`00ROl01@00ROl0100000000>7o003Qo`000002003oh@03
00000000ohT00?n900800?n900<0000000oo000?o`000`0?o`000`000000j_l00>[o00040>[o0003
0000003o0000oooo00<0oooo0@0000010?ooo`001`3oool4000000<0oooo00@000000?ooo`3oool0
oooo0P3o00000`000000jP3o0>X0o`040>X0o`030000000?0?l03`3o00<03`3o00<000000029o`00
ROl00P00ROl0100000000>7o00000000on42000000H00?n90P00000`00oo000300000000ohT00?n9
00T00?n900<00000003oh@00on400P00on42000000@00>7o00<000000029o`00ROl02@00ROl00`00
00003`3o00l0o`0]00l0o`8000001P00ROl200000005003Qo`0000000?oQ003oh@0000001000ohT0
0`0000003ol000oo000300oo00030000003Zo`00j_l000<0j_l000<000000?l0003oool00`3oool1
00000040oooo00070?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P3o0000
0`000000jP3o0>X0o`030>X0o`030000000?0?l03`3o00<03`3o00<000000029o`00ROl00P00ROl0
1@0000000>7o00000000on40000000H00?n90P00000c00oo000300000000ohT00?n900P00?n900<0
0000003oh@00on400P00on42000000@00>7o00<000000029o`00ROl02000ROl00`0000003`3o00l0
o`0`00l0o`8000001P00ROl00`0000000>7o00000002003oh@0300000000ohT00?n900800?n900<0
000000oo000?o`000`0?o`000`000000j_l00>[o00030>[o00030000003oool0oooo0080oooo0@00
00010?ooo`00203oool00`000000oooo0?ooo`030?ooo`8000000P3oool00`3o000000000>X0o`05
0>X0o`030000000?0?l03`3o00<03`3o00T000000029o`00ROl008Wo00000000hOl00000003oh@00
00001P00ohT00`0000003ol000oo000C00oo00D000006`0?o`000`0000000?n9003oR@09003oR@04
00000000on400?oQ003oh@8000000`00hOl00`00000008Wo0029o`080029o`030000000?0?l03`3o
01X03`3o1@00000D00l0o`0300000000ROl008Wo00@008Wo00H00000003Qo`0000000000003oh@00
0003003oR@030000000?o`003ol000<03ol000<000000>[o003Zo`000`3Zo`0010000000oooo0?oo
o`3oool200000040oooo00090?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool0oooo
0?l0000000050>X0o`030000000?0?l03`3o00<03`3o00<000000029o`00ROl00P0000001000hOl0
0000003oh@000005003oR@800000400?o`06000000D0j_l01@00000G00oo000300000000ohT00?n9
00P00?n900@00000003oh@00on400?oQ0P000003003Qo`0300000000ROl008Wo00P008Wo00<00000
00l0o`0?0?l0500?0?l6000000D0jP3o1P00000?00l0o`8000001@00ROl200000004003Qo`000000
0?oQ000000<00?n900<0000000oo000?o`000`0?o`000`000000j_l00>[o00030>[o00050000003o
ool0oooo0?ooo`0000000@3oool000L0oooo00@000000?ooo`3oool000000`3oool01@000000oooo
0?ooo`3oool0000000D0jP3o00<0000000l0o`0?0?l00P0?0?l20000008008Wo00H00000003Qo`00
00000000003oh@000005003oR@030000000?o`003ol000/03ol01@00000@0>[o00D000004`0?o`00
0`0000000?n9003oR@07003oR@0400000000on400?oQ003oh@8000000`00hOl00`00000008Wo0029
o`070029o`030000000?0?l03`3o01403`3o1000000A0>X0o`D00000300?0?l2000000D008Wo00D0
0000003Qo`0000000?oQ00000003003oR@030000000?o`003ol000<03ol000<000000>[o003Zo`00
0P3Zo`001@000000oooo0?ooo`3oool000000040oooo00080?ooo`800000103oool010000000oooo
0?ooo`3oool60>X0o`050000000?0?l03`3o00l0o`0000000`00ROl0100000000>7o00000000ool2
000000@00?n90P00000;00oo00<000006P3Zo`02000001403ol000<00000003oR@00ohT01`00ohT0
100000000?oQ003oh@00on42000000<00>7o00<000000029o`00ROl01P00ROl00`0000003`3o00l0
o`0@00l0o`8000006P3Z0?l2000000`03`3o00<000000029o`00ROl00`00ROl300000003003oh@00
00000?n900800?n900<0000000oo000?o`000P0?o`000`000000j_l00>[o00020>[o00@0oooo0@00
00010?ooo`003P3oool010000000oooo0?ooo`3oool50>X0o`030000000?0?l03`3o00803`3o00X0
00000029o`00ROl00000003Qo`0000000?oo00000000on4000000`00ohT00`0000003ol000oo0009
00oo008000007`3Zo`02000001003ol000<00000003oR@00ohT01P00ohT0100000000?oQ003oh@00
on42000000<00>7o00<000000029o`00ROl01P00ROl00`0000003`3o00l0o`0>00l0o`8000007P3Z
0?l2000000/03`3o00<000000029o`00ROl00P00ROl01P0000000>7o0000000000000?oQ000000<0
0?n900<0000000oo000?o`000P0?o`0010000000j_l00>[o003Zo`040?ooo`4000000@3oool000h0
oooo00@000000?ooo`3oool0oooo103Z0?l00`0000003`3o00l0o`0200l0o`0400000000ROl008Wo
0029o`80000000@00?oo00000000on4000000`00ohT00`0000003ol000oo000800oo008000008`3Z
o`000`0000003ol000oo000=00oo000300000000ohT00?n900H00?n900D00000003oh@00on400?oQ
00000003003Qo`0300000000ROl008Wo00H008Wo00<0000000l0o`0?0?l03@0?0?l200000280jP3o
0P00000:00l0o`0300000000ROl008Wo008008Wo00H00000003Qo`0000000000003oh@000002003o
R@030000000?o`003ol000<03ol000<000000>[o003Zo`00103oool100000040oooo000>0?ooo`04
0000003oool0oooo0?ooo`@0jP3o00D0000000l0o`0?0?l03`3o000000030029o`0600000000hOl0
000000000000on4000000P00ohT2000000T03ol00P00000V0>[o00030000000?o`003ol000d03ol0
00<00000003oR@00ohT01P00ohT0100000000?oQ003oh@000003003Qo`0300000000ROl008Wo00H0
08Wo00<0000000l0o`0?0?l0300?0?l00`000000jP3o0>X0o`0T0>X0o`8000002@0?0?l2000000<0
08Wo00H00000003Qo`0000000000003oh@000002003oR@030000000?o`003ol000803ol000<00000
0>[o003Zo`00103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`<0jP3o00<00000
00l0o`0?0?l00P0?0?l01`00000008Wo0029o`0000000>7o00000000on400P000002003oR@030000
000?o`003ol000L03ol00P00000Y0>[o008000003@0?o`000`0000000?n9003oR@06003oR@040000
0000on400?oQ000000<00>7o00<000000029o`00ROl01@00ROl00`0000003`3o00l0o`0;00l0o`80
0000:@3Z0?l2000000T03`3o00@000000029o`00ROl008Wo0P0000001000hOl00000003oh@000002
003oR@030000000?o`003ol000803ol000<000000>[o003oool00`3oool100000040oooo000>0?oo
o`8000000P3oool20>X0o`030000000?0?l03`3o00803`3o00P000000029o`00ROl00000003Qo`00
00000?oQ000000<00?n900<0000000oo000?o`001P0?o`02000002d0j_l000<0000000oo000?o`00
2`0?o`000`0000000?n9003oR@05003oR@0400000000on400?oQ000000<00>7o00<000000029o`00
ROl01@00ROl00`0000003`3o00l0o`0:00l0o`030000003Z0?l0jP3o02/0jP3o0P00000800l0o`03
00000000ROl008Wo008008Wo00D00000003Qo`0000000?oQ00000002003oR@030000000?o`003ol0
00803ol000<000000?ooo`3oool00P3oool100000040oooo000>0?ooo`060000003oool0oooo0?oo
o`3Z0?l00000100?0?l02000000008Wo0029o`0000000>7o00000000on4000001000ohT00`000000
3ol000oo000400oo00800000<03Zo`000`0000003ol000oo000:00oo000300000000ohT00?n900D0
0?n900@00000003oh@00on4000000`00hOl00`00000008Wo0029o`050029o`030000000?0?l03`3o
00T03`3o00<000000>X0o`3Z0?l0;P3Z0?l2000000L03`3o00<000000029o`00ROl00P00ROl01@00
00000>7o00000000on40000000800?n900D0000000oo000?o`003ol0000000040?ooo`4000000@3o
ool000h0oooo00H000000?ooo`3oool0oooo0>X0o`00000300l0o`0800000000ROl008Wo00000000
hOl00000003oh@000003003oR@8000001@0?o`02000003<0j_l000<0000000oo000?o`002P0?o`00
0`0000000?n9003oR@04003oR@0400000000on400?oQ000000<00>7o00<000000029o`00ROl01000
ROl00`0000003`3o00l0o`0:00l0o`030000003Z0?l0jP3o0300jP3o0P00000600l0o`8000000`00
ROl01@0000000>7o00000000on40000000800?n900D0000000oo000?o`003ol0000000030?ooo`40
00000@3oool000h0oooo00D000000?ooo`3oool0oooo0000000300l0o`0400000000ROl008Wo0029
o`80000000<00?oQ00000000ohT00P00ohT00`0000003ol000oo000400oo00030000003Zo`00j_l0
03@0j_l000<0000000oo000?o`002@0?o`000`0000000?n9003oR@04003oR@0400000000on400?oQ
000000800>7o00<000000029o`00ROl01@00ROl00`0000003`3o00l0o`0900l0o`030000003Z0?l0
jP3o03<0jP3o0P00000600l0o`0400000000ROl008Wo0029o`@000000`00ohT0100000003ol000oo
000000030?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo100?0?l00`00000008Wo
0029o`04000000800?n90P00000500oo008000004@3Zo`0A000001D0j_l000<0000000oo000?o`00
2@0?o`000`0000000?n9003oR@04003oR@0400000000on400?oQ000000800>7o00<000000029o`00
ROl01@00ROl00`0000003`3o00l0o`0800l0o`030000003Z0?l0jP3o01@0jP3o4@00000A0>X0o`03
0000000?0?l03`3o00@03`3o0P0000020029o`@000000P00ohT00`0000003ol000oo00040?ooo`40
00000@3oool000h0oooo00@000000?ooo`3oool0oooo0`0?0?l00`00000008Wo0029o`03000000<0
0?n900<0000000oo000?o`00100?o`000`000000j_l00>[o000<0>[o00D000004@3o0003000001<0
j_l000<0000000oo000?o`002@0?o`000`0000000?n9003oR@03003oR@0400000000on400?oQ0000
00800>7o00<000000029o`00ROl01000ROl00`0000003`3o00l0o`0800l0o`030000003Z0?l0jP3o
0140jP3o1000000A0?l000@000003P3Z0?l2000000H03`3o00<000000029o`00ROl010000002003o
R@030000000?o`00oooo00<0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool200l0
o`0300000000ROl0000000<000000`00ohT00`0000003ol000oo000300oo00800000303Zo`030000
01T0o`000P00000B0>[o00030000000?o`003ol000P03ol000<00000003oR@00ohT00`00ohT01000
00000?oQ003oh@000002003Qo`0300000000ROl008Wo00@008Wo00<0000000l0o`0?0?l01`0?0?l0
0`000000jP3o0>X0o`0@0>X0o`8000006@3o0003000000d0jP3o00<0000000l0o`0?0?l0100?0?l0
0`00000008Wo0029o`04000000800?n900<000000?ooo`3oool00P3oool100000040oooo000>0?oo
o`090000003oool0oooo0?ooo`0?0?l000000029o`0000000>7o008000000`00ohT00`0000003ol0
00oo000300oo00030000003Zo`00j_l000T0j_l00`00000N0?l0008000004@3Zo`000`0000003ol0
00oo000700oo000300000000ohT00?n900<00?n900@00000003oh@00on4000000P00hOl00`000000
08Wo0029o`040029o`030000000?0?l03`3o00H03`3o00<000000>X0o`3Z0?l03`3Z0?l2000001h0
o`000`00000;0>X0o`8000001@0?0?l01@00000008Wo0029o`0000000>7o0080000000<00?n90000
003oool00`3oool100000040oooo000>0?ooo`8000000P3oool02000000008Wo00000000hOl00000
003oh@0000000?n90P00000400oo008000002@3Zo`03000002<0o`000P00000?0>[o00030000000?
o`003ol000L03ol000<00000003oR@00ohT00`00ohT0100000000?oQ003oh@000002003Qo`030000
0000ROl008Wo00<008Wo00<0000000l0o`0?0?l01`0?0?l00`000000jP3o0>X0o`0=0>X0o`800000
8`3o0003000000X0jP3o00<0000000l0o`0?0?l00`0?0?l2000000030029o`0000000>7o00800000
00<00?n90000003oool00P3oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`8008Wo
0P0000001000on400000003oR@00000500oo00030000003Zo`00j_l000L0j_l00P00000X0?l00080
00003P3Zo`000`0000003ol000oo000600oo000300000000ohT00?n900<00?n900@00000003oh@00
on4000000P00hOl00`00000008Wo0029o`030029o`030000000?0?l03`3o00H03`3o00<000000>X0
o`3Z0?l03@3Z0?l00`000000o`000?l0000V0?l0008000002@3Z0?l2000000D03`3o00<000000029
o`0000000P0000000`00ohT0oooo0?ooo`020?ooo`4000000@3oool000h0oooo00D000000?ooo`3o
ool0oooo0029o`0400000003003oR@0000003ol000@03ol000<000000>[o003Zo`001P3Zo`020000
02`0o`0000<000000>[o003Zo`00303Zo`000`0000003ol000oo000600oo000300000000ohT00?n9
00<00?n900<00000003oh@0000000P00hOl00`00000008Wo0029o`030029o`030000000?0?l03`3o
00H03`3o00<000000>X0o`3Z0?l02`3Z0?l2000002/0o`000P0000090>X0o`030000000?0?l03`3o
00<03`3o00<000000029o`0000000P0000040?ooo`4000000@3oool000h0oooo00@000000?ooo`3o
ool0oooo0`000002003oR@030000000?o`003ol000803ol00P0000070>[o00800000;`3o00020000
00`0j_l000<0000000oo000?o`001P0?o`000`0000000?n9003oR@03003oR@0300000000on400000
00800>7o00<000000029o`00ROl00P00ROl00`0000003`3o00l0o`0600l0o`030000003Z0?l0jP3o
00/0jP3o00<000000?l0003o0000;@3o0002000000P0jP3o00<0000000l0o`0?0?l00P0?0?l00`00
000008Wo0029o`03000000<0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool20000
00800?n900<0000000oo000?o`000P0?o`000`000000j_l00>[o00060>[o00030000003o0000o`00
0340o`0000<000000>[o003Zo`002P3Zo`000`0000003ol000oo000500oo000300000000ohT00?n9
00<00?n900<00000003oh@0000000P00hOl00`00000008Wo0029o`020029o`030000000?0?l03`3o
00H03`3o00<000000>X0o`3Z0?l02P3Z0?l00`000000o`000?l0000`0?l000030000003Z0?l0jP3o
00H0jP3o00<0000000l0o`0?0?l00P0?0?l00`00000008Wo0029o`02000000<0oooo0@0000010?oo
o`003P3oool00`000000oooo0?ooo`3;0?ooo`4000000@3oool000h0oooo00<000000?ooo`3oool0
b`3oool100000040oooo000>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool100000040oooo000>0?oooll000000@3oool00=h0oooo0000\
\>"],
    ImageRangeCache->{{{0, 221}, {221, 0}} -> {-2, -2, 0, 0}}],
  StyleBox["               ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.192308 0.5 0.192308 [
[.11538 -0.0125 -6 -9 ]
[.11538 -0.0125 6 0 ]
[.30769 -0.0125 -6 -9 ]
[.30769 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -3 -9 ]
[.69231 -0.0125 3 0 ]
[.88462 -0.0125 -3 -9 ]
[.88462 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11538 -12 -4.5 ]
[-0.0125 .11538 0 4.5 ]
[-0.0125 .30769 -12 -4.5 ]
[-0.0125 .30769 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .69231 -6 -4.5 ]
[-0.0125 .69231 0 4.5 ]
[-0.0125 .88462 -6 -4.5 ]
[-0.0125 .88462 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-2)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-1)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(1)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(2)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11538 m
.00625 .11538 L
s
[(-2)] -0.0125 .11538 1 0 Mshowa
0 .30769 m
.00625 .30769 L
s
[(-1)] -0.0125 .30769 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .69231 m
.00625 .69231 L
s
[(1)] -0.0125 .69231 1 0 Mshowa
0 .88462 m
.00625 .88462 L
s
[(2)] -0.0125 .88462 1 0 Mshowa
.125 Mabswid
0 .15385 m
.00375 .15385 L
s
0 .19231 m
.00375 .19231 L
s
0 .23077 m
.00375 .23077 L
s
0 .26923 m
.00375 .26923 L
s
0 .34615 m
.00375 .34615 L
s
0 .38462 m
.00375 .38462 L
s
0 .42308 m
.00375 .42308 L
s
0 .46154 m
.00375 .46154 L
s
0 .53846 m
.00375 .53846 L
s
0 .57692 m
.00375 .57692 L
s
0 .61538 m
.00375 .61538 L
s
0 .65385 m
.00375 .65385 L
s
0 .73077 m
.00375 .73077 L
s
0 .76923 m
.00375 .76923 L
s
0 .80769 m
.00375 .80769 L
s
0 .84615 m
.00375 .84615 L
s
0 .07692 m
.00375 .07692 L
s
0 .03846 m
.00375 .03846 L
s
0 .92308 m
.00375 .92308 L
s
0 .96154 m
.00375 .96154 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11538 m
1 .11538 L
s
.99375 .30769 m
1 .30769 L
s
.99375 .5 m
1 .5 L
s
.99375 .69231 m
1 .69231 L
s
.99375 .88462 m
1 .88462 L
s
.125 Mabswid
.99625 .15385 m
1 .15385 L
s
.99625 .19231 m
1 .19231 L
s
.99625 .23077 m
1 .23077 L
s
.99625 .26923 m
1 .26923 L
s
.99625 .34615 m
1 .34615 L
s
.99625 .38462 m
1 .38462 L
s
.99625 .42308 m
1 .42308 L
s
.99625 .46154 m
1 .46154 L
s
.99625 .53846 m
1 .53846 L
s
.99625 .57692 m
1 .57692 L
s
.99625 .61538 m
1 .61538 L
s
.99625 .65385 m
1 .65385 L
s
.99625 .73077 m
1 .73077 L
s
.99625 .76923 m
1 .76923 L
s
.99625 .80769 m
1 .80769 L
s
.99625 .84615 m
1 .84615 L
s
.99625 .07692 m
1 .07692 L
s
.99625 .03846 m
1 .03846 L
s
.99625 .92308 m
1 .92308 L
s
.99625 .96154 m
1 .96154 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.129 0 1 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.035 0 1 r
.01923 .6998 m
.02464 .69796 L
.04751 .68824 L
.07579 .67669 L
.09266 .66968 L
.10407 .6652 L
.13235 .6538 L
.16063 .64243 L
.16287 .6414 L
.18891 .63135 L
.21719 .6204 L
.23529 .61312 L
.24548 .60987 L
.27376 .60006 L
.30204 .59111 L
.32644 .58484 L
.33032 .58414 L
.3586 .58116 L
.38567 .58484 L
.38688 .5853 L
.4147 .61312 L
.41516 .61433 L
.41884 .6414 L
.41586 .66968 L
.41516 .67356 L
.40889 .69796 L
.39994 .72624 L
.39013 .75452 L
.38688 .76471 L
.3796 .78281 L
.36865 .81109 L
.3586 .83713 L
.35757 .83937 L
.3462 .86765 L
.3348 .89593 L
.33032 .90734 L
.32331 .92421 L
.31176 .95249 L
.30204 .97536 L
.3002 .98077 L
.01923 .98077 L
F
0 g
.01923 .6998 m
.02464 .69796 L
.04751 .68824 L
.07579 .67669 L
.09266 .66968 L
.10407 .6652 L
.13235 .6538 L
.16063 .64243 L
.16287 .6414 L
.18891 .63135 L
.21719 .6204 L
.23529 .61312 L
.24548 .60987 L
.27376 .60006 L
.30204 .59111 L
.32644 .58484 L
.33032 .58414 L
.3586 .58116 L
.38567 .58484 L
.38688 .5853 L
.4147 .61312 L
.41516 .61433 L
.41884 .6414 L
.41586 .66968 L
.41516 .67356 L
.40889 .69796 L
.39994 .72624 L
.39013 .75452 L
.38688 .76471 L
.3796 .78281 L
.36865 .81109 L
.3586 .83713 L
.35757 .83937 L
.3462 .86765 L
.3348 .89593 L
.33032 .90734 L
.32331 .92421 L
.31176 .95249 L
.30204 .97536 L
.3002 .98077 L
s
.035 0 1 r
.01923 .3002 m
.02464 .30204 L
.04751 .31176 L
.07579 .32331 L
.09266 .33032 L
.10407 .3348 L
.13235 .3462 L
.16063 .35757 L
.16287 .3586 L
.18891 .36865 L
.21719 .3796 L
.23529 .38688 L
.24548 .39013 L
.27376 .39994 L
.30204 .40889 L
.32644 .41516 L
.33032 .41586 L
.3586 .41884 L
.38567 .41516 L
.38688 .4147 L
.4147 .38688 L
.41516 .38567 L
.41884 .3586 L
.41586 .33032 L
.41516 .32644 L
.40889 .30204 L
.39994 .27376 L
.39013 .24548 L
.38688 .23529 L
.3796 .21719 L
.36865 .18891 L
.3586 .16287 L
.35757 .16063 L
.3462 .13235 L
.3348 .10407 L
.33032 .09266 L
.32331 .07579 L
.31176 .04751 L
.30204 .02464 L
.3002 .01923 L
.01923 .01923 L
F
0 g
.01923 .3002 m
.02464 .30204 L
.04751 .31176 L
.07579 .32331 L
.09266 .33032 L
.10407 .3348 L
.13235 .3462 L
.16063 .35757 L
.16287 .3586 L
.18891 .36865 L
.21719 .3796 L
.23529 .38688 L
.24548 .39013 L
.27376 .39994 L
.30204 .40889 L
.32644 .41516 L
.33032 .41586 L
.3586 .41884 L
.38567 .41516 L
.38688 .4147 L
.4147 .38688 L
.41516 .38567 L
.41884 .3586 L
.41586 .33032 L
.41516 .32644 L
.40889 .30204 L
.39994 .27376 L
.39013 .24548 L
.38688 .23529 L
.3796 .21719 L
.36865 .18891 L
.3586 .16287 L
.35757 .16063 L
.3462 .13235 L
.3348 .10407 L
.33032 .09266 L
.32331 .07579 L
.31176 .04751 L
.30204 .02464 L
.3002 .01923 L
s
.223 0 1 r
.01923 .69848 m
.02081 .69796 L
.04751 .68667 L
.07579 .67477 L
.08751 .66968 L
.10407 .66286 L
.13235 .65086 L
.15408 .6414 L
.16063 .63873 L
.18891 .62651 L
.21719 .61388 L
.21853 .61312 L
.24548 .60114 L
.27376 .58727 L
.27707 .58484 L
.30204 .57276 L
.32576 .55656 L
.33032 .55576 L
.35458 .52828 L
.3586 .52196 L
.36275 .5 L
.3586 .47804 L
.35458 .47172 L
.33032 .44424 L
.32576 .44344 L
.30204 .42724 L
.27707 .41516 L
.27376 .41273 L
.24548 .39886 L
.21853 .38688 L
.21719 .38612 L
.18891 .37349 L
.16063 .36127 L
.15408 .3586 L
.13235 .34914 L
.10407 .33714 L
.08751 .33032 L
.07579 .32523 L
.04751 .31333 L
.02081 .30204 L
.01923 .30152 L
F
0 g
.01923 .69848 m
.02081 .69796 L
.04751 .68667 L
.07579 .67477 L
.08751 .66968 L
.10407 .66286 L
.13235 .65086 L
.15408 .6414 L
.16063 .63873 L
.18891 .62651 L
.21719 .61388 L
.21853 .61312 L
.24548 .60114 L
.27376 .58727 L
.27707 .58484 L
.30204 .57276 L
.32576 .55656 L
.33032 .55576 L
.35458 .52828 L
.3586 .52196 L
.36275 .5 L
.3586 .47804 L
.35458 .47172 L
.33032 .44424 L
.32576 .44344 L
.30204 .42724 L
.27707 .41516 L
.27376 .41273 L
.24548 .39886 L
.21853 .38688 L
.21719 .38612 L
.18891 .37349 L
.16063 .36127 L
.15408 .3586 L
.13235 .34914 L
.10407 .33714 L
.08751 .33032 L
.07579 .32523 L
.04751 .31333 L
.02081 .30204 L
.01923 .30152 L
s
0 .23 1 r
.01923 .29057 m
.04751 .30032 L
.05233 .30204 L
.07579 .30951 L
.10407 .31801 L
.13235 .32559 L
.15149 .33032 L
.16063 .33186 L
.18891 .3363 L
.21719 .33823 L
.24548 .33655 L
.27171 .33032 L
.27376 .32941 L
.30204 .31288 L
.31288 .30204 L
.32941 .27376 L
.33032 .27171 L
.33655 .24548 L
.33823 .21719 L
.3363 .18891 L
.33186 .16063 L
.33032 .15149 L
.32559 .13235 L
.31801 .10407 L
.30951 .07579 L
.30204 .05233 L
.30032 .04751 L
.29057 .01923 L
.01923 .01923 L
F
0 g
.01923 .29057 m
.04751 .30032 L
.05233 .30204 L
.07579 .30951 L
.10407 .31801 L
.13235 .32559 L
.15149 .33032 L
.16063 .33186 L
.18891 .3363 L
.21719 .33823 L
.24548 .33655 L
.27171 .33032 L
.27376 .32941 L
.30204 .31288 L
.31288 .30204 L
.32941 .27376 L
.33032 .27171 L
.33655 .24548 L
.33823 .21719 L
.3363 .18891 L
.33186 .16063 L
.33032 .15149 L
.32559 .13235 L
.31801 .10407 L
.30951 .07579 L
.30204 .05233 L
.30032 .04751 L
.29057 .01923 L
s
0 .23 1 r
.01923 .70943 m
.04751 .69968 L
.05233 .69796 L
.07579 .69049 L
.10407 .68199 L
.13235 .67441 L
.15149 .66968 L
.16063 .66814 L
.18891 .6637 L
.21719 .66177 L
.24548 .66345 L
.27171 .66968 L
.27376 .67059 L
.30204 .68712 L
.31288 .69796 L
.32941 .72624 L
.33032 .72829 L
.33655 .75452 L
.33823 .78281 L
.3363 .81109 L
.33186 .83937 L
.33032 .84851 L
.32559 .86765 L
.31801 .89593 L
.30951 .92421 L
.30204 .94767 L
.30032 .95249 L
.29057 .98077 L
.01923 .98077 L
F
0 g
.01923 .70943 m
.04751 .69968 L
.05233 .69796 L
.07579 .69049 L
.10407 .68199 L
.13235 .67441 L
.15149 .66968 L
.16063 .66814 L
.18891 .6637 L
.21719 .66177 L
.24548 .66345 L
.27171 .66968 L
.27376 .67059 L
.30204 .68712 L
.31288 .69796 L
.32941 .72624 L
.33032 .72829 L
.33655 .75452 L
.33823 .78281 L
.3363 .81109 L
.33186 .83937 L
.33032 .84851 L
.32559 .86765 L
.31801 .89593 L
.30951 .92421 L
.30204 .94767 L
.30032 .95249 L
.29057 .98077 L
s
0 .695 1 r
.01923 .27065 m
.0459 .27376 L
.04751 .27688 L
.07579 .28179 L
.10407 .28502 L
.13235 .28604 L
.16063 .28416 L
.18891 .27831 L
.20231 .27376 L
.21719 .26673 L
.24548 .24573 L
.24573 .24548 L
.26673 .21719 L
.27376 .20231 L
.27831 .18891 L
.28416 .16063 L
.28604 .13235 L
.28502 .10407 L
.28179 .07579 L
.27688 .04751 L
.27376 .0459 L
.27065 .01923 L
.01923 .01923 L
F
0 g
.01923 .27065 m
.0459 .27376 L
.04751 .27688 L
.07579 .28179 L
.10407 .28502 L
.13235 .28604 L
.16063 .28416 L
.18891 .27831 L
.20231 .27376 L
.21719 .26673 L
.24548 .24573 L
.24573 .24548 L
.26673 .21719 L
.27376 .20231 L
.27831 .18891 L
.28416 .16063 L
.28604 .13235 L
.28502 .10407 L
.28179 .07579 L
.27688 .04751 L
.27376 .0459 L
.27065 .01923 L
s
0 .695 1 r
.01923 .72935 m
.0459 .72624 L
.04751 .72312 L
.07579 .71821 L
.10407 .71498 L
.13235 .71396 L
.16063 .71584 L
.18891 .72169 L
.20231 .72624 L
.21719 .73327 L
.24548 .75427 L
.24573 .75452 L
.26673 .78281 L
.27376 .79769 L
.27831 .81109 L
.28416 .83937 L
.28604 .86765 L
.28502 .89593 L
.28179 .92421 L
.27688 .95249 L
.27376 .9541 L
.27065 .98077 L
.01923 .98077 L
F
0 g
.01923 .72935 m
.0459 .72624 L
.04751 .72312 L
.07579 .71821 L
.10407 .71498 L
.13235 .71396 L
.16063 .71584 L
.18891 .72169 L
.20231 .72624 L
.21719 .73327 L
.24548 .75427 L
.24573 .75452 L
.26673 .78281 L
.27376 .79769 L
.27831 .81109 L
.28416 .83937 L
.28604 .86765 L
.28502 .89593 L
.28179 .92421 L
.27688 .95249 L
.27376 .9541 L
.27065 .98077 L
s
0 1 .642 r
.01923 .75759 m
.04751 .75582 L
.07579 .75623 L
.10407 .75942 L
.13235 .76625 L
.16063 .77808 L
.16891 .78281 L
.18891 .7975 L
.2025 .81109 L
.21719 .83109 L
.22192 .83937 L
.23375 .86765 L
.24058 .89593 L
.24377 .92421 L
.24418 .95249 L
.24241 .98077 L
.01923 .98077 L
F
0 g
.01923 .75759 m
.04751 .75582 L
.07579 .75623 L
.10407 .75942 L
.13235 .76625 L
.16063 .77808 L
.16891 .78281 L
.18891 .7975 L
.2025 .81109 L
.21719 .83109 L
.22192 .83937 L
.23375 .86765 L
.24058 .89593 L
.24377 .92421 L
.24418 .95249 L
.24241 .98077 L
s
0 1 .642 r
.01923 .24241 m
.04751 .24418 L
.07579 .24377 L
.10407 .24058 L
.13235 .23375 L
.16063 .22192 L
.16891 .21719 L
.18891 .2025 L
.2025 .18891 L
.21719 .16891 L
.22192 .16063 L
.23375 .13235 L
.24058 .10407 L
.24377 .07579 L
.24418 .04751 L
.24241 .01923 L
.01923 .01923 L
F
0 g
.01923 .24241 m
.04751 .24418 L
.07579 .24377 L
.10407 .24058 L
.13235 .23375 L
.16063 .22192 L
.16891 .21719 L
.18891 .2025 L
.2025 .18891 L
.21719 .16891 L
.22192 .16063 L
.23375 .13235 L
.24058 .10407 L
.24377 .07579 L
.24418 .04751 L
.24241 .01923 L
s
.488 0 1 r
.01923 .68841 m
.04751 .67444 L
.05667 .66968 L
.07579 .65983 L
.10407 .64413 L
.1086 .6414 L
.13235 .627 L
.15239 .61312 L
.16063 .60725 L
.18641 .58484 L
.18891 .58262 L
.20986 .55656 L
.21719 .54401 L
.22345 .52828 L
.22786 .5 L
.22345 .47172 L
.21719 .45599 L
.20986 .44344 L
.18891 .41738 L
.18641 .41516 L
.16063 .39275 L
.15239 .38688 L
.13235 .373 L
.1086 .3586 L
.10407 .35587 L
.07579 .34017 L
.05667 .33032 L
.04751 .32556 L
.01923 .31159 L
F
0 g
.01923 .68841 m
.04751 .67444 L
.05667 .66968 L
.07579 .65983 L
.10407 .64413 L
.1086 .6414 L
.13235 .627 L
.15239 .61312 L
.16063 .60725 L
.18641 .58484 L
.18891 .58262 L
.20986 .55656 L
.21719 .54401 L
.22345 .52828 L
.22786 .5 L
.22345 .47172 L
.21719 .45599 L
.20986 .44344 L
.18891 .41738 L
.18641 .41516 L
.16063 .39275 L
.15239 .38688 L
.13235 .373 L
.1086 .3586 L
.10407 .35587 L
.07579 .34017 L
.05667 .33032 L
.04751 .32556 L
.01923 .31159 L
s
.221 1 0 r
.01923 .20767 m
.04751 .2044 L
.07579 .19797 L
.10076 .18891 L
.10407 .1874 L
.13235 .17103 L
.1455 .16063 L
.16063 .1455 L
.17103 .13235 L
.1874 .10407 L
.18891 .10076 L
.19797 .07579 L
.2044 .04751 L
.20767 .01923 L
.01923 .01923 L
F
0 g
.01923 .20767 m
.04751 .2044 L
.07579 .19797 L
.10076 .18891 L
.10407 .1874 L
.13235 .17103 L
.1455 .16063 L
.16063 .1455 L
.17103 .13235 L
.1874 .10407 L
.18891 .10076 L
.19797 .07579 L
.2044 .04751 L
.20767 .01923 L
s
.221 1 0 r
.01923 .79233 m
.04751 .7956 L
.07579 .80203 L
.10076 .81109 L
.10407 .8126 L
.13235 .82897 L
.1455 .83937 L
.16063 .8545 L
.17103 .86765 L
.1874 .89593 L
.18891 .89924 L
.19797 .92421 L
.2044 .95249 L
.20767 .98077 L
.01923 .98077 L
F
0 g
.01923 .79233 m
.04751 .7956 L
.07579 .80203 L
.10076 .81109 L
.10407 .8126 L
.13235 .82897 L
.1455 .83937 L
.16063 .8545 L
.17103 .86765 L
.1874 .89593 L
.18891 .89924 L
.19797 .92421 L
.2044 .95249 L
.20767 .98077 L
s
1 .718 0 r
.01923 .16768 m
.0426 .16063 L
.04751 .15881 L
.07579 .14546 L
.09581 .13235 L
.10407 .12578 L
.12578 .10407 L
.13235 .09581 L
.14546 .07579 L
.15881 .04751 L
.16063 .0426 L
.16768 .01923 L
.01923 .01923 L
F
0 g
.01923 .16768 m
.0426 .16063 L
.04751 .15881 L
.07579 .14546 L
.09581 .13235 L
.10407 .12578 L
.12578 .10407 L
.13235 .09581 L
.14546 .07579 L
.15881 .04751 L
.16063 .0426 L
.16768 .01923 L
s
1 .718 0 r
.01923 .83232 m
.0426 .83937 L
.04751 .84119 L
.07579 .85454 L
.09581 .86765 L
.10407 .87422 L
.12578 .89593 L
.13235 .90419 L
.14546 .92421 L
.15881 .95249 L
.16063 .9574 L
.16768 .98077 L
.01923 .98077 L
F
0 g
.01923 .83232 m
.0426 .83937 L
.04751 .84119 L
.07579 .85454 L
.09581 .86765 L
.10407 .87422 L
.12578 .89593 L
.13235 .90419 L
.14546 .92421 L
.15881 .95249 L
.16063 .9574 L
.16768 .98077 L
s
.953 0 1 r
.01923 .66425 m
.04751 .64438 L
.05136 .6414 L
.07579 .62122 L
.08424 .61312 L
.10407 .59175 L
.10927 .58484 L
.12666 .55656 L
.13235 .54327 L
.13683 .52828 L
.14016 .5 L
.13683 .47172 L
.13235 .45673 L
.12666 .44344 L
.10927 .41516 L
.10407 .40825 L
.08424 .38688 L
.07579 .37878 L
.05136 .3586 L
.04751 .35562 L
.01923 .33575 L
F
0 g
.01923 .66425 m
.04751 .64438 L
.05136 .6414 L
.07579 .62122 L
.08424 .61312 L
.10407 .59175 L
.10927 .58484 L
.12666 .55656 L
.13235 .54327 L
.13683 .52828 L
.14016 .5 L
.13683 .47172 L
.13235 .45673 L
.12666 .44344 L
.10927 .41516 L
.10407 .40825 L
.08424 .38688 L
.07579 .37878 L
.05136 .3586 L
.04751 .35562 L
.01923 .33575 L
s
1 0 0 r
.01923 .12306 m
.04751 .10773 L
.053 .10407 L
.07579 .08578 L
.08578 .07579 L
.10407 .053 L
.10773 .04751 L
.12306 .01923 L
.01923 .01923 L
F
0 g
.01923 .12306 m
.04751 .10773 L
.053 .10407 L
.07579 .08578 L
.08578 .07579 L
.10407 .053 L
.10773 .04751 L
.12306 .01923 L
s
1 0 0 r
.01923 .87694 m
.04751 .89227 L
.053 .89593 L
.07579 .91422 L
.08578 .92421 L
.10407 .947 L
.10773 .95249 L
.12306 .98077 L
.01923 .98077 L
F
0 g
.01923 .87694 m
.04751 .89227 L
.053 .89593 L
.07579 .91422 L
.08578 .92421 L
.10407 .947 L
.10773 .95249 L
.12306 .98077 L
s
1 0 .384 r
.01923 .61842 m
.02387 .61312 L
.04437 .58484 L
.04751 .58 L
.05867 .55656 L
.06716 .52828 L
.06996 .5 L
.06716 .47172 L
.05867 .44344 L
.04751 .42 L
.04437 .41516 L
.02387 .38688 L
.01923 .38158 L
F
0 g
.01923 .61842 m
.02387 .61312 L
.04437 .58484 L
.04751 .58 L
.05867 .55656 L
.06716 .52828 L
.06996 .5 L
.06716 .47172 L
.05867 .44344 L
.04751 .42 L
.04437 .41516 L
.02387 .38688 L
.01923 .38158 L
s
.223 0 1 r
.69848 .01923 m
.69796 .02081 L
.68667 .04751 L
.67477 .07579 L
.66968 .08751 L
.66286 .10407 L
.65086 .13235 L
.6414 .15408 L
.63873 .16063 L
.62651 .18891 L
.61388 .21719 L
.61312 .21853 L
.60114 .24548 L
.58727 .27376 L
.58484 .27707 L
.57276 .30204 L
.55656 .32576 L
.55576 .33032 L
.52828 .35458 L
.52196 .3586 L
.5 .36275 L
.47804 .3586 L
.47172 .35458 L
.44424 .33032 L
.44344 .32576 L
.42724 .30204 L
.41516 .27707 L
.41273 .27376 L
.39886 .24548 L
.38688 .21853 L
.38612 .21719 L
.37349 .18891 L
.36127 .16063 L
.3586 .15408 L
.34914 .13235 L
.33714 .10407 L
.33032 .08751 L
.32523 .07579 L
.31333 .04751 L
.30204 .02081 L
.30152 .01923 L
F
0 g
.69848 .01923 m
.69796 .02081 L
.68667 .04751 L
.67477 .07579 L
.66968 .08751 L
.66286 .10407 L
.65086 .13235 L
.6414 .15408 L
.63873 .16063 L
.62651 .18891 L
.61388 .21719 L
.61312 .21853 L
.60114 .24548 L
.58727 .27376 L
.58484 .27707 L
.57276 .30204 L
.55656 .32576 L
.55576 .33032 L
.52828 .35458 L
.52196 .3586 L
.5 .36275 L
.47804 .3586 L
.47172 .35458 L
.44424 .33032 L
.44344 .32576 L
.42724 .30204 L
.41516 .27707 L
.41273 .27376 L
.39886 .24548 L
.38688 .21853 L
.38612 .21719 L
.37349 .18891 L
.36127 .16063 L
.3586 .15408 L
.34914 .13235 L
.33714 .10407 L
.33032 .08751 L
.32523 .07579 L
.31333 .04751 L
.30204 .02081 L
.30152 .01923 L
s
.223 0 1 r
.69848 .98077 m
.69796 .97919 L
.68667 .95249 L
.67477 .92421 L
.66968 .91249 L
.66286 .89593 L
.65086 .86765 L
.6414 .84592 L
.63873 .83937 L
.62651 .81109 L
.61388 .78281 L
.61312 .78147 L
.60114 .75452 L
.58727 .72624 L
.58484 .72293 L
.57276 .69796 L
.55656 .67424 L
.55576 .66968 L
.52828 .64542 L
.52196 .6414 L
.5 .63725 L
.47804 .6414 L
.47172 .64542 L
.44424 .66968 L
.44344 .67424 L
.42724 .69796 L
.41516 .72293 L
.41273 .72624 L
.39886 .75452 L
.38688 .78147 L
.38612 .78281 L
.37349 .81109 L
.36127 .83937 L
.3586 .84592 L
.34914 .86765 L
.33714 .89593 L
.33032 .91249 L
.32523 .92421 L
.31333 .95249 L
.30204 .97919 L
.30152 .98077 L
F
0 g
.69848 .98077 m
.69796 .97919 L
.68667 .95249 L
.67477 .92421 L
.66968 .91249 L
.66286 .89593 L
.65086 .86765 L
.6414 .84592 L
.63873 .83937 L
.62651 .81109 L
.61388 .78281 L
.61312 .78147 L
.60114 .75452 L
.58727 .72624 L
.58484 .72293 L
.57276 .69796 L
.55656 .67424 L
.55576 .66968 L
.52828 .64542 L
.52196 .6414 L
.5 .63725 L
.47804 .6414 L
.47172 .64542 L
.44424 .66968 L
.44344 .67424 L
.42724 .69796 L
.41516 .72293 L
.41273 .72624 L
.39886 .75452 L
.38688 .78147 L
.38612 .78281 L
.37349 .81109 L
.36127 .83937 L
.3586 .84592 L
.34914 .86765 L
.33714 .89593 L
.33032 .91249 L
.32523 .92421 L
.31333 .95249 L
.30204 .97919 L
.30152 .98077 L
s
.488 0 1 r
.68841 .01923 m
.67444 .04751 L
.66968 .05667 L
.65983 .07579 L
.64413 .10407 L
.6414 .1086 L
.627 .13235 L
.61312 .15239 L
.60725 .16063 L
.58484 .18641 L
.58262 .18891 L
.55656 .20986 L
.54401 .21719 L
.52828 .22345 L
.5 .22786 L
.47172 .22345 L
.45599 .21719 L
.44344 .20986 L
.41738 .18891 L
.41516 .18641 L
.39275 .16063 L
.38688 .15239 L
.373 .13235 L
.3586 .1086 L
.35587 .10407 L
.34017 .07579 L
.33032 .05667 L
.32556 .04751 L
.31159 .01923 L
F
0 g
.68841 .01923 m
.67444 .04751 L
.66968 .05667 L
.65983 .07579 L
.64413 .10407 L
.6414 .1086 L
.627 .13235 L
.61312 .15239 L
.60725 .16063 L
.58484 .18641 L
.58262 .18891 L
.55656 .20986 L
.54401 .21719 L
.52828 .22345 L
.5 .22786 L
.47172 .22345 L
.45599 .21719 L
.44344 .20986 L
.41738 .18891 L
.41516 .18641 L
.39275 .16063 L
.38688 .15239 L
.373 .13235 L
.3586 .1086 L
.35587 .10407 L
.34017 .07579 L
.33032 .05667 L
.32556 .04751 L
.31159 .01923 L
s
.488 0 1 r
.68841 .98077 m
.67444 .95249 L
.66968 .94333 L
.65983 .92421 L
.64413 .89593 L
.6414 .8914 L
.627 .86765 L
.61312 .84761 L
.60725 .83937 L
.58484 .81359 L
.58262 .81109 L
.55656 .79014 L
.54401 .78281 L
.52828 .77655 L
.5 .77214 L
.47172 .77655 L
.45599 .78281 L
.44344 .79014 L
.41738 .81109 L
.41516 .81359 L
.39275 .83937 L
.38688 .84761 L
.373 .86765 L
.3586 .8914 L
.35587 .89593 L
.34017 .92421 L
.33032 .94333 L
.32556 .95249 L
.31159 .98077 L
F
0 g
.68841 .98077 m
.67444 .95249 L
.66968 .94333 L
.65983 .92421 L
.64413 .89593 L
.6414 .8914 L
.627 .86765 L
.61312 .84761 L
.60725 .83937 L
.58484 .81359 L
.58262 .81109 L
.55656 .79014 L
.54401 .78281 L
.52828 .77655 L
.5 .77214 L
.47172 .77655 L
.45599 .78281 L
.44344 .79014 L
.41738 .81109 L
.41516 .81359 L
.39275 .83937 L
.38688 .84761 L
.373 .86765 L
.3586 .8914 L
.35587 .89593 L
.34017 .92421 L
.33032 .94333 L
.32556 .95249 L
.31159 .98077 L
s
.953 0 1 r
.66425 .01923 m
.64438 .04751 L
.6414 .05136 L
.62122 .07579 L
.61312 .08424 L
.59175 .10407 L
.58484 .10927 L
.55656 .12666 L
.54327 .13235 L
.52828 .13683 L
.5 .14016 L
.47172 .13683 L
.45673 .13235 L
.44344 .12666 L
.41516 .10927 L
.40825 .10407 L
.38688 .08424 L
.37878 .07579 L
.3586 .05136 L
.35562 .04751 L
.33575 .01923 L
F
0 g
.66425 .01923 m
.64438 .04751 L
.6414 .05136 L
.62122 .07579 L
.61312 .08424 L
.59175 .10407 L
.58484 .10927 L
.55656 .12666 L
.54327 .13235 L
.52828 .13683 L
.5 .14016 L
.47172 .13683 L
.45673 .13235 L
.44344 .12666 L
.41516 .10927 L
.40825 .10407 L
.38688 .08424 L
.37878 .07579 L
.3586 .05136 L
.35562 .04751 L
.33575 .01923 L
s
.953 0 1 r
.66425 .98077 m
.64438 .95249 L
.6414 .94864 L
.62122 .92421 L
.61312 .91576 L
.59175 .89593 L
.58484 .89073 L
.55656 .87334 L
.54327 .86765 L
.52828 .86317 L
.5 .85984 L
.47172 .86317 L
.45673 .86765 L
.44344 .87334 L
.41516 .89073 L
.40825 .89593 L
.38688 .91576 L
.37878 .92421 L
.3586 .94864 L
.35562 .95249 L
.33575 .98077 L
F
0 g
.66425 .98077 m
.64438 .95249 L
.6414 .94864 L
.62122 .92421 L
.61312 .91576 L
.59175 .89593 L
.58484 .89073 L
.55656 .87334 L
.54327 .86765 L
.52828 .86317 L
.5 .85984 L
.47172 .86317 L
.45673 .86765 L
.44344 .87334 L
.41516 .89073 L
.40825 .89593 L
.38688 .91576 L
.37878 .92421 L
.3586 .94864 L
.35562 .95249 L
.33575 .98077 L
s
1 0 .384 r
.61842 .01923 m
.61312 .02387 L
.58484 .04437 L
.58 .04751 L
.55656 .05867 L
.52828 .06716 L
.5 .06996 L
.47172 .06716 L
.44344 .05867 L
.42 .04751 L
.41516 .04437 L
.38688 .02387 L
.38158 .01923 L
F
0 g
.61842 .01923 m
.61312 .02387 L
.58484 .04437 L
.58 .04751 L
.55656 .05867 L
.52828 .06716 L
.5 .06996 L
.47172 .06716 L
.44344 .05867 L
.42 .04751 L
.41516 .04437 L
.38688 .02387 L
.38158 .01923 L
s
1 0 .384 r
.61842 .98077 m
.61312 .97613 L
.58484 .95563 L
.58 .95249 L
.55656 .94133 L
.52828 .93284 L
.5 .93004 L
.47172 .93284 L
.44344 .94133 L
.42 .95249 L
.41516 .95563 L
.38688 .97613 L
.38158 .98077 L
F
0 g
.61842 .98077 m
.61312 .97613 L
.58484 .95563 L
.58 .95249 L
.55656 .94133 L
.52828 .93284 L
.5 .93004 L
.47172 .93284 L
.44344 .94133 L
.42 .95249 L
.41516 .95563 L
.38688 .97613 L
.38158 .98077 L
s
.035 0 1 r
.98077 .3002 m
.97536 .30204 L
.95249 .31176 L
.92421 .32331 L
.90734 .33032 L
.89593 .3348 L
.86765 .3462 L
.83937 .35757 L
.83713 .3586 L
.81109 .36865 L
.78281 .3796 L
.76471 .38688 L
.75452 .39013 L
.72624 .39994 L
.69796 .40889 L
.67356 .41516 L
.66968 .41586 L
.6414 .41884 L
.61433 .41516 L
.61312 .4147 L
.5853 .38688 L
.58484 .38567 L
.58116 .3586 L
.58414 .33032 L
.58484 .32644 L
.59111 .30204 L
.60006 .27376 L
.60987 .24548 L
.61312 .23529 L
.6204 .21719 L
.63135 .18891 L
.6414 .16287 L
.64243 .16063 L
.6538 .13235 L
.6652 .10407 L
.66968 .09266 L
.67669 .07579 L
.68824 .04751 L
.69796 .02464 L
.6998 .01923 L
.98077 .01923 L
F
0 g
.98077 .3002 m
.97536 .30204 L
.95249 .31176 L
.92421 .32331 L
.90734 .33032 L
.89593 .3348 L
.86765 .3462 L
.83937 .35757 L
.83713 .3586 L
.81109 .36865 L
.78281 .3796 L
.76471 .38688 L
.75452 .39013 L
.72624 .39994 L
.69796 .40889 L
.67356 .41516 L
.66968 .41586 L
.6414 .41884 L
.61433 .41516 L
.61312 .4147 L
.5853 .38688 L
.58484 .38567 L
.58116 .3586 L
.58414 .33032 L
.58484 .32644 L
.59111 .30204 L
.60006 .27376 L
.60987 .24548 L
.61312 .23529 L
.6204 .21719 L
.63135 .18891 L
.6414 .16287 L
.64243 .16063 L
.6538 .13235 L
.6652 .10407 L
.66968 .09266 L
.67669 .07579 L
.68824 .04751 L
.69796 .02464 L
.6998 .01923 L
s
.035 0 1 r
.98077 .6998 m
.97536 .69796 L
.95249 .68824 L
.92421 .67669 L
.90734 .66968 L
.89593 .6652 L
.86765 .6538 L
.83937 .64243 L
.83713 .6414 L
.81109 .63135 L
.78281 .6204 L
.76471 .61312 L
.75452 .60987 L
.72624 .60006 L
.69796 .59111 L
.67356 .58484 L
.66968 .58414 L
.6414 .58116 L
.61433 .58484 L
.61312 .5853 L
.5853 .61312 L
.58484 .61433 L
.58116 .6414 L
.58414 .66968 L
.58484 .67356 L
.59111 .69796 L
.60006 .72624 L
.60987 .75452 L
.61312 .76471 L
.6204 .78281 L
.63135 .81109 L
.6414 .83713 L
.64243 .83937 L
.6538 .86765 L
.6652 .89593 L
.66968 .90734 L
.67669 .92421 L
.68824 .95249 L
.69796 .97536 L
.6998 .98077 L
.98077 .98077 L
F
0 g
.98077 .6998 m
.97536 .69796 L
.95249 .68824 L
.92421 .67669 L
.90734 .66968 L
.89593 .6652 L
.86765 .6538 L
.83937 .64243 L
.83713 .6414 L
.81109 .63135 L
.78281 .6204 L
.76471 .61312 L
.75452 .60987 L
.72624 .60006 L
.69796 .59111 L
.67356 .58484 L
.66968 .58414 L
.6414 .58116 L
.61433 .58484 L
.61312 .5853 L
.5853 .61312 L
.58484 .61433 L
.58116 .6414 L
.58414 .66968 L
.58484 .67356 L
.59111 .69796 L
.60006 .72624 L
.60987 .75452 L
.61312 .76471 L
.6204 .78281 L
.63135 .81109 L
.6414 .83713 L
.64243 .83937 L
.6538 .86765 L
.6652 .89593 L
.66968 .90734 L
.67669 .92421 L
.68824 .95249 L
.69796 .97536 L
.6998 .98077 L
s
.223 0 1 r
.98077 .69848 m
.97919 .69796 L
.95249 .68667 L
.92421 .67477 L
.91249 .66968 L
.89593 .66286 L
.86765 .65086 L
.84592 .6414 L
.83937 .63873 L
.81109 .62651 L
.78281 .61388 L
.78147 .61312 L
.75452 .60114 L
.72624 .58727 L
.72293 .58484 L
.69796 .57276 L
.67424 .55656 L
.66968 .55576 L
.64542 .52828 L
.6414 .52196 L
.63725 .5 L
.6414 .47804 L
.64542 .47172 L
.66968 .44424 L
.67424 .44344 L
.69796 .42724 L
.72293 .41516 L
.72624 .41273 L
.75452 .39886 L
.78147 .38688 L
.78281 .38612 L
.81109 .37349 L
.83937 .36127 L
.84592 .3586 L
.86765 .34914 L
.89593 .33714 L
.91249 .33032 L
.92421 .32523 L
.95249 .31333 L
.97919 .30204 L
.98077 .30152 L
F
0 g
.98077 .69848 m
.97919 .69796 L
.95249 .68667 L
.92421 .67477 L
.91249 .66968 L
.89593 .66286 L
.86765 .65086 L
.84592 .6414 L
.83937 .63873 L
.81109 .62651 L
.78281 .61388 L
.78147 .61312 L
.75452 .60114 L
.72624 .58727 L
.72293 .58484 L
.69796 .57276 L
.67424 .55656 L
.66968 .55576 L
.64542 .52828 L
.6414 .52196 L
.63725 .5 L
.6414 .47804 L
.64542 .47172 L
.66968 .44424 L
.67424 .44344 L
.69796 .42724 L
.72293 .41516 L
.72624 .41273 L
.75452 .39886 L
.78147 .38688 L
.78281 .38612 L
.81109 .37349 L
.83937 .36127 L
.84592 .3586 L
.86765 .34914 L
.89593 .33714 L
.91249 .33032 L
.92421 .32523 L
.95249 .31333 L
.97919 .30204 L
.98077 .30152 L
s
0 .23 1 r
.98077 .29057 m
.95249 .30032 L
.94767 .30204 L
.92421 .30951 L
.89593 .31801 L
.86765 .32559 L
.84851 .33032 L
.83937 .33186 L
.81109 .3363 L
.78281 .33823 L
.75452 .33655 L
.72829 .33032 L
.72624 .32941 L
.69796 .31288 L
.68712 .30204 L
.67059 .27376 L
.66968 .27171 L
.66345 .24548 L
.66177 .21719 L
.6637 .18891 L
.66814 .16063 L
.66968 .15149 L
.67441 .13235 L
.68199 .10407 L
.69049 .07579 L
.69796 .05233 L
.69968 .04751 L
.70943 .01923 L
.98077 .01923 L
F
0 g
.98077 .29057 m
.95249 .30032 L
.94767 .30204 L
.92421 .30951 L
.89593 .31801 L
.86765 .32559 L
.84851 .33032 L
.83937 .33186 L
.81109 .3363 L
.78281 .33823 L
.75452 .33655 L
.72829 .33032 L
.72624 .32941 L
.69796 .31288 L
.68712 .30204 L
.67059 .27376 L
.66968 .27171 L
.66345 .24548 L
.66177 .21719 L
.6637 .18891 L
.66814 .16063 L
.66968 .15149 L
.67441 .13235 L
.68199 .10407 L
.69049 .07579 L
.69796 .05233 L
.69968 .04751 L
.70943 .01923 L
s
0 .23 1 r
.98077 .70943 m
.95249 .69968 L
.94767 .69796 L
.92421 .69049 L
.89593 .68199 L
.86765 .67441 L
.84851 .66968 L
.83937 .66814 L
.81109 .6637 L
.78281 .66177 L
.75452 .66345 L
.72829 .66968 L
.72624 .67059 L
.69796 .68712 L
.68712 .69796 L
.67059 .72624 L
.66968 .72829 L
.66345 .75452 L
.66177 .78281 L
.6637 .81109 L
.66814 .83937 L
.66968 .84851 L
.67441 .86765 L
.68199 .89593 L
.69049 .92421 L
.69796 .94767 L
.69968 .95249 L
.70943 .98077 L
.98077 .98077 L
F
0 g
.98077 .70943 m
.95249 .69968 L
.94767 .69796 L
.92421 .69049 L
.89593 .68199 L
.86765 .67441 L
.84851 .66968 L
.83937 .66814 L
.81109 .6637 L
.78281 .66177 L
.75452 .66345 L
.72829 .66968 L
.72624 .67059 L
.69796 .68712 L
.68712 .69796 L
.67059 .72624 L
.66968 .72829 L
.66345 .75452 L
.66177 .78281 L
.6637 .81109 L
.66814 .83937 L
.66968 .84851 L
.67441 .86765 L
.68199 .89593 L
.69049 .92421 L
.69796 .94767 L
.69968 .95249 L
.70943 .98077 L
s
0 .695 1 r
.98077 .27065 m
.9541 .27376 L
.95249 .27688 L
.92421 .28179 L
.89593 .28502 L
.86765 .28604 L
.83937 .28416 L
.81109 .27831 L
.79769 .27376 L
.78281 .26673 L
.75452 .24573 L
.75427 .24548 L
.73327 .21719 L
.72624 .20231 L
.72169 .18891 L
.71584 .16063 L
.71396 .13235 L
.71498 .10407 L
.71821 .07579 L
.72312 .04751 L
.72624 .0459 L
.72935 .01923 L
.98077 .01923 L
F
0 g
.98077 .27065 m
.9541 .27376 L
.95249 .27688 L
.92421 .28179 L
.89593 .28502 L
.86765 .28604 L
.83937 .28416 L
.81109 .27831 L
.79769 .27376 L
.78281 .26673 L
.75452 .24573 L
.75427 .24548 L
.73327 .21719 L
.72624 .20231 L
.72169 .18891 L
.71584 .16063 L
.71396 .13235 L
.71498 .10407 L
.71821 .07579 L
.72312 .04751 L
.72624 .0459 L
.72935 .01923 L
s
0 .695 1 r
.98077 .72935 m
.9541 .72624 L
.95249 .72312 L
.92421 .71821 L
.89593 .71498 L
.86765 .71396 L
.83937 .71584 L
.81109 .72169 L
.79769 .72624 L
.78281 .73327 L
.75452 .75427 L
.75427 .75452 L
.73327 .78281 L
.72624 .79769 L
.72169 .81109 L
.71584 .83937 L
.71396 .86765 L
.71498 .89593 L
.71821 .92421 L
.72312 .95249 L
.72624 .9541 L
.72935 .98077 L
.98077 .98077 L
F
0 g
.98077 .72935 m
.9541 .72624 L
.95249 .72312 L
.92421 .71821 L
.89593 .71498 L
.86765 .71396 L
.83937 .71584 L
.81109 .72169 L
.79769 .72624 L
.78281 .73327 L
.75452 .75427 L
.75427 .75452 L
.73327 .78281 L
.72624 .79769 L
.72169 .81109 L
.71584 .83937 L
.71396 .86765 L
.71498 .89593 L
.71821 .92421 L
.72312 .95249 L
.72624 .9541 L
.72935 .98077 L
s
0 1 .642 r
.98077 .75759 m
.95249 .75582 L
.92421 .75623 L
.89593 .75942 L
.86765 .76625 L
.83937 .77808 L
.83109 .78281 L
.81109 .7975 L
.7975 .81109 L
.78281 .83109 L
.77808 .83937 L
.76625 .86765 L
.75942 .89593 L
.75623 .92421 L
.75582 .95249 L
.75759 .98077 L
.98077 .98077 L
F
0 g
.98077 .75759 m
.95249 .75582 L
.92421 .75623 L
.89593 .75942 L
.86765 .76625 L
.83937 .77808 L
.83109 .78281 L
.81109 .7975 L
.7975 .81109 L
.78281 .83109 L
.77808 .83937 L
.76625 .86765 L
.75942 .89593 L
.75623 .92421 L
.75582 .95249 L
.75759 .98077 L
s
0 1 .642 r
.98077 .24241 m
.95249 .24418 L
.92421 .24377 L
.89593 .24058 L
.86765 .23375 L
.83937 .22192 L
.83109 .21719 L
.81109 .2025 L
.7975 .18891 L
.78281 .16891 L
.77808 .16063 L
.76625 .13235 L
.75942 .10407 L
.75623 .07579 L
.75582 .04751 L
.75759 .01923 L
.98077 .01923 L
F
0 g
.98077 .24241 m
.95249 .24418 L
.92421 .24377 L
.89593 .24058 L
.86765 .23375 L
.83937 .22192 L
.83109 .21719 L
.81109 .2025 L
.7975 .18891 L
.78281 .16891 L
.77808 .16063 L
.76625 .13235 L
.75942 .10407 L
.75623 .07579 L
.75582 .04751 L
.75759 .01923 L
s
.488 0 1 r
.98077 .68841 m
.95249 .67444 L
.94333 .66968 L
.92421 .65983 L
.89593 .64413 L
.8914 .6414 L
.86765 .627 L
.84761 .61312 L
.83937 .60725 L
.81359 .58484 L
.81109 .58262 L
.79014 .55656 L
.78281 .54401 L
.77655 .52828 L
.77214 .5 L
.77655 .47172 L
.78281 .45599 L
.79014 .44344 L
.81109 .41738 L
.81359 .41516 L
.83937 .39275 L
.84761 .38688 L
.86765 .373 L
.8914 .3586 L
.89593 .35587 L
.92421 .34017 L
.94333 .33032 L
.95249 .32556 L
.98077 .31159 L
F
0 g
.98077 .68841 m
.95249 .67444 L
.94333 .66968 L
.92421 .65983 L
.89593 .64413 L
.8914 .6414 L
.86765 .627 L
.84761 .61312 L
.83937 .60725 L
.81359 .58484 L
.81109 .58262 L
.79014 .55656 L
.78281 .54401 L
.77655 .52828 L
.77214 .5 L
.77655 .47172 L
.78281 .45599 L
.79014 .44344 L
.81109 .41738 L
.81359 .41516 L
.83937 .39275 L
.84761 .38688 L
.86765 .373 L
.8914 .3586 L
.89593 .35587 L
.92421 .34017 L
.94333 .33032 L
.95249 .32556 L
.98077 .31159 L
s
.221 1 0 r
.98077 .20767 m
.95249 .2044 L
.92421 .19797 L
.89924 .18891 L
.89593 .1874 L
.86765 .17103 L
.8545 .16063 L
.83937 .1455 L
.82897 .13235 L
.8126 .10407 L
.81109 .10076 L
.80203 .07579 L
.7956 .04751 L
.79233 .01923 L
.98077 .01923 L
F
0 g
.98077 .20767 m
.95249 .2044 L
.92421 .19797 L
.89924 .18891 L
.89593 .1874 L
.86765 .17103 L
.8545 .16063 L
.83937 .1455 L
.82897 .13235 L
.8126 .10407 L
.81109 .10076 L
.80203 .07579 L
.7956 .04751 L
.79233 .01923 L
s
.221 1 0 r
.98077 .79233 m
.95249 .7956 L
.92421 .80203 L
.89924 .81109 L
.89593 .8126 L
.86765 .82897 L
.8545 .83937 L
.83937 .8545 L
.82897 .86765 L
.8126 .89593 L
.81109 .89924 L
.80203 .92421 L
.7956 .95249 L
.79233 .98077 L
.98077 .98077 L
F
0 g
.98077 .79233 m
.95249 .7956 L
.92421 .80203 L
.89924 .81109 L
.89593 .8126 L
.86765 .82897 L
.8545 .83937 L
.83937 .8545 L
.82897 .86765 L
.8126 .89593 L
.81109 .89924 L
.80203 .92421 L
.7956 .95249 L
.79233 .98077 L
s
1 .718 0 r
.98077 .16768 m
.9574 .16063 L
.95249 .15881 L
.92421 .14546 L
.90419 .13235 L
.89593 .12578 L
.87422 .10407 L
.86765 .09581 L
.85454 .07579 L
.84119 .04751 L
.83937 .0426 L
.83232 .01923 L
.98077 .01923 L
F
0 g
.98077 .16768 m
.9574 .16063 L
.95249 .15881 L
.92421 .14546 L
.90419 .13235 L
.89593 .12578 L
.87422 .10407 L
.86765 .09581 L
.85454 .07579 L
.84119 .04751 L
.83937 .0426 L
.83232 .01923 L
s
1 .718 0 r
.98077 .83232 m
.9574 .83937 L
.95249 .84119 L
.92421 .85454 L
.90419 .86765 L
.89593 .87422 L
.87422 .89593 L
.86765 .90419 L
.85454 .92421 L
.84119 .95249 L
.83937 .9574 L
.83232 .98077 L
.98077 .98077 L
F
0 g
.98077 .83232 m
.9574 .83937 L
.95249 .84119 L
.92421 .85454 L
.90419 .86765 L
.89593 .87422 L
.87422 .89593 L
.86765 .90419 L
.85454 .92421 L
.84119 .95249 L
.83937 .9574 L
.83232 .98077 L
s
.953 0 1 r
.98077 .66425 m
.95249 .64438 L
.94864 .6414 L
.92421 .62122 L
.91576 .61312 L
.89593 .59175 L
.89073 .58484 L
.87334 .55656 L
.86765 .54327 L
.86317 .52828 L
.85984 .5 L
.86317 .47172 L
.86765 .45673 L
.87334 .44344 L
.89073 .41516 L
.89593 .40825 L
.91576 .38688 L
.92421 .37878 L
.94864 .3586 L
.95249 .35562 L
.98077 .33575 L
F
0 g
.98077 .66425 m
.95249 .64438 L
.94864 .6414 L
.92421 .62122 L
.91576 .61312 L
.89593 .59175 L
.89073 .58484 L
.87334 .55656 L
.86765 .54327 L
.86317 .52828 L
.85984 .5 L
.86317 .47172 L
.86765 .45673 L
.87334 .44344 L
.89073 .41516 L
.89593 .40825 L
.91576 .38688 L
.92421 .37878 L
.94864 .3586 L
.95249 .35562 L
.98077 .33575 L
s
1 0 0 r
.98077 .12306 m
.95249 .10773 L
.947 .10407 L
.92421 .08578 L
.91422 .07579 L
.89593 .053 L
.89227 .04751 L
.87694 .01923 L
.98077 .01923 L
F
0 g
.98077 .12306 m
.95249 .10773 L
.947 .10407 L
.92421 .08578 L
.91422 .07579 L
.89593 .053 L
.89227 .04751 L
.87694 .01923 L
s
1 0 0 r
.98077 .87694 m
.95249 .89227 L
.947 .89593 L
.92421 .91422 L
.91422 .92421 L
.89593 .947 L
.89227 .95249 L
.87694 .98077 L
.98077 .98077 L
F
0 g
.98077 .87694 m
.95249 .89227 L
.947 .89593 L
.92421 .91422 L
.91422 .92421 L
.89593 .947 L
.89227 .95249 L
.87694 .98077 L
s
1 0 .384 r
.98077 .61842 m
.97613 .61312 L
.95563 .58484 L
.95249 .58 L
.94133 .55656 L
.93284 .52828 L
.93004 .5 L
.93284 .47172 L
.94133 .44344 L
.95249 .42 L
.95563 .41516 L
.97613 .38688 L
.98077 .38158 L
F
0 g
.98077 .61842 m
.97613 .61312 L
.95563 .58484 L
.95249 .58 L
.94133 .55656 L
.93284 .52828 L
.93004 .5 L
.93284 .47172 L
.94133 .44344 L
.95249 .42 L
.95563 .41516 L
.97613 .38688 L
.98077 .38158 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{222, 222},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003N0000gR000`400?l00000o`00003ogP3oool0
0=h0oooo003N0?ooo`009`3oool4000002@0oooo1@00000P0?ooo`8000009@3oool5000002<0oooo
1000000G0?ooo`009`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01l0oooo00@0
00000?ooo`3oool000009P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo
000X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool07`3oool010000000oooo0?oo
o`00000V0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool05`3oool00240oooo1000
00040?ooo`030000003oool0oooo01d0oooo100000040?ooo`030000003oool0oooo01l0oooo00@0
00000?ooo`3oool000009P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01H0oooo
000W0?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool07`3oool010000000oooo
0?ooo`00000V0?ooo`030000003oool0oooo02<0oooo00@000000?ooo`3oool000005`3oool002P0
oooo0P00000V0?ooo`8000008P3oool2000002H0oooo0P00000V0?ooo`800000603oool00=h0oooo
003N0?ooo`00gP3oool00=h0oooo003N0?ooo`003P3oooo?00000040oooo000>0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0D0?ooo`4000000@3o
ool000h0oooo00<000000?ooo`3oool0b`3oool100000040oooo000>0?ooo`030000003oool0oooo
0</0oooo0@0000010?ooo`003P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01H0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3ooolD0?l000030000
003o]`00okL000L0okL000<0000003So000ho`001P0ho`000`0000000?nT003oY004003oY0030000
0000/Ol00;7o00<00;7o00H00000000jo`00>_l003[o000000080?l20000000303T0o`000000O03o
00<0O03o00<000000?<0o`3c0?l01`3c0?l00`000000o`1R0?l0HP0/0?l0HP030000003c0?l0l`3o
00H0l`3o00<0000007`0o`1l0?l00P1l0?l01P000000>@3o03T0o`000000203o000000@003[o00<0
0000002ao`00/Ol00P00/Ol00`0000000?nT003oY005003oY0030000000ho`00>?l000D0>?l000<0
00000?ng003o]`001`3o]`000`000000o`000?l0000A0?l000@0oooo0@0000010?ooo`003P3oool0
10000000oooo0?ooo`3ooolD0?l000030000003o]`00okL000L0okL000<0000003So000ho`001P0h
o`000`0000000?nT003oY004003oY00300000000/Ol00;7o00<00;7o00<00000000jo`00>_l00P00
>_l30000000303T0o`000000O03o00@0O03o00<000000?<0o`3c0?l01`3c0?l2000002X0o`1R0P00
00080?<0o`030000001l0?l0O03o00<0O03o00D0000003T0o`000000203o00000005000jo`030000
0000/Ol00;7o00800;7o00<00000003oY000oj@01@00oj@00`000000>?l003So000503So00030000
003o]`00okL000L0okL000<000000?l0003o00004@3o00040?ooo`4000000@3oool000h0oooo00@0
00000?ooo`3oool0oooo4`3o00000`000000okL00?ng00070?ng00030000000ho`00>?l000H0>?l0
00<00000003oY000oj@01@00oj@00`0000000;7o002ao`04002ao`0600000000>_l003[o000jo`00
0000203o0P0000000`0i0?l0000007`0o`0307`0o`030000003c0?l0l`3o00T0l`3o00<000000?l0
HP3o06809P3o06800`000000l`3o0?<0o`080?<0o`030000001l0?l0O03o0080O03o00H0000003T0
o`0i0?l0000000P0o`000004000jo`0300000000/Ol00;7o00<00;7o00<00000003oY000oj@01@00
oj@00`000000>?l003So000603So00030000003o]`00okL000L0okL000<000000?l0003o0000403o
00040?ooo`4000000@3oool000h0oooo0P0000020?oooa<0o`0000<000000?ng003o]`001`3o]`00
0`000000>?l003So000603So000300000000oj@00?nT00D00?nT00<00000002ao`00/Ol01000/Ol0
0`00000003[o000jo`02000jo`<0000000<0>@3o0000001l0?l0101l0?l00`000000l`3o0?<0o`09
0?<0o`800000903o0682000000X0l`3o00<0000007`0o`1l0?l00`1l0?l01@000000>@3o00000008
0?l0000000D003[o00<00000002ao`00/Ol00`00/Ol00`0000000?nT003oY005003oY0030000000h
o`00>?l000H0>?l000<000000?ng003o]`001`3o]`000`000000o`000?l0000@0?l000@0oooo0@00
00010?ooo`003P3oool010000000oooo0?ooo`3ooolB0?l000030000003o]`00okL000P0okL000<0
000003So000ho`001P0ho`000`0000000?nT003oY005003oY00300000000/Ol00;7o00@00;7o00<0
0000000jo`00>_l00P00>_l01P000000203o000000000000>@3o000000D0O03o00<000000?<0o`3c
0?l02P3c0?l200000200o`1R0P00000;0?<0o`030000001l0?l0O03o00<0O03o00H0000003T0o`0i
0?l0000000P0o`000004000jo`8000001@00/Ol00`0000000?nT003oY005003oY0030000000ho`00
>?l000L0>?l000<000000?ng003o]`001`3o]`000`000000o`000?l0000?0?l000@0oooo0@000001
0?ooo`003P3oool010000000oooo0?ooo`3ooolB0?l000030000003o]`00okL000L0okL000<00000
03So000ho`001`0ho`000`0000000?nT003oY005003oY00300000000/Ol00;7o00@00;7o00<00000
000jo`00>_l00P00>_l01P000000203o000000000000>@3o000000H0O03o00<000000?<0o`3c0?l0
2`3c0?l2000001`0o`1R0P00000<0?<0o`030000001l0?l0O03o00<0O03o00<0000003T0o`0i0?l0
0P0000000`080?l00000000jo`03000jo`0300000000/Ol00;7o00@00;7o00<00000003oY000oj@0
1@00oj@00`000000>?l003So000703So00030000003o]`00okL000L0okL000<000000?l0003o0000
3`3o00040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo4P3o00000`000000okL0
0?ng00070?ng00030000000ho`00>?l000L0>?l000<00000003oY000oj@01@00oj@00`0000000;7o
002ao`04002ao`0300000000>_l003[o008003[o00<0000000P0o`080?l00P0000000`0i0?l00000
07`0o`0507`0o`030000003c0?l0l`3o00`0l`3o0P00000H0?l0HP8000003@3c0?l00`000000O03o
07`0o`0407`0o`040000000i0?l0>@3o00000080203o00<00000000jo`00>_l00P00>_l00`000000
0;7o002ao`04002ao`0300000000oj@00?nT00H00?nT00<0000003So000ho`001`0ho`000`000000
okL00?ng00070?ng00030000003o0000o`0000h0o`00103oool100000040oooo000>0?ooo`040000
003oool0oooo0?oooa40o`0000<000000?ng003o]`001`3o]`000`000000>?l003So000703So0003
00000000oj@00?nT00H00?nT00<00000002ao`00/Ol01000/Ol00`00000003[o000jo`03000jo`06
000000080?l000000000000i0?l000001`1l0?l00`000000l`3o0?<0o`0=0?<0o`<000004P3o0683
000000h0l`3o00<0000007`0o`1l0?l0101l0?l00`000000>@3o03T0o`0200000080203o00D00000
000jo`00>_l003[o00000007002ao`0300000000oj@00?nT00H00?nT00<0000003So000ho`001`0h
o`000`000000okL00?ng00080?ng00030000003o0000o`0000d0o`00103oool100000040oooo000>
0?ooo`040000003oool0oooo0?oooa00o`0000<000000?ng003o]`00203o]`000`000000>?l003So
000703So000300000000oj@00?nT00H00?nT00<00000002ao`00/Ol01@00/Ol00`00000003[o000j
o`02000jo`04000000080?l0203o00000080>@3o00<0000007`0o`1l0?l0101l0?l00`000000l`3o
0?<0o`0@0?<0o`D000001`3o068600000140l`3o00<0000007`0o`1l0?l0101l0?l00`000000>@3o
03T0o`020000000300P0o`00000003[o00<003[o00<00000002ao`00/Ol01@00/Ol00`0000000?nT
003oY006003oY0030000000ho`00>?l000L0>?l000<000000?ng003o]`002@3o]`000`000000o`00
0?l0000<0?l000@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool?0?l000030000
003o]`00okL000P0okL000<0000003So000ho`00200ho`000`0000000?nT003oY006003oY0030000
0000/Ol00;7o00D00;7o00<00000000jo`00>_l00`00>_l01P000000203o000000000000>@3o0000
00L0O03o00<000000?<0o`3c0?l0503c0?l7000001H0l`3o00<0000007`0o`1l0?l0101l0?l00`00
0000>@3o03T0o`0200000080203o00<00000000jo`00>_l00P00>_l00`0000000;7o002ao`05002a
o`0300000000oj@00?nT00L00?nT00<0000003So000ho`001`0ho`000`000000okL00?ng00090?ng
00030000003o0000o`0000/0o`00103oool100000040oooo000>0?ooo`040000003oool0oooo0?oo
o`h0o`0000<000000?ng003o]`002@3o]`000`000000>?l003So000803So000300000000oj@00?nT
00H00?nT00<00000002ao`00/Ol01@00/Ol00`00000003[o000jo`03000jo`04000000080?l0203o
00000080>@3o00<0000007`0o`1l0?l01@1l0?l00`000000l`3o0?<0o`0_0?<0o`030000001l0?l0
O03o00D0O03o00<0000003T0o`0i0?l00P00000200P0o`0300000000>_l003[o008003[o00<00000
002ao`00/Ol01@00/Ol00`0000000?nT003oY007003oY0030000000ho`00>?l000L0>?l000<00000
0?ng003o]`002P3o]`000`000000o`000?l0000:0?l000@0oooo0@0000010?ooo`003P3oool20000
0080oooo3@3o00000`000000okL00?ng00090?ng00030000000ho`00>?l000T0>?l000<00000003o
Y000oj@01P00oj@00`0000000;7o002ao`05002ao`0300000000>_l003[o00<003[o00@0000000P0
o`080?l000000P0i0?l00`000000O03o07`0o`0607`0o`030000003c0?l0l`3o02d0l`3o00<00000
07`0o`1l0?l01@1l0?l01@000000>@3o03T0o`0i0?l0000000<0203o00<00000000jo`00>_l00P00
>_l00`0000000;7o002ao`05002ao`0300000000oj@00?nT00L00?nT00<0000003So000ho`00200h
o`000`000000okL00?ng000:0?ng00030000003o0000o`0000T0o`00103oool100000040oooo000>
0?ooo`040000003oool0oooo0?ooo``0o`0000<000000?ng003o]`002@3o]`000`000000>?l003So
000903So000300000000oj@00?nT00L00?nT00<00000002ao`00/Ol01@00/Ol00`00000003[o000j
o`04000jo`04000000080?l0000000000080>@3o00<0000007`0o`1l0?l01P1l0?l00`000000l`3o
0?<0o`0/0?<0o`030000001l0?l0O03o00D0O03o00<0000003T0o`0i0?l00P00000200P0o`030000
0000>_l003[o00<003[o00<00000002ao`00/Ol01@00/Ol00`0000000?nT003oY007003oY0030000
000ho`00>?l000P0>?l000<000000?ng003o]`002`3o]`000`000000o`000?l000080?l000@0oooo
0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool;0?l000030000003o]`00okL000X0okL0
00<0000003So000ho`002@0ho`000`0000000?nT003oY007003oY00300000000/Ol00;7o00D00;7o
00<00000000jo`00>_l01000>_l010000000203o00P0o`00000203T0o`030000001l0?l0O03o00L0
O03o00<000000?<0o`3c0?l0:P3c0?l00`000000O03o07`0o`0507`0o`050000000i0?l0>@3o03T0
o`0000000`080?l00`00000003[o000jo`03000jo`0300000000/Ol00;7o00D00;7o00<00000003o
Y000oj@02000oj@00`000000>?l003So000803So00030000003o]`00okL000/0okL000<000000?l0
003o00001`3o00040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo2@3o00020000
00`0okL000<0000003So000ho`002@0ho`000`0000000?nT003oY008003oY00300000000/Ol00;7o
00H00;7o00<00000000jo`00>_l00`00>_l00`000000203o00P0o`0200000080>@3o00<0000007`0
o`1l0?l01`1l0?l00`000000l`3o0?<0o`0W0?<0o`800000201l0?l01@000000>@3o03T0o`0i0?l0
000000<0203o00<00000000jo`00>_l00`00>_l00`0000000;7o002ao`06002ao`0300000000oj@0
0?nT00L00?nT00<0000003So000ho`002@0ho`000`000000okL00?ng000;0?ng00030000003o0000
o`0000H0o`00103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`P0o`0000<00000
0?ng003o]`002`3o]`000`000000>?l003So000:03So000300000000oj@00?nT00P00?nT00<00000
002ao`00/Ol01P00/Ol00`00000003[o000jo`04000jo`04000000080?l0000000000080>@3o00<0
000007`0o`1l0?l0201l0?l00`000000l`3o0?<0o`0U0?<0o`030000001l0?l0O03o00L0O03o00D0
000003T0o`0i0?l0>@3o0000000300P0o`0300000000>_l003[o00@003[o00<00000002ao`00/Ol0
1P00/Ol00`0000000?nT003oY007003oY0030000000ho`00>?l000T0>?l000<000000?ng003o]`00
303o]`000`000000o`000?l000050?l000@0oooo0@0000010?ooo`001`3oool4000000<0oooo00@0
00000?ooo`3oool0oooo1`3o00000`000000okL00?ng000<0?ng00030000000ho`00>?l000X0>?l0
00<00000003oY000oj@02000oj@00`0000000;7o002ao`06002ao`0300000000>_l003[o00@003[o
00<0000000P0o`080?l00P00000203T0o`030000001l0?l0O03o00P0O03o00<000000?<0o`3c0?l0
8`3c0?l00`000000O03o07`0o`0807`0o`050000000i0?l0>@3o03T0o`0000000`080?l00`000000
03[o000jo`04000jo`0300000000/Ol00;7o00H00;7o00<00000003oY000oj@02000oj@00`000000
>?l003So000903So00030000003o]`00okL000`0okL000<000000?l0003o0000103o00040?ooo`40
00000@3oool000L0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool60?l00003
0000003o]`00okL000`0okL000<0000003So000ho`002P0ho`000`0000000?nT003oY009003oY003
00000000/Ol00;7o00H00;7o00<00000000jo`00>_l01000>_l00`000000203o00P0o`02000000<0
>@3o00<0000007`0o`1l0?l0201l0?l200000280l`3o00<0000007`0o`1l0?l0201l0?l010000000
>@3o03T0o`0i0?l2000000<0203o00<00000000jo`00>_l01000>_l00`0000000;7o002ao`06002a
o`0300000000oj@00?nT00P00?nT00<0000003So000ho`002P0ho`000`000000okL00?ng000<0?ng
00800000103o00040?ooo`4000000@3oool000P0oooo00<000000?ooo`3oool00`3oool200000080
oooo103o0002000000h0okL000<0000003So000ho`002`0ho`000`0000000?nT003oY008003oY003
00000000/Ol00;7o00L00;7o00<00000000jo`00>_l01000>_l010000000203o00P0o`080?l20000
00<0>@3o00<0000007`0o`1l0?l02@1l0?l2000001h0l`3o0P00000:07`0o`030000000i0?l0>@3o
0080>@3o00D0000000P0o`080?l0203o00000007000jo`0300000000/Ol00;7o00H00;7o00<00000
003oY000oj@02@00oj@00`000000>?l003So000:03So00030000003o]`00okL000d0okL00P000002
0?l000<0oooo0P0000010?ooo`0000<0oooo0000000000000P0000040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool0oooo0P3o000200000100okL000<0000003So000ho`002P0ho`00
0`0000000?nT003oY009003oY00300000000/Ol00;7o00L00;7o00<00000000jo`00>_l01000>_l0
10000000203o00P0o`080?l2000000<0>@3o00<0000007`0o`1l0?l02`1l0?l00`000000l`3o0?<0
o`0J0?<0o`030000001l0?l0O03o00X0O03o00@0000003T0o`0i0?l0>@3o0P00000300P0o`030000
0000>_l003[o00@003[o00<00000002ao`00/Ol01`00/Ol00`0000000?nT003oY009003oY0030000
000ho`00>?l000/0>?l000<000000?ng003o]`003P3o]`02000000@0oooo0@0000010?ooo`001`3o
ool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo0?ooo`8000004@3o]`000`000000
>?l003So000:03So000300000000oj@00?nT00X00?nT00<00000002ao`00/Ol01`00/Ol00`000000
03[o000jo`05000jo`05000000080?l0203o00P0o`000000100i0?l00`000000O03o07`0o`0;07`0
o`800000603c0?l2000000`0O03o00<0000003T0o`0i0?l00P0i0?l2000000<0203o00<00000000j
o`00>_l01000>_l00`0000000;7o002ao`08002ao`0300000000oj@00?nT00T00?nT00<0000003So
000ho`002`0ho`000`000000okL00?ng000?0?ng00050000003oool0oooo0?ooo`0000000@3oool0
00P0oooo0P0000040?ooo`040000003oool0oooo0?oooa80okL000<0000003So000ho`002`0ho`00
0`0000000?nT003oY009003oY00300000000/Ol00;7o00P00;7o00<00000000jo`00>_l01@00>_l0
10000000203o00P0o`080?l2000000<0>@3o00<0000007`0o`1l0?l03@1l0?l00`000000l`3o0?<0
o`0C0?<0o`8000003P1l0?l010000000>@3o03T0o`0i0?l2000000<0203o00<00000000jo`00>_l0
1@00>_l00`0000000;7o002ao`08002ao`0300000000oj@00?nT00T00?nT00<0000003So000ho`00
300ho`000`000000okL00?ng000>0?ng00@0oooo0@0000010?ooo`003P3oool010000000oooo0?oo
o`3oool@0?ng008000003@0ho`000`0000000?nT003oY00:003oY00300000000/Ol00;7o00P00;7o
00<00000000jo`00>_l01@00>_l00`000000203o00P0o`0200P0o`030000000i0?l0>@3o0080>@3o
00<0000007`0o`1l0?l03@1l0?l3000000l0l`3o0`00000?07`0o`030000000i0?l0>@3o0080>@3o
0P00000300P0o`0300000000>_l003[o00D003[o00<00000002ao`00/Ol02000/Ol00`0000000?nT
003oY00:003oY0030000000ho`00>?l000`0>?l00P00000>0?ng00@0oooo0@0000010?ooo`003P3o
ool010000000oooo0?ooo`3oool?0?ng00030000000ho`00>?l000`0>?l000<00000003oY000oj@0
2`00oj@00`0000000;7o002ao`08002ao`0300000000>_l003[o00D003[o00<0000000P0o`080?l0
0P080?l00`000000>@3o03T0o`0303T0o`030000001l0?l0O03o00l0O03o100000070?<0o`@00000
4@1l0?l00`000000>@3o03T0o`0203T0o`030000000Q0?l0000000<0203o00<00000000jo`00>_l0
1@00>_l00`0000000;7o002ao`08002ao`0300000000oj@00?nT00/00?nT00<0000003So000ho`00
3@0ho`000`000000okL00?ng000;0?ng00@0oooo0@0000010?ooo`003P3oool010000000oooo0?oo
o`3oool=0?ng008000003`0ho`000`0000000?nT003oY00:003oY00300000000/Ol00;7o00T00;7o
00<00000000jo`00>_l01@00>_l00`000000203o00P0o`0300P0o`030000000i0?l0>@3o0080>@3o
00<0000007`0o`1l0?l04`1l0?l7000001D0O03o00<0000003T0o`0i0?l00P0i0?l2000000<0203o
00<00000000jo`00>_l01P00>_l00`0000000;7o002ao`09002ao`0300000000oj@00?nT00X00?nT
00<0000003So000ho`003P0ho`02000000/0okL0103oool100000040oooo000>0?ooo`040000003o
ool0oooo0?ooo`/0okL00P00000@03So000300000000oj@00?nT00/00?nT00<00000002ao`00/Ol0
2@00/Ol00`00000003[o000jo`06000jo`03000000080?l0203o0080203o00<0000003T0o`0i0?l0
0`0i0?l00`000000O03o07`0o`0]07`0o`030000000i0?l0>@3o0080>@3o00<000000240o`000000
0`080?l00`00000003[o000jo`06000jo`0300000000/Ol00;7o00T00;7o00<00000003oY000oj@0
2`00oj@00`000000>?l003So000?03So008000002@3o]`040?ooo`4000000@3oool000h0oooo0P00
00020?ooo`P0okL00`00000A03So000300000000oj@00?nT00`00?nT00<00000002ao`00/Ol02@00
/Ol00`00000003[o000jo`06000jo`03000000080?l0203o0080203o0P00000503T0o`030000001l
0?l0O03o02`0O03o00<0000003T0o`0i0?l00P0i0?l00`0000008@3o0000000300P0o`0300000000
>_l003[o00L003[o00<00000002ao`00/Ol02@00/Ol00`0000000?nT003oY00;003oY0030000000h
o`00>?l00100>?l00`0000060?ng00@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3o
ool60?ng008000004`0ho`000`0000000?nT003oY00<003oY00300000000/Ol00;7o00X00;7o00<0
0000000jo`00>_l01P00>_l00`000000203o00P0o`0300P0o`030000000i0?l0>@3o00<0>@3o00<0
000007`0o`1l0?l0:`1l0?l00`000000>@3o03T0o`0303T0o`80000010080?l00`00000003[o000j
o`07000jo`0300000000/Ol00;7o00T00;7o00<00000003oY000oj@03000oj@00`000000>?l003So
000B03So00800000103o]`040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo0`3o
]`03000001@0>?l000<00000003oY000oj@03@00oj@00`0000000;7o002ao`0:002ao`0300000000
>_l003[o00L003[o00<0000000P0o`080?l00P080?l2000000D0>@3o00<0000007`0o`1l0?l0:@1l
0?l00`000000>@3o03T0o`0403T0o`80000010080?l00`00000003[o000jo`07000jo`0300000000
/Ol00;7o00X00;7o00<00000003oY000oj@03000oj@00`000000>?l003So000C03So008000000P3o
]`040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo0`00000E03So008000003`00
oj@00`0000000;7o002ao`0;002ao`0300000000>_l003[o00L003[o00<0000000P0o`080?l00P08
0?l2000000H0>@3o00<0000007`0o`1l0?l09`1l0?l00`000000>@3o03T0o`0403T0o`8000001@08
0?l00`00000003[o000jo`07000jo`0300000000/Ol00;7o00/00;7o00<00000003oY000oj@03000
oj@2000001D0>?l00`0000030?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo5`0h
o`000`0000000?nT003oY00>003oY00300000000/Ol00;7o00/00;7o00<00000000jo`00>_l02000
>_l00`000000203o00P0o`0300P0o`8000001P0i0?l00`000000O03o07`0o`0U07`0o`030000000i
0?l0>@3o00D0>@3o00<0000000P0o`080?l010080?l00`00000003[o000jo`07000jo`0300000000
/Ol00;7o00`00;7o00<00000003oY000oj@03@00oj@00`000000>?l003So000D03So00@0oooo0@00
00010?ooo`003P3oool010000000oooo0?ooo`3ooolE03So008000004@00oj@00`0000000;7o002a
o`0;002ao`0300000000>_l003[o00P003[o00<0000000P0o`080?l00`080?l2000000L0>@3o00<0
000007`0o`1l0?l0901l0?l00`000000>@3o03T0o`0403T0o`8000001@080?l00`00000003[o000j
o`08000jo`0300000000/Ol00;7o00`00;7o00<00000003oY000oj@03P00oj@2000001@0>?l0103o
ool100000040oooo000>0?ooo`040000003oool0oooo0?oooa<0>?l00P00000B003oY00300000000
/Ol00;7o00`00;7o00<00000000jo`00>_l02000>_l00`000000203o00P0o`0300P0o`800000200i
0?l00`000000O03o07`0o`0R07`0o`030000000i0?l0>@3o00D0>@3o0P00000500P0o`0300000000
>_l003[o00T003[o00<00000002ao`00/Ol03000/Ol00`0000000?nT003oY00?003oY08000004P0h
o`040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo4P0ho`000`0000000?nT003o
Y00B003oY00300000000/Ol00;7o00/00;7o00<00000000jo`00>_l02@00>_l00`000000203o00P0
o`0400P0o`800000200i0?l00`000000O03o07`0o`0P07`0o`030000000i0?l0>@3o00D0>@3o0P00
000600P0o`0300000000>_l003[o00T003[o00<00000002ao`00/Ol03000/Ol00`0000000?nT003o
Y00A003oY0800000400ho`040?ooo`4000000@3oool000h0oooo0P0000020?ooo`l0>?l00`00000D
003oY00300000000/Ol00;7o00`00;7o00<00000000jo`00>_l02@00>_l00`000000203o00P0o`04
00P0o`800000200i0?l00`000000O03o07`0o`0O07`0o`030000000i0?l0>@3o00H0>@3o0P000006
00P0o`0300000000>_l003[o00T003[o00<00000002ao`00/Ol03@00/Ol00`0000000?nT003oY00B
003oY0<000003@0ho`040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo2`0ho`04
000001D00?nT0P00000?002ao`0300000000>_l003[o00T003[o00<0000000P0o`080?l010080?l0
0`0000008@3o0000000803T0o`8000007P1l0?l00`000000>@3o03T0o`0703T0o`8000001P080?l0
0`00000003[o000jo`09000jo`0300000000/Ol00;7o00h00;7o00<00000003oY000oj@05000oj@4
000000T0>?l0103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`P0>?l00`00000H
003oY00300000000/Ol00;7o00l00;7o00<00000000jo`00>_l02@00>_l00`000000203o00P0o`05
00P0o`8000002P0i0?l00`000000O03o07`0o`0I07`0o`8000002@0i0?l2000000L0203o00<00000
000jo`00>_l02P00>_l00`0000000;7o002ao`0>002ao`0300000000oj@00?nT01L00?nT0`000006
03So00@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool8000001X00?nT00<00000
002ao`00/Ol03`00/Ol00`00000003[o000jo`0;000jo`03000000080?l0203o00@0203o00<00000
0240o`0000002P0i0?l2000001P0O03o00<0000003T0o`0i0?l02@0i0?l2000000L0203o00<00000
000jo`00>_l02P00>_l00`0000000;7o002ao`0?002ao`8000006P00oj@7000000<0oooo0@000001
0?ooo`003P3oool010000000oooo0?ooo`3ooolP003oY08000004P00/Ol00`00000003[o000jo`0;
000jo`03000000080?l0203o00D0203o0P00000<03T0o`030000001l0?l0O03o01<0O03o0P00000;
03T0o`80000020080?l00`00000003[o000jo`0;000jo`0300000000/Ol00;7o01000;7o0P00000N
003oY0@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3ooolO003oY00300000000/Ol0
0;7o01400;7o00<00000000jo`00>_l03000>_l00`000000203o00P0o`0500P0o`030000000Q0?l0
000000`0>@3o0P00000A07`0o`8000003@0i0?l2000000P0203o00<00000000jo`00>_l02`00>_l0
0`0000000;7o002ao`0B002ao`0300000000oj@00?nT01/00?nT103oool100000040oooo000>0?oo
o`040000003oool0oooo0?oooad00?nT0P00000C002ao`0300000000>_l003[o00d003[o00<00000
00P0o`080?l01@080?l00`0000008@3o0000000>03T0o`8000003@1l0?l2000000l0>@3o0P000008
00P0o`0300000000>_l003[o00`003[o00<00000002ao`00/Ol04P00/Ol00`0000000?nT003oY00J
003oY0@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3ooolK003oY08000005@00/Ol0
0`00000003[o000jo`0=000jo`03000000080?l0203o00H0203o0P00000@03T0o`<000001`1l0?l3
00000100>@3o0P00000900P0o`0300000000>_l003[o00d003[o00<00000002ao`00/Ol04P00/Ol2
000001X00?nT103oool100000040oooo000>0?ooo`8000000P3ooolI003oY08000005P00/Ol00`00
000003[o000jo`0>000jo`03000000080?l0203o00H0203o00<000000240o`0000004P0i0?l70000
01<0>@3o0P00000900P0o`0300000000>_l003[o00d003[o00<00000002ao`00/Ol05000/Ol20000
01P00?nT103oool100000040oooo000>0?ooo`040000003oool0oooo0?oooaD00?nT1000000G002a
o`0300000000>_l003[o00l003[o00<0000000P0o`080?l01`080?l2000002/0>@3o00<000000240
o`0000002@080?l00`00000003[o000jo`0>000jo`0300000000/Ol00;7o01D00;7o1000000D003o
Y0@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool@003oY0D000006`00/Ol00`00
000003[o000jo`0?000jo`03000000080?l0203o00L0203o00<000000240o`000000:P0i0?l20000
00X0203o00<00000000jo`00>_l03`00>_l00`0000000;7o002ao`0H002ao`H000003P00oj@40?oo
o`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo4000000O002ao`0300000000>_l003[o
010003[o00<0000000P0o`080?l020080?l2000002T0>@3o00<000000240o`0000002P080?l00`00
000003[o000jo`0@000jo`0300000000/Ol00;7o01d00;7o3`0000030?ooo`4000000@3oool000h0
oooo00@000000?ooo`3oool0oooo;P00/Ol00`00000003[o000jo`0A000jo`03000000080?l0203o
00P0203o0P00000X03T0o`040000000Q0?l08@3o000000X0203o00<00000000jo`00>_l04@00>_l0
0`0000000;7o002ao`0Z002ao`@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool]
002ao`0300000000>_l003[o014003[o00<0000000P0o`080?l02P080?l2000002L0>@3o00<00000
0240o`0000002`080?l00`00000003[o000jo`0B000jo`0300000000/Ol00;7o02T00;7o103oool1
00000040oooo000>0?ooo`040000003oool0oooo0?ooob/00;7o0P00000D000jo`03000000080?l0
203o00X0203o0P00000V03T0o`040000000Q0?l08@3o000000/0203o00<00000000jo`00>_l04`00
>_l2000002T00;7o103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooobX00;7o00<0
0000000jo`00>_l05000>_l00`000000203o00P0o`0:00P0o`030000000Q0?l0000002D0>@3o00@0
00000240o`0Q0?l0000030080?l00`00000003[o000jo`0D000jo`0300000000/Ol00;7o02H00;7o
103oool100000040oooo000>0?ooo`8000000P3oool3000002D00;7o0P00000F000jo`0300000008
0?l0203o00`0203o0P00000T03T0o`040000000Q0?l08@3o000000d0203o00<00000000jo`00>_l0
5@00>_l2000002@00;7o0`0000030?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo
0`00>_l4000001h00;7o0`00000H000jo`03000000080?l0203o00`0203o00<000000240o`000000
8`0i0?l0100000008@3o0240o`00000=00P0o`0300000000>_l003[o01L003[o0P00000O002ao`<0
00000P00>_l40?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo1P00>_l3000001P0
0;7o1000000J000jo`03000000080?l0203o00d0203o00@000000240o`0Q0?l000008P0i0?l01000
00008@3o0240o`00000>00P0o`0300000000>_l003[o01P003[o1000000I002ao`<000001000>_l4
0?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo2@00>_l<000000H00;7o1P00000N
000jo`03000000080?l0203o00d0203o00@000000240o`0Q0?l000008@0i0?l0100000008@3o0240
o`00000?00P0o`0300000000>_l003[o01`003[o1P000007002ao``000001`00>_l40?ooo`400000
0@3oool000h0oooo00@000000?ooo`3oool0oooo5@00>_l6000002<003[o00<0000000P0o`080?l0
3P080?l01@0000008@3o0240o`0Q0?l000000200>@3o00@000000240o`0Q0?l0000040080?l00`00
000003[o000jo`0Q000jo`L000004`00>_l40?ooo`4000000@3oool000h0oooo00@000000?ooo`3o
ool0oooo0P00000l000jo`03000000080?l0203o00l0203o00@000000240o`0Q0?l000007`0i0?l0
1@0000008@3o0240o`0Q0?l000000140203o00<00000000jo`00>_l0>@00>_l2000000<0oooo0@00
00010?ooo`001`3oool500000080oooo00@000000?ooo`3oool0oooo0P080?l3000003P003[o00<0
000000P0o`080?l040080?l01@0000008@3o0240o`0Q0?l0000001h0>@3o00@000000240o`0Q0?l0
00004P080?l00`00000003[o000jo`0g000jo`80000000<0203o0?ooo`3oool00P3oool100000040
oooo00090?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0`00000200P0o`D0
0000<`00>_l00`000000203o00P0o`0@00P0o`050000000Q0?l08@3o0240o`0000007@0i0?l01@00
00008@3o0240o`0Q0?l0000001<0203o00<00000000jo`00>_l0<@00>_l500000080203o0P000003
0?ooo`4000000@3oool000T0oooo00<000000?ooo`3oool00P3oool200000080oooo0P0i0?l30000
00D0203o1000000]000jo`8000004`080?l00`0000008@3o0240o`020240o`030000000i0?l0>@3o
01T0>@3o00<000000240o`0Q0?l00P0Q0?l00`000000203o00P0o`0B00P0o`0300000000>_l003[o
02`003[o1000000500P0o`80000000@0>@3o0?ooo`3oool0oooo0P0000010?ooo`0000<0oooo0000
000000000P0000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
03T0o`<000001P080?l3000002T003[o00<0000000P0o`080?l050080?l00`0000008@3o0240o`02
0240o`030000000i0?l0>@3o01P0>@3o00<000000240o`0Q0?l00P0Q0?l00`000000203o00P0o`0C
00P0o`0300000000>_l003[o02P003[o0`00000600P0o`<000000`0i0?l01@000000oooo0?ooo`3o
ool000000040oooo00090?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo07`0
o`02000000@0>@3o1000000600P0o`<000009@00>_l00`000000203o00P0o`0E00P0o`030000000Q
0?l08@3o00808@3o00<0000003T0o`0i0?l05`0i0?l00`0000008@3o0240o`020240o`0300000008
0?l0203o01D0203o0P00000U000jo`<000001P080?l4000000<0>@3o0P0000040?ooo`4000000@3o
ool000P0oooo0P0000040?ooo`040000003oool0oooo0?ooo`<0O03o0P00000403T0o`@000001`08
0?l20000024003[o0P00000I00P0o`030000000Q0?l08@3o00808@3o00<0000003T0o`0i0?l05P0i
0?l00`0000008@3o0240o`020240o`03000000080?l0203o01L0203o00<00000000jo`00>_l07`00
>_l3000000L0203o1000000303T0o`8000000P1l0?l40?ooo`4000000@3oool000h0oooo00@00000
0?ooo`3oool0oooo1@1l0?l2000000@0>@3o1000000700P0o`<000007@00>_l00`000000203o00P0
o`0I00P0o`030000000Q0?l08@3o00<08@3o00<0000003T0o`0i0?l0500i0?l00`0000008@3o0240
o`030240o`03000000080?l0203o01P0203o0P00000L000jo`<0000020080?l4000000@0>@3o00<0
000007`0o`1l0?l00P1l0?l40?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo1`1l
0?l2000000@0>@3o1000000800P0o`L000004P00>_l4000001`0203o00<000000240o`0Q0?l00`0Q
0?l00`000000>@3o03T0o`0D03T0o`030000000Q0?l08@3o00<08@3o00<0000000P0o`080?l06P08
0?l30000018003[o1`00000900P0o`<000001@0i0?l2000000D0O03o103oool100000040oooo000>
0?ooo`050000003oool0oooo0?ooo`000000201l0?l2000000D0>@3o1000000<00P0oa8000008008
0?l00`0000008@3o0240o`040240o`030000000i0?l0>@3o0180>@3o00<000000240o`0Q0?l0100Q
0?l00`000000203o00P0o`0M00P0oa8000003@080?l3000000H0>@3o0P00000707`0o`050000003o
ool0oooo0?ooo`0000000@3oool000h0oooo00D000000?ooo`3oool0oooo0?<0o`02000000P0O03o
0P00000603T0o`<00000?0080?l00`0000008@3o0240o`050240o`030000000i0?l0>@3o0100>@3o
00<000000240o`0Q0?l01@0Q0?l00`000000203o00P0o`0i00P0o`@000001P0i0?l2000000P0O03o
00<000000?ooo`3oool00P3oool100000040oooo000>0?ooo`8000000P3oool30?<0o`030000001l
0?l0O03o00L0O03o0P00000603T0o`@00000>@080?l00`0000008@3o0240o`060240o`030000000i
0?l0>@3o00d0>@3o0P0000070240o`03000000080?l0203o03L0203o1@00000603T0o`800000201l
0?l2000000030?<0o`3oool0oooo0080oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3o
ool40?<0o`8000002@1l0?l2000000H0>@3o1@00000f00P0o`030000000Q0?l08@3o00L08@3o00<0
000003T0o`0i0?l02`0i0?l00`0000008@3o0240o`070240o`03000000080?l0203o03@0203o0`00
00000`0Q0?l000000000000603T0o`8000002@1l0?l010000000l`3o0?<0o`3c0?l40?ooo`400000
0@3oool000h0oooo00@000000?ooo`3oool0oooo1P3c0?l00`000000O03o07`0o`0807`0o`800000
1P0i0?l2000000030240o`000000000003@0203o00<000000240o`0Q0?l0200Q0?l00`000000>@3o
03T0o`0903T0o`030000000Q0?l08@3o00P08@3o00<0000000P0o`080?l0<P080?l2000000808@3o
0P00000603T0o`8000002P1l0?l00`000000l`3o0?<0o`020?<0o`@0oooo0@0000010?ooo`003P3o
ool010000000oooo0?ooo`3oool70?<0o`030000001l0?l0O03o00P0O03o00<0000003T0o`0i0?l0
1P0i0?l500000380203o00<000000240o`0Q0?l02@0Q0?l;000000/08@3o00<0000000P0o`080?l0
<@080?l5000000L0>@3o00<0000007`0o`1l0?l02@1l0?l00`000000l`3o0?<0o`030?<0o`@0oooo
0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool80?<0o`030000001l0?l0O03o00P0O03o
0P00000903T0o`@00000<0080?l00`0000008@3o0240o`0O0240o`03000000080?l0203o02h0203o
1000000903T0o`8000002`1l0?l00`000000l`3o0?<0o`040?<0o`@0oooo0@0000010?ooo`003P3o
ool010000000oooo0?ooo`3oool90?<0o`8000002P1l0?l2000000T0>@3o1@00000]00P0o`030000
000Q0?l08@3o01l08@3o00<0000000P0o`080?l0:`080?l5000000T0>@3o0P00000;07`0o`800000
1`3c0?l40?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo2`3c0?l00`000000O03o
07`0o`0907`0o`8000002@0i0?l6000002X0203o00<000000240o`0Q0?l0800Q0?l00`000000203o
00P0o`0X00P0o`D000002P0i0?l00`000000O03o07`0o`0:07`0o`030000003c0?l0l`3o00L0l`3o
103oool100000040oooo000>0?ooo`050000003oool0oooo0?ooo`0000002`3c0?l00`000000O03o
07`0o`0:07`0o`8000002P0i0?l6000002L0203o00<000000240o`0Q0?l0800Q0?l00`000000203o
00P0o`0U00P0o`D000002`0i0?l2000000`0O03o00<000000?<0o`3c0?l0203c0?l01@000000oooo
0?ooo`3oool000000040oooo000>0?ooo`8000000P3oool00`3o068000000?<0o`0:0?<0o`030000
001l0?l0O03o00/0O03o0P00000;03T0o`80000000@08@3o000000000000000090080?l00`000000
8@3o0240o`0P0240o`03000000080?l0203o0280203o1P00000;03T0o`800000301l0?l2000000X0
l`3o00<000000?ooo`3oool00P3oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`80
o`1R00<000000?<0o`3c0?l02@3c0?l00`000000O03o07`0o`0;07`0o`030000000i0?l0>@3o00/0
>@3o0P0000020240o`<0000080080?l00`0000008@3o0240o`0R0240o`03000000080?l0203o01h0
203o0`0000000`0Q0?l000000000000=03T0o`030000001l0?l0O03o00/0O03o00<000000?<0o`3c
0?l02@3c0?l00`000000o`1R0?ooo`030?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0
oooo0P3o06800`000000l`3o0?<0o`0:0?<0o`030000001l0?l0O03o00/0O03o00<0000003T0o`0i
0?l0300i0?l2000000<08@3o0`00000L00P0o`030000000Q0?l08@3o02@08@3o00<0000000P0o`08
0?l06P080?l3000000808@3o0P00000>03T0o`030000001l0?l0O03o00/0O03o00<000000?<0o`3c
0?l02P3c0?l00`000000o`1R0?ooo`030?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0
oooo0`3o06800`000000l`3o0?<0o`0:0?<0o`030000001l0?l0O03o00/0O03o0P00000>03T0o`80
0000100Q0?l3000001P0203o00<000000240o`0Q0?l09P0Q0?l00`000000203o00P0o`0F00P0o`<0
0000100Q0?l00`000000>@3o03T0o`0=03T0o`030000001l0?l0O03o00`0O03o00<000000?<0o`3c
0?l02@3c0?l00`000000o`1R0?l0HP040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0
oooo103o06800`000000l`3o0?<0o`0:0?<0o`030000001l0?l0O03o00`0O03o00<0000003T0o`0i
0?l03@0i0?l2000000D08@3o0P00000E00P0o`030000000Q0?l08@3o02P08@3o00<0000000P0o`08
0?l04P080?l3000000D08@3o0P00000>03T0o`8000003P1l0?l00`000000l`3o0?<0o`090?<0o`04
0000003o0680o`1R0?l0HP@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool40?l0
HP030000003c0?l0l`3o00/0l`3o00<0000007`0o`1l0?l0301l0?l2000000l0>@3o0P0000050240
o`@0000040080?l00`0000008@3o0240o`0Z0240o`03000000080?l0203o00d0203o100000060240
o`8000003`0i0?l00`000000O03o07`0o`0=07`0o`030000003c0?l0l`3o00X0l`3o00@000000?l0
HP3o0680o`1R103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`D0o`1R00<00000
0?<0o`3c0?l02`3c0?l00`000000O03o07`0o`0=07`0o`030000000i0?l0>@3o00h0>@3o0P000007
0240o`H000001`080?l3000002h08@3o0`00000600P0o`H000001`0Q0?l300000100>@3o00<00000
07`0o`1l0?l03@1l0?l00`000000l`3o0?<0o`0:0?<0o`030000003o0680o`1R0080o`1R103oool1
00000040oooo000>0?ooo`040000003oool0oooo0?ooo`H0o`1R00<000000?<0o`3c0?l02P3c0?l0
0`000000O03o07`0o`0=07`0o`030000000i0?l0>@3o0100>@3o0P00000;0240o`L00000=00Q0?l6
000000/08@3o0P00000B03T0o`030000001l0?l0O03o00d0O03o00<000000?<0o`3c0?l02`3c0?l0
0`000000o`1R0?l0HP020?l0HP@0oooo0@0000010?ooo`003P3oool200000080oooo1P3o06800`00
0000l`3o0?<0o`0;0?<0o`030000001l0?l0O03o00d0O03o00<0000003T0o`0i0?l04@0i0?l20000
05<08@3o0P00000C03T0o`030000001l0?l0O03o00h0O03o00<000000?<0o`3c0?l02P3c0?l00`00
0000o`1R0?l0HP030?l0HP@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool70?l0
HP030000003c0?l0l`3o00X0l`3o00<0000007`0o`1l0?l03P1l0?l00`000000>@3o03T0o`0B03T0
o`030000000Q0?l08@3o04l08@3o00<0000003T0o`0i0?l04P0i0?l00`000000O03o07`0o`0>07`0
o`030000003c0?l0l`3o00/0l`3o00<000000?l0HP3o06800`3o06840?ooo`4000000@3oool000h0
oooo00@000000?ooo`3oool0oooo1`3o06800`000000l`3o0?<0o`0;0?<0o`030000001l0?l0O03o
00d0O03o00<0000003T0o`0i0?l04`0i0?l2000004d08@3o0P00000E03T0o`030000001l0?l0O03o
00d0O03o00<000000?<0o`3c0?l02`3c0?l00`000000o`1R0?l0HP040?l0HP@0oooo0@0000010?oo
o`003P3oool010000000oooo0?ooo`3oool80?l0HP030000003c0?l0l`3o00X0l`3o00<0000007`0
o`1l0?l03P1l0?l00`000000>@3o03T0o`0D03T0o`800000B@0Q0?l2000001H0>@3o00<0000007`0
o`1l0?l03P1l0?l00`000000l`3o0?<0o`0;0?<0o`030000003o0680o`1R00@0o`1R103oool10000
0040oooo000>0?ooo`040000003oool0oooo0?ooo`P0o`1R00<000000?<0o`3c0?l02`3c0?l00`00
0000O03o07`0o`0>07`0o`030000000i0?l0>@3o01D0>@3o0P0000150240o`8000005`0i0?l00`00
0000O03o07`0o`0>07`0o`030000003c0?l0l`3o00/0l`3o00<000000?l0HP3o06801@3o06840?oo
o`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo203o06800`000000l`3o0?<0o`0;0?<0
o`030000001l0?l0O03o00l0O03o00<0000003T0o`0i0?l05P0i0?l00`0000008@3o0240o`110240
o`030000000i0?l0>@3o01L0>@3o00<0000007`0o`1l0?l03P1l0?l00`000000l`3o0?<0o`0;0?<0
o`030000003o0680o`1R00D0o`1R103oool100000040oooo000>0?ooo`040000003oool0oooo0?oo
o`T0o`1R00<000000?<0o`3c0?l02`3c0?l00`000000O03o07`0o`0>07`0o`030000000i0?l0>@3o
01L0>@3o00<000000240o`0Q0?l0?`0Q0?l00`000000>@3o03T0o`0G03T0o`030000001l0?l0O03o
00h0O03o00<000000?<0o`3c0?l0303c0?l00`000000o`1R0?l0HP050?l0HP@0oooo0@0000010?oo
o`003P3oool010000000oooo0?ooo`3oool90?l0HP030000003c0?l0l`3o00/0l`3o00<0000007`0
o`1l0?l03`1l0?l00`000000>@3o03T0o`0F03T0o`030000000Q0?l08@3o03h08@3o00<0000003T0
o`0i0?l0600i0?l00`000000O03o07`0o`0>07`0o`030000003c0?l0l`3o00/0l`3o00<000000?l0
HP3o06801P3o06840?ooo`4000000@3oool000h0oooo0P0000020?ooo`T0o`1R00<000000?<0o`3c
0?l02`3c0?l00`000000O03o07`0o`0?07`0o`030000000i0?l0>@3o01L0>@3o00<000000240o`0Q
0?l0?@0Q0?l00`000000>@3o03T0o`0G03T0o`030000001l0?l0O03o00l0O03o00<000000?<0o`3c
0?l02`3c0?l00`000000o`1R0?l0HP060?l0HP@0oooo0@0000010?ooo`003P3oool010000000oooo
0?ooo`3oool:0?l0HP030000003c0?l0l`3o00/0l`3o00<0000007`0o`1l0?l03`1l0?l00`000000
>@3o03T0o`0G03T0o`030000000Q0?l08@3o03/08@3o00<0000003T0o`0i0?l0600i0?l00`000000
O03o07`0o`0>07`0o`030000003c0?l0l`3o00`0l`3o00<000000?l0HP3o06801P3o06840?ooo`40
00000@3oool000h0oooo00@000000?ooo`3oool0oooo2P3o06800`000000l`3o0?<0o`0;0?<0o`03
0000001l0?l0O03o00l0O03o00<0000003T0o`0i0?l0600i0?l00`0000008@3o0240o`0i0240o`03
0000000i0?l0>@3o01P0>@3o00<0000007`0o`1l0?l03`1l0?l00`000000l`3o0?<0o`0<0?<0o`03
0000003o0680o`1R00H0o`1R103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`X0
o`1R00<000000?<0o`3c0?l02`3c0?l00`000000O03o07`0o`0?07`0o`030000000i0?l0>@3o01T0
>@3o00<000000240o`0Q0?l0=`0Q0?l00`000000>@3o03T0o`0I03T0o`030000001l0?l0O03o00l0
O03o00<000000?<0o`3c0?l0303c0?l00`000000o`1R0?l0HP060?l0HP@0oooo0@0000010?ooo`00
3P3oool010000000oooo0?ooo`3oool:0?l0HP030000003c0?l0l`3o00/0l`3o00<0000007`0o`1l
0?l03`1l0?l00`000000>@3o03T0o`0I03T0o`030000000Q0?l08@3o03L08@3o00<0000003T0o`0i
0?l06@0i0?l00`000000O03o07`0o`0?07`0o`030000003c0?l0l`3o00`0l`3o00<000000?l0HP3o
06801P3o06840?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo2P3o06800`000000
l`3o0?<0o`0;0?<0o`030000001l0?l0O03o00l0O03o00<0000003T0o`0i0?l06@0i0?l00`000000
8@3o0240o`0g0240o`030000000i0?l0>@3o01P0>@3o00<0000007`0o`1l0?l03`1l0?l00`000000
l`3o0?<0o`0<0?<0o`030000003o0680o`1R00L0o`1R103oool100000040oooo00080?ooo`800000
103oool010000000oooo0?ooo`3oool;0?l0HP030000003c0?l0l`3o00/0l`3o00<0000007`0o`1l
0?l03`1l0?l00`000000>@3o03T0o`0I03T0o`030000000Q0?l08@3o03H08@3o00<0000003T0o`0i
0?l0600i0?l00`000000O03o07`0o`0?07`0o`030000003c0?l0l`3o00`0l`3o00<000000?l0HP3o
06801`3o06840?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool000000`3oool010000000
oooo0?ooo`3oool;0?l0HP030000003c0?l0l`3o00/0l`3o00<0000007`0o`1l0?l03`1l0?l00`00
0000>@3o03T0o`0I03T0o`030000000Q0?l08@3o03H08@3o00<0000003T0o`0i0?l0600i0?l00`00
0000O03o07`0o`0?07`0o`030000003c0?l0l`3o00`0l`3o00<000000?l0HP3o06801`3o06840?oo
o`4000000@3oool000L0oooo00@000000?ooo`3oool000000`3oool200000080oooo2`3o06800`00
0000l`3o0?<0o`0;0?<0o`030000001l0?l0O03o00l0O03o00<0000003T0o`0i0?l06@0i0?l00`00
00008@3o0240o`0f0240o`030000000i0?l0>@3o01P0>@3o00<0000007`0o`1l0?l03`1l0?l00`00
0000l`3o0?<0o`0<0?<0o`030000003o0680o`1R00L0o`1R0`3oool200000040oooo00070?ooo`04
0000003oool0oooo000000<0oooo00@000000?ooo`3oool0oooo2`3o06800`000000l`3o0?<0o`0;
0?<0o`030000001l0?l0O03o00l0O03o00<0000003T0o`0i0?l06@0i0?l00`0000008@3o0240o`0f
0240o`030000000i0?l0>@3o01P0>@3o00<0000007`0o`1l0?l03`1l0?l00`000000l`3o0?<0o`0<
0?<0o`030000003o0680o`1R00L0o`1R103oool100000040oooo00070?ooo`040000003oool0oooo
000000<0oooo00@000000?ooo`3oool0oooo2`3o06800`000000l`3o0?<0o`0;0?<0o`030000001l
0?l0O03o00l0O03o00<0000003T0o`0i0?l0600i0?l00`0000008@3o0240o`0g0240o`030000000i
0?l0>@3o01P0>@3o00<0000007`0o`1l0?l03`1l0?l00`000000l`3o0?<0o`0<0?<0o`030000003o
0680o`1R00L0o`1R103oool100000040oooo00080?ooo`800000103oool010000000oooo0?ooo`3o
ool:0?l0HP030000003c0?l0l`3o00/0l`3o00<0000007`0o`1l0?l03`1l0?l00`000000>@3o03T0
o`0I03T0o`030000000Q0?l08@3o03L08@3o00<0000003T0o`0i0?l0600i0?l00`000000O03o07`0
o`0?07`0o`030000003c0?l0l`3o00`0l`3o00<000000?l0HP3o06801`3o06840?ooo`4000000@3o
ool000h0oooo00@000000?ooo`3oool0oooo2P3o06800`000000l`3o0?<0o`0;0?<0o`030000001l
0?l0O03o00l0O03o00<0000003T0o`0i0?l06@0i0?l00`0000008@3o0240o`0g0240o`030000000i
0?l0>@3o01T0>@3o00<0000007`0o`1l0?l03`1l0?l00`000000l`3o0?<0o`0<0?<0o`030000003o
0680o`1R00H0o`1R103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`X0o`1R00<0
00000?<0o`3c0?l02`3c0?l00`000000O03o07`0o`0?07`0o`030000000i0?l0>@3o01P0>@3o00<0
00000240o`0Q0?l0>00Q0?l00`000000>@3o03T0o`0I03T0o`030000001l0?l0O03o00l0O03o00<0
00000?<0o`3c0?l0303c0?l00`000000o`1R0?l0HP060?l0HP@0oooo0@0000010?ooo`003P3oool0
10000000oooo0?ooo`3oool:0?l0HP030000003c0?l0l`3o00/0l`3o00<0000007`0o`1l0?l03`1l
0?l00`000000>@3o03T0o`0H03T0o`030000000Q0?l08@3o03T08@3o00<0000003T0o`0i0?l0600i
0?l00`000000O03o07`0o`0?07`0o`030000003c0?l0l`3o00`0l`3o00<000000?l0HP3o06801P3o
06840?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo2P3o06800`000000l`3o0?<0
o`0;0?<0o`030000001l0?l0O03o00l0O03o00<0000003T0o`0i0?l05`0i0?l00`0000008@3o0240
o`0k0240o`030000000i0?l0>@3o01P0>@3o00<0000007`0o`1l0?l03P1l0?l00`000000l`3o0?<0
o`0<0?<0o`030000003o0680o`1R00H0o`1R103oool100000040oooo000>0?ooo`8000000P3oool9
0?l0HP030000003c0?l0l`3o00/0l`3o00<0000007`0o`1l0?l03`1l0?l00`000000>@3o03T0o`0G
03T0o`030000000Q0?l08@3o03d08@3o00<0000003T0o`0i0?l05`0i0?l00`000000O03o07`0o`0?
07`0o`030000003c0?l0l`3o00/0l`3o00<000000?l0HP3o06801P3o06840?ooo`4000000@3oool0
00h0oooo00@000000?ooo`3oool0oooo2@3o06800`000000l`3o0?<0o`0;0?<0o`030000001l0?l0
O03o00l0O03o00<0000003T0o`0i0?l05P0i0?l00`0000008@3o0240o`0o0240o`030000000i0?l0
>@3o01L0>@3o00<0000007`0o`1l0?l03P1l0?l00`000000l`3o0?<0o`0<0?<0o`030000003o0680
o`1R00D0o`1R103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`P0o`1R00<00000
0?<0o`3c0?l02`3c0?l00`000000O03o07`0o`0?07`0o`030000000i0?l0>@3o01H0>@3o00<00000
0240o`0Q0?l0@@0Q0?l00`000000>@3o03T0o`0F03T0o`030000001l0?l0O03o00h0O03o00<00000
0?<0o`3c0?l0303c0?l00`000000o`1R0?l0HP050?l0HP@0oooo0@0000010?ooo`003P3oool01000
0000oooo0?ooo`3oool80?l0HP030000003c0?l0l`3o00/0l`3o00<0000007`0o`1l0?l03P1l0?l0
0`000000>@3o03T0o`0E03T0o`800000A@0Q0?l2000001L0>@3o00<0000007`0o`1l0?l03P1l0?l0
0`000000l`3o0?<0o`0;0?<0o`030000003o0680o`1R00D0o`1R103oool100000040oooo000>0?oo
o`040000003oool0oooo0?ooo`P0o`1R00<000000?<0o`3c0?l02P3c0?l00`000000O03o07`0o`0>
07`0o`030000000i0?l0>@3o01D0>@3o00<000000240o`0Q0?l0A`0Q0?l00`000000>@3o03T0o`0E
03T0o`030000001l0?l0O03o00h0O03o00<000000?<0o`3c0?l02`3c0?l00`000000o`1R0?l0HP04
0?l0HP@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool70?l0HP030000003c0?l0
l`3o00/0l`3o00<0000007`0o`1l0?l03P1l0?l00`000000>@3o03T0o`0C03T0o`800000B`0Q0?l2
000001D0>@3o00<0000007`0o`1l0?l03P1l0?l00`000000l`3o0?<0o`0;0?<0o`030000003o0680
o`1R00@0o`1R103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`L0o`1R00<00000
0?<0o`3c0?l02P3c0?l00`000000O03o07`0o`0>07`0o`030000000i0?l0>@3o01<0>@3o00<00000
0240o`0Q0?l0C@0Q0?l00`000000>@3o03T0o`0C03T0o`030000001l0?l0O03o00h0O03o00<00000
0?<0o`3c0?l02`3c0?l00`000000o`1R0?l0HP030?l0HP@0oooo0@0000010?ooo`003P3oool01000
0000oooo0?ooo`3oool60?l0HP030000003c0?l0l`3o00/0l`3o00<0000007`0o`1l0?l03@1l0?l0
0`000000>@3o03T0o`0B03T0o`800000D@0Q0?l2000001@0>@3o00<0000007`0o`1l0?l03P1l0?l0
0`000000l`3o0?<0o`0:0?<0o`030000003o0680o`1R00<0o`1R103oool100000040oooo000>0?oo
o`8000000P3oool60?l0HP030000003c0?l0l`3o00X0l`3o00<0000007`0o`1l0?l03P1l0?l00`00
0000>@3o03T0o`0@03T0o`800000E@0Q0?l200000180>@3o00<0000007`0o`1l0?l03P1l0?l00`00
0000l`3o0?<0o`0;0?<0o`030000003o0680o`1R0080o`1R103oool100000040oooo000>0?ooo`04
0000003oool0oooo0?ooo`D0o`1R00<000000?<0o`3c0?l02`3c0?l00`000000O03o07`0o`0=07`0
o`030000000i0?l0>@3o00l0>@3o0P0000070240o`l00000;P0Q0?l>000000L08@3o0P00000A03T0
o`8000003`1l0?l00`000000l`3o0?<0o`0:0?<0o`030000003o0680o`1R0080o`1R103oool10000
0040oooo000>0?ooo`040000003oool0oooo0?ooo`@0o`1R00<000000?<0o`3c0?l02`3c0?l00`00
0000O03o07`0o`0=07`0o`030000000i0?l0>@3o0100>@3o00<000000240o`0Q0?l0100Q0?l20000
00l0203o00<000000240o`0Q0?l0:P0Q0?l00`000000203o00P0o`0<00P0o`8000001`0Q0?l00`00
0000>@3o03T0o`0@03T0o`030000001l0?l0O03o00`0O03o00<000000?<0o`3c0?l02`3c0?l01000
0000o`1R0?l0HP3o06840?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo103o0680
0`000000l`3o0?<0o`0;0?<0o`030000001l0?l0O03o00`0O03o00<0000003T0o`0i0?l03`0i0?l2
000000<08@3o1000000B00P0o`030000000Q0?l08@3o02P08@3o00<0000000P0o`080?l03`080?l4
000000@08@3o0P00000A03T0o`030000001l0?l0O03o00`0O03o00<000000?<0o`3c0?l02P3c0?l0
10000000o`1R0?l0HP3o06840?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo0`3o
06800`000000l`3o0?<0o`0;0?<0o`030000001l0?l0O03o00/0O03o0P00000@03T0o`80000000<0
8@3o0000000000000P00000G00P0o`030000000Q0?l08@3o02H08@3o00<0000000P0o`080?l05008
0?l5000000030240o`00000000000100>@3o00<0000007`0o`1l0?l0301l0?l00`000000l`3o0?<0
o`0:0?<0o`030000003o0680o`1R00@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3o
ool20?l0HP030000003c0?l0l`3o00X0l`3o0P00000=07`0o`030000000i0?l0>@3o00d0>@3o1P00
000L00P0o`030000000Q0?l08@3o02@08@3o00<0000000P0o`080?l06P080?l6000000h0>@3o00<0
000007`0o`1l0?l0301l0?l00`000000l`3o0?<0o`0:0?<0o`030000003o0680oooo00<0oooo0@00
00010?ooo`003P3oool010000000oooo0?ooo`3oool20?l0HP030000003c0?l0l`3o00T0l`3o00<0
000007`0o`1l0?l0301l0?l00`000000>@3o03T0o`0;03T0o`<0000000<08@3o0000000000008008
0?l00`0000008@3o0240o`0R0240o`03000000080?l0203o01h0203o0P0000000`0Q0?l000000000
000=03T0o`030000001l0?l0O03o00`0O03o00<000000?<0o`3c0?l02@3c0?l00`000000o`1R0?oo
o`030?ooo`4000000@3oool000h0oooo00H000000?ooo`3oool0oooo0?l0HP00000;0?<0o`030000
001l0?l0O03o00`0O03o00<0000003T0o`0i0?l02P0i0?l2000000808@3o0P00000S00P0o`030000
000Q0?l08@3o02008@3o00<0000000P0o`080?l08@080?l2000000040240o`0000000000000000/0
>@3o0P00000=07`0o`030000003c0?l0l`3o00T0l`3o00<000000?ooo`3oool00P3oool100000040
oooo000>0?ooo`8000000P3oool00`000000l`3o0?<0o`090?<0o`030000001l0?l0O03o00/0O03o
0P00000;03T0o`8000000P0Q0?l2000002D0203o00<000000240o`0Q0?l0800Q0?l00`000000203o
00P0o`0S00P0o`8000000P0Q0?l2000000/0>@3o00<0000007`0o`1l0?l02`1l0?l00`000000l`3o
0?<0o`090?<0o`050000003oool0oooo0?ooo`0000000@3oool000h0oooo00@000000?ooo`3oool0
oooo303c0?l00`000000O03o07`0o`0907`0o`8000002`0i0?l2000000040240o`00000000000000
02L0203o00<000000240o`0Q0?l0800Q0?l00`000000203o00P0o`0U00P0o`<0000000<08@3o0000
000000002P0i0?l2000000`0O03o00<000000?<0o`3c0?l0203c0?l40?ooo`4000000@3oool000h0
oooo00@000000?ooo`3oool0oooo2`3c0?l00`000000O03o07`0o`0907`0o`030000000i0?l0>@3o
00P0>@3o1P00000Z00P0o`030000000Q0?l08@3o01l08@3o00<0000000P0o`080?l0:@080?l20000
00030240o`000000000000X0>@3o00<0000007`0o`1l0?l02P1l0?l00`000000l`3o0?<0o`070?<0
o`@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool90?<0o`8000002P1l0?l20000
00P0>@3o1P00000]00P0o`030000000Q0?l08@3o01l08@3o00<0000000P0o`080?l0:`080?l60000
00P0>@3o0P00000;07`0o`8000001`3c0?l40?ooo`4000000@3oool000h0oooo00@000000?ooo`3o
ool0oooo203c0?l00`000000O03o07`0o`0807`0o`800000200i0?l2000000030240o`0000000000
0300203o00<000000240o`0Q0?l03@0Q0?l4000000h08@3o00<0000000P0o`080?l0;P080?l50000
00P0>@3o0P00000;07`0o`030000003c0?l0l`3o00@0l`3o103oool100000040oooo000>0?ooo`04
0000003oool0oooo0?ooo`L0l`3o00<0000007`0o`1l0?l0201l0?l00`000000>@3o03T0o`0603T0
o`D00000<P080?l00`0000008@3o0240o`0:0240o`<00000100i0?l3000000/08@3o00<0000000P0
o`080?l0<@080?l4000000P0>@3o00<0000007`0o`1l0?l02@1l0?l00`000000l`3o0?<0o`030?<0
o`@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool60?<0o`030000001l0?l0O03o
00T0O03o00<0000003T0o`0i0?l0100i0?l4000003D0203o00<000000240o`0Q0?l0200Q0?l20000
00X0>@3o00<000000240o`0Q0?l0200Q0?l00`000000203o00P0o`0c00P0o`@000001`0i0?l00`00
0000O03o07`0o`0907`0o`030000003c0?l0l`3o0080l`3o103oool100000040oooo000>0?ooo`04
0000003oool0oooo0?ooo`@0l`3o0P00000:07`0o`800000100i0?l5000003L0203o00<000000240
o`0Q0?l01`0Q0?l00`000000>@3o03T0o`0;03T0o`030000000Q0?l08@3o00L08@3o00<0000000P0
o`080?l0=@080?l5000000D0>@3o0P00000:07`0o`040000003c0?l0l`3o0?<0o`@0oooo0@000001
0?ooo`003P3oool200000080oooo0`3c0?l00`000000O03o07`0o`0807`0o`800000100i0?l50000
03T0203o00<000000240o`0Q0?l01P0Q0?l00`000000>@3o03T0o`0=03T0o`030000000Q0?l08@3o
00H08@3o00<0000000P0o`080?l0=`080?l6000000@0>@3o0P00000907`0o`80000000<0l`3o0?oo
o`3oool00P3oool100000040oooo000>0?ooo`050000003oool0oooo0?ooo`3c0?l00P00000907`0
o`800000100i0?l400000140203o1@00000V00P0o`030000000Q0?l08@3o00D08@3o00<0000003T0
o`0i0?l03`0i0?l2000000L08@3o00<0000000P0o`080?l090080?l500000100203o1@00000403T0
o`8000002@1l0?l00`000000oooo0?ooo`020?ooo`4000000@3oool000h0oooo00D000000?ooo`3o
ool0oooo0000000907`0o`800000100i0?l4000000T0203o2P000005000jo`H0000080080?l00`00
00008@3o0240o`040240o`030000000i0?l0>@3o0180>@3o00<000000240o`0Q0?l0100Q0?l00`00
0000203o00P0o`0N00P0o`H000001@00>_l9000000X0203o1000000403T0o`800000201l0?l01@00
0000oooo0?ooo`3oool000000040oooo000>0?ooo`040000003oool0oooo0?ooo`P0O03o0P000004
03T0o`<000002@080?l3000001D003[o1000000L00P0o`030000000Q0?l08@3o00<08@3o00<00000
03T0o`0i0?l0500i0?l00`0000008@3o0240o`030240o`03000000080?l0203o01X0203o1000000D
000jo`<000002@080?l4000000@0>@3o0P00000607`0o`@0oooo0@0000010?ooo`003P3oool01000
0000oooo0?ooo`3oool607`0o`8000000`0i0?l3000000L0203o1@00000L000jo`8000006P080?l0
0`0000008@3o0240o`030240o`030000000i0?l0>@3o01@0>@3o00<000000240o`0Q0?l00`0Q0?l0
0`000000203o00P0o`0H00P0o`8000006`00>_l5000000L0203o1000000303T0o`800000101l0?l4
0?ooo`4000000@3oool000L0oooo1@0000020?ooo`040000003oool0oooo0?ooo`@0O03o0P000002
03T0o`@000001@080?l4000002<003[o0P00000H00P0o`030000000Q0?l08@3o00808@3o00<00000
03T0o`0i0?l05P0i0?l00`0000008@3o0240o`020240o`03000000080?l0203o01H0203o0P00000R
000jo`D000001@080?l400000080>@3o0P00000207`0o`@0oooo0@0000010?ooo`002@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`80O03o0P00000203T0o`@0000010080?l3
000002T003[o00<0000000P0o`080?l050080?l00`0000008@3o0240o`020240o`030000000i0?l0
>@3o01L0>@3o00<000000240o`0Q0?l00P0Q0?l00`000000203o00P0o`0D00P0o`800000:@00>_l3
000000@0203o1000000203T0o`800000103oool100000040oooo00090?ooo`030000003oool0oooo
0080oooo0P0000020?ooo`8000000P0i0?l4000000<0203o0`00000]000jo`03000000080?l0203o
01<0203o00<000000240o`0Q0?l00P0Q0?l00`000000>@3o03T0o`0H03T0o`030000000Q0?l08@3o
00808@3o00<0000000P0o`080?l04P080?l00`00000003[o000jo`0/000jo`<000000`080?l40000
0080>@3o00<000000?ooo`3oool00P0000010?ooo`002@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo0?ooo`80>@3o0`00000400P0o`800000<@00>_l00`000000203o00P0o`0A00P0
o`030000000Q0?l08@3o00808@3o00<0000003T0o`0i0?l06@0i0?l00`0000008@3o0240o`020240
o`03000000080?l0203o0180203o00<00000000jo`00>_l0;`00>_l2000000<0203o100000040?oo
o`4000000@3oool000T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool30000
0080203o1000000d000jo`03000000080?l0203o0100203o00D000000240o`0Q0?l08@3o0000000M
03T0o`050000000Q0?l08@3o0240o`0000004`080?l00`00000003[o000jo`0b000jo`@0000000@0
203o00000000000000000`3oool100000040oooo00080?ooo`800000103oool010000000oooo0?oo
o`3oool200P0o`<00000>@00>_l00`000000203o00P0o`0?00P0o`050000000Q0?l08@3o0240o`00
00007P0i0?l0100000008@3o0240o`00000B00P0o`0300000000>_l003[o03L003[o0P0000000`08
0?l0oooo0?ooo`020?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo0P00000l000j
o`03000000080?l0203o00l0203o00@000000240o`0Q0?l000007`0i0?l01@0000008@3o0240o`0Q
0?l000000100203o00<00000000jo`00>_l0>P00>_l2000000<0oooo0@0000010?ooo`003P3oool0
10000000oooo0?ooo`3oool@000jo`l000008000>_l00`000000203o00P0o`0=00P0o`050000000Q
0?l08@3o0240o`000000800i0?l0100000008@3o0240o`00000@00P0o`0300000000>_l003[o01d0
03[o4000000>000jo`@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool:000jo`H0
00003`00/Ol3000001d003[o00<0000000P0o`080?l03@080?l0100000008@3o0240o`00000Q03T0
o`050000000Q0?l08@3o0240o`0000003P080?l00`00000003[o000jo`0K000jo`<000004000/Ol6
000000P003[o103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`@003[o1P00000H
002ao`D000006@00>_l00`000000203o00P0o`0<00P0o`040000000Q0?l0000000000280>@3o00@0
00000240o`0Q0?l000003@080?l00`00000003[o000jo`0H000jo`@000006@00/Ol60000008003[o
103oool100000040oooo000>0?ooo`8000000P3oool4000002<00;7o0P00000G000jo`0300000008
0?l0203o00`0203o0P00000T03T0o`040000000Q0?l08@3o000000d0203o00<00000000jo`00>_l0
5P00>_l2000002<00;7o0`0000030?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo
:@00/Ol00`00000003[o000jo`0D000jo`03000000080?l0203o00/0203o00<000000240o`000000
9@0i0?l0100000008@3o0240o`00000<00P0o`0300000000>_l003[o01D003[o00<00000002ao`00
/Ol09@00/Ol40?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo:P00/Ol2000001D0
03[o00<0000000P0o`080?l02P080?l2000002H0>@3o00@000000240o`0Q0?l0000030080?l00`00
000003[o000jo`0C000jo`800000:000/Ol40?ooo`4000000@3oool000h0oooo00@000000?ooo`3o
ool0oooo;000/Ol00`00000003[o000jo`0B000jo`03000000080?l0203o00X0203o0P00000W03T0
o`030000000Q0?l0000000/0203o00<00000000jo`00>_l04`00>_l00`0000000;7o002ao`0X002a
o`@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool]002ao`8000004`00>_l00`00
0000203o00P0o`0800P0o`800000:00i0?l0100000008@3o0240o`00000:00P0o`0300000000>_l0
03[o014003[o0P00000[002ao`@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool_
002ao`0300000000>_l003[o010003[o00<0000000P0o`080?l020080?l2000002T0>@3o00<00000
0240o`0000002P080?l00`00000003[o000jo`0@000jo`0300000000/Ol00;7o02/00;7o103oool1
00000040oooo000>0?ooo`040000003oool0oooo0?oooa@000007000/Ol00`00000003[o000jo`0?
000jo`03000000080?l0203o00L0203o00<000000240o`000000:@0i0?l00`0000008@3o0000000:
00P0o`0300000000>_l003[o00l003[o00<00000002ao`00/Ol06P00/OlC000000<0oooo0@000001
0?ooo`003P3oool010000000oooo0?ooo`3ooolD003oY08000006P00/Ol00`00000003[o000jo`0?
000jo`03000000080?l0203o00L0203o0P00000[03T0o`030000000Q0?l0000000T0203o00<00000
000jo`00>_l03P00>_l00`0000000;7o002ao`0H002ao`<000004P00oj@40?ooo`4000000@3oool0
00h0oooo0P0000020?oooaH00?nT0`00000H002ao`0300000000>_l003[o00h003[o00<0000000P0
o`080?l01P080?l00`0000008@3o0000000[03T0o`030000000Q0?l0000000T0203o00<00000000j
o`00>_l03@00>_l00`0000000;7o002ao`0F002ao`<000005@00oj@40?ooo`4000000@3oool000h0
oooo00@000000?ooo`3oool0oooo6@00oj@3000001H00;7o00<00000000jo`00>_l03@00>_l00`00
0000203o00P0o`0600P0o`030000000Q0?l0000001<0>@3o1@00000D03T0o`8000002@080?l00`00
000003[o000jo`0=000jo`0300000000/Ol00;7o01<00;7o0`00000H003oY0@0oooo0@0000010?oo
o`003P3oool010000000oooo0?ooo`3ooolL003oY08000005000/Ol00`00000003[o000jo`0=000j
o`03000000080?l0203o00D0203o00<000000240o`0000003`0i0?l5000000D0O03o1@00000?03T0
o`030000000Q0?l0000000P0203o00<00000000jo`00>_l03000>_l00`0000000;7o002ao`0B002a
o`8000006`00oj@40?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo7P00oj@20000
01<00;7o00<00000000jo`00>_l03000>_l00`000000203o00P0o`0500P0o`030000000Q0?l00000
00d0>@3o0P00000?07`0o`8000003P0i0?l2000000P0203o00<00000000jo`00>_l02`00>_l00`00
00000;7o002ao`0B002ao`0300000000oj@00?nT01/00?nT103oool100000040oooo000>0?ooo`04
0000003oool0oooo0?ooob000?nT00<00000002ao`00/Ol04@00/Ol00`00000003[o000jo`0;000j
o`03000000080?l0203o00D0203o0P00000=03T0o`030000001l0?l0O03o0140O03o0P00000<03T0
o`80000020080?l00`00000003[o000jo`0;000jo`0300000000/Ol00;7o01000;7o0P00000N003o
Y0@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool3000001h00?nT0P00000A002a
o`0300000000>_l003[o00/003[o00<0000000P0o`080?l010080?l00`0000008@3o0000000<03T0
o`030000001l0?l0O03o01@0O03o00<0000003T0o`0i0?l02P0i0?l2000000L0203o00<00000000j
o`00>_l02P00>_l00`0000000;7o002ao`0?002ao`8000007P00oj@3000000<0oooo0@0000010?oo
o`003P3oool010000000oooo0?ooo`3oool303So00H000006P00oj@00`0000000;7o002ao`0?002a
o`0300000000>_l003[o00T003[o00<0000000P0o`080?l01@080?l2000000/0>@3o0P00000H07`0
o`030000000i0?l0>@3o00T0>@3o0P00000700P0o`0300000000>_l003[o00X003[o00<00000002a
o`00/Ol03P00/Ol00`0000000?nT003oY00I003oY0D000000P0ho`040?ooo`4000000@3oool000h0
oooo00@000000?ooo`3oool0oooo2@0ho`05000001H00?nT00<00000002ao`00/Ol03P00/Ol00`00
000003[o000jo`09000jo`03000000080?l0203o00D0203o0P00000:03T0o`030000001l0?l0O03o
01T0O03o0P00000903T0o`8000001`080?l00`00000003[o000jo`0:000jo`0300000000/Ol00;7o
00d00;7o00<00000003oY000oj@05@00oj@5000000L0>?l0103oool100000040oooo000>0?ooo`80
00000P3oool>03So008000005@00oj@00`0000000;7o002ao`0=002ao`0300000000>_l003[o00T0
03[o00<0000000P0o`080?l010080?l2000000T0>@3o0P00000N07`0o`030000000i0?l0>@3o00L0
>@3o0P00000600P0o`0300000000>_l003[o00T003[o00<00000002ao`00/Ol03P00/Ol00`000000
0?nT003oY00C003oY0800000300ho`040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0
oooo400ho`03000001<00?nT00<00000002ao`00/Ol03000/Ol00`00000003[o000jo`09000jo`03
000000080?l0203o00@0203o0P00000803T0o`030000001l0?l0O03o01l0O03o0P00000703T0o`80
00001P080?l00`00000003[o000jo`09000jo`0300000000/Ol00;7o00d00;7o00<00000003oY000
oj@04@00oj@3000000h0>?l0103oool100000040oooo000>0?ooo`040000003oool0oooo0?oooa<0
>?l000<00000003oY000oj@04@00oj@00`0000000;7o002ao`0;002ao`0300000000>_l003[o00T0
03[o00<0000000P0o`080?l010080?l2000000L0>@3o00<0000007`0o`1l0?l08P1l0?l00`000000
>@3o03T0o`0403T0o`8000001P080?l00`00000003[o000jo`09000jo`0300000000/Ol00;7o00`0
0;7o00<00000003oY000oj@04000oj@200000140>?l0103oool100000040oooo000>0?ooo`040000
003oool0oooo0?oooa@0>?l00P00000A003oY00300000000/Ol00;7o00`00;7o00<00000000jo`00
>_l02000>_l00`000000203o00P0o`0300P0o`8000001`0i0?l00`000000O03o07`0o`0S07`0o`03
0000000i0?l0>@3o00D0>@3o0P00000500P0o`0300000000>_l003[o00T003[o00<00000002ao`00
/Ol02`00/Ol00`0000000?nT003oY00@003oY0030000000ho`00>?l00140>?l0103oool100000040
oooo000>0?ooo`040000003oool0oooo0?oooaH0>?l000<00000003oY000oj@03`00oj@00`000000
0;7o002ao`0;002ao`0300000000>_l003[o00P003[o00<0000000P0o`080?l00`080?l2000000H0
>@3o00<0000007`0o`1l0?l09@1l0?l00`000000>@3o03T0o`0403T0o`8000001@080?l00`000000
03[o000jo`08000jo`0300000000/Ol00;7o00`00;7o00<00000003oY000oj@03P00oj@2000001@0
>?l0103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`8000005@0ho`000`000000
0?nT003oY00?003oY00300000000/Ol00;7o00X00;7o00<00000000jo`00>_l02000>_l00`000000
203o00P0o`0200P0o`030000000Q0?l0000000H0>@3o00<0000007`0o`1l0?l09P1l0?l00`000000
>@3o03T0o`0403T0o`8000001@080?l00`00000003[o000jo`07000jo`0300000000/Ol00;7o00/0
0;7o00<00000003oY000oj@03P00oj@00`000000>?l003So000D03So00050000003oool0oooo0?oo
o`0000000@3oool000h0oooo00@000000?ooo`3oool0oooo0P3o]`02000001@0>?l00P00000?003o
Y00300000000/Ol00;7o00/00;7o00<00000000jo`00>_l01`00>_l00`000000203o00P0o`0200P0
o`8000001P0i0?l00`000000O03o07`0o`0W07`0o`030000000i0?l0>@3o00@0>@3o0P00000500P0
o`0300000000>_l003[o00L003[o00<00000002ao`00/Ol02P00/Ol00`0000000?nT003oY00=003o
Y08000005@0ho`02000000@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool40?ng
00<000004`0ho`000`0000000?nT003oY00=003oY00300000000/Ol00;7o00X00;7o00<00000000j
o`00>_l01`00>_l00`000000203o00P0o`0200P0o`8000001@0i0?l00`000000O03o07`0o`0Y07`0
o`030000000i0?l0>@3o00@0>@3o0P00000400P0o`0300000000>_l003[o00L003[o00<00000002a
o`00/Ol02P00/Ol00`0000000?nT003oY00<003oY0030000000ho`00>?l00180>?l00`0000020?ng
00@0oooo0@0000010?ooo`003P3oool200000080oooo1`3o]`0200000180>?l000<00000003oY000
oj@03000oj@00`0000000;7o002ao`0:002ao`0300000000>_l003[o00H003[o00<0000000P0o`08
0?l00`080?l00`000000>@3o03T0o`0303T0o`030000001l0?l0O03o02/0O03o0P00000403T0o`80
000010080?l00`00000003[o000jo`07000jo`0300000000/Ol00;7o00T00;7o00<00000003oY000
oj@03000oj@00`000000>?l003So000A03So008000001@3o]`040?ooo`4000000@3oool000h0oooo
00@000000?ooo`3oool0oooo2@3o]`0200000140>?l000<00000003oY000oj@03000oj@00`000000
0;7o002ao`09002ao`0300000000>_l003[o00H003[o00<0000000P0o`080?l00P080?l2000000@0
>@3o00<0000007`0o`1l0?l0;@1l0?l00`000000>@3o03T0o`0203T0o`030000000Q0?l0000000<0
203o00<00000000jo`00>_l01`00>_l00`0000000;7o002ao`09002ao`0300000000oj@00?nT00/0
0?nT00<0000003So000ho`00400ho`02000000L0okL0103oool100000040oooo000>0?ooo`040000
003oool0oooo0?ooo`/0okL00P00000@03So000300000000oj@00?nT00/00?nT00<00000002ao`00
/Ol02@00/Ol00`00000003[o000jo`06000jo`03000000080?l0203o0080203o00<0000003T0o`0i
0?l00`0i0?l00`000000O03o07`0o`0^07`0o`030000000i0?l0>@3o0080>@3o0P00000300P0o`03
00000000>_l003[o00H003[o00<00000002ao`00/Ol02@00/Ol00`0000000?nT003oY00;003oY003
0000000ho`00>?l000l0>?l00P0000090?ng00@0oooo0@0000010?ooo`003P3oool010000000oooo
0?ooo`3oool=0?ng00030000000ho`00>?l000h0>?l000<00000003oY000oj@02P00oj@00`000000
0;7o002ao`09002ao`0300000000>_l003[o00D003[o00<0000000P0o`080?l00`080?l00`000000
>@3o03T0o`0203T0o`030000001l0?l0O03o01@0O03o1@00000F07`0o`030000000i0?l0>@3o0080
>@3o0P00000300P0o`0300000000>_l003[o00H003[o00<00000002ao`00/Ol02@00/Ol00`000000
0?nT003oY00:003oY0030000000ho`00>?l000l0>?l000<000000?ng003o]`002@3o]`040?ooo`40
00000@3oool000h0oooo00@000000?ooo`3oool0oooo3P3o]`02000000h0>?l000<00000003oY000
oj@02`00oj@00`0000000;7o002ao`08002ao`0300000000>_l003[o00D003[o00<0000000P0o`08
0?l00P080?l00`000000>@3o03T0o`0303T0o`030000001l0?l0O03o00l0O03o1@0000050?<0o`D0
00004P1l0?l00`000000>@3o03T0o`0203T0o`8000000`080?l00`00000003[o000jo`05000jo`03
00000000/Ol00;7o00P00;7o00<00000003oY000oj@02`00oj@00`000000>?l003So000=03So0080
0000303o]`040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo403o]`000`000000
>?l003So000<03So000300000000oj@00?nT00X00?nT00<00000002ao`00/Ol02000/Ol00`000000
03[o000jo`05000jo`03000000080?l0203o0080203o00<0000003T0o`0i0?l00P0i0?l00`000000
O03o07`0o`0>07`0o`8000003`3c0?l3000000l0O03o00<0000003T0o`0i0?l00P0i0?l2000000<0
203o00<00000000jo`00>_l01@00>_l00`0000000;7o002ao`08002ao`0300000000oj@00?nT00X0
0?nT00<0000003So000ho`003@0ho`000`000000okL00?ng000<0?ng00@0oooo0@0000010?ooo`00
1`3oool4000000<0oooo00@000000?ooo`3oool0oooo4@3o]`02000000d0>?l000<00000003oY000
oj@02@00oj@00`0000000;7o002ao`08002ao`0300000000>_l003[o00D003[o00@0000000P0o`08
0?l0203o0P00000303T0o`030000001l0?l0O03o00d0O03o0P00000D0?<0o`8000003P1l0?l00`00
0000>@3o03T0o`0203T0o`05000000080?l0203o00P0o`0000001`00>_l00`0000000;7o002ao`08
002ao`0300000000oj@00?nT00T00?nT00<0000003So000ho`00300ho`02000000l0okL0103oool1
00000040oooo00070?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000B
0?ng00030000000ho`00>?l000/0>?l000<00000003oY000oj@02@00oj@00`0000000;7o002ao`07
002ao`0300000000>_l003[o00D003[o00D0000000P0o`080?l0203o0000000403T0o`030000001l
0?l0O03o00/0O03o0P00000H0?<0o`800000301l0?l00`000000>@3o03T0o`0203T0o`8000000`08
0?l00`00000003[o000jo`04000jo`0300000000/Ol00;7o00P00;7o00<00000003oY000oj@02@00
oj@00`000000>?l003So000;03So00030000003o]`00okL000l0okL000D000000?ooo`3oool0oooo
000000010?ooo`00203oool00`000000oooo0?ooo`030?ooo`8000000P3oool00`3o000000000000
000A0?ng00030000000ho`00>?l000X0>?l000<00000003oY000oj@02@00oj@00`0000000;7o002a
o`07002ao`0300000000>_l003[o00@003[o00@0000000P0o`080?l0203o0P00000303T0o`030000
001l0?l0O03o00X0O03o0P00000L0?<0o`8000002`1l0?l00`000000>@3o03T0o`0203T0o`050000
00080?l0203o00P0o`0000001`00>_l00`0000000;7o002ao`06002ao`0300000000oj@00?nT00T0
0?nT00<0000003So000ho`002P0ho`0200000100okL00P0000030?ooo`8000000@3oool000T0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool30?l000800000403o]`000`000000
>?l003So000:03So000300000000oj@00?nT00T00?nT00<00000002ao`00/Ol01P00/Ol00`000000
03[o000jo`04000jo`05000000080?l0203o00P0o`000000100i0?l00`000000O03o07`0o`0807`0
o`800000803c0?l2000000T0O03o00<0000003T0o`0i0?l00P0i0?l2000000<0203o00<00000000j
o`00>_l01000>_l00`0000000;7o002ao`06002ao`0300000000oj@00?nT00T00?nT00<0000003So
000ho`002@0ho`000`000000okL00?ng000>0?ng008000000P3o00040?ooo`4000000@3oool000L0
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`3oool50?l000<000003P3o]`00
0`000000>?l003So000:03So000300000000oj@00?nT00P00?nT00<00000002ao`00/Ol01P00/Ol0
0`00000003[o000jo`04000jo`03000000080?l0203o008000000P0i0?l2000000T0O03o0P00000T
0?<0o`030000001l0?l0O03o00L0O03o0P00000303T0o`05000000080?l0203o00P0o`0000001P00
>_l00`0000000;7o002ao`06002ao`0300000000oj@00?nT00P00?nT00<0000003So000ho`002@0h
o`000`000000okL00?ng000<0?ng00<00000103o00040?ooo`4000000@3oool000P0oooo0P000004
0?ooo`040000003oool0oooo0?ooo`P0o`0000<000000?ng003o]`002`3o]`000`000000>?l003So
000:03So000300000000oj@00?nT00P00?nT00<00000002ao`00/Ol01P00/Ol00`00000003[o000j
o`04000jo`04000000080?l0203o00000080>@3o00<0000007`0o`1l0?l0201l0?l00`000000l`3o
0?<0o`0U0?<0o`030000001l0?l0O03o00L0O03o00D0000003T0o`0i0?l0>@3o0000000300P0o`03
00000000>_l003[o00@003[o00<00000002ao`00/Ol01P00/Ol00`0000000?nT003oY007003oY003
0000000ho`00>?l000T0>?l000<000000?ng003o]`00303o]`000`000000o`000?l000050?l000@0
oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool90?l000800000303o]`000`000000
>?l003So000903So000300000000oj@00?nT00P00?nT00<00000002ao`00/Ol01P00/Ol00`000000
03[o000jo`03000jo`03000000080?l0203o008000000P0i0?l00`000000O03o07`0o`0707`0o`03
0000003c0?l0l`3o02L0l`3o00<0000007`0o`1l0?l01`1l0?l00`000000>@3o03T0o`02000000<0
203o00<00000000jo`00>_l00`00>_l00`0000000;7o002ao`06002ao`0300000000oj@00?nT00L0
0?nT00<0000003So000ho`002@0ho`000`000000okL00?ng000;0?ng00030000003o0000o`0000H0
o`00103oool100000040oooo000>0?ooo`040000003oool0oooo0?ooo`/0o`0000<000000?ng003o
]`002P3o]`000`000000>?l003So000903So000300000000oj@00?nT00L00?nT00<00000002ao`00
/Ol01@00/Ol00`00000003[o000jo`04000jo`04000000080?l0203o00000080>@3o00<0000007`0
o`1l0?l0201l0?l00`000000l`3o0?<0o`0X0?<0o`030000001l0?l0O03o00H0O03o00D0000003T0
o`0i0?l0>@3o0000000300P0o`0300000000>_l003[o00<003[o00<00000002ao`00/Ol01@00/Ol0
0`0000000?nT003oY008003oY0030000000ho`00>?l000P0>?l000<000000?ng003o]`002`3o]`00
0`000000o`000?l000070?l000@0oooo0@0000010?ooo`003P3oool010000000oooo0?ooo`3oool<
0?l000030000003o]`00okL000T0okL000<0000003So000ho`002@0ho`000`0000000?nT003oY007
003oY00300000000/Ol00;7o00D00;7o00<00000000jo`00>_l01000>_l010000000203o00P0o`00
000203T0o`030000001l0?l0O03o00L0O03o00<000000?<0o`3c0?l0:P3c0?l00`000000O03o07`0
o`0607`0o`030000000i0?l0>@3o008000000P080?l00`00000003[o000jo`03000jo`0300000000
/Ol00;7o00D00;7o00<00000003oY000oj@01`00oj@00`000000>?l003So000803So00030000003o
]`00okL000/0okL000<000000?l0003o0000203o00040?ooo`4000000@3oool000h0oooo00@00000
0?ooo`3oool0oooo3@3o00000`000000okL00?ng00090?ng00030000000ho`00>?l000T0>?l000<0
0000003oY000oj@01P00oj@00`0000000;7o002ao`05002ao`0300000000>_l003[o00<003[o00@0
000000P0o`080?l000000P0i0?l00`000000O03o07`0o`0707`0o`030000003c0?l0l`3o02`0l`3o
00<0000007`0o`1l0?l01@1l0?l00`000000>@3o03T0o`02000000<0203o00<00000000jo`00>_l0
0P00>_l00`0000000;7o002ao`05002ao`0300000000oj@00?nT00L00?nT00<0000003So000ho`00
200ho`000`000000okL00?ng000:0?ng00030000003o0000o`0000T0o`00103oool100000040oooo
000>0?ooo`8000000P3oool>0?l000030000003o]`00okL000T0okL000<0000003So000ho`00200h
o`000`0000000?nT003oY006003oY00300000000/Ol00;7o00D00;7o00<00000000jo`00>_l00`00
>_l010000000203o00P0o`00000203T0o`030000001l0?l0O03o00D0O03o0P00000`0?<0o`030000
001l0?l0O03o00D0O03o00<0000003T0o`0i0?l00P00000200P0o`0300000000>_l003[o008003[o
00<00000002ao`00/Ol01@00/Ol00`0000000?nT003oY007003oY0030000000ho`00>?l000L0>?l0
00<000000?ng003o]`002P3o]`000`000000o`000?l0000:0?l000@0oooo0@0000010?ooo`003P3o
ool010000000oooo0?ooo`3oool?0?l000030000003o]`00okL000P0okL000<0000003So000ho`00
200ho`000`0000000?nT003oY006003oY00300000000/Ol00;7o00D00;7o00<00000000jo`00>_l0
0`00>_l01P000000203o000000000000>@3o000000L0O03o00<000000?<0o`3c0?l0<@3c0?l00`00
0000O03o07`0o`0407`0o`030000000i0?l0>@3o008000000P080?l00`00000003[o000jo`02000j
o`0300000000/Ol00;7o00D00;7o00<00000003oY000oj@01`00oj@00`000000>?l003So000703So
00030000003o]`00okL000T0okL000<000000?l0003o00002`3o00040?ooo`4000000@3oool000h0
oooo00@000000?ooo`3oool0oooo403o00000`000000okL00?ng00080?ng00030000000ho`00>?l0
00L0>?l000<00000003oY000oj@01P00oj@00`0000000;7o002ao`05002ao`0300000000>_l003[o
008003[o00@0000000P0o`080?l000000P0i0?l00`000000O03o07`0o`0407`0o`030000003c0?l0
l`3o0140l`3o3`00000C0?<0o`030000001l0?l0O03o00@0O03o00<0000003T0o`0i0?l00P000000
0`080?l00000000jo`03000jo`0300000000/Ol00;7o00D00;7o00<00000003oY000oj@01P00oj@0
0`000000>?l003So000703So00030000003o]`00okL000T0okL000<000000?l0003o0000303o0004
0?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo403o00000`000000okL00?ng0008
0?ng00030000000ho`00>?l000L0>?l000<00000003oY000oj@01P00oj@00`0000000;7o002ao`04
002ao`0300000000>_l003[o00<003[o00H0000000P0o`000000000003T0o`00000707`0o`030000
003c0?l0l`3o00l0l`3o0P00000?0?l0HP<00000403c0?l00`000000O03o07`0o`0407`0o`030000
000i0?l0>@3o008000000P080?l01@00000003[o000jo`00>_l0000000L00;7o00<00000003oY000
oj@01P00oj@00`000000>?l003So000703So00030000003o]`00okL000T0okL000<000000?l0003o
0000303o00040?ooo`4000000@3oool000h0oooo00@000000?ooo`3oool0oooo4@3o00000`000000
okL00?ng00080?ng00030000000ho`00>?l000L0>?l000<00000003oY000oj@01@00oj@00`000000
0;7o002ao`04002ao`0300000000>_l003[o008003[o00<0000000P0o`080?l00P0000000`0i0?l0
000007`0o`0507`0o`030000003c0?l0l`3o00d0l`3o0`00000D0?l0HP<000003P3c0?l00`000000
O03o07`0o`0407`0o`040000000i0?l0>@3o00000080203o00<00000000jo`00>_l00P00>_l00`00
00000;7o002ao`04002ao`0300000000oj@00?nT00H00?nT00<0000003So000ho`001`0ho`000`00
0000okL00?ng00080?ng00030000003o0000o`0000d0o`00103oool100000040oooo000>0?ooo`04
0000003oool0oooo0?oooa80o`0000<000000?ng003o]`001`3o]`000`000000>?l003So000703So
000300000000oj@00?nT00D00?nT00<00000002ao`00/Ol01000/Ol00`00000003[o000jo`02000j
o`06000000080?l000000000000i0?l000001P1l0?l00`000000l`3o0?<0o`0<0?<0o`8000006P3o
0682000000d0l`3o00<0000007`0o`1l0?l00`1l0?l00`000000>@3o03T0o`020000000300P0o`00
000003[o00<003[o00<00000002ao`00/Ol01000/Ol00`0000000?nT003oY005003oY0030000000h
o`00>?l000L0>?l000<000000?ng003o]`00203o]`000`000000o`000?l0000>0?l000@0oooo0@00
00010?ooo`003P3oool010000000oooo0?ooo`3ooolB0?l000030000003o]`00okL000P0okL000<0
000003So000ho`001P0ho`000`0000000?nT003oY005003oY00300000000/Ol00;7o00@00;7o00<0
0000000jo`00>_l00P00>_l01P000000203o000000000000>@3o000000D0O03o00<000000?<0o`3c
0?l02`3c0?l2000001h0o`1R0P00000<0?<0o`030000001l0?l0O03o00<0O03o00H0000003T0o`0i
0?l0000000P0o`000004000jo`8000001@00/Ol00`0000000?nT003oY005003oY0030000000ho`00
>?l000L0>?l000<000000?ng003o]`001`3o]`000`000000o`000?l0000?0?l000@0oooo0@000001
0?ooo`003P3oool010000000oooo0?ooo`3ooolB0?l000030000003o]`00okL000P0okL000<00000
03So000ho`001P0ho`000`0000000?nT003oY005003oY00300000000/Ol00;7o00@00;7o00<00000
000jo`00>_l00P00>_l01@000000203o0000000i0?l0000000D0O03o00<000000?<0o`3c0?l02`3c
0?l00`000000o`1R0?l0HP0P0?l0HP030000003c0?l0l`3o00X0l`3o00<0000007`0o`1l0?l00P1l
0?l01P000000>@3o03T0o`000000203o000000D003[o00<00000002ao`00/Ol00`00/Ol00`000000
0?nT003oY005003oY0030000000ho`00>?l000H0>?l000<000000?ng003o]`001`3o]`000`000000
o`000?l0000@0?l000@0oooo0@0000010?ooo`003P3oool200000080oooo4`3o00000`000000okL0
0?ng00070?ng00030000000ho`00>?l000H0>?l000<00000003oY000oj@01@00oj@00`0000000;7o
002ao`04002ao`0600000000>_l003[o000jo`000000203o0P0000000`0i0?l0000007`0o`0407`0
o`030000003c0?l0l`3o00T0l`3o0P00000T0?l0HP8000002P3c0?l00`000000O03o07`0o`0307`0
o`060000000i0?l0>@3o000000080?l000001000>_l00`0000000;7o002ao`03002ao`0300000000
oj@00?nT00D00?nT00<0000003So000ho`001P0ho`000`000000okL00?ng00070?ng00030000003o
0000o`000100o`00103oool100000040oooo000>0?ooo`040000003oool0oooo0?oooa<0o`0000<0
00000?ng003o]`00203o]`000`000000>?l003So000503So000300000000oj@00?nT00D00?nT00<0
0000002ao`00/Ol00`00/Ol00`00000003[o000jo`02000jo`05000000080?l0000003T0o`000000
1@1l0?l00`000000l`3o0?<0o`090?<0o`030000003o0680o`1R02H0o`1R00<000000?<0o`3c0?l0
203c0?l00`000000O03o07`0o`0207`0o`060000000i0?l0>@3o000000080?l000001000>_l00`00
00000;7o002ao`03002ao`0300000000oj@00?nT00D00?nT00<0000003So000ho`001P0ho`000`00
0000okL00?ng00060?ng00030000003o0000o`000140o`00103oool100000040oooo000>0?ooo`04
0000003oool0oooo0?oooa@0o`0000<000000?ng003o]`001`3o]`000`000000>?l003So000603So
000300000000oj@00?nT00@00?nT00<00000002ao`00/Ol00`00/Ol00`00000003[o000jo`02000j
o`<0000000<0>@3o0000001l0?l00`1l0?l00`000000l`3o0?<0o`080?<0o`800000:P3o06820000
00T0l`3o00<0000007`0o`1l0?l00P1l0?l00`000000>@3o00000002000000D003[o00<00000002a
o`00/Ol00P00/Ol00`0000000?nT003oY005003oY0030000000ho`00>?l000D0>?l000<000000?ng
003o]`001`3o]`000`000000o`000?l0000A0?l000@0oooo0@0000010?ooo`003P3oool010000000
oooo0?ooo`3ooolD0?l000030000003o]`00okL000P0okL000<0000003So000ho`001@0ho`000`00
00000?nT003oY004003oY00300000000/Ol00;7o00<00;7o00T00000000jo`00>_l003[o00000008
0?l0000003T0o`0000001@1l0?l00`000000l`3o0?<0o`070?<0o`030000003o0680o`1R02`0o`1R
00<000000?<0o`3c0?l01P3c0?l00`000000O03o07`0o`0207`0o`060000000i0?l0>@3o00000008
0?l000001000>_l00`0000000;7o002ao`02002ao`0300000000oj@00?nT00D00?nT00<0000003So
000ho`001@0ho`000`000000okL00?ng00060?ng00030000003o0000o`000180o`00103oool10000
0040oooo000>0?ooo`040000003oool0oooo0?oooaD0o`0000<000000?ng003o]`001`3o]`000`00
0000>?l003So000503So000300000000oj@00?nT00@00?nT00<00000002ao`00/Ol00`00/Ol02@00
000003[o000jo`00>_l0000000P0o`000000>@3o0000000407`0o`030000003c0?l0l`3o00L0l`3o
00<000000?l0HP3o0680;P3o06800`000000l`3o0?<0o`060?<0o`030000001l0?l0O03o0080O03o
00D0000003T0o`000000203o00000004000jo`0300000000/Ol00;7o00800;7o00<00000003oY000
oj@01@00oj@00`000000>?l003So000503So00030000003o]`00okL000H0okL000<000000?l0003o
00004P3o00040?ooo`4000000@3oool000h0oooo00<000000?ooo`3oool0b`3oool100000040oooo
000>0?ooo`030000003oool0oooo0</0oooo0@0000010?ooo`003P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`003P3oooo?00000040oooo003N0?ooo`00
\
\>"],
    ImageRangeCache->{{{0, 221}, {221, 0}} -> {-2, -2, 0, 0}}],
  StyleBox["     \n\tFigure 3.B",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Contour plot for  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"u", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        "=", \(x\^3 - 3\ x\ y\^2 = C\)}]]],
  "     and     ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"v", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        "=", \(3\ x\^2\ y - y\^3 = C\)}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tIn Chapter 11 we will show that if  ",
  Cell[BoxData[
      \(f \((z)\) = u \((x, y)\) + i\ v \((x, y)\)\)]],
  " is an analytic function.  Then the two families of level curves    ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(u \((x, y)\)\), "=", 
          RowBox[{"C", ":", " ", 
            RowBox[{
              StyleBox["C",
                FontSize->14], "  ", 
              StyleBox["is",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["a",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["real",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["constant",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}], "}"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(v \((x, y)\)\), "=", 
          RowBox[{
            StyleBox["C",
              FontSize->14], ":", " ", 
            RowBox[{
              StyleBox["C",
                FontSize->14], "  ", 
              StyleBox["is",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["a",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["real",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["constant",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}], "}"}]]],
  ",  are orthogonal in the sense that if ",
  Cell[BoxData[
      \(\((x\_0, y\_0)\)\)]],
  "is a point in common to the two curves  ",
  Cell[BoxData[
      RowBox[{\(u \((x, y)\)\), "=", 
        StyleBox[\(C\_1\),
          FontSize->14]}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{\(v \((x, y)\)\), "=", 
        StyleBox[\(C\_2\),
          FontSize->14]}]]],
  ",  and  if   ",
  Cell[BoxData[
      \(\(\(f' \((x\_0 + \[ImaginaryI]\ y\_0)\)\)\(\[NotEqual]\)\(0\)\(\ \)\)\
\)]],
  ",  then these two curves intersect orthogonally.  The orthogonal grid \
shown in Figure 3.C.  "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.190476 0.5 0.190476 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11905 -12 -4.5 ]
[-0.0125 .11905 0 4.5 ]
[-0.0125 .30952 -12 -4.5 ]
[-0.0125 .30952 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .69048 -6 -4.5 ]
[-0.0125 .69048 0 4.5 ]
[-0.0125 .88095 -6 -4.5 ]
[-0.0125 .88095 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-2)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-1)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(1)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(2)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.15714 0 m
.15714 .00375 L
s
.19524 0 m
.19524 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.27143 0 m
.27143 .00375 L
s
.34762 0 m
.34762 .00375 L
s
.38571 0 m
.38571 .00375 L
s
.42381 0 m
.42381 .00375 L
s
.4619 0 m
.4619 .00375 L
s
.5381 0 m
.5381 .00375 L
s
.57619 0 m
.57619 .00375 L
s
.61429 0 m
.61429 .00375 L
s
.65238 0 m
.65238 .00375 L
s
.72857 0 m
.72857 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.80476 0 m
.80476 .00375 L
s
.84286 0 m
.84286 .00375 L
s
.08095 0 m
.08095 .00375 L
s
.04286 0 m
.04286 .00375 L
s
.00476 0 m
.00476 .00375 L
s
.91905 0 m
.91905 .00375 L
s
.95714 0 m
.95714 .00375 L
s
.99524 0 m
.99524 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11905 m
.00625 .11905 L
s
[(-2)] -0.0125 .11905 1 0 Mshowa
0 .30952 m
.00625 .30952 L
s
[(-1)] -0.0125 .30952 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .69048 m
.00625 .69048 L
s
[(1)] -0.0125 .69048 1 0 Mshowa
0 .88095 m
.00625 .88095 L
s
[(2)] -0.0125 .88095 1 0 Mshowa
.125 Mabswid
0 .15714 m
.00375 .15714 L
s
0 .19524 m
.00375 .19524 L
s
0 .23333 m
.00375 .23333 L
s
0 .27143 m
.00375 .27143 L
s
0 .34762 m
.00375 .34762 L
s
0 .38571 m
.00375 .38571 L
s
0 .42381 m
.00375 .42381 L
s
0 .4619 m
.00375 .4619 L
s
0 .5381 m
.00375 .5381 L
s
0 .57619 m
.00375 .57619 L
s
0 .61429 m
.00375 .61429 L
s
0 .65238 m
.00375 .65238 L
s
0 .72857 m
.00375 .72857 L
s
0 .76667 m
.00375 .76667 L
s
0 .80476 m
.00375 .80476 L
s
0 .84286 m
.00375 .84286 L
s
0 .08095 m
.00375 .08095 L
s
0 .04286 m
.00375 .04286 L
s
0 .00476 m
.00375 .00476 L
s
0 .91905 m
.00375 .91905 L
s
0 .95714 m
.00375 .95714 L
s
0 .99524 m
.00375 .99524 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11905 .99375 m
.11905 1 L
s
.30952 .99375 m
.30952 1 L
s
.5 .99375 m
.5 1 L
s
.69048 .99375 m
.69048 1 L
s
.88095 .99375 m
.88095 1 L
s
.125 Mabswid
.15714 .99625 m
.15714 1 L
s
.19524 .99625 m
.19524 1 L
s
.23333 .99625 m
.23333 1 L
s
.27143 .99625 m
.27143 1 L
s
.34762 .99625 m
.34762 1 L
s
.38571 .99625 m
.38571 1 L
s
.42381 .99625 m
.42381 1 L
s
.4619 .99625 m
.4619 1 L
s
.5381 .99625 m
.5381 1 L
s
.57619 .99625 m
.57619 1 L
s
.61429 .99625 m
.61429 1 L
s
.65238 .99625 m
.65238 1 L
s
.72857 .99625 m
.72857 1 L
s
.76667 .99625 m
.76667 1 L
s
.80476 .99625 m
.80476 1 L
s
.84286 .99625 m
.84286 1 L
s
.08095 .99625 m
.08095 1 L
s
.04286 .99625 m
.04286 1 L
s
.00476 .99625 m
.00476 1 L
s
.91905 .99625 m
.91905 1 L
s
.95714 .99625 m
.95714 1 L
s
.99524 .99625 m
.99524 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11905 m
1 .11905 L
s
.99375 .30952 m
1 .30952 L
s
.99375 .5 m
1 .5 L
s
.99375 .69048 m
1 .69048 L
s
.99375 .88095 m
1 .88095 L
s
.125 Mabswid
.99625 .15714 m
1 .15714 L
s
.99625 .19524 m
1 .19524 L
s
.99625 .23333 m
1 .23333 L
s
.99625 .27143 m
1 .27143 L
s
.99625 .34762 m
1 .34762 L
s
.99625 .38571 m
1 .38571 L
s
.99625 .42381 m
1 .42381 L
s
.99625 .4619 m
1 .4619 L
s
.99625 .5381 m
1 .5381 L
s
.99625 .57619 m
1 .57619 L
s
.99625 .61429 m
1 .61429 L
s
.99625 .65238 m
1 .65238 L
s
.99625 .72857 m
1 .72857 L
s
.99625 .76667 m
1 .76667 L
s
.99625 .80476 m
1 .80476 L
s
.99625 .84286 m
1 .84286 L
s
.99625 .08095 m
1 .08095 L
s
.99625 .04286 m
1 .04286 L
s
.99625 .00476 m
1 .00476 L
s
.99625 .91905 m
1 .91905 L
s
.99625 .95714 m
1 .95714 L
s
.99625 .99524 m
1 .99524 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.02381 .88974 m
.03644 .86415 L
.04784 .83613 L
.05182 .82568 L
.05649 .80812 L
.06203 .78011 L
.06402 .7521 L
.06196 .72409 L
.05518 .69608 L
.05182 .68664 L
.0427 .66807 L
.02381 .64116 L
s
.97619 .35884 m
.9573 .33193 L
.94818 .31336 L
.94482 .30392 L
.93804 .27591 L
.93598 .2479 L
.93797 .21989 L
.94351 .19188 L
.94818 .17432 L
.95216 .16387 L
.96356 .13585 L
.97619 .11026 L
s
.88974 .97619 m
.86415 .96356 L
.83613 .95216 L
.82568 .94818 L
.80812 .94351 L
.78011 .93797 L
.7521 .93598 L
.72409 .93804 L
.69608 .94482 L
.68664 .94818 L
.66807 .9573 L
.64116 .97619 L
s
.35884 .02381 m
.33193 .0427 L
.31336 .05182 L
.30392 .05518 L
.27591 .06196 L
.2479 .06402 L
.21989 .06203 L
.19188 .05649 L
.17432 .05182 L
.16387 .04784 L
.13585 .03644 L
.11026 .02381 L
s
.02381 .93226 m
.03273 .92017 L
.05182 .89257 L
.05209 .89216 L
.06972 .86415 L
.07983 .84667 L
.08524 .83613 L
.09822 .80812 L
.10784 .78173 L
.10828 .78011 L
.11488 .7521 L
.11758 .72409 L
.11573 .69608 L
.10849 .66807 L
.10784 .66624 L
.09444 .64006 L
.07983 .62085 L
.07125 .61204 L
.05182 .59573 L
.03403 .58403 L
.02381 .5783 L
s
.97619 .4217 m
.96597 .41597 L
.94818 .40427 L
.92875 .38796 L
.92017 .37915 L
.90556 .35994 L
.89216 .33376 L
.89151 .33193 L
.88427 .30392 L
.88242 .27591 L
.88512 .2479 L
.89172 .21989 L
.89216 .21827 L
.90178 .19188 L
.91476 .16387 L
.92017 .15333 L
.93028 .13585 L
.94791 .10784 L
.94818 .10743 L
.96727 .07983 L
.97619 .06774 L
s
.93226 .97619 m
.92017 .96727 L
.89257 .94818 L
.89216 .94791 L
.86415 .93028 L
.84667 .92017 L
.83613 .91476 L
.80812 .90178 L
.78173 .89216 L
.78011 .89172 L
.7521 .88512 L
.72409 .88242 L
.69608 .88427 L
.66807 .89151 L
.66624 .89216 L
.64006 .90556 L
.62085 .92017 L
.61204 .92875 L
.59573 .94818 L
.58403 .96597 L
.5783 .97619 L
s
.4217 .02381 m
.41597 .03403 L
.40427 .05182 L
.38796 .07125 L
.37915 .07983 L
.35994 .09444 L
.33376 .10784 L
.33193 .10849 L
.30392 .11573 L
.27591 .11758 L
.2479 .11488 L
.21989 .10828 L
.21827 .10784 L
.19188 .09822 L
.16387 .08524 L
.15333 .07983 L
.13585 .06972 L
.10784 .05209 L
.10743 .05182 L
.07983 .03273 L
.06774 .02381 L
s
.02381 .95619 m
.03104 .94818 L
.05182 .92387 L
.0549 .92017 L
.07792 .89216 L
.07983 .88982 L
.09964 .86415 L
.10784 .85326 L
.11976 .83613 L
.13585 .81165 L
.13793 .80812 L
.15352 .78011 L
.16387 .75832 L
.16613 .7521 L
.17501 .72409 L
.1796 .69608 L
.17903 .66807 L
.1722 .64006 L
.16387 .62178 L
.15718 .61204 L
.13585 .58871 L
.13016 .58403 L
.10784 .56895 L
.08155 .55602 L
.07983 .5553 L
.05182 .54523 L
.02381 .53756 L
s
.97619 .46244 m
.94818 .45477 L
.92017 .4447 L
.91845 .44398 L
.89216 .43105 L
.86984 .41597 L
.86415 .41129 L
.84282 .38796 L
.83613 .37822 L
.8278 .35994 L
.82097 .33193 L
.8204 .30392 L
.82499 .27591 L
.83387 .2479 L
.83613 .24168 L
.84648 .21989 L
.86207 .19188 L
.86415 .18835 L
.88024 .16387 L
.89216 .14674 L
.90036 .13585 L
.92017 .11018 L
.92208 .10784 L
.9451 .07983 L
.94818 .07613 L
.96896 .05182 L
.97619 .04381 L
s
.95619 .97619 m
.94818 .96896 L
.92387 .94818 L
.92017 .9451 L
.89216 .92208 L
.88982 .92017 L
.86415 .90036 L
.85326 .89216 L
.83613 .88024 L
.81165 .86415 L
.80812 .86207 L
.78011 .84648 L
.75832 .83613 L
.7521 .83387 L
.72409 .82499 L
.69608 .8204 L
.66807 .82097 L
.64006 .8278 L
.62178 .83613 L
.61204 .84282 L
.58871 .86415 L
.58403 .86984 L
.56895 .89216 L
.55602 .91845 L
.5553 .92017 L
.54523 .94818 L
.53756 .97619 L
s
.46244 .02381 m
.45477 .05182 L
.4447 .07983 L
.44398 .08155 L
.43105 .10784 L
.41597 .13016 L
.41129 .13585 L
.38796 .15718 L
.37822 .16387 L
.35994 .1722 L
.33193 .17903 L
.30392 .1796 L
.27591 .17501 L
.2479 .16613 L
.24168 .16387 L
.21989 .15352 L
.19188 .13793 L
.18835 .13585 L
.16387 .11976 L
.14674 .10784 L
.13585 .09964 L
.11018 .07983 L
.10784 .07792 L
.07983 .0549 L
.07613 .05182 L
.05182 .03104 L
.04381 .02381 L
s
.02381 .96982 m
.04475 .94818 L
.05182 .94073 L
.07118 .92017 L
.07983 .91107 L
.0973 .89216 L
.10784 .88085 L
.12285 .86415 L
.13585 .84979 L
.14762 .83613 L
.16387 .81738 L
.17135 .80812 L
.19188 .78258 L
.19368 .78011 L
.2139 .7521 L
.21989 .74389 L
.23134 .72409 L
.24538 .69608 L
.2479 .68989 L
.25457 .66807 L
.25805 .64006 L
.25422 .61204 L
.2479 .59365 L
.24034 .58403 L
.21989 .56297 L
.20989 .55602 L
.19188 .54599 L
.16387 .53502 L
.1384 .52801 L
.13585 .52742 L
.10784 .52189 L
.07983 .51778 L
.05182 .51464 L
.02381 .5122 L
s
.97619 .4878 m
.94818 .48536 L
.92017 .48222 L
.89216 .47811 L
.86415 .47258 L
.8616 .47199 L
.83613 .46498 L
.80812 .45401 L
.79011 .44398 L
.78011 .43703 L
.75966 .41597 L
.7521 .40635 L
.74578 .38796 L
.74195 .35994 L
.74543 .33193 L
.7521 .31011 L
.75462 .30392 L
.76866 .27591 L
.78011 .25611 L
.7861 .2479 L
.80632 .21989 L
.80812 .21742 L
.82865 .19188 L
.83613 .18262 L
.85238 .16387 L
.86415 .15021 L
.87715 .13585 L
.89216 .11915 L
.9027 .10784 L
.92017 .08893 L
.92882 .07983 L
.94818 .05927 L
.95525 .05182 L
.97619 .03018 L
s
.96982 .97619 m
.94818 .95525 L
.94073 .94818 L
.92017 .92882 L
.91107 .92017 L
.89216 .9027 L
.88085 .89216 L
.86415 .87715 L
.84979 .86415 L
.83613 .85238 L
.81738 .83613 L
.80812 .82865 L
.78258 .80812 L
.78011 .80632 L
.7521 .7861 L
.74389 .78011 L
.72409 .76866 L
.69608 .75462 L
.68989 .7521 L
.66807 .74543 L
.64006 .74195 L
.61204 .74578 L
.59365 .7521 L
.58403 .75966 L
.56297 .78011 L
.55602 .79011 L
.54599 .80812 L
.53502 .83613 L
.52801 .8616 L
.52742 .86415 L
.52189 .89216 L
.51778 .92017 L
.51464 .94818 L
.5122 .97619 L
s
.4878 .02381 m
.48536 .05182 L
.48222 .07983 L
.47811 .10784 L
.47258 .13585 L
.47199 .1384 L
.46498 .16387 L
.45401 .19188 L
.44398 .20989 L
.43703 .21989 L
.41597 .24034 L
.40635 .2479 L
.38796 .25422 L
.35994 .25805 L
.33193 .25457 L
.31011 .2479 L
.30392 .24538 L
.27591 .23134 L
.25611 .21989 L
.2479 .2139 L
.21989 .19368 L
.21742 .19188 L
.19188 .17135 L
.18262 .16387 L
.16387 .14762 L
.15021 .13585 L
.13585 .12285 L
.11915 .10784 L
.10784 .0973 L
.08893 .07983 L
.07983 .07118 L
.05927 .05182 L
.05182 .04475 L
.03018 .02381 L
s
.02381 .97579 m
.05137 .94818 L
.05182 .94773 L
.07928 .92017 L
.07983 .91962 L
.10716 .89216 L
.10784 .89148 L
.135 .86415 L
.13585 .86331 L
.16278 .83613 L
.16387 .83507 L
.19046 .80812 L
.19188 .80675 L
.218 .78011 L
.21989 .7783 L
.24531 .7521 L
.2479 .74965 L
.27223 .72409 L
.27591 .72068 L
.29845 .69608 L
.30392 .69119 L
.32337 .66807 L
.33193 .66075 L
.34579 .64006 L
.35994 .62159 L
.36429 .61204 L
.37635 .58403 L
.37644 .55602 L
.35994 .52908 L
.35479 .52801 L
.33193 .5174 L
.30392 .51089 L
.27591 .5073 L
.2479 .50513 L
.21989 .50374 L
.19188 .50281 L
.16387 .50216 L
.13585 .5017 L
.10784 .50136 L
.07983 .50111 L
.05182 .50091 L
.02381 .50076 L
s
.97619 .49924 m
.94818 .49909 L
.92017 .49889 L
.89216 .49864 L
.86415 .4983 L
.83613 .49784 L
.80812 .49719 L
.78011 .49626 L
.7521 .49487 L
.72409 .4927 L
.69608 .48911 L
.66807 .4826 L
.64521 .47199 L
.64006 .47092 L
.62356 .44398 L
.62365 .41597 L
.63571 .38796 L
.64006 .37841 L
.65421 .35994 L
.66807 .33925 L
.67663 .33193 L
.69608 .30881 L
.70155 .30392 L
.72409 .27932 L
.72777 .27591 L
.7521 .25035 L
.75469 .2479 L
.78011 .2217 L
.782 .21989 L
.80812 .19325 L
.80954 .19188 L
.83613 .16493 L
.83722 .16387 L
.86415 .13669 L
.865 .13585 L
.89216 .10852 L
.89284 .10784 L
.92017 .08038 L
.92072 .07983 L
.94818 .05227 L
.94863 .05182 L
.97619 .02421 L
s
.97579 .97619 m
.94818 .94863 L
.94773 .94818 L
.92017 .92072 L
.91962 .92017 L
.89216 .89284 L
.89148 .89216 L
.86415 .865 L
.86331 .86415 L
.83613 .83722 L
.83507 .83613 L
.80812 .80954 L
.80675 .80812 L
.78011 .782 L
.7783 .78011 L
.7521 .75469 L
.74965 .7521 L
.72409 .72777 L
.72068 .72409 L
.69608 .70155 L
.69119 .69608 L
.66807 .67663 L
.66075 .66807 L
.64006 .65421 L
.62159 .64006 L
.61204 .63571 L
.58403 .62365 L
.55602 .62356 L
.52908 .64006 L
.52801 .64521 L
.5174 .66807 L
.51089 .69608 L
.5073 .72409 L
.50513 .7521 L
.50374 .78011 L
.50281 .80812 L
.50216 .83613 L
.5017 .86415 L
.50136 .89216 L
.50111 .92017 L
.50091 .94818 L
.50076 .97619 L
s
.49924 .02381 m
.49909 .05182 L
.49889 .07983 L
.49864 .10784 L
.4983 .13585 L
.49784 .16387 L
.49719 .19188 L
.49626 .21989 L
.49487 .2479 L
.4927 .27591 L
.48911 .30392 L
.4826 .33193 L
.47199 .35479 L
.47092 .35994 L
.44398 .37644 L
.41597 .37635 L
.38796 .36429 L
.37841 .35994 L
.35994 .34579 L
.33925 .33193 L
.33193 .32337 L
.30881 .30392 L
.30392 .29845 L
.27932 .27591 L
.27591 .27223 L
.25035 .2479 L
.2479 .24531 L
.2217 .21989 L
.21989 .218 L
.19325 .19188 L
.19188 .19046 L
.16493 .16387 L
.16387 .16278 L
.13669 .13585 L
.13585 .135 L
.10852 .10784 L
.10784 .10716 L
.08038 .07983 L
.07983 .07928 L
.05227 .05182 L
.05182 .05137 L
.02421 .02381 L
s
.02381 .49924 m
.05182 .49909 L
.07983 .49889 L
.10784 .49864 L
.13585 .4983 L
.16387 .49784 L
.19188 .49719 L
.21989 .49626 L
.2479 .49487 L
.27591 .4927 L
.30392 .48911 L
.33193 .4826 L
.35479 .47199 L
.35994 .47092 L
.37644 .44398 L
.37635 .41597 L
.36429 .38796 L
.35994 .37841 L
.34579 .35994 L
.33193 .33925 L
.32337 .33193 L
.30392 .30881 L
.29845 .30392 L
.27591 .27932 L
.27223 .27591 L
.2479 .25035 L
.24531 .2479 L
.21989 .2217 L
.218 .21989 L
.19188 .19325 L
.19046 .19188 L
.16387 .16493 L
.16278 .16387 L
.13585 .13669 L
.135 .13585 L
.10784 .10852 L
.10716 .10784 L
.07983 .08038 L
.07928 .07983 L
.05182 .05227 L
.05137 .05182 L
.02381 .02421 L
s
.97619 .97579 m
.94863 .94818 L
.94818 .94773 L
.92072 .92017 L
.92017 .91962 L
.89284 .89216 L
.89216 .89148 L
.865 .86415 L
.86415 .86331 L
.83722 .83613 L
.83613 .83507 L
.80954 .80812 L
.80812 .80675 L
.782 .78011 L
.78011 .7783 L
.75469 .7521 L
.7521 .74965 L
.72777 .72409 L
.72409 .72068 L
.70155 .69608 L
.69608 .69119 L
.67663 .66807 L
.66807 .66075 L
.65421 .64006 L
.64006 .62159 L
.63571 .61204 L
.62365 .58403 L
.62356 .55602 L
.64006 .52908 L
.64521 .52801 L
.66807 .5174 L
.69608 .51089 L
.72409 .5073 L
.7521 .50513 L
.78011 .50374 L
.80812 .50281 L
.83613 .50216 L
.86415 .5017 L
.89216 .50136 L
.92017 .50111 L
.94818 .50091 L
.97619 .50076 L
s
.49924 .97619 m
.49909 .94818 L
.49889 .92017 L
.49864 .89216 L
.4983 .86415 L
.49784 .83613 L
.49719 .80812 L
.49626 .78011 L
.49487 .7521 L
.4927 .72409 L
.48911 .69608 L
.4826 .66807 L
.47199 .64521 L
.47092 .64006 L
.44398 .62356 L
.41597 .62365 L
.38796 .63571 L
.37841 .64006 L
.35994 .65421 L
.33925 .66807 L
.33193 .67663 L
.30881 .69608 L
.30392 .70155 L
.27932 .72409 L
.27591 .72777 L
.25035 .7521 L
.2479 .75469 L
.2217 .78011 L
.21989 .782 L
.19325 .80812 L
.19188 .80954 L
.16493 .83613 L
.16387 .83722 L
.13669 .86415 L
.13585 .865 L
.10852 .89216 L
.10784 .89284 L
.08038 .92017 L
.07983 .92072 L
.05227 .94818 L
.05182 .94863 L
.02421 .97619 L
s
.97579 .02381 m
.94818 .05137 L
.94773 .05182 L
.92017 .07928 L
.91962 .07983 L
.89216 .10716 L
.89148 .10784 L
.86415 .135 L
.86331 .13585 L
.83613 .16278 L
.83507 .16387 L
.80812 .19046 L
.80675 .19188 L
.78011 .218 L
.7783 .21989 L
.7521 .24531 L
.74965 .2479 L
.72409 .27223 L
.72068 .27591 L
.69608 .29845 L
.69119 .30392 L
.66807 .32337 L
.66075 .33193 L
.64006 .34579 L
.62159 .35994 L
.61204 .36429 L
.58403 .37635 L
.55602 .37644 L
.52908 .35994 L
.52801 .35479 L
.5174 .33193 L
.51089 .30392 L
.5073 .27591 L
.50513 .2479 L
.50374 .21989 L
.50281 .19188 L
.50216 .16387 L
.5017 .13585 L
.50136 .10784 L
.50111 .07983 L
.50091 .05182 L
.50076 .02381 L
s
.02381 .4878 m
.05182 .48536 L
.07983 .48222 L
.10784 .47811 L
.13585 .47258 L
.1384 .47199 L
.16387 .46498 L
.19188 .45401 L
.20989 .44398 L
.21989 .43703 L
.24034 .41597 L
.2479 .40635 L
.25422 .38796 L
.25805 .35994 L
.25457 .33193 L
.2479 .31011 L
.24538 .30392 L
.23134 .27591 L
.21989 .25611 L
.2139 .2479 L
.19368 .21989 L
.19188 .21742 L
.17135 .19188 L
.16387 .18262 L
.14762 .16387 L
.13585 .15021 L
.12285 .13585 L
.10784 .11915 L
.0973 .10784 L
.07983 .08893 L
.07118 .07983 L
.05182 .05927 L
.04475 .05182 L
.02381 .03018 L
s
.97619 .96982 m
.95525 .94818 L
.94818 .94073 L
.92882 .92017 L
.92017 .91107 L
.9027 .89216 L
.89216 .88085 L
.87715 .86415 L
.86415 .84979 L
.85238 .83613 L
.83613 .81738 L
.82865 .80812 L
.80812 .78258 L
.80632 .78011 L
.7861 .7521 L
.78011 .74389 L
.76866 .72409 L
.75462 .69608 L
.7521 .68989 L
.74543 .66807 L
.74195 .64006 L
.74578 .61204 L
.7521 .59365 L
.75966 .58403 L
.78011 .56297 L
.79011 .55602 L
.80812 .54599 L
.83613 .53502 L
.8616 .52801 L
.86415 .52742 L
.89216 .52189 L
.92017 .51778 L
.94818 .51464 L
.97619 .5122 L
s
.4878 .97619 m
.48536 .94818 L
.48222 .92017 L
.47811 .89216 L
.47258 .86415 L
.47199 .8616 L
.46498 .83613 L
.45401 .80812 L
.44398 .79011 L
.43703 .78011 L
.41597 .75966 L
.40635 .7521 L
.38796 .74578 L
.35994 .74195 L
.33193 .74543 L
.31011 .7521 L
.30392 .75462 L
.27591 .76866 L
.25611 .78011 L
.2479 .7861 L
.21989 .80632 L
.21742 .80812 L
.19188 .82865 L
.18262 .83613 L
.16387 .85238 L
.15021 .86415 L
.13585 .87715 L
.11915 .89216 L
.10784 .9027 L
.08893 .92017 L
.07983 .92882 L
.05927 .94818 L
.05182 .95525 L
.03018 .97619 L
s
.96982 .02381 m
.94818 .04475 L
.94073 .05182 L
.92017 .07118 L
.91107 .07983 L
.89216 .0973 L
.88085 .10784 L
.86415 .12285 L
.84979 .13585 L
.83613 .14762 L
.81738 .16387 L
.80812 .17135 L
.78258 .19188 L
.78011 .19368 L
.7521 .2139 L
.74389 .21989 L
.72409 .23134 L
.69608 .24538 L
.68989 .2479 L
.66807 .25457 L
.64006 .25805 L
.61204 .25422 L
.59365 .2479 L
.58403 .24034 L
.56297 .21989 L
.55602 .20989 L
.54599 .19188 L
.53502 .16387 L
.52801 .1384 L
.52742 .13585 L
.52189 .10784 L
.51778 .07983 L
.51464 .05182 L
.5122 .02381 L
s
.02381 .46244 m
.05182 .45477 L
.07983 .4447 L
.08155 .44398 L
.10784 .43105 L
.13016 .41597 L
.13585 .41129 L
.15718 .38796 L
.16387 .37822 L
.1722 .35994 L
.17903 .33193 L
.1796 .30392 L
.17501 .27591 L
.16613 .2479 L
.16387 .24168 L
.15352 .21989 L
.13793 .19188 L
.13585 .18835 L
.11976 .16387 L
.10784 .14674 L
.09964 .13585 L
.07983 .11018 L
.07792 .10784 L
.0549 .07983 L
.05182 .07613 L
.03104 .05182 L
.02381 .04381 L
s
.97619 .95619 m
.96896 .94818 L
.94818 .92387 L
.9451 .92017 L
.92208 .89216 L
.92017 .88982 L
.90036 .86415 L
.89216 .85326 L
.88024 .83613 L
.86415 .81165 L
.86207 .80812 L
.84648 .78011 L
.83613 .75832 L
.83387 .7521 L
.82499 .72409 L
.8204 .69608 L
.82097 .66807 L
.8278 .64006 L
.83613 .62178 L
.84282 .61204 L
.86415 .58871 L
.86984 .58403 L
.89216 .56895 L
.91845 .55602 L
.92017 .5553 L
.94818 .54523 L
.97619 .53756 L
s
.46244 .97619 m
.45477 .94818 L
.4447 .92017 L
.44398 .91845 L
.43105 .89216 L
.41597 .86984 L
.41129 .86415 L
.38796 .84282 L
.37822 .83613 L
.35994 .8278 L
.33193 .82097 L
.30392 .8204 L
.27591 .82499 L
.2479 .83387 L
.24168 .83613 L
.21989 .84648 L
.19188 .86207 L
.18835 .86415 L
.16387 .88024 L
.14674 .89216 L
.13585 .90036 L
.11018 .92017 L
.10784 .92208 L
.07983 .9451 L
.07613 .94818 L
.05182 .96896 L
.04381 .97619 L
s
.95619 .02381 m
.94818 .03104 L
.92387 .05182 L
.92017 .0549 L
.89216 .07792 L
.88982 .07983 L
.86415 .09964 L
.85326 .10784 L
.83613 .11976 L
.81165 .13585 L
.80812 .13793 L
.78011 .15352 L
.75832 .16387 L
.7521 .16613 L
.72409 .17501 L
.69608 .1796 L
.66807 .17903 L
.64006 .1722 L
.62178 .16387 L
.61204 .15718 L
.58871 .13585 L
.58403 .13016 L
.56895 .10784 L
.55602 .08155 L
.5553 .07983 L
.54523 .05182 L
.53756 .02381 L
s
.02381 .4217 m
.03403 .41597 L
.05182 .40427 L
.07125 .38796 L
.07983 .37915 L
.09444 .35994 L
.10784 .33376 L
.10849 .33193 L
.11573 .30392 L
.11758 .27591 L
.11488 .2479 L
.10828 .21989 L
.10784 .21827 L
.09822 .19188 L
.08524 .16387 L
.07983 .15333 L
.06972 .13585 L
.05209 .10784 L
.05182 .10743 L
.03273 .07983 L
.02381 .06774 L
s
.97619 .93226 m
.96727 .92017 L
.94818 .89257 L
.94791 .89216 L
.93028 .86415 L
.92017 .84667 L
.91476 .83613 L
.90178 .80812 L
.89216 .78173 L
.89172 .78011 L
.88512 .7521 L
.88242 .72409 L
.88427 .69608 L
.89151 .66807 L
.89216 .66624 L
.90556 .64006 L
.92017 .62085 L
.92875 .61204 L
.94818 .59573 L
.96597 .58403 L
.97619 .5783 L
s
.4217 .97619 m
.41597 .96597 L
.40427 .94818 L
.38796 .92875 L
.37915 .92017 L
.35994 .90556 L
.33376 .89216 L
.33193 .89151 L
.30392 .88427 L
.27591 .88242 L
.2479 .88512 L
.21989 .89172 L
.21827 .89216 L
.19188 .90178 L
.16387 .91476 L
.15333 .92017 L
.13585 .93028 L
.10784 .94791 L
.10743 .94818 L
.07983 .96727 L
.06774 .97619 L
s
.93226 .02381 m
.92017 .03273 L
.89257 .05182 L
.89216 .05209 L
.86415 .06972 L
.84667 .07983 L
.83613 .08524 L
.80812 .09822 L
.78173 .10784 L
.78011 .10828 L
.7521 .11488 L
.72409 .11758 L
.69608 .11573 L
.66807 .10849 L
.66624 .10784 L
.64006 .09444 L
.62085 .07983 L
.61204 .07125 L
.59573 .05182 L
.58403 .03403 L
.5783 .02381 L
s
.02381 .35884 m
.0427 .33193 L
.05182 .31336 L
.05518 .30392 L
.06196 .27591 L
.06402 .2479 L
.06203 .21989 L
.05649 .19188 L
.05182 .17432 L
.04784 .16387 L
.03644 .13585 L
.02381 .11026 L
s
.97619 .88974 m
.96356 .86415 L
.95216 .83613 L
.94818 .82568 L
.94351 .80812 L
.93797 .78011 L
.93598 .7521 L
.93804 .72409 L
.94482 .69608 L
.94818 .68664 L
.9573 .66807 L
.97619 .64116 L
s
.35884 .97619 m
.33193 .9573 L
.31336 .94818 L
.30392 .94482 L
.27591 .93804 L
.2479 .93598 L
.21989 .93797 L
.19188 .94351 L
.17432 .94818 L
.16387 .95216 L
.13585 .96356 L
.11026 .97619 L
s
.88974 .02381 m
.86415 .03644 L
.83613 .04784 L
.82568 .05182 L
.80812 .05649 L
.78011 .06203 L
.7521 .06402 L
.72409 .06196 L
.69608 .05518 L
.68664 .05182 L
.66807 .0427 L
.64116 .02381 L
s
.02381 .6173 m
.0284 .61204 L
.04871 .58403 L
.05182 .57924 L
.06288 .55602 L
.07128 .52801 L
.07406 .5 L
.07128 .47199 L
.06288 .44398 L
.05182 .42076 L
.04871 .41597 L
.0284 .38796 L
.02381 .3827 L
s
.97619 .6173 m
.9716 .61204 L
.95129 .58403 L
.94818 .57924 L
.93712 .55602 L
.92872 .52801 L
.92594 .5 L
.92872 .47199 L
.93712 .44398 L
.94818 .42076 L
.95129 .41597 L
.9716 .38796 L
.97619 .3827 L
s
.6173 .97619 m
.61204 .9716 L
.58403 .95129 L
.57924 .94818 L
.55602 .93712 L
.52801 .92872 L
.5 .92594 L
.47199 .92872 L
.44398 .93712 L
.42076 .94818 L
.41597 .95129 L
.38796 .9716 L
.3827 .97619 L
s
.6173 .02381 m
.61204 .0284 L
.58403 .04871 L
.57924 .05182 L
.55602 .06288 L
.52801 .07128 L
.5 .07406 L
.47199 .07128 L
.44398 .06288 L
.42076 .05182 L
.41597 .04871 L
.38796 .0284 L
.3827 .02381 L
s
.02381 .66269 m
.05182 .643 L
.05563 .64006 L
.07983 .62007 L
.0882 .61204 L
.10784 .59088 L
.11299 .58403 L
.13022 .55602 L
.13585 .54286 L
.14029 .52801 L
.14359 .5 L
.14029 .47199 L
.13585 .45714 L
.13022 .44398 L
.11299 .41597 L
.10784 .40912 L
.0882 .38796 L
.07983 .37993 L
.05563 .35994 L
.05182 .357 L
.02381 .33731 L
s
.97619 .66269 m
.94818 .643 L
.94437 .64006 L
.92017 .62007 L
.9118 .61204 L
.89216 .59088 L
.88701 .58403 L
.86978 .55602 L
.86415 .54286 L
.85971 .52801 L
.85641 .5 L
.85971 .47199 L
.86415 .45714 L
.86978 .44398 L
.88701 .41597 L
.89216 .40912 L
.9118 .38796 L
.92017 .37993 L
.94437 .35994 L
.94818 .357 L
.97619 .33731 L
s
.66269 .97619 m
.643 .94818 L
.64006 .94437 L
.62007 .92017 L
.61204 .9118 L
.59088 .89216 L
.58403 .88701 L
.55602 .86978 L
.54286 .86415 L
.52801 .85971 L
.5 .85641 L
.47199 .85971 L
.45714 .86415 L
.44398 .86978 L
.41597 .88701 L
.40912 .89216 L
.38796 .9118 L
.37993 .92017 L
.35994 .94437 L
.357 .94818 L
.33731 .97619 L
s
.66269 .02381 m
.643 .05182 L
.64006 .05563 L
.62007 .07983 L
.61204 .0882 L
.59088 .10784 L
.58403 .11299 L
.55602 .13022 L
.54286 .13585 L
.52801 .14029 L
.5 .14359 L
.47199 .14029 L
.45714 .13585 L
.44398 .13022 L
.41597 .11299 L
.40912 .10784 L
.38796 .0882 L
.37993 .07983 L
.35994 .05563 L
.357 .05182 L
.33731 .02381 L
s
.02381 .68661 m
.05182 .67278 L
.0609 .66807 L
.07983 .65831 L
.10784 .64276 L
.11232 .64006 L
.13585 .62579 L
.1557 .61204 L
.16387 .60623 L
.1894 .58403 L
.19188 .58183 L
.21262 .55602 L
.21989 .54359 L
.22609 .52801 L
.23045 .5 L
.22609 .47199 L
.21989 .45641 L
.21262 .44398 L
.19188 .41817 L
.1894 .41597 L
.16387 .39377 L
.1557 .38796 L
.13585 .37421 L
.11232 .35994 L
.10784 .35724 L
.07983 .34169 L
.0609 .33193 L
.05182 .32722 L
.02381 .31339 L
s
.97619 .68661 m
.94818 .67278 L
.9391 .66807 L
.92017 .65831 L
.89216 .64276 L
.88768 .64006 L
.86415 .62579 L
.8443 .61204 L
.83613 .60623 L
.8106 .58403 L
.80812 .58183 L
.78738 .55602 L
.78011 .54359 L
.77391 .52801 L
.76955 .5 L
.77391 .47199 L
.78011 .45641 L
.78738 .44398 L
.80812 .41817 L
.8106 .41597 L
.83613 .39377 L
.8443 .38796 L
.86415 .37421 L
.88768 .35994 L
.89216 .35724 L
.92017 .34169 L
.9391 .33193 L
.94818 .32722 L
.97619 .31339 L
s
.68661 .97619 m
.67278 .94818 L
.66807 .9391 L
.65831 .92017 L
.64276 .89216 L
.64006 .88768 L
.62579 .86415 L
.61204 .8443 L
.60623 .83613 L
.58403 .8106 L
.58183 .80812 L
.55602 .78738 L
.54359 .78011 L
.52801 .77391 L
.5 .76955 L
.47199 .77391 L
.45641 .78011 L
.44398 .78738 L
.41817 .80812 L
.41597 .8106 L
.39377 .83613 L
.38796 .8443 L
.37421 .86415 L
.35994 .88768 L
.35724 .89216 L
.34169 .92017 L
.33193 .9391 L
.32722 .94818 L
.31339 .97619 L
s
.68661 .02381 m
.67278 .05182 L
.66807 .0609 L
.65831 .07983 L
.64276 .10784 L
.64006 .11232 L
.62579 .13585 L
.61204 .1557 L
.60623 .16387 L
.58403 .1894 L
.58183 .19188 L
.55602 .21262 L
.54359 .21989 L
.52801 .22609 L
.5 .23045 L
.47199 .22609 L
.45641 .21989 L
.44398 .21262 L
.41817 .19188 L
.41597 .1894 L
.39377 .16387 L
.38796 .1557 L
.37421 .13585 L
.35994 .11232 L
.35724 .10784 L
.34169 .07983 L
.33193 .0609 L
.32722 .05182 L
.31339 .02381 L
s
.02381 .69659 m
.02538 .69608 L
.05182 .68489 L
.07983 .67311 L
.09144 .66807 L
.10784 .66131 L
.13585 .64942 L
.15738 .64006 L
.16387 .63741 L
.19188 .62531 L
.21989 .6128 L
.22121 .61204 L
.2479 .60018 L
.27591 .58644 L
.27919 .58403 L
.30392 .57206 L
.32742 .55602 L
.33193 .55523 L
.35596 .52801 L
.35994 .52175 L
.36406 .5 L
.35994 .47825 L
.35596 .47199 L
.33193 .44477 L
.32742 .44398 L
.30392 .42794 L
.27919 .41597 L
.27591 .41356 L
.2479 .39982 L
.22121 .38796 L
.21989 .3872 L
.19188 .37469 L
.16387 .36259 L
.15738 .35994 L
.13585 .35058 L
.10784 .33869 L
.09144 .33193 L
.07983 .32689 L
.05182 .31511 L
.02538 .30392 L
.02381 .30341 L
s
.97619 .69659 m
.97462 .69608 L
.94818 .68489 L
.92017 .67311 L
.90856 .66807 L
.89216 .66131 L
.86415 .64942 L
.84262 .64006 L
.83613 .63741 L
.80812 .62531 L
.78011 .6128 L
.77879 .61204 L
.7521 .60018 L
.72409 .58644 L
.72081 .58403 L
.69608 .57206 L
.67258 .55602 L
.66807 .55523 L
.64404 .52801 L
.64006 .52175 L
.63594 .5 L
.64006 .47825 L
.64404 .47199 L
.66807 .44477 L
.67258 .44398 L
.69608 .42794 L
.72081 .41597 L
.72409 .41356 L
.7521 .39982 L
.77879 .38796 L
.78011 .3872 L
.80812 .37469 L
.83613 .36259 L
.84262 .35994 L
.86415 .35058 L
.89216 .33869 L
.90856 .33193 L
.92017 .32689 L
.94818 .31511 L
.97462 .30392 L
.97619 .30341 L
s
.69659 .97619 m
.69608 .97462 L
.68489 .94818 L
.67311 .92017 L
.66807 .90856 L
.66131 .89216 L
.64942 .86415 L
.64006 .84262 L
.63741 .83613 L
.62531 .80812 L
.6128 .78011 L
.61204 .77879 L
.60018 .7521 L
.58644 .72409 L
.58403 .72081 L
.57206 .69608 L
.55602 .67258 L
.55523 .66807 L
.52801 .64404 L
.52175 .64006 L
.5 .63594 L
.47825 .64006 L
.47199 .64404 L
.44477 .66807 L
.44398 .67258 L
.42794 .69608 L
.41597 .72081 L
.41356 .72409 L
.39982 .7521 L
.38796 .77879 L
.3872 .78011 L
.37469 .80812 L
.36259 .83613 L
.35994 .84262 L
.35058 .86415 L
.33869 .89216 L
.33193 .90856 L
.32689 .92017 L
.31511 .94818 L
.30392 .97462 L
.30341 .97619 L
s
.69659 .02381 m
.69608 .02538 L
.68489 .05182 L
.67311 .07983 L
.66807 .09144 L
.66131 .10784 L
.64942 .13585 L
.64006 .15738 L
.63741 .16387 L
.62531 .19188 L
.6128 .21989 L
.61204 .22121 L
.60018 .2479 L
.58644 .27591 L
.58403 .27919 L
.57206 .30392 L
.55602 .32742 L
.55523 .33193 L
.52801 .35596 L
.52175 .35994 L
.5 .36406 L
.47825 .35994 L
.47199 .35596 L
.44477 .33193 L
.44398 .32742 L
.42794 .30392 L
.41597 .27919 L
.41356 .27591 L
.39982 .2479 L
.38796 .22121 L
.3872 .21989 L
.37469 .19188 L
.36259 .16387 L
.35994 .15738 L
.35058 .13585 L
.33869 .10784 L
.33193 .09144 L
.32689 .07983 L
.31511 .05182 L
.30392 .02538 L
.30341 .02381 L
s
.97619 .6979 m
.97083 .69608 L
.94818 .68645 L
.92017 .67501 L
.90346 .66807 L
.89216 .66363 L
.86415 .65233 L
.83613 .64108 L
.83392 .64006 L
.80812 .6301 L
.78011 .61925 L
.76219 .61204 L
.7521 .60882 L
.72409 .59911 L
.69608 .59024 L
.67191 .58403 L
.66807 .58333 L
.64006 .58039 L
.61324 .58403 L
.61204 .58449 L
.58449 .61204 L
.58403 .61324 L
.58039 .64006 L
.58333 .66807 L
.58403 .67191 L
.59024 .69608 L
.59911 .72409 L
.60882 .7521 L
.61204 .76219 L
.61925 .78011 L
.6301 .80812 L
.64006 .83392 L
.64108 .83613 L
.65233 .86415 L
.66363 .89216 L
.66807 .90346 L
.67501 .92017 L
.68645 .94818 L
.69608 .97083 L
.6979 .97619 L
s
.02381 .6979 m
.02917 .69608 L
.05182 .68645 L
.07983 .67501 L
.09654 .66807 L
.10784 .66363 L
.13585 .65233 L
.16387 .64108 L
.16608 .64006 L
.19188 .6301 L
.21989 .61925 L
.23781 .61204 L
.2479 .60882 L
.27591 .59911 L
.30392 .59024 L
.32809 .58403 L
.33193 .58333 L
.35994 .58039 L
.38676 .58403 L
.38796 .58449 L
.41551 .61204 L
.41597 .61324 L
.41961 .64006 L
.41667 .66807 L
.41597 .67191 L
.40976 .69608 L
.40089 .72409 L
.39118 .7521 L
.38796 .76219 L
.38075 .78011 L
.3699 .80812 L
.35994 .83392 L
.35892 .83613 L
.34767 .86415 L
.33637 .89216 L
.33193 .90346 L
.32499 .92017 L
.31355 .94818 L
.30392 .97083 L
.3021 .97619 L
s
.97619 .3021 m
.97083 .30392 L
.94818 .31355 L
.92017 .32499 L
.90346 .33193 L
.89216 .33637 L
.86415 .34767 L
.83613 .35892 L
.83392 .35994 L
.80812 .3699 L
.78011 .38075 L
.76219 .38796 L
.7521 .39118 L
.72409 .40089 L
.69608 .40976 L
.67191 .41597 L
.66807 .41667 L
.64006 .41961 L
.61324 .41597 L
.61204 .41551 L
.58449 .38796 L
.58403 .38676 L
.58039 .35994 L
.58333 .33193 L
.58403 .32809 L
.59024 .30392 L
.59911 .27591 L
.60882 .2479 L
.61204 .23781 L
.61925 .21989 L
.6301 .19188 L
.64006 .16608 L
.64108 .16387 L
.65233 .13585 L
.66363 .10784 L
.66807 .09654 L
.67501 .07983 L
.68645 .05182 L
.69608 .02917 L
.6979 .02381 L
s
.02381 .3021 m
.02917 .30392 L
.05182 .31355 L
.07983 .32499 L
.09654 .33193 L
.10784 .33637 L
.13585 .34767 L
.16387 .35892 L
.16608 .35994 L
.19188 .3699 L
.21989 .38075 L
.23781 .38796 L
.2479 .39118 L
.27591 .40089 L
.30392 .40976 L
.32809 .41597 L
.33193 .41667 L
.35994 .41961 L
.38676 .41597 L
.38796 .41551 L
.41551 .38796 L
.41597 .38676 L
.41961 .35994 L
.41667 .33193 L
.41597 .32809 L
.40976 .30392 L
.40089 .27591 L
.39118 .2479 L
.38796 .23781 L
.38075 .21989 L
.3699 .19188 L
.35994 .16608 L
.35892 .16387 L
.34767 .13585 L
.33637 .10784 L
.33193 .09654 L
.32499 .07983 L
.31355 .05182 L
.30392 .02917 L
.3021 .02381 L
s
.97619 .70744 m
.94818 .69778 L
.9434 .69608 L
.92017 .68868 L
.89216 .68025 L
.86415 .67275 L
.84519 .66807 L
.83613 .66654 L
.80812 .66214 L
.78011 .66023 L
.7521 .66189 L
.72612 .66807 L
.72409 .66897 L
.69608 .68533 L
.68533 .69608 L
.66897 .72409 L
.66807 .72612 L
.66189 .7521 L
.66023 .78011 L
.66214 .80812 L
.66654 .83613 L
.66807 .84519 L
.67275 .86415 L
.68025 .89216 L
.68868 .92017 L
.69608 .9434 L
.69778 .94818 L
.70744 .97619 L
s
.02381 .70744 m
.05182 .69778 L
.0566 .69608 L
.07983 .68868 L
.10784 .68025 L
.13585 .67275 L
.15481 .66807 L
.16387 .66654 L
.19188 .66214 L
.21989 .66023 L
.2479 .66189 L
.27388 .66807 L
.27591 .66897 L
.30392 .68533 L
.31467 .69608 L
.33103 .72409 L
.33193 .72612 L
.33811 .7521 L
.33977 .78011 L
.33786 .80812 L
.33346 .83613 L
.33193 .84519 L
.32725 .86415 L
.31975 .89216 L
.31132 .92017 L
.30392 .9434 L
.30222 .94818 L
.29256 .97619 L
s
.97619 .29256 m
.94818 .30222 L
.9434 .30392 L
.92017 .31132 L
.89216 .31975 L
.86415 .32725 L
.84519 .33193 L
.83613 .33346 L
.80812 .33786 L
.78011 .33977 L
.7521 .33811 L
.72612 .33193 L
.72409 .33103 L
.69608 .31467 L
.68533 .30392 L
.66897 .27591 L
.66807 .27388 L
.66189 .2479 L
.66023 .21989 L
.66214 .19188 L
.66654 .16387 L
.66807 .15481 L
.67275 .13585 L
.68025 .10784 L
.68868 .07983 L
.69608 .0566 L
.69778 .05182 L
.70744 .02381 L
s
.02381 .29256 m
.05182 .30222 L
.0566 .30392 L
.07983 .31132 L
.10784 .31975 L
.13585 .32725 L
.15481 .33193 L
.16387 .33346 L
.19188 .33786 L
.21989 .33977 L
.2479 .33811 L
.27388 .33193 L
.27591 .33103 L
.30392 .31467 L
.31467 .30392 L
.33103 .27591 L
.33193 .27388 L
.33811 .2479 L
.33977 .21989 L
.33786 .19188 L
.33346 .16387 L
.33193 .15481 L
.32725 .13585 L
.31975 .10784 L
.31132 .07983 L
.30392 .0566 L
.30222 .05182 L
.29256 .02381 L
s
.97619 .72717 m
.94977 .72409 L
.94818 .721 L
.92017 .71613 L
.89216 .71294 L
.86415 .71192 L
.83613 .71379 L
.80812 .71958 L
.79485 .72409 L
.78011 .73105 L
.7521 .75185 L
.75185 .7521 L
.73105 .78011 L
.72409 .79485 L
.71958 .80812 L
.71379 .83613 L
.71192 .86415 L
.71294 .89216 L
.71613 .92017 L
.721 .94818 L
.72409 .94977 L
.72717 .97619 L
s
.02381 .72717 m
.05023 .72409 L
.05182 .721 L
.07983 .71613 L
.10784 .71294 L
.13585 .71192 L
.16387 .71379 L
.19188 .71958 L
.20515 .72409 L
.21989 .73105 L
.2479 .75185 L
.24815 .7521 L
.26895 .78011 L
.27591 .79485 L
.28042 .80812 L
.28621 .83613 L
.28808 .86415 L
.28706 .89216 L
.28387 .92017 L
.279 .94818 L
.27591 .94977 L
.27283 .97619 L
s
.97619 .27283 m
.94977 .27591 L
.94818 .279 L
.92017 .28387 L
.89216 .28706 L
.86415 .28808 L
.83613 .28621 L
.80812 .28042 L
.79485 .27591 L
.78011 .26895 L
.7521 .24815 L
.75185 .2479 L
.73105 .21989 L
.72409 .20515 L
.71958 .19188 L
.71379 .16387 L
.71192 .13585 L
.71294 .10784 L
.71613 .07983 L
.721 .05182 L
.72409 .05023 L
.72717 .02381 L
s
.02381 .27283 m
.05023 .27591 L
.05182 .279 L
.07983 .28387 L
.10784 .28706 L
.13585 .28808 L
.16387 .28621 L
.19188 .28042 L
.20515 .27591 L
.21989 .26895 L
.2479 .24815 L
.24815 .2479 L
.26895 .21989 L
.27591 .20515 L
.28042 .19188 L
.28621 .16387 L
.28808 .13585 L
.28706 .10784 L
.28387 .07983 L
.279 .05182 L
.27591 .05023 L
.27283 .02381 L
s
.97619 .75514 m
.94818 .75338 L
.92017 .75379 L
.89216 .75695 L
.86415 .76371 L
.83613 .77544 L
.82793 .78011 L
.80812 .79467 L
.79467 .80812 L
.78011 .82793 L
.77544 .83613 L
.76371 .86415 L
.75695 .89216 L
.75379 .92017 L
.75338 .94818 L
.75514 .97619 L
s
.02381 .75514 m
.05182 .75338 L
.07983 .75379 L
.10784 .75695 L
.13585 .76371 L
.16387 .77544 L
.17207 .78011 L
.19188 .79467 L
.20533 .80812 L
.21989 .82793 L
.22456 .83613 L
.23629 .86415 L
.24305 .89216 L
.24621 .92017 L
.24662 .94818 L
.24486 .97619 L
s
.97619 .24486 m
.94818 .24662 L
.92017 .24621 L
.89216 .24305 L
.86415 .23629 L
.83613 .22456 L
.82793 .21989 L
.80812 .20533 L
.79467 .19188 L
.78011 .17207 L
.77544 .16387 L
.76371 .13585 L
.75695 .10784 L
.75379 .07983 L
.75338 .05182 L
.75514 .02381 L
s
.02381 .24486 m
.05182 .24662 L
.07983 .24621 L
.10784 .24305 L
.13585 .23629 L
.16387 .22456 L
.17207 .21989 L
.19188 .20533 L
.20533 .19188 L
.21989 .17207 L
.22456 .16387 L
.23629 .13585 L
.24305 .10784 L
.24621 .07983 L
.24662 .05182 L
.24486 .02381 L
s
.97619 .78955 m
.94818 .79279 L
.92017 .79915 L
.89544 .80812 L
.89216 .80962 L
.86415 .82584 L
.85113 .83613 L
.83613 .85113 L
.82584 .86415 L
.80962 .89216 L
.80812 .89544 L
.79915 .92017 L
.79279 .94818 L
.78955 .97619 L
s
.02381 .78955 m
.05182 .79279 L
.07983 .79915 L
.10456 .80812 L
.10784 .80962 L
.13585 .82584 L
.14887 .83613 L
.16387 .85113 L
.17416 .86415 L
.19038 .89216 L
.19188 .89544 L
.20085 .92017 L
.20721 .94818 L
.21045 .97619 L
s
.97619 .21045 m
.94818 .20721 L
.92017 .20085 L
.89544 .19188 L
.89216 .19038 L
.86415 .17416 L
.85113 .16387 L
.83613 .14887 L
.82584 .13585 L
.80962 .10784 L
.80812 .10456 L
.79915 .07983 L
.79279 .05182 L
.78955 .02381 L
s
.02381 .21045 m
.05182 .20721 L
.07983 .20085 L
.10456 .19188 L
.10784 .19038 L
.13585 .17416 L
.14887 .16387 L
.16387 .14887 L
.17416 .13585 L
.19038 .10784 L
.19188 .10456 L
.20085 .07983 L
.20721 .05182 L
.21045 .02381 L
s
.97619 .82915 m
.95305 .83613 L
.94818 .83794 L
.92017 .85116 L
.90034 .86415 L
.89216 .87066 L
.87066 .89216 L
.86415 .90034 L
.85116 .92017 L
.83794 .94818 L
.83613 .95305 L
.82915 .97619 L
s
.02381 .82915 m
.04695 .83613 L
.05182 .83794 L
.07983 .85116 L
.09966 .86415 L
.10784 .87066 L
.12934 .89216 L
.13585 .90034 L
.14884 .92017 L
.16206 .94818 L
.16387 .95305 L
.17085 .97619 L
s
.97619 .17085 m
.95305 .16387 L
.94818 .16206 L
.92017 .14884 L
.90034 .13585 L
.89216 .12934 L
.87066 .10784 L
.86415 .09966 L
.85116 .07983 L
.83794 .05182 L
.83613 .04695 L
.82915 .02381 L
s
.02381 .17085 m
.04695 .16387 L
.05182 .16206 L
.07983 .14884 L
.09966 .13585 L
.10784 .12934 L
.12934 .10784 L
.13585 .09966 L
.14884 .07983 L
.16206 .05182 L
.16387 .04695 L
.17085 .02381 L
s
.97619 .87335 m
.94818 .88853 L
.94274 .89216 L
.92017 .91028 L
.91028 .92017 L
.89216 .94274 L
.88853 .94818 L
.87335 .97619 L
s
.02381 .87335 m
.05182 .88853 L
.05726 .89216 L
.07983 .91028 L
.08972 .92017 L
.10784 .94274 L
.11147 .94818 L
.12665 .97619 L
s
.97619 .12665 m
.94818 .11147 L
.94274 .10784 L
.92017 .08972 L
.91028 .07983 L
.89216 .05726 L
.88853 .05182 L
.87335 .02381 L
s
.02381 .12665 m
.05182 .11147 L
.05726 .10784 L
.07983 .08972 L
.08972 .07983 L
.10784 .05726 L
.11147 .05182 L
.12665 .02381 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 288},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<03oool400000300oooo1@00000]0?ooo`800000
<03oool5000002l0oooo1000000P0?ooo`00<03oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo02`0oooo00@000000?ooo`3oool00000<@3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo0240oooo000a0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0;03o
ool010000000oooo0?ooo`00000a0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
803oool002X0oooo100000040?ooo`030000003oool0oooo02T0oooo100000040?ooo`030000003o
ool0oooo02`0oooo00@000000?ooo`3oool00000<@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo01l0oooo000`0?ooo`040000003oool0oooo00000380oooo00<000000?ooo`3oool0
;03oool010000000oooo0?ooo`00000a0?ooo`030000003oool0oooo02l0oooo00@000000?ooo`3o
ool00000803oool00340oooo0P00000b0?ooo`800000;`3oool200000340oooo0P00000b0?ooo`80
00008@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool000l0ooooo`00000A00000040oooo000?0?ooo`8000002P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`8000000@3oool000l0oooo0P00000N0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0703oool200000040oooo000?0?ooo`030000003oool0oooo0?l0oooo3@3oool10000
0040oooo000?0?ooo`030000003oool0oooo0?l0oooo3@3oool100000040oooo000?0?ooo`030000
003oool0oooo0?l0oooo3@3oool100000040oooo000?0?ooo`030000003oool0oooo0?l0oooo3@3o
ool100000040oooo000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo0P0000020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo008000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02000000/0oooo00<000000?ooo`3oool0
0`3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool100000040oooo000?0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`80
00002`3oool2000000`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P0000080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
008000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`8000000P3oool00`000000oooo0?ooo`040?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`<000002`3oool2000000D0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo
0@0000010?ooo`003`3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`8000002P3oool3000000T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0000000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00002`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool2000000H0
oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0
oooo0`00000;0?ooo`030000003oool0oooo00@0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000001@3oool100000040oooo000?0?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool010000000oooo0?ooo`3oool3000000H0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool2000000@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool2000000d0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool300000080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`040?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool0000000H0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool00000008000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000030?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool03@3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P0000020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000>
0?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool00P0000000`3oool000000?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0080oooo0P0000060?ooo`030000003oool0oooo00D0oooo0P00
00060?ooo`040000003oool0oooo0?ooo`<0000000<0oooo0000003oool01P3oool100000040oooo
000?0?ooo`800000103oool01@000000oooo0?ooo`000000oooo00<000000`3oool2000000H0oooo
0P0000040?ooo`030000003oool0oooo00L0oooo0P0000000`3oool000000?ooo`0:0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0000000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`8000003P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool010000000oooo0000000000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool010000000oooo0?ooo`3oool3000000050?ooo`000000oooo0?ooo`000000103oool20000
0040oooo000?0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool000000?ooo`030000
00@0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000/0oooo0P00000;
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000<0oooo0P0000050?ooo`030000003oool0oooo00d0oooo0P00
000:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P0000030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02@3oool2000000h0oooo00<000000?ooo`3oool0103o
ool300000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool2000000/0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`<0000000D0oooo0000003o
ool0oooo000000060?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0103oool01P000000
oooo0?ooo`3oool000000?ooo`<00000103oool00`000000oooo0?ooo`050?ooo`030000003oool0
000000d0oooo0`0000090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@000001`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`040000003oool0
oooo000000d0oooo00<000000?ooo`3oool01@3oool400000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool3000000`0oooo00<000000?ooo`3oool00P0000070?ooo`040000003oool0oooo0?ooo`<00000
00<0oooo0000003oool00P3oool00`000000oooo0?ooo`040?ooo`4000000@3oool000l0oooo00<0
00000?ooo`3oool01@3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000040?oo
o`8000001P3oool2000000d0oooo00<000000?ooo`3oool00`0000060?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`D000000`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05000000D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0`000002
0?ooo`030000003oool0oooo00/0oooo0P0000070?ooo`8000000`3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool01@3oool100000040oooo000?0?ooo`030000003oool0
oooo00H0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001@3oool00`000000
oooo0?ooo`030?ooo`<000002`3oool00`000000oooo0?ooo`040?ooo`L000002P3oool00`000000
oooo0?ooo`060?ooo`D0000000@0oooo0000003oool0oooo0P0000020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`8000001P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo0P0000060?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`000000
0`3oool000000?ooo`060?ooo`030000003oool0oooo00P0oooo1`0000060?ooo`030000003oool0
oooo00T0oooo0`0000060?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`07
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000D0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`8000002@3oool00`000000oooo0?ooo`090?ooo`T000000`3oool00`00
0000oooo0?ooo`020?ooo`D000001@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo0P000003
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`3oool0oooo0P0000090?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0`3oool5000000@0oooo00<000000?ooo`3oool00P3oool8000000/0oooo00<000000?ooo`3oool0
1`3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`4000000@3oool000l0oooo
00<000000?ooo`3oool0203oool020000000oooo0?ooo`3oool000000?ooo`000000oooo0P000004
0?ooo`030000003oool0000000H0oooo0P0000060?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool01P3oool8000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00T0oooo100000090?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`06
0?ooo`@000002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool9000000L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`8000001P3o
ool010000000oooo0?ooo`0000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`080?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`060000003oool0oooo0?ooo`000000oooo0P0000000`3oool000000?ooo`030?oo
o`030000003oool0oooo00L0oooo0P0000040?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0=0?ooo`@000001@3oool010000000oooo0?ooo`3oool2000000<0oooo00<0
00000?ooo`3oool00`3oool5000000h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo0P0000080?ooo`<00000103oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`4000000@3oool000l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0?ooo`00
0000oooo0P0000000`3oool000000?ooo`020?ooo`8000002P3oool2000000030?ooo`000000oooo
00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo0000000@0?ooo`040000003oool0oooo0?ooo`H000000`3oool2000000<0oooo
1P0000040?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo000000090?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo
000000X0oooo0P0000040?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool0oooo0000003oool2000000040?oo
o`000000oooo00000080oooo00<000000?ooo`3oool02@3oool2000000`0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000403oool00`00
0000oooo0?ooo`070?ooo`X000002P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool00000
00T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo0`00000:
0?ooo`050000003oool0oooo0000003oool00P000000103oool000000?ooo`0000030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool100000040oooo000?0?ooo`8000001`3o
ool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0?ooo`000000oooo0P0000000`3oool0
00000?ooo`030?ooo`8000002@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?oo
o`8000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool01`3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo0P0000090?ooo`800000103oool01P000000oooo0?oo
o`000000oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`80
00000@3oool000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000000`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0203oool0
10000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0=0?ooo`040000003oool00000000000L0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`070?ooo`030000003oool0oooo00<0
oooo00H000000?ooo`00000000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool100000040oooo000?0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`060000003oool000000000003oool000001@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P0000070?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`040000003o
ool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`8000000`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00D0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`02000000050?ooo`000000oooo0?ooo`0000001P3oool00`000000oooo0?ooo`07
0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`8000000`3o
ool00`000000oooo0?ooo`050?ooo`8000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`3oool2000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool010000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`04
0000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`8000001P3oool00`00
0000oooo0?ooo`020?ooo`8000001@3oool010000000oooo0?ooo`0000020?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`080?ooo`4000000@3oool000l0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`080000003oool000000000003oool00000
0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000002@3oool30000
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0080oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`03000000T0oooo00@000000?ooo`3oool000001P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`090?ooo`40
00000@3oool000l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`800000
3@3oool3000000`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`040000
003oool0oooo0?ooo`8000000`3oool3000000X0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`8000000`3oool2000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo0`00000<0?ooo`030000003oool0000000H0oooo00@000000?ooo`3oool000000P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool02@3oool100000040oooo000?0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00@00000
0?ooo`00000000002P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00@0
00000?ooo`3oool0oooo0P0000020?ooo`<00000303oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00D000000?ooo`000000
00000?ooo`02000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`0=0?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`3oool000000?ooo`8000000`3o
ool00`000000oooo0?ooo`0:0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`0000000000303oool010000000oooo
0?ooo`3oool2000000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool01000
0000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00H0oooo0P0000030?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`000000103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0@0000010?ooo`003`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P0000050?ooo`8000000`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`030?ooo`@00000103oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`0000000`0000040?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo0P0000050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo100000020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`<000001P3oool00`000000
oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000L0oooo00<00000
0?ooo`3oool00`3oool100000040oooo00070?ooo`@00000103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo0P0000070?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`02000000H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`D000002`3oool00`000000oooo0?ooo`040?ooo`@000000P3oool2000000D0oooo00<00000
0?ooo`3oool02`3oool200000080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02
0?ooo`8000001@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo008000003P3oool0
0`000000oooo0?ooo`020?ooo`8000000P3oool4000000H0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo00000003000000X0oooo00<000000?ooo`3oool01P3oool2000000D0oooo0P000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool2000000H0oooo00<0
00000?ooo`3oool0103oool100000040oooo00070?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000003oool01P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0000003oool00`0000060?ooo`8000001`3o
ool00`000000oooo0?ooo`0;0?oooa@000000`3oool010000000oooo0?ooo`3oool2000000@0oooo
00<000000?ooo`3oool03@3oool3000000`0oooo00<000000?ooo`3oool00`3oool2000000D0oooo
00<000000?ooo`3oool02P3oool3000000l0oooo00<000000?ooo`3oool00P3oool2000000@0oooo
00<000000?ooo`3oool05000000>0?ooo`030000003oool0oooo00@0oooo0P0000060?ooo`<00000
00D0oooo0000003oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00@000000?ooo`00
00000000103oool00`000000oooo0?ooo`040?ooo`4000000@3oool000P0oooo00<000000?ooo`3o
ool0103oool3000000D0oooo00@000000?ooo`0000000000103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`030000003o
ool0oooo00d0oooo0P00000<0?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003o
ool0oooo00X0oooo0P00000@0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
0P0000000`3oool000000?ooo`050?ooo`8000000@3oool000030?ooo`000000000000800000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P0000070?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`00000000000080oooo00<0
00000?ooo`3oool01@3oool200000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<0
00000?ooo`3oool0303oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00<0oooo
0P0000060?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000003P3oool00`000000
oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`02000000L0oooo00<000000?ooo`3o
ool00P0000000`3oool00000000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool2000000L0oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00<0oooo0P0000000`3oool000000?ooo`070?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool0oooo0P0000030?ooo`040000003oool0oooo000000P0oooo0P00000@
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`8000001@3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo0?ooo`8000002@3o
ool00`000000oooo0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`060?ooo`8000000`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`800000203o
ool00`000000oooo0?ooo`0200000080oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool010000000oooo0000000000050?ooo`4000000@3oool000P0oooo0P00
00050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`80
00001`3oool3000000d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0103oool2000000H0oooo00<000000?ooo`3oool0103oool2000000H0oooo00<000000?ooo`3o
ool0103oool2000000H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`80
00001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool3000000P0oooo00<000000?ooo`3oool00P0000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool2000000@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`8000001@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo0`0000030?ooo`030000003oool0
oooo00@0oooo0P0000060?ooo`040000003oool0oooo0?ooo`<000002@3oool2000000T0oooo00<0
00000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo008000000P3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`003`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00050?ooo`030000003oool0oooo008000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool2000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0;0?ooo`80000000<0oooo0000003oool01@3oool2000000H0oooo00@000000?ooo`000000
00003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0200000080
oooo00<000000?ooo`3oool00`3oool010000000oooo0000000000050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool100000040oooo000?0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`3oool200000080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0200000080oooo00@000000?ooo`3oool000001`3oool2
000000P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo0P0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3ooolB
00000140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`8000001@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool2
000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00P0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo008000000P3oool00`000000oooo000000090?ooo`8000001P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000H0oooo00<0
00000?ooo`3oool00P3oool200000140oooo00<000000?ooo`3oool01@3oool2000000L0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P00
00050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`040?ooo`8000002@3oool00`000000oooo000000020?ooo`8000000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo0P0000000`3oool000000?ooo`070?ooo`030000003o
ool0oooo00P0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo0P0000070?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0:0?ooo`8000000`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000060?ooo`040000003o
ool0oooo000001<0oooo00<000000?ooo`3oool01@3oool2000000L0oooo00<000000?ooo`3oool0
4@3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo0P00000<0?ooo`03
0000003oool0oooo008000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo0P0000070?ooo`030000003oool0oooo00T0oooo0@0000010?ooo`003`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00@0oooo0P0000000`3oool000000?ooo`060?ooo`030000
003oool0oooo00D0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000d0oooo0P000000
0`3oool000000?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool2
000000H0oooo00<000000?ooo`000000503oool00`000000oooo0?ooo`050?ooo`8000001`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0000000H0oooo0P0000050?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000=0?ooo`050000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00@000000?ooo`00000000001@3oool00`000000oooo0?ooo`090?ooo`4000000@3oool000l0oooo
0P00000:0?ooo`040000003oool0oooo0?ooo`<000000`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000003@3oool20000
00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
00H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`8000001`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo0P0000050?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0303oool3000000`0oooo0P0000030?ooo`040000003oool0oooo
000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool0
0`000000oooo0?ooo`080?ooo`8000000@3oool000l0oooo00<000000?ooo`3oool02P3oool30000
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`050000003oool00000
0?ooo`000000103oool00`000000oooo0?ooo`0:0?ooo`040000003oool00000000000d0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`8000001@3oool00`000000oooo0000
000C0?ooo`030000003oool0oooo00H0oooo0P0000080?ooo`030000003oool0oooo0140oooo00@0
00000?ooo`0000000000103oool2000000H0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0;0?ooo`<00000303oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`00
00001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo0`00000<0?ooo`40
00000@3oool000l0oooo00<000000?ooo`3oool02@3oool2000000T0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000
oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`8000002`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00@0oooo0P0000030?ooo`8000000`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00H0oooo0P0000080?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool00P3oool200000080oooo0P0000060?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02@3oool200000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo0`00000:0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool01@3oool40000
00030?ooo`000000oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0000000<0oooo0P0000030?ooo`800000203oool00`000000oooo0?ooo`040?oo
o`8000002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00@000000?oo
o`00000000001P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo0P000008
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool4000000H0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`<000001@3oool00`000000oooo0?ooo`06
0?ooo`800000103oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`0000070?ooo`400000
0@3oool000l0oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000030?ooo`800000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
100000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool3000000T0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`8000002@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00L0oooo100000050?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool4000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`80
00001@3oool100000040oooo000?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3oool2000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`H0
0000303oool00`000000oooo0000000300000080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo0P0000090?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0203oool200000080oooo100000000`3oool000000?ooo`0:0?ooo`H0
00003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`4000000@3oool000l0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo0P0000060?ooo`03
0000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0000000=000000H0oooo0P0000090?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0203oool2000000T0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`070?ooo`030000003oool0000000H0oooo3@0000000`3oool000000?ooo`0A0?ooo`05
0000003oool0oooo0?ooo`000000103oool2000000@0oooo00<000000?ooo`3oool0103oool20000
00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`4000000@3oool000l0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0
oooo0P0000000`3oool000000?ooo`060?ooo`030000003oool0oooo0080oooo0P0000040?ooo`80
000000<0oooo0000003oool04@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0
oooo0P00000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool2000000X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`8000001`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo0`0000040?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool01@3oool010000000oooo0000000000070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool02`3oool100000040oooo000?0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`8000000`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0000000X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`8000002P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo0P0000070?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0403oool2000000@0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`060?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00`0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P0000060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P00000A0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01@3oool2000000/0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`090?ooo`8000002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0
oooo0P0000080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000
oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0
oooo0@0000010?ooo`003`3oool2000000d0oooo00<000000?ooo`3oool02@3oool2000000P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00000P3oool2000000l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0000000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`80
00002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo0P0000080?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool00000
0080oooo0P0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool30000
00X0oooo00<000000?ooo`3oool02`3oool200000040oooo000?0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool01P3oool4000000X0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000002`3oool2000000H0
oooo00<000000?ooo`3oool02P3oool2000000`0oooo00<000000?ooo`3oool0103oool2000000/0
oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`090?ooo`@000001`3oool00`000000oooo0?ooo`0<0?ooo`4000000@3oool000l0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`<00000103oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`000000303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
0P00000<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool2000000T0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`8000001P3oool2000000@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
0`0000040?ooo`030000003oool0oooo00`0oooo0@0000010?ooo`003`3oool00`000000oooo0?oo
o`0=0?ooo`D000001`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`8000002P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000003@3oool01@000000oooo
0?ooo`3oool0000000d0oooo0P00000=0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`00
0000oooo000000090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo1@00000>0?ooo`4000000@3oool0
00l0oooo00<000000?ooo`3oool0203oool6000000/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`070?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000003@3oool30000
00h0oooo00<000000?ooo`0000003@3oool3000000h0oooo0P0000090?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo0P00000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool60000
00X0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`030?ooo`D000001@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool3000000D0
oooo0P0000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0303oool00`000000
oooo0000000=0?ooo`8000003P3oool00`000000oooo000000090?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool01@3oool2000000L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`D000001@3oool100000040oooo000?0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`3oool0oooo000000050?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0000000=0?ooo`04
0000003oool00000000000`0oooo00<000000?ooo`0000002`3oool2000000030?ooo`000000oooo
00d0oooo0P00000:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P000006
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=
0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`030000003oool0
oooo00@0oooo0P0000070?ooo`8000000`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`0000003@3oool010000000oooo0?ooo`3oool2000000X0oooo00<0
00000?ooo`0000002@3oool2000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000
000:0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0oooo0P0000070?ooo`800000
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`003`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool010000000oooo0000000000070?ooo`030000003oool0oooo00@0oooo0P0000080?ooo`<00000
4`3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0
103oool2000000P0oooo00<000000?ooo`0000001`3oool2000000L0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0000000:0?ooo`030000003oool0oooo0140oooo0`0000080?ooo`030000
003oool0000000D0oooo00<000000?ooo`3oool01@3oool2000000030?ooo`000000oooo00/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool000l0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo0P00
00090?ooo`030000003oool0oooo00D0oooo0P0000080?ooo`<000004P3oool00`000000oooo0?oo
o`090?ooo`8000002`3oool00`000000oooo0?ooo`070?ooo`D000000`3oool00`000000oooo0000
00020?ooo`D000002P3oool00`000000oooo0?ooo`080?ooo`8000002`3oool00`000000oooo0?oo
o`0@0?ooo`8000002@3oool00`000000oooo000000050?ooo`030000003oool0oooo00P0oooo0P00
000;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool100000040oooo000?
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`07
0?ooo`80000000<0oooo0000003oool02@3oool00`000000oooo0?ooo`050?ooo`8000001`3oool0
0`000000oooo0?ooo`0200000100oooo00<000000?ooo`3oool02@3oool00`000000oooo00000009
0?ooo`030000003oool0oooo00d0oooo2000000?0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`0000002`3oool00`000000oooo0?ooo`0>0?ooo`8000000P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0203oool010000000oooo00000000
00090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool100000040oooo000?
0?ooo`8000003`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo0P000003
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool2000000D0oooo00<00000
0?ooo`3oool00`3oool2000000h0oooo00<000000?ooo`3oool02P3oool2000000P0oooo00<00000
0?ooo`3oool0403oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo00H0oooo0P00
000<0?ooo`030000003oool0oooo00`0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`800000
1`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo0P0000010?ooo`003`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool0oooo
100000060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo
000000030?ooo`030000003oool0oooo00H0oooo0P00000<0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000001<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0000000=0?ooo`030000003oool0oooo00T0
oooo0P0000080?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0103oool4000000<0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0>0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`060?ooo`P000002P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00D0oooo00D000000?ooo`000000oooo0000000;0?ooo`8000002P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`00
000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000003@3oool00`000000oooo0?oo
o`070?ooo`8000002P3oool01P000000oooo0?ooo`000000oooo000000H0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`080?ooo`P00000203oool00`000000oooo0?ooo`0>0?ooo`40
00000@3oool000l0oooo00<000000?ooo`3oool00`3ooolD000000D0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`000000
00003@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`00
00000P3oool2000001D0oooo00@000000?ooo`3oool000005@3oool200000080oooo00<000000?oo
o`0000003P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo0P0000000`3o
ool000000?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`030?oooa@000001@3oool100000040oooo000?0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01@3oool3000000h0oooo0`0000060?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`0000000P00000G0?ooo`040000003oool0oooo000001L0oooo0`0000000`3o
ool000000?ooo`0=0?ooo`030000003oool0oooo00<0oooo0`00000>0?ooo`<000001`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0>0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`030?ooo`80000000<0oooo000000000000403oool3000000<0oooo00<000000?ooo`3o
ool02@3oool4000000030?ooo`000000oooo01L0oooo00@000000?ooo`3oool00000603oool00`00
0000oooo00000003000000`0oooo00<000000?ooo`3oool00`00000@0?ooo`80000000<0oooo0000
000000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`4000000@3oool000l0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02`3oool01@000000oooo0?ooo`3oool0000000@0oooo0P00000B0?ooo`D000001P3oool40000
00<0oooo00<000000?ooo`000000603oool010000000oooo0?ooo`00000H0?ooo`030000003oool0
000000<0oooo100000060?ooo`D000004P3oool2000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0>0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo000000060?ooo`<000004P3oool00`000000oooo0?ooo`06000000L0oooo00@000000?oo
o`3oool000005`3oool010000000oooo0?ooo`00000G0?ooo`040000003oool0oooo000000L0oooo
1P0000020?ooo`030000003oool0oooo0100oooo0`0000060?ooo`80000000<0oooo0000003oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
3P3oool100000040oooo000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo0P0000080?ooo`030000003o
ool000000140oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000G0?ooo`050000003o
ool0oooo0?ooo`0000005P3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`0000002@3oool2000000d0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`003`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0000000T0oooo00<000000?ooo`000000403oool00`000000oooo
0?ooo`0>0?ooo`040000003oool0oooo000001H0oooo00D000000?ooo`3oool0oooo0000000E0?oo
o`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
000000X0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03@3oool100000040oooo000?0?ooo`8000003`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool20000
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0000000>0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`0000005P3oool01@000000oooo0?ooo`3oool0000001D0oooo00@00000
0?ooo`3oool000004@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000/0oooo00<0
00000?ooo`3oool00P0000090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0<0?ooo`8000000@3oool000l0oooo00<000000?ooo`3oool00`3oool9
00000080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00H0oooo0P0000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000003@3oool0
0`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000001D0oooo00D000000?ooo`3oool0oooo
0000000D0?ooo`050000003oool0oooo0?ooo`0000004@3oool2000000d0oooo0P00000;0?ooo`03
0000003oool0oooo00<0oooo0P0000070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`08000000D0oooo0@0000010?ooo`003`3oool00`000000oooo
0?ooo`0;0?ooo`80000000<0oooo0000003oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00@0oooo0P0000070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000
2`3oool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo0?ooo`000000503oool01@000000
oooo0?ooo`3oool0000001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00X0oooo0P00000;0?ooo`030000003oool0oooo00H0oooo0P0000050?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool3000000d0oooo0@0000010?oo
o`003`3oool00`000000oooo0?ooo`0=0?ooo`@00000303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0000000@000002P3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000X0
oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool0000001@0oooo00D000000?oo
o`3oool0oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000503oool00`000000oooo0?oo
o`080?ooo`800000303oool00`000000oooo0?ooo`080?ooo`@0000000<0oooo0000003oool03@3o
ool00`000000oooo0?ooo`0:0?ooo`@000003`3oool100000040oooo000?0?ooo`030000003oool0
oooo00d0oooo00@000000?ooo`3oool0oooo3@0000080?ooo`P000003`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?oo
o`3oool0000001<0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`060?ooo`<00000303oool00`000000
oooo0?ooo`0=0?ooo`P00000203oool=000000<0oooo00<000000?ooo`3oool03@3oool100000040
oooo000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo
00000007000000L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0000000H0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool000000180
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?oo
o`0000005P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`050?ooo`T000003`3oool00`000000oooo0?ooo`0=0?oo
o`4000000@3oool000l0oooo00<000000?ooo`3oool00`3oool2000000P0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool02P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo0P000005
0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool01@3oool2000000D0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool02P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3o
ool2000000L0oooo0@0000010?ooo`001`3oool5000000<0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<000000`3oool00`000000oooo0?ooo`030?ooo`40
00000@3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`<00000
103oool4000000h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P00000I0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`050000003oool000000?ooo`00
00003P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0303oool4000000@0oooo0`0000050?ooo`4000000@3oool000T0oooo00<000000?ooo`3oool0
0`3oool3000000H0oooo0P0000040?ooo`030000003oool0000000<000002P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool010000000oooo
00000000000I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0G0?ooo`80000000<0oooo0000003oool03@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool3000000030?ooo`000000oooo00<0
oooo0P0000070?ooo`8000000@3oool000030?ooo`000000000000800000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`050?ooo`<00000
1P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3@3oool010000000oooo0?ooo`00000I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo000000l0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo0`0000050?oo
o`040000003oool00000000000X0oooo0@0000010?ooo`002@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo0P0000050?ooo`<00000203oool400000080oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`0000000P3oool2000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01H0oooo00@000000?ooo`3oool0oooo0P00000>0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`3oool4000000L0oooo0`00
00050?ooo`8000001@3oool100000040oooo00080?ooo`8000001@3oool00`000000oooo0?ooo`05
0?ooo`8000000`3oool00`000000oooo0?ooo`02000000X0oooo0`00000A0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool02@3oool2000000<0oooo00D000000?ooo`3oool0oooo0000
000F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0D0?ooo`8000000`3oool00`000000oooo0?ooo`02000000/0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0?0?ooo`@000002@3oool200000080oooo00@000000?ooo`3oool0oooo
0P0000070?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool01`3oool4000000@0oooo0`00
00090?ooo`D000003@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo0P00
00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo0P0000090?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool02`3oool5000000X0oooo0P0000040?ooo`@000002@3oool100000040oooo000?
0?ooo`030000003oool0oooo00T0oooo0`0000060?ooo`8000001P3oool00`000000oooo0?ooo`03
0?ooo`@000002@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo0P000008
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo0P0000070?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool01`3oool4000000@0oooo00<000000?ooo`3oool01@3oool3000000D0oooo0`00000;
0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`000007
0?ooo`800000103oool00`000000oooo0?ooo`070?ooo`8000001`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3o
ool0000001D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`8000002@3o
ool00`000000oooo0?ooo`020?ooo`<000001P3oool010000000oooo0?ooo`00000;0?ooo`400000
0@3oool000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`8000001`3o
ool3000000030?ooo`000000oooo00X0oooo2000000D0?ooo`030000003oool0000000<000003@3o
ool01@000000oooo0?ooo`3oool0000001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0:0?ooo`@0000000<0oooo0000003oool04`3oool8000000/0oooo00<000000?ooo`000000
0`0000060?ooo`800000103oool00`000000oooo0?ooo`080?ooo`4000000@3oool000l0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000L0oooo0`0000060?ooo`@00000
4@3oool8000000P0oooo1`00000B0?ooo`040000003oool0oooo0?ooo`8000004P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool2000000<0
oooo0P00000A0?ooo`L00000203oool800000140oooo100000070?ooo`8000001`3oool01@000000
oooo0?ooo`3oool0000000D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`040?ooo`80
000000<0oooo0000003oool02@3oool2000000D0oooo00<000000?ooo`0000000P00000?0?ooo`03
0000003oool0oooo00D0oooo200000050?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool00P3oool200000100oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool2000000P0oooo00<000000?ooo`3o
ool03P3oool2000000@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`P0
0000203oool00`000000oooo0?ooo`0<0?ooo`<0000000<0oooo0000003oool01@3oool2000000T0
oooo00@000000?ooo`00000000001P3oool100000040oooo000?0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02`3oool2000000<0oooo00@000000?ooo`3oool0oooo1000000<0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?oo
o`8000003P3oool00`000000oooo0?ooo`080?ooo`8000000`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00T0oooo100000040?ooo`040000003oool0oooo0?ooo`800000303oool0
0`000000oooo0?ooo`060?ooo`4000000@3oool000l0oooo0P0000060?ooo`040000003oool00000
000000d0oooo0`0000060?ooo`D00000203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00T0oooo00@000000?ooo`3oool00000303oool01@000000oooo0?ooo`3oool0000000X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`D000001P3oool010000000oooo
00000000000<0?ooo`80000000<0oooo0000003oool01@3oool200000040oooo000?0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool2000000d0oooo0P0000070?ooo`D00000
1P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
1@3oool2000000`0oooo00<000000?ooo`3oool02P3oool2000000d0oooo00@000000?ooo`000000
00002`3oool00`000000oooo0?ooo`0;0?ooo`8000001P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool5000000P0oooo0P00000<0?ooo`80
0000103oool00`000000oooo0?ooo`040?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool0
00002@3oool4000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0E0?ooo`04
0000003oool0oooo0?ooo`@000002@3oool2000000030?ooo`000000oooo00X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`4000000@3oool000l0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3o
ool0oooo0000000;0?ooo`H000005P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`D000001`3oool30000
00030?ooo`000000oooo00/0oooo00<000000?ooo`3oool0203oool2000000P0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0E0?ooo`H000002P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?oo
o`4000000@3oool000l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo0P00000;0?ooo`D000005@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00H0oooo0P0000080?ooo`030000003oool0oooo00T0oooo0P0000050?ooo`L0
00001@3oool2000000X0oooo00<000000?ooo`3oool01P3oool2000000T0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0C0?ooo`H000002P3oool2000000H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo0P00000;0?ooo`800000
00<0oooo0000000000004`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo
0P0000060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool04@3oool2000000040?ooo`0000000000000000X0oooo0P0000090?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool100000040oooo000?0?ooo`030000
003oool0oooo00l0oooo0P0000040?ooo`030000003oool0oooo00P0oooo0P0000080?ooo`030000
003oool0oooo00H00000403oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00T0oooo
0P0000040?ooo`030000003oool0oooo00H0oooo0P00000G0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool2000000`0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0>0?ooo`H000000P3oool00`000000oooo0?ooo`060?ooo`8000002`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00l0oooo0@0000010?ooo`003`3oool00`000000oooo0?oo
o`0A0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`80000000<0oooo0000000000003@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00X0oooo0P0000000`3oool000000?ooo`060?ooo`8000006P3oool2000000L0oooo
00@000000?ooo`00000000003@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00`0
oooo0P0000000`3oool00000000000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0303oool010000000oooo0?ooo`00000B0?ooo`4000000@3oool000l0oooo00<000000?ooo`3o
ool04P3oool2000000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`80
000000@0oooo00000000000000002P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00/0oooo2@00000N0?ooo`T000003P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00T0oooo0P0000000`3oool00000000000080?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03P3oool2000001<0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00`0oooo0P00000@0?ooo`8000000`3oool00`000000oooo0?ooo`080?ooo`80
00000P3oool2000000P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00H0oooo0`0000000`3oool000000000000;0?ooo`030000003oool0oooo0080
00004@3oool2000000d0oooo00<000000?ooo`3oool00`3oool100000040oooo000?0?ooo`800000
1@3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`00
00003@3oool200000080oooo0P0000060?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`040?ooo`8000000P3oool2000000d0oooo00<000000?ooo`00
00004@3oool2000000030?ooo`000000oooo00/0oooo00<000000?ooo`3oool00`3oool200000040
oooo000?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00l0oooo0P00000?0?ooo`<0000000@0oooo000000000000
00000`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`3o
ool0oooo0`000000103oool0000000000000000@0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo0@000001
0?ooo`003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0>0?ooo`<000004@3oool200000080oooo1000000M0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01/0oooo100000020?ooo`8000004@3oool2000000030?ooo`000000oooo
00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo0P0000080?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`8000000P3oool5000001/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool500000080oooo0P00000B0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?oo
o`8000001P3oool00`000000oooo0?ooo`060?ooo`4000000@3oool000l0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo0`0000040?ooo`@0
00005`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0E0?ooo`@00000103oool3000001<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0
203oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01@3oool200000180oooo0`0000070?ooo`8000005P3oool00`000000oooo0?ooo`040?ooo`80
0000=@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo0P0000070?ooo`<0
00004P3oool2000000L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`05
0000003oool0oooo0?ooo`0000002@3oool100000040oooo000?0?ooo`030000003oool0oooo00T0
oooo0P00000>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo008000001`3oool2000001@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool04P3oool2000000L0oooo0P0000020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo0`00000:0?ooo`40
00000@3oool000l0oooo00<000000?ooo`3oool01`3oool300000100oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0`3oool2000000L0oooo1@00000@0?ooo`050000003oool0oooo0?ooo`000000>P3oool01@000000
oooo0?ooo`3oool000000100oooo1@0000070?ooo`8000001@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?oo
o`<000002@3oool100000040oooo000?0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo0000000@0?ooo`8000000`3oool2000000h0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`060?ooo`<000002@3oool4000000`0oooo1000000l0?ooo`@00000303oool40000
00X0oooo0P0000080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool20000
00@0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000P0oooo0@000001
0?ooo`003`3oool00`000000oooo0?ooo`040?ooo`800000103oool00`000000oooo0?ooo`0?0?oo
o`040000003oool0000000000140oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`8000002`3oool=00000480oooo3@00000<0?ooo`8000002`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00l0oooo0P0000000`3oool000000?ooo`0?0?ooo`030000003oool0
oooo00<0oooo0P0000060?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo01@0oooo0P00000>0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool04P3oool200000100oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`4000000@3oool000l0oooo0P00000<0?ooo`030000003oool0oooo00d0
oooo0`00000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool2000001@0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0B0?ooo`8000004@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0180oooo0`00000>0?ooo`030000003oool0oooo00/0
oooo0P0000010?ooo`003`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo
00D000000?ooo`3oool0oooo0000000E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool04P3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool0303oool10000
0040oooo000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool2000000@0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0
oooo0P00000A0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03`3oool2000001H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080
oooo0P00000:0?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`003`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00H0oooo0P0000070?ooo`030000003oool0oooo01<0oooo
00D000000?ooo`3oool0oooo0000000H0?ooo`8000003`3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00d0oooo0P00000I0?ooo`040000003oool0oooo000001D0oooo00<000000?oo
o`3oool01@3oool2000000P0oooo00<000000?ooo`3oool03@3oool100000040oooo000?0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool2000000T0oooo00<000000?ooo`3o
ool0503oool3000001/0oooo0P00000=0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool02`3oool2000001`0oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`070?ooo`80
00001@3oool00`000000oooo0?ooo`0>0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0
3P3oool010000000oooo0?ooo`3oool2000000`0oooo00<000000?ooo`3oool04`3oool2000001h0
oooo0P00000;0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool02@3oool2000001l0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`<000000P3oool00`000000
oooo0?ooo`0>0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool03P3oool010000000oooo
00000000000>0?ooo`030000003oool0oooo0140oooo0P0000020?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool07P3oool010000000oooo00000000000B0?ooo`030000003oool0oooo
00h0oooo0`00000@0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool03@3oool300000140
oooo00<000000?ooo`3oool03P3oool2000000@0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0O0?ooo`040000003oool0oooo0?ooo`800000403oool00`000000oooo0?ooo`0?0?oo
o`<000003`3oool100000040oooo000?0?ooo`030000003oool0oooo00X0oooo0`0000020?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool2000000L0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo0P00000=0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool00`00000<0?ooo`4000000@3oool000l0oooo
00<000000?ooo`3oool01P3oool4000000D0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`090?ooo`8000002@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool01P3oool2000000/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`030?ooo`@00000203oool100000040oooo000?0?ooo`800000103oool3000000T0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`<000002`3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A`3oool01@000000oooo0?oo
o`3oool000000240oooo00<000000?ooo`3oool02@3oool3000000P0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`070?ooo`<00000103oool200000040oooo000?0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`<000003`3o
ool00`000000oooo0?ooo`0O0?ooo`050000003oool0oooo0?ooo`000000B@3oool010000000oooo
0?ooo`00000R0?ooo`030000003oool0oooo00`0oooo0`0000040?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0403oool100000040oooo000?0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool500000180oooo00<000000?ooo`3oool0803oool00`000000oooo
0000001;0?ooo`030000003oool000000240oooo00<000000?ooo`3oool0403oool500000180oooo
00<000000?ooo`3oool0403oool100000040oooo000?0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0303oool5000001H0oooo00<000000?ooo`3oool07`3oool3000004d0oooo0P00
000Q0?ooo`030000003oool0oooo01@0oooo1@00000>0?ooo`030000003oool0oooo0100oooo0@00
00010?ooo`003`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo20000004
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0703oool3000000<0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`03000001h0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`020?ooo`P000001P3oool00`000000oooo0?ooo`0@0?ooo`4000000@3oool0
00l0oooo00<000000?ooo`3oool0403oool7000000`0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0I0?ooo`<000001P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
00<0oooo0`00000K0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02P3oool80000
0140oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`080?ooo`T000004P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01D0oooo100000090?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool01P3oool4000001L0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0000000H000002P3oool100000040oooo000?0?ooo`030000
003oool0oooo00<0oooo1@0000090?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0>0?ooo`H000003@3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo00/0oooo1P00000@0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`070?ooo`D000001@3oool100000040oooo00080?ooo`8000001@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`070?ooo`L00000503oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo0140oooo1`0000090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0A0?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3o
oolG000001/0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0H0?oooaL000002@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo0@0000010?ooo`001`3oool0
10000000oooo0?ooo`0000040?ooo`<000000`3oool[000000d0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02`3o
ool[000000@0oooo0P0000010?ooo`001`3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool00`3ooolV000002<0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`0Q0?ooobH00000103oool00`000000oooo0?ooo`0A0?ooo`4000000@3o
ool000L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0503oool00`000000oooo0000000>000001@0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`0A0?oooa4000005P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0140oooo0@0000010?ooo`00203oool2000000D0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool03P3oool5000000h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0<
0?ooo`D00000403oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool100000040oooo000?0?ooo`030000003oool0oooo00<0oooo300000000`3o
ool000000?ooo`0A0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool40000
00X0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`070?ooo`@000005@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0300000050?oo
o`4000000@3oool000l0oooo00<000000?ooo`3oool03`3oool8000000`0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0H0?ooo`<000001`3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo00@0oooo0`00000J0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool02`3oool700000140oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00@0oooo1@0000070?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
6`3oool2000000D0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`020?ooo`800000
7@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo1P0000050?ooo`030000
003oool0oooo0100oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00T0oooo100000030?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07@3o
ool200000080oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`02000001l0oooo00<0
00000?ooo`3oool0503oool010000000oooo0?ooo`3oool4000000/0oooo00<000000?ooo`3oool0
403oool100000040oooo000?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03@3o
ool4000001H0oooo00<000000?ooo`3oool07`3oool4000004/0oooo0`00000Q0?ooo`030000003o
ool0oooo01@0oooo1000000?0?ooo`030000003oool0oooo0100oooo0@0000010?ooo`003`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo1@00000B0?ooo`030000003oool0
oooo0200oooo00@000000?ooo`3oool00000B@3oool010000000oooo0?ooo`00000Q0?ooo`030000
003oool0oooo0100oooo1@00000B0?ooo`030000003oool0oooo0100oooo0@0000010?ooo`003`3o
ool00`000000oooo0?ooo`030?ooo`8000002P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00<0oooo0`00000>0?ooo`030000003oool0oooo0200oooo00D000000?ooo`3oool0oooo
000000190?ooo`050000003oool0oooo0?ooo`0000008@3oool00`000000oooo0?ooo`0<0?ooo`<0
0000103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo0P0000050?ooo`40
00000@3oool000l0oooo0P0000060?ooo`@000001P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00H0oooo0P00000<0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0:0?ooo`800000203oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00@0oooo100000060?ooo`8000000@3oool000l0oooo00<000000?ooo`3oool02@3o
ool400000080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`<000002@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3o
ool3000000X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`04000000/0oooo0@00
00010?ooo`003`3oool00`000000oooo0?ooo`0=0?ooo`<000004@3oool00`000000oooo0?ooo`0<
0?ooo`<000001@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool00P3oool3000000h0oooo00<000000?ooo`3oool03`3oool3000000l0oooo0@000001
0?ooo`003`3oool00`000000oooo0?ooo`0>0?ooo`@000003`3oool00`000000oooo0?ooo`0?0?oo
o`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool00P00000A0?ooo`030000003oool0oooo00h0oooo0`00000@0?ooo`4000000@3oool000l0
oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`3oool2000000`0oooo00<000000?oo
o`3oool04P3oool3000001h0oooo0P00000;0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool02@3oool2000001l0oooo0P00000D0?ooo`030000003oool0oooo00X0oooo0`0000020?oo
o`030000003oool0oooo00h0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00<0oooo0P0000090?ooo`030000003oool0oooo01@0oooo0`00000K0?ooo`80
00003@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00/0oooo0P00000L0?ooo`03
0000003oool0000001D0oooo00<000000?ooo`3oool01`3oool2000000D0oooo00<000000?ooo`3o
ool03P3oool100000040oooo000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1P3oool2000000L0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0000001T0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0603oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo
00D0oooo0P0000080?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`003`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo0P0000040?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080
oooo0P00000:0?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`003`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool200000140oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`0?0?ooo`8000005@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo
00`0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0
oooo0`00000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool04@3oool200000180
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`<000003P3oool00`000000
oooo0?ooo`0<0?ooo`4000000@3oool000l0oooo0P0000040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03P3oool2000001@0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0C0?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo
0P00000@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool200000040oooo
000?0?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`030000003oool0oooo00h0oooo00@0
00000?ooo`00000000004@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo
0P00000?0?ooo`P00000@P3oool00`000000oooo00000006000000l0oooo0P00000<0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool2000000030?ooo`000000oooo00l0oooo
00<000000?ooo`3oool00`3oool2000000H0oooo0@0000010?ooo`003`3oool00`000000oooo0?oo
o`060?ooo`050000003oool0oooo0?ooo`0000004@3oool01@000000oooo0?ooo`3oool0000000l0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`8000002P3oool7000000L0
oooo1000000l0?ooo`D000001`3oool6000000/0oooo0P0000090?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0
oooo00D000000?ooo`3oool0oooo000000080?ooo`4000000@3oool000l0oooo00<000000?ooo`3o
ool01`3oool300000140oooo00<000000?ooo`3oool00`3oool2000000`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`050?ooo`800000203oool4000000h0oooo00D000000?ooo`3o
ool0oooo0000000j0?ooo`050000003oool0oooo0?ooo`0000003P3oool4000000P0oooo0P000007
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool2000000D0oooo00<00000
0?ooo`3oool03`3oool3000000T0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`090?oo
o`8000003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`030?ooo`8000001`3oool300000140oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03`3oool3000000L0oooo0P0000050?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo0P00000;0?oo
o`4000000@3oool000l0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000=0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool200000180oooo00<000000?oo
o`0000000P0000050?ooo`@00000503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`@000001@3oool30000
00030?ooo`000000oooo0140oooo0P0000080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02`3oool010000000oooo0?ooo`00000:0?ooo`4000000@3oool000l0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo0P0000050?oo
o`<000005`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`<000001@3oool2000001@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`4000000@3oool000l0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo0P0000000`3oool0
00000?ooo`020?ooo`8000006P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`8000000`3oool010000000
oooo00000000000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool10000
0040oooo000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000004P3oool20000
00<0oooo1000000L0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000030?ooo`8000004P3oool01000
0000oooo0?ooo`00000>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool20000
0140oooo0P0000030?ooo`@000007@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0K0?ooo`@000000`3oool20000
0140oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool100000040oooo000?0?ooo`8000001P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool2000000l0
oooo0P0000030?ooo`8000000`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0:P3oool2000000`0oooo00<000000?ooo`3oool06`3oool010000000
oooo0?ooo`3oool300000080oooo0`00000?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo0P0000010?oo
o`003`3oool00`000000oooo0?ooo`030?ooo`800000303oool2000000030?ooo`000000oooo00l0
oooo0P0000000`3oool000000?ooo`0<0?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`80
0000303oool010000000oooo00000000000@0?ooo`80000000<0oooo0000003oool0303oool00`00
0000oooo0?ooo`030?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0=0?ooo`800000103oool00`000000oooo0?ooo`070?ooo`<000000P3oool3000000L0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0
oooo0`0000020?ooo`8000002@3oool00`000000oooo0?ooo`020?ooo`800000403oool00`000000
oooo0?ooo`0B0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool04@3oool2000000030?oo
o`000000oooo00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`<00000
0`3oool2000000X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0<0?ooo`T00000
7P3oool9000000l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`090?ooo`800000
0P3oool3000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0000001<0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0203oool2000000P0oooo00@000000?ooo`3oool0oooo
0P0000030?ooo`<000003@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo
0P0000020?ooo`030000003oool0oooo00@0oooo0P00000J0?ooo`8000001P3oool00`000000oooo
0?ooo`02000000h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`800000
0`3oool2000000<0oooo00<000000?ooo`3oool01P3oool2000000/0oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo0P00000;0?ooo`<000000P3oool300000100oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`<00000103oool00`000000oooo
0?ooo`060?ooo`8000005P3oool2000000P0oooo00<000000?ooo`3oool00P3oool3000000/0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0>0?ooo`<000000P3oool4000000X0oooo
0P0000090?ooo`030000003oool0oooo0080oooo0P00000@0?ooo`4000000@3oool000l0oooo00<0
00000?ooo`3oool03@3oool2000000L0oooo00<000000?ooo`3oool00`3oool2000000/0oooo1`00
000C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01`3oool2000000L0oooo00<0
00000?ooo`3oool0203oool2000000L0oooo1@0000060?ooo`8000002P3oool00`000000oooo0?oo
o`050?ooo`<000002@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo1`00
000;0?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo0@00
00010?ooo`003`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`D000005P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00H0oooo0P0000090?ooo`030000003oool0oooo00X0oooo0P0000000`3oool000000000
0002000000D0oooo100000000`3oool000000?ooo`0;0?ooo`030000003oool0oooo00P0oooo0P00
00080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool5000000/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo0@00
00010?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool010000000oooo0?ooo`00000;0?ooo`<000000`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00/0oooo0P00000=0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`04000000X0oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`003`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P00000=0?ooo`8000002P3o
ool3000000D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00@0oooo0P00000<0?ooo`030000003oool0oooo00X0oooo0P00000>0?ooo`800000303o
ool00`000000oooo0?ooo`0;0?ooo`8000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool00`3oool4000000T0oooo0`00000<0?ooo`800000103o
ool00`000000oooo0?ooo`040?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool0000000d0oooo0`0000080?ooo`@000001`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000003@3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool4000000P0oooo
0`00000=0?ooo`050000003oool0oooo0?ooo`0000001P3oool100000040oooo000?0?ooo`800000
1P3oool3000000`0oooo0P0000030?ooo`030000003oool0oooo00<0oooo100000090?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000`0
oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01`3oool4000000H0oooo00<000000?ooo`3oool00P00000<0?ooo`<000001P3oool20000
0040oooo000?0?ooo`030000003oool0oooo00@0oooo0`00000<0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@00000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`020?ooo`8000003`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`80
00002@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo1@0000020?ooo`03
0000003oool0oooo00<0oooo0P00000;0?ooo`<000001P3oool100000040oooo000?0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000090?ooo`8000001`3oool5000000h0
oooo5P00000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool2000000<0
oooo00<000000?ooo`3oool04P3ooolF000000h0oooo1P0000070?ooo`800000203oool01@000000
oooo0?ooo`3oool0000000D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo0P0000070?ooo`@000003@3oool5000001@0oooo1000000@0?ooo`04
0000003oool0oooo0?ooo`8000004P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`3oool2000000l0oooo1000000D
0?ooo`D000003@3oool5000000L0oooo0P0000060?ooo`030000003oool0oooo00L0oooo0@000001
0?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo0P0000060?oo
o`@0000000<0oooo0000003oool02@3oool4000000@0oooo00<000000?ooo`3oool04P3oool01000
0000oooo0?ooo`3oool3000000`0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02@3oool3000000<0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`020?ooo`@000002P3oool00`000000oooo00000004000000H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`4000000@3oool000l0oooo00<00000
0?ooo`3oool02@3oool010000000oooo0000000000050?ooo`D000000`3oool00`000000oooo0?oo
o`040?ooo`@00000203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo0P00
00090?ooo`050000003oool0oooo0?ooo`0000005@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo0P0000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
1P3oool4000000H0oooo00<000000?ooo`3oool00P3oool5000000@0oooo0P0000000`3oool00000
0?ooo`0:0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool02@3oool2000000D0oooo1@00
00060?ooo`030000003oool0000000<00000303oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000001H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`@0000000<0oooo0000003oool0
1P3oool5000000@0oooo0P00000;0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool01`3o
ool2000000040?ooo`000000oooo0?ooo`D000001`3oool400000100oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo0000000F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0D0?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`@00000203oool400000080
oooo00@000000?ooo`00000000002@3oool100000040oooo00070?ooo`D000000`3oool00`000000
oooo0?ooo`050?ooo`8000000`3oool6000000D0oooo100000020?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`8000000P3oool01@000000
oooo0?ooo`3oool0000001L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000P3oool2000000/0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@000001P3oool5
000000<0oooo0P0000070?ooo`4000000@3oool000T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`8000000`3oool5000000D0oooo0`0000060?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`8000000P3oool20000
01P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool00P00000>0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`040?ooo`@00000103oool5000000<0oooo0P0000050?oo
o`4000000@3oool000T0oooo00<000000?ooo`3oool00`3oool3000000H0oooo10000000103oool0
00000?ooo`3oool4000000X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00`0oooo1000000I0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`@000003P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool3000000040?ooo`000000oooo
0?ooo`@000001`3oool200000040oooo00090?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool3000000D0oooo0P00000>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo008000006@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool01@00
0000oooo0000003oool0000000h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00`0oooo0P0000050?ooo`<000001P3oool100000040oooo00090?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool2000000D0oooo0`00000?0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00d0oooo0`0000050?ooo`8000001@3oool100000040oooo0008
0?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`8000000P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`02000000X0oooo
0@0000010?ooo`003`3oool00`000000oooo0?ooo`050?ooo`<000001@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0:0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool3000000L0
oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`030?ooo`800000203oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0503oool01@000000oooo
0?ooo`3oool000000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`05
0000003oool0oooo0?ooo`0000005P3oool00`000000oooo0?ooo`040?ooo`030000003oool00000
00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01P3oool2000000D0oooo0@0000010?ooo`003`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo500000020?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool02P3oool00`000000oooo000000080?ooo`030000003oool0oooo01<0
oooo00D000000?ooo`3oool0oooo0000000C0?ooo`050000003oool0oooo0?ooo`0000004P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01P3oool3
000000`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000C000000T0oooo00<00000
0?ooo`3oool03@3oool100000040oooo000?0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01`0000060?ooo`030000003oool0oooo00/0oooo1000000>0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo
0?ooo`000000503oool01@000000oooo0?ooo`3oool0000001<0oooo00D000000?ooo`3oool0oooo
0000000D0?ooo`030000003oool0oooo00P0oooo0P00000<0?ooo`030000003oool0oooo00/0oooo
1000000=0?ooo`030000003oool0oooo00@0oooo200000000`3oool000000?ooo`0>0?ooo`400000
0@3oool000l0oooo00<000000?ooo`3oool02`3oool5000000d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`04000000T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000
000;0?ooo`030000003oool0oooo0140oooo00D000000?ooo`3oool0oooo0000000D0?ooo`050000
003oool0oooo0?ooo`0000004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool02P3oool2000000/0oooo00<000000?ooo`3oool01`3oool400000080
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`@000003@3oool100000040
oooo000?0?ooo`030000003oool0oooo00P0oooo100000020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`<000001P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool0403oool010000000oooo
0?ooo`00000E0?ooo`050000003oool0oooo0?ooo`000000503oool01@000000oooo0?ooo`3oool0
00000180oooo00<000000?ooo`3oool02`3oool2000000/0oooo00<000000?ooo`3oool0103oool2
000000H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00@000002@3oool100000040oooo000?0?ooo`800000103oool5000000H0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo0P0000030?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0000001H0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`050000003oool0
oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000/0oooo00@0
00000?ooo`3oool0oooo0P0000080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`040?ooo`@00000103oool200000040oooo000?0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00X0oooo0P0000000`3oool000000?ooo`080?ooo`030000003oool0000000l0oooo00<0
00000?ooo`3oool03`3oool010000000oooo0?ooo`00000F0?ooo`050000003oool0oooo0?ooo`00
00005@3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`0000002P3oool010000000oooo00000000000:0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool000l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool000000140oooo00<000000?oo
o`3oool03P3oool00`000000oooo0000000G0?ooo`050000003oool0oooo0?ooo`0000005@3oool0
1@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool03P3oool00`000000oooo0000
000:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<
0?ooo`8000001`3oool00`000000oooo0000000B0?ooo`030000003oool0oooo00d0oooo00@00000
0?ooo`3oool000005`3oool010000000oooo0?ooo`00000G0?ooo`040000003oool0oooo00000100
oooo00<000000?ooo`3oool03`3oool00`000000oooo000000070?ooo`<000003@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool100000040
oooo000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P0000040?ooo`030000
003oool0000001<0oooo00@000000?ooo`3oool0oooo1`0000050?ooo`030000003oool0000001P0
oooo00@000000?ooo`3oool000005`3oool010000000oooo0?ooo`0000060?ooo`L000000P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0000000D0oooo00D000000?ooo`3oool0oooo0000
000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0>0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`03
0?ooo`060000003oool0oooo0000003oool000004P3oool6000000L0oooo1P0000000`3oool00000
0?ooo`0G0?ooo`040000003oool0oooo000001P0oooo00<000000?ooo`0000001P0000070?ooo`D0
00004P3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool03P3oool100000040oooo000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
103oool2000000030?ooo`000000oooo00l0oooo0`0000030?ooo`030000003oool0oooo00/0oooo
0`00000I0?ooo`040000003oool0oooo000001P0oooo1000000>0?ooo`030000003oool0oooo00<0
0000403oool00`000000oooo00000002000000H0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool100000040
oooo000?0?ooo`030000003oool0oooo00<0oooo500000050?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`<000003@3oool4000000H0oooo
00<000000?ooo`3oool02`3oool00`000000oooo00000002000001L0oooo00@000000?ooo`3oool0
00005`3oool3000000030?ooo`000000oooo00d0oooo00<000000?ooo`3oool00`3oool4000000d0
oooo0`0000070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`040?oooa<000001@3oool100000040oooo000?0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01P3oool6000000`0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`050?ooo`80000000<0oooo0000003oool02P3oool2000000X0oooo00<000000?ooo`3oool0
2P3oool010000000oooo0?ooo`0000020?ooo`8000005@3oool010000000oooo0?ooo`00000E0?oo
o`8000000P3oool00`000000oooo0000000>0?ooo`030000003oool0oooo00L0oooo0P00000;0?oo
o`040000003oool00000000000L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`L000001`3oool00`000000oooo0?ooo`0>0?ooo`4000000@3oool000l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`D000002@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00D0oooo0P0000030?ooo`030000003oool0oooo00H0oooo0P00000<0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0B0?oo
o`040000003oool0oooo000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000=
0?ooo`030000003oool0oooo00T0oooo0P0000080?ooo`040000003oool0oooo0?ooo`8000001`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo1@00000<0?ooo`030000003o
ool0oooo00h0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00P3oool4000000@0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`050?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`8000003P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool04@3oool0
10000000oooo0?ooo`00000C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000003@3o
ool00`000000oooo0?ooo`0;0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`8000001`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo100000040?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool03P3oool100000040oooo000?0?ooo`8000003`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
000000P0oooo00<000000?ooo`3oool04@3oool300000180oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0000000;0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`8000001P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00800000203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo0P000001
0?ooo`003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0203oool3000000X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`040000003oool0000000000140oooo00<000000?ooo`3oool02@3oool00`000000oooo00000009
0?ooo`8000003@3oool5000000030?ooo`000000000000<000003@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool03`3oool2000000030?ooo`000000
oooo00L0oooo0P0000060?ooo`030000003oool0oooo00T0oooo0P00000:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool03@3oool100000040oooo000?0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`@000001`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000C0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`060?ooo`@00000103oool00`00
0000oooo000000040?ooo`<000002@3oool00`000000oooo0?ooo`090?ooo`030000003oool00000
00X0oooo00<000000?ooo`3oool04@3oool2000000T0oooo0P0000060?ooo`030000003oool0oooo
00H0oooo0`00000<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool10000
0040oooo000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`040000003oool0oooo0?ooo`800000103oool00`000000oooo0?ooo`040?oo
o`800000203oool200000080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?oo
o`030000003oool0000000d0oooo00<000000?ooo`3oool00P3oool3000000P0oooo00<000000?oo
o`0000001`3oool3000000D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000000:0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool00P0000080?ooo`8000001P3oool00`00
0000oooo0?ooo`030?ooo`8000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool03@3oool100000040oooo000?0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`0000003@3oool00`000000oooo0?ooo`02000000/0oooo00<000000?ooo`0000002P3oool20000
0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0000000:0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`8000001@3oool01000
0000oooo0?ooo`3oool2000000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?oo
o`<000001@3oool00`000000oooo000000070?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000l0oooo0P00000=0?oo
o`030000003oool0000000`0oooo0`00000>0?ooo`030000003oool0000000T0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo0P0000050?oo
o`030000003oool0000000P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00d0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`030?ooo`@0
00001P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01`3oool2000000@0oooo00<000000?ooo`0000001P3oool2000000L0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000h0oooo0P00000>0?ooo`03
0000003oool0000000d0oooo0P00000>0?ooo`030000003oool0000000T0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`060?ooo`8000001`3oool2000000@0oooo0P0000090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`@0
00001@3oool100000040oooo000?0?ooo`030000003oool0oooo00L0oooo2000000:0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0000000H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`00000=0?oo
o`8000003@3oool010000000oooo0?ooo`00000>0?ooo`8000002@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool200000080oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo2000
00090?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool03@3oool00`000000oooo00000004
000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`040000003oool0
oooo0?ooo`@000001P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0000000<0?ooo`8000000`3oool00`000000oooo0?oo
o`0;0?ooo`8000003@3oool010000000oooo0?ooo`3oool2000000`0oooo00<000000?ooo`000000
2@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo0P0000060?ooo`<00000
0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0P3oool500000080oooo00<000000?ooo`3oool0303oool100000040oooo000?0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo0P0000060?ooo`800000303o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000002`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo0P00000<0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02P3oool2000000T0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`8000001@3oool2000000@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo008000001`3oool00`000000oooo0?oo
o`0<0?ooo`4000000@3oool000l0oooo0P00000=0?ooo`030000003oool0oooo00L0oooo0`00000:
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000
oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00X0oooo0P00000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo000000080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`020?ooo`<00000103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo0P0000090?ooo`030000003oool0oooo00/0oooo0P0000010?ooo`003`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo0`0000070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`0000002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo0P00000;
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool2000000P0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool2000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`@000002P3o
ool00`000000oooo0?ooo`0<0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`080?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool200000140oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`8000002`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00T0oooo0P00000;0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool2000000P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0?0?ooo`<00000103oool2000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`030?ooo`8000000`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo0@00
00010?ooo`003`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool000000180oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`8000002P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo0P0000070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0403o
ool2000000D0oooo0P0000040?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool100000040oooo
000?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`050?ooo`<000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000004P3oool00`000000oooo0000000<000000L0oooo0P00000:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0203oool2000000X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`080?ooo`8000001`3oool=00000080oooo00<000000?ooo`3oool0
403oool00`000000oooo000000050?ooo`800000103oool00`000000oooo0?ooo`050?ooo`<00000
1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo0@0000010?ooo`003`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3o
ool3000000D0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000040?ooo`030000003o
ool0oooo00`0oooo1@00000<0?ooo`D000000`3oool2000000T0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`070?ooo`8000002@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00P0oooo0P0000020?ooo`@0000000<0oooo0000003oool02P3oool5000000l0oooo00@0
00000?ooo`3oool0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000
2P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo0@0000010?ooo`003`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0?ooo`800000103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo0P0000030?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00P3oool4000000T0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`070?ooo`8000002@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0
oooo100000050?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool0oooo0P00000<0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
000000@0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00/0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`030?ooo`@000000`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool2
000000030?ooo`000000oooo0080oooo0P0000030?ooo`800000203oool00`000000oooo0?ooo`06
0?ooo`<000001P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo10000006
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool2000000P0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`@000001P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00<0oooo0`0000080?ooo`030000003oool0oooo00H0oooo0P000004
0?ooo`060000003oool0oooo0?ooo`000000oooo0P0000040?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`<000001@3oool100000040oooo
000?0?ooo`030000003oool0oooo00L0oooo100000090?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`<000002@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00@0oooo0P0000030?ooo`8000000`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00H0oooo0P0000080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0P3oool200000080oooo0P0000060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1P3oool4000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo1@0000080?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool02P3oool2000000P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`040000003oool000000?ooo`80
00000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00800000303oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`030000003oool0000001<0
oooo00<000000?ooo`3oool01P3oool2000000P0oooo00<000000?ooo`3oool04@3oool010000000
oooo0000000000040?ooo`8000001P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo0P0000000`3oool000000?ooo`0;0?ooo`040000003oool0oooo0?ooo`80000000@0oooo
0000003oool000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo0P00
000<0?ooo`4000000@3oool000l0oooo0P00000:0?ooo`030000003oool0oooo008000001@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P00
00030?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000060?ooo`800000503oool00`000000oooo0?oo
o`050?ooo`8000001`3oool00`000000oooo0?ooo`0B0?ooo`8000001`3oool2000000D0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`8000003@3oool010000000oooo0?oo
o`3oool200000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00<0oooo0P0000020?ooo`030000003oool0oooo00P0oooo0P0000010?ooo`003`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo0P0000030?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02000000<0oooo00<0
00000?ooo`3oool02`3oool3000000l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`8000001`3oool2000001@0oooo00<000000?ooo`3oool01@3oool2000000L0oooo00<0
00000?ooo`3oool04P3oool2000000L0oooo0P0000050?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0303oool010000000oooo00000000000<0?ooo`040000003oool0oooo0?ooo`80
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P0000040?ooo`030000003oool0oooo00T0oooo0@0000010?ooo`003`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00D0oooo0`0000080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P000000103oool000000?ooo`00000<0?ooo`8000000P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000060?ooo`040000003oool0oooo000001<0oooo00<000000?ooo`3oool01@3oool20000
00L0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0080oooo0P00000;0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo0`0000060?ooo`030000003oool0oooo00T0oooo0@00
00010?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo0P000006
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo00T0oooo0P0000050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`8000004@3o
ool00`000000oooo0?ooo`050?ooo`8000001`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool2000000D0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
0P0000080?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`003`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P0000030?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000P0oooo
0P0000070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool00P3oool7000000<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`8000001`3oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`80
000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`080?ooo`4000000@3oool000l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
0P0000000`3oool000000?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000D0oooo0P00000:0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00d0oooo1P0000020?ooo`8000000`3oool500000100oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`8000001@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo0?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool00P0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool100000040oooo000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`800000
1@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo0`0000000`3oool00000
0?ooo`050?ooo`8000001P3oool00`000000oooo00000002000000`0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000H0
oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool100000040oooo000?0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00D0
oooo0`00000=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0
oooo0P0000040?ooo`030000003oool0oooo00@0oooo0P0000060?ooo`030000003oool0oooo0080
oooo0P0000090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo0`0000080?ooo`030000003oool0oooo008000000P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo0@000001
0?ooo`003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo
000000070?ooo`8000003`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`040?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`8000001P3oool00`000000oooo
0?ooo`040?ooo`8000001P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
0P0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0>0?ooo`8000001`3oool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool100000040oooo00070?ooo`@00000103oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`800000
0P3oool01@000000oooo0?ooo`3oool0000000H0oooo0P0000020?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080
oooo0P0000040?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool0oooo0P0000090?oo
o`030000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0oooo00H0oooo0P0000030?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00P0000060?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000000000001@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool1
00000040oooo00070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool20000
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`@000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0oooo0P000005
0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`00000000002`3oool00`000000oooo0?oo
o`030?ooo`8000001@3oool00`000000oooo0?ooo`090?ooo`80000000<0oooo0000003oool03P3o
ool010000000oooo0?ooo`3oool2000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo0?ooo`@000001@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo0P0000060?ooo`4000000@3oool000P0oooo00<000000?ooo`3oool0
103oool3000000@0oooo00@000000?ooo`00000000001@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`00000000000`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?oo
o`L000002@3oool010000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool03@3oool2
000000d0oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool02`3oool2
000000l0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool01P3oool7
000000H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000000030?ooo`000000oooo00@0oooo0P00
00010?ooo`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo000000000000oooo00<000001P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00/0oooo1`0000060?ooo`P0000000<0oooo0000003oool00`3oool2000000@0oooo
00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00<0
oooo0P0000050?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000003`3oool01000
0000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`0000001`0000060?ooo`H000003`3oool0
0`000000oooo0?ooo`050?ooo`8000001@3oool3000000050?ooo`00000000000?ooo`0000001@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?oo
o`040?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo0`0000060?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`00000000000P3oool2000000H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`D000002`3oool00`000000oooo0?ooo`050?ooo`L00000103oool00`000000oooo
0?ooo`0<0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`80
00001@3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`00
0000oooo0?ooo`020?ooo`L000001`3oool00`000000oooo0?ooo`090?ooo`D000002P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`80000000<0oooo0000
003oool0103oool00`000000oooo0?ooo`030?ooo`<000001P3oool00`000000oooo0?ooo`030?oo
o`4000000@3oool000P0oooo0P0000050?ooo`030000003oool0oooo00/0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool4000000@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0?ooo`800000103o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`<000000`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3o
ool4000000H0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo0P00000=0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0200000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`0000000000303oool00`000000oooo000000030000
00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`060000003oool0oooo
0?ooo`000000oooo0P0000000`3oool000000?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`03000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00H0oooo100000000`3oool000000?ooo`0<0?ooo`030000003oool0000000@0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`020?ooo`800000103oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool2000000`0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`8000000`3oool20000
00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0080oooo0P0000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0:0?ooo`<000000P3oool2000000@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo0P00000>0?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool02P3oool100000040oooo000?0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00`3oool2000000@0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`80000000<0oooo0000003oool02P3oool2000000030?ooo`000000oooo
00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo
0?ooo`000000103oool010000000oooo0000000000080?ooo`8000002@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01`3oool2000000T0oooo0`0000030?ooo`800000103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool010000000oooo0000
0000000;0?ooo`040000003oool00000000000D0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`3oool2000000D0oooo00<000000?ooo`3oool02@3oool100000040oooo000?0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool020000000oooo000000000000
oooo0000003oool000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00002@3oool2000000<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00@00000
0?ooo`3oool0oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`040?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`3oool0oooo0P0000090?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`02000000060?ooo`000000oooo0000003oool000001P3oool00`000000oooo0?oo
o`080?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000oooo0P0000050?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool2000000D0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo
0P0000030?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02@3oool010000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool20000
00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`8000000P3oool00`00
0000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool10000
0040oooo000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`3oool2000000040?ooo`000000oooo000000D0oooo0P0000060?ooo`030000003oool0
oooo0080oooo0P0000080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`800000103oool00`000000oooo0?oo
o`050?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0203oool010000000oooo0?oo
o`3oool2000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`040000
003oool00000000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00H0oooo0`0000030?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`060000003oool00000
0000003oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0@00
00010?ooo`003`3oool2000000L0oooo00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`3o
ool000000?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`070?ooo`040000
003oool00000000000X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03P3oool2000000T0oooo00@000000?ooo`3oool0oooo0P000003
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`08
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`<000002@3o
ool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P0000010?ooo`003`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool0oooo0000003oool20000
00040?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0203oool2000000`0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000403o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000002@3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool2000000X0oooo00L000000?ooo`3o
ool0oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00H000000?ooo`3oool0oooo0000003oool200000080oooo00H0
00000?ooo`3oool000000?ooo`0000090?ooo`80000000<0oooo0000003oool02`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000@0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`0000001`0000090?ooo`030000003oool0oooo
00h0oooo00@000000?ooo`3oool000002@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02`3oool010000000oooo0000000000090?ooo`030000003oool0000000<0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool100000040oooo000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool01P000000oooo0?ooo`3oool000000?ooo`8000000P3oool010000000oooo0?ooo`3o
ool2000000T0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000000403oool00`00
0000oooo0?ooo`020?ooo`H000000P3oool2000000<0oooo1@0000050?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool2000000@0oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool100000040oooo000?0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`<000000P3oool01000
0000oooo0?ooo`3oool3000000L0oooo0P0000050?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0=0?ooo`D00000103oool010000000oooo0?ooo`3oool2000000<0oooo00<0
00000?ooo`3oool00P3oool5000000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`030?ooo`8000001`3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`00
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`00
3`3oool00`000000oooo0?ooo`080?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`3ooolB000000H0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02P3oool3000000T0oooo00<000000?ooo`3oool00P0000030?ooo`030000
003oool0oooo00H0oooo0`00000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103ooolC00000080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`080?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool01`3oool02000
0000oooo0?ooo`3oool000000?ooo`000000oooo0P0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P0000090?ooo`030000003oool0oooo00T0oooo100000080?ooo`030000
003oool0oooo00H0oooo1@0000000`3oool000000?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo0P0000020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P00000:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000@00000203oool00`00
0000oooo0?ooo`070?ooo`@000002P3oool00`000000oooo0?ooo`070?ooo`8000000P3oool00`00
0000oooo0?ooo`030?ooo`8000000`3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool01`3oool100000040oooo000?0?ooo`030000003oool0oooo00H0oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`040?ooo`<00000
2`3oool00`000000oooo0?ooo`040?ooo`D0000000<0oooo0000003oool02@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo0`0000000`3oool000000?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`800000
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo008000000`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo0P0000070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`3oool000000?ooo`<000001@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0100000050?oo
o`030000003oool0oooo00X0oooo0P0000080?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool01P3oool100000040oooo000?0?ooo`030000003o
ool0oooo00D0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool00`00
0000oooo0?ooo`050?ooo`8000003@3oool00`000000oooo00000003000000H0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`050?ooo`8000001@3oool00`000000oooo000000020000
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo
0?ooo`8000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo008000000`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo00000002000000030?ooo`000000
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00@0oooo100000000`3oool000000?ooo`0<0?ooo`800000203oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`00
3`3oool00`000000oooo0?ooo`040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`3oool0103oool200000080oooo00<000000?ooo`3oool02@3oool3
000000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`00000000000?ooo`02000000L0oooo00<000000?ooo`3oool0303o
ool00`000000oooo000000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P00
00030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool010000000oooo0?oo
o`00000=0?ooo`030000003oool0oooo00D0oooo0P0000001@3oool000000?ooo`3oool0000000H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo0`00000;0?ooo`030000003oool0oooo008000001`3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`003`3oool2
000000@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool200000003
0?ooo`000000oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool3000000@0oooo00<000000?oo
o`3oool03@3oool2000000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`8000003`3oool00`00
0000oooo0?ooo`020?ooo`80000000D0oooo0000003oool0oooo000000020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00@000000?ooo`00000000002@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`8000000@3oool000l0oooo00<000000?ooo`3oool01P3oool01@000000
oooo0000003oool0000000<0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool2000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool010000000oooo000000000002
0?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool03P3oool00`000000oooo0000
000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P0000030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02P3oool2000000l0oooo00@000000?ooo`0000000000
0`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool2000000H0oooo00<000000?ooo`3oool0103oool2000000H0oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000203oool100000040oooo000?0?ooo`030000003oool0
oooo00D0oooo0`0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00@0oooo0P000007
0?ooo`040000003oool0oooo0?ooo`<000001P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool00`3oool2000000d0oooo0P0000020?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0200000080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00800000
3@3oool2000000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00@0oooo0`0000030?ooo`030000003oool0oooo00H0oooo0P0000050?ooo`06
0000003oool0oooo0?ooo`000000oooo0`0000070?ooo`4000000@3oool000l0oooo00<000000?oo
o`3oool0103oool2000000030?ooo`000000000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`<000002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`040000003oool00000
00000080oooo00<000000?ooo`3oool0103oool2000000/0oooo0P0000050?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0200000080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P00000;
0?ooo`8000001P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01`3oool3000000/0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`3oool2000000030?ooo`000000000000H0oooo0@0000010?ooo`003`3oool00`000000oooo0?oo
o`030?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`030?ooo`8000002P3o
ool2000000`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P0000080?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00800000
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`80
00002`3oool2000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0000000000050?oo
o`4000000@3oool000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`80
0000103oool2000000X0oooo0P0000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo008000000P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`02000000/0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00<00000
0?ooo`0000001@3oool100000040oooo000?0?ooo`030000003oool0oooo0?l0oooo3@3oool10000
0040oooo000?0?ooo`030000003oool0oooo0?l0oooo3@3oool100000040oooo000?0?ooo`030000
003oool0oooo0?l0oooo3@3oool100000040oooo000?0?ooo`030000003oool0oooo0?l0oooo3@3o
ool100000040oooo000?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0M0?ooo`4000000@3oool000l0oooo0P00000:0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo0P0000010?ooo`003`3ooooo0000014000000@3oool00?l0oooo8@3oool00001\
\>"],
    ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2, -2, 0, 0}}],
  "     ",
  StyleBox["\n\t\tFigure 3.C",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The orthogonal grid formed by ",
  Cell[BoxData[
      \(x\^3 - 3\ x\ y\^2 = C\)]],
  " and ",
  Cell[BoxData[
      \(3\ x\^2\ y - y\^3 = C\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(u \((x, y)\) = \ 
        x - 2\ x\^3 - 6\ x\ y - 4\ x\^3\ y + 6\ x\ y\^2 + 4\ x\ y\^3\)]],
  "  is a harmonic function and find the harmonic conjugate  ",
  Cell[BoxData[
      \(v \((x, y)\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the function u[x,y], do a step by step construction.", "Text"],

Cell[BoxData[{
    \(\(u[x_, y_]\  = \ 
        x - 2\ x\^3 - 6\ x\ y - 4\ x\^3\ y + 6\ x\ y\^2 + 
          4\ x\ y\^3;\)\ \), "\[IndentingNewLine]", 
    \(\(c[
          x_] = \[Integral]\((\(-\ \[PartialD]\_y\ 
                    u[x, y]\)\  - \ \[PartialD]\_x\ \ \((\[Integral]\
\[PartialD]\_x\ u[x, 
                            y] \[DifferentialD]y)\))\) \
\[DifferentialD]x;\)\), "\[IndentingNewLine]", 
    \(\(v[x_, 
          y_]\  = \ \[Integral]\[PartialD]\_x u[x, y] \[DifferentialD]y\  + \ 
          c[x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< u[x,y] = \>", u[x, y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(u\_x\)[x,y] = \>\"", \[PartialD]\_x u[x, 
            y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(u\_y\)[x,y] = \>\"", \[PartialD]\_y u[x, 
            y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Construct the function c[x]\>"];\)\), "\[IndentingNewLine]", \

    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<c[x] = \[Integral](- \!\(\[PartialD]\_y\)u[x,y] - \!\(\
\[PartialD]\_x\)(\[Integral]\!\(\[PartialD]\_x\) u[x,y]\[DifferentialD]y))\
\[DifferentialD]x\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<c[x] = \[Integral](- \!\(\[PartialD]\_y\)(\>\"", 
        u[x, y], \*"\"\<) - \
\!\(\[PartialD]\_x\)(\[Integral]\!\(\[PartialD]\_x\)(\>\"", 
        u[x, y], "\<)\[DifferentialD]y))\[DifferentialD]x\>"\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<c[x] = \[Integral](- (\>", \[PartialD]\_y u[x, 
            y], \*"\"\<) - \!\(\[PartialD]\_x\)(\>\"", \[Integral]\((\
\[PartialD]\_x u[x, 
                  y])\) \[DifferentialD]y, "\<))\[DifferentialD]x\>"\ ];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<c[x] = \[Integral](\>", \(-\ \[PartialD]\_y u[x, 
              y]\), "\< - (\>", \
\[PartialD]\_x\((\[Integral]\[PartialD]\_x\((u[x, 
                      y])\) \[DifferentialD]y)\)\ , "\<))\[DifferentialD]x\>"\
\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<c[x] = \[Integral](\>", \(-\ \[PartialD]\_y u[x, 
                y]\)\  - \ \[PartialD]\_x\((\[Integral]\[PartialD]\_x\ 
                    u[x, y] \[DifferentialD]y)\), "\<)\[DifferentialD]x\>"\ \
];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<c[x] = \>", \[Integral]\((\(-\ \[PartialD]\_y u[x, 
                      y]\)\  - \ \[PartialD]\_x\((\[Integral]\[PartialD]\_x\ 
                          u[x, y] \[DifferentialD]y)\))\) \[DifferentialD]x\ \
];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Now construct v[x,y]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<v[x,y] = \[Integral]\!\(\[PartialD]\_y\)v[x,y]\
\[DifferentialD]y + c[x]\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<v[x,y] = \[Integral]\!\(\[PartialD]\_x\)u[x,y]\
\[DifferentialD]y + c[x]\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<v[x,y] = \[Integral]\!\(\[PartialD]\_x\)(\>\"", 
        u[x, y], "\<)\[DifferentialD]y + (\>", 
        c[x], "\<)\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \[Integral](\>", \[PartialD]\_x u[x, 
            y], "\<)\[DifferentialD]y + (\>", 
        c[x], "\<)\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = (\>", \[Integral]\[PartialD]\_x u[x, 
                y] \[DifferentialD]y, "\<) + (\>", 
        c[x], "\<)\>", "\<+ C\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", \[Integral]\[PartialD]\_x u[x, 
                  y] \[DifferentialD]y\  + \ 
          c[x], "\<+ C\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Expand[\[Integral]\[PartialD]\_x u[x, y] \[DifferentialD]y\  + \ 
            c[x]], "\<+ C\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We are done!\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can also construct v[x,y] by the following alternative method."
}], "Text"],

Cell["\<\
Enter the function u[x,y], and determine if it is a harmonic function.  If \
so, proceed with the construction of the harmonic conjugate v[x,y].\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[f, F, u, v, x, y];\)\ \), "\[IndentingNewLine]", 
    \(\(u[x_, y_]\  = \ 
        x - 2\ x\^3 - 6\ x\ y - 4\ x\^3\ y + 6\ x\ y\^2 + 
          4\ x\ y\^3;\)\ \), "\n", 
    \(\(v[x_, y_]\  = \ con[u[x, y]];\)\ \), "\n", 
    \(\(Print["\<u(x,y) = \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Constructing the harmonic conjugate we get\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<v(x,y) = \>", v[x, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v(x,y) = \>", 
        Expand[v[x, y]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Form the analytic function  f[z] = u[x,y]+ i v[x,y]  and verify that the \
Cauchy-Riemann equations hold.\
\>", "Text"],

Cell[BoxData[{
    \(\(Ux\  = \ \[PartialD]\_x\ u[x, y];\)\ \), "\n", 
    \(\(Uy\  = \ \[PartialD]\_y\ u[x, y];\)\ \), "\n", 
    \(\(Vx\  = \ \[PartialD]\_x\ v[x, y];\)\ \), "\n", 
    \(\(Vy\  = \ \[PartialD]\_y\ v[x, y];\)\ \), "\[IndentingNewLine]", 
    \(\(f[x_, y_] = u[x, y]\  + \ \[ImaginaryI]\ v[x, y];\)\ \), "\n", 
    \(\(Print["\<   f[z] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< u[x,y] = \>", u[x, y]];\)\ \), "\n", 
    \(\(Print["\< v[x,y] = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_x\)[x,y] = \>\"", Ux];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(u\_y\)[x,y] = \>\"", Uy];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_x\)[x,y] = \>\"", Vx];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(v\_y\)[x,y] = \>\"", 
        Vy];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_x\)[x,y] =  \!\(v\_y\)[x,y] ?      \>\"", 
        Ux \[Equal] Vy];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(u\_y\)[x,y] = -\!\(v\_x\)[x,y] ?      \>\"", 
        Uy \[Equal] \(-Vx\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Therefore  ",
  Cell[BoxData[
      \(v[x, y] = 
        3\ x\^2 + x\^4 + \((1 - 6\ x\^2)\)\ y - 3\ \((1 + 2\ x\^2)\)\ y\^2 + 
          2\ y\^3 + y\^4\)]],
  " is the harmonic conjugate of  ",
  Cell[BoxData[
      \(u[x, y] = 
        x - 2\ x\^3 - 6\ x\ y - 4\ x\^3\ y + 6\ x\ y\^2 + 4\ x\ y\^3\)]],
  ".  \n",
  StyleBox["\nAside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to get the standard form of an analytic function.  "
}], "Text"],

Cell[BoxData[{
    \(\(F[z_] = 
        ReplaceAll[
          f[x, y], {x \[Rule] \(z + Conjugate[z]\)\/2, 
            y \[Rule] \(z - Conjugate[z]\)\/\(2  \[ImaginaryI]\)}];\)\ \), "\
\[IndentingNewLine]", 
    \(\(F[z_] = ComplexExpand[F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(W = 
        ReplaceAll[
          f[x, y], {x \[Rule] \(z + \(\(z\)\(\ \)\)\&_\)\/2, 
            y \[Rule] \(z - \(\(z\)\(\ \)\)\&_\)\/\(2  \[ImaginaryI]\)}];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", W];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Fluid Flow",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tHarmonic functions are solutions to many physical problems.  \
Applications include two-dimensional models of heat flow, electrostatics, and \
fluid flow.  We now give an example of the latter.\n\t\n\tWe assume that an \
incompressible and frictionless fluid flows over the complex plane and that \
all cross sections in planes parallel to the complex plane are the same.  \
Situations such as this occur when fluid is flowing in a deep channel. The \
velocity vector at the point ",
  Cell[BoxData[
      \(\((x, y)\)\)]],
  " is \n\n",
  StyleBox["(3-29)\t",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["V",
            FontWeight->"Bold"], \((x, y)\)}], " ", "=", 
        " ", \(p \((x, y)\) + \[ImaginaryI]\ q \((x, y)\)\)}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe assumption that the flow is irrotational and has no sources or sinks \
implies that both the curl and divergence vanish, that is, ",
  Cell[BoxData[
      \(q\_x - p\_y = 0\)]],
  " and ",
  Cell[BoxData[
      \(p\_x + q\_y = 0\)]],
  ".  Hence ",
  StyleBox["p",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["q",
    FontFamily->"Courier New"],
  " obey the partial differential equations \n\n",
  StyleBox["(3-30)\t",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(\(p\_x\) \((x, y)\)\  = \ \(-\ q\_y\) \((x, y)\)\)]],
  ",   and \n\n\t\t\t",
  Cell[BoxData[
      \(\(p\_y\) \((x, y)\)\  = \ \(q\_x\) \((x, y)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Equations ",
  StyleBox["(3-30)",
    FontColor->RGBColor[0, 0, 1]],
  " are similar to the Cauchy-Riemann equations and permit us to define a \
special complex function:\n\n",
  StyleBox["(3-31)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(u \((x, y)\) + \[ImaginaryI]\ v \((x, y)\)\  = \ 
          p \((x, y)\) - \[ImaginaryI]\ q \((x, y)\)\)\)]],
  ".  \n\nHere we have  ",
  Cell[BoxData[
      RowBox[{\(u\_x = p\_x\), ",", " ", \(u\_y = p\_y\), ",", " ", 
        RowBox[{\(v\_x\), "=", 
          RowBox[{
            RowBox[{\(-q\_x\), "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(v\_y\)}], 
            "=", \(-q\_y\)}]}]}]]],
  ".  We can use Equations ",
  StyleBox["(3-30)",
    FontColor->RGBColor[0, 0, 1]],
  " to verify that the Cauchy-Riemann equations are satisfied for ",
  StyleBox["f",
    FontFamily->"Courier New"],
  ":  \n\n\t\t\t",
  Cell[BoxData[
      \(\(u\_x\) \((x, 
            y)\)\  = \ \(\(p\_x\) \((x, 
              y)\)\  = \ \(\(-\ q\_y\) \((x, y)\)\  = \ \(v\_y\) \((x, 
                y)\)\)\)\)]],
  ",   and    \n\n\t\t\t",
  Cell[BoxData[
      \(\(u\_y\) \((x, 
            y)\)\  = \ \(\(p\_y\) \((x, 
              y)\)\  = \ \(\(q\_x\) \((x, y)\)\  = \ \(-\ v\_x\) \((x, 
                y)\)\)\)\)]],
  ".  \n\nAssuming the functions ",
  StyleBox["p",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["q",
    FontFamily->"Courier New"],
  " have continuous partials, Theorem 3.4 guarantees that function ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " defined in Equation ",
  StyleBox["(3-31)",
    FontColor->RGBColor[0, 0, 1]],
  " is analytic, and that the fluid flow of Equation ",
  StyleBox["(3-29)",
    FontColor->RGBColor[0, 0, 1]],
  " is the conjugate of an analytic function, that is,\n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["V",
            FontWeight->"Bold"], \((x, y)\)}], " ", "=", 
        " ", \(\(f \((z)\)\)\&_\)}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\n\tIn Chapter 6 we will prove that every analytic function ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " has an analytic antiderivative ",
  StyleBox["F",
    FontFamily->"Courier New"],
  ";  assuming this to be the case, we can write  \n\n",
  StyleBox["(3-32)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(F \((z)\)\  = \ \[Phi] \((x, y)\) + \[ImaginaryI]\ \[Psi] \((x, 
              y)\)\)]],
  ",  \n\nwhere ",
  Cell[BoxData[
      \(F' \((z)\) = f \((z)\)\)]],
  ".  \n\n\tTheorem 3.8 tells us that ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  " is a harmonic function.  If we use the vector interpretation of a complex \
number we see that the gradient of ",
  Cell[BoxData[
      \(\[Phi]\)]],
  " can be written as \n\n\t\t\t",
  Cell[BoxData[
      \(grad\ \[Phi] \((x, 
            y)\)\  = \ \ \(\[Phi]\_x\) \((x, 
              y)\) + \[ImaginaryI]\ \(\[Phi]\_y\) \((x, y)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\n\tThe Cauchy-Riemann equations applied to ",
  Cell[BoxData[
      \(F \((z)\)\)]],
  " give  ",
  Cell[BoxData[
      \(\(\[Phi]\_y\) \((x, y)\) = \(-\ \[Psi]\_x\) \((x, y)\)\)]],
  ";   making this substitution in the last equation yields  \n\n\t\t\t",
  Cell[BoxData[
      \(grad\ \[Phi] \((x, 
            y)\)\  = \ \ \(\(\[Phi]\_x\) \((x, 
                y)\) - \[ImaginaryI]\ \(\[Psi]\_x\) \((x, 
                y)\)\  = \ \(\(\[Phi]\_x\) \((x, y)\) + \[ImaginaryI]\ \(\
\[Psi]\_x\) \((x, y)\)\)\&_\)\)]],
  ".  \n\nEquation ",
  StyleBox["(3-14)",
    FontColor->RGBColor[0, 0, 1]],
  " says that  ",
  Cell[BoxData[
      \(\(\[Phi]\_x\) \((x, y)\) + \[ImaginaryI]\ \(\[Psi]\_x\) \((x, y)\) = 
        F' \((z)\)\)]],
  ",  which by the preceeding equation and Equation ",
  StyleBox["(3-32)",
    FontColor->RGBColor[0, 0, 1]],
  " imply that  \n\n\t\t\t",
  Cell[BoxData[
      \(grad\ \[Phi] \((x, 
            y)\)\  = \ \(\(F' \((z)\)\)\&_\  = \ \(f \((z)\)\)\&_\)\)]],
  ".  \n\nFinally, from Equation ",
  StyleBox["(3-29)",
    FontColor->RGBColor[0, 0, 1]],
  ",  ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  " is the scalar potential function for the a fluid flow, so \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["V",
            FontWeight->"Bold"], \((x, y)\)}], 
        "=", \(grad\ \[Phi] \((x, y)\)\)}]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe curves given by ",
  Cell[BoxData[
      \({\((x, y)\) : \ \ \[Phi] \((x, y)\) = constant}\)]],
  " are call",
  "ed equipotentials.  ",
  "The curves ",
  Cell[BoxData[
      \({\((x, y)\) : \ \[Psi] \((x, y)\) = constant}\)]],
  " are ca",
  "lled streamlines and de",
  "scribe the path of fluid flow.  In Chapter 11 we will see that the family \
of equipotentials is orthogonal to the family of streamlines."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 3.14.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  "Show that the harmonic function",
  " ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\  = \ x\^2 - y\^2\)]],
  "  is the scalar potential function for the fluid flow  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["V",
            FontWeight->"Bold"], \((x, y)\)}], " ", "=", 
        " ", \(2\ x - 2\ \[ImaginaryI]\ y\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We can write the fluid flow expression as\n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["V",
            FontWeight->"Bold"], \((x, y)\)}], " ", "=", 
        " ", \(2\ x - 2\ \[ImaginaryI]\ y\  = \ 2  z\)}]]],
  ".   \n\nAn antiderivative of  ",
  Cell[BoxData[
      \(f \((z)\) = 2  z\)]],
  "  is  ",
  Cell[BoxData[
      \(F \((z)\) = z\^2\)]],
  ",  and the real part of ",
  Cell[BoxData[
      \(F \((z)\)\)]],
  " is the desired harmonic function:  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\  = \ \(Re[
            F \((z)\)]\  = \ \(Re[x\^2 - y\^2 + 2\ \[ImaginaryI]\ x\ y]\  = \ 
            x\^2 - y\^2\)\)\)]],
  ".  \n\nNote that the hyperbolas  ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\  = \ \(x\^2 - y\^2\  = \ C\)\)]],
  "  are the equipotential curves and that the hyperbolas  ",
  Cell[BoxData[
      \(\[Psi] \((x, y)\)\  = \ \(2  x\ y\  = \ C\)\)]],
  "  are the streamline curves; these curves are orthogonal, as shown in \
Figure 3.6."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0.0131579 0.131579 0.0131579 0.131579 [
[.14474 .00066 -4.21875 -10.9375 ]
[.14474 .00066 4.21875 0 ]
[.27632 .00066 -4.21875 -10.9375 ]
[.27632 .00066 4.21875 0 ]
[.40789 .00066 -4.21875 -10.9375 ]
[.40789 .00066 4.21875 0 ]
[.53947 .00066 -4.21875 -10.9375 ]
[.53947 .00066 4.21875 0 ]
[.67105 .00066 -4.21875 -10.9375 ]
[.67105 .00066 4.21875 0 ]
[.80263 .00066 -4.21875 -10.9375 ]
[.80263 .00066 4.21875 0 ]
[.93421 .00066 -4.21875 -10.9375 ]
[.93421 .00066 4.21875 0 ]
[.00066 .14474 -8.4375 -5.46875 ]
[.00066 .14474 0 5.46875 ]
[.00066 .27632 -8.4375 -5.46875 ]
[.00066 .27632 0 5.46875 ]
[.00066 .40789 -8.4375 -5.46875 ]
[.00066 .40789 0 5.46875 ]
[.00066 .53947 -8.4375 -5.46875 ]
[.00066 .53947 0 5.46875 ]
[.00066 .67105 -8.4375 -5.46875 ]
[.00066 .67105 0 5.46875 ]
[.00066 .80263 -8.4375 -5.46875 ]
[.00066 .80263 0 5.46875 ]
[.00066 .93421 -8.4375 -5.46875 ]
[.00066 .93421 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14474 .01316 m
.14474 .01941 L
s
gsave
.14474 .00066 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.27632 .01316 m
.27632 .01941 L
s
gsave
.27632 .00066 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.40789 .01316 m
.40789 .01941 L
s
gsave
.40789 .00066 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.53947 .01316 m
.53947 .01941 L
s
gsave
.53947 .00066 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.67105 .01316 m
.67105 .01941 L
s
gsave
.67105 .00066 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.80263 .01316 m
.80263 .01941 L
s
gsave
.80263 .00066 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.93421 .01316 m
.93421 .01941 L
s
gsave
.93421 .00066 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
0 .01316 m
1 .01316 L
s
.01316 .14474 m
.01941 .14474 L
s
gsave
.00066 .14474 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.01316 .27632 m
.01941 .27632 L
s
gsave
.00066 .27632 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.01316 .40789 m
.01941 .40789 L
s
gsave
.00066 .40789 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.01316 .53947 m
.01941 .53947 L
s
gsave
.00066 .53947 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.01316 .67105 m
.01941 .67105 L
s
gsave
.00066 .67105 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.01316 .80263 m
.01941 .80263 L
s
gsave
.00066 .80263 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.01316 .93421 m
.01941 .93421 L
s
gsave
.00066 .93421 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.01316 0 m
.01316 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.03195 .93421 m
.03408 .84058 L
.03636 .75943 L
.04046 .64732 L
.04534 .5512 L
.04977 .486 L
.0544 .43292 L
.05943 .38732 L
.06856 .32567 L
.07863 .27759 L
.08931 .2405 L
.09843 .21619 L
.10847 .1948 L
.12686 .16542 L
.14664 .14286 L
.16666 .12594 L
.1857 .1135 L
.22188 .09611 L
.24052 .08931 L
.26038 .08319 L
.29978 .07356 L
.33774 .0665 L
.37426 .0611 L
.4131 .05645 L
.45051 .05274 L
.48649 .04974 L
.52478 .047 L
.56164 .04472 L
.60083 .04262 L
.63858 .04084 L
.67489 .03932 L
.71352 .03788 L
.75072 .03663 L
.78649 .03555 L
.82457 .03449 L
.86123 .03357 L
.9002 .03268 L
.93421 .03195 L
s
.08835 .93421 m
.09632 .84591 L
.10505 .76678 L
.12266 .64558 L
.14203 .55051 L
.16008 .4845 L
.19471 .39459 L
.21364 .35859 L
.23152 .33029 L
.26564 .28744 L
.30194 .25297 L
.33689 .22708 L
.37049 .20696 L
.40627 .18932 L
.44071 .17513 L
.47732 .16236 L
.51259 .15182 L
.54651 .143 L
.58261 .13477 L
.61736 .12777 L
.6543 .12117 L
.68988 .11549 L
.72412 .11056 L
.76054 .10582 L
.79561 .10166 L
.82933 .09801 L
.86524 .09443 L
.89979 .09126 L
.93421 .08835 L
s
.18233 .93421 m
.21283 .79351 L
.2461 .68208 L
.27734 .60297 L
.30738 .54274 L
.33936 .49082 L
.37015 .44963 L
.40287 .41299 L
.43439 .38307 L
.46472 .35822 L
.49698 .33521 L
.52805 .31578 L
.55792 .29919 L
.58972 .28341 L
.62033 .26978 L
.65288 .25673 L
.68423 .24535 L
.71438 .23537 L
.74647 .22564 L
.77736 .21705 L
.81019 .20866 L
.84182 .20119 L
.87225 .19453 L
.90462 .18795 L
.93421 .18233 L
s
.31391 .93421 m
.33907 .8631 L
.36652 .79709 L
.39229 .74379 L
.41708 .69896 L
.44346 .65691 L
.46886 .62103 L
.49585 .58704 L
.52186 .5577 L
.54688 .53217 L
.5735 .50752 L
.59913 .48589 L
.62377 .46682 L
.65001 .44812 L
.67526 .43153 L
.70211 .41523 L
.72797 .40068 L
.75285 .38765 L
.77932 .37471 L
.80481 .36307 L
.83189 .3515 L
.85799 .34104 L
.8831 .33158 L
.9098 .3221 L
.93421 .31391 L
s
.48308 .93421 m
.50138 .89969 L
.52134 .86487 L
.54009 .83457 L
.55811 .8074 L
.5773 .78038 L
.59577 .75606 L
.6154 .73184 L
.63432 .70996 L
.65251 .69013 L
.67187 .67023 L
.69051 .65215 L
.70843 .63568 L
.72752 .61905 L
.74588 .60386 L
.76541 .58853 L
.78422 .57449 L
.80231 .56163 L
.82156 .54856 L
.8401 .53656 L
.8598 .52439 L
.87878 .51318 L
.89704 .50285 L
.91646 .49232 L
.93421 .48308 L
s
.68985 .93421 m
.69976 .92091 L
.71057 .90684 L
.72073 .89402 L
.73049 .88203 L
.74089 .86962 L
.75089 .858 L
.76152 .846 L
.77177 .83475 L
.78163 .82421 L
.79211 .81329 L
.80221 .80306 L
.81192 .79346 L
.82225 .78349 L
.8322 .77413 L
.84278 .76443 L
.85297 .75531 L
.86277 .74675 L
.87319 .73786 L
.88323 .7295 L
.8939 .72082 L
.90418 .71265 L
.91407 .70497 L
.9246 .69699 L
.93421 .68985 L
s
0 0 1 r
[ .025 .025 ] 0 setdash
.01316 .01316 m
.05052 .05052 L
.09127 .09127 L
.12954 .12954 L
.16635 .16635 L
.20552 .20552 L
.24323 .24323 L
.28331 .28331 L
.32193 .32193 L
.35908 .35908 L
.3986 .3986 L
.43666 .43666 L
.47325 .47325 L
.51221 .51221 L
.54971 .54971 L
.58958 .58958 L
.62798 .62798 L
.66492 .66492 L
.70423 .70423 L
.74207 .74207 L
.78228 .78228 L
.82103 .82103 L
.85831 .85831 L
.89797 .89797 L
.93421 .93421 L
s
.01316 .14474 m
.01428 .14474 L
.01531 .14475 L
.01649 .14478 L
.01761 .14481 L
.01959 .14489 L
.02175 .14502 L
.02412 .14519 L
.02664 .14543 L
.03116 .14596 L
.04019 .14749 L
.05014 .14983 L
.06017 .15288 L
.07096 .15687 L
.09047 .16577 L
.12993 .18908 L
.16794 .21631 L
.2045 .24537 L
.2434 .27835 L
.28086 .31144 L
.32066 .34763 L
.35901 .38319 L
.39591 .41789 L
.43516 .45519 L
.47295 .49141 L
.5093 .52645 L
.54799 .56394 L
.58524 .60017 L
.62483 .63882 L
.66297 .67615 L
.69965 .71215 L
.73869 .75052 L
.77627 .78754 L
.81241 .82317 L
.85089 .86116 L
.88792 .89776 L
.92476 .93421 L
s
.01316 .27632 m
.01425 .27632 L
.01524 .27632 L
.01638 .27634 L
.01746 .27635 L
.01939 .27639 L
.02148 .27645 L
.02378 .27653 L
.02621 .27664 L
.03059 .27689 L
.0351 .27723 L
.03933 .27761 L
.04896 .27874 L
.05879 .28024 L
.06778 .28192 L
.08802 .28676 L
.12482 .29902 L
.16021 .31462 L
.19788 .33468 L
.23415 .3568 L
.27269 .38276 L
.30982 .40972 L
.34555 .43711 L
.38355 .46752 L
.42015 .49781 L
.45534 .52772 L
.4928 .56025 L
.52886 .59213 L
.5672 .62652 L
.60412 .66007 L
.63965 .69267 L
.67744 .72767 L
.71384 .76162 L
.74882 .79447 L
.78608 .82965 L
.82194 .86367 L
.86007 .90001 L
.89582 .93421 L
s
.01316 .40789 m
.01419 .4079 L
.01512 .4079 L
.0162 .40791 L
.01722 .40792 L
.01903 .40794 L
.021 .40797 L
.02317 .40802 L
.02547 .40809 L
.02959 .40824 L
.03385 .40844 L
.03784 .40867 L
.04692 .40934 L
.05618 .41023 L
.06465 .41124 L
.08373 .41415 L
.10032 .4174 L
.11843 .42169 L
.15395 .43225 L
.18814 .44494 L
.22447 .4609 L
.25948 .47845 L
.29317 .49712 L
.32899 .5187 L
.3635 .54094 L
.39668 .56353 L
.432 .5887 L
.466 .61389 L
.50214 .64158 L
.53695 .66904 L
.57045 .69608 L
.60608 .72546 L
.64039 .75426 L
.67338 .78238 L
.70851 .81274 L
.74231 .8423 L
.77826 .87409 L
.81288 .905 L
.84534 .93421 L
s
.01316 .53947 m
.01409 .53947 L
.01494 .53948 L
.01592 .53948 L
.01685 .53949 L
.01849 .5395 L
.02028 .53952 L
.02225 .53955 L
.02434 .53959 L
.02808 .53969 L
.03195 .53981 L
.03557 .53995 L
.04382 .54037 L
.05223 .54092 L
.05993 .54155 L
.07726 .54336 L
.09233 .5454 L
.10878 .54809 L
.14104 .55479 L
.17209 .56295 L
.20509 .57338 L
.23689 .58505 L
.26749 .5977 L
.30003 .61258 L
.33137 .62819 L
.36151 .64431 L
.39359 .66257 L
.42447 .68113 L
.4573 .70183 L
.48892 .72263 L
.51934 .74338 L
.55171 .76618 L
.58287 .78877 L
.61283 .81104 L
.64474 .83529 L
.67544 .85911 L
.70809 .88491 L
.73954 .91018 L
.76902 .93421 L
s
.01316 .67105 m
.01395 .67105 L
.01468 .67105 L
.01551 .67106 L
.0163 .67106 L
.01771 .67107 L
.01923 .67108 L
.02091 .6711 L
.02269 .67112 L
.02589 .67118 L
.02918 .67125 L
.03227 .67133 L
.03931 .67157 L
.04648 .6719 L
.05305 .67226 L
.06783 .67332 L
.08068 .67451 L
.0947 .67609 L
.12221 .68003 L
.1487 .68487 L
.17684 .69111 L
.20396 .69816 L
.23005 .70588 L
.2578 .71507 L
.28453 .72482 L
.31023 .73501 L
.33759 .7467 L
.36393 .75872 L
.39192 .77229 L
.41889 .7861 L
.44483 .80003 L
.47243 .8155 L
.49901 .83101 L
.52456 .84644 L
.55177 .86341 L
.57796 .88024 L
.6058 .89863 L
.63262 .9168 L
.65776 .93421 L
s
.01316 .80263 m
.01374 .80263 L
.01428 .80263 L
.01489 .80263 L
.01547 .80263 L
.01651 .80264 L
.01763 .80264 L
.01887 .80265 L
.02018 .80266 L
.02253 .80269 L
.02495 .80272 L
.02723 .80276 L
.0324 .80287 L
.03768 .80301 L
.04252 .80318 L
.05339 .80366 L
.06285 .80419 L
.07317 .80491 L
.09342 .8067 L
.11291 .80891 L
.13363 .81177 L
.15358 .81502 L
.17279 .81861 L
.19321 .8229 L
.21288 .8275 L
.2318 .83235 L
.25193 .83795 L
.27132 .84377 L
.29192 .8504 L
.31177 .85722 L
.33086 .86416 L
.35118 .87195 L
.37074 .87984 L
.38954 .88776 L
.40957 .89657 L
.42884 .90538 L
.44933 .91511 L
.46907 .92482 L
.48757 .93421 L
s
.14474 .01325 m
.14571 .0292 L
.1466 .03537 L
.14859 .04523 L
.15218 .05803 L
.16033 .07908 L
.17676 .11039 L
.21169 .16183 L
.24479 .20379 L
.27663 .24143 L
.31051 .27981 L
.34313 .31576 L
.37449 .34968 L
.40789 .38531 L
.44003 .41924 L
.4742 .45503 L
.50712 .48927 L
.53878 .52204 L
.57247 .55677 L
.60491 .59009 L
.63938 .6254 L
.67259 .65933 L
.70455 .69191 L
.73854 .7265 L
.77127 .75976 L
.80275 .79171 L
.83626 .82567 L
.86851 .85833 L
.90279 .89301 L
.93421 .92476 L
s
.27632 .01328 m
.27713 .03385 L
.27787 .04177 L
.27953 .05439 L
.28252 .07062 L
.28931 .09686 L
.303 .13464 L
.33211 .19338 L
.35969 .23862 L
.38623 .2776 L
.41446 .31613 L
.44164 .35131 L
.46778 .38387 L
.49561 .41752 L
.52239 .44913 L
.55087 .48207 L
.5783 .51329 L
.60468 .54292 L
.63276 .5741 L
.65979 .60382 L
.68852 .63514 L
.71619 .66508 L
.74282 .69372 L
.77115 .724 L
.79843 .75302 L
.82466 .7808 L
.85258 .81027 L
.87946 .83852 L
.90803 .86846 L
.93421 .89582 L
s
.40789 .01329 m
.40854 .03581 L
.40914 .04448 L
.41046 .05826 L
.41286 .07593 L
.41829 .10434 L
.42925 .14473 L
.45253 .20611 L
.4746 .25213 L
.49583 .29092 L
.51841 .32854 L
.54016 .36232 L
.56107 .39314 L
.58333 .42459 L
.60476 .45381 L
.62754 .48395 L
.64948 .51225 L
.67059 .53889 L
.69305 .56673 L
.71468 .59308 L
.73766 .62068 L
.7598 .64692 L
.7811 .67188 L
.80376 .69817 L
.82558 .72324 L
.84657 .74716 L
.86891 .77243 L
.89041 .79658 L
.91327 .82209 L
.93421 .84534 L
s
.53947 .01329 m
.53996 .03581 L
.5404 .04447 L
.5414 .05823 L
.54319 .07585 L
.54727 .10408 L
.55149 .12628 L
.55549 .14397 L
.57295 .20384 L
.58887 .24648 L
.60581 .28561 L
.62212 .31947 L
.6378 .34957 L
.6545 .37964 L
.67057 .40709 L
.68766 .43499 L
.70411 .46083 L
.71994 .4849 L
.73679 .50978 L
.75301 .53313 L
.77024 .55737 L
.78685 .58025 L
.80283 .60186 L
.81982 .62447 L
.83619 .64591 L
.85193 .66625 L
.86868 .68763 L
.88481 .70797 L
.90195 .72936 L
.91847 .74976 L
.93421 .76902 L
s
.67105 .01328 m
.67138 .03383 L
.67167 .04174 L
.67234 .05428 L
.67353 .07034 L
.67625 .09601 L
.67907 .11615 L
.68173 .13216 L
.69337 .18597 L
.70399 .22391 L
.71528 .2584 L
.72615 .28799 L
.7366 .31407 L
.74774 .33993 L
.75845 .36335 L
.76984 .38698 L
.78081 .40872 L
.79137 .42883 L
.8026 .44949 L
.81341 .46876 L
.8249 .48866 L
.83597 .50732 L
.84662 .52486 L
.85795 .54311 L
.86886 .56034 L
.87936 .57661 L
.89053 .59363 L
.90128 .60976 L
.91271 .62664 L
.92372 .64267 L
.93421 .65776 L
s
.80263 .01325 m
.80279 .02917 L
.80294 .03529 L
.80327 .045 L
.80387 .05743 L
.80457 .06851 L
.80523 .07726 L
.80797 .10512 L
.81076 .12674 L
.81379 .14636 L
.81944 .17692 L
.82487 .20187 L
.8301 .22322 L
.83567 .24392 L
.84102 .26234 L
.84672 .28066 L
.8522 .29729 L
.85748 .31251 L
.8631 .328 L
.8685 .34232 L
.87425 .35697 L
.87978 .37061 L
.88511 .38333 L
.89077 .39649 L
.89623 .40882 L
.90148 .42039 L
.90706 .43244 L
.91244 .44378 L
.91815 .45559 L
.92366 .46674 L
.92895 .47728 L
.93421 .48757 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 288},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<@3oool00`000000oooo0?oo
o`0O0?ooo`0404i>CP000000000000000200oooo00@0d=3@04i>CP1>CTh0d=3@8`3oool00`000000
oooo0?ooo`0O0?ooo`040=3@d01>CTh0CTi>0=3@d240oooo00@0hN7Q04i>CP1>CTh0d=3@8@3oool0
0`000000oooo0?ooo`0C0?ooo`00<@3oool00`000000oooo0?ooo`0O0?ooo`030=3@d02=SHd0oooo
0240oooo00@0CTi>0?ooo`3oool0CTi>8P3oool300000200oooo00@0CTi>0?ooo`3oool0CTi>8@3o
ool0101lO7`0lO7a0?ooo`1>CThQ0?ooo`0306QXJ03alO40oooo01<0oooo000a0?ooo`030000003o
ool0oooo0240oooo00<0YjNW0?ooo`3oool08@3oool00`3alO4000000?ooo`0Q0?ooo`0306QXJ000
0000oooo02<0oooo00<0CTi>0?ooo`3oool07`3oool010000000jNWY0?ooo`1>CThQ0?ooo`0308f=
S@3QhN40oooo01<0oooo000a0?ooo`030000003oool0oooo0240oooo00<0jNWY08f=S@3oool0803o
ool00`3@d=0000000;>c/`0R0?ooo`030:NWY`000000oooo0200oooo0P1XJ6P00`1>CTh0d=3@0?oo
o`0P0?ooo`040000002=SHd000000=3@d240oooo0P2m_KdD0?ooo`00<03oool00`2WYjL000000?oo
o`0P0?ooo`0404i>CP3YjNT0jNWY00000280oooo00<0jNWY04i>CP3oool08@3oool00`3@d=000000
0?ooo`0P0?ooo`030;>c/`37alL0oooo0280oooo00<0SHf=0>WYj@3oool08P3oool00`3YjNT0O7al
0?ooo`0C0?ooo`00<@3oool00`1XJ6P0oooo0?ooo`0O0?ooo`040=3@d01>CTh0CTi>0=3@d200oooo
00@0/k>c000000000000/k>c8P3oool00`3alO4000000?ooo`0P0?ooo`040>WYj@00000000000000
0240oooo00@0jNWY06QXJ0000000/k>c803oool3000001@0oooo003o0?ooob40oooo000=0?ooo`03
0000003oool0oooo0?l0oooo4@3oool000d0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`003@3o
ool00`000000oooo0?ooo`3o0?oooa40oooo000=0?ooo`030000003oool0oooo0?l0oooo4@3oool0
00T0oooo100000000`000?l000000000000Q000000030000o`00000000000240000000<0003o0000
000000008P0000000`000?l000000000000Q000000030000o`00000000000240000000<0003o0000
000000008P0000000`000?l000000000000d00000080oooo000=0?ooo`03000000000?l0oooo0240
oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0R0?ooo`030000o`3oool0oooo0240
oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0R0?ooo`030000o`3oool0oooo0240
oooo00<000000?ooo`3oool04P3oool000d0oooo00<000000?ooo`000?l08@3oool00`000?l0oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo0280oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo0280oooo00<0003o0?ooo`3oool08@3oool00`000000oooo
0?ooo`0B0?ooo`003@3oool010000000oooo0?ooo`000?lP0?ooo`030000o`3oool0oooo0240oooo
00<0003o0?ooo`3oool08P3oool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0240oooo
00<0003o0?ooo`3oool08P3oool00`000?l0oooo0?ooo`0f0?ooo`003@3oool01@000000oooo0?oo
o`3oool0003o01l0oooo00<0003o0?ooo`3oool08P3oool00`000?l0oooo0?ooo`0Q0?ooo`030000
o`3oool0oooo0240oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0R0?ooo`030000
o`3oool0oooo03H0oooo000=0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0703o
ool00`000?l0oooo0?ooo`0R0?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool08@3o
ool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0280oooo00<0003o0?ooo`3oool04`3o
ool?0?l001@0oooo000=0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool08@3oool0
0`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool08@3oool0
0`000?l0oooo0?ooo`0?0?oooa<0o`0000<0003o0?l0003o00004`3o000S0?ooo`003@3oool00`00
0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool08@3oool00`00
0?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo01h0oooo0`3o00000`000?l0o`000?l0000?0?l0
01<0oooo00<0003o0?ooo`3oool0=P3oool000d0oooo00<000000?ooo`3oool0VP3ooolE0?l00640
oooo000=0?ooo`030000003oool0oooo08D0oooo5@3o001f0?ooo`003@3oool00`000000oooo0?oo
o`060?ooo`80003oL`3oool:0?l008/0oooo000=0?ooo`030000003oool0oooo00P0oooo00<0003o
0?ooo`3oool0IP3oool:0?l009D0oooo000=0?ooo`030000003oool0oooo00T0oooo00<0003o0?oo
o`3oool0FP3oool;0?l009l0oooo000=0?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3o
ool05`3oool00`000?l0oooo0?ooo`0h0?ooo`P0o`00ZP3oool000d0oooo00<000000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool0
3`3oool50?l000d0oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0Q0?ooo`030000
o`3oool0oooo0240oooo00<0003o0?ooo`3oool0=P3oool000d0oooo00<000000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo0200oooo00<0003o0?ooo`3oool02P3o
ool50?l00180oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3o
ool0oooo0240oooo00<0003o0?ooo`3oool0=P3oool000d0oooo00<000000?ooo`3oool0903oool0
0`000?l0oooo0?ooo`0P0?ooo`030000o`3oool0oooo00D0oooo1@3o000G0?ooo`030000o`3oool0
oooo0240oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0
oooo03H0oooo000=0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool07`3oool00`00
0?l0oooo0?ooo`050?l001`0oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0Q0?oo
o`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool0=P3oool000d0oooo00<000000?ooo`3o
ool09@3oool00`000?l0oooo0?ooo`0L0?ooo`<0o`0000<0003o0?l0003o00008@3oool00`000?l0
oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool08@3oool00`000?l0
oooo0?ooo`0f0?ooo`003@3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0180oooo
00<0003o0?ooo`3oool0603oool40?l000@0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo0280oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo
0?ooo`0f0?ooo`003@3oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0180oooo00<0
003o0?ooo`3oool0503oool30?l000P0oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?oo
o`0Q0?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?oo
o`0e0?ooo`003@3oool00`000000oooo0?ooo`0B0?ooo`030000o`3oool0oooo02D0oooo0`3o000_
0?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0Q
0?ooo`030000o`3oool0oooo01<0oooo3P3o000D0?ooo`003@3oool00`000000oooo0?ooo`0C0?oo
o`030000o`3oool0oooo0280oooo0P3o002Z0?ooo`X0o`008P3oool000d0oooo00<000000?ooo`3o
ool0503oool00`000?l0oooo0?ooo`0O0?ooo`80o`00XP3oool:0?l002`0oooo000=0?ooo`030000
003oool0oooo01D0oooo00<0003o0?ooo`3oool0703oool20?l009/0oooo2@3o000f0?ooo`003@3o
ool00`000000oooo0?ooo`0b0?ooo`80o`00U@3oool80?l003l0oooo000=0?ooo`030000003oool0
oooo02T0oooo00<0003o0?ooo`3oool0103oool20?l00980oooo1@3o00170?ooo`003@3oool00`00
0000oooo0?ooo`0Z0?ooo`040000o`3oool0oooo0?ooo`80o`006P3oool00`000?l0oooo0?ooo`0P
0?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`06
0?ooo`L0o`00503oool00`000?l0oooo0?ooo`0e0?ooo`003@3oool00`000000oooo0?ooo`0[0?oo
o`030000o`3o0000o`0001`0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`0Q0?oo
o`030000o`3oool0oooo0240oooo00<0003o0?l0003o00001@3o000K0?ooo`030000o`3oool0oooo
03D0oooo000=0?ooo`030000003oool0oooo01X0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
003o0?ooo`0N0?ooo`030000o`3oool0oooo0200oooo00<0003o0?ooo`3oool0803oool00`000?l0
oooo0?ooo`0M0?ooo`@0o`0000<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`0e0?ooo`00
3@3oool00`000000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00X0oooo0P3o00020?ooo`030000
o`3oool0oooo01`0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`0P0?ooo`030000
o`3oool0oooo01P0oooo1@3o00040?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool0
=03oool000d0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3o
ool0oooo0200oooo00<0003o0?ooo`3oool04`3oool50?l000T0oooo00<0003o0?ooo`3oool08@3o
ool00`000?l0oooo0?ooo`0d0?ooo`003@3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0L0?ooo`030000o`3oool0
oooo01l0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`0<0?ooo`L0o`003P3oool0
0`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo03@0oooo000=0?ooo`030000003oool0oooo
01h0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo
01l0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`040?ooo`L0o`005@3oool00`00
0?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo03@0oooo000=0?ooo`030000003oool0oooo01l0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`180?ooo`030000o`3oool0oooo0200
oooo00@0003o0?ooo`3oool0oooo0`3o000M0?ooo`030000o`3oool0oooo0200oooo00<0003o0?oo
o`3oool0=03oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`03
0?l0003oool0oooo06`0oooo103o001j0?ooo`001@3oool00`000000oooo0?ooo`050?ooo`@0003o
8@3oool00`3o0000oooo0?ooo`1Y0?ooo`@0o`00OP3oool000D0oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`3oool30000oad0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`1F0?ooo`@0o`00PP3oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0P0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0DP3oool40?l008H0oooo0004
0?ooo`030:NWY`000000oooo00H0oooo00<000000?ooo`3oool02P3oool20000oa<0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo04h0oooo0`3o002:
0?ooo`001@3oool00`1XJ6P0oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo0`000?l?0?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0K0?oo
o`030000o`3oool0oooo01h0oooo00<0003o0?ooo`3oool02`3oool40?l008d0oooo000=0?ooo`03
0000003oool0oooo00l0oooo0`000?l;0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo01h0oooo00<0003o0?ooo`3o
ool0203oool30?l001D0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`0Q0?ooo`03
0000o`3oool0oooo0380oooo000=0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool0
7P3oool00`000?l0oooo0?ooo`050?ooo`80o`00603oool00`000?l0oooo0?ooo`0P0?ooo`030000
o`3oool0oooo0240oooo00<0003o0?ooo`3oool0<P3oool000d0oooo00<000000?ooo`3oool06`3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool06@3o
ool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo0080oooo0`3o000K0?ooo`030000o`3o
ool0oooo0200oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`0b0?ooo`003@3oool0
0`000000oooo0?ooo`0K0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool09P3oool0
0`000?l0oooo0?ooo`0N0?ooo`040000o`3oool0o`000?l001h0oooo00<0003o0?ooo`3oool0803o
ool00`000?l0oooo0?ooo`0P0?ooo`030000o`3oool0oooo0380oooo000=0?ooo`030000003oool0
oooo01L0oooo00@0003o0?ooo`3oool0o`00=`3oool00`000?l0oooo0?ooo`0M0?ooo`030?l00000
0?l0o`000200oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`0P0?ooo`030000o`3o
ool0oooo0380oooo000=0?ooo`030000003oool0oooo01P0oooo0P000?li0?ooo`030000o`3oool0
oooo01X0oooo0P3o00020?ooo`030000o`3oool0oooo01l0oooo00<0003o0?ooo`3oool07`3oool0
0`000?l0oooo0?ooo`0P0?ooo`030000o`3oool0oooo0380oooo000=0?ooo`030000003oool0oooo
01T0oooo00<0o`000000o`000?l0D@3oool30?l000@0oooo00<0003o0?ooo`3oool07`3oool00`00
0?l0oooo0?ooo`0P0?ooo`030000o`3oool0oooo0200oooo00<0003o0?ooo`3oool06@3oool40?l0
01@0oooo000=0?ooo`030000003oool0oooo01P0oooo00D0o`000?ooo`3oool0oooo0000o`0L0?oo
o`030000o`3oool0oooo02l0oooo0P3o001<0?ooo`030000o`3oool0oooo0200oooo00<0003o0?oo
o`3oool04P3oool70?l001P0oooo000=0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3o
ool04P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo02/0oooo0`3o00220?ooo`@0
o`007`3oool000d0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0D0?ooo`030000
o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0:03oool20?l00840oooo103o000S0?ooo`003@3o
ool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo01H0oooo0P000?l:0?ooo`030000o`3o
ool0oooo02D0oooo0`3o001o0?ooo`@0o`009`3oool000d0oooo00<000000?ooo`3oool05P3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo00P0oooo0P3o001m0?ooo`D0o`00:`3oool0
00d0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00`0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo
00D0oooo0P3o000E0?ooo`030000o`3oool0oooo06<0oooo103o000`0?ooo`003@3oool00`000000
oooo0?ooo`0E0?ooo`030?l0003oool0oooo00`0oooo0P000?l<0?ooo`030000o`3oool0oooo00T0
oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`030?ooo`80o`005`3oool00`000?l0
oooo0?ooo`0O0?ooo`030000o`3oool0oooo01l0oooo00<0003o0?ooo`3oool06P3oool50?l003@0
oooo000=0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`0_0?ooo`050000o`3oool0oooo0?ooo`3o00006P3oool00`000?l0oooo0?ooo`0N0?ooo`03
0000o`3oool0oooo01l0oooo00<0003o0?ooo`3oool05P3oool40?l000H0oooo00<0003o0?ooo`3o
ool0<03oool000d0oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`0@0?ooo`80003o
<03oool00`000?l0o`000?l0000K0?ooo`030000o`3oool0oooo01l0oooo00<0003o0?ooo`3oool0
7P3oool00`000?l0oooo0?ooo`0B0?ooo`@0o`002P3oool00`000?l0oooo0?ooo`0`0?ooo`003@3o
ool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0480oooo00<0003o0?ooo`3oool0703o
ool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo01l0oooo00<0003o0?ooo`3oool03P3o
ool30?l000l0oooo00<0003o0?ooo`3oool0;`3oool000d0oooo00<000000?ooo`3oool04`3oool0
0`3o0000oooo0?ooo`110?ooo`80o`0000<0oooo0000o`3oool0703oool00`000?l0oooo0?ooo`0N
0?ooo`030000o`3oool0oooo01l0oooo00<0003o0?ooo`3oool02`3oool30?l00180oooo00<0003o
0?ooo`3oool0;`3oool000d0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0Q0?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0P0?oo
o`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`070?oo
o`@0o`005@3oool00`000?l0oooo0?ooo`0_0?ooo`003@3oool00`000000oooo0?ooo`0C0?ooo`03
0?l0003oool0oooo0280oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0>0?ooo`80
o`008`3oool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo01l0oooo00<0003o0?ooo`3o
ool00P3oool40?l001X0oooo00<0003o0?ooo`3oool0;P3oool000d0oooo00<000000?ooo`3oool0
4`3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo00T0oooo0P000?l80?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0A03oool00`000?l0oooo0?ooo`0O0?ooo`030000
o`3o0000o`000080o`007P3oool00`000?l0oooo0?ooo`0^0?ooo`003@3oool00`000000oooo0?oo
o`0B0?ooo`030?l0003oool0oooo01T0oooo0P000?l;0?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`1V0?ooo`80o`00D`3oool000d0oooo00<00000
0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0K0?ooo`80003o2P3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo00P0oooo0P3o001V0?ooo`<0o`00E@3oool000d0oooo00<000000?oo
o`3oool04P3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo0140oooo0P000?l70?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0E@3oool30?l005P0oooo000=0?ooo`03
0000003oool0oooo0140oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0G0?ooo`80
o`003`3oool00`000?l0oooo0?ooo`1A0?ooo`<0o`00F`3oool000d0oooo00<000000?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0h0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
6P3oool00`000?l0oooo0?ooo`0`0?ooo`<0o`00GP3oool000d0oooo00<000000?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0g0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool06P3o
ool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo00`0oooo0`3o001Q0?ooo`003@3oool0
0`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo02h0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool07@3oool0
0`000?l0oooo0?ooo`0:0?ooo`80o`004`3oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0
oooo02`0oooo000=0?ooo`030000003oool0oooo0100oooo00<0o`000?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool05@3oool00`00
0?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo01h0oooo00<0003o0?ooo`3oool01`3oool20?l0
01D0oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0/0?ooo`003@3oool00`000000
oooo0?ooo`0@0?ooo`030?l0003oool0oooo02H0oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`020?ooo`040?l0003oool0oooo0000oc80oooo00<0003o0?ooo`3oool07@3oool00`00
0?l0oooo0?ooo`050?ooo`80o`00603oool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo
02`0oooo00030?ooo`0404i>CP0000000000000000H0oooo00<000000?ooo`3oool0403oool00`3o
0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo00L0oooo00@0003o0?ooo`3oool0o`00103oool0
0`000?l0oooo0?ooo`0_0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool00`3oool2
0?l001X0oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0[0?ooo`000`3oool00`3@
d=00SHf=0?ooo`070?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool0:@3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3o0000oooo00D0oooo00<0003o0?ooo`3oool0;`3oool00`00
0?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo0080o`00703oool00`000?l0oooo0?ooo`0O0?oo
o`030000o`3oool0oooo02/0oooo00050?ooo`030:NWY`3oool0oooo00D0oooo20000?l:0?ooo`03
0?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool01P3oool00`3o0000003o0?ooo`060?ooo`03
0000o`3oool0oooo04h0oooo00<0003o0?l0003o00007`3oool00`000?l0oooo0?ooo`0O0?ooo`03
0000o`3oool0oooo02X0oooo00050?ooo`030>WYj@2=SHd0oooo00D0oooo00<000000?ooo`3oool0
2P3oool50000o`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo04`0oooo0P3o000Q0?ooo`030000o`3oool0oooo01l0oooo
00<0003o0?ooo`3oool0:P3oool000<0oooo00@0CTi>0>WYj@3YjNT000001P3oool00`000000oooo
0?ooo`0?0?ooo`<0003o<@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0180oooo
00<0003o0?ooo`3oool0<`3oool30?l004D0oooo00<0003o0?ooo`3oool0:P3oool000<0oooo00@0
d=3@04i>CP1>CTh0d=3@1P3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0340oooo
00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`0`0?ooo`80o`00M@3oool000d0oooo00<0
00000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0`0?ooo`030?l0003oool0oooo0280oooo00<0
003o0?ooo`3oool0;P3oool20?l007L0oooo000=0?ooo`030000003oool0oooo00h0oooo00<0o`00
0?ooo`3oool01`3oool20000obH0oooo00<0o`000?ooo`000?l0203oool00`000?l0oooo0?ooo`0I
0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool03`3oool20?l007T0oooo000=0?oo
o`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool02@3oool30000ob<0oooo00@0o`000?oo
o`3oool0003o203oool00`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo01P0oooo00<0003o
0?ooo`3oool03@3oool20?l007/0oooo000=0?ooo`030000003oool0oooo00d0oooo00<0o`000?oo
o`3oool03@3oool20000ob00oooo00<0o`000?ooo`3oool00P3oool20000o`L0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?oo
o`3oool02P3oool20?l000l0oooo00<0003o0?ooo`3oool0J`3oool000d0oooo00<000000?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0^0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3o
ool0603oool00`000?l0oooo0?ooo`080?ooo`80o`004P3oool00`000?l0oooo0?ooo`0M0?ooo`03
0000o`3oool0oooo01l0oooo00<0003o0?ooo`3oool0:03oool000d0oooo00<000000?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`0]0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`80003o;@3oool00`000?l0oooo0?ooo`050?ooo`80o`00
503oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo01l0oooo00<0003o0?ooo`3oool0
:03oool000d0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0D0?ooo`80003o5P3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00<0oooo0P3o000G0?ooo`030000o`3o
ool0oooo01d0oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0A0?ooo`80o`00503o
ool000d0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0G0?ooo`80003o4`3oool0
0`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo02/0oooo00<0003o0?ooo`3oool00P3o000I
0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0=
0?ooo`@0o`005P3oool000d0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0I0?oo
o`80003o4@3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo02`0oooo00<0o`000?oo
o`3oool06P3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo01h0oooo00<0003o0?oo
o`3oool02P3oool30?l001X0oooo000=0?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3o
ool06`3oool20000o`h0oooo00<0o`000?ooo`3oool0<03oool00`000?l0oooo0?ooo`0F0?ooo`80
o`007@3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo01l0oooo00<0003o0?ooo`3o
ool01`3oool20?l001d0oooo000=0?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3oool0
:P3oool00`3o0000oooo0?ooo`0b0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0
?P3oool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo00D0oooo0P3o000O0?ooo`003@3o
ool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo02T0oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool04@3o
ool20?l006<0oooo00@0003o0?ooo`3oool0oooo0`3o000Q0?ooo`003@3oool00`000000oooo0?oo
o`0;0?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`0B0?ooo`80003o1`3oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo0100oooo00<0
o`000?ooo`3oool0H`3oool40?l002@0oooo000=0?ooo`030000003oool0oooo00/0oooo00<0o`00
0?ooo`3oool0903oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo01D0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00l0oooo00<0003o
0?ooo`3oool03@3oool20?l000P0oooo00<0003o0?ooo`3oool0F03oool30?l002P0oooo000=0?oo
o`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool09@3oool20000o`030?ooo`3o0000oooo
01P0oooo0P000?l50?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0E@3oool20?l0
02/0oooo000=0?ooo`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool09`3oool00`000?l0
o`000?ooo`0J0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`0@0?ooo`030000o`3oool0oooo00P0oooo0P3o000<0?ooo`030000o`3oool0oooo01/0
oooo00<0003o0?ooo`3oool0=@3oool20?l002d0oooo000=0?ooo`030000003oool0oooo00/0oooo
00<0o`000?ooo`3oool09`3oool00`3o0000003o0?ooo`0Q0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01X0oooo
00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`0C0?ooo`80o`00;`3oool000d0oooo00<0
00000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0W0?ooo`030?l0003oool0oooo02T0oooo00<0
003o0?ooo`3oool05P3oool20?l00140oooo00<0003o0?ooo`3oool06P3oool00`000?l0oooo0?oo
o`0L0?ooo`030000o`3oool0oooo0140oooo0P3o000;0?ooo`030000o`3oool0oooo02<0oooo000=
0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool09`3oool00`3o0000oooo0?ooo`0[
0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0J
0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool03P3oool20?l000h0oooo00<0003o
0?ooo`3oool08P3oool000d0oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0V0?oo
o`030?l0003oool0oooo0480oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0J0?oo
o`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool0303oool20?l00100oooo00<0003o0?oo
o`3oool08P3oool000d0oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0V0?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0603oool00`000?l0oooo0?ooo`0L0?ooo`03
0000o`3o0000oooo0380oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`080?ooo`<0
o`004P3oool00`000?l0oooo0?ooo`0R0?ooo`003@3oool00`000000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo02D0oooo00<0o`000?ooo`3oool0203oool20000oaT0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0E0?ooo`030?l000000?l0oooo03<0oooo00<0003o0?ooo`3oool0
703oool00`000?l0oooo0?ooo`060?ooo`80o`005P3oool00`000?l0oooo0?ooo`0Q0?ooo`003@3o
ool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool02P3o
ool20000oaP0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0B0?ooo`80o`000P3o
ool00`000?l0oooo0?ooo`1A0?ooo`030000o`3oool0oooo00<0oooo0P3o000H0?ooo`030000o`3o
ool0oooo0240oooo000=0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool0903oool0
0`3o0000oooo0?ooo`0=0?ooo`80003o5`3oool00`000?l0oooo0?ooo`030?ooo`80003o1@3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0E03oool3
0?l001/0oooo00<0003o0?ooo`3oool0803oool000d0oooo00<000000?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo02L0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo03T0oooo0P3o00110?ooo`003@3oool00`000000
oooo0?ooo`090?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool0=P3oool20?l004<0
oooo000=0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo
0?ooo`0g0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo
0?ooo`0d0?ooo`80o`00A@3oool000d0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0S0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0803oool01@000?l0oooo0?oo
o`3oool0o`0002<0oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`0E0?ooo`80o`00
A`3oool000d0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003o
ool0oooo01L0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?l0000U0?ooo`030000o`3o
ool0oooo01T0oooo00<0003o0?ooo`3oool04P3oool20?l004T0oooo000=0?ooo`030000003oool0
oooo00T0oooo00<0o`000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0
oooo01@0oooo00<0003o0?ooo`3oool0203oool20?l002H0oooo00<0003o0?ooo`3oool06@3oool0
0`000?l0oooo0?ooo`0@0?ooo`80o`002P3oool00`000?l0oooo0?ooo`0n0?ooo`000`3oool0103@
d=00CTi>04i>CP3@d=060?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool08P3oool0
0`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00`3oool0
10000?l0oooo0?ooo`3o000Y0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool07P3o
ool000<0oooo00@0CTi>0?ooo`3oool0CTi>1P3oool00`000000oooo0?ooo`090?ooo`030?l0003o
ool0oooo0280oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?l0003oool04`3oool00`000?l0oooo0?ooo`0_0?ooo`030000o`3o
ool0oooo00`0oooo0P3o000>0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool07@3o
ool000D0oooo00<0lO7a0000003oool01@3oool80000o`@0oooo00<0o`000?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000003o0?ooo`0D0?ooo`030000o`3oool0oooo02l0oooo00<0003o0?ooo`3oool02@3oool2
0?l00140oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`0L0?ooo`00103oool00`3@
d=0000000;>c/`060?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`000?l00`000?lO0?oo
o`030?l0003oool0oooo03D0oooo00@0003o0?ooo`3oool0o`000P3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0<03oool00`000?l0oooo0?ooo`06
0?ooo`80o`004`3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo01`0oooo00050?oo
o`030>WYj@1>CTh0oooo00D0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`030?oo
o`@0003o6`3oool00`3o0000oooo0?ooo`0f0?ooo`030000o`3o0000oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo03L0oooo00<0o`000?oo
o`3oool0503oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo01/0oooo00030?ooo`04
0;>c/`00000000000;>c/`H0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0d0?oo
o`80o`005`3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo01/0oooo000=0?ooo`03
0000003oool0oooo00P0oooo00<0o`000?ooo`3oool03P3oool40000o`l0oooo00<0o`000?ooo`3o
ool0903oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo01/0oooo0P3o000i0?ooo`03
0000o`3oool0oooo01/0oooo000=0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0
4P3oool30000o`/0oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool08`3oool00`000?l0oooo0?ooo`0H0?ooo`80o`00
F@3oool000d0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0P0?ooo`030?l0003o
ool0oooo02L0oooo0P000?l<0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool08`3o
ool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo05T0oooo000=0?ooo`030000003oool0
oooo00P0oooo00<0o`000?ooo`3oool06P3oool20000o`@0oooo00<0o`000?ooo`3oool0:@3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0;@3oool0
0`000?l0oooo0?ooo`0D0?ooo`80o`000`3oool00`000?l0oooo0?ooo`1F0?ooo`003@3oool00`00
0000oooo0?ooo`080?ooo`030?l0003oool0oooo01`0oooo0P000?l00`3oool0o`000?ooo`0/0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo02L0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo05H0oooo000=0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3o
ool07P3oool20000ocH0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo0180oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0h0?ooo`00
3@3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo01h0oooo00@0o`000?ooo`000?l0
003o<`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0S0?ooo`80o`00203oool00`000?l0oooo0?ooo`0K0?ooo`03
0000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool0603oool000d0oooo00<000000?ooo`3oool0
203oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo03<0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
303oool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
6`3oool00`000?l0oooo0?ooo`0L0?ooo`030000o`3oool0oooo01L0oooo000=0?ooo`030000003o
ool0oooo00P0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo02T0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0N0?ooo`80o`00303o
ool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool05`3o
ool000d0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0
oooo00P0oooo0P000?lY0?ooo`030?l000000?l0oooo01H0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool05P3oool0
00d0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo
00X0oooo0P000?lV0?ooo`030?l0003oool0oooo0080003o6`3oool00`000?l0oooo0?ooo`0;0?oo
o`030000o`3oool0oooo01X0oooo0P3o000^0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?oo
o`3oool05P3oool000d0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0M0?ooo`03
0?l0003oool0oooo00d0oooo0P000?lS0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool06@3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo01<0oooo00@0003o0?ooo`3o
ool0oooo0P3o000a0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool05@3oool000d0
oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo0380
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?l0001B0?ooo`030000o`3oool0oooo01D0
oooo000=0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo
0?ooo`0a0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo
0?ooo`0[0?ooo`030000o`3oool0oooo0540oooo00<0003o0?ooo`3oool05@3oool000d0oooo00<0
00000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo01D0oooo0P00
0?lJ0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0T0?ooo`030?l000000?l0oooo01P0oooo00<0003o0?ooo`3oool0C`3oool000d0oooo00<00000
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo01L0oooo0P000?lH
0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0Q
0?ooo`80o`000P3oool00`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo04h0oooo000=0?oo
o`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0J0?oo
o`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo01H0oooo00<0003o0?ooo`3oool0CP3oool000d0oooo00<000000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo01/0oooo0P000?lC0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03`3oool01@000?l0oooo0?ooo`3oool0003o
00D0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
01h0oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`0K0?ooo`80o`00503oool000d0
oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo01d0
oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01<0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo01P0
oooo0P3o000F0?ooo`003@3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo01X0oooo
00<0o`000?ooo`3oool0<03oool00`3o0000oooo0?ooo`0@0?ooo`80003o503oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool01P3oool20?l002<0oooo
00<0003o0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0E0?ooo`80o`00603oool000d0oooo00<0
00000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0oooo02l0oooo00<0
o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo00X0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo01T0oooo00<0
003o0?ooo`3oool04`3oool20?l001X0oooo000=0?ooo`030000003oool0oooo00L0oooo00<0o`00
0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0503oool20000oaT0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0480oooo00<0003o0?ooo`3oool0403oool20?l001`0oooo000=0?oo
o`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`0U0?oo
o`80003o1`3oool00`3o0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool0303oool20?l00100oooo00<0003o0?ooo`3oool0<P3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo01`0oooo000=0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3o
ool06@3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0:@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool0<P3oool00`000?l0oooo0?ooo`0<0?ooo`80o`007`3oool000d0oooo00<000000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo02T0oooo0P000?l30?ooo`030?l0
003oool0oooo02X0oooo00D0003o0?ooo`3oool0oooo0000o`0@0?ooo`030?l0003oool0oooo0180
oooo00<0003o0?ooo`3oool0?`3oool20?l00240oooo000=0?ooo`030000003oool0oooo00L0oooo
00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0o`0002h0oooo
00@0003o0?ooo`3oool0oooo0P000?l=0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3o
ool0?@3oool00`3o0000oooo0?ooo`0Q0?ooo`003@3oool00`000000oooo0?ooo`070?ooo`030?l0
003oool0oooo01P0oooo00<0o`000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0N0?ooo`030000
o`3oool0oooo00d0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0F0?ooo`030000
o`3oool0oooo0240oooo0P3o000T0?ooo`003@3oool00`000000oooo0?ooo`060?ooo`030?l0003o
ool0oooo01T0oooo00<0o`000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3o
ool0oooo00d0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`80003o103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo
0?ooo`0N0?ooo`80o`009P3oool000d0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0I0?ooo`030?l0003oool0oooo02`0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0L0?ooo`80003o4P3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l000T0oooo
00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo02H0oooo
000=0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?oo
o`0/0?ooo`030?l0003oool0oooo00<0oooo0P000?lN0?ooo`030000o`3oool0oooo0100oooo00<0
003o0?ooo`3oool00`3oool00`000?l0o`000?ooo`090?ooo`030000o`3oool0oooo02T0oooo00<0
003o0?ooo`3oool0603oool010000?l0oooo0?l0003o000Y0?ooo`003@3oool00`000000oooo0?oo
o`060?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool0;03oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?oo
o`0:0?ooo`030000o`3oool0oooo02P0oooo00<0003o0?ooo`3oool0603oool00`3o0000003o0?oo
o`0Z0?ooo`001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0o`00
0?ooo`3oool0603oool00`3o0000oooo0?ooo`0[0?ooo`030?l0003oool0oooo00P0oooo0P000?lc
0?ooo`030?l0003oool0003o00`0oooo00<0003o0?ooo`3oool0:03oool20000oaH0oooo0P3o0000
0`3oool0003o0?ooo`0Z0?ooo`00103oool3000000H0oooo20000?l00`3oool0o`000?ooo`0I0?oo
o`030?l0003oool0oooo02/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0Z0?oo
o`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`0P0?ooo`030000o`3oool0
oooo02X0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0X0?ooo`00103oool00`1X
J6P000000?ooo`060?ooo`030000003oool0oooo00H0oooo00@0o`000?ooo`3oool0oooo1P000?lA
0?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool0>@3oool01P000?l0oooo0?ooo`3o
0000oooo0000ob@0oooo00<0003o0?ooo`3oool09`3oool20?l000H0oooo00<0003o0?ooo`3oool0
9`3oool000@0oooo00<0YjNW0000003oool01P3oool00`000000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00L0oooo0P000?l>0?ooo`030?l0003oool0oooo02/0oooo00<0o`000?ooo`3oool0>P3o
ool20000o`<0oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0V0?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool09`3oool000@0oooo00<0d=3@0000003oool01P3oool0
0`000000oooo0?ooo`060?ooo`030?l0003oool0oooo00l0oooo10000?l40?ooo`030?l0003oool0
oooo02X0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
003o00<0oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool09P3oool000@0oooo00<0lO7a0000003oool01P3oool00`00
0000oooo0?ooo`060?ooo`030?l0003oool0oooo01<0oooo10000?l00`3o0000oooo0?ooo`0Z0?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`090?oo
o`050?l0003oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0
oooo0100oooo00<0003o0?ooo`3oool08@3oool20?l003@0oooo000=0?ooo`030000003oool0oooo
00H0oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo
01@0oooo0P000?lJ0?ooo`80003o203oool00`3o0000oooo0?ooo`070?ooo`050000o`3oool0oooo
0?ooo`000?l0303oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo01D0oooo00<0003o
0?ooo`3oool01`3oool20?l003H0oooo000=0?ooo`030000003oool0oooo00H0oooo00<0o`000?oo
o`3oool05P3oool00`3o0000oooo0?ooo`040?ooo`80003o903oool00`3o0000oooo0?ooo`0F0?oo
o`80003o6P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00T0oooo00D0003o0?oo
o`3oool0oooo0000o`0;0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool05@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo03H0oooo000=0?ooo`030000003oool0oooo
00H0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`060?ooo`<0003o803oool00`3o
0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01P0oooo0P000?l30?ooo`030?l0003oool0oooo
00l0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0W0?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0=`3oool000d0oooo00<000000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`0F0?ooo`030?l0003oool0oooo00T0oooo0P000?lN0?ooo`030?l0003oool0oooo01X0
oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00T0
oooo00<0003o0?ooo`3oool09`3oool010000?l0oooo0?ooo`3oool20?l001D0oooo00<0003o0?oo
o`3oool08P3oool000d0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo02P0oooo00<0o`000?ooo`3oool0>03oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0X0?ooo`03
0000o`3oool0o`0001L0oooo00<0003o0?ooo`3oool08P3oool000d0oooo00<000000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo0140oooo0P000?lE0?ooo`030?l0
003oool0oooo03P0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00P0oooo00<0003o0?ooo`3oool09`3oool00`000?l0o`000?ooo`0H0?ooo`030000
o`3oool0oooo0240oooo000=0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool05`3o
ool00`3o0000oooo0?ooo`0C0?ooo`<0003o4@3oool00`3o0000oooo0?ooo`0h0?ooo`030?l0003o
ool0oooo00h0oooo00D0003o0?ooo`3oool0oooo0000o`0Q0?ooo`030000o`3oool0oooo0180oooo
0P3o00000`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo0240oooo000=0?ooo`030000003o
ool0oooo00D0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`0G0?ooo`80003o3`3o
ool00`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0;0?ooo`050000o`3oool0oooo0?ooo`000?l08@3oool00`000?l0oooo
0?ooo`0@0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool0803oool000d0oooo00<0
00000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo02L0oooo00<0
o`000?ooo`3oool08`3oool20000oa80oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`0;0?ooo`050000o`3oool0oooo0?ooo`000?l0803oool00`000?l0oooo0?ooo`0>0?ooo`80o`00
7P3oool00`000?l0oooo0?ooo`0P0?ooo`003@3oool00`000000oooo0?ooo`050?ooo`030?l0003o
ool0oooo01H0oooo00<0o`000?ooo`3oool09`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0;0?ooo`050000o`3o
ool0oooo0?ooo`000?l0803oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo01l0oooo
00<0003o0?ooo`3oool07`3oool000d0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`0F0?ooo`030?l0003oool0oooo01l0oooo0P000?l50?ooo`030?l0003oool0oooo02L0oooo0P00
0?l>0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool03`3oool01@000?l0oooo0?oo
o`3oool0003o00X0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo0480oooo000=0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool05P3o
ool00`3o0000oooo0?ooo`0Q0?ooo`80003o0`3oool00`3o0000oooo0?ooo`0Y0?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0?0?ooo`050000o`3o
ool0oooo0?ooo`000?l02P3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00L0oooo
0P3o000;0?ooo`030000o`3oool0oooo03L0oooo000=0?ooo`030000003oool0oooo00D0oooo00<0
o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`0T0?ooo`80003o00<0o`000?ooo`3oool0=P3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0g0?ooo`003@3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0
oooo01D0oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`0e0?ooo`030?l0003oool0
oooo0280oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool0=P3oool000d0oooo00<000000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool0=@3oool00`3o
0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0=@3oool000d0
oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo02D0
oooo00<0o`000?ooo`3oool0<03oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo01d0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0100
oooo0P3o000B0?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool06`3oool000d0oooo
00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo02D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0Z0?ooo`80003o00<0oooo0?l0003oool0
503oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
7@3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool0
6P3oool000d0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003o
ool0oooo02D0oooo00<0o`000?ooo`3oool01P3oool20000ob`0oooo00<0003o0?l0003oool05@3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool06`3o
ool00`3o0000oooo0000o`0E0?ooo`030000o`3oool0oooo01H0oooo00<0003o0?ooo`3oool06P3o
ool000d0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0
oooo02D0oooo00<0o`000?ooo`3oool0203oool20000obX0oooo00<0o`000000o`000?l05P3oool2
0000o`X0oooo00D0003o0?ooo`3oool0oooo0000o`0L0?ooo`050?l0003oool0oooo0?ooo`000?l0
;P3oool00`000?l0oooo0?ooo`0I0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030?l0003o
ool0oooo01D0oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0:0?ooo`80003o9`3o
ool01@3o0000oooo0?ooo`3oool0003o01L0oooo00<0003o0?ooo`3oool0203oool01@000?l0oooo
0?ooo`3oool0003o01X0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0/0?ooo`03
0000o`3oool0oooo01P0oooo000=0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0
5@3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo03@0oooo00<0o`000?ooo`3oool0
6@3oool00`000?l0oooo0?ooo`0=0?ooo`050000o`3oool0oooo0?ooo`000?l02P3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0;03oool00`000?l0
oooo0?ooo`0H0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo01D0oooo
00<0o`000?ooo`3oool0903oool00`3o0000oooo0?ooo`0c0?ooo`030?l0003oool0oooo01/0oooo
00<0003o0?ooo`3oool03@3oool20000o`80oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0;03oool00`000?l0oooo
0?ooo`0G0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo01D0oooo00<0
o`000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo01`0oooo00<0
o`000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo02l0oooo000=
0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`0T
0?ooo`030?l0003oool0oooo01D0oooo0P000?lK0?ooo`030?l0003oool0oooo00T0oooo0P000?lX
0?ooo`030000o`3oool0oooo00P0oooo00D0003o0?ooo`3oool0oooo0?l0000R0?ooo`030000o`3o
ool0oooo02h0oooo000=0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0503oool0
0`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo01P0oooo0P000?lI0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo00P0oooo00<0003o0?l0003o00008`3oool00`000?l0oooo0?ooo`0^0?ooo`003@3oool00`00
0000oooo0?ooo`040?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool08`3oool00`3o
0000oooo0?ooo`0J0?ooo`80003o5P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
01<0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
00L0oooo00<0o`000000o`3oool0903oool00`000?l0oooo0?ooo`0]0?ooo`003@3oool00`000000
oooo0?ooo`040?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool08`3oool00`3o0000
oooo0?ooo`0a0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool04`3oool00`000?l0
oooo0?ooo`080?ooo`80003o0P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo02H0
oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`0C0?ooo`003@3oool00`000000oooo
0?ooo`040?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo
0?ooo`0b0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo
0?ooo`090?ooo`040000o`3oool0oooo0000o`T0oooo00<0o`000?ooo`3oool04`3oool00`000?l0
oooo0?ooo`0A0?ooo`030000o`3oool0oooo01H0oooo00<0003o0?ooo`3oool04`3oool000d0oooo
00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0280oooo
00<0o`000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo01<0oooo
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`020000o`H0oooo00<0o`000?ooo`3oool0
5@3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo01H0oooo00<0003o0?ooo`3oool0
4P3oool000d0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003o
ool0oooo0280oooo00<0o`000?ooo`3oool08`3oool20000o``0oooo00<0o`000?ooo`3oool0:P3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool05`3o
ool00`000?l0oooo0?ooo`0n0?ooo`000`3oool0103@d=00CTi>04i>CP3@d=060?ooo`030000003o
ool0oooo00@0oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003o
ool0oooo02D0oooo0P000?l:0?ooo`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool03@3o
ool010000?l0oooo0?ooo`000?l:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0
?P3oool000<0oooo00@0CTi>0?ooo`3oool0CTi>1P3oool00`000000oooo0?ooo`040?ooo`030?l0
003oool0oooo01<0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0W0?ooo`80003o
1`3oool00`3o0000oooo0?ooo`0l0?ooo`050000o`3oool0o`000?ooo`000?l02P3oool00`000?l0
oooo0?ooo`0=0?ooo`030000o`3oool0oooo03d0oooo00060?ooo`0304i>CP3oool0oooo00@0oooo
20000?l50?ooo`@0003o303oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo02X0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo0240oooo
00@0o`000?ooo`3oool0oooo0P000?l90?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o
ool0?03oool000<0oooo0P1XJ6P00`1>CTh0d=3@0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<0o`000?ooo`3oool01`3oool40000o`P0oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo
0?ooo`0_0?ooo`030?l0003oool0oooo01`0oooo0P000?lO0?ooo`030000o`3o0000oooo00D0oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo01<0oooo
00<0003o0?ooo`3oool09P3oool000<0oooo00<0/k>c0<O7a`3oool01`3oool00`000000oooo0?oo
o`040?ooo`030?l0003oool0oooo0140oooo1@000?lP0?ooo`030?l0003oool0oooo0300oooo00<0
o`000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0L0?ooo`030?l000000?l0oooo00H0oooo00<0
003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0R0?ooo`030000o`3oool0oooo02D0oooo0003
0?ooo`040>WYj@0000000000000000H0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?oo
o`0B0?ooo`040?l0003oool0oooo0?ooo`<0003o7@3oool00`3o0000oooo0?ooo`0_0?ooo`030?l0
003oool0oooo0200oooo0P000?lC0?ooo`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3oool0
003o4@3oool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo02D0oooo000=0?ooo`030000
003oool0oooo00@0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0:0?ooo`80003o
5@3oool00`3o0000oooo0?ooo`0^0?ooo`030?l0003oool0003o02<0oooo00<0003o0?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0
003o<P3oool00`000?l0oooo0?ooo`0T0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030?l0
003oool0oooo0180oooo00<0o`000?ooo`3oool0303oool30000oa40oooo00<0o`000?ooo`3oool0
;P3oool0103o0000oooo0?ooo`3oool20000ocH0oooo00D0003o0?ooo`3oool0oooo0?l000060?oo
o`040000o`3oool0oooo0000oc80oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0B
0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo0180oooo00<0o`000?oo
o`3oool03`3oool20000o`l0oooo00<0o`000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo03@0oooo00<0003o0?ooo`3o0000203oool00`000?l0oooo0?ooo`020000
oa`0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0<0?ooo`80o`005@3oool000d0
oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo0200
oooo00<0o`000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`050?ooo`80003o=@3oool20000o`d0
oooo00D0003o0?ooo`3oool0oooo0000o`0H0?ooo`030000o`3oool0oooo0140oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`0E0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`03
0?l0003oool0oooo0180oooo00<0o`000?ooo`3oool05`3oool30000o`D0oooo00<0o`000?ooo`3o
ool0;@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo0340oooo00<0o`000?ooo`3o
ool03P3oool01@000?l0oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo01H0oooo000=0?ooo`030000003oool0oooo00<0
oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0J0?ooo`@0003o00<0oooo0?l0003o
ool0;P3oool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool0503oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3o
ool06`3oool00`3o0000oooo0?ooo`0G0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030?l0
003oool0oooo0180oooo00<0o`000?ooo`3oool07`3oool00`000?l0o`000?ooo`0]0?ooo`030?l0
003oool0oooo02d0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0E0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0H0?ooo`80o`00
6P3oool000d0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003o
ool0oooo0200oooo00<0o`000?ooo`3oool0;03oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo01`0oooo0P000?l:0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool05P3o
ool00`3o0000oooo0?ooo`0J0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0
oooo0180oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`030?ooo`80003o9`3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0200oooo00@0003o0?ooo`3o0000o`007@3o
ool000d0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0
oooo01l0oooo00<0o`000?ooo`3oool01@3oool40000ob<0oooo00<0o`000?ooo`3oool04P3oool2
0000oah0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`0<0?ooo`030000o`3oool0oooo0200oooo00<0
003o0?ooo`3oool07@3oool000d0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0B
0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool02@3oool20000ob00oooo00<0o`00
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool0003o02d0oooo00<0o`000000o`3oool07P3o
ool000d0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0
oooo01h0oooo00<0o`000?ooo`3oool0;03oool00`3o0000oooo0?ooo`0F0?ooo`80003o8@3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000
o`0[0?ooo`040?l0003oool0oooo0000oah0oooo000=0?ooo`030000003oool0oooo00<0oooo00<0
o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo02/0oooo00<0
o`000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00L0oooo00D0
003o0?ooo`3oool0oooo0000o`0K0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0K0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030?l0003o
ool0oooo0140oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0A0?ooo`@0003o5P3o
ool00`3o0000oooo0?ooo`0h0?ooo`030?l0003oool0003o0140oooo00<0003o0?ooo`3oool02`3o
ool010000?l0oooo0?ooo`000?lH0?ooo`030000o`3oool0oooo00P0oooo0P3o00060?ooo`030000
o`3oool0oooo01X0oooo000=0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo01H0oooo0P000?lC0?ooo`030?l0003o
ool0oooo03T0oooo00@0o`000?ooo`3oool0003o7`3oool010000?l0oooo0?ooo`000?l90?ooo`03
0000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0S0?ooo`00
3@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0
7P3oool00`3o0000oooo0?ooo`0H0?ooo`80003o4@3oool00`3o0000oooo0?ooo`0O0?ooo`030000
o`3oool0oooo01H0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0P0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo02@0oooo000=0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool0803o
ool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0803o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`0U0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0
oooo0140oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0Y0?ooo`030?l0003oool0
oooo0280oooo0P000?lD0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool06@3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool02`3oool0
1@000?l0oooo0?ooo`3oool0o`0002P0oooo000=0?ooo`030000003oool0oooo00<0oooo00<0o`00
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo0200oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0T0?ooo`80003o4P3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?l0000Y
0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0100oooo00<0o`000?oo
o`3oool07P3oool00`3o0000oooo0?ooo`0Q0?ooo`80003o1P3oool00`3o0000oooo0?ooo`0W0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`070?oo
o`050000o`3oool0oooo0?ooo`000?l02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool05@3oool000d0oooo00<000000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool08`3oool20000
o`@0oooo00<0o`000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo
00L0oooo0P000?l20?ooo`030000o`3oool0oooo01D0oooo0P3o000D0?ooo`030000o`3oool0oooo
01@0oooo000=0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0403oool00`3o0000
oooo0?ooo`0M0?ooo`030?l0003oool0oooo02H0oooo0P000?l00`3oool0o`000?ooo`0h0?ooo`03
0?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool0203oool010000?l0oooo0?ooo`000?lE0?oo
o`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0503oool000d0oooo00<000000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3o
ool0:@3oool00`3o0000oooo0?ooo`0f0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool03P3oool20000o``0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0F0?ooo`03
0000o`3oool0oooo01<0oooo000=0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0
403oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo02P0oooo00<0o`000?ooo`3oool0
;`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
703oool010000?l0oooo0?ooo`000?l>0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0B0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030?l0
003oool0oooo0100oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`0Y0?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool0:`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo01<0oooo0P000?lM0?ooo`040000o`3oool0oooo0000o`P0oooo00D0003o0?ooo`3o
ool0oooo0?l000090?ooo`030000o`3oool0oooo02@0oooo000=0?ooo`030000003oool0oooo00<0
oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo02P0
oooo00<0o`000?ooo`3oool0103oool20000ob`0oooo0P000?l20?ooo`030?l0003oool0oooo01H0
oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0o`0000/0
oooo00<0003o0?ooo`3oool08`3oool000d0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`0@0?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool0:03oool00`3o0000oooo
0?ooo`060?ooo`80003o;03oool00`000?l0o`000?ooo`0I0?ooo`030000o`3oool0oooo01P0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00/0oooo
00<0003o0?ooo`3oool08P3oool000d0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0@0?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool09`3oool00`3o0000oooo0?oo
o`090?ooo`80003o:P3oool00`3o0000003o0?ooo`0I0?ooo`030000o`3oool0oooo00l0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`000?l03@3oool00`000?l0oooo0?ooo`0Q0?ooo`003@3oool00`000000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`0X
0?ooo`030?l0003oool0oooo03D0oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0oooo0P3o00030?ooo`030000o`3o
ool0oooo00/0oooo00<0003o0?ooo`3oool0803oool000d0oooo00<000000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool09`3oool0
0`3o0000oooo0?ooo`0e0?ooo`030?l0003oool0oooo02h0oooo00<0003o0?ooo`3oool01P3oool0
10000?l0oooo0?ooo`000?l50?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0;@3o
ool000<0oooo00@0hN7Q04i>CP1>CTh0d=3@1P3oool00`000000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00l0oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`0W0?ooo`030?l0003o
ool0oooo03@0oooo00<0o`000?ooo`3oool0<03oool00`000?l0oooo0?ooo`060?ooo`80003o00<0
oooo0000o`3oool00P3oool00`3o0000oooo0?ooo`0e0?ooo`000`3oool0101lO7`0lO7a0?ooo`1>
CTh60?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?oo
o`0L0?ooo`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3oool04P3oool20000oal0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo00d0oooo00<0
003o0?ooo`3oool01`3oool00`000?l0oooo0000o`020?ooo`030?l0003oool0oooo03D0oooo0003
0?ooo`040000003YjNT0oooo04i>CPH0oooo20000?l50?ooo`80003o2@3oool00`3o0000oooo0?oo
o`0K0?ooo`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3oool05@3oool20000oad0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo00d0oooo00<0
003o0?ooo`3oool02@3oool00`000?l0o`000?ooo`0g0?ooo`000`3oool010000000SHf=0000003@
d=060?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool60000o`<0oooo00<0
o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0W0?ooo`030?l0003oool0oooo01L0oooo0P00
0?lJ0?ooo`030?l0003oool0oooo00X0oooo0P000?lI0?ooo`030000o`3oool0oooo01P0oooo00<0
o`000000o`3oool00P3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo01`0oooo0003
0?ooo`0308f=S@3YjNT0oooo00L0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0@
0?ooo`030?l0003oool0oooo00L0003o503oool00`3o0000oooo0?ooo`0W0?ooo`030?l0003oool0
oooo01T0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo01L0oooo00<0003o0?ooo`3oool05P3oool0103o0000oooo0?ooo`000?l30?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0K0?ooo`000`3oool0
103YjNT0J6QX0000002c/k<60?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0403o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool09P3o
ool00`3o0000oooo0?ooo`0c0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool05`3o
ool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo01X0oooo000=0?ooo`030000003oool0
oooo0080oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`D0003o1`3oool0
0`3o0000oooo0?ooo`0W0?ooo`030?l0003oool0oooo0380oooo00<0o`000?ooo`3oool0:P3oool0
0`000?l0oooo0?ooo`0>0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?oo
o`0I0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo0100oooo00<0o`00
0?ooo`3oool04`3oool30000o`@0oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0Q
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0?@3oool00`000?l0oooo0?l00005
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0;
0?ooo`030000o`3oool0oooo01P0oooo000=0?ooo`030000003oool0oooo0080oooo00<0o`000?oo
o`3oool0403oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0oooo02H0oooo00<0o`000?oo
o`3oool08P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo03h0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0G0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`03
0?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool06`3oool00`3o0000003o0000o`020000ob@0
oooo00<0o`000?ooo`3oool08`3oool20000o``0oooo00<0o`000?ooo`3oool05`3oool00`000?l0
oooo0?ooo`0T0?ooo`030?l0003oool0003o00L0oooo00@0003o0?ooo`3oool0003o2`3oool00`00
0?l0oooo0?ooo`0T0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo00l0
oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`030?ooo`@0003o7`3oool00`3o0000
oooo0?ooo`0V0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0603oool00`000?l0
oooo0?ooo`0F0?ooo`030000o`3oool0oooo00T0oooo00D0o`000?ooo`3oool0oooo0000o`070?oo
o`80003o00<0oooo0000o`3oool0<03oool000d0oooo00<000000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0?0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool09P3oool00`3o0000
oooo0?ooo`0W0?ooo`80003o203oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo01H0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0
oooo00@0003o0?ooo`000?l0003o;`3oool000d0oooo00<000000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0?0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool03@3oool20000oaL0
oooo00<0o`000?ooo`3oool0<03oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo01H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo02`0
oooo000=0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo
0?ooo`0J0?ooo`030?l0003oool0oooo00l0oooo0`000?lC0?ooo`030?l0003oool0oooo0340oooo
00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool04`3oool00`000?l0oooo0000o`0F0?ooo`030000o`3oool0oooo0180oooo
000=0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?oo
o`0J0?ooo`030?l0003oool0oooo0180oooo0P000?lA0?ooo`030?l0003oool0oooo02h0oooo00<0
003o0?ooo`3o00008@3oool00`000?l0oooo0?ooo`0F0?ooo`050000o`3oool0oooo0?ooo`3o0000
6@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0
4P3oool000d0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo01T0oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0`0?ooo`80003o>`3o
ool00`000?l0oooo0?l0000K0?ooo`80003o1`3oool00`000?l0oooo0?ooo`0N0?ooo`003@3oool0
0`000000oooo0?ooo`020?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool06@3oool0
0`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo0300oooo00<0o`000?ooo`000?l0>`3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01d0oooo000=0?ooo`030000003oool0oooo
0080oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo
01/0oooo0`000?l70?ooo`030?l0003oool0oooo02l0oooo00@0o`000?ooo`3oool0oooo0P000?lh
0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool01@3oool20000o`D0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0L0?ooo`003@3oool00`000000oooo0?ooo`020?oo
o`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`0N0?oo
o`80003o103oool00`3o0000oooo0?ooo`0`0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool08@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool01P3oool01P000?l0oooo0?ooo`000?l0oooo0000o`P0oooo00<0003o0?ooo`3oool06`3o
ool000d0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0
oooo01T0oooo00<0o`000?ooo`3oool08@3oool20000o`80oooo00<0o`000?ooo`3oool0;`3oool0
0`3o0000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool0003o2P3o
ool00`000?l0oooo0?ooo`0J0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0
oooo00h0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0
oooo02h0oooo00<0o`000?ooo`3oool0:`3oool20000o`h0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool0003o9P3o
ool000d0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0
oooo01T0oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo02X0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0
oooo02<0oooo000=0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3oool00`3oool20000
obT0oooo00<0o`000?ooo`3oool0303oool20000ob40oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo01P0oooo00<0003o0?ooo`3oool08P3oool000d0
oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo01P0
oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`050?ooo`80003o9`3oool00`3o0000
oooo0?ooo`0>0?ooo`80003o:P3oool00`3o0000oooo0?ooo`0:0?ooo`80003o6@3oool00`000?l0
oooo0000o`0Q0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo00h0oooo
00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo00P0oooo
0P000?lT0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool09P3oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`0E0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo00h0oooo00<0
o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo02h0oooo00<0
o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo01h0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool0503oool000d0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0=
0?ooo`030?l0003oool0oooo01T0oooo00<0o`000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0^
0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?l0000R
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo01@0oooo000=0?ooo`030000003oool0oooo0080oooo00<0o`000?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo02<0oooo00<0o`000?oo
o`3oool0403oool20000oa`0oooo00<0o`000?ooo`3oool0>03oool00`000?l0oooo0?ooo`0R0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo01<0oooo000=0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3o
ool04P3oool20000oaT0oooo00<0o`000?ooo`3oool0>03oool00`3o0000oooo0000o`0T0?ooo`03
0000o`3oool0oooo00D0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l70?ooo`030000o`3oool0
oooo0180oooo000=0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool05@3oool20000
oaL0oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0I0?ooo`050?l0003oool0oooo
0?ooo`000?l05@3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00D0oooo00@0003o
0?ooo`3oool0003o7@3oool000d0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0=
0?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0G
0?ooo`80003o503oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo01P0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0C0?ooo`80003o3@3oool00`000?l0oooo0?ooo`05
0?ooo`040000o`3oool0oooo0000oa`0oooo000=0?ooo`030000003oool0oooo0080oooo00<0o`00
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo02<0oooo00<0o`00
0?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0N0?ooo`80003o5`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`0I
0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo00d0oooo00<0o`000?oo
o`3oool05`3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo02d0oooo00<0o`000?oo
o`3oool08@3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo01d0oooo00<0003o0?oo
o`3oool05P3oool010000?l0oooo0?ooo`000?lG0?ooo`003@3oool00`000000oooo0?ooo`020?oo
o`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0S0?oo
o`030?l0003oool0oooo01l0oooo0P000?l;0?ooo`030?l0003oool0oooo02<0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo01H0oooo00@0003o0?oo
o`3oool0003o5P3oool000d0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?oo
o`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0R0?oo
o`80003o2@3oool00`3o0000oooo0?ooo`0g0?ooo`030?l0003oool0oooo03/0oooo00<0003o0?oo
o`3oool0503oool000d0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0T0?ooo`80
003o1P3oool00`3o0000oooo0?ooo`0g0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool08@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool04`3oool000d0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0
003oool0oooo01L0oooo00<0o`000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0V0?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo0240oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo0180oooo00040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo01L0oooo00<0o`000?ooo`3oool08P3o
ool00`3o0000oooo0?ooo`0/0?ooo`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0?0?ooo`80003o8P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo01H0oooo00040?ooo`0306QXJ03alO40oooo00H0oooo0P0000030?ooo`030?l0003oool0
oooo00`0oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0
oooo02/0oooo00<0o`000?ooo`3oool0;@3oool20000o`P0oooo00<0o`000?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`0B0?ooo`80003o303oool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0
oooo0000oa@0oooo00040?ooo`0308f=S@3QhN40oooo00H0oooo00<000000?ooo`3oool0o`3ooolA
0?ooo`00103oool20;fm_@L0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`00103oool00`3YjNT0
O7al0?ooo`060?ooo`030000003oool0oooo0?l0oooo4@3oool000<0oooo0`0000070?ooo`030000
003oool0oooo0?l0oooo4@3oool000d0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`003@3oool0
0`000000oooo0?ooo`3o0?oooa40oooo000=0?ooo`030000003oool0oooo0?l0oooo4@3oool000d0
oooo00<000000?ooo`3oool0o`3ooolA0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooa40oooo
000=0?ooo`030000003oool0oooo0?l0oooo4@3oool000d0oooo00<000000?ooo`3oool0o`3ooolA
0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooa40oooo000=0?ooo`030000003oool0oooo0?l0
oooo4@3oool000d0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`003@3oool00`000000oooo0?oo
o`3o0?oooa40oooo000=0?ooo`030000003oool0oooo0?l0oooo4@3oool000d0oooo00<000000?oo
o`3oool0o`3ooolA0?ooo`003@3oool00`000000oooo0?ooo`3o0?oooa40oooo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {287, 0}} -> {0, 0, 0, 0}}],
  "  ",
  StyleBox["\nFigure 3.6",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Blue equipotential curves ",
  Cell[BoxData[
      \(x\^2 - y\^2 = C\)]],
  ", and red streamline curves ",
  Cell[BoxData[
      \(2  x\ y = \ C\)]],
  ", for ",
  Cell[BoxData[
      \(F \((z)\) = z\^2\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 3.14.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the complex potential  ",
  Cell[BoxData[
      \(F[z] = z\^2\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[F, \[Phi], \[CurlyPhi], z];\)\ \), "\n", 
    \(\(F[z_]\  = \ z\^2;\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ 
        ComplexExpand[Re[F[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(\[CurlyPhi][x_, y_]\  = \ 
        ComplexExpand[
          Im[F[x + \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The complex potential is\>"];\)\ \), "\n", 
    \(\(Print["\<  F(z) = \>", F[z]];\)\ \), "\n", 
    \(\(Print["\< F'(z) = \>", 
        Expand[\(F'\)[x + \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The vector field is\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<V(x,y) = \!\(\(F' \((z)\)\)\&_\) = \>\"", \n\ \ \ \ \ \ \
\ ComplexExpand[
          Conjugate[\(F'\)[
              x + \[ImaginaryI]\ y]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The equipotential curves are\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi](x,y) = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The streamline curves are\>"];\)\ \), "\n", 
    \(\(Print["\<\[CurlyPhi](x,y) = \>", \[CurlyPhi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the velocity potential and streamline curves"
}], "Text"],

Cell[BoxData[{
    \(\(g1 = 
        ContourPlot[\[Phi][x, y], {x, \(-8\), 8}, {y, 0, 
            8}, \[IndentingNewLine]Contours\  \[Rule] \ 10, 
          PlotPoints \[Rule] 25, 
          AspectRatio \[Rule] 1\/2, \[IndentingNewLine]ContourShading \[Rule] 
            False, AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<The curves  \[Phi](x,y) = \>", \[Phi][x, 
          y], "\< = C\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(g2 = 
        ContourPlot[\[CurlyPhi][x, y], {x, \(-8\), 8}, {y, 0, 
            8}, \[IndentingNewLine]Contours\  \[Rule] \ 10, 
          PlotPoints \[Rule] 25, 
          AspectRatio \[Rule] 1\/2, \[IndentingNewLine]ContourShading \[Rule] 
            False, AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<The curves  \[CurlyPhi](x,y) = \>", \[CurlyPhi][x, 
          y], "\< = C\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[g1, g2];\)\ \), "\n", 
    \(\(Print["\<The equipotential  curves  \[Phi](x,y) = \>", \[Phi][x, 
          y], "\< = C\>"\ ];\)\ \ \), "\n", 
    \(\(Print["\<and the streamline curves  \[CurlyPhi](x,y) = \>", \
\[CurlyPhi][x, y], "\< = C\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(ContourPlot[\[Phi][x, y], {x, \(-8\), 8}, {y, 0, 8}, 
        Contours\  \[Rule] \ 10, PlotPoints \[Rule] 25, 
        AspectRatio \[Rule] 1\/2, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The equipotential curves are\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi](x,y) = \>", \[Phi][x, 
          y], "\< = C\>"\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(ContourPlot[\[CurlyPhi][x, y], {x, \(-8\), 8}, {y, 
          0, 8}, Contours\  \[Rule] \ 10, PlotPoints \[Rule] 25, 
        AspectRatio \[Rule] 1\/2, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The streamline curves are\>"];\)\ \), "\n", 
    \(\(Print["\<\[CurlyPhi](x,y) = \>", \[CurlyPhi][x, 
          y], "\< = C\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Analytic Functions",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/AnalyticFunBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Cauchy-Riemann Equations",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/CauchyRiemannBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Harmonic Functions",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/HarmonicFunBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1004, 632},
WindowMargins->{{1, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[154950, 4168, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[348420, 8081, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 895801, 22841}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 121, 2, 33, "Text"],
Cell[2226, 66, 1837, 53, 128, "Text"],
Cell[4066, 121, 1560, 42, 113, "Text"],
Cell[5629, 165, 132077, 3516, 186, "Text"],

Cell[CellGroupData[{
Cell[137731, 3685, 101, 2, 33, "Text"],
Cell[137835, 3689, 1256, 22, 270, "Input"],
Cell[139094, 3713, 161, 3, 70, "Input"],
Cell[139258, 3718, 161, 3, 70, "Input"],
Cell[139422, 3723, 181, 4, 70, "Input"],
Cell[139606, 3729, 181, 4, 70, "Input"],
Cell[139790, 3735, 230, 5, 83, "Input"]
}, Closed]],
Cell[140035, 3743, 208, 4, 30, "Text"],
Cell[140246, 3749, 2314, 67, 52, "Text",
  Evaluatable->False],
Cell[142563, 3818, 12032, 334, 527, "Text"],

Cell[CellGroupData[{
Cell[154620, 4156, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[154768, 4162, 179, 4, 33, "Text",
  Evaluatable->False],
Cell[154950, 4168, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[155310, 4180, 3176, 95, 68, "Text"],
Cell[158489, 4277, 4720, 137, 278, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[163234, 4418, 245, 9, 33, "Text",
  Evaluatable->False],
Cell[163482, 4429, 112, 3, 33, "Text"],
Cell[163597, 4434, 1332, 25, 450, "Input"],
Cell[164932, 4461, 705, 22, 90, "Text",
  Evaluatable->False],
Cell[165640, 4485, 834, 16, 210, "Input"]
}, Closed]],
Cell[166489, 4504, 128, 3, 30, "Text"],
Cell[166620, 4509, 1478, 41, 147, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[168123, 4554, 245, 9, 33, "Text",
  Evaluatable->False],
Cell[168371, 4565, 112, 3, 33, "Text"],
Cell[168486, 4570, 1348, 25, 450, "Input"],
Cell[169837, 4597, 817, 24, 90, "Text",
  Evaluatable->False],
Cell[170657, 4623, 819, 15, 210, "Input"]
}, Closed]],
Cell[171491, 4641, 5999, 177, 87, "Text"],
Cell[177493, 4820, 155601, 2830, 253, "Text"],
Cell[333097, 7652, 1845, 46, 204, "Text"],
Cell[334945, 7700, 641, 22, 52, "Text",
  Evaluatable->False],
Cell[335589, 7724, 9357, 257, 328, "Text"],
Cell[344949, 7983, 3121, 82, 112, "Text"],

Cell[CellGroupData[{
Cell[348095, 8069, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[348243, 8075, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[348420, 8081, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[348780, 8093, 285, 5, 49, "Text"],
Cell[349068, 8100, 371, 13, 38, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[349464, 8117, 356, 11, 33, "Text",
  Evaluatable->False],
Cell[349823, 8130, 1106, 22, 298, "Input",
  InitializationCell->True]
}, Closed]],
Cell[350944, 8155, 355, 13, 30, "Text",
  Evaluatable->False],
Cell[351302, 8170, 3117, 89, 209, "Text"],
Cell[354422, 8261, 1681, 48, 229, "Text"],

Cell[CellGroupData[{
Cell[356128, 8313, 245, 9, 33, "Text",
  Evaluatable->False],
Cell[356376, 8324, 74, 0, 33, "Text"],
Cell[356453, 8326, 3652, 66, 620, "Input"],
Cell[360108, 8394, 467, 10, 110, "Input"],
Cell[360578, 8406, 424, 8, 90, "Input"],
Cell[361005, 8416, 821, 15, 110, "Input"],
Cell[361829, 8433, 201, 6, 71, "Text"],
Cell[362033, 8441, 168, 3, 33, "Text"],
Cell[362204, 8446, 605, 12, 210, "Input"],
Cell[362812, 8460, 129, 3, 33, "Text"],
Cell[362944, 8465, 1290, 23, 390, "Input"],
Cell[364237, 8490, 444, 15, 76, "Text"],
Cell[364684, 8507, 900, 19, 238, "Input"]
}, Closed]],
Cell[365599, 8529, 5029, 132, 30, "Text"],
Cell[370631, 8663, 221041, 7115, 260, "Text"],
Cell[591675, 15780, 5724, 153, 71, "Text"],
Cell[597402, 15935, 187817, 4436, 326, "Text"],
Cell[785222, 20373, 412, 14, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[785659, 20391, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[785826, 20397, 74, 0, 33, "Text"],
Cell[785903, 20399, 3856, 70, 653, "Input"],
Cell[789762, 20471, 201, 6, 71, "Text"],
Cell[789966, 20479, 168, 3, 33, "Text"],
Cell[790137, 20484, 680, 14, 210, "Input"],
Cell[790820, 20500, 129, 3, 33, "Text"],
Cell[790952, 20505, 1290, 23, 390, "Input"],
Cell[792245, 20530, 554, 18, 71, "Text"],
Cell[792802, 20550, 900, 19, 238, "Input"]
}, Closed]],
Cell[793717, 20572, 929, 24, 182, "Text"],
Cell[794649, 20598, 696, 24, 128, "Text"],
Cell[795348, 20624, 2314, 68, 280, "Text"],
Cell[797665, 20694, 975, 30, 204, "Text"],
Cell[798643, 20726, 1414, 42, 242, "Text"],
Cell[800060, 20770, 449, 13, 52, "Text"],
Cell[800512, 20785, 527, 19, 33, "Text",
  Evaluatable->False],
Cell[801042, 20806, 1051, 30, 204, "Text"],
Cell[802096, 20838, 87287, 1833, 326, "Text"],

Cell[CellGroupData[{
Cell[889408, 22675, 245, 9, 33, "Text",
  Evaluatable->False],
Cell[889656, 22686, 111, 5, 33, "Text"],
Cell[889770, 22693, 1315, 26, 372, "Input"],
Cell[891088, 22721, 167, 5, 52, "Text"],
Cell[891258, 22728, 1214, 22, 282, "Input"],
Cell[892475, 22752, 468, 8, 124, "Input"],
Cell[892946, 22762, 499, 8, 145, "Input"]
}, Closed]],
Cell[893460, 22773, 290, 7, 30, "Text"],
Cell[893753, 22782, 287, 7, 33, "Text"],
Cell[894043, 22791, 295, 7, 33, "Text"],
Cell[894341, 22800, 287, 7, 33, "Text"],
Cell[894631, 22809, 257, 5, 33, "Text"],
Cell[894891, 22816, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

