(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    122063,       3451]*)
(*NotebookOutlinePosition[    123692,       3506]*)
(*  CellTagsIndexPosition[    123615,       3500]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 4  Sequences, Julia and Mandelbrot Sets, and \
Power Series",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Overview",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tIn 1980 ",
  StyleBox[ButtonBox["Benoit Mandelbrot",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Mandelbrot.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " led a team of mathematicians in producing some stunning computer graphics \
from very simple rules for manipulating complex numbers.  This event marked \
the beginning of a new branch of mathematics, known as fractal geometry, that \
has some amazing applications.  Many of the tools needed to appreciate \
Mandelbrot's work are contained in this chapter.  We look at extensions to \
the complex domain of sequences and series, ideas that are familiar to \
students who have completed a standard calculus course."
}], "Text"],

Cell[TextData[StyleBox["4.1  Sequences and Series",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tIn formal terms, a complex sequence is a function whose domain is the \
positive integers and whose range is a subset of the complex numbers. The \
following are examples of sequences:  \n\n",
  Cell[BoxData[GridBox[{
          {
            RowBox[{
              StyleBox[\((4 - 1)\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->RGBColor[0, 0, 0.996109],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              "                    "}], \(f \((n)\)\  = \ \((2 - 
                    1\/n)\) + \((5 + 1\/n)\) \[ImaginaryI]\), 
            RowBox[{" ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{\(n = 1\), 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "2", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "3", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "..."}], ")"}], 
                StyleBox[";",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}]},
          {
            RowBox[{
              StyleBox[\((4 - 2)\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->RGBColor[0, 0, 0.996109],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "                    "}], 
            RowBox[{\(g \((n)\)\), " ", "=", " ", 
              
              RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI] \( \[Pi]\ n\)\/4\)\),
                 "                        ", 
                StyleBox[\(1\/1\),
                  FontColor->GrayLevel[1]]}]}], 
            RowBox[{" ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{\(n = 1\), 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "2", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "3", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "..."}], ")"}], 
                StyleBox[";",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}]},
          {
            RowBox[{
              StyleBox[\((4 - 3)\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->RGBColor[0, 0, 0.996109],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "                    "}], 
            RowBox[{\(h \((k)\)\), " ", "=", " ", 
              RowBox[{"5", "+", \(3  \[ImaginaryI]\), "+", 
                RowBox[{\(\((1\/\(1 + \[ImaginaryI]\))\)\^k\), "    ", 
                  StyleBox[\(1\/1\),
                    FontColor->GrayLevel[1]]}]}]}], 
            RowBox[{" ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{\(k = 1\), 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "2", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "3", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "..."}], ")"}], 
                StyleBox[";",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}]},
          {
            RowBox[{
              StyleBox[\((4 - 4)\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->RGBColor[0, 0, 0.996109],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              "                    "}], \(\(r \((n)\)\)\(\ \)\(=\)\(\ \
\)\(\((1\/4 + \[ImaginaryI]\/2)\)\^n\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \)\), 
            RowBox[{" ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{\(n = 1\), 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "2", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "3", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "..."}], ")"}], 
                StyleBox[".",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}]}
          }]]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f\_n_\  = \ \((2 - 
              1\/n)\) + \((5 + 
                1\/n)\) \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(f\_n\) = f(n) = \>\""\ , 
        f\_n];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Table[{"\<f\>"\_n, "\<=\>", f\_n, "\<=\>", 
              PaddedForm[N[f\_n], {12, 12}]}, {n, 1, 
              20}]]];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(g\_n_\  = \ \[ExponentialE]\^\(\[ImaginaryI] \( \[Pi]\ n\)\/4\);\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(g\_n\) = g(n) = \>\""\ , 
        g\_n];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Table[{"\<g\>"\_n, "\<=\>", g\_n, "\<=\>", 
              PaddedForm[N[g\_n], {12, 12}]}, {n, 1, 
              16}]]];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(h\_k_\  = \ 
        5 + 3  \[ImaginaryI] + \((1\/\(1 + \[ImaginaryI]\))\)\^k;\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(h\_k\) = h(k) = 5+3\[ImaginaryI] + (\!\(1\/\(1 + \
\[ImaginaryI]\)\)\!\(\()\^k\)\) = \>\""\ , 
        h\_k];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Table[{"\<h\>"\_k, "\<=\>", h\_k, "\<=\>", 
              PaddedForm[N[h\_k], {12, 12}]}, {k, 1, 
              14}]]];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(r\_n_\  = \ \((1\/4 + \[ImaginaryI]\/2)\)\^n;\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(r\_n\) = r(n) = \>\""\ , 
        r\_n];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Table[{"\<r\>"\_n, "\<=\>", r\_n, "\<=\>", 
              PaddedForm[N[r\_n], {12, 12}]}, {n, 1, 
              16}]]];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tFor convenience, at times we use the term sequence rather than complex \
sequence.  If we want a function ",
  StyleBox["s",
    FontFamily->"Courier New"],
  " to represent an arbitrary sequence, we can specify it by writing  ",
  Cell[BoxData[
      \(s \((1)\) = z\_1, s \((2)\) = z\_2, s \((3)\) = z\_3\)]],
  ",  and so on.  The values   ",
  Cell[BoxData[
      \(z\_1, z\_2, z\_3,  ... \)]],
  ",  are called the terms of a sequence, and mathematicians, being generally \
lazy when it comes to such things, often refer to ",
  Cell[BoxData[
      \(z\_1, z\_2, z\_3, \(\(etc\)\(.\)\)\)]],
  " as the sequence itself, even though they are really speaking of the range \
of the sequence when they do so.  You will usually see a sequence written as  \
",
  Cell[BoxData[
      \({z\_n}\_\(n = 1\)\%\[Infinity]\)]],
  ", ",
  Cell[BoxData[
      \({z\_n}\_1\%\[Infinity]\)]],
  ", or when the indices are understood, as ",
  Cell[BoxData[
      \({z\_n}\)]],
  ".  Mathematicians are also not so fussy about starting a sequence at  ",
  Cell[BoxData[
      \(z\_1\)]],
  ", so that  ",
  Cell[BoxData[
      \({z\_n}\_\(n = \(-1\)\)\%\[Infinity]\)]],
  ", ",
  Cell[BoxData[
      \({z\_n}\_\(n = 0\)\%\[Infinity]\)]],
  ", etc., would also be acceptable notation, provided all terms were \
defined.  For example, the sequence ",
  StyleBox["r",
    FontFamily->"Courier New"],
  " given by Equation ",
  StyleBox["(4-4)",
    FontColor->RGBColor[0, 0, 1]],
  " could be written in a variety of ways:  \n\n\t",
  Cell[BoxData[
      \({\ \((1\/4 + \[ImaginaryI]\/2)\)\^n\ }\_\(n = 1\)\%\[Infinity]\)]],
  ",  ",
  Cell[BoxData[
      \({\ \((1\/4 + \[ImaginaryI]\/2)\)\^n\ }\_1\%\[Infinity]\)]],
  ",  ",
  Cell[BoxData[
      \({\ \((1\/4 + \[ImaginaryI]\/2)\)\^n\ }\_\(n = 1\)\%\[Infinity]\)]],
  ",  ",
  Cell[BoxData[
      \({\ \((1\/4 + \[ImaginaryI]\/2)\)\^\(n + 2\)\ }\_\(n = \(-2\)\)\%\
\[Infinity]\)]],
  ", ",
  Cell[BoxData[
      \({\ \((1\/4 + \[ImaginaryI]\/2)\)\^k\ }\_\(k = 1\)\%\[Infinity]\)]],
  ", ..."
}], "Text"],

Cell[TextData[{
  "\tThe sequences ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["g",
    FontFamily->"Courier New"],
  " given by Equations ",
  StyleBox["(4-1)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(4-2)",
    FontColor->RGBColor[0, 0, 1]],
  " behave differently as ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " gets larger.  The terms in Equation ",
  StyleBox["(4-1)",
    FontColor->RGBColor[0, 0, 1]],
  " approach  ",
  Cell[BoxData[
      \(2 + 5  \[ImaginaryI]\  = \((2, 5)\)\)]],
  ",  but those in Equation  ",
  StyleBox["(4-2)",
    FontColor->RGBColor[0, 0, 1]],
  "  do not approach any particular number, as they oscillate around the \
eight eighth roots of unity on the unit circle.  Informally, the sequence  ",
  Cell[BoxData[
      \({z\_n}\_1\%\[Infinity]\)]],
  "  has  ",
  Cell[BoxData[
      \(\[Zeta]\)]],
  "  as its limit as  n  approaches infinity, provided the terms  ",
  Cell[BoxData[
      \(z\_n\)]],
  "  can be made as close as we want to  ",
  Cell[BoxData[
      \(\[Zeta]\)]],
  "  by making  n  large enough.  When this happens, we write \n\n ",
  StyleBox["(4-5)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{\(lim\+\(n \[Rule] \[Infinity]\)\ z\_n\), "=", 
        RowBox[{
          RowBox[{"\[Zeta]", "      ", 
            StyleBox["or",
              FontFamily->"Times New Roman"], "     ", \(z\_n\)}], "\[Rule]", 
          
          RowBox[{
            RowBox[{"\[Zeta]", "   ", 
              StyleBox["as",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "   ", "n"}], " ", "\[Rule]", 
            "\[Infinity]"}]}]}]]],
  ". \n\nIf  ",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ z\_n = \[Zeta]\)]],
  ",  we say that the sequence  ",
  Cell[BoxData[
      \({z\_n}\_1\%\[Infinity]\)]],
  "  converges to  ",
  Cell[BoxData[
      \(\[Zeta]\)]],
  ".  \n\n\tWe need a rigorous definition for Statement ",
  StyleBox["(4-5)",
    FontColor->RGBColor[0, 0, 1]],
  ", however, if we are to do honest mathematics."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 4.1 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Limit of a Sequence",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ConvergentSequence.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ z\_n = \[Zeta]\)]],
  "  means that for any real number  ",
  Cell[BoxData[
      \(\[Epsilon] > 0\)]],
  "  there corresponds a positive integer  ",
  Cell[BoxData[
      \(N\_\[Epsilon]\)]],
  "  (which depends on  ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  ")  such that  ",
  Cell[BoxData[
      \(z\_n \[Element] \(D\_\[Epsilon]\) \((\[Zeta])\)\)]],
  "  whenever  ",
  Cell[BoxData[
      \(n > N\_\[Epsilon]\)]],
  ".   That is  ",
  Cell[BoxData[
      \(\(\(|\)\(\[Zeta] - z\_n\)\(|\)\(\(<\)\(\[Element]\)\)\)\)]],
  "  whenever  ",
  Cell[BoxData[
      \(n > N\_\[Epsilon]\)]],
  ".  Figure 4.1 illustrates a convergent sequence."
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-017 0.025 -2.08167e-017 0.025 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 0 1 r
.02 w
.375 .375 Mdot
1 0 0 r
.34338 .39661 Mdot
.33224 .42243 Mdot
.31531 .44712 Mdot
.29668 .46878 Mdot
.28691 .49398 Mdot
.30014 .53232 Mdot
.35144 .5837 Mdot
.4492 .63047 Mdot
.57972 .6446 Mdot
.70073 .60721 Mdot
.76331 .52455 Mdot
.74997 .42572 Mdot
.6897 .34206 Mdot
.63436 .28558 Mdot
.62947 .2462 Mdot
.71204 .21172 Mdot
.91502 .19207 Mdot
0 0 1 r
.5 Mabswid
[ ] 0 setdash
newpath
.375 .375 .3625 0 365.73 arc
s
0 g
gsave
.9175 .15 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.7275 .175 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.6275 .2075 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.585 .6125 -69.4063 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.44 .6 -74.5313 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.313 14.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
80.438 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
86.063 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.71 .65 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.725 .625 -65.6875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
68.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.7425 .61 -65.6875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\316) show
68.375 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.35 .225 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\316) show
70.188 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4 .4 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.375 .375 m
.375 .0125 L
s
% Start of user PostScript
15. 15. 15. 0.5 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 216},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000f2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00H`3ooolB0000oj/0oooo001K
0?ooo`P0003o203oool00`000?l0oooo0?ooo`070?ooo`L0003oY03oool005H0oooo1@000?l?0?oo
o`<0003o3`3oool50000oil0oooo001A0?ooo`D0003o503oool30000oa@0oooo1@000?nJ0?ooo`00
C`3oool20000oaT0oooo0`000?lI0?ooo`<0003oU`3oool004X0oooo1@000?lK0?ooo`<0003o703o
ool20000oiD0oooo00170?ooo`<0003o7`3oool50000oad0oooo1@000?n@0?ooo`00A@3oool20000
ob80oooo1@000?lR0?ooo`<0003oS@3oool00480oooo0`000?lT0?ooo`D0003o9@3oool20000oh/0
oooo00100?ooo`80003o9`3oool50000obL0oooo0P000?n90?ooo`00?P3oool20000obP0oooo1`00
0?lX0?ooo`80003oQ`3oool003d0oooo00<0003o0?ooo`3oool0:03oool70000obX0oooo0P000?n5
0?ooo`00>`3oool20000ob/0oooo1`000?l/0?ooo`030000o`3oool0oooo0880oooo000i0?ooo`80
003o;@3oool70000obd0oooo0P000?n20?ooo`00=`3oool20000obh0oooo2@000?l^0?ooo`80003o
P03oool003D0oooo0P000?l`0?ooo`T0003o<03oool20000ogh0oooo000d0?ooo`030000o`3oool0
oooo03@0oooo00<0003o0?ooo`3oool0=03oool20000og`0oooo000c0?ooo`030000o`3oool0oooo
03D0oooo00<0003o0?ooo`3oool0=P3oool00`000?l0oooo0?ooo`1i0?ooo`00<@3oool20000ocP0
oooo00<0003o0?ooo`3oool0=`3oool20000ogT0oooo000`0?ooo`030000o`3oool0oooo03P0oooo
00<0003o0?ooo`3oool0>@3oool00`000?l0oooo0?ooo`1f0?ooo`00;P3oool20000oc/0oooo00<0
003o0?ooo`3oool0>P3oool00`000?l0oooo0?ooo`1e0?ooo`00;03oool20000ocd0oooo00<0003o
0?ooo`3oool0>`3oool20000ogD0oooo000[0?ooo`030000o`3oool0oooo03d0oooo00<0003o0?oo
o`3oool0?@3oool00`000?l0oooo0?ooo`1b0?ooo`00:P3oool00`000?l0oooo0?ooo`0n0?ooo`03
0000o`3oool0oooo03h0oooo00<0003o0?ooo`3oool0L@3oool002P0oooo0P000?m10?ooo`030000
o`3oool0oooo03l0oooo0P000?ma0?ooo`009`3oool00`000?l0oooo0?ooo`110?ooo`030000o`3o
ool0oooo0440oooo00<0003o0?ooo`3oool0KP3oool002H0oooo00<0003o0?ooo`3oool0@P3oool0
0`000?l0oooo0?ooo`120?ooo`030000o`3oool0oooo06d0oooo000U0?ooo`030000o`3oool0oooo
04<0oooo00<0003o0?ooo`3oool0@`3oool00`000?l0oooo0?ooo`1/0?ooo`009@3oool00`000?l0
oooo0?ooo`130?ooo`030000o`3oool0oooo04@0oooo00<0003o0?ooo`3oool0J`3oool002@0oooo
00<0003o0?ooo`3oool0A03oool00`000?l0oooo0?ooo`150?ooo`030000o`3oool0oooo06X0oooo
000S0?ooo`030000o`3oool0oooo04D0oooo00<0003o0?ooo`3oool0AP3oool00`000?l0oooo0?oo
o`1Y0?ooo`008@3oool20000odP0oooo00<0003o0?ooo`3oool0A`3oool20000ofT0oooo000P0?oo
o`030000o`3oool0oooo04P0oooo00<0003o0?ooo`3oool0B03oool00`000?l0oooo0?ooo`1W0?oo
o`007`3oool00`000?l0oooo0?ooo`190?ooo`030000o`3oool0oooo04T0oooo00<0003o0?ooo`3o
ool0IP3oool001h0oooo00<0003o0?ooo`3oool0BP3oool00`000?l0oooo0?ooo`1:0?ooo`030000
o`3oool0oooo06D0oooo000M0?ooo`030000o`3oool0oooo04/0oooo00<0003o0?ooo`3oool0B`3o
ool00`000?l0oooo0?ooo`1T0?ooo`00703oool00`000?l0oooo0?ooo`1<0?ooo`030000o`3oool0
oooo04`0oooo00<0003o0?ooo`3oool0BP3oool5000001@0oooo000L0?ooo`030000o`3oool0oooo
04`0oooo00<0003o0?ooo`3oool0C@3oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo
01@0oooo000K0?ooo`030000o`3oool0oooo04d0oooo00<0003o0?ooo`3oool0C@3oool00`000?l0
oooo0?ooo`130?ooo`D000000`3oool00`000000oooo0?ooo`0D0?ooo`006P3oool00`000?l0oooo
0?ooo`1>0?ooo`030000o`3oool0oooo04h0oooo00<0003o0?ooo`3oool0@`3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000o`3oool0oooo04l0oooo
00<0003o0?ooo`3oool0C`3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0503oool001P0oooo00<0003o0?ooo`3oool0D03oool00`000?l0oooo0?oo
o`1@0?ooo`030000o`3oool0oooo04<0oooo00@000000?ooo`3oool0oooo0P00000F0?ooo`005`3o
ool00`000?l0oooo0?ooo`1A0?ooo`030000o`3oool0oooo0540oooo00<0003o0?ooo`3oool0@03o
ool010000000oooo0?ooo`00000J0?ooo`005`3oool00`000?l0oooo0?ooo`1A0?ooo`030000o`3o
ool0oooo0580oooo00<0003o0?ooo`3oool03`3oool3000002d0oooo1@00000I0?ooo`005P3oool0
0`000?l0oooo0?ooo`1B0?ooo`030000o`3oool0oooo0580oooo00<0003o0?ooo`3oool03`3oool0
0`000000oooo0?ooo`1;0?ooo`005@3oool00`000?l0oooo0?ooo`1C0?ooo`030000o`3oool0oooo
05<0oooo00<0003o0?ooo`3oool01`3oool5000000<0oooo00<000000?ooo`3oool0BP3oool001D0
oooo00<0003o0?ooo`3oool0D`3oool00`000?l0oooo0?ooo`1C0?ooo`030000o`3oool0oooo00P0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`1:0?ooo`00503oool00`000?l0
oooo0?ooo`1D0?ooo`030000o`3oool0oooo05@0oooo00<0003o0?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`030000003oool0000004/0oooo000D0?ooo`030000o`3oool0oooo05@0oooo
00<0003o0?ooo`3oool0E03oool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0BP3oool001<0oooo00<0003o0?ooo`3oool0E@3oool00`000?l0oooo0?oo
o`1E0?ooo`030000o`3oool0oooo00H0oooo00@000000?ooo`3oool00000D03oool001<0oooo00<0
003o0?ooo`3oool0E@3oool00`000?l0oooo0?ooo`1F0?ooo`030000o`3oool0oooo00D0oooo1@00
000d0?ooo`<0o`00603oool00180oooo00<0003o0?ooo`3oool0EP3oool00`000?l0oooo0?ooo`1F
0?ooo`030000o`3oool0oooo03d0oooo1@3o000G0?ooo`004@3oool00`000?l0oooo0?ooo`1G0?oo
o`030000o`3oool0oooo05L0oooo00<0003o0?ooo`3oool0?03oool50?l001L0oooo000@0?ooo`03
0000o`3oool0oooo05P0oooo00<0003o0?ooo`3oool0A`3oool2000000h0oooo00<0003o0?ooo`3o
ool0?03oool50?l001L0oooo000@0?ooo`030000o`3oool0oooo05P0oooo00<0003o0?ooo`3oool0
@03oool5000000@0oooo00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`0l0?ooo`<0o`00
603oool00100oooo00<0003o0?ooo`3oool0F03oool00`000?l0oooo0?ooo`110?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`1F0?ooo`003`3o
ool00`000?l0oooo0?ooo`1I0?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00<0o`00D`3oool000l0oooo00<0003o
0?ooo`3oool0F@3oool00`000?l0oooo0?ooo`130?ooo`070000003oool0oooo0?ooo`000000oooo
0000000@0?ooo`030000o`3o0000o`0000<0o`00DP3oool000h0oooo00<0003o0?ooo`3oool0FP3o
ool00`000?l0oooo0?ooo`110?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
3`3oool00`000?l0o`000?l000030?l00580oooo000>0?ooo`030000o`3oool0oooo0540oooo1000
00050?ooo`030000o`3oool0oooo0440oooo1@00000E0?ooo`030000o`3o0000o`000080o`00DP3o
ool000d0oooo00<0003o0?ooo`3oool0D@3oool00`000000oooo0?ooo`070?ooo`030000o`3oool0
oooo05/0oooo00@0003o0?l0003o0000o`00D`3oool000`0oooo00<0003o0?ooo`3oool0DP3oool0
0`000000oooo0?ooo`070?ooo`030000o`3oool0oooo05`0oooo00<0003o0?ooo`3oool0D`3oool0
00`0oooo00<0003o0?ooo`3oool0DP3oool5000000D0oooo00<0003o0?ooo`3oool0G03oool00`00
0?l0oooo0?ooo`1C0?ooo`002`3oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo00L0
oooo00<0003o0?ooo`3oool0G@3oool00`000?l0oooo0?ooo`1B0?ooo`002`3oool00`000?l0oooo
0?ooo`1D0?ooo`@000001@3oool00`000?l0oooo0?ooo`1M0?ooo`030000o`3oool0oooo0580oooo
000:0?ooo`030000o`3oool0oooo05h0oooo00<0003o0?ooo`3oool0A@3oool30?l001D0oooo00<0
003o0?ooo`3oool0DP3oool000X0oooo00<0003o0?ooo`3oool0GP3oool00`000?l0oooo0?ooo`14
0?ooo`D0o`005@3oool00`000?l0oooo0?ooo`1A0?ooo`002P3oool00`000?l0oooo0?ooo`1N0?oo
o`030000o`3oool0oooo04@0oooo1@3o000E0?ooo`030000o`3oool0oooo0540oooo000:0?ooo`03
0000o`3oool0oooo05h0oooo00<0003o0?ooo`3oool0A03oool50?l001H0oooo00<0003o0?ooo`3o
ool0D03oool000X0oooo00<0003o0?ooo`3oool0GP3oool00`000?l0oooo0?ooo`150?ooo`<0o`00
5`3oool00`000?l0oooo0?ooo`1@0?ooo`002@3oool00`000?l0oooo0?ooo`1O0?ooo`030000o`3o
ool0oooo0600oooo00<0003o0?ooo`3oool0C`3oool000T0oooo00<0003o0?ooo`3oool0G`3oool0
0`000?l0oooo0?ooo`1P0?ooo`030000o`3oool0oooo04l0oooo00080?ooo`030000o`3oool0oooo
0600oooo00<0003o0?ooo`3oool0H03oool00`000?l0oooo0?ooo`1?0?ooo`00203oool00`000?l0
oooo0?ooo`1P0?ooo`030000o`3oool0oooo0600oooo00<0003o0?ooo`3oool0C`3oool000P0oooo
00<0003o0?ooo`3oool0H03oool00`000?l0oooo0?ooo`1P0?ooo`030000o`3oool0oooo04l0oooo
00070?ooo`030000o`3oool0oooo0640oooo00<0003o0?ooo`3oool0H@3oool00`000?l0oooo0?oo
o`1>0?ooo`001`3oool00`000?l0oooo0?ooo`1Q0?ooo`030000o`3oool0oooo0640oooo00<0003o
0?ooo`3oool0CP3oool000H0oooo00<0003o0?ooo`3oool0HP3oool00`000?l0oooo0?ooo`160?oo
o`<0o`00603oool00`000?l0oooo0?ooo`1>0?ooo`001P3oool00`000?l0oooo0?ooo`1R0?ooo`03
0000o`3oool0oooo04D0oooo1@3o000H0?ooo`030000o`3oool0oooo04d0oooo00060?ooo`030000
o`3oool0oooo0680oooo00<0003o0?ooo`3oool0A@3oool50?l001P0oooo00<0003o0?ooo`3oool0
C@3oool000H0oooo00<0003o0?ooo`3oool0HP3oool00`000?l0oooo0?ooo`150?ooo`D0o`00603o
ool00`000?l0oooo0?ooo`1=0?ooo`001P3oool00`000?l0oooo0?ooo`1R0?ooo`030000o`3oool0
oooo04H0oooo0`3o000I0?ooo`030000o`3oool0oooo04d0oooo00050?ooo`030000o`3oool0oooo
06<0oooo00<0003o0?ooo`3oool0HP3oool00`000?l0oooo0?ooo`1=0?ooo`001@3oool00`000?l0
oooo0?ooo`1S0?ooo`030000o`3oool0oooo06<0oooo00<0003o0?ooo`3oool0C03oool000D0oooo
00<0003o0?ooo`3oool0H`3oool00`000?l0oooo0?ooo`1S0?ooo`030000o`3oool0oooo04`0oooo
00050?ooo`030000o`3oool0oooo06<0oooo00<0003o0?ooo`3oool0I03oool00`000?l0oooo0?oo
o`1;0?ooo`001@3oool00`000?l0oooo0?ooo`1S0?ooo`030000o`3oool0oooo06@0oooo00<0003o
0?ooo`3oool0B`3oool000@0oooo00<0003o0?ooo`3oool0I03oool00`000?l0oooo0?ooo`1T0?oo
o`030000o`3oool0oooo04/0oooo00040?ooo`030000o`3oool0oooo06@0oooo00<0003o0?ooo`3o
ool0I03oool00`000?l0oooo0?ooo`1;0?ooo`00103oool00`000?l0oooo0?ooo`1T0?ooo`030000
o`3oool0oooo06@0oooo00<0003o0?ooo`3oool0B`3oool000@0oooo00<0003o0?ooo`3oool0I03o
ool00`000?l0oooo0?ooo`1T0?ooo`030000o`3oool0oooo04/0oooo00040?ooo`030000o`3oool0
oooo06@0oooo00<0003o0?ooo`3oool0I03oool00`000?l0oooo0?ooo`1;0?ooo`00103oool00`00
0?l0oooo0?ooo`1T0?ooo`030000o`3oool0oooo06@0oooo00<0003o0?ooo`3oool0B`3oool000@0
oooo00<0003o0?ooo`3oool0I03oool00`000?l0oooo0?ooo`1F0?ooo`<0o`00303oool00`000?l0
oooo0?ooo`1:0?ooo`00103oool00`000?l0oooo0?ooo`1T0?ooo`030000o`3oool0oooo05D0oooo
1@3o000;0?ooo`030000o`3oool0oooo04X0oooo00040?ooo`030000o`3oool0oooo06@0oooo00<0
003o0?ooo`3oool0E@3oool50?l000/0oooo00<0003o0?ooo`3oool0BP3oool000@0oooo00<0003o
0?ooo`3oool0I03oool00`000?l0oooo0?ooo`1E0?ooo`D0o`002`3oool00`000?l0oooo0?ooo`1:
0?ooo`00103oool00`000?l0oooo0?ooo`1T0?ooo`030000o`3oool0oooo05H0oooo0`3o000<0?oo
o`030000o`3oool0oooo04X0oooo00030?ooo`030000o`3oool0oooo06D0oooo00<0003o0?ooo`3o
ool0I@3oool00`000?l0oooo0?ooo`1:0?ooo`000`3oool00`000?l0oooo0?ooo`1U0?ooo`030000
o`3oool0oooo06D0oooo00<0003o0?ooo`3oool0BP3oool000<0oooo00<0003o0?ooo`3oool0I@3o
ool00`000?l0oooo0?ooo`1U0?ooo`030000o`3oool0oooo04X0oooo00030?ooo`030000o`3oool0
oooo06D0oooo00<0003o0?ooo`3oool0I@3oool00`000?l0oooo0?ooo`1:0?ooo`000`3oool00`00
0?l0oooo0?ooo`1T0?ooo`<0003oIP3oool00`000?l0oooo0?ooo`1:0?ooo`000`3oool00`000?l0
oooo0?ooo`1S0?ooo`D0003oI@3oool00`000?l0oooo0?ooo`1:0?ooo`000`3oool00`000?l0oooo
0?ooo`1S0?ooo`D0003oI@3oool00`000?l0oooo0?ooo`1:0?ooo`000`3oool00`000?l0oooo0?oo
o`1S0?ooo`D0003oI@3oool00`000?l0oooo0?ooo`1:0?ooo`000`3oool00`000?l0oooo0?ooo`1T
0?ooo`<0003oIP3oool00`000?l0oooo0?ooo`1:0?ooo`000`3oool00`000?l0oooo0?ooo`3=0?oo
o`030000o`3oool0oooo04X0oooo00030?ooo`030000o`3oool0oooo06l0oooo1000001J0?ooo`03
0000o`3oool0oooo04X0oooo00030?ooo`030000o`3oool0oooo05/0oooo0`3o000@0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0E`3oool00`000?l0oooo0?ooo`1:0?ooo`000`3o
ool00`000?l0oooo0?ooo`1J0?ooo`D0o`004@3oool3000005X0oooo00<0003o0?ooo`3oool0BP3o
ool000@0oooo00<0003o0?ooo`3oool0F@3oool50?l00100oooo00<000000?ooo`3oool0F`3oool0
0`000?l0oooo0?ooo`1:0?ooo`00103oool00`000?l0oooo0?ooo`1I0?ooo`D0o`00403oool00`00
0000oooo0?ooo`1K0?ooo`030000o`3oool0oooo04X0oooo00040?ooo`030000o`3oool0oooo05X0
oooo0`3o000A0?ooo`030000003oool0oooo05/0oooo00<0003o0?ooo`3oool0BP3oool000@0oooo
00<0003o0?ooo`3oool0K`3oool00`000000oooo0?ooo`1J0?ooo`030000o`3oool0oooo04X0oooo
00040?ooo`030000o`3oool0oooo0700oooo0`00001I0?ooo`030000o`3oool0oooo04X0oooo0004
0?ooo`030000o`3oool0oooo05L0oooo0`3o000E0?ooo`8000000P3oool00`000000oooo0?ooo`1E
0?ooo`030000o`3oool0oooo04/0oooo00040?ooo`030000o`3oool0oooo05H0oooo1@3o000F0?oo
o`<00000E`3oool00`000?l0oooo0?ooo`030?l004P0oooo00040?ooo`030000o`3oool0oooo05H0
oooo1@3o001`0?ooo`030000o`3oool0o`0000@0o`00A`3oool000@0oooo00<0003o0?ooo`3oool0
EP3oool50?l00700oooo00<0003o0?ooo`3o0000103o00170?ooo`00103oool00`000?l0oooo0?oo
o`1G0?ooo`<0o`00L@3oool00`000?l0oooo0?l000040?l004L0oooo00050?ooo`030000o`3oool0
oooo0<X0oooo00<0003o0?ooo`3oool00`3o00180?ooo`001@3oool00`000?l0oooo0?ooo`3:0?oo
o`030000o`3oool0oooo04/0oooo00050?ooo`030000o`3oool0oooo0540oooo0`3o001f0?ooo`03
0000o`3oool0oooo04/0oooo00050?ooo`030000o`3oool0oooo0500oooo1@3o001d0?ooo`030000
o`3oool0oooo04`0oooo00050?ooo`030000o`3oool0oooo0500oooo1@3o001d0?ooo`030000o`3o
ool0oooo04`0oooo00050?ooo`030000o`3oool0oooo0500oooo1@3o001c0?ooo`030000o`3oool0
oooo04d0oooo00060?ooo`030000o`3oool0oooo0500oooo0`3o001d0?ooo`030000o`3oool0oooo
04d0oooo00060?ooo`030000o`3oool0oooo0<L0oooo00<0003o0?ooo`3oool0C@3oool000H0oooo
00<0003o0?ooo`3oool0BP3oool30?l007X0oooo00<0003o0?ooo`3oool0C@3oool000H0oooo00<0
003o0?ooo`3oool0B@3oool50?l007T0oooo00<0003o0?ooo`3oool0C@3oool000H0oooo00<0003o
0?ooo`3oool0B@3oool50?l007P0oooo00<0003o0?ooo`3oool0CP3oool000L0oooo00<0003o0?oo
o`3oool0B03oool50?l007P0oooo00<0003o0?ooo`3oool0CP3oool000L0oooo00<0003o0?ooo`3o
ool0B@3oool30?l007T0oooo00<0003o0?ooo`3oool0CP3oool000P0oooo00<0003o0?ooo`3oool0
``3oool00`000?l0oooo0?ooo`1?0?ooo`00203oool00`000?l0oooo0?ooo`330?ooo`030000o`3o
ool0oooo04l0oooo00080?ooo`030000o`3oool0oooo04H0oooo0`3o001j0?ooo`030000o`3oool0
oooo04l0oooo00090?ooo`030000o`3oool0oooo04@0oooo1@3o001i0?ooo`030000o`3oool0oooo
04l0oooo00090?ooo`030000o`3oool0oooo04@0oooo1@3o001i0?ooo`030000o`3oool0oooo04l0
oooo000:0?ooo`030000o`3oool0oooo04<0oooo1@3o001h0?ooo`030000o`3oool0oooo0500oooo
000:0?ooo`030000o`3oool0oooo04@0oooo0`3o001i0?ooo`030000o`3oool0oooo0500oooo000:
0?ooo`030000o`3oool0oooo0;l0oooo00<0003o0?ooo`3oool0D@3oool000X0oooo00<0003o0?oo
o`3oool0_`3oool00`000?l0oooo0?ooo`1A0?ooo`002P3oool00`000?l0oooo0?ooo`2n0?ooo`03
0000o`3oool0oooo0580oooo000;0?ooo`030000o`3oool0oooo0;d0oooo00<0003o0?ooo`3oool0
DP3oool000/0oooo00<0003o0?ooo`3oool0_@3oool00`000?l0oooo0?ooo`0;0?ooo`<0o`00A03o
ool000`0oooo00<0003o0?ooo`3oool0^`3oool00`000?l0oooo0?ooo`0;0?ooo`D0o`00@`3oool0
00`0oooo00<0003o0?ooo`3oool0A@3oool30?l007<0oooo00<0003o0?ooo`3oool02`3oool50?l0
04<0oooo000=0?ooo`030000o`3oool0oooo04<0oooo1@3o001a0?ooo`030000o`3oool0oooo00`0
oooo1@3o00130?ooo`003P3oool00`000?l0oooo0?ooo`120?ooo`D0o`00L@3oool00`000?l0oooo
0?ooo`0=0?ooo`<0o`00A03oool000h0oooo00<0003o0?ooo`3oool0@P3oool50?l00700oooo00<0
003o0?ooo`3oool0E@3oool000l0oooo00<0003o0?ooo`3oool0@P3oool30?l00740oooo00<0003o
0?ooo`3oool0E@3oool000l0oooo00<0003o0?ooo`3oool0]@3oool00`000?l0oooo0?ooo`1F0?oo
o`00403oool00`000?l0oooo0?ooo`2d0?ooo`030000o`3oool0oooo05H0oooo000@0?ooo`030000
o`3oool0oooo0;<0oooo00<0003o0?ooo`3oool0E`3oool00100oooo00<0003o0?ooo`3oool0/P3o
ool00`000?l0oooo0?ooo`1H0?ooo`004@3oool00`000?l0oooo0?ooo`2a0?ooo`030000o`3oool0
oooo05P0oooo000A0?ooo`030000o`3oool0oooo0;00oooo00<0003o0?ooo`3oool0F@3oool00180
oooo00<0003o0?ooo`3oool0[`3oool00`000?l0oooo0?ooo`1I0?ooo`004`3oool00`000?l0oooo
0?ooo`2]0?ooo`030000o`3oool0oooo05X0oooo000D0?ooo`030000o`3oool0oooo0:/0oooo00<0
003o0?ooo`3oool0F`3oool001@0oooo00<0003o0?ooo`3oool0Z`3oool00`000?l0oooo0?ooo`1K
0?ooo`005@3oool00`000?l0oooo0?ooo`1;0?ooo`<0o`00F`3oool00`000?l0oooo0?ooo`1L0?oo
o`005@3oool00`000?l0oooo0?ooo`1:0?ooo`D0o`00FP3oool00`000?l0oooo0?ooo`1L0?ooo`00
5P3oool00`000?l0oooo0?ooo`190?ooo`D0o`006P3oool00`000000oooo0?ooo`0l0?ooo`030000
o`3oool0oooo05d0oooo000G0?ooo`030000o`3oool0oooo04P0oooo1@3o000B0?ooo`80000000<0
oooo0000000000000`3oool00`000000oooo0?ooo`05000003L0oooo00<0003o0?ooo`3oool0G@3o
ool001L0oooo00<0003o0?ooo`3oool0B@3oool30?l001@0oooo00<000000?ooo`0000000P3oool5
00000080oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`1N0?ooo`00603oool00`00
0?l0oooo0?ooo`1H0?ooo`D000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`1O0?ooo`006@3oool00`000?l0
oooo0?ooo`1H0?ooo`040000003oool0oooo00000080oooo100000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`1P0?ooo`006P3oool00`000?l0
oooo0?ooo`1H0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool07`3oool200000003
0?ooo`000000000000l0oooo00<0003o0?ooo`3oool0203oool30?l005H0oooo000K0?ooo`030000
o`3oool0oooo05P0oooo00<000000?ooo`3oool0303oool200000280oooo00<000000?ooo`000000
3`3oool00`000?l0oooo0?ooo`080?ooo`D0o`002@3oool2000004X0oooo000L0?ooo`030000o`3o
ool0oooo05D0oooo00@000000?ooo`3oool00000:P3oool5000000<0oooo00<000000?ooo`000000
3P3oool00`000?l0oooo0?ooo`080?ooo`D0o`00203oool00`000000oooo0?ooo`1:0?ooo`00703o
ool00`000?l0oooo0?ooo`1E0?ooo`D00000:P3oool010000000oooo0?ooo`0000020?ooo`@00000
3@3oool00`000?l0oooo0?ooo`090?ooo`D0o`00203oool3000004X0oooo000M0?ooo`030000o`3o
ool0oooo08@0oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0;0?ooo`<0o`002@3o
ool00`000000oooo0?ooo`1:0?ooo`007P3oool00`000?l0oooo0?ooo`240?ooo`030000003oool0
oooo0100oooo00<0003o0?ooo`3oool04P3oool3000000040?ooo`000000oooo0?ooo`800000BP3o
ool001l0oooo00<0003o0?ooo`3oool0P@3oool010000000oooo0?ooo`00000@0?ooo`030000o`3o
ool0oooo01@0oooo00@000000?ooo`0000000000CP3oool00200oooo00<0003o0?ooo`3oool0G03o
ool30?l00240oooo1@00000>0?ooo`030000o`3oool0oooo01D0oooo00@000000?ooo`0000000000
CP3oool00240oooo00<0003o0?ooo`3oool0FP3oool50?l003<0oooo00<0003o0?ooo`3oool05@3o
ool2000000030?ooo`000000oooo04d0oooo000R0?ooo`80003oFP3oool50?l00340oooo0P000?lH
0?ooo`80000000<0oooo0000003oool0C@3oool002<0oooo00<0003o0?ooo`3oool0F03oool50?l0
0300oooo00<0003o0?ooo`3oool05`3oool2000000030?ooo`000000000004h0oooo000T0?ooo`03
0000o`3oool0oooo05P0oooo0`3o000S0?ooo`<0o`002P3oool00`000?l0oooo0?ooo`1[0?ooo`00
9@3oool00`000?l0oooo0?ooo`1l0?ooo`D0o`00203oool00`000?l0oooo0?ooo`0E0?ooo`D00000
DP3oool002H0oooo00<0003o0?ooo`3oool0N`3oool50?l000L0oooo00<0003o0?ooo`3oool05P3o
ool01@000000oooo0?ooo`3oool000000580oooo000W0?ooo`030000o`3oool0oooo07X0oooo1@3o
00060?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool0D`3oool002P0oooo00<0003o
0?ooo`3oool0NP3oool30?l000H0oooo00<0003o0?ooo`3oool06P3oool00`000000oooo0?ooo`1B
0?ooo`00:@3oool20000oh40oooo0P000?lK0?ooo`040000003oool0oooo000005<0oooo000[0?oo
o`030000o`3oool0oooo07d0oooo00<0003o0?ooo`3oool06`3oool500000580oooo000/0?ooo`80
003oO03oool00`000?l0oooo0?ooo`1c0?ooo`00;P3oool20000ogP0oooo0P000?mf0?ooo`00<03o
ool00`000?l0oooo0?ooo`1d0?ooo`030000o`3oool0oooo07H0oooo000a0?ooo`030000o`3oool0
oooo0780oooo00<0003o0?ooo`3oool0M`3oool00380oooo0P000?m`0?ooo`80003oNP3oool003@0
oooo00<0003o0?ooo`3oool0J`3oool20000og`0oooo000e0?ooo`030000o`3oool0oooo06T0oooo
00<0003o0?ooo`3oool0O03oool003H0oooo0P000?mW0?ooo`80003oO`3oool003P0oooo0`000?mR
0?ooo`80003oP@3oool003/0oooo0P000?mN0?ooo`80003oP`3oool003d0oooo00<0003o0?ooo`3o
ool0F@3oool20000ohD0oooo000n0?ooo`030000o`3oool0oooo05L0oooo00<0003o0?ooo`3oool0
Q@3oool003l0oooo0`000?mD0?ooo`80003oR03oool00480oooo0P000?m?0?ooo`<0003oRP3oool0
04@0oooo0`000?m:0?ooo`80003oS@3oool004L0oooo1@000?m20?ooo`<0003oS`3oool004`0oooo
0P000?lk0?ooo`D0003oTP3oool004h0oooo0`000?lf0?ooo`80003oU`3oool00540oooo1@000?l/
0?ooo`D0003oV@3oool005H0oooo1@000?lR0?ooo`D0003oWP3oool005/0oooo1`000?lC0?ooo`P0
003oX`3oool00680oooo4`000?n[0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00\
\>"],
    ImageRangeCache->{{{0, 287}, {215, 0}} -> {0, 0, 0, 0}}],
  StyleBox["\n\t\t\tFigure 4.1",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   A sequence ",
  Cell[BoxData[
      \({z\_n}\_1\%\[Infinity]\)]],
  " that converges to ",
  Cell[BoxData[
      \(\[Zeta]\)]],
  ".   (If  ",
  Cell[BoxData[
      \(n > N\_\[Epsilon]\)]],
  " then ",
  Cell[BoxData[
      \(z\_n \[Element] \(D\_\[Epsilon]\) \((\[Zeta])\)\)]],
  ".)"
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 4.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The reason we use the notation ",
  Cell[BoxData[
      \(N\_\[Epsilon]\)]],
  " is to emphasize the fact that this number depends on our choice of ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  ".  Sometimes it will be convenient to drop the subscript."
}], "Text"],

Cell["\<\
\tIn form, Definition 4.1 is exactly the same as the corresponding definition \
for limits of real sequences.  In fact, a simple criterion casts the \
convergence of complex sequences in terms of the convergence of real \
sequences.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 4.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(z\_n = x\_n + \[ImaginaryI]\ y\_n\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Zeta] = u + \[ImaginaryI]\ v\)]],
  ".  Then \n\n ",
  StyleBox["(4-6)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ z\_n = \[Zeta]\)]],
  ",   iff  \n\n ",
  StyleBox["(4-7)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      RowBox[{\(lim\+\(n \[Rule] \[Infinity]\)\ x\_n\), "=", 
        RowBox[{
          RowBox[{"u", "    ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], 
            "    ", \(lim\+\(n \[Rule] \[Infinity]\)\ y\_n\)}], "=", 
          "v"}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.1 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the limit of the sequence  ",
  Cell[BoxData[
      \({z\_n} = {\(\@n\  + \ \[ImaginaryI] \((\ n + 1)\)\)\/n}\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We write  ",
  Cell[BoxData[
      \(z\_n\  = \ \(x\_n + \[ImaginaryI]\ y\_n\  = \ \(\(1\)\(\ \)\)\/\@n\  \
+ \ \[ImaginaryI] \( n + 1\)\/n\)\)]],
  ".  Using results concerning sequences of real numbers, we find that  \n\n\t\
",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ 
          x\_n = \(lim\+\(n \[Rule] \[Infinity]\)\ \(\(1\)\(\ \)\)\/\@n = 
          0\)\)]],
  "    and    ",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ 
          y\_n = \(lim\+\(n \[Rule] \[Infinity]\)\ \(n + 1\)\/n = 1\)\)]],
  ".  \n\nTherefore  ",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ 
          z\_n\  = \ \(lim\+\(n \[Rule] \[Infinity]\)\ \(\@n\  + \ \
\[ImaginaryI] \((\ n + 1)\)\)\/n\  = \ \(0 + \[ImaginaryI]\  = \ \
\[ImaginaryI]\)\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the formula for the terms of the sequence.", "Text"],

Cell[BoxData[{
    \(\(Remove[x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[limX, limY, limZ, n];\)\ \), "\n", 
    \(\(x\_n_\  = \ \@n\/n;\)\ \), "\n", 
    \(\(y\_n_\  = \ \(n + 1\)\/n;\)\ \), "\n", 
    \(\(z\_n_\  = \ 
        x\_n\  + \ \[ImaginaryI]\ y\_n;\)\ \), "\[IndentingNewLine]", 
    \(\(table = Table[z\_n, {n, 1, 9}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\n", 
    \(\(limX\  = \ Limit[x\_n, \ n \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(limY\  = \ Limit[y\_n, \ n \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(limZ\  = \ 
        Limit[z\_n, \ n \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_n\) = \>\"", 
        z\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_n\) = \>\"", 
        x\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_n\) = \>\"", 
        y\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(x\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", x\_n, "\< = \>", 
        limX];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(y\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", y\_n, "\< = \>", 
        limY];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(z\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(z\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The limit of the sequence is\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(z\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) (\>\"", 
        z\_n, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(z\_n\) = \>\"", 
        limX, "\< + \[ImaginaryI] (\>", 
        limY, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(z\_n\) = \>\"", 
        limZ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to compute some of the terms in the sequence."
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(z\_n\) = z(n) = \>\""\ , 
        z\_n];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Table[{"\<z\>"\_n, "\<=\>", z\_n, "\<=\>", 
              PaddedForm[N[z\_n], {12, 12}]}, {n, 1, 20}]]];\)\ \)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to compute more of the terms in the sequence."
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(z\_\(2\^n\)\) = z(\!\(2\^n\)) = \>\""\ , 
        z\_\(2\^n\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Table[{"\<z\>"\_\(2\^n\), "\<=\>", z\_\(2\^n\), "\<=\>", 
              PaddedForm[N[z\_\(2\^n\)], {12, 12}]}, {n, 1, 
              20}]]];\)\ \)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the terms in the sequence."
}], "Text"],

Cell[BoxData[{
    \(\(set\  = \ \ Table[{N[x\_n], N[y\_n]}, {n, 1, 
            50}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{PointSize[0.025], Red, 
            Point[{0, 1}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(gr = 
        ListPlot[set, Prolog \[Rule] {PointSize[0.02], Blue}, 
          PlotRange \[Rule] {{0.0, 1.0}, {0.0, 2.0}}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \[IndentingNewLine]Ticks \
\[Rule] {Range[0, 1, 1\/2], Range[0, 2, 1\/2]}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[gr, dot, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(z\_n\) = \
\!\(lim\+\(n \[Rule] \[Infinity]\)\) (\>\"", z\_n, "\<) = \>", 
        limX, "\< + \[ImaginaryI] (\>", limY, "\<) = \>", 
        limZ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the limit of the sequence  ",
  Cell[BoxData[
      \({z\_n} = {\(\@n\  + \ \[ImaginaryI] \((\ n + 1)\)\)\/n}\ \ \ is\
\ \ \ \[ImaginaryI]\)]],
  ".  However, the real part is converging slowly to 0  and the imaginary \
part is converging a little faster to  ",
  Cell[BoxData[
      \(\[ImaginaryI]\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the sequence  ",
  Cell[BoxData[
      \({z\_n} = {\((1 + \[ImaginaryI])\)\^n}\)]],
  "  diverges.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We have  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(z\_n\ \  = \ \(\((1 + \[ImaginaryI])\)\^n\  = \ 
          x\_n\  + \ \[ImaginaryI]\ y\_n\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(z\_n\ \ \  = \ \((\@2)\)\^n\ \ cos \( n\ \[Pi]\)\/4\  + \ \
\[ImaginaryI]\ \ \((\@2)\)\^n\ sin \( n\ \[Pi]\)\/4\)}]],
  "  \n\nThe real sequences  ",
  Cell[BoxData[
      \(x\_n\  = \ \((\@2)\)\^n\ \ cos \( n\ \[Pi]\)\/4\)]],
  "  and  ",
  Cell[BoxData[
      \(\(\(\ \)\(y\_n\  = \ \((\@2)\)\^n\ sin \( n\ \[Pi]\)\/4\)\)\)]],
  "  both exhibit divergent oscillations, so we conclude that  ",
  Cell[BoxData[
      \(z\_n\  = \ \((1 + \[ImaginaryI])\)\^n\)]],
  "  diverges."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 4.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the formula for the terms of the sequence, and determine if the \
sequence converges or diverges.\
\>", "Text"],

Cell[BoxData[{
    \(\(Remove[x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[limX, limY, limZ, n];\)\ \), "\n", 
    \(\(z\_n_ = \ \((1\  + \ \[ImaginaryI])\)\^n;\)\ \), \
"\[IndentingNewLine]", 
    \(\(table = Table[z\_n, {n, 1, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\n", 
    \(\(lim\  = \ 
        Limit[z\_n, \ n \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(z\_n\)} = {\>\"", 
        z\_n, "\<}\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(z\_n\)} = {\>\"", 
        ComplexExpand[z\_n], "\<}\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(z\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(z\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", z\_n, "\< = \>", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Investigate the limit in more detail.", "Text"],

Cell[BoxData[{
    \(\(x\_n_ = ComplexExpand[Re[z\_n]];\)\ \), "\[IndentingNewLine]", 
    \(\(y\_n_ = ComplexExpand[Im[z\_n]];\)\ \), "\n", 
    \(\(limX\  = \ Limit[x\_n, \ n \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(limY\  = \ Limit[y\_n, \ n \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(limZ\  = \ limX\  + \ \[ImaginaryI]\ limY;\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(x\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", x\_n, "\< = \>", 
        limX];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(y\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", y\_n, "\< = \>", 
        limY];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(z\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", z\_n, "\< = \>", 
        limX, "\< + \[ImaginaryI] (\>", 
        limY, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(z\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", z\_n, "\< = \>", 
        limZ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Therefore, the limit of the sequence does ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " exist, and exhibits \"divergent oscillations.\""
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Table[x\_n, {n, 1, 14}], 
        PlotStyle \[Rule] {Red, PointSize[0.025]}, 
        PlotRange \[Rule] {{0, 14}, {\(-65\), 
              25}}];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(x\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", x\_n, "\< = \>", 
        limX];\)\ \), "\n", 
    \(\(Print[\*"\"\<   {\!\(x\_n\)}  diverges\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(ListPlot[Table[y\_n, {n, 1, 14}], 
        PlotStyle \[Rule] {Blue, PointSize[0.025]}, 
        PlotRange \[Rule] {{0, 14}, {\(-130\), 
              35}}];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(y\_n\) = \>\"", \
\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", y\_n, "\< = \>", 
        limY];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   {\!\(y\_n\)}  diverges\>\""];\)\ \)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to compute some of the terms in the sequence."
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\< \!\(z\_n\) = z(n) = \>\""\ , 
        z\_n];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Table[{"\< z\>"\_n, "\<=\>", z\_n, "\<=\>", 
              PaddedForm[N[z\_n], {12, 12}]}, {n, 1, 
              40}]]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(z\_n\)}  diverges\>\""];\)\ \)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the terms in the sequence."
}], "Text"],

Cell[BoxData[{
    \(\(set\  = \ \ Table[{N[x\_n], N[y\_n]}, {n, 1, 
            7}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[set, Prolog \[Rule] {PointSize[0.03], Magenta}, 
        PlotRange \[Rule] {{\(-4.3\), 8.0}, {\(-9.0\), 2.5}}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \[IndentingNewLine]AspectRatio \
\[Rule] 1, 
        Ticks \[Rule] {Range[\(-4\), 8, 2], 
            Range[\(-8\), 2, 2]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(z\_n\)  = z(n) = \>\""\ , 
        z\_n];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(z\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", 
        z\_n, "\< = \>", limX, "\< + \[ImaginaryI] \>", 
        limY];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(z\_n\)}  diverges\>\""];\)\ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the sequence  ",
  Cell[BoxData[
      \({z\_n} = {\((1 + \[ImaginaryI])\)\^n}\)]],
  "  is divergent.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Definition 4.2 (Bounded Sequence).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  A complex sequence ",
  Cell[BoxData[
      \({z\_n}\)]],
  " is bounded provided that there exists a positive real number ",
  StyleBox["R",
    FontFamily->"Courier New"],
  " and an integer ",
  StyleBox["N",
    FontFamily->"Courier New"],
  " such that  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_n\)\(|\)\(\(<\)\(\ \)\(R\)\)\)\)]],
  "  for all  ",
  Cell[BoxData[
      \(n > N\)]],
  ".  In other words, for ",
  Cell[BoxData[
      \(n > N\)]],
  ", the sequence ",
  Cell[BoxData[
      \({z\_n}\)]],
  " is contained in the disk  ",
  Cell[BoxData[
      \(\(D\_R\) \((0)\)\)]],
  ".  "
}], "Text"],

Cell["\<\
\tBounded sequences play an important role in some newer developments in \
complex analysis that are discussed in Section 4.2.  A theorem from real \
analysis stipulates that convergent sequences are bounded.  The same result \
holds for complex sequences.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 4.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If ",
  Cell[BoxData[
      \({z\_n}\)]],
  " is a convergent sequence, then ",
  Cell[BoxData[
      \({z\_n}\)]],
  " is bounded.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.2 is left as an exercise in the \
book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\<\
\tAs with real numbers, we also have the following definition.  \
\>", "Text"],

Cell[TextData[{
  StyleBox["Definition 4.3 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Cauchy Sequence",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CauchySequence.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The sequence ",
  Cell[BoxData[
      \({z\_n}\)]],
  " is said to be a ",
  StyleBox[ButtonBox["Cauchy sequence",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CauchySequence.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " if for every  ",
  Cell[BoxData[
      \(\[Epsilon] > 0\)]],
  "  there exists a positive integer  ",
  Cell[BoxData[
      \(N\_\[Epsilon]\)]],
  ",  such that if  ",
  Cell[BoxData[
      \(n, m\  > N\_\[Epsilon]\)]],
  ",  then  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_n - z\_m\)\(|\)\(\(<\)\(\[Element]\)\)\)\)]],
  ",  or, equivalently,  ",
  Cell[BoxData[
      \(z\_n - z\_m\  \[Element] \ \(D\_\[Epsilon]\) \((0)\)\)]],
  ".  "
}], "Text"],

Cell["\tThe following should now come as no surprise.", "Text"],

Cell[TextData[{
  StyleBox["Theorem 4.3,  (Cauchy Sequences Converge).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \({z\_n}\)]],
  "  is a Cauchy sequence, then ",
  Cell[BoxData[
      \({z\_n}\)]],
  "  converges."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.3 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  "\tOne of the most important notions in analysis (real or complex) is a \
theory that allows us to add up infinitely many terms.  To make sense of such \
an idea we begin with a sequence ",
  Cell[BoxData[
      \({z\_n}\)]],
  ", and form a new sequence ",
  Cell[BoxData[
      \({S\_n}\)]],
  ", called the sequence of partial sums, as follows. \n\n\t\t\t\t",
  Cell[BoxData[{
      RowBox[{\(S\_1\  = \ z\_1\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(S\_2\  = \ z\_1 + z\_2\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(S\_3\  = \ z\_1 + z\_2 + z\_3\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", "      ", 
        "\[VerticalEllipsis]"}], "\[IndentingNewLine]", 
      RowBox[{\(S\_n\  = \ \(\(z\_1 + z\_2 +  ... \) + 
              z\_n\  = \ \[Sum]\+\(k = 1\)\%\[Infinity] z\_k\)\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", "      ", 
        "\[VerticalEllipsis]"}]}]],
  "   "
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 4.4 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Infinite Series",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Series.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The formal expression ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 1\)\%\[Infinity] z\_k\  = \ \(z\_1 + z\_2 +  ... \) + 
            z\_n +  ... \)]],
  "  is called an infinite series, and  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_n\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  ",  are called the terms of the series.  "
}], "Text"],

Cell[TextData[{
  "\tIf there is a complex number ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " for which \n\n\t\t\t",
  Cell[BoxData[
      \(S\  = \ \(lim\+\(n \[Rule] \[Infinity]\)\ S\_n\  = \ 
          lim\+\(n \[Rule] \[Infinity]\)\(\[Sum]\+\(k = 1\)\%n z\_k\)\)\)]],
  ",  \n\t\t\t\nwe will say that the infinite series ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 1\)\%\[Infinity] z\_k\)]],
  " converges to ",
  StyleBox["S",
    FontFamily->"Courier New"],
  ", and that ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " is the sum of the infinite series.  When this occurs, we write \n\n\t\t\t\
",
  Cell[BoxData[
      \(S = \[Sum]\+\(k = 1\)\%\[Infinity] z\_k\)]],
  ".  \n\n\tThe series  ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 1\)\%\[Infinity] z\_k\)]],
  "  is said to be absolutely convergent provided that the (real) series of \
magnitudes  ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 1\)\%\[Infinity]\(\(|\)\(z\_k\)\(|\)\)\)]],
  "  converges.  \n\n\tIf a series does not converge, we say that it \
diverges. "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 4.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The first finitely many terms of a series do not affect its convergence \
or divergence and, in this respect, the beginning index of a series is \
irrelevant.  Thus, we will without comment conclude that if a series  ",
  Cell[BoxData[
      \(\[Sum]\+\(k = N + 1\)\%\[Infinity] z\_k\)]],
  "  converges, then so does  ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 1\)\%\[Infinity] z\_k\)]],
  ",  where  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_N\)}]]],
  "  i",
  "s any fin",
  "ite collection of terms.  A similar remark holds for determining \
divergence of a series."
}], "Text"],

Cell["\<\
\tAs you might expect, many of the results concerning real series carry over \
to complex series.  We now give several of the more standard theorems for \
complex series, along with examples of how they are used.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 4.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(z\_n = x\_n + \[ImaginaryI]\ y\_n\)]],
  "  and  ",
  Cell[BoxData[
      \(S = U + \[ImaginaryI]\ V\)]],
  ".  Then  \n\n\t\t\t",
  Cell[BoxData[
      \(S\  = \ \(\[Sum]\+\(n = 1\)\%\[Infinity] z\_n\  = \ \[Sum]\+\(n = 1\)\
\%\[Infinity]\((x\_n + \[ImaginaryI]\ y\_n)\)\)\)]],
  "     (converges) \n\nif and only if both  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{"U", " ", "=", " ", 
        RowBox[{
          RowBox[{\(\[Sum]\+\(n = 1\)\%\[Infinity]\), 
            RowBox[{\(x\_n\), "   ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "    ", "V"}]}], " ", "=", 
          " ", \(\[Sum]\+\(n = 1\)\%\[Infinity] y\_n\)}]}]]],
  "     (converge).  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.4 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 4.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] z\_n\)]],
  "  is a convergent complex series, then  ",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ z\_n = 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.5 is left as an exercise in the \
book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\( 1\  + \ \[ImaginaryI]\ n \
\((\(-1\))\)\^n\)\/n\^2\  = \ \[Sum]\+\(n = 1\)\%\[Infinity]\([1\/n\^2 + \
\[ImaginaryI] \((\(-1\))\)\^n\/n]\)\)]],
  "  ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FormBox["",
            "TraditionalForm"],
          FontSize->14], TraditionalForm]]],
  "is convergent."
}], "Text"],

Cell[TextData[{
  "Solution.  Recall that the real series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] 1\/n\^2\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\((\(-1\))\)\^n\/n\)]],
  "  are convergent.  Hence, Theorem 4.4 implies that the given complex \
series is convergent.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 4.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the formula for the series, and determine if the series converges or \
diverges.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{\(Clear[k, n, sumX, sumY, sumZ];\), " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"sumX", " ", "=", 
          StyleBox[\(\[Sum]\+\(n = 1\)\%\[Infinity] 1\/n\^2\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"sumY", " ", "=", " ", 
          
          StyleBox[\(\[Sum]\+\(n = 1\)\%\[Infinity]\( n \
\((\(-1\))\)\^n\)\/n\^2\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{\(sumZ\  = \ sumX\  + \ \[ImaginaryI]\ sumY;\), 
      " "}], "\n", \(Print["\<The real and imaginary parts are\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<         \!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(1\/n\^2\) = \
\>\"", 
            StyleBox[",",
              FontSize->14], "sumX"}], "]"}], ";"}], " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<    \!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\(n \
\((\(-1\))\)\^n\)\/n\^2\) = \>\"", 
            StyleBox[",",
              FontSize->14], "sumY"}], "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), 
      " "}], "\n", \(Print["\<The complex series is\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\(1 + \
\[ImaginaryI]\\\ n \((\(-1\))\)\^n\)\/n\^2\) = \>\"", sumZ];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\(1 + \
\[ImaginaryI]\\\ n \((\(-1\))\)\^n\)\/n\^2\) = \>\"", N[sumZ]];\), 
      " "}]}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(X\_n_\  = \[Sum]\+\(k = 1\)\%n 1\/k\^2;\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(Y\_n_\  = \[Sum]\+\(k = 1\)\%n\((\(-1\))\)\^k\/k\), 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(S\_n_\), " ", "=", " ", 
          RowBox[{
            StyleBox[\(\[Sum]\+\(k = 1\)\%n 1\/k\^2\),
              FontSize->14], 
            StyleBox[" ",
              FontSize->14], 
            StyleBox["+",
              FontSize->14], 
            StyleBox[" ",
              FontSize->14], 
            RowBox[{"\[ImaginaryI]", "  ", 
              StyleBox[\(\[Sum]\+\(k = 1\)\%n\((\(-1\))\)\^k\/k\),
                FontSize->14]}]}]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\[IndentingNewLine]", 
    RowBox[{\(table = Table[FullSimplify[S\_n], {n, 1, 10}];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(table = Append[table, "\<...\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\< \!\(S\_n\)  = (\!\(\[Sum]\+\(k = 1\)\%n\)\!\(1\/k\
\^2\)) + \[ImaginaryI](\!\(\[Sum]\+\(k = \
1\)\%n\)\!\(\((\(-1\))\)\^k\/k\))\>\""];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", table];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", N[table]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(S\_n\) = (\!\(\[Sum]\+\(k = \
1\)\%n\)\!\(1\/k\^2\)) + \[ImaginaryI](\!\(\[Sum]\+\(k = \
1\)\%n\)\!\(\((\(-1\))\)\^k\/k\)) = \>\"", S\_n];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print["\<The sum of the infinite series is\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<S = \!\(\[Sum]\+\(k = \
1\)\%\[Infinity]\)\!\(1\/\(\(k\^2\)\(\\\ \)\)\)+ \[ImaginaryI]\!\(\[Sum]\+\(k \
= 1\)\%\[Infinity]\)\!\(\((\(-1\))\)\^k\/k\) = \>\"", sumZ];\), 
      " "}]}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to compute some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(S\_n\) = S(n) = \>\""\ , 
        S\_n];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Table[{"\<S\>"\_n, "\<=\>", Simplify[S\_n], "\<=\>", 
              PaddedForm[N[S\_n], {12, 12}]}, {n, 1, 20}]]];\)\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\(set\  = \ \ Table[{X\_n, Y\_n}, {n, 1, 
            30}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{PointSize[0.02], Red, 
            Point[{sumX, sumY}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(graph = 
        ListPlot[set, Prolog \[Rule] {PointSize[0.02], Blue}, 
          PlotRange \[Rule] {{0.9, 
                1.7}, {\(-1.05\), \(-0.4\)}}, \[IndentingNewLine]AxesLabel \
\[Rule] {"\<x\>", "\<y\>"}, \[IndentingNewLine]Ticks \[Rule] {Range[0.8, 2, 
                0.2], Range[\(-1\), \(-0.6\), 0.2]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph, dot, AxesOrigin \[Rule] {0.9, \(-0.4\)}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(S\_n\) = S(n) = \>\""\ , 
        S\_n];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(S\_n\) = \>\"", 
        sumZ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(S\_n\) = \>\"", 
        N[sumZ]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<S = \!\(\[Sum]\+\(k = 1\)\%\[Infinity]\)\!\(\(1 + \
\[ImaginaryI]\\\ k \((\(-1\))\)\^k\)\/k\^2\) = \>\"", 
        sumZ\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S = \!\(\[Sum]\+\(k = 1\)\%\[Infinity]\)\!\(\(1 + \
\[ImaginaryI]\\\ k \((\(-1\))\)\^k\)\/k\^2\) = \>\"", 
        N[sumZ]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Therefore, we see that the infinite series converges, indeed  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\( 1\  + \ \[ImaginaryI]\ n \
\((\(-1\))\)\^n\)\/n\^2 = \[Pi]\^2\/6 - \[ImaginaryI]\ Log[2]\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\(\((\(-1\))\)\^n + \[ImaginaryI]\)\/n\ \
 = \ \[Sum]\+\(n = 1\)\%\[Infinity]\([\((\(-1\))\)\^n\/n + \[ImaginaryI] 
                 1\/n]\)\)]],
  "  is divergent."
}], "Text"],

Cell[TextData[{
  "Solution.  We know that the real series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] 1\/n\)]],
  "  is divergent.  Hence, Theorem 4.4 implies that the given complex series \
is divergent."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 4.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the formula for the series, and determine if the series converges or \
diverges.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[n, sumN, sumX, sumY, sumZ];\)\ \), "\n", 
    \(\(sumX\  = \ \[Sum]\+\(n = 1\)\%\[Infinity]\((\(-1\))\)\^n\/n;\)\ \), "\
\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = \
1\)\%\[Infinity]\)\!\(\((\(-1\))\)\^n\/n\) = \>\"", sumX];\)\ \), "\n", 
    \(\(Print["\<The real part converges.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(sumY\  = \ \[Sum]\+\(n = 1\)\%\[Infinity] 1\/n;\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(1\/n\) = \>\"", 
        sumY];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The imaginary part diverges.\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(sumZ\  = \ 
        sumX\  + \ \[ImaginaryI]\ sumY;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = \
1\)\%\[Infinity]\)\!\(\(\((\(-1\))\)\^n + \[ImaginaryI]\)\/n\) = \>\"", 
        sumZ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The series diverges.\>"];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Remark 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  Since the answer returned for the imaginary part was  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] 1\/n\)]],
  ",  this means that a sum was not found.\nIt is known that the partial sums \
of the harmonic series grow slowly without bound.  \nFor example, adding 10,  \
100,  1000  and  10000 terms yields:"
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%m\)\!\(1\/n\) = \>\"", \
\[Sum]\+\(n = 1\)\%m 1\/n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          5, \(i++\), \n\ \ Print[\*"\"\<\!\(\[Sum]\+\(n = \
1\)\)\>\""\&\(10\^i\), \*"\"\<\!\(1\/n\) = \>\"", 
          N[HarmonicNumber[10\^i]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Therefore, the series slowly diverges to ",
  Cell[BoxData[
      \(\[Infinity]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  The integral test could also be used."
}], "Text"],

Cell[BoxData[{
    \(\(lim = 
        Limit[\[Integral]\_1\%b\( 1\/x\) \[DifferentialD]x, 
          b \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_1\%\[Infinity]\)\!\(1\/x\)\
\[DifferentialD]x = \>\"", "\<lim\>"\+\(b \[Rule] \[Infinity]\), \*"\"\<\!\(\
\[Integral]\_1\%b\)\!\(1\/x\)\[DifferentialD]x = \>\"", "\<lim\>"\+\(b \
\[Rule] \[Infinity]\), "\< \>", \ \[Integral]\_1\%b\( 
                1\/x\) \[DifferentialD]x\ , "\< = \>", 
        lim];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The integral diverges, therefore\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<the series  \!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(1\/n\
\)  diverges to  \[Infinity].\>\""];\)\ \)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(X\_n_\  = \[Sum]\+\(k = 1\)\%n\((\(-1\))\)\^k\/k;\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(Y\_n_\  = \[Sum]\+\(k = 1\)\%n 1\/k\), 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(S\_n_\), " ", "=", " ", 
          RowBox[{
            StyleBox[\(\[Sum]\+\(k = 1\)\%n\((\(-1\))\)\^k\/k\),
              FontSize->14], 
            StyleBox[" ",
              FontSize->14], 
            StyleBox["+",
              FontSize->14], 
            StyleBox[" ",
              FontSize->14], 
            RowBox[{"\[ImaginaryI]", "  ", 
              StyleBox[\(\[Sum]\+\(k = 1\)\%n 1\/k\),
                FontSize->14]}]}]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\[IndentingNewLine]", 
    RowBox[{\(table = Table[FullSimplify[S\_n], {n, 1, 10}];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(table = Append[table, "\<...\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", table];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", N[table]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\< \!\(S\_n\)  = \!\(\[Sum]\+\(k = \
1\)\%n\)\!\(\((\(-1\))\)\^k\/k\) + \[ImaginaryI]\!\(\[Sum]\+\(k = \
1\)\%n\)\!\(1\/k\) = \>\"", S\_n];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\< \!\(\[Sum]\+\(k = \
1\)\%\[Infinity]\)\!\(\((\(-1\))\)\^k\/k\) + \[ImaginaryI]\!\(\[Sum]\+\(k = 1\
\)\%\[Infinity]\)\!\(1\/k\) = \>\"", S\_\[Infinity]];\), " "}]}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(S\_\(2\^n\)\) = S(\!\(2\^n\)) = \>\""\ , 
        S\_\(2\^n\)];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Table[{"\<S\>"\_\(2\^n\), "\<=\>", 
              PaddedForm[N[S\_\(2\^n\)], {12, 12}]}, {n, 1, 
              17}]]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The series diverges.\>"];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the series ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\((1 + \[ImaginaryI])\)\^n\)]],
  " is divergent.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  Here we set  ",
  Cell[BoxData[
      \(z\_n\ \  = \ \((1 + \[ImaginaryI])\)\^n\)]],
  "  and observe that  \n\n\t\t\t",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ \(\(|\)\(z\_n\)\(|\)\) = \(lim\+\(n \
\[Rule] \[Infinity]\)\ \(\(|\)\(\((1 + \[ImaginaryI])\)\^n\)\(|\)\) = \(lim\+\
\(n \[Rule] \[Infinity]\)\ \ \((\@2)\)\^n = \ \[Infinity]\)\)\)]],
  ".  \n\nThus ",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ z\_n\  \[NotEqual] \ 0\)]],
  ", and Theorem 4.5 implies that the series is not convergent;  hence it is \
divergent. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 4.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the formula ",
  Cell[BoxData[
      \(z\_n = \((1 + \[ImaginaryI])\)\^n\)]],
  " for the terms of the sequence, and look at the modulus."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[limX, limY, limZ, n];\)\ \), "\n", 
    \(\(z\_n_ = \ \((1\  + \ \[ImaginaryI])\)\^n;\)\ \), \
"\[IndentingNewLine]", 
    \(\(m\_n_ = Abs[z\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(M\_n_ = ComplexExpand[m\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(lim\  = \ 
        Limit[m\_n, \ n \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) |\>\"", 
        z\_n, \*"\"\<| = \!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", 
        m\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) |\>\"", 
        z\_n, \*"\"\<| = \!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", 
        M\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) |\>\"", 
        z\_n, "\<| = \>", lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Hence ",
  Cell[BoxData[
      \(lim\+\(n\  \[Rule] \ \[Infinity]\)\ z\_n \[NotEqual] 0\)]],
  ", and the series is divergent."
}], "Text"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will indicate that there is a problem with convergence. "
}], "Text"],

Cell[BoxData[{
    \(\(sum = \[Sum]\+\(n = 1\)\%\[Infinity]\((1 + \[ImaginaryI])\)\^n;\)\ \ \
\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\((1 + \
\[ImaginaryI])\)\^n\) = \>\"", sum];\)\ \)}], "Input"],

Cell[TextData[{
  "Which is comforting to see that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knows the answer too! "
}], "Text"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(S\_n_\), " ", "=", " ", 
          StyleBox[\(\[Sum]\+\(k = 1\)\%n\((1 + \[ImaginaryI])\)\^k\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\[IndentingNewLine]", 
    RowBox[{\(X\_n_\  = ComplexExpand[\ Re[S\_n]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Y\_n_\  = ComplexExpand[Im[S\_n]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(table = Table[FullSimplify[S\_n], {n, 1, 10}];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(table = Append[table, "\<...\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", table];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", N[table]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\< \!\(S\_n\)  =  \!\(\*
StyleBox[\(\[Sum]\+\(k = 1\)\%n\),\nFontSize->14]\)\!\(\*
StyleBox[\"(\",\nFontSize->14]\)\!\(\*
StyleBox[\"1\",\nFontSize->14]\)\!\(\*
StyleBox[\"+\",\nFontSize->14]\)\!\(\*
StyleBox[\"\[ImaginaryI]\",\nFontSize->14]\)\!\(\*
StyleBox[\()\^n\),\nFontSize->14]\) = \>\"", ",", \(S\_n\)}], " ", "]"}], 
        ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\< \!\(X\_n\)  =  Re[\!\(S\_n\)]  =  \>\"", 
          X\_n\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\< \!\(Y\_n\)  =  Im[\!\(S\_n\)]  =  \>\"", 
          Y\_n\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), 
      " "}], "\[IndentingNewLine]", \(Xlim = 
        Limit[X\_n, 
          n \[Rule] \[Infinity]];\), "\[IndentingNewLine]", \(Ylim = 
        Limit[Y\_n, 
          n \[Rule] \[Infinity]];\), "\[IndentingNewLine]", \(Print["\<lim\>"\
\+\(n \[Rule] \[Infinity]\), "\<(\>", X\_n, "\<) = \>", 
      Xlim]\), "\[IndentingNewLine]", \(Print["\<lim\>"\+\(n \[Rule] \
\[Infinity]\), "\<(\>", Y\_n, "\<) = \>", Ylim]\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to compute more of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\< \!\(S\_n\) = S(n) = \>\""\ , 
        S\_n];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Table[{"\<S\>"\_n, "\<=\>", Simplify[S\_n], "\<=\>", 
              PaddedForm[N[S\_n], {20, 12}]}, {n, 1, 40}]]];\)\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\(set\  = \ \ Table[{N[X\_n], N[Y\_n]}, {n, 1, 
            13}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[set, Prolog \[Rule] {PointSize[0.022], Red}, 
        PlotRange \[Rule] {{\(-135\), 50}, {\(-20\), 66}}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \[IndentingNewLine]AspectRatio \
\[Rule] 1, 
        Ticks \[Rule] {Range[\(-120\), 60, 20], 
            Range[\(-20\), 60, 20]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        set];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", 
        S\_n, "\< = \>", Xlim, "\< + \[ImaginaryI] \>", 
        Ylim\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the  series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\((1 + \[ImaginaryI])\)\^n\)]],
  " is divergent.   "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 4.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] z\_n\ \ and\ \ \(\[Sum]\+\(n = 1\)\%\
\[Infinity] w\_n\)\)]],
  "  be convergent series, and let  c  be a complex number.  Then  \n\n\t\t\t\
",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] c\ z\_n = 
        c \(\[Sum]\+\(n = 1\)\%\[Infinity] z\_n\)\)]],
  "  \n\t\tand  \n\t\t\t",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\((z\_n + 
              w\_n)\) = \[Sum]\+\(n = 1\)\%\[Infinity] z\_n + \[Sum]\+\(n = 1\
\)\%\[Infinity] w\_n\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.6 is left as an exercise in the \
book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Definition 4.5 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Cauchy Product of Series",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CauchyProduct.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] a\_n\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] b\_n\)]],
  "  be convergent series, where ",
  Cell[BoxData[
      \(a\_n\ \ and\ \ b\_n\)]],
  "  are complex numbers.  The ",
  StyleBox[ButtonBox["Cauchy product",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CauchyProduct.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " of the two series is defined to be the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] c\_n\)]],
  ",  where  ",
  Cell[BoxData[
      \(c\_n = \[Sum]\+\(k = 1\)\%n\( a\_k\) b\_\(n - k\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 4.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If the Cauchy product converges, then  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] c\_n = \((\[Sum]\+\(n = 1\)\%\
\[Infinity] a\_n)\) \((\[Sum]\+\(n = 1\)\%\[Infinity] b\_n)\)\)]],
  ",  \n\t\twhere  \n\t\t\t",
  Cell[BoxData[
      \(c\_n = \[Sum]\+\(k = 1\)\%n\( a\_k\) b\_\(n - k\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "The proof can be found in a number of texts, for example, ",
  StyleBox[ButtonBox["Infinite Sequences and Series",
    ButtonData:>{
      URL[ 
      "http://www.amazon.com/exec/obidos/tg/detail/-/0486601536/qid=\
1130330440/sr=2-1/ref=pd_bbs_b_2_1/002-9738967-2168054?v=glance&s=books"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ", by ",
  StyleBox[ButtonBox["Konrad Knopp",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Knopp.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " (translated by Frederick Bagemihl;  New York: Dover, 1956)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["Theorem 4.8  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Comparison Test",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ComparisonTest.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] M\_n\)]],
  "  be a convergent series of real nonnegative terms.  If  ",
  Cell[BoxData[
      \({z\_n}\)]],
  "  is a sequence of complex numbers and  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_n\)\(|\)\(\(\[LessEqual]\)\(\ \)\(M\_n\)\)\)\)]],
  "  holds for all  n, then  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] z\_n\)]],
  "  converges."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.8 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Corollary 4.1. ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " If  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\(\(|\)\(z\_n\)\(|\)\)\)]],
  ", then  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] z\_n\)]],
  "  converges.  In other words, absolute convergence implies convergence for \
complex series as well as for real series."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 4.1 is left as an exercise in the \
book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\((3\  + \ 4  \
\[ImaginaryI])\)\^n\/\(5\^n\ n\^2\)\)]],
  "  is convergent."
}], "Text"],

Cell[TextData[{
  "Solution.  We calculate  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_n\)\(|\)\)\ \  = \ \(\(\(|\)\(\((3\  + \ 4  \
\[ImaginaryI])\)\^n\/\(5\^n\ n\^2\)\)\(|\)\)\  = \ \(1\/n\^2\  = \ 
            M\_n\)\)\)]],
  ".    Using the comparison test and the fact that  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] 1\/n\^2\)]],
  "  converges, we determine that  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\(\(|\)\(\((3\  + \ 4  \[ImaginaryI])\)\
\^n\/\(5\^n\ n\^2\)\)\(|\)\)\)]],
  "  converges and hence, by Corollary 4.1, so does ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\((3\  + \ 4  \
\[ImaginaryI])\)\^n\/\(5\^n\ n\^2\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 4.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the formula for the series, and determine if the series converges or \
diverges.\
\>", "Text"],

Cell[BoxData[{
    \(\(Remove[x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[absZn, n, sum, sumX, sumY, sumZ];\)\ \), "\n", 
    \(\(z\_n_\  = \ \((3 + 4  \[ImaginaryI])\)\^n\/\(5\^n\ n\^2\);\)\ \), "\n\
", 
    \(\(x\_n_\  = \ ComplexExpand[Re[z\_n]];\)\ \), "\n", 
    \(\(y\_n_\  = \ ComplexExpand[Im[z\_n]];\)\ \), "\n", 
    \(\(sumX\  = \ \[Sum]\+\(n = 1\)\%\[Infinity] x\_n;\)\ \), "\n", 
    \(\(sumY\  = \ \[Sum]\+\(n = 1\)\%\[Infinity] y\_n;\)\ \), "\n", 
    \(\(sumZ\  = \ \[Sum]\+\(n = 1\)\%\[Infinity] z\_n;\)\ \), "\n", 
    \(\(Print[\*"\"\<  \!\(z\_n\) = \>\"", z\_n];\)\ \), "\n", 
    \(\(Print[\*"\"\<  \!\(z\_n\) = \>\"", 
        ComplexExpand[z\_n]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(x\_n\) = \>\"", x\_n];\)\ \), "\n", 
    \(\(Print[\*"\"\<  \!\(y\_n\) = \>\"", 
        y\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(x\_n\) = \>\"", 
        sumX];\)\ \), "\n", 
    \(\(Print["\<     = \>", 
        FullSimplify[sumX]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<     = \>", Chop[N[sumX]]\ ];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(y\_n\) = \>\"", 
        sumY];\)\ \), "\n", 
    \(\(Print["\<     = \>", 
        FullSimplify[sumY]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<     = \>", Chop[N[sumY]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\((3 + 4  \
\[ImaginaryI])\)\^n\/\(5\^n*n\^2\)\) = \>\"", 
        sumZ\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\((3 + 4  \
\[ImaginaryI])\)\^n\/\(5\^n*n\^2\)\) = \>\"", 
        N[sumZ]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Hence we see that the series converges and that  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\((3\  + \ 4  \
\[ImaginaryI])\)\^n\/\(5\^n\ n\^2\)\  = \ \(PolyLog[2, 
            3\/5 + \(4\ \[ImaginaryI]\)\/5]\  = \ 
          0.403311\[InvisibleSpace] + 1.00841  \[ImaginaryI]\)\)]],
  ".  \nOr we could use Corollary 4.1 and show that the series converges \
absolutely.  "
}], "Text"],

Cell[BoxData[{
    \(\(absZn\  = \ ComplexExpand[Abs[z\_n]];\)\ \), "\n", 
    \(\(sum\ \  = \ \ \[Sum]\+\(n = 1\)\%\[Infinity] 1\/n\^2;\)\ \), "\n", 
    \(\(Print["\<|\>", z\_n, "\<| = \>", 
        absZn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)|\!\(\((3 + 4  \
\[ImaginaryI])\)\^n\/\(5\^n*n\^2\)\)| = \>\"", 
        sum];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The series of absolute values converges, therefore the series converges.\n\
\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\(S\_n_\  = \ \[Sum]\+\(k = 1\)\%n\((3 + 4  \[ImaginaryI])\)\^k\/\(5\^k\
\ k\^2\);\)\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Table[FullSimplify[S\_n], {n, 1, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(S\_n\)  =  \!\(\[Sum]\+\(k = 1\)\%n\)\!\(\((3 + 4  \
\[ImaginaryI])\)\^k\/\(5\^k*k\^2\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_n\) = \!\(\[Sum]\+\(k = 1\)\%n\)\!\(\((3 + 4  \
\[ImaginaryI])\)\^k\/\(5\^k*k\^2\)\) = \>\"", 
        S\_n];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(S\_n\) = S(n) = \>\""\ , 
        S\_n];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Table[{"\<S\>"\_n, "\<=\>", Simplify[S\_n], "\<=\>", 
              PaddedForm[N[S\_n], {12, 12}]}, {n, 1, 20}]]];\)\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to compute more of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(S\_\(2\^n\)\) = S(\!\(2\^n\)) = \>\""\ , 
        S\_\(2\^n\)];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Table[{"\<S\>"\_\(2\^n\), "\<=\>", 
              PaddedForm[N[S\_\(2\^n\)], {12, 12}]}, {n, 1, 
              10}]]];\)\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\(set\  = \ \ Table[{Re[S\_n], Im[S\_n]}, {n, 1, 
            17}];\)\ \), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{{PointSize[0.023], Red, 
              Point[{sumX, sumY}]\ \ }}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(graph = 
        ListPlot[set, Prolog \[Rule] {PointSize[0.023], Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph, dot, PlotRange \[Rule] {{0.35, 0.55}, {0.95, 1.1}}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 1, 0.05], 
            Range[0.6, 1.1, 0.05]}, AxesOrigin \[Rule] {0.35, 0.95}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\((3 + 4  \
\[ImaginaryI])\)\^n\/\(5\^n*n\^2\)\) = \>\"", sumZ, "\< = \>", 
        N[sumZ]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Therefore, we see that the series converges, and we have  ",
  Cell[BoxData[
      \(\(\(\ \)\(\[Sum]\+\(n = 1\)\%\[Infinity]\((3\  + \ 4  \
\[ImaginaryI])\)\^n\/\(5\^n\ n\^2\) = \(PolyLog[2, 
            3\/5 + \(4\ \[ImaginaryI]\)\/5]\  = \ 
          0.403311\[InvisibleSpace] + \(\(1.00841\)  \(\[ImaginaryI]\)\(\ \
\)\)\)\)\)\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Geometric Series",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/GeometricSeriesBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Convergence of Series",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/SeriesConvergenceBib.html"],
     None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Power Series",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/PowerSeriesBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{988, 632},
WindowMargins->{{12, Automatic}, {Automatic, 2}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[56108, 1508, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[71020, 1930, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[73357, 2017, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[82845, 2300, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[83939, 2342, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[106641, 2992, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[110802, 3133, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[111996, 3176, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 122707, 3468}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 157, 3, 33, "Text"],
Cell[2262, 67, 886, 19, 109, "Text"],
Cell[3151, 88, 115, 2, 33, "Text"],
Cell[3269, 92, 8902, 207, 174, "Text"],

Cell[CellGroupData[{
Cell[12196, 303, 101, 2, 33, "Text"],
Cell[12300, 307, 453, 11, 103, "Input"],
Cell[12756, 320, 429, 10, 97, "Input"],
Cell[13188, 332, 512, 12, 118, "Input"],
Cell[13703, 346, 410, 10, 105, "Input"]
}, Closed]],
Cell[14128, 359, 2058, 59, 147, "Text"],
Cell[16189, 420, 2315, 73, 185, "Text"],
Cell[18507, 495, 1135, 38, 52, "Text"],
Cell[19645, 535, 34619, 904, 254, "Text"],
Cell[54267, 1441, 369, 11, 33, "Text"],
Cell[54639, 1454, 256, 5, 52, "Text"],
Cell[54898, 1461, 860, 31, 109, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[55783, 1496, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[55931, 1502, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[56108, 1508, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[56468, 1520, 294, 10, 39, "Text",
  Evaluatable->False],
Cell[56765, 1532, 819, 22, 138, "Text"],

Cell[CellGroupData[{
Cell[57609, 1558, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[57772, 1564, 64, 0, 33, "Text"],
Cell[57839, 1566, 2265, 43, 606, "Input"],
Cell[60107, 1611, 140, 5, 33, "Text"],
Cell[60250, 1618, 276, 6, 50, "Input"],
Cell[60529, 1626, 140, 5, 33, "Text"],
Cell[60672, 1633, 337, 7, 50, "Input"],
Cell[61012, 1642, 137, 5, 33, "Text"],
Cell[61152, 1649, 1030, 21, 193, "Input"],
Cell[62185, 1672, 355, 10, 42, "Text"]
}, Closed]],
Cell[62555, 1685, 278, 10, 30, "Text",
  Evaluatable->False],
Cell[62836, 1697, 737, 18, 154, "Text"],

Cell[CellGroupData[{
Cell[63598, 1719, 244, 9, 33, "Text",
  Evaluatable->False],
Cell[63845, 1730, 127, 3, 33, "Text"],
Cell[63975, 1735, 1002, 19, 259, "Input"],
Cell[64980, 1756, 53, 0, 33, "Text"],
Cell[65036, 1758, 1219, 20, 264, "Input"],
Cell[66258, 1780, 181, 5, 33, "Text"],
Cell[66442, 1787, 1000, 18, 166, "Input"],
Cell[67445, 1807, 140, 5, 33, "Text"],
Cell[67588, 1814, 373, 8, 70, "Input"],
Cell[67964, 1824, 137, 5, 33, "Text"],
Cell[68104, 1831, 1057, 21, 218, "Input"],
Cell[69164, 1854, 148, 5, 33, "Text"]
}, Closed]],
Cell[69327, 1862, 734, 29, 49, "Text"],
Cell[70064, 1893, 280, 5, 52, "Text"],
Cell[70347, 1900, 301, 13, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[70673, 1917, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[70821, 1923, 196, 5, 33, "Text",
  Evaluatable->False],
Cell[71020, 1930, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[71380, 1942, 88, 2, 30, "Text"],
Cell[71471, 1946, 1140, 38, 52, "Text"],
Cell[72614, 1986, 63, 0, 33, "Text"],
Cell[72680, 1988, 327, 13, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[73032, 2005, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[73180, 2011, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[73357, 2017, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[73717, 2029, 3044, 83, 218, "Text"],
Cell[76764, 2114, 1798, 53, 52, "Text"],
Cell[78565, 2169, 1049, 30, 223, "Text"],
Cell[79617, 2201, 1511, 43, 71, "Text"],
Cell[81131, 2246, 236, 4, 52, "Text"],
Cell[81370, 2252, 1125, 32, 147, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[82520, 2288, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[82668, 2294, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[82845, 2300, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[83205, 2312, 362, 13, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[83592, 2329, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[83740, 2335, 196, 5, 33, "Text",
  Evaluatable->False],
Cell[83939, 2342, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[84299, 2354, 518, 17, 33, "Text"],
Cell[84820, 2373, 331, 9, 36, "Text"],

Cell[CellGroupData[{
Cell[85176, 2386, 244, 9, 33, "Text",
  Evaluatable->False],
Cell[85423, 2397, 110, 3, 33, "Text"],
Cell[85536, 2402, 1780, 49, 378, "Input"],
Cell[87319, 2453, 156, 5, 33, "Text"],
Cell[87478, 2460, 2197, 51, 446, "Input"],
Cell[89678, 2513, 154, 5, 33, "Text"],
Cell[89835, 2520, 284, 6, 50, "Input"],
Cell[90122, 2528, 151, 5, 33, "Text"],
Cell[90276, 2535, 1608, 30, 332, "Input"],
Cell[91887, 2567, 254, 6, 37, "Text"]
}, Closed]],
Cell[92156, 2576, 363, 10, 33, "Text"],
Cell[92522, 2588, 233, 6, 36, "Text"],

Cell[CellGroupData[{
Cell[92780, 2598, 244, 9, 33, "Text",
  Evaluatable->False],
Cell[93027, 2609, 110, 3, 33, "Text"],
Cell[93140, 2614, 1056, 20, 385, "Input"],
Cell[94199, 2636, 435, 10, 74, "Text"],
Cell[94637, 2648, 425, 9, 162, "Input"],
Cell[95065, 2659, 123, 5, 33, "Text"],
Cell[95191, 2666, 154, 5, 33, "Text"],
Cell[95348, 2673, 748, 13, 138, "Input"],
Cell[96099, 2688, 156, 5, 33, "Text"],
Cell[96258, 2695, 1861, 44, 381, "Input"],
Cell[98122, 2741, 383, 8, 70, "Input"]
}, Closed]],
Cell[98520, 2752, 297, 10, 30, "Text",
  Evaluatable->False],
Cell[98820, 2764, 596, 14, 109, "Text"],

Cell[CellGroupData[{
Cell[99441, 2782, 244, 9, 33, "Text",
  Evaluatable->False],
Cell[99688, 2793, 175, 5, 33, "Text"],
Cell[99866, 2800, 942, 17, 237, "Input"],
Cell[100811, 2819, 158, 5, 33, "Text"],
Cell[100972, 2826, 229, 8, 33, "Text"],
Cell[101204, 2836, 248, 4, 92, "Input"],
Cell[101455, 2842, 145, 5, 33, "Text"],
Cell[101603, 2849, 156, 5, 33, "Text"],
Cell[101762, 2856, 2144, 47, 424, "Input"],
Cell[103909, 2905, 154, 5, 33, "Text"],
Cell[104066, 2912, 285, 6, 50, "Input"],
Cell[104354, 2920, 151, 5, 33, "Text"],
Cell[104508, 2927, 878, 17, 178, "Input"],
Cell[105389, 2946, 166, 5, 33, "Text"]
}, Closed]],
Cell[105570, 2954, 699, 21, 106, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[106294, 2979, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[106442, 2985, 196, 5, 33, "Text",
  Evaluatable->False],
Cell[106641, 2992, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[107001, 3004, 1124, 35, 49, "Text"],
Cell[108128, 3041, 488, 14, 109, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[108641, 3059, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[108789, 3065, 760, 21, 33, "Text",
  Evaluatable->False]
}, Open  ]],
Cell[109564, 3089, 888, 28, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[110477, 3121, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[110625, 3127, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[110802, 3133, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[111162, 3145, 460, 14, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[111647, 3163, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[111795, 3169, 198, 5, 33, "Text",
  Evaluatable->False],
Cell[111996, 3176, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[112356, 3188, 275, 9, 34, "Text"],
Cell[112634, 3199, 698, 18, 60, "Text"],

Cell[CellGroupData[{
Cell[113357, 3221, 244, 9, 33, "Text",
  Evaluatable->False],
Cell[113604, 3232, 110, 3, 33, "Text"],
Cell[113717, 3237, 1930, 36, 688, "Input"],
Cell[115650, 3275, 417, 9, 55, "Text"],
Cell[116070, 3286, 464, 9, 176, "Input"],
Cell[116537, 3297, 234, 6, 71, "Text"],
Cell[116774, 3305, 922, 17, 290, "Input"],
Cell[117699, 3324, 156, 5, 33, "Text"],
Cell[117858, 3331, 284, 6, 50, "Input"],
Cell[118145, 3339, 154, 5, 33, "Text"],
Cell[118302, 3346, 311, 7, 50, "Input"],
Cell[118616, 3355, 151, 5, 33, "Text"],
Cell[118770, 3362, 1207, 24, 233, "Input"],
Cell[119980, 3388, 374, 9, 36, "Text"]
}, Closed]],
Cell[120369, 3400, 290, 7, 30, "Text"],
Cell[120662, 3409, 289, 7, 33, "Text"],
Cell[120954, 3418, 296, 7, 33, "Text"],
Cell[121253, 3427, 281, 7, 33, "Text"],
Cell[121537, 3436, 257, 5, 33, "Text"],
Cell[121797, 3443, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

