(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     88171,       2509]*)
(*NotebookOutlinePosition[     89208,       2546]*)
(*  CellTagsIndexPosition[     89132,       2540]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["4.2  Julia and Mandelbrot Sets",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tAn impetus for studying complex analysis is the comparison of properties \
of real numbers and functions with their complex counterparts. In this \
section we take a look at Newton's method for finding solutions to the \
equation ",
  Cell[BoxData[
      \(f \((x)\) = 0\)]],
  ".  Then, by examining the more general topic of iteration, we will plunge \
into a breathtaking world of color and imagination. The mathematics \
surrounding this topic has generated a great deal of popular attention in the \
past few years."
}], "Text"],

Cell[TextData[{
  "\tRecall from calculus that ",
  StyleBox[ButtonBox["Newton's method",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/NewtonsMethod.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " method proceeds by starting with a function  f(x)  and an initial \"guess\
\"  ",
  Cell[BoxData[
      \(x\_0\)]],
  "  as a solution to ",
  Cell[BoxData[
      \(f \((x)\) = 0\)]],
  ".  We then generate a new guess  ",
  Cell[BoxData[
      \(x\_1\)]],
  "  by the computation  ",
  Cell[BoxData[
      \(x\_1 = x\_0 - \(f \((x\_0)\)\)\/\(f' \((x\_0)\)\)\)]],
  ".  Using  ",
  Cell[BoxData[
      \(x\_1\)]],
  " in place of  ",
  Cell[BoxData[
      \(x\_0\)]],
  ",  this process is repeated, giving us  ",
  Cell[BoxData[
      \(x\_2 = x\_1 - \(f \((x\_1)\)\)\/\(f' \((x\_1)\)\)\)]],
  ".  Thus we obtain a sequence of points  ",
  Cell[BoxData[
      \({x\_k}\)]],
  ", where  ",
  Cell[BoxData[
      \(x\_\(k + 1\) = x\_k - \(f \((x\_k)\)\)\/\(f' \((x\_k)\)\)\)]],
  ".  The points  ",
  Cell[BoxData[
      \({x\_k}\_\(k = 0\)\%\[Infinity]\)]],
  "  are called the iterates of  ",
  Cell[BoxData[
      \(x\_0\)]],
  ".  For functions defined on the real numbers, this method gives remarkably \
good results so that the sequence  ",
  Cell[BoxData[
      \({x\_k}\)]],
  "  often converges to a solution of  ",
  Cell[BoxData[
      \(f \((x)\) = 0\)]],
  "  rather quickly.  In the late 1800's the british mathematician ",
  StyleBox[ButtonBox["Arthur Cayley",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cayley.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " investigated the question as to whether Newton's method can be applied to \
complex functions.  He wrote a paper giving an analysis for how this method \
works for quadratic polynomials and indicated his intention to publish a \
subsequent paper for cubic polynomials.  Unfortunately, Cayley died before \
producing this paper. As you will see, the extension of ",
  StyleBox[ButtonBox["Newton's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Newton.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " method to the complex domain and the more general question of iteration \
are quite complicated."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 4.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Trace out the next five iterates of Newton's method given an initial \
guess of  ",
  Cell[BoxData[
      \(z\_0 = 1\/4 + \[ImaginaryI]\/4\)]],
  "  as a solution to the equation  ",
  Cell[BoxData[
      \(f \((z)\) = 0\)]],
  ",  where  ",
  Cell[BoxData[
      \(f \((z)\) = z\^2 + 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  For any guess z for a solution, Newton's method gives as the \
next guess the number ",
  Cell[BoxData[
      \(z - \(f \((z)\)\)\/\(f' \((z)\)\)\  = \ \(z - \(z\^2 + 1\)\/\(2  z\)\ \
 = \ \(z\^2 - 1\)\/\(2  z\)\)\)]],
  ".  Table 4.1 gives the required iterates.  "
}], "Text"],

Cell[TextData[{
  "\tFigure 4.2 shows the relative positions of these points on the z plane.  \
Note that the points ",
  Cell[BoxData[
      RowBox[{\(z\_4\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(z\_5\)}]]],
  " are so close together that they appear to coincide, and that the value \
for ",
  Cell[BoxData[
      \(z\_5\)]],
  " agrees to six decimal places with the actual solution ",
  Cell[BoxData[
      \(z = \[ImaginaryI]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      RowBox[{
        TagBox[GridBox[{
              {
                "k", \(\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \)\(z\_k\)\), \(\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \)\(f \((z\_k)\)\)\)},
              {
                "0", \(\(\ \ \ \)\(0.2500000000\ \ \ \ \ \ \ \ \ \ \ \ \ \
\[InvisibleSpace] + \ 
                  0.2500000000\ \[ImaginaryI]\)\), \
\(1.0\[InvisibleSpace]000000000\ \ \ \ \ \ \ \ \ \ \ \ \  + \ 
                  0.1250000000\ \[ImaginaryI]\)},
              {
                "1", \(\(-0.8750000000\)\ \ \ \ \ \ \ \ \ \ \ \ \  + \ 
                  1.1250000000\ \[ImaginaryI]\), \
\(0.5\[InvisibleSpace]000000000\ \ \ \ \ \ \ \ \ \ \ \ \  - \ 
                  1.9687500000\ \[ImaginaryI]\)},
              {
                "2", \(\(-0.2221153846\)\ \ \ \ \ \ \ \ \ \ \ \ \  + \ 
                  0.8394230769\ \[ImaginaryI]\), \(0.3447041420\ \ \ \ \ \ \ \
\ \ \ \ \ \  - \ 0.3728975591\ \[ImaginaryI]\)},
              {
                "3", \(\(\ \ \ \)\(0.0362402512\[InvisibleSpace]\ \ \ \ \ \ \ \
\ \ \ \ \ \  + \ 
                  0.9763829875\ \[ImaginaryI]\)\), \(0.0479896174\
\[InvisibleSpace]\ \ \ \ \ \ \ \ \ \ \ \ \  + \ 
                  0.0707687295\ \[ImaginaryI]\)},
              {
                "4", \(\(-0.0008610408\)\ \ \ \ \ \ \ \ \ \ \ \ \  + \ 
                  0.9995811063\ \[ImaginaryI]\), \(0.0008383531\
\[InvisibleSpace]\ \ \ \ \ \ \ \ \ \ \ \ \  - \ 
                  0.0017213603\ \[ImaginaryI]\)},
              {
                "5", \(\(\ \ \ \)\(3.6059156651\[Times]10\^\(-7\)\  + \ 
                  0.9999997166\ \[ImaginaryI]\)\), \(5.6677795053\[Times]10\^\
\(-7\)\  + \ 7.2118292865\[Times]10\^\(-7\)\ \[ImaginaryI]\)},
              {
                "6", \(\(-1.0218768555\)\[Times]10\^\(-13\) + \ 
                  0.9999999999\ \[ImaginaryI]\), \
\(4.9717068413\[Times]10\^\(-14\) - \ 
                  2.0437537111\[Times]10\^\(-13\)\ \[ImaginaryI]\)}
              },
            RowSpacings->1,
            ColumnSpacings->3,
            RowAlignments->Baseline,
            ColumnAlignments->{Left}],
          Function[ BoxForm`e$, 
            TableForm[ 
            BoxForm`e$, TableHeadings -> {None, {"k", "\!\(z\_k\)", 
              "f[\!\(z\_k\)]"}}]]], " "}]], "Input",
    FontWeight->"Plain"],
  "  ",
  StyleBox["\n\n\t\tTable 4.1",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The iterates of ",
  Cell[BoxData[
      \(z\_0 = 1\/4 + \[ImaginaryI]\/4\)]],
  " for Newton's method applied to ",
  Cell[BoxData[
      \(f \((z)\) = z\^2 + 1\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85714 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.769231 0.854701 3.03306e-017 0.745342 [
[.12821 -0.0125 -15 -9 ]
[.12821 -0.0125 15 0 ]
[.34188 -0.0125 -12 -9 ]
[.34188 -0.0125 12 0 ]
[.55556 -0.0125 -15 -9 ]
[.55556 -0.0125 15 0 ]
[.98291 -0.0125 -12 -9 ]
[.98291 -0.0125 12 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[.75673 .14907 -18 -4.5 ]
[.75673 .14907 0 4.5 ]
[.75673 .29814 -18 -4.5 ]
[.75673 .29814 0 4.5 ]
[.75673 .4472 -18 -4.5 ]
[.75673 .4472 0 4.5 ]
[.75673 .59627 -18 -4.5 ]
[.75673 .59627 0 4.5 ]
[.75673 .74534 -6 -4.5 ]
[.75673 .74534 0 4.5 ]
[.76923 .88214 -5 0 ]
[.76923 .88214 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .85714 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12821 0 m
.12821 .00625 L
s
[(-0.75)] .12821 -0.0125 0 1 Mshowa
.34188 0 m
.34188 .00625 L
s
[(-0.5)] .34188 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(-0.25)] .55556 -0.0125 0 1 Mshowa
.98291 0 m
.98291 .00625 L
s
[(0.25)] .98291 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.76923 .14907 m
.77548 .14907 L
s
[(0.2)] .75673 .14907 1 0 Mshowa
.76923 .29814 m
.77548 .29814 L
s
[(0.4)] .75673 .29814 1 0 Mshowa
.76923 .4472 m
.77548 .4472 L
s
[(0.6)] .75673 .4472 1 0 Mshowa
.76923 .59627 m
.77548 .59627 L
s
[(0.8)] .75673 .59627 1 0 Mshowa
.76923 .74534 m
.77548 .74534 L
s
[(1)] .75673 .74534 1 0 Mshowa
.76923 0 m
.76923 .85714 L
s
gsave
.76923 .88214 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .85714 L
0 .85714 L
closepath
clip
newpath
1 0 0 r
.02 w
.98291 .18634 Mdot
.02137 .83851 Mdot
.57939 .62566 Mdot
.80021 .72774 Mdot
.76849 .74503 Mdot
.76923 .74534 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 246.813},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000mR000`400?l00000o`00003oo`3ooolQ
0?ooo`008`3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0080oooo0P00000T0?oo
o`800000103oool2000000@0oooo0P00000U0?ooo`800000103oool2000000<0oooo100000030?oo
o`800000E03oool2000000@0oooo0P0000030?ooo`@000000`3oool2000001H0oooo000R0?ooo`04
0000003oool0oooo000000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0200oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000S0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00001B0?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
000E0?ooo`008P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0803oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0240oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0500
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01<0oooo000L0?ooo`@000000P3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo
0?ooo`8000007@3oool400000080oooo00@000000?ooo`3oool000002@3oool2000001h0oooo1000
00020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool2000005<0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`8000005P3oool00280oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
0280oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0S0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`1B0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0E0?oo
o`008`3oool2000000T0oooo100000030?ooo`<000008`3oool2000000X0oooo0`00000T0?ooo`80
00002P3oool2000000@0oooo0`00001C0?ooo`8000002P3oool2000000@0oooo0`00000E0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3oool=0?ooo`80000000<0oooo0000
000000003`3oool00?l0oooo3P3oool00`000000oooo0000000@0?ooo`002P3ooook000000T0oooo
00<000000?ooo`3oool03`3oool002X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`090?ooo`80000000<0oooo0000000000003`3oool00<X0oooo00<000000?ooo`3oool0D`3oool0
0<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo
00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<00000
0?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3o
ool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3o
ool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0
oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<0
00000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?oo
o`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0
D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool0
0<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo
00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<00000
0?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3o
ool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3o
ool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0
oooo00<000000?ooo`3oool0D`3oool00;L0oooo0P0000040?ooo`8000000`3oool4000000@0oooo
00<000000?ooo`3oool0D`3oool00;H0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo05<0oooo002f0?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool0103oool3000005<0oooo002f0?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1C0?ooo`00]P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0D`3oool00;L0oooo
0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?oo
o`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?oo
o`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`0b0?ooo`<0o`00
7P3oool00<X0oooo00<000000?ooo`3oool0<@3oool50?l001d0oooo003:0?ooo`030000003oool0
oooo0340oooo1@3o000M0?ooo`00bP3oool00`000000oooo0?ooo`0a0?ooo`D0o`007@3oool00<X0
oooo00<000000?ooo`3oool0<P3oool30?l001h0oooo003:0?ooo`030000003oool0oooo05<0oooo
003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?oo
o`030000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000
003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003oool0
oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0
oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:
0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`03
0000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003o
ool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo
05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo
003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo002g0?oo
o`800000103oool2000000D0oooo0`0000030?ooo`030000003oool0oooo05<0oooo002f0?ooo`04
0000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1C0?oo
o`00]P3oool010000000oooo0?ooo`0000080?ooo`D000000`3oool3000005<0oooo002f0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1C
0?ooo`00]P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool0D`3oool00;L0oooo0P00000;0?ooo`800000103oool00`000000oooo0?ooo`1C0?oo
o`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3o
ool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`00
0000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo
0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C
0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00
bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool0
0`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000
oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?oo
o`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?oo
o`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3o
ool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`00
0000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo
0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C
0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00
]`3oool2000000@0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`1C0?ooo`00]P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0D`3oool00;H0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?oo
o`<00000D`3oool00;H0oooo00@000000?ooo`3oool00000203oool3000000D0oooo00<000000?oo
o`3oool0D`3oool00;H0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo05<0oooo002g0?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3o
ool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3o
ool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0
oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<0
00000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?oo
o`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0
D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool0
0<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo
00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<00000
0?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3o
ool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3o
ool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0
oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<0
00000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?oo
o`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0
D`3oool00;L0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0D`3o
ool00;H0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo05<0oooo002f0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000103oool3000005<0oooo002f0?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`03
0000003oool0oooo05<0oooo002f0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1C0?ooo`00]`3oool2000000X0oooo0P0000050?ooo`03
0000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003o
ool0oooo05<0oooo002J0?ooo`<0o`00;@3oool00`000000oooo0?ooo`1C0?ooo`00V@3oool50?l0
02`0oooo00<000000?ooo`3oool0D`3oool009T0oooo1@3o000/0?ooo`030000003oool0oooo05<0
oooo002I0?ooo`D0o`00;03oool00`000000oooo0?ooo`1C0?ooo`00VP3oool30?l002d0oooo00<0
00000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?oo
o`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0
D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool0
0<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo
00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<00000
0?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3o
ool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3o
ool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0
oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<0
00000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0103oool30?l004`0oooo003:0?oo
o`030000003oool0oooo00<0oooo1@3o001;0?ooo`00bP3oool00`000000oooo0?ooo`030?ooo`D0
o`00B`3oool00<X0oooo00<000000?ooo`3oool00`3oool50?l004/0oooo003:0?ooo`030000003o
ool0oooo00@0oooo0`3o001<0?ooo`00`P3oool500000080oooo0`3o001D0?ooo`00a03oool01000
0000oooo0?ooo`3oool50?l005<0oooo00340?ooo`040000003oool0oooo0?ooo`D0o`00D`3oool0
0<@0oooo00@000000?ooo`3oool0oooo1@3o001C0?ooo`00a03oool00`000000oooo0?ooo`020?oo
o`<0o`00E03oool00<<0oooo0P0000050?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000
003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003oool0
oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0
oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:
0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`03
0000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003o
ool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo
05<0oooo003:0?ooo`030000003oool0oooo05<0oooo003:0?ooo`030000003oool0oooo05<0oooo
003:0?ooo`030000003oool0oooo05<0oooo000>0?ooo`<0o`00^@3oool00`000000oooo0?ooo`1C
0?ooo`003@3oool50?l00;P0oooo00<000000?ooo`3oool0D`3oool000d0oooo1@3o002h0?ooo`03
0000003oool0oooo05<0oooo000=0?ooo`D0o`00^03oool00`000000oooo0?ooo`1C0?ooo`003P3o
ool30?l00;T0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool0
0<X0oooo00<000000?ooo`3oool0D`3oool00<X0oooo00<000000?ooo`3oool0D`3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00<P0oooo0P00001F0?ooo`00b@3oool00`000000
oooo0?ooo`1D0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00b@3oool00`000000oooo0000
001D0?ooo`00b03oool010000000oooo0?ooo`00001D0?ooo`00a`3oool3000000030?ooo`000000
000005<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000
\
\>"],
    ImageRangeCache->{{{0, 287}, {245.813, 0}} -> {0, 0, 0, 0}}],
  StyleBox["   \n\t\tFigure 4.2",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The iterates of ",
  Cell[BoxData[
      \(z\_0 = 1\/4 + \[ImaginaryI]\/4\)]],
  " for Newton's method applied to ",
  Cell[BoxData[
      \(f \((z)\) = z\^2 + 1\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = z\^2 + 1\)]],
  "  and find the next five iterates."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, i, k, K, list, set];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_]\  = \ z\^2\  + \ 1\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(K = Table[i, {i, 0, 5}];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = Table[0, {6}];\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\) = 
        N[1\/4 + \[ImaginaryI]\/4];\)\ \), "\[IndentingNewLine]", 
    \(\(g[z_] = z - f[z]\/\(f'\)[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The formula for iteration is\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_\(k + 1\)\) = \!\(z\_k\) - \
\!\(f[z\_k]\/\(f'\)[z\_k]\) = \>\"", 
        g[\*"\"\<\!\(z\_k\)\>\""]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Now compute the next five iterates  ",
  Cell[BoxData[
      \(z\_k\)]],
  "  and the corresponding values of  ",
  Cell[BoxData[
      \(f[z\_k]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(For[k = 0, 
        k \[LessEqual] 
          4, \(k++\), \[IndentingNewLine]\(Z\_\(\(\[LeftDoubleBracket]\)\(k + \
2\)\(\[RightDoubleBracket]\)\) = 
            g[Z\_\(\(\[LeftDoubleBracket]\)\(k + 1\)\(\[RightDoubleBracket]\)\
\)];\)\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Transpose[{K, Z, 
              f[Z]}], \[IndentingNewLine]TableHeadings \[Rule] {None, \
{"\<k\>", \*"\"\<\!\(z\_k\)\>\"", \*"\"\<f[\!\(z\_k\)]\>\""}}]];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Plot the iterates  ",
  Cell[BoxData[
      \(z\_k\)]],
  "  and observe that they are converging to  ",
  Cell[BoxData[
      \(z = \[ImaginaryI]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(set\  = \ \ ReplaceAll[Z, xx_Real \[Rule] {xx, 0}];\)\ \), "\n", 
    \(\(list\  = \ \ ReplaceAll[set, 
          Complex[xx_, yy_] \[Rule] {xx, yy}];\)\ \), "\[IndentingNewLine]", 
    \(\(ListPlot[list, PlotRange \[Rule] {{\(-0.9\), 0.5}, {0.0, 1.2}}, 
        Prolog \[Rule] {PointSize[0.02], 
            Magenta}, \[IndentingNewLine]AspectRatio \[Rule] 1.2\/1.4, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \[IndentingNewLine]Ticks \
\[Rule] {Range[\(-1\), 1, 0.2], 
            Range[0, 1.2, 0.2]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Transpose[{K, 
              Z}], \[IndentingNewLine]TableHeadings \[Rule] {None, {"\<k\>", \
\*"\"\<\!\(z\_k\)\>\""}}]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Notice that the points  ",
  Cell[BoxData[
      \(z\_4\ \ and\ \ z\_5\)]],
  "  are co close together that they appear to coincide and that the value \
for  ",
  Cell[BoxData[
      \(\(\(\ \)\(z\_5\)\)\)]],
  "  agrees to six decimal places with the actual solution  ",
  Cell[BoxData[
      \(z = \[ImaginaryI]\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell["\<\
\tThe complex version of Newton's method also appears to work quite well.  \
Recall, however, that with functions defined on the reals, not every initial \
guess produces a sequence that converges to a solution.  Example 4.8 shows \
that the same is true in the complex case. \
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 4.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that Newton's method fails for the function  ",
  Cell[BoxData[
      \(f \((z)\) = z\^2 + 1\)]],
  "  if the initial guess is a real number."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  From Example 4.7 we know that, for any guess ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " as a solution of ",
  Cell[BoxData[
      \(z\^2 + 1 = 0\)]],
  ", the next guess at a solution is  ",
  Cell[BoxData[
      \(N \((z)\) = \(z - \(f \((z)\)\)\/\(f' \((z)\)\)\  = \ \(z\^2 - \
1\)\/\(2  z\)\)\)]],
  ".  We let ",
  Cell[BoxData[
      \(z\_0\)]],
  " be any real number and ",
  Cell[BoxData[
      \({z\_k}\)]],
  " be the sequence of iterations produced by the initial seed ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  If for any k,  ",
  Cell[BoxData[
      \(z\_k = 0\)]],
  ",  the procedure terminates, as ",
  Cell[BoxData[
      \(z\_\(k + 1\)\)]],
  " will be undefined.  If all the terms of the sequence ",
  Cell[BoxData[
      \({z\_k}\)]],
  " are defined, an easy induction argument shows that all the terms of the \
sequence are real.  Because the solutions of ",
  Cell[BoxData[
      \(z\^2 + 1 = 0\)]],
  " are ",
  Cell[BoxData[
      \(z = \(\[PlusMinus]\[ImaginaryI]\)\)]],
  ", the sequence ",
  Cell[BoxData[
      \({z\_k}\)]],
  " cannot possibly converge to either solution.  In the exercises we ask you \
to explore in detail what happens when ",
  Cell[BoxData[
      \(z\_0\)]],
  " is in the upper or lower half-plane."
}], "Text"],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Investigate Newton's method for finding the roots of  ",
  Cell[BoxData[
      \(f \((z)\) = z\^3 + 1\)]],
  ".\nGiven the initial seed  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  determine if the sequence  ",
  Cell[BoxData[
      \({z\_k}\)]],
  "  converges to one of the roots  ",
  Cell[BoxData[
      \(z = \(-1\), 1\/2 + \(\[ImaginaryI]\ \@3\)\/2, 
      1\/2 - \(\[ImaginaryI]\ \@3\)\/2\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = z\^3 + 1\)]],
  "  and find its roots."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = z\^3 + 1;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[f[z] \[Equal] 0, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_1 = 
        ComplexExpand[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), 
          TargetFunctions \[Rule] {Im, Re}];\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_2 = 
        ComplexExpand[
          solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\), 
          TargetFunctions \[Rule] {Im, Re}];\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_3 = 
        ComplexExpand[
          solset\_\(\(\[LeftDoubleBracket]\)\(3, 1, \
2\)\(\[RightDoubleBracket]\)\), 
          TargetFunctions \[Rule] {Im, Re}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", 
        Z\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", 
        Z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", 
        Z\_3];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We color each point ",
  Cell[BoxData[
      \(z\_0\)]],
  "  in the rectangle  ",
  Cell[BoxData[
      \(R = {z = 
            x + \(\[ImaginaryI]y : \(-2\) \[LessEqual] x \[LessEqual] 
                  2\), \(-2\) \[LessEqual] x \[LessEqual] 2}\)]],
  " in the following fashion.  Color the point yellow, blue, or red, if the \
sequence of iterations produced by the seed  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  converges to ",
  Cell[BoxData[
      \(\(-1\), 1\/2 + \(\[ImaginaryI]\ \@3\)\/2, 
      1\/2 - \(\[ImaginaryI]\ \@3\)\/2\)]],
  ", respectively.  The iteration formula is "
}], "Text"],

Cell[BoxData[{
    \(\(g[z_] = Together[z - f[z]\/\(f'\)[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[z] = \>", g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The formulas for  f[z] and  g[z]  and approximations to the roots ",
  Cell[BoxData[
      \(z = \(-1\), 1\/2 + \(\[ImaginaryI]\ \@3\)\/2, 
      and\ 1\/2 - \(\[ImaginaryI]\ \@3\)\/2\)]],
  " are used in the function  newton[x,y]  to make the density plot."
}], "Text"],

Cell[BoxData[
    \(\(\(newton = \n
        Compile[{x, y}, \[IndentingNewLine]Module[{z, ct = 0}, 
            z = x + \[ImaginaryI]\ y; \ \[IndentingNewLine]While[
              Abs[Evaluate[z\^3 + 1]] > 0.001\  && \ 
                ct \[LessEqual] 
                  50, \[IndentingNewLine]z = \(\(-1\) + 2\ z\^3\)\/\(3\ \
z\^2\); \ \(++ct\)]; \ \[IndentingNewLine]Which[\[IndentingNewLine]Abs[
                  z - \((\(-1\))\)] < 0.1, 
              0.15, \[IndentingNewLine]Abs[
                  z - \((0.5\[InvisibleSpace] + 0.866\ \[ImaginaryI])\)] < 
                0.1, 0.5, \[IndentingNewLine]Abs[
                  z - \((0.5\[InvisibleSpace] - 0.866\ \[ImaginaryI])\)] < 
                0.1, 0.9]]\ ];\)\(\ \)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[TextData[{
  "Make a plot showing the initial seeds  ",
  Cell[BoxData[
      \(z\_0\)]],
  ",  and the nature of the sequence ",
  Cell[BoxData[
      \({z\_k}\)]],
  "  that is produced by it."
}], "Text"],

Cell[BoxData[{
    \(\(DensityPlot[
        newton[x, y], \[IndentingNewLine]{x, \(-2\), 2. }, \ {y, \(-2\), 
          2}, \[IndentingNewLine]PlotPoints \[Rule] 100, Mesh \[Rule] False, 
        AspectRatio \[Rule] 1, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Yellow points converge to  -1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Blue points converge to  \!\(1\/2\)+\!\(\(\[ImaginaryI] \
\@ 3\)\/2\).\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Red  points converge to  \!\(1\/2\)-\!\(\(\[ImaginaryI] \
\@ 3\)\/2\).\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Notice.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not produce graphs with the color scheme indicated in the book!"
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\tThe case for cubic polynomials is more complicated than that for \
quadratics.  Fortunately, we can get an idea of what's going on by doing some \
experimentation with computer graphics.  We begin with the cubic polynomial \
",
  Cell[BoxData[
      \(f \((z)\) = z\^3 + 1\)]],
  ".  (Recall that the roots of this polynomial are at ",
  Cell[BoxData[
      \(z = \(-1\), \ 1\/2 + \(\(\(\ \)\(\@3\)\)\/2\) \[ImaginaryI], \ 
      1\/2 - \(\(\(\ \)\(\@3\)\)\/2\) \[ImaginaryI]\)]],
  ".)  We associate a color with each root (blue, red, and green, \
respectively).  We form a rectangular region ",
  Cell[BoxData[
      \(R\)]],
  ", which contains the three roots of ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  ", and partition this region into equal rectangles ",
  Cell[BoxData[
      \(R\_\(i\ j\)\)]],
  ".  We then choose a point ",
  Cell[BoxData[
      \(z\_\(i\ j\)\)]],
  " at the center of each rectangle and for each of these points we apply the \
following algorithm."
}], "Text"],

Cell[TextData[{
  StyleBox["1.",
    FontColor->RGBColor[0, 0, 1]],
  "  With  ",
  Cell[BoxData[
      \(N \((z)\)\  = \ \(z - \(f \((z)\)\)\/\(f' \((z)\)\)\  = \ \(z - \
\(z\^3 + 1\)\/\(3\ z\^2\)\  = \ \(2\ z\^3 - 1\)\/\(3\ z\^2\)\)\)\)]],
  ",  compute  ",
  Cell[BoxData[
      \(N \((z\_\(i\ j\))\)\)]],
  ".  Continue computing successive iterates of this initial point until we \
either are within a certain preassigned tolerance (say, ) of one of the roots \
of   ",
  Cell[BoxData[
      \(f \((z)\) = 0\)]],
  ",  or until the number of iterations has exceeded a preassigned maximum."
}], "Text"],

Cell[TextData[{
  StyleBox["2.",
    FontColor->RGBColor[0, 0, 1]],
  "  If Step 1 leaves us within  of one of the roots of ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  ", we color the entire rectangle ",
  Cell[BoxData[
      \(R\_\(i\ j\)\)]],
  " with the color associated with that root.  \nOtherwise, we assume that \
the initial point ",
  Cell[BoxData[
      \(z\_\(i\ j\)\)]],
  " does not converge to any root, and we color the entire rectangle yellow."
}], "Text"],

Cell[TextData[{
  "\tNote that this algorithm doesn't prove anything.  In Step 2, there is no \
a priori reason to justify the assumption mentioned, nor is there any \
necessity for an initial point ",
  Cell[BoxData[
      \(z\_\(i\ j\)\)]],
  " to have its sequence of iterates converging to one of the roots of ",
  Cell[BoxData[
      \(f \((z)\) = 0\)]],
  ", just because a particular iteration is within  of that root.  Finally, \
the fact that one point in a rectangle behaves in a certain way does not \
imply that all the points in that rectangle behave in a like manner.  \
Nevertheless, we can use this algorithm as a basis for mathematical \
explorations.  Indeed, computer experiments such as the one described have \
contributed to a lot of exciting mathematics during the past 20 years.  The \
color plates located on the inside front and back covers of this book \
illustrate the results of applying our algorithm to various functions.  Color \
plate 1shows the results for the cubic polynomial ",
  Cell[BoxData[
      \(f \((z)\) = z\^3 + 1\)]],
  ".  The points in the blue, red, and green regions are those \"initial \
guesses\" that will converge to the roots ",
  Cell[BoxData[
      \(z = \(-1\), \ 1\/2 + \(\(\(\ \)\(\@3\)\)\/2\) \[ImaginaryI], \ 
      1\/2 - \(\(\(\ \)\(\@3\)\)\/2\) \[ImaginaryI]\)]],
  " -1, respectively.  (The roots themselves are located in the middle of the \
three largest colored regions.)  The complexity of this picture becomes \
apparent when you observe that, wherever two colors appear to meet, the third \
color emerges between them.  But then, a closer inspection of the area where \
this third color meets one of the other colors reveals again a different \
color between them.  This process continues with an infinite complexity."
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Color Plate 1.",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_1.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  ",
  StyleBox[ButtonBox["Newton's method applied to",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_1.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  "  ",
  Cell[BoxData[
      \(f \((z)\) = z\^3 + 1\)],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[". ",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "\tThere appear to be no yellow regions with any area in Color plate 1, \
indicating that at least most initial guesses ",
  Cell[BoxData[
      \(z\_0\)]],
  " at a solution to ",
  Cell[BoxData[
      \(z\^3 + 1 = 0\)]],
  " will produce a sequence ",
  Cell[BoxData[
      \({z\_k}\)]],
  " that converges to one of the three roots.  Color plate 2 demonstrates \
that this outcome does not always occur.  It shows the results of applying \
the preceding algorithm to the polynomial ",
  Cell[BoxData[
      \(f \((z)\) = 
        z\^3 + \((\(-0.26\) + 0.02  \[ImaginaryI])\) 
            z + \((\(-0.74\) + 0.02  \[ImaginaryI])\)\)]],
  ".  The yellow area shown is often referred to as the rabbit.  It consists \
of a main body and two ears.  Upon closer inspection (color plate 3) you can \
see that each of the ears consists of a main body and two ears.  Color plate \
2 is an example of a fractal image.  Mathematicians use the term fractal to \
indicate an object that have this kind of recursive structure."
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Color Plate 2.",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_2.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  ",
  StyleBox[ButtonBox["The rabbit fractal of",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_2.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  "  ",
  Cell[BoxData[
      \(f \((z)\) = 
        z\^3 + \((\(-0.26\) + 0.02  \[ImaginaryI])\) z - 0.74 + 
          0.02  \[ImaginaryI]\)],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".  ",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Color Plate 3.",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_3.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  ",
  StyleBox[ButtonBox["A zoom of the rabbit fractal of",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_3.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  "  ",
  Cell[BoxData[
      \(f \((z)\) = 
        z\^3 + \((\(-0.26\) + 0.02  \[ImaginaryI])\) z - 0.74 + 
          0.02  \[ImaginaryI]\)],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".  ",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "\tIn 1918 the French mathematicians ",
  StyleBox[ButtonBox["Gaston Julia",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Julia.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " and ",
  StyleBox[ButtonBox["Pierre Fatou",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Fatou.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " noticed the fractal phenomenon when exploring iterations of functions not \
necessarily connected with Newton's method.  Beginning with a function  f(z)  \
and a point  ",
  Cell[BoxData[
      \(z\_0\)]],
  ",  they computed the iterates  ",
  Cell[BoxData[
      \(z\_1 = f \((z\_0)\)\)]],
  ", ",
  Cell[BoxData[
      \(z\_2 = f \((z\_1)\)\)]],
  ", ... , ",
  Cell[BoxData[
      \(z\_\(k + 1\) = f \((z\_k)\)\)]],
  ", and investigated properties of the sequences  ",
  Cell[BoxData[
      \({z\_k}\)]],
  ".  Their findings did not receive a great deal of attention, in part \
because computer graphics were not available at this time.  With the recent \
proliferation of computers, it is not surprising that these investigations \
were revived in the 1980's.  Detailed studies of Newton's method and the more \
general topic of iteration were undertaken by a host of mathematicians \
including Curry, Douady, Garnett, Hubbard, ",
  StyleBox[ButtonBox["Mandelbrot",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Mandelbrot.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ", ",
  StyleBox[ButtonBox["Milnor",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Milnor.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " and Sullivan.  We now turn our attention to some of their results by \
focusing on the iterates produced by quadratics of the form   ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\) = z\^2 + c\)]],
  ".  You will be surprised at the startling pictures that graphical iterates \
of such a simple functions produce."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 4.9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  For  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\) = z\^2 + c\)]],
  ",  analyze all possible iterations when ",
  Cell[BoxData[
      \(c = 0\)]],
  ", that is, for the function ",
  Cell[BoxData[
      \(f\_0\)]],
  " defined by  ",
  Cell[BoxData[
      \(\(f\_0\) \((z)\) = z\^2 + 0\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We leave as an exercise the claim that, if  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_0\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ",  the sequence will converge to ",
  StyleBox["0",
    FontFamily->"Courier New"],
  ";  if  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_0\)\(|\)\(\(>\)\(\ \)\(1\)\)\)\)]],
  ",  the sequence will be unbounded;  and if  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_0\)\(|\)\) = \ 1\)]],
  ",  the sequence will either oscillate around the unit circle or converge \
to ",
  StyleBox["1",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  "\tFor the function ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  " defined by  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\) = z\^2 + c\)]],
  ",  and an initial seed  ",
  Cell[BoxData[
      \(z\_0\)]],
  ",  the set of iterates given by  ",
  Cell[BoxData[
      \(z\_1 = \(f\_c\) \((z\_0)\)\)]],
  ", ",
  Cell[BoxData[
      \(z\_2 = \(f\_c\) \((z\_1)\)\)]],
  ", etc., are also called the ",
  StyleBox["orbits",
    FontColor->RGBColor[0, 0, 1]],
  " of  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  generated by  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  ".  We let  ",
  Cell[BoxData[
      \(K\_c\)]],
  "  denote the set of points with bounded orbits for  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  ".  Example 4.9 shows that  ",
  Cell[BoxData[
      \(K\_0\)]],
  "  is the closed unit disk ",
  Cell[BoxData[
      \(\(\(D\_1\)\&_\) \((0)\)\)]],
  ".  The boundary of  ",
  Cell[BoxData[
      \(K\_c\)]],
  "  is known as the ",
  StyleBox[ButtonBox["Julia set",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/JuliaSet.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " for the function  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  ".  Thus the Julia set for  ",
  Cell[BoxData[
      \(\(f\_0\) \((z)\)\)]],
  "  is the unit circle  ",
  Cell[BoxData[
      \(\(C\_1\) \((0)\)\)]],
  ".  It turns out that  ",
  Cell[BoxData[
      \(K\_c\)]],
  "  is a nice simple set only when  ",
  Cell[BoxData[
      \(c = \(0\ \ or\ \ c = \(-2\)\)\)]],
  ".  Otherwise,   ",
  Cell[BoxData[
      \(K\_c\)]],
  "  is fractal.  Color plate 4 shows ",
  Cell[BoxData[
      \(K\_\(-1.25\)\)]],
  ".  The variation in colors indicate the length of time it takes for points \
to become \"sufficiently unbounded\" according to the following algorithm, \
which uses the same notation as our algorithm for iterations via Newton's \
method."
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Color Plate 4.",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_4.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  ",
  StyleBox[ButtonBox["The Julia set for",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_4.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  "  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\) = \(\(f\_\(-1.25\)\) \((z)\) = z\^2 - 1.25\)\)],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[". ",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Plot the Julia set for ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\) = \(\(f\_\(-1.25\)\) \((z)\) = z\^2 - 1.25\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Here is the subroutine from the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  Journal."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(juliaC\  = \n
        Compile[{x, y, lim, cx, cy}, \[IndentingNewLine]Module[{z, ct = 0}, 
            z = x + \[ImaginaryI]\ y; \ \[IndentingNewLine]While[
              Abs[z] < 2.0\  && \ ct \[LessEqual] lim, \[IndentingNewLine]z = 
                z\^2 + \((cx + \[ImaginaryI]\ cy)\); \ \(++ct\)]; \ 
            ct]\ ];\)\(\ \)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[TextData[{
  "Here is the Julia set generated by the value  c = -1.25.  This is a fuzzy \
picture of Color Plate 4.  Increase the number of PlotPoints to get a sharper \
picture.  Also, it will increase the computing time.  It takes quite a bit of \
time with  ",
  Cell[BoxData[
      \(PlotPoints \[Rule] 200\)]],
  ".  Things start to look better with  ",
  Cell[BoxData[
      \(PlotPoints \[Rule] 500\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(DensityPlot[\(-juliaC[x, y, 50, \(-1.25\), 
            0]\), \[IndentingNewLine]{x, \(-1.5\), 1.5}, \ {y, \(-1.0\), 
          1.0}, \[IndentingNewLine]PlotPoints \[Rule] 200, 
        Mesh \[Rule] False, 
        AspectRatio \[Rule] 2\/3, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Julia set generated by the value c = -1.25\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Notice.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not produce graphs with the color scheme indicated in the book!"
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["1.",
    FontColor->RGBColor[0, 0, 1]],
  "  Compute  ",
  Cell[BoxData[
      \(\(f\_c\) \((z\_\(i\ j\))\)\)]],
  ".  Continue computing successive iterates of this initial point until the \
absolute value of one of the iterations exceeds a certain bound (say, L), or \
until the number of iterations has exceeded a preassigned maximum. \n",
  StyleBox["2.",
    FontColor->RGBColor[0, 0, 1]],
  "  If Step 1 leaves us with an iteration whose absolute value exceeds L, we \
color the entire rectangle ",
  Cell[BoxData[
      \(R\_\(i\ j\)\)]],
  " with a color indicating the number of iterations needed before this value \
was attained (the more iterations required, the darker the color).  \
Otherwise, we assume that the orbits of the initial point ",
  Cell[BoxData[
      \(z\_\(i\ j\)\)]],
  " do not diverge to infinity, and we color the entire rectangle black.\n\n\t\
Note, again, that this algorithm doesn't prove anything.  It merely guides \
the direction of our efforts to do rigorous mathematics."
}], "Text"],

Cell[TextData[{
  "\tColor plate 5 shows the Julia set for the function ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  ", where ",
  Cell[BoxData[
      \(c = \(-0.11\) - 0.67  \[ImaginaryI]\)]],
  ".  The boundary of this set is different from the boundaries of the other \
sets we have seen, in that it is disconnected.  Julia and Fatou independently \
discovered a simple criterion that can be used to tell when the Julia set for \
 ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  "  is connected or disconnected.  We state their result, but omit the \
proof, as it is beyond the scope of this text."
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Color Plate 5.",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_5.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  ",
  StyleBox[ButtonBox["A disconnected Julia set for",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_5.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  "  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\) = z\^2 - 0.11 - 0.67  \[ImaginaryI]\)],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".  ",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 4.9.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The boundary of  ",
  Cell[BoxData[
      \(K\_c\)]],
  "  is connected if and only if  ",
  Cell[BoxData[
      \(0  \[Epsilon]\ K\_c\)]],
  ".  In other words, the Julia set for  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  "  is connected if and only if the orbits of  0  are bounded."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.9 is beyond the scope of this \
book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["The reader is encouraged to research this topic.", "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Julia Sets",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/JuliaSetsBib.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the Julia set for  ",
  Cell[BoxData[
      \(\(f\_\[ImaginaryI]\) \((z)\) = z\^2 + \[ImaginaryI]\)]],
  "  is connected."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We apply Theorem 4.9 and compute the orbits of ",
  StyleBox["0",
    FontFamily->"Courier New"],
  " for ",
  Cell[BoxData[
      \(\(f\_\[ImaginaryI]\) \((z)\) = z\^2 + \[ImaginaryI]\)]],
  ".  We have  ",
  Cell[BoxData[
      \(\(f\_\[ImaginaryI]\) \((0)\) = \[ImaginaryI]\)]],
  ",  ",
  Cell[BoxData[
      \(\(f\_\[ImaginaryI]\) \((0)\) = \(-1\) + \[ImaginaryI]\)]],
  ",  ",
  Cell[BoxData[
      \(\(f\_\[ImaginaryI]\) \((\(-1\) + \[ImaginaryI])\) = \
\(-\[ImaginaryI]\)\)]],
  ",  and  ",
  Cell[BoxData[
      \(\(f\_\[ImaginaryI]\) \((\(-\[ImaginaryI]\))\) = \(-1\) + \
\[ImaginaryI]\)]],
  ".  Thus the orbits of ",
  StyleBox["0",
    FontFamily->"Courier New"],
  "  are the sequence  ",
  Cell[BoxData[
      \({0, \[ImaginaryI], \(-1\) + \[ImaginaryI], \(-\[ImaginaryI]\), \(-1\) \
+ \[ImaginaryI], \(-\[ImaginaryI]\), \(-1\) + \[ImaginaryI], \(-\[ImaginaryI]\
\),  ... }\)]],
  ",  which is clearly a bounded sequence.  Thus, by Theorem 4.9, the Julia \
set for ",
  Cell[BoxData[
      \(\(f\_\[ImaginaryI]\) \((z)\)\)]],
  " is connected."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 4.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "We apply Theorem 4.8 and compute the orbit of  0  for  ",
  Cell[BoxData[
      \(\(f\_\[ImaginaryI]\) \((z)\) = z\^2 + \[ImaginaryI]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, i];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = z\^2 + \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = NestList[f, 0, 10];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(f\_\[ImaginaryI]\)(z) = \>\"", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_0\) = \>\"", 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<z\>"\_1, \*"\"\< = \!\(f\_\[ImaginaryI]\)(\>\"", "\<z\>"\_0, \
\*"\"\<) =  \!\(f\_\[ImaginaryI]\)(\>\"", 0\ , "\<) = \>", "\<\t\>", 
        Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)];\)\ \
\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          9, \(i++\), \[IndentingNewLine]\(Print["\<z\>"\_\(i + 1\), \*"\"\< \
= \!\(f\_\[ImaginaryI]\)(\>\"", "\<z\>"\_i, \*"\"\<) =  \
\!\(f\_\[ImaginaryI]\)(\>\"", 
            Z\_\(\(\[LeftDoubleBracket]\)\(i + 1\)\(\[RightDoubleBracket]\)\)\
\ , "\<) = \>", "\<\t\>", 
            Z\_\(\(\[LeftDoubleBracket]\)\(i + \
2\)\(\[RightDoubleBracket]\)\)];\)\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Thus, the orbit of  0  is the sequence  ",
  Cell[BoxData[
      \({0, \[ImaginaryI], \(-1\) + \[ImaginaryI], \(-\[ImaginaryI]\), \(-1\) \
+ \[ImaginaryI], \(-\[ImaginaryI]\), \(-1\) + \[ImaginaryI], \(-\[ImaginaryI]\
\),  ... }\)]],
  "  which is clearly a bounded sequence.  Thus, by Theorem 4.9, the Julia \
set for  ",
  Cell[BoxData[
      \(\(f\_\[ImaginaryI]\) \((z)\)\)]],
  "  is connected."
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\tIn 1980, the Polish born mathematician ",
  StyleBox[ButtonBox["Benoit Mandelbrot",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Mandelbrot.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " used computer graphics to study the following set:  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{"M", "  ", "=", " ", 
        RowBox[{"{", 
          RowBox[{"c", ":", " ", 
            RowBox[{
              StyleBox["the",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["Julia",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["set",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], " ", \(f\_c\), \((z)\), " ", 
              StyleBox["is",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["connected",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}], "}"}]}], "\n", 
      RowBox[{"M", "  ", "=", " ", 
        RowBox[{"{", 
          RowBox[{"c", ":", " ", 
            RowBox[{
              StyleBox["the",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["orbits",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["of",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "0", "  ", 
              StyleBox["determined",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["by",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], " ", \(f\_c\), \((z)\), " ", 
              StyleBox["are",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["bounded",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}], "}"}]}]}]],
  "   "
}], "Text"],

Cell[TextData[{
  "\tThe set ",
  StyleBox["M",
    FontFamily->"Courier New"],
  " has come to be known as the ",
  StyleBox[ButtonBox["Mandelbrot Set",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/MandelbrotSet.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ".  Color plate 6 shows its intricate nature. Technically, the Mandelbrot \
set is not fractal because it is not self-similar (although it may look that \
way).  However, it is infinitely complex.  Color plate 7 shows a zoom over \
the upper portion of the set shown in color plate 6.  Likewise, color plate 8 \
zooms in on the upper portion of color plate 7.  In color plate 8 you can see \
the emergence of another structure very similar to the Mandelbrot set that we \
began with.  Although it isn't an exact replica, if you zoomed in on this set \
at almost any spot, you would eventually see yet another \"Mandelbrot clone\" \
and so on ad infinitum!  In the remainder of this section we look at some of \
the properties of this amazing set."
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Color Plate 6.",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_6.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  ",
  StyleBox[ButtonBox["The Mandelbrot set M.",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_6.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}]
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Color Plate 7.",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_7.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  ",
  StyleBox[ButtonBox["A zoom of the upper portion of the Mandelbrot set M.",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_7.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}]
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Color Plate 8.",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_8.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  ",
  StyleBox[ButtonBox["A zoom of the upper portion of the Color Plate 7.",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/juliamandelbrotset/\
JuliaMandelbrotPlates/Links/JuliaMandelbrotPlates_lnk_8.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}]
}], "Text"],

Cell[TextData[{
  StyleBox["Example 4.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that ",
  Cell[BoxData[
      \({c : \(\(|\)\(z\)\(|\)\(\(\[LessEqual]\)\(1\/4\)\)\)}\)]],
  " is a subset of the Mandelbrot set  M. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  Let ",
  Cell[BoxData[
      \({a\_n}\_\(n = 0\)\%\[Infinity]\)]],
  " be the orbits of ",
  StyleBox["0",
    FontFamily->"Courier New"],
  " generated by ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\) = z\^2 + c\)]],
  ", where ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(\[LessEqual]\)\(1\/4\)\)\)\)]],
  ".  Then\n\n\t\t\t",
  Cell[BoxData[{\(a\_0\  = \ \(f \((0)\)\  = \ \(0 + c\  = \ c\)\)\), 
    "\n", \(a\_1\  = \ \(f \((a\_0)\)\  = \ a\_0\%2 + c\)\), 
    "\n", \(a\_2\  = \ \(f \((a\_1)\)\  = \ a\_1\%2 + c\)\), "\n", 
      StyleBox[\(in\ general\),
        FontFamily->"Times New Roman"], 
    "\n", \(a\_\(n + 1\)\  = \ \(f \((a\_n)\)\  = \ a\_n\%2 + c\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "We show that ",
  Cell[BoxData[
      \({a\_n}\_\(n = 0\)\%\[Infinity]\)]],
  " is bounded, and, in particular, we show that ",
  Cell[BoxData[
      \(\(\(|\)\(a\_n\)\(|\)\(\(\[LessEqual]\)\(1\/2\)\)\)\)]],
  " for all n by mathematical induction.  Clearly ",
  Cell[BoxData[
      \(\(\(|\)\(a\_n\)\(|\)\(\(\[LessEqual]\)\(1\/2\)\)\)\)]],
  " if ",
  Cell[BoxData[
      RowBox[{"n", "=", 
        RowBox[{"0", " ", 
          StyleBox["or",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "1"}]}]]],
  ".  We assume that ",
  Cell[BoxData[
      \(\(\(|\)\(a\_n\)\(|\)\(\(\[LessEqual]\)\(1\/2\)\)\)\)]],
  " for some value of ",
  Cell[BoxData[
      \(n \[GreaterEqual] 1\)]],
  " (our goal is to show ",
  Cell[BoxData[
      \(\(\(|\)\(a\_\(n + 1\)\)\(|\)\(\(\[LessEqual]\)\(1\/2\)\)\)\)]],
  ").  Now,  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(a\_\(n + 1\)\)\(|\)\)\ \  = \ \ \(\(|\)\(a\_n\%2 + 
            c\)\(|\)\(\ \)\)\)]],
  "\n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(\(\[LessEqual]\)\(\ \ \
\)\(\(|\)\(a\_n\%2\)\(|\)\(+\(\(|\)\(c\)\(|\)\(\ \ \)\)\)\)\)\)\)]],
  "\n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(\(\(\[LessEqual]\)\(\ \ \
\)\(1\/4 + 1\/4\)\)\  = \ 1\/2\)\)\)]],
  " "
}], "Text"],

Cell[TextData[{
  "\tIn the exercises, we ask you to show that, if ",
  Cell[BoxData[
      \(\(\(|\)\(c\)\(|\)\(\(>\)\(2\)\)\)\)]],
  ", then ",
  StyleBox["c",
    FontFamily->"Courier New"],
  " is not in the set ",
  StyleBox["M",
    FontFamily->"Courier New"],
  ".  Thus the Mandelbrot set depicted in color plate 6 contains \nthe disk  \
",
  Cell[BoxData[
      \(\(\(D\_\(1\/4\)\)\&_\) \((0)\)\)]],
  " and is contained in the disk ",
  Cell[BoxData[
      \(\(\(\ \)\(\(\(D\_2\)\&_\) \((0)\)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "    \tWe can use other methods to determine which points belong to ",
  StyleBox["M",
    FontFamily->"Courier New"],
  ".  To do so, we need some additional vocabulary."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 4.6 (Fixed Point).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The point  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  is a fixed point for the function  ",
  StyleBox["f",
    FontFamily->"Courier New"],
  "  if  ",
  Cell[BoxData[
      \(f \((z\_0)\) = z\_0\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Definition 4.7 (Attracting Point).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The point  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  is an attracting point for the function  ",
  StyleBox["f",
    FontFamily->"Courier New"],
  "  if  ",
  Cell[BoxData[
      \(\(\(|\)\(f' \((z\_0)\)\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tTheorems 4.10 and 4.11 explain the significance of these terms.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 4.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose that ",
  Cell[BoxData[
      \(z\_0\)]],
  "  is an attracting fixed point for the function  f.  Then there is a disk  \
",
  Cell[BoxData[
      \(\(D\_r\) \((z\_0)\)\)]],
  "  about  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  such that the iterates of all the points in ",
  Cell[BoxData[
      \(\(D\_r\) \((z\_0)\)\)]],
  "  are dawn toward the point  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  in the sense that, if  ",
  Cell[BoxData[
      \(z \[Element] \(D\_r\%*\) \((z\_0)\)\)]],
  ", then  ",
  Cell[BoxData[
      \(\(\(|\)\(f \((z)\) - 
          z\_0\)\(|\)\(\(<\)\(\(|\)\(z - z\_0\)\(|\)\)\)\)\)]],
  ".  In fact, if ",
  Cell[BoxData[
      \(z\_k\)]],
  " is the ",
  Cell[BoxData[
      \(k\^th\)]],
  " iterate of ",
  Cell[BoxData[
      \(z \[Element] \(D\_r\%*\) \((z\_0)\)\)]],
  ", then ",
  Cell[BoxData[
      \(lim\+\(k \[Rule] \[Infinity]\)\ z\_k\  = \ z\_0\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.10 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  "\tIn 1905, ",
  StyleBox[ButtonBox["Pierre Fatou",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Fatou.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " showed that, if the function ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  " defined by ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\) = z\^2 + c\)]],
  " has attracting fixed points, then the orbits of ",
  StyleBox["0",
    FontFamily->"Courier New"],
  " determined by ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  " must converge to one of them.  Because a convergent sequence is bounded, \
this condition implies that c must belong to M.  In the exercises we ask you \
to show that the main cardioid-shaped body of M in color plate 6 is composed \
of those points c for which ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  " has attracting fixed points.  You will find Theorem 4.10 to be a useful \
characterization of those points."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 4.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The function ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  " defined by ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\) = z\^2 + c\)]],
  " has attracting fixed points iff ",
  Cell[BoxData[
      \(\(\(|\)\(1 + \((1 - 4  c)\)\^\(1/2\)\)\(|\)\(\(<\)\(\ \
\)\(1\)\)\)\)]],
  "  or  ",
  Cell[BoxData[
      \(\(\(|\)\(1 - \((1 - 4  c)\)\^\(1/2\)\)\(|\)\(\(<\)\(\ \
\)\(1\)\)\)\)]],
  ",  where the square root designates the principal square root function. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.11 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Definition 4.8 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["n-Cycle",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/MapCycle.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  An n-cycle for a function  f  is a set  ",
  Cell[BoxData[
      \({z\_0, z\_1,  ... , z\_\(n - 1\)}\)]],
  "  of  n  complex numbers such that  ",
  Cell[BoxData[
      \(z\_k = f \((z\_\(k - 1\))\)\)]],
  "  for  ",
  Cell[BoxData[
      \(k = 1, 2,  ... , n - 1\)]],
  ",  and  ",
  Cell[BoxData[
      \(f \((z\_\(n - 1\))\) = z\_0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Definition 4.9 (Attracting n-Cycle).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  An n-cycle  ",
  Cell[BoxData[
      \({z\_0, z\_1,  ... , z\_\(n - 1\)}\)]],
  "  for a function  f   is said to be attracting if  ",
  Cell[BoxData[
      \(\(\(|\)\(\(g\_n\%'\) \((z\_0)\)\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ",  where  ",
  Cell[BoxData[
      \(g\_n\)]],
  "  is the composition of  f  with itself  n  times.  For example, if n = 2, \
then ",
  Cell[BoxData[
      \(\(g\_2\) \((z)\)\  = \ f \((f \((z)\))\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 4.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Example 4.10 shows that  ",
  Cell[BoxData[
      \({\(-1\) + \[ImaginaryI], \(-\[ImaginaryI]\)}\)]],
  "  is a 2-cycle for the function  ",
  Cell[BoxData[
      \(\(f\_\[ImaginaryI]\) \((z)\) = z\^2 + \[ImaginaryI]\)]],
  ".  It is not an attracting 2-cycle because  ",
  Cell[BoxData[
      \(\(g\_2\) \((z)\) = 
        z\^4 + 2\ \[ImaginaryI]\ z\^2 + \((\(-1\) + \[ImaginaryI])\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\(g\_2\%'\) \((z)\)\  = \ 4\ z\^3 + 4\ \[ImaginaryI]\ z\)]],
  ".  Hence  ",
  Cell[BoxData[
      \(\(\(|\)\(\(g\_2\%'\) \((\(-1\) + \[ImaginaryI])\)\)\(|\)\)\  = \ \(\(\
\(|\)\(4\ \((\(-1\) + \[ImaginaryI])\)\^3 + 
              4\ \[ImaginaryI]\ \((\(-1\) + \[ImaginaryI])\)\)\(|\)\)\  = \ \
\(\(|\)\(4 + 4\ \[ImaginaryI]\)\(|\)\)\)\)]],
  ",  so that  ",
  Cell[BoxData[
      \(\(\(|\)\(\(g\_2\%'\) \((\(-1\) + \
\[ImaginaryI])\)\)\(|\)\(\(>\)\(1\)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = z\^2 + \[ImaginaryI]\)]],
  "  and point  ",
  Cell[BoxData[
      \(z\_0 = \(-1\) + \[ImaginaryI]\)]],
  "  and determine if  ",
  Cell[BoxData[
      \(\(\(|\)\(\(g\_n\%'\) \((z\_0)\)\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g2];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = z\^2 + \[ImaginaryI];\)\ \), "\n", 
    \(\(g2[z_] = 
        Apart[ComplexExpand[f[f[z]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_0 = \(-1\) + \[ImaginaryI];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_\[ImaginaryI]\)[z] = \>\"", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(g\_2\)[z] = \!\(f\_\[ImaginaryI]\)[\!\(f\_\
\[ImaginaryI]\)[z]]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(g\_2\)[z] = \!\(f\_\[ImaginaryI]\)[\>\"", 
        f[z], "\<]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(g\_2\)[z] = \>\"", 
        f[f[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(g\_2\)[z] = \>\"", 
        g2[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\(g\_2\%'\)\)[z] = \>\"", \(g2'\)[
          z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(\(g\_2\%'\)\)[\>\"", 
        Z\_0, "\<]  =  \>", \(g2'\)[Z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|\!\(\(g\_2\%'\)\)[\>\"", 
        Z\_0, "\<]| = |\>", \(g2'\)[
          Z\_0], "\<|\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|\!\(\(g\_2\%'\)\)[\>\"", Z\_0, "\<]| = \>", 
        Abs[\(g2'\)[Z\_0]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Is  |\!\(\(g\_2\%'\)\)[\>\"", Z\_0, "\<]| < 1 ?  \>", 
        Abs[\(g2'\)[Z\_0]] < 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Is  |\!\(\(g\_2\%'\)\)[\>\"", Z\_0, "\<]| > 1 ?  \>", 
        Abs[\(g2'\)[Z\_0]] > 1];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We have shown that ",
  Cell[BoxData[
      \(\(\(|\)\(\(g\_2\%'\) \((\(-1\) + \
\[ImaginaryI])\)\)\(|\)\(\(>\)\(1\)\)\)\)]],
  ".  Therefore,  ",
  Cell[BoxData[
      \({\(-1\) + \[ImaginaryI], \(-\[ImaginaryI]\)}\)]],
  "  is not an attracting 2-cycle."
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\tIn the exercises, we ask you to show that, if ",
  Cell[BoxData[
      \({z\_0, z\_1,  ... , z\_\(n - 1\)}\)]],
  " is an attracting ",
  StyleBox["n",
    FontFamily->"Courier New"],
  "-cycle for a function ",
  StyleBox["f",
    FontFamily->"Courier New"],
  ", then not only does ",
  Cell[BoxData[
      \(z\_0\)]],
  " \nsatisfy  ",
  Cell[BoxData[
      \(\(\(|\)\(\(g\_n\%'\) \((z\_0)\)\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ",  but also that  ",
  Cell[BoxData[
      \(\(\(|\)\(\(g\_n\%'\) \((z\_k)\)\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ",  for  ",
  Cell[BoxData[
      \(k = 1, 2,  ... , n - 1\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tIt turns out that the large disk to the left of the cardioid in color \
plate 6 consists of those points c for which ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  " has a 2-cycle.  The large disks above and below the main cardioid disk \
are the points c for which ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  " has a 3-cycle."
}], "Text"],

Cell["\<\
\tContinuing with this scheme, we see that the idea of n-cycles explains the \
appearance of the \"buds\" that you see on color plate 6.  It does not, \
however, begin to do justice to the enormous complexity of the entire set.  \
Even color plates 7 and 8 are mere glimpses into its awesome beauty.  In the \
exercises, we suggest several references for projects that you could pursue \
for a more detailed study of topics relating to those covered in this \
section.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Extra Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Plot the Mandelbrot set."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "This modification of the  juliaC  code can be used to plot the Mandelbrot \
set.\n\nHere is the subroutine from the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  Journal."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(mandelbrotC = 
        Compile[{x, y, lim}, \[IndentingNewLine]Module[{z, ct = 0}, 
            z = x + \[ImaginaryI]\ y; \ \[IndentingNewLine]While[
              Abs[z] < 2.0\  && \ ct \[LessEqual] lim, \[IndentingNewLine]z = 
                z\^2 + \((x + \[ImaginaryI]\ y)\); \ \(++ct\)]; \ 
            ct]\ ];\)\(\ \)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[TextData[{
  "This is a fuzzy picture of Color Plate 6. Increase the number of \
PlotPoints to get a sharper picture.  Also, it will increase the computing \
time.  It takes quite a bit of time with  ",
  Cell[BoxData[
      \(PlotPoints \[Rule] 200\)]],
  ".  Things start to look better with  ",
  Cell[BoxData[
      \(PlotPoints \[Rule] 500\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(DensityPlot[\(-mandelbrotC[x, y, 
            50]\), \[IndentingNewLine]{x, \(-2.0\), 0.55}, \ {y, \(-1.15\), 
          1.15}, \[IndentingNewLine]PlotPoints \[Rule] 200, \ 
        Mesh \[Rule] False, \[IndentingNewLine]Frame \[Rule] False, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Mandelbrot set.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Notice.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not produce graphs with the color scheme indicated in the book!"
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Julia Sets",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/JuliaSetsBib.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Mandelbrot Set",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/MandelbrotSetBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Fractals",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/FractalBib.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{934, 605},
WindowMargins->{{17, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[74981, 2099, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[77348, 2179, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 88815, 2526}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 120, 2, 33, "Text"],
Cell[2225, 66, 554, 11, 71, "Text"],
Cell[2782, 79, 2431, 70, 159, "Text"],
Cell[5216, 151, 466, 17, 36, "Text",
  Evaluatable->False],
Cell[5685, 170, 308, 7, 39, "Text"],
Cell[5996, 179, 698, 21, 52, "Text"],
Cell[6697, 202, 2699, 65, 184, "Text"],
Cell[9399, 269, 15687, 333, 288, "Text"],

Cell[CellGroupData[{
Cell[25111, 606, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[25274, 612, 137, 5, 33, "Text"],
Cell[25414, 619, 904, 16, 297, "Input"],
Cell[26321, 637, 187, 8, 33, "Text"],
Cell[26511, 647, 548, 13, 110, "Input"],
Cell[27062, 662, 190, 8, 33, "Text"],
Cell[27255, 672, 780, 15, 186, "Input"],
Cell[28038, 689, 357, 12, 33, "Text"]
}, Closed]],
Cell[28410, 704, 300, 5, 49, "Text"],
Cell[28713, 711, 314, 10, 33, "Text",
  Evaluatable->False],
Cell[29030, 723, 1305, 44, 96, "Text"],
Cell[30338, 769, 575, 20, 61, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[30938, 793, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[31105, 799, 124, 5, 33, "Text"],
Cell[31232, 806, 1327, 29, 290, "Input"],
Cell[32562, 837, 623, 18, 61, "Text"],
Cell[33188, 857, 180, 3, 85, "Input"],
Cell[33371, 862, 289, 6, 42, "Text"],
Cell[33663, 870, 770, 14, 231, "Input"],
Cell[34436, 886, 212, 8, 33, "Text"],
Cell[34651, 896, 674, 12, 212, "Input"],
Cell[35328, 910, 242, 8, 33, "Text"]
}, Closed]],
Cell[35585, 921, 1013, 26, 96, "Text"],
Cell[36601, 949, 606, 16, 58, "Text"],
Cell[37210, 967, 473, 14, 52, "Text"],
Cell[37686, 983, 1803, 31, 194, "Text"],
Cell[39492, 1016, 776, 23, 33, "Text"],
Cell[40271, 1041, 1046, 23, 109, "Text"],
Cell[41320, 1066, 859, 25, 33, "Text"],
Cell[42182, 1093, 869, 25, 33, "Text"],
Cell[43054, 1120, 2258, 61, 128, "Text"],
Cell[45315, 1183, 462, 19, 33, "Text",
  Evaluatable->False],
Cell[45780, 1204, 578, 18, 52, "Text"],
Cell[46361, 1224, 1947, 71, 109, "Text"],
Cell[48311, 1297, 808, 23, 33, "Text"],
Cell[49122, 1322, 293, 10, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[49440, 1336, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[49607, 1342, 180, 7, 33, "Text",
  Evaluatable->False],
Cell[49790, 1351, 399, 7, 134, "Input"],
Cell[50192, 1360, 483, 13, 52, "Text",
  Evaluatable->False],
Cell[50678, 1375, 501, 10, 146, "Input"],
Cell[51182, 1387, 242, 8, 33, "Text"]
}, Closed]],
Cell[51439, 1398, 1052, 23, 144, "Text"],
Cell[52494, 1423, 622, 15, 71, "Text"],
Cell[53119, 1440, 811, 23, 33, "Text"],
Cell[53933, 1465, 461, 16, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[54419, 1485, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[54567, 1491, 194, 5, 33, "Text",
  Evaluatable->False],
Cell[54764, 1498, 64, 0, 33, "Text"],
Cell[54831, 1500, 290, 7, 33, "Text"],
Cell[55124, 1509, 272, 6, 33, "Text"]
}, Closed]],
Cell[55411, 1518, 300, 10, 30, "Text",
  Evaluatable->False],
Cell[55714, 1530, 1101, 34, 71, "Text"],

Cell[CellGroupData[{
Cell[56840, 1568, 245, 9, 33, "Text",
  Evaluatable->False],
Cell[57088, 1579, 177, 5, 33, "Text"],
Cell[57268, 1586, 1199, 22, 230, "Input"],
Cell[58470, 1610, 431, 11, 52, "Text"]
}, Closed]],
Cell[58916, 1624, 7402, 188, 85, "Text"],
Cell[66321, 1814, 1076, 20, 109, "Text"],
Cell[67400, 1836, 627, 17, 33, "Text"],
Cell[68030, 1855, 658, 17, 33, "Text"],
Cell[68691, 1874, 655, 17, 33, "Text"],
Cell[69349, 1893, 307, 10, 36, "Text",
  Evaluatable->False],
Cell[69659, 1905, 724, 21, 148, "Text"],
Cell[70386, 1928, 1512, 44, 137, "Text"],
Cell[71901, 1974, 531, 18, 59, "Text"],
Cell[72435, 1994, 201, 5, 33, "Text"],
Cell[72639, 2001, 389, 16, 33, "Text",
  Evaluatable->False],
Cell[73031, 2019, 432, 16, 33, "Text",
  Evaluatable->False],
Cell[73466, 2037, 89, 2, 33, "Text"],
Cell[73558, 2041, 1072, 42, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[74655, 2087, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[74803, 2093, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[74981, 2099, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[75341, 2111, 1027, 29, 68, "Text"],
Cell[76371, 2142, 626, 21, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[77022, 2167, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[77170, 2173, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[77348, 2179, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[77708, 2191, 807, 28, 49, "Text",
  Evaluatable->False],
Cell[78518, 2221, 630, 20, 52, "Text",
  Evaluatable->False],
Cell[79151, 2243, 1065, 30, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[80241, 2277, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[80405, 2283, 312, 11, 33, "Text"],
Cell[80720, 2296, 1814, 33, 416, "Input"],
Cell[82537, 2331, 287, 9, 33, "Text"]
}, Closed]],
Cell[82839, 2343, 649, 23, 49, "Text"],
Cell[83491, 2368, 371, 10, 52, "Text"],
Cell[83865, 2380, 492, 8, 71, "Text"],
Cell[84360, 2390, 195, 7, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[84580, 2401, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[84747, 2407, 264, 8, 71, "Text",
  Evaluatable->False],
Cell[85014, 2417, 390, 7, 114, "Input"],
Cell[85407, 2426, 422, 12, 52, "Text",
  Evaluatable->False],
Cell[85832, 2440, 426, 7, 130, "Input"],
Cell[86261, 2449, 242, 8, 33, "Text"]
}, Closed]],
Cell[86518, 2460, 290, 7, 30, "Text"],
Cell[86811, 2469, 272, 6, 33, "Text"],
Cell[87086, 2477, 285, 7, 33, "Text"],
Cell[87374, 2486, 268, 6, 33, "Text"],
Cell[87645, 2494, 257, 5, 33, "Text"],
Cell[87905, 2501, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

