(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    334056,       6492]*)
(*NotebookOutlinePosition[    335392,       6538]*)
(*  CellTagsIndexPosition[    335315,       6532]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["4.3  Geometric Series and Convergence Theorems",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tWe begin this section by presenting a series of the form   ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity] z\^n\)]],
  ",  ",
  "which is called a geometric series and is one of the most important series \
in mathematics."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Real Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "\tThe complex geometric series is a generalization of the real geometric \
series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\ x\^n\)]],
  "  that is studied in calculus.  The partial sums ",
  Cell[BoxData[
      \(\(\(\ \)\(\(S\_n\) \((x)\)\  = \ \[Sum]\+\(k = 0\)\%n\ x\^k\)\)\)]],
  " converge to the infinite series  ",
  Cell[BoxData[
      \(S \((x)\)\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\ x\^n\)]],
  "  on the interval ",
  Cell[BoxData[
      \(\(-1\) < x < 1\)]],
  ", and the infinite sum is  ",
  Cell[BoxData[
      \(S \((x)\) = 1\/\(1\  - \ x\)\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(S = 0; Remove[S];\), "\[IndentingNewLine]", 
    \(\(S\_n_[x_]\  = \ \[Sum]\+\(k = 0\)\%n\ 
          x\^k;\)\), "\[IndentingNewLine]", 
    \(\(For[m = 0, 
        m \[LessEqual] 
          10, \(m++\), \[IndentingNewLine]Print["\<S\>"\_m, "\<(x) = \>", 
          Apart[S\_m[
              x]]\ ]; \[IndentingNewLine]Print["\<S\>"\_m, "\<(x) = \>", 
          S\_m[x]\ ];\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(S\_n\)\>\"", "\<(x) = \>", 
        Apart[S\_5[
            x]]\ , \*"\"\< +...+ \!\(x\^\(n - 1\)\)+ \!\(x\^n\)\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(S\_n\)\>\"", "\<(x) = \>", 
        S\_n[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<If |x|<1, then \>", "\<lim\>"\+\(n \[Rule] \[Infinity]\), \
\*"\"\< \!\(x\^n\) = 0  and we get\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<lim\>"\+\(n \[Rule] \[Infinity]\), \*"\"\< \!\(S\_n\)\>\"", \
"\<(x) = \>", "\<lim\>"\+\(n \[Rule] \[Infinity]\), "\<(\>", 
        S\_n[x], "\<)\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<lim\>"\+\(n \[Rule] \[Infinity]\), \*"\"\< \!\(S\_n\)\>\"", \
"\<(x) = \>", "\<lim\>"\+\(n \[Rule] \[Infinity]\), "\<(\>", 
        Apart[S\_n[x]], "\<)\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<lim\>"\+\(n \[Rule] \[Infinity]\), \*"\"\< \!\(S\_n\)\>\"", \
"\<(x) = \>", \ \[Sum]\+\(k = 0\)\%\[Infinity]\ 
          x\^k, "\< + 0\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<lim\>"\+\(n \[Rule] \[Infinity]\), \*"\"\< \!\(S\_n\)\>\"", \
"\<(x) = \>", \ \[Sum]\+\(k = 0\)\%\[Infinity]\ x\^k\ ];\)\)}], "Input"],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to draw a series of graph which illustrate the convergence of the partial \
sums to the infinite sum. "
}], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 1\/\(1 - x\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{{Green, PointSize[0.025], 
              Point[{0, f[0]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(ends = 
        Graphics[{{Cyan, Line[{{\(-1.0\), 0.0}, {\(-1.0\), 1.0}}]}, {Cyan, 
              Line[{{1.0, 0.0}, {1.0, 
                    10.5}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[m = 1, 
      m \[LessEqual] 21, \(m++\), \[IndentingNewLine]S[x_]\  = \ 
        Normal[Series[f[x], {x, 0, m}]]; \ \ \[IndentingNewLine]graph = 
        Plot[{f[x], S[x]}, {x, \(-1.25\), 1.25}, 
          PlotStyle \[Rule] {Blue, Red}, 
          PlotRange \[Rule] {{\(-1.25\), 1.25}, {0.0, 10.5}}, 
          Ticks \[Rule] {Range[\(-1.5\), 1.5, 0.5], Range[0, 10, 2]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph, 
        dot, ends, 
        DisplayFunction \[Rule] $DisplayFunction]; \[IndentingNewLine]Print["\
\<f(x) = \>", f[x], "\< \[TildeTilde] \>", "\<S\>"\_m, "\<(x) = \>", 
        S[x]\ ];\ \[IndentingNewLine]\ ]\ \ \)}], "Input"],

Cell["\<\
The following might give an insight into what happens when a complex number \
is used instead of a real number.\
\>", "Text"],

Cell[BoxData[{
    \(S = 0; Remove[S];\), "\[IndentingNewLine]", 
    \(\(S\_n_[
          y_]\  = \ \[Sum]\+\(k = 0\)\%n\ \((\[ImaginaryI]\ y)\)\^k;\)\), "\
\[IndentingNewLine]", 
    \(\(X\_n_[y_]\  := 
        Simplify[Re[ComplexExpand[Apart[S\_n[y]]]], 
          y \[Element] Reals];\)\), "\[IndentingNewLine]", 
    \(\(Y\_n_[y_]\  := 
        Simplify[Im[ComplexExpand[Apart[S\_n[y]]]], 
          y \[Element] Reals];\)\), "\[IndentingNewLine]", 
    \(\(X[n_] = 
        Simplify[
          Sum[\((\[ImaginaryI]\ y)\)\^k, {k, 0, n, 
              2}]];\)\), "\[IndentingNewLine]", 
    \(\(Y[n_] = 
        Simplify[
          Sum[\((\[ImaginaryI]\ y)\)\^k, {k, 1, n, 
              2}]];\)\), "\[IndentingNewLine]", 
    \(\(For[m = 0, 
        m \[LessEqual] 
          10, \(m++\), \[IndentingNewLine]Print["\<S\>"\_m, "\<(\[ImaginaryI] \
y) = \>", 
          Apart[S\_m[
              y]]\ ]; \[IndentingNewLine]Print["\<S\>"\_m, "\<(\[ImaginaryI] \
y) = \>", 
          X\_m[y] + \[ImaginaryI]\ \ Y\_m[
                y]]; \[IndentingNewLine]Print["\<S\>"\_m, "\<(\[ImaginaryI] \
y) = \>", X[m] + \ Y[m]\ ];\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<There are two cases, n = 2k, 2k+1\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(S\_\(2  k\)\)\>\"", \*"\"\<(\[ImaginaryI] y) = \!\(\
\(1 + y\^\(2\\\ k + 2\)\)\/\(1 + y\^2\)\) + \[ImaginaryI]\!\(\(\(\\\ \)\(y\\\ \
\((1 - y\^\(2\\\ k\))\)\)\)\/\(1 + y\^2\)\)\>\""\ ];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(S\_\(2  k + 1\)\)\>\"", \*"\"\<(\[ImaginaryI] y) = \
\!\(\(1 + y\^\(2\\\ k + 2\)\)\/\(1 + y\^2\)\) + \!\(\(\[ImaginaryI]\\\ y\\\ \
\((1 + y\^\(2\\\ k + 2\))\)\)\/\(1 + y\^2\)\)\>\""\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<If |y|<1, then \>", "\<lim\>"\+\(k \[Rule] \[Infinity]\), \
\*"\"\< \!\(y\^\(2\\\ k + 2\)\) = 0  and we get\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<lim\>"\+\(n \[Rule] \[Infinity]\), \*"\"\< \!\(S\_n\)\>\"", \
\*"\"\<(\[ImaginaryI] y) =  \!\(\(1 + 0\)\/\(1 + y\^2\)\) + \!\(\(\
\[ImaginaryI]\\\ y\\\ \((1 + 0)\)\)\/\(1 + y\^2\)\)\>\""\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<lim\>"\+\(n \[Rule] \[Infinity]\), \*"\"\< \!\(S\_n\)\>\"", \
\*"\"\<(\[ImaginaryI] y) =  \!\(1\/\(1 + y\^2\)\) + \[ImaginaryI]\!\(\(\(\\\ \
\)\(y\)\)\/\(1 + y\^2\)\)\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Of course this is the same as the simple \
computation\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(1\/\(1 - \[ImaginaryI]\\\ y\)\) = \!\(1\/\(1 - \
\[ImaginaryI]\\\ y\)\)\!\(\(1 + \[ImaginaryI]\\\ y\)\/\(1 + \[ImaginaryI]\\\ \
y\)\) = \!\(\(1 + \[ImaginaryI]\\\ y\)\/\(\((1 - \[ImaginaryI]\\\ y)\) \((1 + \
\[ImaginaryI]\\\ y)\)\)\) = \!\(\(1 + \[ImaginaryI]\\\ y\)\/\(1 + \
y\^2\)\)\>\""];\)\)}], "Input"],

Cell["\<\
In this module we extend geometric series to the complex numbers.\
\>", "Text"]
}, Closed]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009M0000nR000`400?l0
0000o`00003oo`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0
oooo;@3oool300000;L0oooo1@00000:0?ooo`@00000I03oool00?l0oooo
;@3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo00<0oooo
100000040?ooo`030000003oool0000006@0oooo003o0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`2h0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000I@3o
ool00?l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool02P3oool4
000006@0oooo001L0?ooo`@0003oE@3oool3000004L0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool00000
04X0oooo0`0000040?ooo`<000003P3oool3000005@0oooo00<000000?oo
o`3oool0;`3oool200000080oooo00<000000?ooo`0000000`0000020?oo
o`030000003oool0oooo03@0oooo001K0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool0D@3oool01@000000oooo0?ooo`3oool00000
04H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000:P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01/0oooo0P00000X
0?ooo`P000000P3oool010000000oooo0?ooo`0000060?ooo`030000003o
ool0000003D0oooo001K0?ooo`H0003oD`3oool01@000000oooo0?ooo`3o
ool0000004H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303o
ool01@000000oooo0?ooo`3oool0000002T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0000000300000004
0?ooo`000000oooo000003D0oooo001@0?ooo`@0003o0`3oool90000o`<0
oooo2@000?l20?ooo`<0003o203oool20000o`040?ooo`000?l0003o0?oo
o`<0003o00<0oooo0000o`000?l00P000?l80?ooo`<000000`3oool30000
00040?ooo`00000000000?ooo`8000001@3oool6000000040?ooo`000000
00000?ooo`80000000<0oooo0000000000000P000000103oool000000000
000000020?ooo`8000001P3oool300000080oooo0`0000050?ooo`800000
00D0oooo00000000000000000?ooo`02000000030?ooo`000000000000H0
oooo2`0000020?ooo`<0000000<0oooo0000000000002`3oool00`000000
oooo0?ooo`050?ooo`D000001`3oool00`000000oooo0?ooo`080?ooo`D0
00006P3oool7000000040?ooo`00000000000?ooo`D0000000<0oooo0000
000000000P3oool3000000D0oooo0P0000001@3oool00000000000000000
oooo0080000000<0oooo0000000000001@3oool3000000040?ooo`000000
00000?ooo`80000000<0oooo0000000000000P0000000`3oool000000?oo
o`02000000<0oooo00@000000?ooo`00000000000P3oool6000000040?oo
o`00000000000?ooo`<000002@3oool00`000000oooo0000000A0?ooo`D0
00001`3oool00`000000oooo0?ooo`020?ooo`D00000103oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo00@0oooo100000070?ooo`03
0000003oool0000000@0oooo1@0000090?ooo`030000003oool0oooo0200
oooo001A0?ooo`80003o1@3oool20000o`030?ooo`000?l0oooo00D0oooo
0P000?l00`3oool0003o0000o`020?ooo`80003o0P3oool20000o`80oooo
00<0003o0?ooo`3oool01@3oool20000o`030?ooo`000?l0003o0080oooo
00@0003o0?ooo`3oool0oooo0P000?l:0?ooo`030000003oool0oooo00<0
oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?oo
o`000000oooo00000080oooo00<000000?ooo`000000103oool010000000
oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool05`3oool01000
0000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo000000020?ooo`040000003oool0oooo000000H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000002
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P000002
0?ooo`030000003oool0oooo008000000P3oool010000000oooo0?ooo`00
00020?ooo`060000003oool0oooo0000003oool000002`3oool01@000000
oooo0000003oool0000000D0oooo1@0000070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool0203oool5000002T0oooo1@00000;
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000002`0oooo001A0?ooo`80003o1@3oool2
0000o`80oooo0`000?l30?ooo`80003o00<0oooo0000o`000?l00P3oool2
0000o`80oooo0P000?l70?ooo`H0003o103oool010000?l0oooo0?ooo`3o
ool20000o`X0oooo00<000000?ooo`3oool00`3oool01P000000oooo0?oo
o`000000oooo000000P0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool00P00
00020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0000000L0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo0?ooo`8000000P3oool0
0`000000oooo0000000=0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`800000203oool8
000000X0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00<000000?ooo`0000001@3oool00`000000
oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo000000080?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`8000002@3oool01@000000oooo0000003oool0
00000140oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05`3ooolF
000001X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02d0oooo001A0?ooo`80003o00<0oooo0000
o`3oool00P3oool20000o`040?ooo`000?l0003o0?ooo`80003o0P3oool2
0000o`030?ooo`000?l0003o0080oooo0P000?l20?ooo`D0003o103oool0
0`000?l0oooo0?ooo`020000o`H0oooo10000?l;0?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`3oool000000?ooo`04000000D0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`<0
000000H0oooo0000003oool0oooo0000003oool4000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<00000
103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`00
00000000103oool2000000h0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo0P00000L0?oo
o`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0000000<000000P3oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo00000003000000D0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0300000080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0000003oool0000000D0oooo1@0000070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo1@00000Y0?ooo`D0
00003@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02`0
oooo001A0?ooo`@0003o0`3oool20000o`040?ooo`000?l0003o0?ooo`80
003o0P3oool20000o`030?ooo`000?l0003o0080oooo0P000?l01@3oool0
003o0000o`000?l0oooo0080003o1@3oool010000?l0oooo0000o`000?l6
0?ooo`040000o`3oool0003o0000o`/0oooo00<000000?ooo`3oool00`3o
ool2000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`02000000070?ooo`00000000000?ooo`00
0000oooo000000020?ooo`030000003oool000000080oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo0?ooo`80000000@0oooo0000003oool000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo008000000P3oool00`000000oooo
000000020?ooo`060000003oool0oooo0000003oool000003@3oool00`00
0000oooo0?ooo`050?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool02P3oool2000001X0oooo00@000000?ooo`3oool000000P3o
ool2000000040?ooo`000000oooo00000080oooo0P0000001@3oool00000
0?ooo`3oool000000080oooo0P0000050?ooo`040000003oool0oooo0?oo
o`80000000@0oooo0000003oool000000P3oool00`000000oooo0?ooo`03
0?ooo`80000000L0oooo000000000000oooo0000003oool000000080oooo
00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00800000
0P3oool010000000oooo0?ooo`0000020?ooo`80000000@0oooo0000003o
ool000000P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`0000004@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000
;@3oool00540oooo0P000?l0103oool0003o0?ooo`3oool30000o`80oooo
20000?l0103oool0003o0000o`3oool50000o`040?ooo`000?l0003o0000
o`H0oooo00@0003o0?ooo`000?l0003o1P3oool010000?l0oooo0000o`00
0?l;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3o
ool2000000D0oooo0P0000001@3oool000000000003oool000000080oooo
00@000000?ooo`3oool0oooo0P0000030?ooo`@0000000<0oooo00000000
00001P3oool300000080oooo0`0000040?ooo`<000000P3oool00`000000
oooo000000030?ooo`8000001P3oool2000000030?ooo`000000oooo0080
00000P3oool300000080oooo00@000000?ooo`0000000000303oool00`00
0000oooo0?ooo`050?ooo`D000001`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00H0oooo1@00000;0?ooo`80000000@0oooo0000
00000000oooo0P0000000`3oool000000?ooo`020?ooo`80000000@0oooo
0000003oool0oooo0P0000020?ooo`80000000<0oooo0000003oool00P3o
ool300000080oooo00<000000?ooo`0000000`3oool2000000D0oooo0P00
00001@3oool000000?ooo`3oool0000000<0oooo0P0000020?ooo`800000
00<0oooo0000000000000P3oool2000000030?ooo`00000000000080oooo
0P0000001@3oool000000000003oool0000000<0oooo100000060?ooo`<0
000000@0oooo00000000000000003`3oool5000000L0oooo00<000000?oo
o`3oool00P3oool5000000@0oooo00<000000?ooo`3oool07`3oool50000
0280oooo00<000000?ooo`3oool05@3oool5000000030?ooo`0000000000
0080oooo00<000000?ooo`3oool0903oool00540oooo0P000?lU0?ooo`<0
003o1`3oool20000o``0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo0000000@0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?oo
o`050000003oool0oooo0?ooo`000000D`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P0000000`3oool000000?ooo`0C0?ooo`040000003oool0
oooo000002H0oooo001A0?ooo`80003o0`3oool010000?l0oooo0000o`00
0?lO0?ooo`80003o1`3oool20000o`T0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000a0?ooo`040000003oool0oooo0000
00<0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000E03o
ool3000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo0200oooo1`0000001`3oool000000?oo
o`3oool000000?ooo`0000004`3oool010000000oooo0?ooo`00000V0?oo
o`00D03oool70000o`030?ooo`000?l0003o01l0oooo0P000?l80?ooo`03
0000o`3oool0oooo00L0oooo1`0000000`3oool000000000000=0?ooo`03
0000003oool0oooo0280oooo0`0000060?ooo`8000003`3oool200000080
oooo00<000000?ooo`3oool0103oool2000000l0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01X0
oooo0P00000A0?ooo`800000:@3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo02T0oooo0P0000000`3oool000000?ooo`0B0?ooo`@0
00009`3oool00?l0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0
J`3oool00?l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0F0?ooo`800000`03oool2000006d0oooo003o0?ooool0ooooG`3oool0
0?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0oooo
G`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?oo
ool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo
003o0?ooool0ooooG`3oool00:X0oooo0`00003o0?oook40oooo002[0?oo
o`030000003oool0oooo0?l0oooo/03oool00:P0oooo1@00002F0?ooo`<0
0000o`3ooolH0?ooo`00Z03oool010000000oooo0?ooo`00002H0?ooo`03
0000003oool0oooo0?l0oooo5`3oool00:T0oooo00<000000?ooo`000000
U@3oool500000?l0oooo603oool00:X0oooo0P00002E0?ooo`040000003o
ool0oooo00000?l0oooo6@3oool00?l0oooo@`3oool00`000000oooo0000
003o0?oooaT0oooo003o0?oood@0oooo0P00003o0?oooaT0oooo002N0?oo
o`@000000`3oool4000000030?ooo`000000000000800000o`3ooon`0?oo
o`00]03oool200000880oooo100000030?ooo`P00000o`3ooolG0?ooo`00
]03oool00`000000oooo0?ooo`2G0?ooo`<00000o`3oool=0?ooo`00]03o
ool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo0?l0oooo3@3o
ool00:T0oooo0P0000090?ooo`030000003oool0oooo09L0oooo00<00000
0?ooo`3oool0o`3oool=0?ooo`00Z03oool010000000oooo0?ooo`000008
0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0o`3oool=
0?ooo`00ZP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
08/0oooo0P00000:0?ooo`030000003oool0oooo0?l0oooo3@3oool00:/0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2:0?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0o`3oool=0?oo
o`00Z03oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oo
o`d0oooo002Y0?ooo`8000002@3oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3oool=0?ooo`00
]03oool00`000000oooo0?ooo`2:0?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0o`3oool=0?ooo`00]03oool00`000000oooo
0?ooo`2;0?ooo`8000002P3oool00`000000oooo0?ooo`3o0?ooo`d0oooo
002d0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0XP3o
ool90000of40oooo002d0?ooo`030000003oool0oooo09L0oooo00<00000
0?ooo`3oool0VP3oool80000o`T0oooo20000?mI0?ooo`00]03oool00`00
0000oooo0?ooo`2G0?ooo`030000003oool0oooo09<0oooo00<0003o0?l0
00000?l010000?lI0?ooo`P0003oD@3oool00;@0oooo00<000000?ooo`3o
ool0U`3oool00`000000oooo0?ooo`2?0?ooo`@0003o00<0oooo0?l0003o
ool08P3oool00`000?l0oooo0?ooo`020000odl0oooo002d0?ooo`030000
003oool0oooo09L0oooo00<000000?ooo`3oool0S03oool30000o`D0oooo
00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`020?ooo`<0003o
C03oool00;@0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?oo
o`290?ooo`<0003o2@3oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3o
ool0oooo00H0oooo0P000?m:0?ooo`00]03oool00`000000oooo0?ooo`2G
0?ooo`030000003oool0oooo08H0oooo0`000?l<0?ooo`030?l0003oool0
oooo01l0oooo00<0003o0?ooo`3oool0203oool30000odL0oooo002d0?oo
o`030000003oool0oooo09L0oooo00<000000?ooo`3oool0Q03oool20000
o`l0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0;0?oo
o`80003oA@3oool00;@0oooo00<000000?ooo`3oool0U`3oool00`000000
oooo0?ooo`220?ooo`80003o4@3oool00`3o0000oooo0?ooo`0O0?ooo`03
0000o`3oool0oooo00d0oooo0`000?m20?ooo`00]03oool00`000000oooo
0?ooo`2G0?ooo`030000003oool0oooo0800oooo0P000?lC0?ooo`030?l0
003oool0oooo01l0oooo00<0003o0?ooo`3oool0403oool30000ocl0oooo
002d0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0OP3o
ool20000oaD0oooo00<0o`000?ooo`3oool07P3oool00`000?l0oooo0?oo
o`0D0?ooo`80003o?@3oool00;@0oooo00<000000?ooo`3oool0U`3oool0
0`000000oooo0?ooo`1m0?ooo`030000o`3oool0oooo01D0oooo00<0o`00
0?ooo`3oool07P3oool00`000?l0oooo0?ooo`0F0?ooo`80003o>`3oool0
0;@0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`1k0?oo
o`80003o603oool00`3o0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo
01P0oooo00<0003o0?ooo`3oool0>03oool00;@0oooo00<000000?ooo`3o
ool0RP3oool4000000T0oooo00<000000?ooo`3oool0NP3oool00`000?l0
oooo0000o`0I0?ooo``0o`00503oool00`000?l0oooo0?ooo`0I0?ooo`80
003o>03oool00;@0oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo07P0oooo0P000?l30?ooo`030000
o`3oool0oooo0140oooo1P3o000;0?ooo`H0o`003@3oool00`000?l0oooo
0?ooo`0L0?ooo`030000o`3oool0oooo03D0oooo002d0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`1g0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02P3o
ool70?l000D0oooo00<0o`000?ooo`3oool03`3oool50?l000P0oooo00<0
003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`0d0?ooo`00]03oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0M@3oool20000o`L0oooo00<0003o0?ooo`3oool01`3oool2
0?l000`0oooo00<0o`000?ooo`3oool0503oool40?l000@0oooo00<0003o
0?ooo`3oool07P3oool20000oc@0oooo002d0?ooo`030000003oool0oooo
08X0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`1c
0?ooo`80003o2@3oool00`000?l0oooo0?ooo`040?ooo`<0o`003P3oool0
0`3o0000oooo0?ooo`0H0?ooo`<0o`0000<0003o0?ooo`3oool08@3oool0
0`000?l0oooo0?ooo`0a0?ooo`00]03oool00`000000oooo0?ooo`2;0?oo
o`8000002P3oool00`000000oooo0?ooo`1b0?ooo`030000o`3oool0oooo
00X0oooo00@0003o0?ooo`3oool0oooo0P3o000A0?ooo`030?l0003oool0
oooo01/0oooo00<0003o0?l0003oool08P3oool00`000?l0oooo0?ooo`0`
0?ooo`00]03oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo
0740oooo00<0003o0?ooo`3oool02`3oool010000?l0o`000?l0003o000C
0?ooo`030?l0003oool0oooo01/0oooo00@0003o0?ooo`3o0000o`008P3o
ool00`000?l0oooo0?ooo`0_0?ooo`00]03oool00`000000oooo0?ooo`21
0?ooo`@000000`3oool8000000L0oooo00<000000?ooo`3oool0L03oool0
0`000?l0oooo0?ooo`0;0?ooo`80o`0000<0003o0?ooo`3oool04`3oool0
0`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo0080oooo0P3o000Q
0?ooo`030000o`3oool0oooo02h0oooo002[0?oooa<0003oT03oool30000
06l0oooo00<0003o0?ooo`3oool02P3oool20?l00080oooo00<0003o0?oo
o`3oool04`3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo
00@0oooo0P3o000P0?ooo`80003o;P3oool00:L0oooo10000?l90?ooo`03
0000o`3oool0oooo00L0oooo1@000?n;0?ooo`030000003oool0oooo06h0
oooo00<0003o0?ooo`3oool02@3oool20?l000D0oooo00<0003o0?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo00L0
oooo0P3o000P0?ooo`030000o`3oool0oooo02/0oooo002S0?ooo`040000
o`3o0000003o0000o`d0oooo00<0003o0?ooo`3oool0303oool20000o`03
0?l000000?l0oooo08H0oooo00<000000?ooo`3oool0K03oool20?l000X0
oooo0P3o00070?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3o
ool06@3oool00`000?l0oooo0?ooo`090?ooo`80o`007`3oool00`000?l0
oooo0?ooo`0Z0?ooo`00X@3oool20000o`030?ooo`3o0000oooo00h0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`040000oh<0oooo
00<000000?ooo`3oool0K03oool00`000?l0o`000?ooo`070?ooo`80o`00
2P3oool00`000?l0oooo0?ooo`0<0?ooo`D0003o00<0o`000000o`3oool0
603oool00`000?l0oooo0?ooo`0<0?ooo`80o`007P3oool00`000?l0oooo
0?ooo`0Y0?ooo`00WP3oool30000o`<0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00@0oooo0P00
0?md0?ooo`D00000203oool00`000000oooo0?ooo`1[0?ooo`040000o`3o
ool0oooo0?l000D0oooo0P3o000<0?ooo`030000o`3oool0oooo00<0oooo
2P000?l40?ooo`030?l0003oool0003o00D0003o4`3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool0
:03oool009`0oooo0P000?l60?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`060?ooo`80003oM03o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06X0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?l000h0oooo00@0
003o0?ooo`3oool0oooo0P000?l>0?ooo`030?l0003oool0oooo00D0oooo
1P000?l<0?ooo`030000o`3oool0oooo0100oooo0P3o000M0?ooo`030000
o`3oool0oooo02L0oooo002I0?ooo`<0003o2@3oool00`3o0000oooo0?oo
o`080?ooo`@0o`0000<0003o0?l0003o00000`3o000:0?ooo`030?l0003o
ool0oooo00P0oooo0P000?mb0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0J03oool20000o`H0oooo0P3o000A0?ooo`<0003o403o
ool00`3o0000oooo0?ooo`0;0?ooo`<0003o2@3oool00`000?l0oooo0?oo
o`0B0?ooo`80o`00703oool00`3o0000oooo0?ooo`0V0?ooo`00U`3oool2
0000o``0oooo00@0o`000?ooo`3oool0oooo1`3o00040?ooo`030000o`3o
ool0oooo00<0oooo203o00020?ooo`030?l0003oool0oooo00X0oooo0P00
0?m`0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0I`3o
ool00`000?l0oooo0?ooo`060?ooo`80o`003@3oool50000oa80oooo00<0
o`000?ooo`3oool03P3oool30000o`D0oooo00<0003o0?ooo`3oool05@3o
ool00`3o0000oooo0?ooo`0H0?ooo`030?l000000?l0oooo02L0oooo002D
0?ooo`<0003o3P3oool40?l000/0oooo00<0003o0?ooo`3oool02`3oool3
0?l000h0oooo00<0003o0?ooo`000?l0K@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool01P3oool0
103o0000oooo0?ooo`3o000:0?ooo`80003o103oool00`000?l0oooo0?oo
o`0@0?ooo`030?l0003oool0oooo0140oooo0P000?l30?ooo`030000o`3o
ool0oooo01H0oooo00<0o`000?ooo`3oool05P3oool0103o0000oooo0?oo
o`000?lW0?ooo`00T`3oool20000o`h0oooo0P3o00000`3oool0o`000?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o00000`3o
000;0?ooo`80003oK03oool2000000X0oooo00<000000?ooo`3oool0I@3o
ool00`000?l0oooo0?ooo`060?ooo`050?l0003oool0oooo0?ooo`3o0000
203oool20000o`L0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo
0?ooo`0C0?ooo`80003o00<0oooo0000o`3oool0603oool00`3o0000oooo
0?ooo`0D0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
903oool00940oooo0P000?l20?ooo`030000o`3oool0oooo00P0oooo0`3o
00030?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`030?ooo`80o`002@3oool010000?l0oooo0000
o`000?mf0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
0`000?l90?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
5P3oool20000oaX0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo02<0oooo002?0?ooo`80003o103o
ool00`000?l0oooo0?ooo`060?ooo`80o`001P3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool01P3o
ool20?l000H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`1c0?ooo`030000003oool0oooo06@0oooo00<0003o0?ooo`3oool0103o
ool20?l000H0oooo00<0o`000?ooo`3oool00P000?l<0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool05P3oool010000?l0oooo0000
o`000?lI0?ooo`80o`004@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo0280oooo002>0?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool00`3oool20?l000P0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00P0oooo0P3o
00030?ooo`030000o`3oool0oooo00@0oooo0P000?mc0?ooo`030000003o
ool0oooo06<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`070?ooo`030?l000000?l0oooo00d0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool08@3oool008d0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?l000X0oooo00<0o`00
0?ooo`3oool00`3ooolB0000o`@0oooo00<0o`000?ooo`3oool02P3oool2
0?l000030?ooo`000?l0oooo00L0oooo00<0003o0?ooo`3oool0L03oool0
0`000000oooo0?ooo`1S0?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?l0000>0?ooo`040000o`3oool0
oooo0?ooo`/0o`000P3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3o
ool0oooo00@0oooo0P000?lI0?ooo`030?l0003oool0oooo00/0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0P0?ooo`00S03oool0
0`000?l0oooo0?ooo`080?ooo`030000o`3o0000o`0000d0oooo00<0o`00
0000o`000?l00P000?l80?ooo`030000o`3oool0oooo00L0oooo10000?l0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?ooo`030000o`3oool0
003o00<0oooo00<0o`000?ooo`3oool01P3oool20000o`80oooo00<0o`00
0?ooo`3oool02`3oool00`3o0000003o0?l000020?l000/0oooo1`3o000B
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool05`3oool0
0`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool0803oool008/0oooo00<0003o0?ooo`3oool0203oool20?l0
00030000o`3oool0oooo00X0oooo0P000?l00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00/0oooo00@0o`000000o`000?l0003o2`3oool0
0`000?l0o`000?l000090?ooo`80003oK`3oool00`000000oooo0?ooo`1Q
0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0?l000080?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01`3oool30?l000030?oo
o`000?l0oooo00h0oooo00<0o`000?ooo`3oool00`3oool30?l000h0oooo
00<0003o0?ooo`3oool0203oool20000oaP0oooo00<0o`000?ooo`3oool0
1P3oool20?l000l0oooo00<0003o0?ooo`3oool07`3oool008X0oooo00<0
003o0?ooo`3oool01`3oool20?l00080oooo00<0003o0?ooo`3oool01`3o
ool30000o`80oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`0;0?ooo`040?l0003oool0oooo0?ooo`80003o203oool01@000?l0oooo
0?ooo`3oool0o`0000X0oooo00<0003o0?ooo`3oool0K03oool00`000000
oooo0?ooo`1Q0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo0`3o00050?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool01P3oool40?l000X0oooo00<0003o0?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0F0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0N0?ooo`00R@3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
0`3oool30000o`H0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo0P000?l60?ooo`030000
o`3oool0oooo0080oooo0P3o00090?ooo`030000o`3oool0oooo06/0oooo
00<000000?ooo`3oool0H03oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0003o00D0oooo0P000?l80?ooo`030?l0003oool0oooo00<0o`00
203oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo
0P3o00070?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0
5P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0180oooo
00<0003o0?ooo`3oool07@3oool008P0oooo00<0003o0?ooo`3oool01P3o
ool20?l000H0oooo00@0003o0?ooo`3oool0oooo0P000?l90?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`060?ooo`80003o0`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0JP3oool00`000000oooo
0?ooo`1O0?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0
003o0`3oool00`000?l0oooo0?ooo`080?ooo`<0o`002`3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo0P3o00050?ooo`03
0000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool05P3oool0103o0000
oooo0?ooo`3o000E0?ooo`030000o`3oool0oooo01d0oooo00270?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool30000o`/0
oooo00<0o`000?ooo`3oool01@3oool40?l000030000o`3o0000o`0000<0
o`001P3oool00`3o0000oooo0?ooo`090?ooo`<0003o2@3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo06T0oooo00<000000?ooo`3o
ool0GP3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`000?l02P3oool30?l000`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0>0?ooo`80o`000P3oool00`000?l0
oooo0?ooo`0?0?ooo`80003o5P3oool00`3o0000oooo0?l0000G0?ooo`03
0000o`3oool0oooo01`0oooo00260?ooo`030000o`3o0000oooo00D0oooo
0P3o000:0?ooo`80003o303oool00`3o0000oooo0?l000050?l000@0oooo
00<0003o0?ooo`3oool00`3oool50?l000030?ooo`3o0000oooo00`0oooo
0P000?l90?ooo`80o`001P3oool00`3o0000oooo0000o`1Z0?ooo`030000
003oool0oooo05h0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`040?ooo`80003o203oool20?l000<0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0100oooo
0P3o00000`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo01<0oooo
0P3o000I0?ooo`030000o`3oool0oooo01/0oooo00250?ooo`040000o`3o
ool0oooo0?l000@0oooo00<0o`000?ooo`3oool0203oool20000o`030?oo
o`000?l0oooo00X0oooo0`3o000:0?ooo`030000o`3oool0oooo00P0oooo
1@3o00090?ooo`030000o`3oool0oooo0080003o2@3oool00`3o0000oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0J@3oool00`000000
oooo0?ooo`1M0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0000o`060?ooo`80o`001@3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0o`000?ooo`0C0?ooo`030000o`3oool0oooo0140
oooo00@0o`000?ooo`3oool0o`00603oool00`000?l0oooo0?ooo`0K0?oo
o`00Q03oool00`000?l0oooo0?ooo`020?ooo`80o`0000<0oooo0?l0003o
ool02@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0
oooo0`3o00020?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`020?ooo`80o`001P3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00@0o`000?ooo`3o
0000o`001@3oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo
05`0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`050000o`3oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo3@000?l50?ooo`030?l0003oool0
oooo0100oooo00@0003o0?ooo`3oool0o`00503oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool05P3o
ool00`000?l0oooo0?ooo`0J0?ooo`00P`3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`80o`001@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool2
0?l000@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0I@3oool0
0`000000oooo0?ooo`1L0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0
o`000?l000T0oooo00<0o`000?ooo`000?l01@000?l40?ooo`030000o`3o
ool0oooo00H0oooo10000?l00`3o0000oooo0?ooo`0A0?ooo`040000o`3o
ool0oooo0?ooo`80o`004`3oool00`000?l0oooo0?ooo`0<0?ooo`80o`00
1P3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01T0oooo
00220?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o00001`3o
ool20000o`L0oooo00<0003o0?ooo`3oool00P3o00070?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`060?ooo`040?l0003oool0oooo0000o`P0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?l000070?ooo`030000o`3oool0oooo05X0oooo
0`0000080?ooo`030000003oool0oooo05/0oooo00H0003o0?ooo`3o0000
o`000?ooo`3o00060?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000003o0?ooo`090?ooo`030000o`3oool0oooo
00X0oooo00<0o`000000o`000?l0403oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo01D0oooo00<0003o0?oo
o`3oool06@3oool00840oooo00<0003o0?ooo`3oool01P3oool0103o0000
oooo0?ooo`3o00050?ooo`030000o`3oool0oooo00L0oooo00<0003o0?l0
003o00002P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01`3oool20?l000030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0
o`0000L0oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo05/0oooo00D0003o0?ooo`3oool0oooo0?l0
00060?ooo`030000o`3oool0oooo00@0oooo00<0o`000000o`3oool0203o
ool20000o`030?ooo`3o0000oooo00T0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`030000o``0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00L0oooo0P3o
000:0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0603o
ool00800oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l02@3oool20?l000030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool040000?l20?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?l0003o00002@3oool01@000?l0oooo0?oo
o`3oool0o`0000D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`1F0?ooo`D00000203oool00`000000oooo0?ooo`1J0?ooo`030000
o`3oool0oooo0080oooo0`3o00030?ooo`030000o`3oool0oooo00@0oooo
00@0o`000?ooo`3oool0003o1P3oool20000o`<0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00@0
oooo0P000?l90?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00/0
oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0H0?ooo`00
P03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`000?l0203oool20?l000<0oooo00<0003o0?ooo`3oool0
1`3oool20000o`030?l000000?l0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0o`000000o`0:0?ooo`040000o`3oool0oooo0?l000T0
oooo00<0003o0?ooo`3o00001`3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo05D0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`1J0?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0
0`3o0000oooo0000o`050?ooo`80o`00103oool010000?l0oooo0?ooo`3o
ool20000o`D0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00H0oooo0P000?l70?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool05P3o
ool00`000?l0oooo0?ooo`0G0?ooo`00O`3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo0P000?l2
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0000o`020000o`H0oooo00<0003o0?ooo`3oool00P3oool2
0?l000P0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo05H0oooo00<000000?ooo`0000002@3oool0
0`000000oooo0?ooo`1I0?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool20?l000@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0000o`070?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`80003o103oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo0140oooo00D0003o
0?ooo`3oool0oooo0?l0000@0?ooo`030?l0003oool0oooo01D0oooo00<0
003o0?ooo`3oool05`3oool007h0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0o`0000H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`80003o103oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool00P3oool30000o`80oooo00<0003o0?ooo`3oool01@3oool2
0?l000D0oooo00<0o`000?ooo`000?l0203oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo05H0oooo0P0000090?ooo`030000003oool0
oooo05T0oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`030000o`3o
ool0o`000080oooo00<0o`000?ooo`3oool01P3oool20000o`P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00/0oooo0P000?l00`3oool0003o0?ooo`0>0?ooo`030?l0003o
ool0oooo0100oooo00@0003o0?ooo`3o0000o`004@3oool00`3o0000oooo
0?ooo`0F0?ooo`030000o`3oool0oooo01H0oooo001m0?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`020000o`H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo0`000?l90?ooo`030?l0
003oool0oooo0080oooo00@0o`000?ooo`3oool0003o203oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3o
ool0F03oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00@0003o0?ooo`3oool0oooo0P3o00080?ooo`030000o`3oool0003o
00T0oooo00<0o`000?ooo`3oool01`3o00000`000?l0o`000?l000030?l0
00D0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool04P3oool00`3o
0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01H0oooo001m0?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`030?ooo`040?l0003oool0oooo0?l000X0oooo0P000?l80?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`070?ooo`<0003o2@3oool0103o0000oooo0?ooo`3o0004
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`1:0?ooo`@000000`3oool8000000L0oooo00<00000
0?ooo`3oool0F03oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?ooo`3oool00P3oool20?l000L0oooo00D0003o0?ooo`3oool0oooo
0000o`070?ooo`@0o`001P3oool20000o`D0oooo0P3o00020?ooo`030?l0
003oool0oooo00h0oooo0P000?lA0?ooo`030?l0003oool0oooo00h0oooo
00<0o`000?ooo`000?l04`3oool00`3o0000oooo0?ooo`0F0?ooo`030000
o`3oool0oooo01D0oooo001l0?ooo`80003o1`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo0P3o00090?ooo`<0003o2@3o
ool00`3o0000oooo0?ooo`020?ooo`@0o`0000<0003o0?l0003o00000`3o
00030?ooo`030?l0003oool0oooo00L0oooo00@0003o0?ooo`3oool0003o
2@3oool20?l000H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo05l0oooo0`00001G0?ooo`80003o
0`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3o00001@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00<0oooo0P3o00000`3oool0o`000?ooo`070?ooo`030000
o`3oool0oooo00H0oooo0`3o000?0?ooo`040000o`3oool0oooo0000oa00
oooo00<0o`000?ooo`3oool0303oool20?l00080oooo00<0003o0?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01D0
oooo001l0?ooo`040000o`3oool0003o0000o`@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`060?ooo`80o`00203oool01@000?l0
oooo0?ooo`3oool0003o00T0oooo103o00040?ooo`030000o`3oool0oooo
00<0oooo103o00080?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool00P3oool30000of40oooo00<000000?oo
o`3oool0E`3oool01@000?l0oooo0000o`3oool0o`0000@0oooo00<0003o
0?ooo`3oool00P3oool0103o0000oooo0?ooo`3oool20?l000030?ooo`00
0?l0003o00D0oooo00<0003o0?ooo`3oool00`3o00040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0203oool30?l000`0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00T0oooo0P3o00050?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0E0?ooo`00N`3oool0
0`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000L0oooo00<0
003o0?ooo`3oool01@3oool0103o0000oooo0?ooo`3o00060?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool30?l000L0oooo
00<0003o0?ooo`3oool01P3oool40?l000D0oooo00<0003o0?ooo`3oool0
0`3oool20000o`D0oooo00<0o`000?ooo`3o00001`3oool00`000?l0oooo
0?ooo`060?ooo`040?l0003oool0oooo0000o`<0oooo00<0003o0?ooo`3o
ool0GP3oool00`000000oooo0?ooo`1G0?ooo`030000o`3oool0oooo00<0
003o0`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0o`000000o`3oool01`3oool00`000?l0o`000?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool0103o0000
oooo0?ooo`3oool30?l000T0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00H0oooo0P3o00070?oo
o`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool05@3oool00`00
0?l0oooo0?ooo`0D0?ooo`00N`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0o`0000H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`020?ooo`040?l0003oool0oooo0?ooo`80003o1P3oool00`00
0?l0oooo0?ooo`020?ooo`80o`000`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool20?l0
0080oooo00<0003o0?ooo`3oool01P3oool01@000?l0oooo0?ooo`3oool0
o`0000<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l000000?l0003o00@0oooo00<0003o0?ooo`3oool0GP3oool0
0`000000oooo0?ooo`1F0?ooo`050000o`3oool0oooo0?ooo`3o00000P3o
ool00`000?l0oooo0000o`040?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?l0003oool01@3oool20?l000030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00@0oooo0P3o00060?ooo`030000o`3oool0oooo00D0oooo0P00
0?l?0?ooo`030?l0003oool0oooo00<0oooo0P3o000:0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?oo
o`0D0?ooo`00NP3oool00`000?l0oooo0?ooo`050?ooo`<0003o103oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`000?l02@3oool010000?l0oooo0?l0003o00050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030?l000000?l0oooo00T0oooo00<0003o0?ooo`3o00001@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo0P00
0?l00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0500oooo1@00
00080?ooo`030000003oool0oooo05H0oooo00D0003o0?ooo`3oool0oooo
0?l000030?ooo`80003o0`3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo0080o`000`3oool01@3o0000oooo0?ooo`3oool0003o00L0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00L0oooo0P3o00030?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool0303oool0103o0000oooo0?ooo`3oool20?l0
00`0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0E0?oo
o`030000o`3oool0oooo01<0oooo001j0?ooo`030000o`3oool0oooo00@0
oooo00@0o`000?ooo`3oool0oooo0P000?l00`3oool0003o0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0o`000?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`060?ooo`030000o`3o0000o`00
00T0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo0080003o0P3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo0580oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`1F0?ooo`040000o`3oool0oooo0?l000@0oooo00<0003o
0?ooo`000?l00P000?l50?ooo`030000o`3oool0oooo0080oooo00@0o`00
0?ooo`3o0000o`00103oool00`000?l0oooo0?ooo`050?ooo`030?l00000
0?l0003o00H0003o203oool00`3o0000oooo0?ooo`090?ooo`030?l0003o
ool0003o00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?l0
000?0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool05@3o
ool00`000?l0oooo0?ooo`0C0?ooo`00N@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00<0oooo0P000?l70?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3o00001`3oool20?l000030?ooo`000?l0
oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0?l0
00070?ooo`030?l0003oool0003o00H0oooo00<0o`000?ooo`3oool01P3o
ool20000o`D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`1A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0EP3o
ool010000?l0oooo0?ooo`3o00040?ooo`060000o`3oool0oooo0?ooo`3o
0000003o0`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@000?l00`3o0000oooo0?ooo`040?oo
o`@0003o103oool00`3o0000oooo0?ooo`0;0?ooo`030?l000000?l0oooo
00/0oooo00<0003o0?ooo`3oool0303oool20?l00100oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo
0180oooo001i0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool20000o`H0oooo00<0o`000?ooo`3oool01@3oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo0P3o00030?ooo`030000o`3oool0oooo
00D0oooo00<0o`000000o`000?l02`000?l00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo0080oooo0P3o00040?ooo`050?l0003oool0oooo
0?ooo`000?l01P3oool00`3o0000oooo0?ooo`040?ooo`80003o1P3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0540oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`1E0?ooo`050000o`3oool0
oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`000080oooo
0`000?l60?ooo`030?l0003oool0o`0000H0oooo0`000?l50?ooo`030?l0
003oool0oooo00@0oooo00@0003o0?ooo`3oool0oooo0P000?l20?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0
oooo0?ooo`090?ooo`80o`0000<0oooo0?l0003oool0403oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3o
ool04P3oool007P0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`040000o`3oool0003o0000o`<0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`030?ooo`040?l0003oool0oooo0?l0
00H0oooo00<0003o0?ooo`3oool00P3oool20000o`030?ooo`3o0000oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000003o0000o`040?oo
o`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3oool0o`001@3oool0
0`000?l0oooo0?ooo`040?ooo`040?l0003oool0oooo0?ooo`80003o0P3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0D03oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo05D0oooo00@0003o0?ooo`3oool0o`00103oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo0P000?l40?ooo`050?l0003oool0oooo0?oo
o`3o0000103oool30000o`H0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`80003o00<0o`000?ooo`3oool02@3oool20000
o`030?ooo`3o0000oooo00d0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo
0180oooo001h0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`020?ooo`80003o00<0oooo0?l0003o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0o`0000P0
oooo00@0003o0?ooo`000?l0003o0`3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`000?l00`3o
ool0003o0?ooo`070?ooo`80o`001P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0003o00D0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo04l0oooo0P00000:0?oo
o`030000003oool0oooo05D0oooo0P3o00000`3oool0o`000?ooo`020?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0000o`04
0?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`000?l0003o0P3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000003o0000o`090?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`050?ooo`80o`001@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?oo
o`0B0?ooo`00N03oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool2
0000o`D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo0P000?l80?ooo`80o`001`3oool0
0`000?l0oooo0?ooo`040?ooo`030?l000000?l0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo05/0oooo00<000000?ooo`3oool0>`3oool4000001H0oooo00<0003o
0?ooo`3o00000`3o00000`3oool0003o0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l00`3oool010000?l0oooo0?ooo`3o00050?ooo`030?l0
00000?l0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
0P000?l60?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`020?ooo`80o`001P3oool2000000030?l0
00000000oooo00h0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0E0?ooo`030000o`3oool0oooo0140oooo001g0?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l000000?l0003o00@0oooo00<0003o0?ooo`3oool01P3o
ool30?l000D0oooo0P000?l00`3oool0003o0?ooo`050?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`040000o`3oool0oooo0000o`D0oooo0P3o00020?ooo`030?l0
003oool0oooo00D0oooo00@0003o0?ooo`3oool0oooo0`000?l00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`1J0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool05P3oool010000?l0oooo0?ooo`3o00030?oo
o`80o`000P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo0P000?l60?ooo`030000o`3o0000oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool20000o`<0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
0080o`00203oool00`000000oooo0?l0000@0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0A0?oo
o`00E`3oool3000001d0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00@0o`000?ooo`3o
ool0oooo0P000?l00`3oool0003o0?ooo`070?ooo`050?l0003oool0oooo
0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0003o00H0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo
0000o`000?l40?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0240
oooo0`00000f0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool05@3oool010000?l0oooo0?ooo`3o00030?ooo`030000o`3oool0o`00
0080o`000`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0003o
00<0oooo0P000?l20?ooo`030?l0003oool0oooo0080oooo00@0003o0?oo
o`3oool0oooo1`3o00000`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`000?l02@3oool00`3o0000oooo0?ooo`0;
0?ooo`80o`002`3oool00`000000oooo0?l0000@0?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0A
0?ooo`00F03oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00<0oooo0P000?l70?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`000?l01@3oool00`000?l0oooo0?ooo`030?oo
o`D0o`0000<0003o0?l0003o00000`3o00050?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3o00001P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool08@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0503oool010000?l0oooo0?ooo`3o0003
0?ooo`040000o`3oool0oooo0?ooo`@0o`0000<0003o0?ooo`3oool00P3o
ool0103o0000oooo0?ooo`3oool30000o`D0oooo00H0o`000?ooo`3oool0
oooo0?l000000?l20?l00080oooo00H0o`000?ooo`3oool0oooo0?l00000
0?l20?l000@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00P0oooo0P3o00000`000?l0oooo0?oo
o`0;0?ooo`030000003o0000oooo00l0oooo00<0003o0?ooo`3oool0403o
ool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo0140oooo001E
0?ooo`D00000703oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0003o00D0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo0?ooo`@0o`000`3o
ool00`000?l0oooo0?ooo`020?ooo`<0o`000`3oool00`000?l0oooo0?oo
o`040?ooo`030?l000000?l0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool20000o`L0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool07P3o
ool5000003H0oooo00<000000?ooo`3oool0>`3oool010000000oooo0?oo
o`00000E0?ooo`040000o`3oool0oooo0?l000<0oooo00@0003o0?ooo`3o
ool0o`000`3oool00`000?l0o`000?ooo`020?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool0103oool01P3o0000oooo0?ooo`3o0000
oooo0000o`@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?l000030?ooo`3o0000oooo00P0oooo0P000?l<0?ooo`030?l0003o
ool0oooo00D0oooo0P3o00030?ooo`030000o`3oool0oooo00P0oooo00D0
00000?ooo`3oool000000?l0000@0?ooo`030000o`3oool0oooo0100oooo
00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0A0?ooo`00E@3o
ool010000000oooo0?ooo`00000M0?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00<0oooo00@0003o0?ooo`3oool0oooo0P000?l20?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3o00001P3oool00`000?l0
o`000?l000020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?l000030000o`3oool0oooo00@0
oooo00@0o`000?ooo`3oool0003o1P3oool00`3o0000oooo0?ooo`030000
o`80oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0M0?ooo`040000003oool0oooo000003L0oooo00<00000
0?ooo`3oool0?03oool2000001D0oooo00@0003o0?ooo`3oool0o`000`3o
ool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00H0003o0?ooo`3o0000
o`000?ooo`3o00050?ooo`80003o1P3oool20?l000<0oooo00D0003o0?oo
o`3oool0oooo0?l000030?ooo`030000o`3oool0oooo00<0oooo0P3o0008
0?ooo`040000o`3oool0oooo0000o`/0oooo00<0o`000?ooo`3oool00`3o
ool20?l000D0oooo00<0003o0?ooo`3oool02@3oool2000000030?ooo`3o
0000oooo00l0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0D0?ooo`030000o`3oool0oooo0140oooo001F0?ooo`030000003oool0
000001d0oooo103o00020?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo0`000?l60?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool20?l000030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo
0000o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0003oool0
0`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo
0P000?l50?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0o`00
803oool00`000000oooo0000000g0?ooo`030000003oool0oooo05<0oooo
00@0003o0?ooo`3oool0o`000`3oool01@000?l0oooo0?ooo`3oool0o`00
00<0oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0
oooo0080003o0P3oool30?l000@0oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3o0000o`00
1@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00T0oooo
00D0o`000?ooo`3oool0oooo0?l000080?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool04@3oool005L0oooo
0P00000M0?ooo`040000o`3oool0oooo0?ooo`<0o`001P3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0103oool0103o0000oooo0000o`000?l30?ooo`030000o`3oool0oooo
00<0oooo00@0o`000?ooo`3oool0o`000P3oool00`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?oo
o`020?ooo`040000o`3oool0oooo0?l000<0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`80003o00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool30?l000@0oooo00<0003o0?ooo`3oool0
7`3oool2000003L0oooo00<000000?ooo`3oool0>03oool4000000030?oo
o`0000000000008000004P3oool50000o`80oooo00@0003o0?ooo`3oool0
o`000`3oool01P000?l0oooo0?ooo`3oool0o`000?ooo`80o`000P3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3o0000oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`000?l0
1@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`0:0?ooo`<0o`002@3oool00`000?l0
oooo0?ooo`050?ooo`L0000000<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3o
ool0403oool007H0oooo00<0003o0?ooo`3oool00`3oool60?l000030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0
003o1P3oool20?l000@0oooo00D0003o0?ooo`3oool0oooo0?l000030?oo
o`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0o`0000H0oooo00@0003o0?ooo`3oool0003o0`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?l000040?l000H0oooo00<0
003o0?ooo`3oool0F03oool00`000000oooo0?ooo`1C0?ooo`050000o`3o
ool0oooo0?l0003oool010000?l00`3oool0o`000?ooo`020?ooo`050000
o`3oool0oooo0?ooo`3o00000`3oool20?l000030000o`3oool0oooo00<0
oooo00<0o`000000o`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o
00<0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`000?l01`3oool00`000?l0oooo0?ooo`08
0?ooo`80o`002`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0D
0?ooo`030000o`3oool0oooo0100oooo001;0?ooo`@00000103oool80000
01X0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`<0o`00103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool20000o`L0oooo0P3o00050?oo
o`060000o`3oool0oooo0?ooo`3o0000oooo10000?l00`3oool0o`000?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3o
ool30000o`@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo0`3o00040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool06`3oool8000003D0oooo00<0
00000?ooo`3oool0D`3oool00`000?l0oooo0?l000030?ooo`030000o`3o
ool0oooo00<0003o0P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00<0003o0?l0003o00000`3oool00`3o0000oooo0000o`040?ooo`030?l0
003oool0003o00@0003o00<0o`000000o`000?l00P000?l30?ooo`030?l0
003oool0oooo00@0oooo00<0o`000000o`3oool0203oool00`000?l0oooo
0?ooo`040?ooo`<0o`000P3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo
0?ooo`0@0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0
403oool007D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo0080o`000P3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3o
ool20000o`D0oooo00@0o`000?ooo`3oool0o`00103oool01@000?l0oooo
0?ooo`000?l0o`0000<0003o00@0oooo0000o`000?l0o`000P3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0o`0000D0oooo0`000?l60?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?l000020?l000030?ooo`000?l0oooo00D0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`1H0?ooo`030000003oool0oooo
0580oooo00@0003o0?ooo`3oool0o`000`3oool010000?l0oooo0?ooo`3o
00020?ooo`D0003o00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?oo
o`3oool0o`000080oooo00@0o`000?ooo`3oool0003o0`3oool01@3o0000
003o0?ooo`3oool0003o0080oooo00D0o`000?ooo`3oool0oooo0000o`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?l0003oool0203oool0
0`000?l0oooo0?ooo`020?ooo`80o`001@3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01<0oooo00@00000
0000o`0000000000403oool007D0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo1@3o0004
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`020000o`80oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`80003o0P3oool00`3o0000oooo0000o`02
0?ooo`030?l0003oool0003o0080003o103oool0103o0000oooo0?ooo`3o
00040?ooo`040000o`3oool0oooo0000o`H0oooo00<0o`000?ooo`3oool0
103oool010000?l0oooo0?ooo`3oool50?l000D0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo05P0
oooo00<000000?ooo`3oool0DP3oool010000?l0oooo0?ooo`3o00030?oo
o`040000o`3oool0oooo0?l000<0oooo00D0003o0?ooo`3oool0oooo0000
o`040?ooo`030000o`3oool0oooo0080oooo0P3o00040?ooo`<0003o00D0
o`000?ooo`3oool0oooo0000o`020?ooo`050?l0003oool0oooo0000o`3o
ool00P000?l00`3o0000oooo0?ooo`030?ooo`80003o0P3oool00`3o0000
oooo0?ooo`070?ooo`040000o`3o0000o`000?l000P0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0C0?oo
o`030000003oool0003o0140oooo001d0?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00<0o`0000<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
00001@3oool00`3o0000oooo0?ooo`020000o`<0oooo00<0o`000?ooo`00
0?l00P3oool00`3o0000oooo0?ooo`020000o`<0oooo00<0o`000?ooo`3o
ool00P3oool0103o0000oooo0?ooo`000?l30?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0o`000?l000040?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo05L0oooo00<000000?oo
o`3oool0>`3oool500000180oooo00@0003o0?ooo`3oool0o`000`3oool0
10000?l0oooo0?ooo`3o00030?ooo`050000o`3oool0oooo0?ooo`3o0000
1@000?l40?ooo`040?l0003oool0o`000?l00080oooo0P000?l20?ooo`04
0?l0003oool0oooo0000o`80oooo00@0o`000?ooo`3oool0003o0P3oool0
0`3o0000003o0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0103oool30?l000/0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`060?ooo`8000000`3oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0503oool0
0`000000003o0?ooo`0@0?ooo`00M03oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`D0o`0000<0oooo0?l0003oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`80003o1P3oool01@3o0000003o0?ooo`3oool0
003o0080oooo00D0o`000?ooo`000?l0oooo0?l000030?ooo`050000o`3o
ool0003o0000o`3o00001@3oool30000o`D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?l000050?l000H0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool0E`3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo0180oooo00@0003o0?ooo`3oool0o`000P3oool01@000?l0
oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
1`3o0000003o0?ooo`3oool0003o0?ooo`3o00000P3oool00`000?l0oooo
0?l000020?ooo`040000o`3oool0oooo0?l00080oooo00@0003o0?ooo`3o
ool0003o1P3oool00`3o0000oooo0?ooo`020?ooo`80o`000`3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0D
0?ooo`030000o`3oool0oooo00l0oooo001F0?ooo`800000703oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00<0oooo0`3o00050?ooo`030000o`3oool0oooo00@0oooo00@0o`000?oo
o`000?l0003o0`3oool20000o`040?l0003oool0oooo0000o`80oooo00D0
o`000?ooo`000?l0oooo0?l000020?ooo`060000o`3oool0oooo0?ooo`3o
0000003o0`3oool20000o`80oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`80o`001@3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo01d0oooo0P00000h0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool04P3oool40?l0
0080oooo00@0003o0?ooo`3oool0o`000`3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?ooo`000?l00`000?l40?ooo`030000o`3o
0000oooo0080oooo00L0003o0?ooo`3o0000oooo0000o`3oool0o`000080
oooo00<0003o0?ooo`3o0000103oool20000o`L0oooo00<0o`000?ooo`3o
ool00P3o00050?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`070?ooo`050000003oool0oooo0?oo
o`3o00003`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0180oooo00@000000?ooo`000?l00000403oool005D0oooo00@000000?oo
o`3oool000006`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o0000103o0006
0?ooo`030?l0003oool0oooo0080oooo0`000?l30?ooo`0<0?l0003oool0
oooo0000o`3oool0o`000?ooo`000?l0oooo0?l0003oool0003o0`3oool0
1P3o0000oooo0?ooo`000?l0oooo0000o`@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0o`000?l000040?l000H0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0L0?ooo`040000
003oool0oooo000003L0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0B0?ooo`030000o`3oool0oooo00T0o`0000<0oooo0000o`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`060000o`3oool0oooo0?oo
o`3o0000oooo0P000?l20?ooo`030000o`3oool0o`0000<0oooo00@0003o
0?l0003o0000003o0`3o00000`000?l0oooo0?l000040?ooo`<0003o1P3o
ool40?l000L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00L0oooo00@000000?ooo`3oool0o`00
403oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01<0oooo
00<000000000o`3oool0403oool005L0oooo00<000000?ooo`3oool06P3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0o`000?l0
00040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3o
ool0103o0000oooo0?ooo`000?l20?l000050000o`3o0000o`000?ooo`00
0?l00P3oool0103o0000oooo0?ooo`3oool20000o`H0oooo00@0o`000?oo
o`3oool0oooo0`3o00060?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0N
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0B0?ooo`040000o`3oool0oooo0?l00080oooo00@0
003o0?ooo`3oool0o`000P3oool60?l000<0oooo00<0003o0?ooo`3oool0
0P3oool0103o0000oooo0?ooo`3oool30000o`80oooo0P3o00001P3oool0
003o0?l0003o0000oooo0000o`80o`0000<0003o0?l0003o00000`3oool0
1@000?l0oooo0?ooo`3oool0003o0080oooo0`3o00020?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00@0oooo00@000000?ooo`3oool00000
0`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo0100oooo
00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0?0?ooo`00F03o
ool00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00H0o`001@3oool30000o`<0oooo00T0
o`000?ooo`000?l0oooo0?l000000?l0oooo0?l000000?l00`3o00020?oo
o`@0003o1@3oool50?l000<0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool07`3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo03`0oooo0P00000D0?ooo`040000o`3oool0oooo
0?l00080oooo00@0003o0?ooo`3oool0o`000`3oool010000?l0oooo0?oo
o`3oool60?l000<0oooo00<0o`000?ooo`3oool00P3oool30000o`<0oooo
0P3o00001`000?l0o`000?ooo`000?l0o`000000o`3oool00P3o00000`3o
ool0003o0000o`040?ooo`<0o`001@3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`050?ooo`800000103oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0503oool00`00
0?l0oooo0?ooo`0?0?ooo`00E@3oool010000000oooo0?ooo`00000K0?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00P3o00020?ooo`040000o`3oool0oooo
0?ooo`80003o00X0oooo0?l0003o0000oooo0000o`3o0000003o0?ooo`3o
0000003o0P3o00000`3oool0003o0000o`040?ooo`030000o`3oool0o`00
0080o`0000<0oooo0?l0003oool01@3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`0K0?ooo`040000003oool0oooo
000003L0oooo00<000000?ooo`3oool0DP3oool010000?l0oooo0?ooo`3o
00020?ooo`040000o`3oool0oooo0?l000<0oooo00D0003o0?ooo`3oool0
oooo0?l000030?ooo`030000o`3oool0o`0000D0o`000P3oool00`000?l0
oooo0?ooo`020000o`080?ooo`3o0000o`000?ooo`3o0000oooo0?l00000
0?l20?ooo`80o`0000@0003o0?ooo`3oool0oooo0`3o00000`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0
003oool0oooo01@0oooo00<0003o0?ooo`3oool03`3oool005H0oooo0P00
000L0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool30?l000D0oooo0P00
0?l0203oool0o`000000o`3oool0003o0?l000000?l0o`000P3oool00`00
0?l0oooo0?ooo`040?ooo`80o`00103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
01`0oooo0P00000h0?ooo`030000003oool0oooo0580oooo00@0003o0?oo
o`3oool0o`000P3oool010000?l0oooo0?ooo`3o00030?ooo`050000o`3o
ool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo00D0o`000P3oool30000o`070?l0003oool0o`000?l00000
0?l0oooo0?l000020000o`@0o`00103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo
01@0oooo00<0003o0?ooo`3oool03`3oool007@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3o0000o`0000@0o`0000@0oooo0000o`3o
ool0o`000P000?l20?l00080oooo00<0003o0?l0003oool01@3o00000`00
0?l0oooo0?ooo`030?ooo`80o`001@3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`1F0?ooo`030000003oool0oooo
0580oooo00@0003o0?ooo`3oool0o`000P3oool010000?l0oooo0?ooo`3o
00030?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00@0003o0?ooo`3oool0oooo103o00000`3o
ool0003o0?l000020?l000<0003o0`3o00070?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool0503oool00`000?l0oooo0?ooo`080?ooo`@000000`3oool007@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo0P000?l50?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool30?l000<0
003o0P3o00030000o`<0o`001@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0903oool2000000030?ooo`000000000002d0
oooo00<000000?ooo`3oool0DP3oool010000?l0oooo0?ooo`3o00020?oo
o`040000o`3oool0oooo0?l000<0oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0o`0000<0o`000P000?l20?l00080oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01@0oooo
00<0003o0?ooo`3oool01`3oool010000000oooo0?ooo`0000040?ooo`00
E03ooolP000003d0003o0P3o00130000ob0000001`3oool00`000000oooo
0000000^0?oooeD00000:@000?l00`3o0000003o0000o`1m0000o`T0oooo
00@000000?ooo`3oool00000103oool005@0oooo00<000000?ooo`3oool0
7@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool20000o`D0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0o`000`000?l20?l00080oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
7@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0B0?ooo`040000
o`3oool0oooo0?l00080oooo00@0003o0?ooo`3oool0o`000`3oool01@00
0?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`040000o`3oool0oooo0?ooo`D0o`0010000?l20?l000040000
o`3o0000o`000?l000L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool01P3oool200000003
0?ooo`000000000000@0oooo001D0?ooo`030000003oool0oooo01d0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`80003o0`3oool50?l000030?oo
o`000?l0003o00<0o`0000<0003o0?ooo`3o0000103o00030?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`030?ooo`80o`001@3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo01d0oooo00<000000?ooo`3oool0
103oool2000000030?ooo`000000000002d0oooo00<000000?ooo`3oool0
DP3oool010000?l0oooo0?ooo`3o00020?ooo`040000o`3oool0oooo0?l0
00<0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`040000o`3oool0
oooo0?ooo`80o`000`3oool40?l00080oooo00D0o`000000o`000?l0o`00
0?ooo`030000o`040?ooo`3o0000003o0000o`@0o`00103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool03`3oool007@0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`040000o`3o0000o`000?l00080
oooo00H0o`000000o`000?l0003o0?ooo`000?l20?l000050000o`3o0000
003o0000o`3o00000`3oool20?l000030?ooo`000?l0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`1F0?ooo`030000003oool0oooo0580oooo00@0
003o0?ooo`3oool0o`000P3oool010000?l0oooo0?ooo`3o00030?ooo`05
0000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?oo
o`@0o`0000<0oooo0000o`3oool00P3oool20000o`80o`0000<0oooo0000
o`3o00000P000?l01@3oool0o`000?ooo`3o0000003o00<0oooo0`3o0000
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0@
0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool03`3oool0
07@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`050?l000@0oooo0P000?l20?l0
00030?ooo`000?l0oooo0080o`0000@0003o0?ooo`3o0000o`000P000?l4
0?ooo`H0o`0000<0oooo0?l0003oool01@3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`1F0?ooo`030000003oool0
oooo0580oooo00@0003o0?ooo`3oool0o`000P3oool010000?l0oooo0?oo
o`3o00030?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool70?l000@0
oooo00@0003o0?ooo`000?l0003o0P3oool20?l000070000o`3o0000oooo
0000o`3o0000003o0?ooo`020?l000030?ooo`000?l0oooo00@0oooo0`3o
00060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo01@0oooo00<0003o0?ooo`3oool03`3oool007@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool3
0?l000@0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`80o`0000L0
oooo0000o`3o0000003o0?ooo`3o0000003o0080o`000P3oool20000o`80
oooo00<0003o0?ooo`3oool00`3oool20?l000H0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0EP3oool00`000000
oooo0?ooo`1B0?ooo`040000o`3oool0oooo0?l00080oooo00@0003o0?oo
o`3oool0o`000`3oool00`000?l0o`000?l000040?l000030?ooo`000?l0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool20000o`<0oooo00<0o`00
0?ooo`000?l00P3o00001P3oool0003o0?l0003oool0003o0?l000<0oooo
00@0003o0?ooo`3oool0oooo0P000?l20?ooo`<0o`000P3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo00l0oooo001d0?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`040000o`3oool0oooo0?ooo`80o`0000<0oooo0?l0003o
ool01@3oool00`000?l0oooo0000o`030?ooo`030?l0003oool0003o0080
o`0000@0003o0?ooo`3o0000003o0P3oool0103o0000oooo0?ooo`3oool2
0000o`L0oooo103o00020?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo05H0oooo00<000000?ooo`3oool0DP3oool0
1@000?l0oooo0?ooo`3o0000oooo00T0o`000`3oool00`3o0000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool20000o`030?oo
o`000?l0oooo0080o`000P3oool010000?l0o`000?l000000?l30?l00003
0000o`3oool0o`0000<0oooo00<0003o0?ooo`000?l01`3oool30?l000T0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0@0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3o
ool03`3oool007@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo
1@3o00030?ooo`030?l0003oool0oooo00<0oooo0`000?l30?ooo`040?l0
003oool0003o0?ooo`80o`0000D0003o0?l0003o0000oooo0000o`020?oo
o`040?l0003oool0oooo0?ooo`80003o1P3oool0103o0000oooo0?ooo`3o
ool50?l000<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo05L0oooo00<0
00000?ooo`3oool0DP3oool50?l000030?ooo`000?l0oooo0080oooo00@0
o`000?ooo`3oool0003o0`3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo0P000?l40?ooo`0;0?l0003oool0oooo0?ooo`00
0?l0oooo0?l0003oool0003o0?ooo`3o00000P3oool00`000?l0oooo0?l0
00030?ooo`80003o203oool00`3o0000oooo0?l000020?l000D0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool03`3o
ool007@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0o`000080o`000P3oool0
0`000?l0oooo0?ooo`030?ooo`040?l0003oool0oooo0?ooo`80003o0P3o
ool010000?l0oooo0?ooo`3o00020?ooo`070000o`3oool0o`000?ooo`00
0?l0oooo0?l000020?ooo`060000o`3oool0oooo0?l0003oool0003o0P3o
ool20000o`<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`020?l000030?ooo`3o0000oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`1G0?ooo`030000003o
ool0oooo0580oooo00@0003o0?ooo`3oool0o`000P3oool01@000?l0oooo
0?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool00P3oool0103o0000
oooo0?ooo`3oool50000o`030?l0003oool0oooo00<0oooo00H0o`000000
o`3oool0003o0?ooo`3o00020?ooo`030000o`3oool0o`000080oooo00@0
003o0?ooo`3oool0o`000P3oool00`000?l0oooo0000o`070?ooo`030?l0
003oool0oooo0080oooo0P3o00030?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0D0?ooo`030000o`3oool0oooo00l0oooo001d0?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo00@0003o0?ooo`3oool0oooo
1@3o00050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`000?l0
1@3oool01@000?l0o`000?ooo`3oool0003o0080oooo00D0o`000?ooo`00
0?l0oooo0?l000020?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool2
0000o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool6
0?l00080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`1G0?ooo`030000003oool0oooo0580oooo00@0003o
0?ooo`3oool0o`000P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo
00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00P3o00020?ooo`040000o`3oool0oooo0?l0
0080oooo00<0003o0?ooo`3o00000`3oool01P000?l0oooo0?ooo`3o0000
oooo0000o`80oooo0P000?l50?ooo`030?l0003oool0oooo00@0oooo0P3o
00000`3oool0003o0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`0@0?ooo`00M03oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`<0o`000`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000000o`3oool01@3oool01@3o0000003o0?ooo`3o
ool0003o0080oooo00<0o`000?ooo`000?l00P3oool0103o0000oooo0?oo
o`000?l20?ooo`030000o`3o0000oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo
0P3o00000`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo05L0oooo00<000000?ooo`3oool0DP3oool010000?l0oooo
0?ooo`3o00020?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01000
0?l0oooo0?ooo`3oool40000o`030?ooo`000?l0oooo00@0oooo0P3o0004
0?ooo`80003o00D0oooo0?l0003oool0oooo0000o`020?ooo`040?l0003o
ool0oooo0000o`<0oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo
0?ooo`3oool0o`0000T0oooo0`3o00080?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0503oool00`000?l0
oooo0?ooo`0@0?ooo`00M03oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool60?l000030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`020?ooo`<0003o00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020000o`<0oooo00<0o`000?ooo`000?l00P3oool01P3o0000oooo
0?ooo`000?l0oooo0000o`80oooo00<0o`000?ooo`3oool00P3oool0103o
0000oooo0000o`000?l40?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool50?l000030?ooo`3o0000oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo05L0oooo00<000000?ooo`3oool0DP3oool010000?l0oooo0?ooo`3o
00030?ooo`040000o`3oool0oooo0?l000<0oooo10000?l00`3o0000oooo
0?ooo`020?ooo`040000o`3oool0oooo0?ooo`<0o`00103oool010000?l0
oooo0?ooo`3o00030?ooo`040000o`3oool0oooo0?l000<0oooo0`000?l0
0`3oool0o`000?ooo`040?ooo`040000o`3oool0oooo0?l000T0oooo00<0
003o0?ooo`3oool00P3o00060?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo0100oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?oo
o`0@0?ooo`00M@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool20?l000H0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0
003o0000o`@0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`<0003o
00@0o`000?ooo`3oool0003o0P3oool00`3o0000oooo0000o`020000o`@0
oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`80003o00<0oooo0000
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo0`3o00040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`1G0?ooo`030000003oool0oooo
05<0oooo00@0003o0?ooo`3oool0o`000P3oool00`000?l0oooo0?ooo`05
0000o`@0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`050?l0003o
ool0oooo0?ooo`3o00000P3oool01@000?l0oooo0?ooo`3oool0o`0000H0
003o00<0o`000000o`000?l00P000?l30?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?l0003oool0203oool00`000?l0oooo0?ooo`030?ooo`80
o`000`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0403oool007D0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0o`0000<0oooo0?l0003oool01@3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?l000040?ooo`050000o`3oool0oooo0000o`3o
00001P000?l0103o0000oooo0?ooo`000?l50?ooo`030?l0003oool0o`00
00H0oooo0P000?l60?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?l000020?l000030?ooo`000?l0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1G0?oo
o`030000003oool0oooo05<0oooo00D0003o0?ooo`3oool0o`000?ooo`04
0000o`050?ooo`3o0000oooo0?ooo`000?l0103oool00`3o0000oooo0?oo
o`020?ooo`030000o`3o0000oooo00@0oooo00<0o`000000o`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`00
0?l0003o1`3oool00`000?l0oooo0?ooo`060?ooo`80o`0000<0oooo0?l0
003oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0D0?oo
o`030000o`3oool0oooo0100oooo001e0?ooo`030000o`3oool0oooo00@0
oooo00@0o`000?ooo`3oool0oooo1@3o00040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`80003o203oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00@0o`000?ooo`3oool0003o0`3oool01@3o0000oooo0?ooo`3o
ool0003o00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0000
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`D0o`000P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo05L0oooo00<000000?ooo`3oool0D`3o
ool50000o`030?ooo`000?l0oooo0080oooo00D0o`000?ooo`3oool0oooo
0000o`030?ooo`030?l0003oool0oooo00<0o`0000<0003o0?ooo`3oool0
0`3oool00`000?l0o`000?ooo`020?ooo`050?l0003oool0oooo0?ooo`00
0?l00`3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00@0o`000?oo
o`3oool0o`00103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo00P0oooo0P3o000<0?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo01@0oooo00<0003o0?ooo`3oool0403oool007D0oooo00<0003o0?oo
o`3oool0103oool40?l00080oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool00`000?l20?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`070000o`3oool0oooo0?ooo`3o0000
oooo0?l000060?ooo`030000o`3oool0oooo0080003o0P3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`<0o`001P3oool00`000?l0
oooo0?ooo`1H0?ooo`030000003oool0oooo05<0oooo00@0003o0?ooo`3o
ool0o`000`3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0003o
0?ooo`3oool00P3oool20?l000@0oooo00D0003o0?ooo`3oool0oooo0000
o`020?ooo`030?l0003oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo
0?l000030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o0000
1P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00T0oooo
00@0o`000?ooo`3o0000o`002@3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0D0?ooo`030000o`3oool0oooo0100oooo001f0?ooo`030000
o`3oool0o`0000@0o`001P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool20000o`H0oooo
00<0003o0?ooo`3oool00P3oool01`3o0000oooo0?ooo`3oool0o`000?oo
o`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`00
0?ooo`3oool00P3oool010000?l0oooo0?ooo`3o00030?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool20000o`L0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo1P3o00000`3oool0003o0?ooo`1I0?ooo`030000003o
ool0oooo05<0oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`050000
o`3oool0oooo0?ooo`3o00000`3oool01P000?l0oooo0?ooo`3o0000oooo
0?l000D0oooo0`000?l40?ooo`80o`00103oool01@000?l0oooo0?ooo`3o
ool0o`0000<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`060?ooo`050000o`3oool0oooo0?ooo`000?l02P3oool00`3o0000oooo
0?ooo`020?ooo`80o`001`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00h0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo
0?ooo`0D0?ooo`030000o`3oool0oooo0140oooo001f0?ooo`80o`00103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
0000oooo00H0oooo00<0003o0?ooo`3oool00P3o00050?ooo`030?l00000
0?l0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?l0003oool0103oool0103o0000oooo
0?ooo`000?l70?ooo`030?l000000?l0003o00@0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool20?l005X0oooo00<000000?ooo`3o
ool0E03oool010000?l0oooo0?ooo`3o00020?ooo`050000o`3oool0oooo
0?ooo`3o00000`3oool00`000?l0o`000?l000030?ooo`030?l0003oool0
oooo0080oooo0P000?l50?ooo`060?l0003oool0o`000?l0003oool0003o
103oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0?ooo`<0
o`002@3oool00`000?l0oooo0000o`0;0?ooo`030?l0003oool0oooo00@0
oooo0P3o00040?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01@0
oooo00<0003o0?ooo`3oool04@3oool007H0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0003o0080
oooo00<0o`000?ooo`3oool01@3oool00`000?l0o`000?ooo`060?ooo`06
0000o`3o0000o`000?l0003oool0o`00103oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0o`000080o`0000<0003o0?ooo`3oool01@3oool0
0`3o0000003o0?ooo`060?ooo`050?l0003oool0oooo0?ooo`000?l00`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo05T0oooo00<000000?ooo`3oool0E03oool010000?l0oooo0?oo
o`3o00020?ooo`060000o`3oool0oooo0?ooo`3o0000oooo0`3o00000`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`000?l0103oool01`3o0000oooo0?ooo`3oool0o`000000o`3o00000`3o
ool00`3o0000oooo0?ooo`020?ooo`040000o`3o0000o`000?l000<0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00L0oooo0`3o00000`3oool0003o0?ooo`0<0?ooo`030?l0
003oool0oooo00h0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0D0?ooo`030000o`3oool0oooo0140oooo001f0?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo0`000?l40?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000000o`000?l01@3oool00`000?l0oooo0?oo
o`020?ooo`@0o`000P3oool00`000?l0oooo0?ooo`040?l000@0oooo00<0
003o0?ooo`3oool0103oool00`000?l0o`000?ooo`060?ooo`030?l0003o
ool0oooo0080oooo0`000?l60?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo05T0oooo00<000000?ooo`3oool0E03oool010000?l0oooo0?oo
o`3o00030?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0
oooo0?ooo`030?ooo`040?l0003oool0003o0000o`<0oooo00@0003o0?oo
o`3oool0o`00103oool00`000?l0oooo0?ooo`080?l000030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0000o`0:
0?ooo`030?l0003oool0oooo00X0oooo0P3o000=0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0E
0?ooo`030000o`3oool0oooo0140oooo001g0?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00<0oooo0P000?l60?ooo`030?l0003oool0oooo
00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00P3o00001P000?l0o`000?l0003o
0000oooo0?l000D0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo
0?ooo`3o00050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`1J0?ooo`03
0000003oool0oooo05@0oooo00D0003o0?ooo`3oool0oooo0?l000020?oo
o`030000o`3o0000o`000080o`00103oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?l0003oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`80003o0`3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00/0oooo00@0003o0?oo
o`3o0000o`002P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0A
0?ooo`00M`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool0
003o0080oooo00<0003o0?ooo`3oool0103oool01@3o0000oooo0?ooo`3o
ool0o`0000D0oooo00@0003o0?ooo`3oool0003o1P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0`3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3o
ool0oooo0?l000070?ooo`040000o`3oool0003o0000o`<0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`1E
0?ooo`030000o`3oool0oooo00@0o`00103oool00`3o0000oooo0?ooo`02
0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0?l000050?ooo`030?l0
00000?l0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00D0o`000?ooo`3oool0
oooo0000o`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`020?ooo`80o`00203oool00`3o0000
oooo0?ooo`0>0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`0B0?ooo`00M`3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
103oool0103o0000oooo0000o`000?l30?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3o00001`3oool00`000?l0oooo0000o`060?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`<0003o1P3oool00`3o0000oooo0?l000070?ooo`03
0000o`3oool0oooo0080oooo0P000?l00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`1J0?ooo`030000003oool0oooo05D0oooo103o00030?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool010000?l0oooo0?ooo`000?l2
0?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`000?l0003o0P3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool01@3oool0103o0000oooo0000o`000?l80?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`040?ooo`80o`001@3oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo0100oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo
0?ooo`0B0?ooo`00N03oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool20000o`H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`80003o1@3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0103oool20000o`H0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo0500oooo0`0000080?ooo`030000003oool0oooo05D0oooo00@0
003o0?ooo`3oool0o`000`3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo0P000?l40?ooo`050?l0003oool0oooo0?ooo`3o
0000103oool30000o`H0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030?l000000?l0oooo00X0oooo00D0003o0?ooo`3o
ool0oooo0?l0000=0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0B0?oo
o`00N03oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00P3oool20000o`030?ooo`3o0000oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?l000080?ooo`03
0000o`3oool0003o0080003o0P3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`000?l00`3oool0
003o0?ooo`060?ooo`030?l0003oool0o`0000H0oooo00<0003o0?ooo`3o
ool0103oool0103o0000oooo0?ooo`000?l40?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`1A0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0EP3oool01000
0?l0oooo0?ooo`3o00030?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00`000?l50?ooo`040?l0003oool0oooo0?l000D0oooo0`00
0?l50?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3o
ool20000o`030?ooo`3o0000oooo00/0oooo00<0003o0?l0003o00003@3o
ool00`000?l0oooo0?ooo`090?ooo`80o`0000<0oooo0?l0003oool0403o
ool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01H0oooo00<0
003o0?ooo`3oool04P3oool007T0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo0000o`@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`040?l0003o
ool0oooo0?l000H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0o`00
0000o`050?ooo`030000o`3oool0oooo00<0oooo00@0003o0?l000000?l0
003o103oool00`000?l0oooo0?ooo`040?ooo`050?l0003oool0oooo0?oo
o`3o0000103oool00`000?l0oooo0?ooo`050?ooo`050?l0003oool0oooo
0?ooo`000?l00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0CP3oool5000000P0oooo00<00000
0?ooo`3oool0EP3oool010000?l0oooo0?ooo`3o00030?ooo`030000o`3o
ool0oooo0080oooo00<0o`000000o`000?l00`3oool00`000?l0oooo0?oo
o`030?ooo`80o`001P3oool00`000?l0oooo0?ooo`040000o`030?ooo`3o
0000oooo00D0oooo1@000?l30?ooo`030?l0003oool0oooo00X0oooo00<0
o`000000o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`80o`004@3o
ool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01D0oooo00<0
003o0?ooo`3oool04`3oool007T0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`<0003o1P3oool00`3o0000oooo0?ooo`04
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool20?l000<0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0000o`0:0000o`030?ooo`3o
0000oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`040?l0003oool0oooo0000o`L0oooo00<0o`000?ooo`3oool0
0`3oool30000o`H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`1?0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool0EP3oool010000?l0oooo0?ooo`3o00040?ooo`060000o`3oool0oooo
0?ooo`000?l0o`00103oool00`000?l0oooo0?ooo`020?ooo`040?l0003o
ool0o`000?l000@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000003o
0000o`060000o`P0oooo00<0o`000?ooo`3oool0203oool0103o0000oooo
0?ooo`000?l;0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
00003`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo01D0
oooo00<0003o0?ooo`3oool04`3oool007T0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`020?ooo`<0003o203oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0o`0000L0oooo0P3o00000`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`3o
00001`3oool00`3o0000003o0?ooo`070?ooo`030?l0003oool0oooo00D0
oooo0`000?l30?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0D03oool00`000000oooo000000090?ooo`030000003oool0oooo05L0
oooo00@0003o0?ooo`3oool0o`000`3oool40000o`030?ooo`3o0000oooo
00@0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0
oooo0?ooo`000?l01`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool20?l000@0oooo00<0
003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0=0?ooo`040?l0003o
ool0oooo0?ooo`80o`003@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0
003oool0oooo01H0oooo00<0003o0?ooo`3oool04`3oool007X0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020000o`80oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0o`000?l000080?ooo`030000o`3o0000oooo00H0oooo00<0
o`000?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0003o0080oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`1B0?ooo`800000
2@3oool00`000000oooo0?ooo`1G0?ooo`040000o`3oool0oooo0?l00080
oooo0`000?l40?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0003o
00001@3oool20?l000030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool00`3oool20?l000X0
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0F0?ooo`03
0000o`3oool0oooo01<0oooo001j0?ooo`030000o`3oool0oooo00D0oooo
00<0o`000000o`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`000?l02@3oool00`000?l0o`00
0?l000060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030?l000000?l0oooo00L0oooo
00@0003o0?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00<0oooo0P000?l70?ooo`030000o`3oool0oooo05d0
oooo00<000000?ooo`3oool0F03oool01@000?l0oooo0?ooo`3o0000003o
0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`030?l000000?l0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool04P3oool00`3o
0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01@0oooo001k0?ooo`03
0000o`3oool0oooo00<0oooo0P000?l70?ooo`030000o`3oool0oooo00H0
oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo
00D0oooo00@0003o0?ooo`3oool0oooo0`3o00020?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool0103o0000oooo0?ooo`3o
ool40?l000030?ooo`000?l0oooo00H0oooo00<0003o0?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0o`0000P0oooo00<0003o0?ooo`3oool0
103oool00`3o0000003o0000o`040?ooo`030000o`3oool0oooo04l0oooo
200000070?ooo`030000003oool0oooo05P0oooo10000?l40?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0000o`070?ooo`030000o`3o0000o`0000H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0o`000080o`00
2P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool0203oool20?l000H0oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01@0oooo
001k0?ooo`040000o`3oool0oooo0?ooo`80003o0P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o0000
1@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
0`3o00070?ooo`030000o`3oool0oooo00H0oooo0`3o00060?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0103o0000oooo
0?ooo`3o00070?ooo`030000o`3oool0oooo00@0oooo00@0o`000?ooo`3o
ool0oooo0P000?l20?ooo`030000o`3oool0oooo05h0oooo0`00001H0?oo
o`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`03
0?ooo`040?l0003oool0o`000?l000<0oooo00<0003o0?ooo`3oool00`3o
ool010000?l0oooo0?ooo`3oool20?l000<0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`070?ooo`<0o`003P3oool01@000?l0oooo
0?ooo`3oool0003o00l0oooo00<0o`000?ooo`3oool02`3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`0E0?ooo`00O03oool30000o`@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00D0oooo0P000?l30?ooo`030000o`3oool0oooo00L0oooo
1P3o00020?ooo`030000o`3oool0oooo00L0o`00203oool010000?l0oooo
0?ooo`3oool20000o`P0oooo0P3o00070?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool00`3oool20000of40oooo00<000000?ooo`3o
ool0F@3oool010000?l0oooo0?ooo`3o00040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00<0oooo103o00080?ooo`030000o`3oool0oooo
00D0oooo0P3o00000`3oool0o`000?ooo`0?0?ooo`<0003o3`3oool00`3o
0000oooo0?ooo`0=0?ooo`80o`000P3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool05@3oool007`0
oooo0P000?l60?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool20?l000T0oooo0`000?l90?ooo`030?l0003oool0oooo00@0
oooo0P3o00000`000?l0o`000?l000060?ooo`030?l0003oool0oooo00L0
oooo0`000?l:0?ooo`80o`001P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0G`3oool00`000000
oooo0?ooo`1I0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`00
0?l0oooo0?ooo`020?ooo`80o`001P3oool20000o`030?ooo`000?l0oooo
00P0oooo2P3o00000`000?l0o`000?l000040?l000<0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
00l0oooo00<0o`000000o`3oool04`3oool00`3o0000oooo0?ooo`0E0?oo
o`030000o`3oool0oooo01H0oooo001n0?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`04
0?l0003oool0oooo0?l000T0oooo0`000?l80?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00P0oooo0P3o00020?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0FP3oool01000
0?l0oooo0?ooo`3o00040?ooo`030000o`3oool0oooo0080o`000P3oool0
0`3o0000oooo0?ooo`050?ooo`80003o203oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0000o`0?0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?l0003o00004P3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0
oooo01H0oooo001n0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020000o`H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00@0oooo0`000?l00`3oool0003o0?ooo`060?ooo`80o`001@3oool0
103o0000oooo0?ooo`000?l80?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0D`3oool5000000P0oooo00<000000?ooo`3oool0FP3o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?l0003oool0
103oool00`3o0000oooo0?ooo`040?ooo`80003o203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
2P3oool20000o`<0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0A0?ooo`040000o`3oool0oooo0?l00140oooo00<0o`000?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`0G0?ooo`00O`3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?l0003o0000
1P3oool20?l000H0oooo00<0003o0?ooo`3oool00P3oool30000o`<0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`040?l0
003oool0oooo0?ooo`80003o1@3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000000o`3oool01`3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo05H0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1J0?ooo`050000o`3oool0oooo0?oo
o`3o00000`3oool20?l000030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020000o`H0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00L0oooo0P000?l60?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`020?ooo`80o`003P3oool00`3o
0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01L0oooo00200?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
003o0?ooo`080?ooo`80o`000`3oool00`000?l0oooo0?ooo`060?ooo`80
003o00<0oooo0?l0003oool01`3oool00`000?l0oooo0?ooo`070?ooo`04
0?l000000?l0003o0000o`L0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3o0000oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`1G0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0F`3oool01`000?l0oooo0?ooo`3oool0
o`000?ooo`3o00000`3oool00`000?l0oooo0?ooo`040?ooo`040?l0003o
ool0oooo0000o`D0oooo0P000?l40?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`050?ooo`80003o
203oool00`000?l0oooo0?ooo`070?ooo`80o`004`3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0
5@3oool00`000?l0oooo0?ooo`0H0?ooo`00P03oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool0003o
2P3oool0103o0000oooo0?ooo`000?l:0?ooo`030?l000000?l0003o00L0
oooo00<0003o0?ooo`3oool01@3oool20000o`030?l0003oool0oooo00T0
oooo00@0003o0?ooo`3o0000o`002@3oool010000?l0oooo0?ooo`3o0005
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0F03oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo05/0oooo00@0003o
0?ooo`3oool0oooo0P3o00050?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`000?l01`3oool20000o`80oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo0P00
0?l;0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`070?ooo`80o`002P3oool00`3o0000oooo0?oo
o`0E0?ooo`030000o`3oool0oooo01T0oooo00210?ooo`030000o`3oool0
oooo00D0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000000o`3oool02P3oool00`3o0000oooo0?oo
o`0?0000o`<0oooo00<0o`000?ooo`3oool0203oool00`000?l0o`000?oo
o`090?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo
0?l000080?ooo`030000o`3oool0oooo05P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`1L0?ooo`030000o`3oool0o`000080oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00P0oooo00<0003o0?l000000?l00P000?l80?ooo`030000
o`3oool0oooo00X0oooo00<0o`000000o`000?l00P000?l>0?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
5P3oool00`000?l0oooo0?ooo`0I0?ooo`00PP3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0o`0000H0oooo00<0003o0?ooo`3oool01`3o
ool010000?l0oooo0?l0003o00090?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030?l0
00000?l0oooo00P0oooo00<0003o0?ooo`3oool0103oool0103o0000oooo
0?ooo`3o00070?ooo`030000o`3oool0oooo05P0oooo0P00000:0?ooo`03
0000003oool0oooo05`0oooo0P3o00030?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`000?l0o`000?ooo`090?ooo`04
0?l0003oool0oooo0?ooo`<0003o1@3oool00`000?l0oooo0?ooo`080?oo
o`80003o00<0o`000?ooo`3oool04@3oool01@000?l0oooo0?ooo`3oool0
o`0001D0oooo00<0003o0?ooo`3oool02`3oool20?l000H0oooo00<0o`00
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0J0?ooo`00P`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`80o`001P3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool01@3oool30?l000030?ooo`000?l0oooo00L0oooo00<0003o0?oo
o`3oool01P3oool20?l000L0oooo00<0003o0?ooo`3oool0I@3oool00`00
0000oooo0?ooo`1M0?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00`3oool010000?l0oooo0?ooo`3oool20000o`80oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`040?oooa00003o0`3oool0
0`3o0000oooo0?ooo`0@0?ooo`040000o`3oool0o`000?l001D0oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo01H0oooo00<0003o0?ooo`3oool06P3oool008<0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?l000080?ooo`80003o1@3oool0
0`000?l0oooo0?ooo`040?ooo`<0o`000`3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00P3oool3
0?l000D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`07
0?ooo`80o`001P3oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0
oooo05d0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0003o00D0oooo0P3o00060?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool0403oool0
1@3o0000oooo0?ooo`3oool0o`0001L0oooo00<0003o0?ooo`3oool06`3o
ool008@0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0o`0000T0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`070?ooo`<0o`002`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0o`000080o`002@3oool010000?l0oooo0?ooo`3oool20000o`T0oooo
00@0o`000?ooo`3oool0o`00103oool00`000?l0oooo0?ooo`1W0?ooo`03
0000003oool0oooo05h0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`030?ooo`80003o1`3oool20?l000@0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0100
oooo00<0o`000?ooo`000?l04`3oool20000oa@0oooo00<0o`000?ooo`3o
0000603oool00`000?l0oooo0?ooo`0K0?ooo`00Q@3oool010000?l0oooo
0?ooo`3o00050?ooo`030?l0003oool0oooo00L0oooo00@0003o0?ooo`3o
ool0003o303oool40?l000P0oooo00<0003o0?ooo`3oool0203oool20?l0
00`0oooo00@0003o0?ooo`000?l0003o2P3oool00`3o0000oooo0?ooo`02
0?ooo`040?l0003oool0oooo0000ofX0oooo00<000000?ooo`3oool0GP3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo0P00
0?l90?ooo`80o`0000<0oooo0?l0003oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00h0oooo0P3o00020?ooo`030000o`3o
ool0oooo0100oooo00<0003o0?ooo`3oool05@3oool20?l001L0oooo00<0
003o0?ooo`3oool0703oool008H0oooo00<0003o0?l0003oool01P3oool0
0`3o0000oooo0?ooo`070?ooo`<0003o303oool0103o0000oooo0?ooo`3o
ool80?l000030000o`3o0000o`0000P0o`0000<0oooo0?l0003oool02`3o
ool20000o`X0oooo0P3o00060?ooo`030?l000000?l0oooo06X0oooo00<0
00000?ooo`3oool0G`3oool00`000?l0oooo0?ooo`030?ooo`050?l0003o
ool0oooo0?ooo`000?l00P3oool20000o`T0oooo0P3o000<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool30?l000D0oooo
00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0E0?ooo`040?l0
003oool0oooo0?l001D0oooo00<0003o0?ooo`3oool07@3oool008L0oooo
00<0o`000?ooo`3oool01P3oool20?l000P0oooo0`000?l;0?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`070?ooo`80003o00<0oooo0000o`3oool0203oool00`3o0000oooo
0?ooo`060?ooo`030000o`3o0000oooo06X0oooo00<000000?ooo`3oool0
H03oool00`000?l0oooo0?ooo`030?ooo`030?l000000?l0003o00D0oooo
00<0003o0?ooo`3oool01P3oool0103o0000oooo0?l0003o000:0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02@3oool20?l000P0
oooo00<0003o0?ooo`3oool0303oool20000oaL0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo01d0
oooo00280?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
103oool010000?l0oooo0?ooo`3oool30000o`P0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0J`3oool00`000000
oooo0?ooo`1P0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?l0003o
ool01P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080
oooo0P3o00080?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool01P3oool30?l000/0oooo00<0003o0?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0F0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0N0?ooo`00R@3oool00`000?l0oooo
0?ooo`070?ooo`80o`000`3oool00`000?l0oooo0?ooo`050?ooo`<0003o
1@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool0103oool20000o`H0oooo00<0003o0?ooo`3oool0
0P3oool20?l000P0oooo00<0003o0?ooo`3oool0K03oool00`000000oooo
0?ooo`1Q0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o0000
1`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
0`3o00050?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
103oool20?l000h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0G0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`0O0?ooo`00RP3oool00`000?l0oooo0?oo
o`080?ooo`040?l0003oool0oooo0000o`X0oooo0P000?l20?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool0103o0000oooo
0?ooo`3oool20000o`T0oooo00@0003o0?ooo`3oool0o`002@3oool00`00
0?l0oooo0?ooo`1]0?ooo`030000003oool0oooo0640oooo00<0003o0?oo
o`3oool00P000?l30?ooo`030?l0003oool0oooo00D0oooo0P000?l20?oo
o`030?l0003oool0oooo00P0oooo103o00000`000?l0o`000?ooo`0>0?oo
o`H0o`004@3oool00`000?l0oooo0?ooo`060?ooo`80003o6@3oool00`3o
0000oooo0?ooo`070?ooo`80o`003@3oool00`000?l0oooo0?ooo`0P0?oo
o`00R`3oool00`000?l0oooo0?ooo`080?ooo`80o`0000<0003o0?ooo`3o
ool02P3oool20000o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool02`3oool0103o0000003o0000o`000?l;0?ooo`030000o`3o0000o`00
00T0oooo00<0003o0?ooo`3oool0KP3oool00`000000oooo0?ooo`1R0?oo
o`80003o1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0o`00
00h0oooo00<0003o0?ooo`3o00003`3o000F0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0803oool008`0
oooo00<0003o0?ooo`3oool0203oool00`000?l0o`000?l0000<0?ooo`03
0?l000000?l0003o00D0003o1P3oool00`000?l0oooo0?ooo`040?ooo`L0
003o00<0o`000?ooo`3oool0303oool00`3o0000003o0?ooo`080?ooo`03
0000o`3oool0oooo06l0oooo00<000000?ooo`3oool0H`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0o`000000o`3o
ool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo01D0
oooo00<0003o0?ooo`3oool00P3oool20000oaX0oooo00<0o`000?ooo`3o
ool0303oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo0240
oooo002=0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0
0P3o000:0?ooo`030?l0003oool0oooo00D0oooo3@000?l70?ooo`030?l0
003oool0oooo00X0oooo0P3o00000`3oool0003o0?ooo`070?ooo`030000
o`3oool0oooo0700oooo00<000000?ooo`3oool0I03oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00@0o`000?ooo`000?l0
003o303oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo01D0
oooo00<0003o0?ooo`3oool00P000?lK0?ooo`030?l0003oool0oooo00h0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0R0?ooo`00
SP3oool20000o`H0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`080?ooo`80o`000`3oool00`000?l0oooo
0?ooo`040?ooo`80003oL`3oool00`000000oooo0?ooo`1U0?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`80003o2P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo01H0oooo0P000?lL0?ooo`030?l0003oool0oooo0100oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0S0?ooo`00T03o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo0P3o
00070?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`050?ooo`80o`001P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo07<0oooo00<000000?ooo`3oool0IP3o
ool00`000?l0oooo0?ooo`050?ooo`050?l0003oool0oooo0?ooo`3o0000
1`3oool30000o`L0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo
0?ooo`0D0?ooo`80003o6`3oool20?l001@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0S0?ooo`00T@3oool010000?l0oooo0?oo
o`000?l:0?ooo`80o`001@3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool00P3oool30?l000T0oooo
00@0003o0?ooo`3oool0003oJ@3oool4000000T0oooo00<000000?ooo`3o
ool0I`3oool00`000?l0oooo0?ooo`050?ooo`040?l0003oool0oooo0?l0
00X0oooo0P000?l40?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool04P3oool20000o`80oooo00<0003o0?ooo`3oool05`3oool00`3o
0000oooo0?ooo`0E0?ooo`050?l0003oool0oooo0?ooo`000?l09P3oool0
0980oooo0`000?l<0?ooo`@0o`0000<0oooo0?l0003oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0o`000080o`003@3oool20000
ofX0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1W0?oo
o`030000o`3oool0oooo00H0oooo0P3o000=0?ooo`80003o0P3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0100oooo0P000?l40?oo
o`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool05`3oool00`3o
0000oooo0000o`0W0?ooo`00U03oool20000o`l0oooo103o000;0?ooo`03
0000o`3oool0oooo00T0oooo1@3o000?0?ooo`030000o`3oool0oooo06/0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1X0?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3o00003P3oool30000oa80
oooo00<0o`000?ooo`3oool03@3oool30000o`L0oooo00<0003o0?ooo`3o
ool04`3oool20?l001/0oooo00<0o`000?ooo`3oool09P3oool009H0oooo
0P000?l=0?ooo`040?l0003oool0oooo0?ooo`/0o`0000<0003o0?l0003o
00002@3o00040?ooo`030?l0003oool0oooo00/0oooo0P000?m_0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0J@3oool00`000?l0
oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`3o00003`3oool40000
o`l0oooo00<0o`000?ooo`3oool01`3oool60000o`X0oooo00<0003o0?oo
o`3oool04P3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo
02L0oooo002H0?ooo`80003o2P3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0203oool30000ofl0
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`1Z0?oo
o`050000o`3oool0oooo0?ooo`3o00001@3oool20?l000`0oooo00<0003o
0?ooo`3oool00P3oool70000o`P0oooo00@0o`000?ooo`3oool0oooo1P00
0?l@0?ooo`030000o`3oool0oooo0100oooo0P3o000L0?ooo`030000o`3o
ool0oooo02P0oooo002J0?ooo`80003o203oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool01P3oool2
0000og<0oooo0P00000:0?ooo`030000003oool0oooo06/0oooo00<0003o
0?ooo`3o0000203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00T0oooo20000?l0103o0000003o0000o`000?lG0?ooo`030000o`3o
ool0oooo00d0oooo0P3o000N0?ooo`030000o`3oool0oooo02P0oooo002L
0?ooo`<0003o1@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool00`3oool30000oh40oooo00<00000
0?ooo`3oool0K03oool20?l000T0oooo0P3o00080?ooo`030000o`3oool0
oooo0180oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo01d0oooo00<0003o0?ooo`3oool0:@3oool0
09l0oooo1@000?l00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00h0oooo00<0o`000000o`000?l00P000?me0?ooo`P000001`3oool00`00
0000oooo0?ooo`1]0?ooo`030000o`3oool0oooo00T0oooo0P3o00060?oo
o`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool06@3oool00`00
0?l0oooo0?ooo`090?ooo`80o`007`3oool00`000?l0oooo0?ooo`0Z0?oo
o`00Y03oool0103o0000003o0000o`000?l<0?ooo`030000o`3oool0oooo
00`0oooo0P000?l00`3o0000oooo0?ooo`260?ooo`<00000KP3oool00`00
0?l0oooo0?ooo`0:0?ooo`80o`000`3oool00`000?l0oooo0?ooo`0C0?oo
o`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool01`3oool20?l0
01l0oooo0P000?l]0?ooo`00Z03oool70000o`D0oooo00<0003o0?ooo`3o
ool01P3oool60000oh/0oooo00<000000?ooo`3oool0K`3oool20000o``0
oooo0`3o00000`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo01X0
oooo00<0003o0?ooo`3oool0103oool20?l00200oooo00<0003o0?ooo`3o
ool0;@3oool00:l0oooo3P000?nA0?ooo`030000003oool0oooo0740oooo
00<0003o0?ooo`3oool02`3oool00`000?l0o`000?l0000D0?ooo`030?l0
003oool0oooo01X0oooo00<0003o0?ooo`3oool00P3oool20?l00200oooo
0P000?l`0?ooo`00]03oool00`000000oooo0?ooo`2G0?ooo`030000003o
ool0oooo0780oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?oo
o`030?l00140oooo00<0o`000?ooo`3oool06`3oool010000?l0oooo0?l0
003o000Q0?ooo`030000o`3oool0oooo0300oooo002d0?ooo`030000003o
ool0oooo08X0oooo1@0000080?ooo`030000003oool0oooo07<0oooo00<0
003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`040?ooo`80o`003`3o
ool00`3o0000oooo0?ooo`0H0?ooo`<0o`0000<0003o0?l0003oool0803o
ool20000oc<0oooo002d0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`1d0?ooo`80003o203oool0
0`000?l0oooo0?ooo`060?ooo`@0o`002`3oool00`3o0000oooo0?ooo`0D
0?ooo`@0o`00103oool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0
oooo03<0oooo002d0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`1f0?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool02`3oool50?l000H0oooo00<0o`000?oo
o`3oool04@3oool30?l000P0oooo00<0003o0?ooo`3oool07@3oool00`00
0?l0oooo0?ooo`0d0?ooo`00]03oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0M`3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo0100oooo1@3o00000`3oool0
o`000?ooo`0<0?ooo`H0o`002`3oool00`000?l0oooo0?ooo`0K0?ooo`80
003o=`3oool00;@0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo07P0oooo0P000?l30?ooo`030000
o`3oool0oooo01D0oooo3`3o000B0?ooo`030000o`3oool0oooo01T0oooo
00<0003o0?ooo`3oool0=`3oool00;@0oooo00<000000?ooo`3oool0R`3o
ool2000000X0oooo00<000000?ooo`3oool0NP3oool30000oaP0oooo00<0
o`000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0G0?ooo`80003o>P3o
ool00;@0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`1l
0?ooo`80003o5`3oool00`3o0000oooo0?ooo`0N0?ooo`030000o`3oool0
oooo01H0oooo00<0003o0?ooo`3oool0>P3oool00;@0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`1n0?ooo`80003o5@3oool00`3o
0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo01@0oooo0P000?lm0?oo
o`00]03oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo0800
oooo0P000?lC0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3o
ool04@3oool20000ocl0oooo002d0?ooo`030000003oool0oooo09L0oooo
00<000000?ooo`3oool0PP3oool20000oa40oooo00<0o`000?ooo`3oool0
7`3oool00`000?l0oooo0?ooo`0?0?ooo`80003o@@3oool00;@0oooo00<0
00000?ooo`3oool0U`3oool00`000000oooo0?ooo`240?ooo`<0003o3P3o
ool00`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo00d0oooo0P00
0?m30?ooo`00]03oool00`000000oooo0?ooo`2G0?ooo`030000003oool0
oooo08L0oooo0`000?l;0?ooo`030?l0003oool0oooo01l0oooo00<0003o
0?ooo`3oool02`3oool20000odD0oooo002d0?ooo`030000003oool0oooo
09L0oooo00<000000?ooo`3oool0RP3oool30000o`P0oooo00<0o`000?oo
o`3oool07`3oool00`000?l0oooo0?ooo`080?ooo`<0003oA`3oool00;@0
oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`2=0?ooo`<0
003o103oool00`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00@0
oooo0`000?m:0?ooo`00]03oool00`000000oooo0?ooo`2G0?ooo`030000
003oool0oooo0900oooo0`000?l00`3oool0o`000?ooo`0R0?ooo`L0003o
C@3oool00;@0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?oo
o`2C0?ooo`040000o`3o0000003o0000oal0oooo0`000?mC0?ooo`00]03o
ool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo09L0oooo1`00
0?l@0?ooo`P0003oEP3oool00;@0oooo00<000000?ooo`3oool0U`3oool0
0`000000oooo0?ooo`2N0?oooa00003oGP3oool00;@0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo002d0?ooo`03
0000003oool0oooo08`0oooo0`0000080?ooo`030000003oool0oooo0?l0
oooo3@3oool00;@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0?l0oooo3@3oool00;@0oooo00<0
00000?ooo`3oool0RP3oool5000000P0oooo00<000000?ooo`3oool0o`3o
ool=0?ooo`00ZP3oool3000000L0oooo00<000000?ooo`3oool0RP3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0oooo3@3o
ool00:/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0o`3oool=
0?ooo`00Z03oool5000000L0oooo00<000000?ooo`3oool0S03oool20000
00T0oooo00<000000?ooo`3oool0o`3oool=0?ooo`00Z03oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo09L0oooo00<000000?oo
o`3oool0o`3oool=0?ooo`00Z@3oool00`000000oooo000000080?ooo`03
0000003oool0oooo08P0oooo200000070?ooo`030000003oool0oooo0?l0
oooo3@3oool00:X0oooo0P0000080?ooo`030000003oool0oooo09L0oooo
0`00003o0?ooo`d0oooo002d0?ooo`030000003oool0oooo0?l0ooooY`3o
ool00:D0oooo100000000`3oool0000000000002000000H0oooo00<00000
0?ooo`3oool0o`3ooonW0?ooo`00]03oool200000?l0ooooZ03oool00?l0
oooo@`3oool200000?l0oooo6P3oool00?l0oooo@P3oool010000000oooo
0?ooo`00003o0?oooaT0oooo003o0?oood@0oooo00<000000?ooo`3oool0
o`3ooolH0?ooo`00Z@3oool2000009T0oooo00<000000?ooo`3oool0o`3o
oolG0?ooo`00Z03oool010000000oooo0?ooo`00002E0?ooo`040000003o
ool0oooo00000?l0oooo6@3oool00:X0oooo00<000000?ooo`3oool0U@3o
ool200000?l0oooo6P3oool00:/0oooo00<000000?ooo`3oool0o`3ooon`
0?ooo`00Z03oool010000000oooo0?ooo`0000060?ooo`800000VP3oool2
00000?l0oooo3P3oool00:T0oooo0P0000080?ooo`030000003oool0oooo
09P0oooo0P00003o0?ooo`h0oooo002d0?ooo`030000003oool0oooo09H0
oooo00@000000?ooo`3oool00000o`3oool=0?ooo`00/`3oool00`000000
oooo0000002F0?ooo`8000000P3oool200000?l0oooo303oool00;80oooo
00@000000?ooo`3oool00000o`3ooonX0?ooo`00/@3oool3000000030?oo
o`00000000000?l0ooooY`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo
0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00
\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{605, 250},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Theorem 4.12 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Geometric Series",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/GeometricSeries.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  " If  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ",  the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity] z\^n\)]],
  "  converges to  ",
  Cell[BoxData[
      \(f \((z)\) = 1\/\(1\  - \ z\)\)]],
  ".  That is, if  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  "  then  \n\n",
  StyleBox["(4-11)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity] z\^n\  = \ \(\(1 + z + 
                  z\^2 +  ... \) + z\^k +  ... \  = \ 1\/\(1\  - \ z\)\)\)]],
  ".  \n\nIf  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(\[GreaterEqual]\)\(1\)\)\)\)]],
  ",  the series diverges.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.12 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot the images of the disk   ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(\[LessEqual]\)\(6\/10\)\)\)\)]],
  "  under the mappings  ",
  Cell[BoxData[
      \(\(S\_n\) \((z)\) = \[Sum]\+\(k = 0\)\%n z\^k\)]],
  ".  \n\nHence we can view how the complex geometric series converges to its \
limit function ",
  Cell[BoxData[
      \(f \((z)\) = 1\/\(1\  - \ z\)\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[g, k, m, n, s];\)\ \), "\[IndentingNewLine]", 
    \(\(s[z_, n_] = \[Sum]\+\(k = 0\)\%n z\^k;\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = 1\/\(1\  - \ z\);\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(For\ [m = 2, 
        m \[LessEqual] 10, \(m++\), \[IndentingNewLine]g[z_] = 
          s[z, m]; \ \[IndentingNewLine]PolarMap[
          g\ , {0, 0.6, 0.075}, {0, 
            2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0.4, 
                2.6}, {\(-1.0\), 1.0}}, 
          AspectRatio \[Rule] 
            2.0\/2.2, \[IndentingNewLine]Ticks \[Rule] {Range[0, 3, 1], 
              Range[\(-\(3\/2\)\), 3\/2, 1\/2]}, 
          AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Red, Blue}, 
          AxesOrigin \[Rule] {0.4, 
              0}]; \ \[IndentingNewLine]Print["\<w = \>", "\<S\>"\_m, "\<(z) \
= \>", Apart[s[z, m]]\ ];\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        f, {0, 0.6, 0.075}, {0, 
          2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0.4, 
              2.6}, {\(-1.0\), 1.0}}, 
        AspectRatio \[Rule] 
          2.0\/2.2, \[IndentingNewLine]Ticks \[Rule] {Range[1, 3, 1], 
            Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}, 
        AxesOrigin \[Rule] {0.4, 0}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The limit function is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = f(z) = \>", f[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Corollary 4.2. ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  " If  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(1\)\)\)\)]],
  ",  the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity] z\^\(-n\)\)]],
  " ",
  " converges to ",
  " ",
  Cell[BoxData[
      \(f \((z)\) = 1\/\(z - \ 1\)\)]],
  ".  That is, if ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(1\)\)\)\)]],
  " then  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \ \ \ \)\(\[Sum]\+\(n = 1\)\%\[Infinity] z\^\(-n\)\ \  = \ \ \ \
\(\(z\^\(-1\) + z\^\(-2\) +  ... \) + z\^\(-4\) +  ... \  = \ 
          1\/\(z - \ 1\)\)\)\)\)]],
  ",  \nor equivalently,\n\t\t\t",
  Cell[BoxData[
      \(\(-\ \(\[Sum]\+\(n = 1\)\%\[Infinity] z\^\(-n\)\)\)\  = \ \(\(\(-\ 
                    z\^\(-1\)\) - z\^\(-2\) -  ... \) - 
              z\^\(-4\) -  ... \  = \ 1\/\(1 - z\)\)\)]],
  ".  \n\nIf  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(\[LessEqual]\)\(1\)\)\)\)]],
  ",  t",
  "he series diverges. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 4.2 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009V0000nR000`400?l0
0000o`00003oo`3ooooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0
oooo2@3oool300000480oooo0`00002h0?ooo`@000001`3oool5000004h0
oooo003o0?ooo`T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`2i0?ooo`040000003oool000000?ooo`@00000103oool00`000000
oooo0?ooo`1>0?ooo`00o`3oool:0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0;L0oooo00<000000?ooo`0000002P3oool00`000000oooo
0?ooo`1>0?ooo`00o`3oool:0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0;L0oooo100000090?ooo`030000003oool0oooo04h0oooo001L
0?ooo`@0003oZ03oool00`000000oooo0000000E0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0000001:
0?ooo`<00000103oool3000000h0oooo0`00001P0?ooo`030000003oool0
oooo0240oooo0P0000020?ooo`030000003oool0000000P000007P3oool0
05/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`2V0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo
0?ooo`000000:P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo02L0oooo0P00000J0?ooo`P000000P3oool010000000oooo0?ooo`00
00070?ooo`030000003oool0oooo01h0oooo001K0?ooo`H0003o_`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`050000003oool0
oooo0?ooo`000000:@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0000000<000000P3oool00`000000oooo
0?ooo`0N0?ooo`00D03oool40000o`<0oooo2@000?l30?ooo`T0003o0P3o
ool30000o`P0oooo0P000?l0103oool0003o0000o`3oool60000o`X0oooo
0`0000030?ooo`<0000000@0oooo000000000000oooo0P0000060?ooo`L0
000000<0oooo0000000000000`0000000`3oool00000000000020?ooo`L0
00000P3oool7000000H0oooo0`0000020?ooo`<000001@3oool200000005
0?ooo`00000000000000003oool00P0000000`3oool00000000000060?oo
o`/000000P3oool3000000030?ooo`000000000001H0oooo1@0000070?oo
o`030000003oool0oooo00D0oooo1@0000070?ooo`030000003oool0oooo
00P0oooo1@00000J0?ooo`L0000000@0oooo000000000000oooo1@000000
0`3oool00000000000020?ooo`<000001@3oool2000000050?ooo`000000
00000000003oool00P0000000`3oool00000000000050?ooo`<0000000@0
oooo000000000000oooo0P0000000`3oool0000000000002000000030?oo
o`000000oooo008000000`3oool010000000oooo0000000000020?ooo`H0
000000@0oooo000000000000oooo0`0000090?ooo`030000003oool00000
0140oooo1@0000070?ooo`030000003oool0oooo0080oooo1@0000040?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0103oool40000
00P0oooo00<000000?ooo`3oool00`3oool5000000h0oooo00<000000?oo
o`3oool01@3oool00540oooo0P000?l50?ooo`80003o00<0oooo0000o`3o
ool01@3oool20000o`030?ooo`000?l0003o0080oooo0P000?l20?ooo`80
003o0P3oool00`000?l0oooo0?ooo`050?ooo`80003o00<0oooo0000o`00
0?l00P3oool20000o`80oooo0P000?l:0?ooo`030000003oool0oooo00<0
oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`00
00020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000
oooo000000020?ooo`040000003oool0oooo000000H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool00P0000020?ooo`030000003o
ool0oooo008000000P3oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000002`3oool01@000000oooo0000003oool0
000000D0oooo1@0000070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0203oool5000002L0oooo1@00000;0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000001H0oooo001A0?ooo`80003o1@3oool20000o`80oooo0`00
0?l30?ooo`80003o00<0oooo0000o`000?l00P3oool20000o`80oooo0P00
0?l70?ooo`H0003o103oool20000o`80oooo0P000?l:0?ooo`030000003o
ool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000070?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`3oool20000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo0?ooo`8000000P3oool00`000000oooo0000000:0?ooo`P0
0000203oool2000000P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo0P0000080?ooo`P0
00002P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo000000050?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0000000P0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo000000020?ooo`040000003oool0oooo000000<0oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo0P0000090?ooo`050000003oool000000?ooo`00
00004@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?oooa@0
00006P3oool00`000000oooo0?ooo`0=0?ooo`8000001P3oool00`000000
oooo0?ooo`0G0?ooo`00D@3oool20000o`030?ooo`000?l0oooo0080oooo
0P000?l0103oool0003o0000o`3oool20000o`80oooo0P000?l00`3oool0
003o0000o`020?ooo`80003o0P3oool50000o`@0oooo00<0003o0?ooo`3o
ool00P000?l50?ooo`80003o0P3oool20000o`X0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`000000oooo00@000001@3oool30000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0000000000060?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo00000003000000@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool00000000000@0
oooo0P00000I0?ooo`8000002P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool2000001`0
oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`0000000`0000020?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0000000<000001@3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`060?ooo`050000003oool000000?ooo`0000001@3oool5000000L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool5000002L0oooo
1@00000=0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
5P3oool00540oooo10000?l30?ooo`80003o00@0oooo0000o`000?l0oooo
0P000?l20?ooo`80003o00<0oooo0000o`000?l00P3oool20000o`050?oo
o`000?l0003o0000o`3oool00P000?l50?ooo`040000o`3oool0003o0000
o`D0oooo1@000?l;0?ooo`030000003oool0oooo00<0oooo0P000000103o
ool000000?ooo`0000020?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool2000000040?ooo`000000oooo0?ooo`800000
00D0oooo0000003oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P000000103oool0
00000?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P0000020?ooo`030000003oool000000080oooo00H000000?oo
o`3oool000000?ooo`00000J0?ooo`800000203oool00`000000oooo0?oo
o`050?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0
2P3oool2000001X0oooo00@000000?ooo`3oool000000P3oool200000004
0?ooo`000000oooo00000080oooo0P0000001@3oool000000?ooo`3oool0
00000080oooo0P0000050?ooo`040000003oool0oooo0?ooo`80000000@0
oooo0000003oool000000P3oool00`000000oooo0?ooo`030?ooo`800000
00L0oooo000000000000oooo0000003oool000000080oooo00<000000?oo
o`3oool00P0000020?ooo`030000003oool0oooo008000000P3oool01000
0000oooo0?ooo`0000020?ooo`80000000@0oooo0000003oool000000P3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
4@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo01@0oooo00@000000?ooo`3oool000005`3oool00540
oooo0P000?l0103oool0003o0?ooo`3oool30000o`80oooo20000?l0103o
ool0003o0000o`3oool50000o`040?ooo`000?l0003o0000o`H0oooo00@0
003o0?ooo`000?l0003o1@3oool20000o`80oooo0P000?l:0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000000`3oool2000000H0oooo
0P0000020?ooo`80000000@0oooo0000003oool0oooo0P000000103oool0
00000?ooo`3oool2000000030?ooo`00000000000080oooo00D000000?oo
o`00000000000?ooo`0200000080oooo0`0000050?ooo`<000000P3oool3
000000@0oooo0`0000020?ooo`030000003oool0000000<0oooo0P000006
0?ooo`80000000<0oooo0000003oool00P0000020?ooo`<000000P3oool0
10000000oooo00000000000;0?ooo`8000003P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo1@0000070?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0;0?ooo`80000000@0oooo000000000000oooo0P0000000`3oool00000
0?ooo`020?ooo`80000000@0oooo0000003oool0oooo0P0000020?ooo`80
000000<0oooo0000003oool00P3oool300000080oooo00<000000?ooo`00
00000`3oool2000000D0oooo0P0000001@3oool000000?ooo`3oool00000
00<0oooo0P0000020?ooo`80000000<0oooo0000000000000P3oool20000
00030?ooo`00000000000080oooo0P0000001@3oool000000000003oool0
000000<0oooo100000060?ooo`<0000000@0oooo00000000000000003`3o
ool5000000L0oooo00<000000?ooo`3oool00P3oool5000000@0oooo00<0
00000?ooo`3oool07P3oool500000240oooo00<000000?ooo`3oool05@3o
ool5000000H0oooo0P0000020?ooo`030000003oool0oooo00T0oooo001A
0?ooo`80003o9@3oool30000o`D0oooo0P000?l20?ooo`80003o2P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`000000403oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000
D`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P0000000`3oool00000
0?ooo`0C0?ooo`@0000000D0oooo0000003oool0oooo0000000;0?ooo`00
D@3oool20000o`<0oooo00@0003o0?ooo`000?l0003o7`3oool20000o`D0
oooo0P000?l20?ooo`80003o1`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000002@0oooo00<000000?ooo`3oool0503oool0
10000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000
403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000E03oool3000000T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo01l0oooo1`0000001`3oool000000?ooo`3oool00000
0?ooo`000000603oool010000000oooo0?ooo`00000;0?ooo`00D03oool7
0000o`030?ooo`000?l0003o01l0oooo0P000?l40?ooo`H0003o203oool7
000000030?ooo`000000000002<0oooo0P00000G0?ooo`<000001P3oool2
000000l0oooo0P0000020?ooo`030000003oool0oooo00@0oooo0P00000@
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo0P00000A
0?ooo`800000:@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo02P0oooo0P0000000`3oool000000?ooo`0G0?ooo`@00000303oool0
0?l0oooo2@3oool00`000000oooo0000000E0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0000002o0?oo
o`030000003oool0oooo05@0oooo003o0?ooo`X0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0
oooo0`00002n0?ooo`800000EP3oool00?l0ooooo`3ooomX0?ooo`00o`3o
oooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?oo
o`00o`3ooooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3o
oomX0?ooo`00o`3ooooo0?ooofP0oooo002^0?ooo`030000003oool0oooo
0:d0oooo00<000000?ooo`3oool0o`3oool60?ooo`00[P3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo0?l0oooo1P3oool00:h0oooo
00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`3o0?ooo`H0oooo
002Y0?ooo`D0o`0000<0003o0?l0003o00000`3o002Z0?ooo`030000003o
ool0oooo0?l0oooo1P3oool00:00oooo2@3o00050?ooo`030000o`3oool0
oooo00<0oooo2P3o002P0?ooo`030000003oool0oooo0?l0oooo1P3oool0
09X0oooo1P3o000>0?ooo`030000o`3oool0oooo00d0oooo1P3o002J0?oo
o`030000003oool0oooo0300oooo7@000?nh0?ooo`00UP3oool40?l00003
0?ooo`3o0000oooo0140oooo00<0003o0?ooo`3oool0403oool00`3o0000
oooo0?ooo`030?l009L0oooo00<000000?ooo`3oool0;@3oool30000o`l0
oooo00<0003o0?ooo`3oool02`3oool60000ok80oooo002C0?ooo`<0o`00
1P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0100oooo
00<0o`000?ooo`3oool00`3oool40?l009<0oooo00<000000?ooo`3oool0
:@3oool40000oa80oooo00<0003o0?ooo`3oool04@3oool50000ojd0oooo
002?0?ooo`@0o`002@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo0100oooo00<0o`000?ooo`3oool01`3oool50?l008h0oooo00<0
00000?ooo`3oool09@3oool40000oaH0oooo00<0003o0?ooo`3oool05P3o
ool30000ojX0oooo002<0?ooo`<0o`003@3oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0303oool2
0?l008`0oooo00<000000?ooo`3oool0803oool50000oaX0oooo00<0003o
0?ooo`3oool06@3oool30000ojL0oooo002:0?ooo`80o`00403oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool03P3oool20?l008X0oooo00<000000?ooo`3oool07P3oool20000
oal0oooo00<0003o0?ooo`3oool0703oool30000oj@0oooo00280?ooo`03
0?l000000?l0oooo0140oooo00<0o`000?ooo`3oool03`3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo0140oooo00<0003o0?l0003o
ool0Q`3oool00`000000oooo0?ooo`0K0?ooo`<0003o8@3oool00`000?l0
oooo0?ooo`0O0?ooo`80003oXP3oool008D0oooo0`3o00000`3oool0003o
0?ooo`0B0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0080o`00
QP3oool00`000000oooo0?ooo`0H0?ooo`030?l000000?l0003o02@0oooo
00<0003o0?ooo`3oool08@3oool30000oil0oooo00230?ooo`80o`00103o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0080oooo0P3o00240?ooo`030000003oool0oooo01L0oooo00<0
003o0?l0003oool09@3oool00`000?l0oooo0?ooo`0T0?ooo`80003oW@3o
ool00840oooo0P3o00060?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool0103oool20?l00880oooo00<00000
0?ooo`3oool05@3oool20000o`80oooo00<0o`000?ooo`3oool08`3oool0
0`000?l0oooo0?ooo`0V0?ooo`80003oV`3oool007l0oooo0P3o00090?oo
o`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool00P3ooolJ0000
o`@0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`060?oo
o`80o`00P03oool00`000000oooo0?ooo`0C0?ooo`80003o103oool00`3o
0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo02P0oooo0P000?nI0?oo
o`00OP3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00l0
oooo00<0003o0?l000000?l00`000?l50?ooo`040000003oool0oooo0000
00<0oooo00<0003o0?ooo`3oool02`3oool30000o`030?l000000?l0003o
0100oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`1m0?oo
o`030000003oool0oooo0140oooo0P000?l70?ooo`030?l0003oool0oooo
0240oooo00<0003o0?ooo`3oool0:`3oool00`000?l0oooo0?ooo`2F0?oo
o`00O03oool20?l000d0oooo00<0003o0?ooo`3oool02`3oool30000o`03
0?ooo`3o0000oooo00X0oooo00<000000?ooo`3oool00P3oool00`000?l0
00000000000>0?ooo`030?l0003oool0oooo0080003o3P3oool00`000?l0
oooo0?ooo`0:0?ooo`80o`00O@3oool00`000000oooo0?ooo`0?0?ooo`80
003o2@3oool00`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo02`0
oooo0P000?nF0?ooo`00NP3oool20?l000l0oooo00<0003o0?ooo`3oool0
203oool30000o`@0oooo00@0o`000?ooo`3oool0oooo100000050?ooo`05
0000003oool0oooo0?ooo`000?l0403oool00`3o0000oooo0?ooo`020?oo
o`@0003o2@3oool00`000?l0oooo0?ooo`0=0?ooo`80o`00N`3oool00`00
0000oooo0?ooo`0=0?ooo`80003o2`3oool00`3o0000oooo0?ooo`0Q0?oo
o`030000o`3oool0oooo02h0oooo0P000?nD0?ooo`00N@3oool00`3o0000
oooo0?ooo`0@0?ooo`030000o`3oool0oooo00@0oooo0`000?l80?ooo`03
0?l0003oool0oooo00H0oooo00@000000?ooo`3oool000000`3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00H0oooo10000?l50?oo
o`030000o`3oool0oooo00l0oooo0P3o001b0?ooo`D000000P3oool00`00
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0803oool00`000?l0oooo0?ooo`0`0?ooo`80003oTP3oool007L0
oooo0P3o000C0?ooo`040000o`3oool0oooo0?ooo`<0003o2`3oool00`3o
0000oooo0?ooo`070?ooo`800000103oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00X0oooo0`000?l20?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool0L@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo0P000?l?0?ooo`030?l0003oool0oooo
01l0oooo00<0003o0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`2?0?oo
o`00MP3oool00`3o0000oooo0?l0000D0?ooo`<0003o3P3oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool03@3oool20000oa<0oooo00@0o`000?ooo`3o0000o`00L@3oool00`00
0000oooo0?ooo`020?ooo`<000002@3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool0=03oool20000
ohl0oooo001e0?ooo`050?l0003oool0oooo0?ooo`3o00004@3oool30000
oa00oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00h0oooo10000?l@0?ooo`050?l0003oool0oooo
0?ooo`3o0000J03oool4000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`070?ooo`80003o4P3oool00`3o0000oooo0?ooo`0O
0?ooo`030000o`3oool0oooo03H0oooo00<0003o0?ooo`3oool0S03oool0
07<0oooo0P3o00040?ooo`030?l0003oool0oooo00d0oooo0P000?l20?oo
o`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool00P3oool20000o`d0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`1]0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool20000oaD0oooo00<0o`000?ooo`3oool07P3oool00`00
0?l0oooo0?ooo`0g0?ooo`030000o`3oool0oooo08/0oooo001b0?ooo`03
0?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool02P3oool20000o`D0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`040?ooo`80003o2`3oool00`3o0000oooo0?ooo`040?ooo`80
o`00K03oool2000000@0oooo00<000000?ooo`3oool0103oool00`000?l0
oooo0?ooo`0E0?ooo`030?l0003oool0oooo01h0oooo00<0003o0?ooo`3o
ool0>03oool20000oh/0oooo001a0?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool0203oool20000o`L0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`070?ooo`80003o
203oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo06l0oooo
00<000000?ooo`3oool00P3oool20000oaP0oooo00<0o`000?ooo`3oool0
7P3oool00`000?l0oooo0?ooo`0j0?ooo`030?l0003oool0oooo08P0oooo
001`0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool01@3o
ool20000o`X0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`040?ooo`P0o`0000<0003o0?l0003o00001`3o00060?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0KP3o
ool010000000oooo0?ooo`3oool20000oaT0oooo00<0o`000?ooo`3oool0
7@3oool00`000?l0oooo0?ooo`0j0?ooo`040?l0003oool0003o0000ohP0
oooo001^0?ooo`80o`00303oool00`3o0000oooo0?ooo`020?ooo`80003o
303oool00`000?l0oooo0?ooo`0=0?ooo`L0o`00203oool00`000?l0oooo
0?ooo`070?ooo`P0o`003@3oool00`000?l0oooo0?ooo`0;0?ooo`80003o
103oool00`3o0000oooo0?ooo`0:0?ooo`80o`00KP3oool010000000oooo
0?ooo`000?l20?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3o
ool0703oool00`000?l0oooo0?ooo`0i0?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool0Q@3oool006d0oooo00<0o`000?ooo`3oool0
3@3oool0103o0000oooo0000o`000?l?0?ooo`030000o`3oool0oooo00T0
oooo0`3o00000`3oool0o`000?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0103o00090?ooo`030000o`3oool0oooo00d0
oooo0P000?l00`3oool0o`000?ooo`0>0?ooo`030?l0003oool0oooo06/0
oooo00<000000?ooo`000?l00`3oool00`000?l0oooo0?ooo`0G0?ooo`03
0?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool0>03oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo08@0oooo001/0?ooo`030?l0
003oool0oooo00h0oooo00<0o`000000o`3oool0403oool00`000?l0oooo
0?ooo`050?ooo`@0o`00103oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0103oool20?l000H0oooo
00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0?0?ooo`030?l0
003oool0oooo06X0oooo00<000000000o`3oool0103oool00`000?l0oooo
0?ooo`0F0?ooo`030?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool0
>03oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo08<0oooo
001[0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o00004P3o
ool00`000?l0oooo0?ooo`040?l000P0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00H0oooo0`3o
00030?ooo`030000o`3oool0oooo0100oooo00<0o`000000o`3oool0403o
ool00`3o0000oooo0?ooo`1Y0?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3o
ool0oooo03L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`220?ooo`00JP3oool00`3o0000oooo0?ooo`0>0?ooo`040000o`3oool0
oooo0?l00180oooo00<0003o0?l0003o0000303oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02@3o
ool20?l000030?ooo`000?l0oooo0100oooo00<0o`000?ooo`3oool00P00
0?l@0?ooo`030?l0003oool0oooo06L0oooo00<0003o0000003oool01`3o
ool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo01/0oooo00<0
003o0?ooo`3oool0=`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo0840oooo001Y0?ooo`030000o`3oool0oooo00h0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0>0?ooo`80o`0000<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0o`000?ooo`0@
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`1U0?ooo`030000o`3oool0000000P0oooo00<0003o
0?ooo`3oool0503oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0
oooo03H0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`20
0?ooo`00J03oool00`3o0000003o0?ooo`0>0?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool02`3oool20?l00080oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0303oool010000?l0oooo0?l0003o000>
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0303oool0
0`000?l0o`000?ooo`1U0?ooo`040000o`3oool0oooo000000T0oooo00<0
003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3o
ool0oooo03D0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`1o0?ooo`00I`3oool0103o0000oooo0?ooo`000?l<0?ooo`80003o203o
ool00`3o0000oooo0?ooo`080?ooo`80o`00103oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo0P3o
000;0?ooo`030?l0003oool0oooo00H0oooo0P000?l<0?ooo`030000o`3o
ool0o`0006@0oooo00D0003o0?ooo`3oool0oooo000000090?ooo`030000
o`3oool0oooo01@0oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo
0?ooo`0d0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
OP3oool006L0oooo00D0o`000?ooo`3oool0oooo0000o`0:0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool20?l000L0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`040?ooo`80o`00203oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00P0oooo00D0003o0?ooo`3oool0oooo0?l0001R0?ooo`03
0000o`3oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000?l0
oooo0?ooo`0C0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3o
ool0=03oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo07d0
oooo001V0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00L0oooo0P3o00060?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo05h0oooo00<0003o0?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`030000o`3oool0oooo01<0oooo
00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0d0?ooo`030?l0
003oool0oooo0180oooo00<0003o0?ooo`3oool0O03oool006D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool20?l000X0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`050?ooo`/0003o1P3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00T0oooo0P3o
00030?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool00`3o
ool20000o`L0oooo00<0o`000?ooo`3oool0G03oool00`000?l0oooo0?oo
o`040?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool04P3o
ool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo03<0oooo00<0
o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`1k0?ooo`00I03oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool03@3oool0103o0000oooo0?ooo`3o000<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000000o`000?l01@000?l40?ooo`030000o`3o
ool0oooo00@0oooo1@000?l00`3oool0o`000?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo0P3o00000`3oool0o`000?ooo`0>0?ooo`050000o`3o
ool0oooo0?ooo`000?l02P3oool00`3o0000oooo0?ooo`1J0?ooo`030?l0
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0B0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool0
<P3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo07X0oooo
001S0?ooo`030?l0003oool0oooo00T0oooo00@0003o0?ooo`3oool0003o
4@3oool20?l000h0oooo00<0003o0?ooo`3oool0203oool30000o`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`000?l0o`00
0000o`030000o`T0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0?0?ooo`040000o`3oool0oooo0000o`/0oooo00<0o`000?ooo`3o
ool0F@3oool00`000?l0o`000?ooo`050?ooo`030000003oool0oooo00X0
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0H0?ooo`03
0000o`3oool0oooo0380oooo00<0o`000?ooo`3oool05`3oool00`000?l0
oooo0?ooo`1j0?ooo`00HP3oool00`3o0000oooo0?ooo`0;0?ooo`80003o
4@3oool00`3o0000oooo0?l0000>0?ooo`030000o`3oool0oooo00D0oooo
0`000?l30?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`020?ooo`80003o1P3oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0o`000140oooo0P000?l=0?ooo`030?l0
003oool0oooo05L0oooo00@0003o0?ooo`3oool0o`001@3oool00`000000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool0603oool00`000?l0oooo0?ooo`0a0?ooo`030?l0003oool0oooo01T0
oooo00<0003o0?ooo`3oool0N@3oool00640oooo00<0o`000?ooo`3oool0
303oool20000oa00oooo00@0o`000?ooo`3oool0o`003`3oool00`000?l0
oooo0?ooo`040000o`H0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00D0oooo0`000?l30?ooo`03
0000o`3oool0oooo00`0oooo00@0o`000?ooo`3oool0oooo0P3o000?0?oo
o`80003o3@3oool00`3o0000oooo0?ooo`1F0?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool05`3oool00`00
0?l0oooo0?ooo`0a0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?oo
o`3oool0N03oool00600oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`020000o``0oooo0P3o00040?ooo`030?l0003oool0oooo00`0
oooo0`000?l;0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`080?ooo`<0003o3`3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00X0oooo0P000?l20?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0E03oool00`000?l0
oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`0000003@3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?oo
o`3oool0<03oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo
07L0oooo001O0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool02@3oool40000o``0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0
oooo0`000?l<0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0DP3oool00`000?l0oooo0?ooo`050?ooo`05
0?l0003oool0oooo0?ooo`0000003@3oool00`000?l0oooo0?ooo`070?oo
oa00o`004P3oool00`000?l0oooo0?ooo`0`0?ooo`030?l0003oool0oooo
01l0oooo00<0003o0?ooo`3oool0MP3oool005l0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`80
003o0`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo0080003o2@3oool00`3o0000oooo0?ooo`070?ooo`80
o`00203oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0D@3oool00`000?l0oooo0?ooo`060?ooo`04
0?l0003oool0oooo000000d0oooo00<0003o0?ooo`3oool00P3oool50?l0
00T0oooo00<0o`000?ooo`3oool0103oool60?l000`0oooo00<0003o0?oo
o`3oool0;`3oool00`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo
07D0oooo001N0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`040?ooo`80o`002P3oool00`3o0000
oooo0?ooo`040?ooo`80003o1P3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo0P000?l60?ooo`03
0?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0C`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0000000h0
oooo00@0003o0?l0003o0000o`003P3oool00`3o0000oooo0?ooo`0:0?oo
o`<0o`002@3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo
0280oooo00<0003o0?ooo`3oool0M@3oool005d0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`050?ooo`80003o0`3oool00`3o0000
oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo04h0
oooo00<0003o0?ooo`3oool02P3oool00`3o000000000?ooo`0:0?ooo`<0
o`0000<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0=0?ooo`80
o`001P3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo02@0
oooo00<0003o0?ooo`3oool0M03oool005`0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0:0?ooo`80003o00<0oooo0?l0003oool0
3P3oool0103o0000oooo0000o`000?l90?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool20000o`03
0?ooo`3o0000oooo00h0oooo00@0o`000?ooo`000?l0003o303oool00`00
0?l0oooo0?ooo`0:0?ooo`80o`00CP3oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00H0oooo0`3o00030?ooo`030000o`3oool0oooo
00l0oooo00<0o`000?ooo`3oool03`3oool30?l000<0oooo00<0003o0?oo
o`3oool0;@3oool00`3o0000oooo0?ooo`0V0?ooo`030000o`3oool0oooo
07<0oooo001K0?ooo`040?l0003oool0o`000?l000/0oooo00<0003o0?oo
o`3oool02`3oool00`000?l0o`000?ooo`0?0?ooo`030?l000000?l0oooo
00/0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?oo
o`3oool0303oool00`000?l0oooo0?ooo`090?ooo`<0o`00C@3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00@0oooo0P3o00070?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool04P3oool20?l0
00030?ooo`000?l0oooo02d0oooo00<0o`000?ooo`3oool0:03oool00`00
0?l0oooo0?ooo`1b0?ooo`00F`3oool01@3o0000oooo0?ooo`3oool0o`00
00T0oooo00<0003o0?ooo`3oool0303oool00`3o0000003o0?ooo`0>0?oo
o`030000o`3oool0o`0000`0oooo00<0003o0?ooo`3oool02@3oool:0?l0
00030000o`3o0000o`0000L0o`0000<0oooo0?l0003oool02@3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l000000?l0003o00l0oooo00<0003o0?l0
003oool03@3oool00`000?l0oooo0?ooo`070?ooo`050?l0003oool0oooo
0?ooo`3o0000B`3oool00`000?l0oooo0?ooo`0=0?ooo`030000003o0000
oooo0080oooo0P3o00090?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool05@3oool00`000?l0o`000?ooo`0/0?ooo`030?l0003oool0
oooo02T0oooo00<0003o0?ooo`3oool0LP3oool005X0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00`0oooo00@0o`000?ooo`3oool0003o3@3oool010000?l0oooo0?ooo`3o
000=0?ooo`030000o`3oool0oooo00H0oooo0`3o00090?ooo`030000o`3o
ool0oooo00L0oooo1P3o00060?ooo`030000o`3oool0oooo00X0oooo00D0
o`000?ooo`3oool0oooo0000o`0=0?ooo`040000o`3oool0oooo0?l000h0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo04P0oooo00@0003o0?ooo`000?l0003o3@3oool00`00
0000oooo0?l000020?l000/0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0E0?ooo`040000o`3oool0o`000?l002X0oooo00<0o`00
0?ooo`3oool0:`3oool00`000?l0oooo0?ooo`1a0?ooo`00FP3oool00`3o
0000oooo0?ooo`040?ooo`80o`001@3oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool00`3oool30?l00080oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0080oooo0`3o00020?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`020?ooo`80o`001P3oool00`3o
0000oooo0?ooo`170?ooo`040000o`3oool0oooo0?ooo`80003o2`3oool0
10000000oooo0?l0003o000=0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`020?ooo`80o`009`3o
ool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo0740oooo001I
0?ooo`030?l0003oool0oooo00L0oooo0P3o00020?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0103oool20000o`L0oooo0P000?l6
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o00000P3o0005
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`050?ooo`80o`0000<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`040?ooo`80003o1`3oool20000o`H0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`020?l000P0oooo00<0o`00
0?ooo`3oool0AP3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo00P0oooo0P3o00000`3oool0o`000?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`04
0?ooo`80o`00903oool00`3o0000oooo0?ooo`0^0?ooo`030000o`3oool0
oooo0700oooo001I0?ooo`030?l0003oool0oooo00T0oooo00<0o`000000
o`3oool0303oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`80o`0000<0003o0?l0003oool0203oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0o`000?l0000:0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?l0003oool02P3oool00`3o0000oooo0?ooo`140?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
000000000?ooo`020?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo
00L0oooo0P3o000Q0?ooo`030?l0003oool0oooo02l0oooo00<0003o0?oo
o`3oool0L03oool005P0oooo00<0o`000?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00D0
oooo0P3o00030?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool00P3o00070?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00/0oooo00<0o`000000o`3oool02`3oool00`3o0000
oooo0?ooo`130?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool00`3oool20?l000030?ooo`000000oooo0080oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo01<0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0L0?ooo`80
o`00<`3oool00`000?l0oooo0?ooo`1_0?ooo`00F03oool00`3o0000oooo
0?ooo`0:0?ooo`040000o`3oool0o`000?l000T0oooo00<0o`000?ooo`3o
ool02P3oool010000?l0oooo0?ooo`000?l<0?ooo`030?l0003oool0oooo
0080oooo0P3o00050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool00`3oool20?l000D0oooo00<0o`000?oo
o`3oool02P3oool010000?l0oooo0?ooo`000?l;0?ooo`030?l0003oool0
oooo00P0oooo0P3o00020?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool0@P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo000000040?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0B0?ooo`030000o`3oool0oooo00/0oooo0P3o000K0?ooo`030?l0003o
ool0oooo03@0oooo00<0003o0?ooo`3oool0KP3oool005L0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`020?ooo`80o`001`3oool0
0`3o0000oooo0?ooo`0;0?ooo`80003o3@3oool01@3o0000oooo0?ooo`3o
ool0o`0000P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`050?l0003oool0oooo0?ooo`3o0000
3P3oool20000o`d0oooo00<0o`000?ooo`3oool01@3oool20?l000@0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`100?ooo`030000
o`3oool0oooo00X0oooo00@0003o0?ooo`3o0000o`00103oool00`000000
oooo0?ooo`020?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0e0?ooo`03
0000o`3oool0oooo06h0oooo001G0?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo00`0oooo0`000?l=0?ooo`<0o`002@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo
0P3o00000`3oool0o`000?ooo`0<0?ooo`<0003o3P3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`100?ooo`030?l0003oool0oooo00/0oooo
0P000?l50?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo0180oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0
003oool0oooo03L0oooo00<0003o0?ooo`3oool0K@3oool005H0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`050?l0003o
ool0oooo0?ooo`3o00003P3oool010000?l0oooo0?ooo`000?l=0?ooo`80
o`002P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02`3oool01@000?l0
oooo0?ooo`3oool0003o00d0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool0?P3oool010000?l0oooo0?l0003o000:0?ooo`030?l0003oool0
003o00D0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`80o`00503oool00`3o0000oooo0?ooo`0h
0?ooo`030000o`3oool0oooo06d0oooo001F0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool01`3oool30?l000h0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`80o`000P3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01`3oool0103o0000oooo0?l0003o000;
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool0
103o0000oooo0?l0003o000:0?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool0?P3oool01@000?l0oooo0?ooo`3oool0o`0000P0oooo
00D0o`000?ooo`3oool0oooo0000o`040?ooo`030000003oool0oooo00<0
oooo00<0o`000?ooo`3oool00`3ooolA0000o`80oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo0100
oooo00<0o`000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`1/0?ooo`00
EP3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo
0P3o000<0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000003o0000o`0=0000o`030?oo
o`3o0000oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0:0?ooo`80o`00303oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo03`0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00D0003o0?ooo`3oool0oooo000000050?ooo`030?l0003oool0oooo00<0
003o1@3oool00`000?l0oooo0?ooo`090?ooo`040000o`3o0000003o0000
oa40oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0=0?oo
o`80o`00?@3oool00`000?l0oooo0?ooo`1/0?ooo`00E@3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00@0o`000?ooo`3o
ool0o`002P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
00<0oooo0P3o00060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool00P3oool40000o`030?l0003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000?l0o`000000o`020000o`D0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`030?ooo`80o`001P3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00@0o`000?oo
o`3oool0o`00303oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo03`0oooo00<0003o0?ooo`3oool0103oool20?l000<0oooo00<0o`00
0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0000000<0oooo0`00
0?l00`3o0000003o0?ooo`070?ooo`80003o2`3oool00`3o0000oooo0?oo
o`030000o`h0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?oo
o`0;0?ooo`030?l0003oool0oooo03h0oooo00<0003o0?ooo`3oool0J`3o
ool005D0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`070?ooo`80003o0P3oool00`3o0000oooo0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`000?l00P000?l<
0?ooo`030000003oool0oooo00X0oooo0`000?l00`3oool0003o0?ooo`08
0?ooo`030?l0003oool0oooo00H0oooo00@0o`000?ooo`3oool0oooo0P00
0?l90?ooo`030000o`3oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo
0?l0000<0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
>P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0o`0000P0oooo
00D0003o0?ooo`3oool000000?ooo`020000o`<0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00<0
oooo0P000?l;0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0o0?ooo`030000o`3oool0oooo06/0
oooo001D0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`030?ooo`80o`001P3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0o`0000X0oooo00<0o`000?ooo`3oool0
1P3oool20000o`l0oooo00<000000?ooo`3oool03@3oool20000o`T0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0000o`0<0?ooo`030000
o`3oool0oooo00@0oooo0P3o00050?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0j0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool010000?l0oooo
0000o`000?l50?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`050?ooo`80003o203oool00`000?l0
oooo0?ooo`0I0?ooo`030?l0003oool0oooo00L0oooo0P3o00120?ooo`03
0000o`3oool0oooo06/0oooo001C0?ooo`030000o`3o0000oooo00X0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`80o`00
0`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool00`3oool20000oa40oooo00<000000?ooo`3oool0
3`3oool20000o`H0oooo00<0o`000?ooo`3oool02@3oool00`3o0000003o
0?ooo`0<0?ooo`040000o`3oool0oooo0?ooo`80o`001`3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
ool0>03oool00`000?l0oooo0?ooo`090?ooo`<0o`00203oool20000o`03
0000003oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`1Z0?ooo`00
D`3oool00`3o0000003o0000o`0:0?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0203oool00`3o0000oooo0000o`0=0?ooo`030?l0
003oool0003o00`0oooo00<0o`000?ooo`3oool00P000?lC0?ooo`030000
003oool0oooo0140oooo0P000?l30?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?l0003oool03@3oool00`000?l0oooo0?l0000:0?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool01P3oool30000o`030?l0
003oool0oooo03P0oooo0`000?l80?ooo`040?l0003oool0oooo0?l000L0
oooo0`000?l00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`80
003o103oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool0A03oool00`000?l0oooo0?ooo`1Z0?ooo`00
D`3oool00`3o0000oooo0?ooo`030000o`H0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l000000?l0oooo00`0oooo
00@0o`000?ooo`3oool0003o2`3oool00`3o0000003o0000o`0E0?ooo`03
0000003oool0oooo01<0oooo0P000?l00`3o0000oooo0?ooo`0:0?ooo`04
0000o`3oool0oooo0?l000d0oooo00<0003o0?l0003oool02`3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00@0oooo0P000?l30?oo
o`030?l0003oool0oooo03P0oooo00<0003o0?ooo`3oool00P000?l50?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool20000
o`80oooo00<0003o0000003oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02`3oool20000
o`030?ooo`000?l0oooo01l0oooo00D0o`000?ooo`3oool0oooo0?l00018
0?ooo`030000o`3oool0oooo06T0oooo001C0?ooo`030?l0003oool0oooo
00<0oooo0P000?l40?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0o`000?l0000;0?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool0203oool00`000?l0o`000?ooo`0E0?oo
o`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool0203oool20000
o`@0oooo00<0o`000?ooo`3oool02@3oool20?l000030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?oo
o`80003o1P3oool00`3o0000oooo0?ooo`0f0?ooo`030000o`3oool0oooo
00<0oooo00D0003o0?ooo`3oool0oooo0?l000060?ooo`040?l0003oool0
oooo0000o`D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?l0
00060?l000030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool03P3o
ool20000ob00oooo00@0o`000?ooo`3o0000o`00B@3oool00`000?l0oooo
0?ooo`1Y0?ooo`00DP3oool00`3o0000oooo0?ooo`060?ooo`80003o00<0
oooo0000o`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`050000o`3o
ool0oooo0?ooo`3o00002@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool05P3oool00`000000oooo
0?ooo`0F0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`060?ooo`80o`000`3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00@0003o0?ooo`000?l0
003o203oool00`3o0000oooo0?ooo`0f0?ooo`030000o`3oool0oooo00@0
oooo0P000?l00`3oool0o`000?ooo`060?ooo`030?l000000?l0oooo00D0
oooo00<0003o0?ooo`3oool00P3oool50?l000L0oooo00<0003o0?l0003o
00000`3o00050?ooo`030?l0003oool0oooo00d0oooo00@0003o0?ooo`3o
ool0003o803oool00`3o0000oooo0?ooo`190?ooo`030000o`3oool0oooo
06T0oooo001B0?ooo`030?l0003oool0oooo00P0oooo0P000?l;0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool00P3oool20?l000H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo01L0oooo00<000000?ooo`3oool05`3oool20000o`H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`80
o`001@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0
oooo0P000?l:0?ooo`030?l0003oool0oooo03D0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o0000oooo00H0
oooo00<000000000o`3o00000P3o00030?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool00`3oool30?l000030?ooo`3o0000oooo00l0
oooo00D0003o0?ooo`3oool0oooo0000o`0N0?ooo`030?l0003oool0o`00
04/0oooo00<0003o0?ooo`3oool0J03oool00540oooo00<0o`000?ooo`3o
ool02@3oool010000?l0oooo0000o`000?l90?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool01@3oool20?l000<0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
01P0oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool01P3oool30000o``0oooo00<0o`000?ooo`3oool0=03oool00`00
0?l0oooo0?ooo`060?ooo`040?l0003oool0003o0000o`@0oooo00<0003o
0?ooo`3oool00P3o00040?ooo`80o`0000<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo0P3o000?
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool06@3oool2
0?l000<0oooo00<0o`000?ooo`3oool0B03oool00`000?l0oooo0?ooo`1X
0?ooo`00D@3oool00`3o0000oooo0?ooo`090?ooo`040000o`3oool0oooo
0?ooo`80003o1P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00L0oooo00@0o`000?ooo`3oool0o`002`3oool010000?l0oooo0?oo
o`000?lK0?ooo`030000003oool0oooo01X0oooo00@0003o0?ooo`3oool0
003o2`3oool0103o0000oooo0?ooo`3o000:0?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool00`3oool30000o`<0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0d0?ooo`030?l0003oool0oooo
00H0oooo00H0o`000?ooo`3oool0oooo0000o`3oool20000o`@0oooo00<0
o`000?ooo`3oool00P3o00000`3oool000000000o`070?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool30?l000d0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool0B@3oool00`000?l0oooo0?oo
o`1W0?ooo`00D@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00@0oooo1@000?l00`3oool0o`000?ooo`0:0?ooo`030000o`3oool0
oooo00T0oooo0P3o000=0?ooo`80003o5@3oool500000080oooo00<00000
0?ooo`3oool06`3oool20000o``0oooo0`3o000;0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000000o`000?l00P000?l60?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool0<`3oool00`000?l0oooo0?l00002
0?l000@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`05
0?ooo`80o`000`3oool00`000000oooo0000o`060?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01`3oool01@3o0000oooo0?ooo`3o
ool0o`0000/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0D0?ooo`80o`001`3oool00`3o0000oooo0?ooo`180?ooo`030000o`3o
ool0oooo06L0oooo001@0?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool02@3oool20000o`/0oooo00<0003o0?ooo`3oool02@3oool3
0?l000`0oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool02@3oool3
0?l000d0oooo00<0003o0?ooo`3oool0203oool20000o`/0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0b0?ooo`030000o`3oool0
oooo0080oooo103o00050?ooo`040000o`3oool0003o0000o`@0oooo0P3o
00040?ooo`040000003oool0003o0?ooo`D0003o00<0o`000000o`000?l0
1@000?l80?ooo`030?l0003oool0oooo00<0oooo0P3o00080?ooo`030000
o`3oool0oooo00P0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo04T0oooo00<0003o0?ooo`3oool0
IP3oool00500oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`0:0?ooo`040?l0003oool0003o0000o`P0oooo00<0003o0?ooo`3oool0
2@3oool01@3o0000oooo0?ooo`3oool0o`0000X0oooo00<0003o0?ooo`3o
ool05`3oool00`000000oooo0?ooo`020?ooo`<000007@3oool00`000?l0
oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`3o0000303oool00`00
0?l0oooo0?ooo`060?ooo`80003o00<0oooo0?l0003oool02P3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo0380oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`040000o`3oool0oooo
0000o`<0oooo00@0o`000?ooo`3oool0o`000`3oool010000000oooo0000
o`000?l50?ooo`030?l0003oool0oooo00@0oooo10000?l50?ooo`030?l0
003oool0oooo00D0oooo0P3o00050?ooo`030000o`3oool0oooo00T0oooo
00<0003o0?ooo`3oool0403oool20?l000/0oooo00<0o`000?ooo`3oool0
B03oool00`000?l0oooo0?ooo`1V0?ooo`00D03oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool00P3o
ool20000o`H0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0403o
ool4000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0N0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo0P00
0?l40?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0`0?ooo`030000o`3oool0oooo00D0oooo00@0
o`000?ooo`3o0000o`000P3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0o`0000@0oooo00<0o`000000o`000?l010000?l50?ooo`030?l0
003oool0oooo00@0oooo00@0003o0?ooo`3oool0oooo0`000?l20?ooo`03
0?l0003oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0000o`0=0?oo
o`030000o`3oool0oooo00d0oooo0P3o000=0?ooo`030?l0003oool0oooo
04P0oooo00<0003o0?ooo`3oool0IP3oool004l0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00@0
oooo0P000?l30?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool0103oool20?l000D0oooo00<0003o0?ooo`3oool06@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3o
ool00`3oool20?l000D0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`030000o`H0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo0300oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`020?ooo`80o`001P3oool00`000?l0
oooo0?ooo`020?ooo`050000o`3o0000oooo0?ooo`0000000P3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0o`000?ooo`0:0?ooo`030?l0003oool0003o
00l0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0>0?oo
o`030?l0003oool0oooo04P0oooo00<0003o0?ooo`3oool0I@3oool004l0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00L0oooo10000?l;0?ooo`030?l0003oool0oooo00H0
oooo0P3o00020?ooo`030000o`3oool0oooo01T0oooo0P0000040?ooo`03
0000003oool0oooo01l0oooo00@0003o0?ooo`3oool0oooo0P3o00080?oo
o`030?l0003oool0oooo00X0oooo0P000?l:0?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0`0?oo
o`@0003o0`3oool00`3o0000oooo0?ooo`030?ooo`80o`000`3oool20?l0
0080003o0P3oool02@000?l0oooo0?ooo`3o0000oooo0000003oool0o`00
0000o`090?l00080oooo00<0003o0?ooo`3oool01P3oool00`3o0000003o
0?ooo`0:0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0
203oool20?l00140oooo00<0o`000?ooo`3oool0B03oool00`000?l0oooo
0?ooo`1U0?ooo`00C`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool30000o`T0oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0000o`0Q0?ooo`030000003o
ool0oooo0200oooo00<0003o0?ooo`3o00002`3oool00`3o0000oooo0?oo
o`070?ooo`<0003o2`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0<03oool010000?l0oooo0?oo
o`3oool20000o`030?l0003oool0oooo00<0oooo00H0003o0?ooo`3oool0
o`000?ooo`3o00030?ooo`<0003o0`3oool40?l000/0oooo0P3o00000`00
0?l0o`000?ooo`050?ooo`040?l0003oool0oooo0000o`T0oooo00<0003o
0?ooo`3o0000403oool00`000?l0oooo0?ooo`060?ooo`80o`00503oool0
0`3o0000oooo0?ooo`170?ooo`030000o`3oool0oooo06D0oooo001>0?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo0080003o1`3oool00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0200oooo00<000000?oo
o`3oool08@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00D0oooo0P000?l20?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
02l0oooo00<0003o0?ooo`3oool0103oool20000o`<0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`80003o0`3oool20?l0
00030?ooo`000000oooo00l0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`80003o1P3oool01@000?l0oooo0?ooo`3oool0
o`000100oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0D
0?ooo`030?l0003oool0oooo04L0oooo00<0003o0?ooo`3oool0I@3oool0
04h0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool00P3oool20000
o`D0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0Q0?oo
o`030000003oool0oooo0240oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`030?ooo`80003o1@3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0^0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool010000?l30?ooo`030?l0003oool0o`000080oooo00H0003o0?oo
o`3oool0003o0?ooo`3o00030?ooo`030000003oool0oooo00l0oooo0P3o
00020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool00P3oool20?l001L0oooo00<0o`000?ooo`3oool0B03o
ool00`000?l0oooo0?ooo`1T0?ooo`00CP3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`050?ooo`D0003o303oool00`000?l0oooo0?ooo`0Q
0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool02P3oool5
0000o`L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0;P3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P000?l2
0?ooo`060?l0003oool0oooo0?ooo`3o0000003o0`3oool00`000?l0o`00
0?ooo`030?ooo`030000003oool0oooo0140oooo0P3o00080?ooo`040000
o`3oool0oooo0000o`L0oooo00<0o`000?ooo`3oool03@3oool010000?l0
oooo0?l0003o000J0?ooo`030?l0003oool0oooo04L0oooo00<0003o0?oo
o`3oool0I03oool004h0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000003o0000o`090?ooo`030000o`3oool0oooo0280
oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`080?ooo`80
003o00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0^0?ooo`D0o`0000<0oooo0?l0003oool00`3oool01@000?l0
oooo0000o`000?l0o`0000<0oooo00D0003o0?l0003oool0oooo0?l00006
0?ooo`030000003oool0oooo0180oooo00<000000?l0003o00001`3oool2
0000o`P0oooo00<0o`000?ooo`3oool0303oool30?l001`0oooo00<0o`00
0?ooo`3oool07P3oool4000002D0oooo00<0003o0?ooo`3oool0I03oool0
04d0oooo103o00080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
0080003o1`3oool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo
02<0oooo00<0003o0?ooo`3oool01@3oool20000o`80oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool01P3oool30?l002l0oooo00<0003o0?oo
o`3oool00`3oool30?l00080oooo00D0003o0?ooo`3oool0oooo0?l00002
0000o`040?ooo`000?l0oooo0?ooo`80o`001`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0o`0000H0oooo0P000?l90?ooo`030?l0003o
ool0oooo00T0oooo0P3o00020?ooo`030000o`3oool0oooo01X0oooo00<0
o`000?ooo`3oool07P3oool00`000000oooo0?ooo`0V0?ooo`030000o`3o
ool0oooo06@0oooo001=0?ooo`040?l0003oool0oooo0?ooo`D0o`000`3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?ooo`80003o103o
ool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo02@0oooo00<0
003o0?ooo`3oool00P3oool20000o`D0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00@0
003o0?ooo`3oool0oooo1@3o00020?ooo`030?l0003oool0oooo02d0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?l000060000
o`3oool0oooo0?ooo`3o0000oooo0P000?l20?ooo`80o`00203oool00`00
0000oooo0?ooo`0@0?ooo`D0000000<0oooo0?l0003oool00`3oool01000
0?l0oooo0?ooo`000?l90?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0
oooo01h0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`1T
0?ooo`00C@3oool00`3o0000oooo0?ooo`060?ooo`@0o`002P3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool01@3oool20000o`80oooo00<0003o0?ooo`3oool08`3oool00`00
0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0080003o1`3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool0203oool40?l000P0oooo00<0o`000?ooo`3oool0;03oool00`00
0?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l00P3o0000
103oool0o`000?ooo`3oool30000o`030?l0003oool0oooo00P0oooo00<0
00000?ooo`3oool0403oool010000000oooo0?ooo`0000030?ooo`040?l0
003oool0003o0000o`@0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`030?ooo`<0o`001P3oool00`000?l0oooo0?ooo`0J0?ooo`03
0?l0003oool0oooo01l0oooo00<000000?ooo`3oool09@3oool00`000?l0
oooo0?ooo`1S0?ooo`00C@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0o`0000@0o`001@3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool01`3oool20000obH0oooo
00<000000?ooo`3oool09@3oool20000o`T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo
1@3o00000`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo02`0oooo
0P000?l30?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3o00001P3oool0003o0?ooo`3oool0o`000000o`X0oooo00<000000?oo
o`3oool04@3oool00`000000oooo000000040?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool0103o0000oooo0?ooo`3oool2
0?l000X0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0M
0?ooo`040000003oool0oooo000002H0oooo00<0003o0?ooo`3oool0H`3o
ool004d0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`04
0?ooo`L0o`002P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool0903oool00`000000oooo0?ooo`0U
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`L0o`001@3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo02`0oooo00<0003o0?ooo`000?l010000?l2
0?ooo`060000o`3oool0oooo0?ooo`3o0000oooo0P3o00020?ooo`030?l0
003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool2000000D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`070?ooo`<0o`00
303oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo01d0oooo
0P00000W0?ooo`030000o`3oool0oooo06<0oooo001=0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`040?l000D0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo02D0oooo00<000000?ooo`3oool09P3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool00P3oool50?l000030?ooo`3o0000oooo00X0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`000?l00P000?l20?ooo`040?l0003o
ool0oooo0000o`<0o`00303oool00`000000oooo0?ooo`0J0?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool20?l000l0oooo
00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`160?ooo`030000
o`3oool0oooo06<0oooo001<0?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`D0o`0000<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo02D0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?l0003o00000P3o
00060?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0080oooo00@0
o`000?ooo`3oool0oooo10000?l01@3oool0003o0?ooo`3oool0o`0000d0
oooo00<000000?ooo`3oool03P3oool8000000@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`80o`000P3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3o
ool06P3oool8000002@0oooo00<0003o0?ooo`3oool0H`3oool004`0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00T0oooo1@3o00070?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool09@3oool00`000000oooo0?ooo`0V0?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool50?l000/0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo02/0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo
0?ooo`000?l20?ooo`040?l0003oool0003o0000o`80oooo00<0o`000?oo
o`3oool02`3oool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0oooo
00<0oooo00@0003o0?ooo`3oool0oooo0P3o00040?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`15
0?ooo`030000o`3oool0oooo06<0oooo001<0?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00<0oooo103o00020?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0103o00050?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo02X0oooo00<0003o0?oo
o`3o00001@3o0000203oool0003o0?ooo`3oool0o`000?ooo`000?l0oooo
0P000?l>0?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool0
103oool30?l000H0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0I0?ooo`030?l0003oool0oooo04D0oooo00<0003o0?ooo`3oool0
H`3oool004`0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`020?ooo`8000001@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00L0oooo1@3o00080?ooo`030000o`3oool0oooo00/0oooo1@00
000F0?ooo`030000003oool0oooo01P0oooo1@0000090?ooo`030000o`3o
ool0oooo00L0oooo1@3o00090?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool01@3oool2000000030?ooo`000?l0oooo00X0oooo00<0
o`000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00D0o`0000@0oooo0000o`3oool0o`003`3oool00`000000oooo
0?ooo`0L0?ooo`040?l0003oool0oooo0?ooo`80o`0000<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00l0
oooo1@0000050?ooo`030?l0003oool0oooo04@0oooo00@000000000o`00
00000000H`3oool004`0oooo00<0o`000?ooo`3oool0203oool01@000?l0
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00@0o`000?oo
o`3oool0oooo1`3o00000`3oool0003o0?ooo`0>0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0:
0?ooo`030000o`3oool0o`0000H0o`000`3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool0
1P000000oooo0?ooo`000000oooo0000o`X0oooo00<0o`000?ooo`3oool0
:P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`00
0?l00P3oool30?l000030?ooo`3o0000oooo00h0oooo00<000000?ooo`3o
ool0403oool5000000L0oooo103o00030?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0A0?ooo`03
0000003oool0oooo00D0oooo00<0o`000?ooo`3oool0703oool2000002H0
oooo00<000000000o`3oool0I03oool004`0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo0P3o000?0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0:0?ooo`80o`00
2P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool01P3oool010000000oooo0?ooo`000?l:0?ooo`03
0?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool00P3oool01@3o0000
oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`000?l00P3o000?0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0203oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0A0?ooo`030000003oool0oooo
00D0oooo00<0o`000?ooo`3oool06`3oool010000000oooo0?ooo`00000V
0?ooo`03000000000?l0oooo06<0oooo001<0?ooo`030?l0003oool0oooo
00H0oooo0P0000000`000?l000000?ooo`040?ooo`050000003oool0oooo
0?ooo`3o00002`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool01@3oool4000000@0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool0
0`000000oooo0000o`0:0?ooo`030?l0003oool0oooo02X0oooo2P000?l0
1P3oool0o`000?ooo`000?l0oooo0?l00100oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo0140oooo00<000000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0M0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0
HP3oool004`0oooo00<0o`000?ooo`3oool0203oool01@000?l0oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo0?l0000;0?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`0=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00@0oooo00H000000?ooo`3oool000000?ooo`000?l:
0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`070000o`030?l0003oool0oooo00h0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo0100oooo00<000000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`0M0?ooo`030000003oool0oooo02<0oooo00@00000
0?ooo`000?l00000H`3oool004`0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`020?ooo`800000103oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`0=0?ooo`800000603oool00`000000oooo0?ooo`0I
0?ooo`8000003@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`04
0?ooo`8000000P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo02X0oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`00
0?l20?ooo`050?l0003oool0003o0?ooo`000?l0403oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool03`3oool2000000P0oooo00<0o`000?ooo`3oool0
6P3oool010000000oooo0?ooo`00000V0?ooo`03000000000?l0oooo06<0
oooo001<0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0W0?ooo`030000
003oool0oooo02P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo02X0oooo
103o00001@3oool0o`000?ooo`3oool0003o0080oooo00D0o`000?ooo`00
0?l0oooo0?l0000@0?ooo`030000003oool0oooo0140oooo0P00000;0?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?oo
o`3oool06`3oool2000002P0oooo00<0003o0?ooo`3oool0HP3oool004`0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo02L0oooo00<000000?ooo`3o
ool0:03oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0:P3oool010000?l0
oooo0?ooo`3oool<0?l00100oooo00<000000?ooo`3oool07P3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo
04D0oooo00<0003o0?ooo`3oool0HP3oool004`0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo02L0oooo00<000000?ooo`3oool0:03oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0:P3oool01@000?l0oooo0?ooo`3oool0o`00
00<0oooo00H0003o0?ooo`3oool0o`000?ooo`000?l20?l00100oooo00<0
00000?ooo`3oool07P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0I0?ooo`030?l0003oool0oooo04D0oooo00<0003o0?ooo`3oool0HP3o
ool004`0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo02L0oooo00<00000
0?ooo`3oool0:03oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool2
000000030?ooo`000000000001h0oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`030000o`3oool0o`000080oooo00<0003o0?l0003oool0403o
ool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo01T0oooo00<0o`000?ooo`3oool0A@3oool00`000?l0oooo0?oo
o`060?ooo`@00000F03oool004T0oooo0`00000i0000oe@00000>@000?l3
000000L0oooo00<000000?ooo`0000005`3oool8000000l0003o<P000023
0000o`L0oooo00@000000?ooo`3oool00000F@3oool004`0oooo00<0o`00
0?ooo`3oool0203oool010000?l0oooo0?ooo`0000070?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00/0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00/0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool01@3oool010000000oooo0?oo
o`000?l:0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0
7P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3o
00000P3oool00`000?l0o`000?ooo`0@0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3o
ool0703oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo00D0
oooo00@000000?ooo`3oool00000F@3oool004`0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo02L0oooo00<000000?ooo`3oool0:03oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool01`3oool2000000030?ooo`000000000001h0
oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`070000o`3oool0oooo
0?l0003oool0003o0?l000060?ooo`8000002@3oool00`000000oooo0?oo
o`0N0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01T0oooo00<0
o`000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`040?ooo`80000000<0
oooo000000000000F@3oool004`0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo02L0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0:P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0
003o0?l0003o00001@3o00040?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0I0?ooo`030?l0003oool0oooo04D0oooo00<0003o0?ooo`3oool0
HP3oool004`0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo02L0oooo00<0
00000?ooo`3oool0:03oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0:P3o
ool90?l00080oooo00D0o`000?ooo`000?l0oooo0?l000040?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool07P3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo04D0
oooo00<0003o0?ooo`3oool0HP3oool004`0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`020?ooo`040?l0
003oool0oooo0000o`80oooo00D0o`000?ooo`000?l0oooo0?l000050?oo
o`8000002@3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0A@3oool00`00
0?l0oooo0?ooo`1R0?ooo`00C03oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool09`3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`0Z0?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`3o
ool0003o0P3oool50000o`@0oooo00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo01X0oooo00<0o`000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`1R
0?ooo`00C03oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool09`3oool00`00
0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0Z0?oo
o`030000o`3oool0oooo0080oooo1`000?l0103oool0003o0?ooo`3o0005
0?ooo`8000002@3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0AP3oool0
0`000?l0oooo0?ooo`1R0?ooo`00C03oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0o`000?oo
o`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`0Z0?ooo`D0003o00@0o`000?ooo`3oool0003o0P3oool0
103o0000oooo0?ooo`000?l20?l000l0oooo00<000000?ooo`3oool07@3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003o
ool0oooo04H0oooo00<0003o0?ooo`3oool0HP3oool004`0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`04
0?ooo`D0o`0000<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`0W
0?ooo`030000o`3o0000o`0000<0o`001@3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo02X0oooo00<0003o
0?ooo`3oool00P3oool0203o0000oooo0?ooo`3oool0003o0?ooo`3o0000
oooo103o00000`3oool0000000000006000000H0oooo00<000000?ooo`3o
ool0703oool20?l000D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3o
ool0AP3oool00`000?l0oooo0?ooo`1R0?ooo`00C03oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`090?ooo`H0o`001@3oool00`000?l0oooo
0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0
103oool60?l000/0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
:P3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo0?ooo`@0
o`0000@0oooo0000o`3oool0o`003`3oool3000001`0oooo00<0o`000?oo
o`3o00000P3o00000`3oool0003o0?ooo`080?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`150?oo
o`030000o`3oool0oooo06<0oooo001<0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00H0oooo103o000:0?ooo`030000o`3oool0oooo02H0
oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`090?ooo`@0
o`001`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0Z0?ooo`03
0000o`3oool0oooo0080oooo1@3o00020?ooo`030?l0003oool0003o0080
oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`03
0?l0003oool0oooo0080oooo0P3o00090?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`150?ooo`03
0000o`3oool0oooo06<0oooo001<0?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00D0o`000`3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo0080oooo1@3o00020?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo02X0oooo00<0003o0?l0003o0000
0P3o00001@3oool0o`000?ooo`3oool0003o00<0oooo00D0o`000000o`00
0?l0003o0?l0000>0?ooo`030000003oool0oooo01/0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?l000020?l000D0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo
04D0oooo00<0003o0?ooo`3oool0H`3oool004d0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0
oooo1@3o00090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool09@3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool01`3oool40?l000T0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo02/0
oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l20?oo
o`@0003o0P3oool00`3o0000oooo0?ooo`0;0?ooo`030000003oool0oooo
01X0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?oo
o`80o`000`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
01X0oooo00<0o`000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`1S0?oo
o`00C@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool01P3o00020?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0U0?ooo`03
0000003oool0oooo02H0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0o`0000H0o`000P3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0;03oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0
003o00L0o`000?ooo`3oool0003o0?ooo`3o0000oooo00D000001`3oool0
0`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool30?l000h0oooo00<0003o0?ooo`3oool06`3oool0
0`3o0000oooo0?ooo`150?ooo`030000o`3oool0oooo06<0oooo001=0?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool50?l0
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool01`3oool50?l000P0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo0080oooo0`000?l00`3o
ool0003o0?ooo`020?ooo`060?l0003oool0o`000?l0003oool0o`000P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`070?ooo`80o`003@3o
ool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo04H0oooo00<0
003o0?ooo`3oool0H`3oool004d0oooo00<0o`000?ooo`3oool02@3oool0
10000?l0oooo0?ooo`3oool50?l00080oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0903oool00`000000oooo0?ooo`0U0?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00D0o`000`3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo02`0oooo1@000?l00`3oool0o`000?oo
o`020?ooo`030000o`3oool0oooo00<0o`0000H0003o0?ooo`3oool0o`00
0?ooo`0000090?ooo`030000003oool0oooo01P0oooo00<0003o0?l0003o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00<0
o`002P3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo04H0
oooo00<0003o0?ooo`3oool0H`3oool004d0oooo00<0o`000?ooo`3oool0
2@3oool40?l000L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00H0oooo0`000?lV0?ooo`030000
003oool0oooo02@0oooo00@0003o0?ooo`000?l0003o203oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool01P3oool40?l000/0oooo00<0o`000?ooo`3oool0;03oool00`000?l0
oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l0103o00020?oo
o`050000o`3oool0003o0000o`0000002@3oool00`000000oooo0?ooo`0H
0?ooo`030?l000000?l0oooo00@0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`030?ooo`80o`001`3oool00`000?l0oooo0?ooo`0J
0?ooo`030?l0003oool0oooo04L0oooo00<0003o0?ooo`3oool0H`3oool0
04h0oooo00<0o`000?ooo`3oool00`3oool50?l000030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00@0oooo0P000?l30?ooo`030000o`3oool0oooo
02<0oooo00<000000?ooo`3oool0903oool010000?l0oooo0?ooo`3oool2
0000o`H0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?l0003o00000`3o0006
0?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`030?l000<0oooo00L0o`000?ooo`3oool0003o0?oo
o`3o0000000000T0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo
0?ooo`020000o`80oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`80o`001@3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0
003oool0oooo04H0oooo00<0003o0?ooo`3oool0I03oool004h0oooo1P3o
00050?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo0080oooo0P00
0?l50?ooo`030000o`3oool0oooo02<0oooo00<000000?ooo`3oool08`3o
ool00`000?l0oooo0?ooo`040?ooo`80003o0`3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`040?ooo`L0o`00;`3oool00`000?l0oooo0?oo
o`030?ooo`<0o`0000<0oooo0000o`3oool00P3oool01P3o0000003o0000
o`3oool0003o00000080o`00203oool00`000000oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo00<0oooo0P000?l90?ooo`030?l0003oool0oooo00T0
oooo0P3o00030?ooo`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3o
ool0AP3oool00`000?l0oooo0?ooo`1T0?ooo`00CP3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`090?ooo`040?l000000?l0003o0000o`P0
oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`03
0000o`3oool0oooo00H0oooo0P000?l00`3oool0o`000?ooo`0:0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo02h0oooo00<0003o0?ooo`3o
ool0103o00040?ooo`030000o`3oool0oooo0080003o0`3oool010000?l0
o`000?l0003o00070?ooo`030000003oool0oooo01D0oooo00<0o`000?oo
o`3oool0103oool20000o`T0oooo00<0o`000?ooo`3oool02`3oool00`3o
0000oooo0000o`0L0?ooo`030?l0003oool0oooo04L0oooo00<0003o0?oo
o`3oool0I03oool004h0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool0203oool20000o`/0oooo00<0003o0?ooo`3oool08P3oool00`000000
oooo0?ooo`0R0?ooo`030000o`3oool0oooo00T0oooo0`000?l:0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo02h0oooo0`3o00030?ooo`03
0?l0003oool0oooo0080oooo0`000?l00`3oool0o`000?ooo`020?ooo`80
o`000P3oool20?l000D0oooo00<000000?ooo`3oool04P3oool30?l000L0
oooo00<0003o0?ooo`000?l01`3oool00`3o0000oooo0?ooo`0=0?ooo`80
o`00703oool00`3o0000oooo0?ooo`170?ooo`030000o`3oool0oooo06@0
oooo001>0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00H0oooo
0P000?l00`3oool0o`000?ooo`0;0?ooo`030000o`3oool0oooo0240oooo
00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo0080003o203oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0_0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0`000?l30?ooo`060?l0003oool0o`000?l0003oool0003o0P3oool00`00
0?l0o`000?ooo`030?ooo`030000003oool0oooo0140oooo0`3o00070?oo
o`050000o`3oool0oooo0?ooo`000?l01@3oool00`3o0000oooo0?ooo`0>
0?ooo`040000o`3oool0o`000?l001T0oooo00<0o`000?ooo`3oool0A`3o
ool00`000?l0oooo0?ooo`1U0?ooo`00C`3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`040?ooo`80003o103oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo0240oooo00<000000?ooo`3oool08@3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo0P000?l5
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo02l0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000003o0000o`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool30000o`030?ooo`3o0000
o`000080oooo00<000000?ooo`3oool03P3oool30?l00080oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0
oooo0?ooo`3o00004@3oool010000?l0oooo0?ooo`3oool20?l001L0oooo
00<0o`000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`1U0?ooo`00C`3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02@3oool010000?l0oooo0?ooo`3oool20000o`H0oooo
00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0P0?ooo`030000
003oool0oooo0200oooo00<0003o0?l0003oool02P3oool00`3o0000oooo
0?ooo`050?ooo`80003o0`3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0`0?ooo`030000o`3oool0oooo0080oooo0`000?l40?ooo`060000
o`3oool0oooo0?l0003oool0o`00103oool00`000?l0oooo0?ooo`020?oo
o`<0o`003P3oool00`000?l0o`000?ooo`050?ooo`040?l0003oool0oooo
0?ooo`80003o1P3oool01@000?l0oooo0?ooo`3oool0o`000100oooo00<0
003o0?ooo`3oool0103oool20?l001D0oooo00<0o`000?ooo`3oool0A`3o
ool00`000?l0oooo0?ooo`1U0?ooo`00C`3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool5
0000o`T0oooo00<0o`000?ooo`3oool01`3oool20?l000030?ooo`000?l0
oooo0200oooo00<000000?ooo`3oool0803oool010000?l0oooo0?l0003o
00090?ooo`030?l0003oool0oooo00L0oooo1@000?l:0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0a0?ooo`@0003o0P3oool00`3o0000oooo0?ooo`030?ooo`80o`000`3o
ool01@3o0000oooo0?ooo`000?l0oooo0080003o0P3oool00`3o0000oooo
000000020?l000030000o`3o0000o`0000T0o`0000<0003o0?ooo`3oool0
1P3oool00`3o0000003o0000o`090?ooo`030000o`3oool0o`000100oooo
00<0003o0?ooo`3oool01`3oool20?l00180oooo00<0o`000?ooo`3oool0
B03oool00`000?l0oooo0?ooo`1U0?ooo`00C`3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool01@3o
ool20000o`030?ooo`000?l0oooo00/0oooo00<0o`000?ooo`3oool01@3o
ool20?l000@0oooo00<0003o0?ooo`3oool05`3oool500000080oooo00<0
00000?ooo`3oool07`3oool00`000?l0oooo0?ooo`020?ooo`80o`001P3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080003o1`3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool0<03oool20000o`D0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030?l000000?l0oooo00<0oooo00D0
003o0?l0003oool0oooo000000020?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3o0000oooo00/0oooo0P000?l@0?ooo`030000o`3oool0oooo00T0oooo
0P3o000@0?ooo`030?l0003oool0oooo04L0oooo00<0003o0?ooo`3oool0
IP3oool00500oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00<0oooo0P000?l40?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo0080oooo0P000?l50?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0b0?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00P3o00000`3oool0003o0?oo
o`030?ooo`030000o`3o0000oooo00@0oooo00@0o`000000o`000?l00000
0P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o000:0?ooo`03
0?l0003oool0003o00l0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0=0?ooo`030?l0003oool0oooo04L0oooo00<0003o0?ooo`3o
ool0IP3oool00500oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo0080003o1P3oool00`000?l0oooo
0?ooo`0;0?ooo`050?l0003oool0oooo0?ooo`3o00002@3oool00`000?l0
oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo0`00000M0?ooo`03
0000o`3oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?oo
o`030000o`3oool0oooo00D0oooo0P000?l20?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0b0?oo
o`030000o`3oool0oooo00@0oooo0`3o00040?ooo`030000o`3oool0oooo
0080003o00<0oooo0?l0003oool00P3oool0103o0000oooo0?ooo`3oool3
0000o`H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0000o`<0oooo00<0o`000?ooo`3oool01`3oool01@3o0000oooo0?ooo`3o
ool0003o00d0oooo00<0003o0?ooo`3oool03P3oool20?l000`0oooo00<0
o`000?ooo`3oool0B03oool00`000?l0oooo0?ooo`1V0?ooo`00D03oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0000o`000?l02@3oool00`000?l0oooo0?ooo`0:0?ooo`040?l0003oool0
o`000?l000/0oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool02@3o
ool0103o0000oooo0?ooo`3o000;0?ooo`030000o`3oool0oooo00P0oooo
0P000?l00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`030?ooo`80o`00
1@3oool010000?l0oooo0?ooo`000?l30?ooo`040?l0003oool0o`000?l0
00<0oooo00<000000?ooo`000?l01P000?l00`3o0000003o0000o`070000
o`H0oooo00<0o`000?ooo`3oool01@3oool20?l000D0oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
00T0oooo00<0o`000?ooo`3oool0B03oool00`000?l0oooo0?ooo`1V0?oo
o`00D@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0
oooo0`000?l<0?ooo`030000o`3oool0oooo00T0oooo0P3o000>0?ooo`03
0000o`3oool0oooo01D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0K0?ooo`030000o`3oool0oooo00/0oooo0P3o000<0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000000o`000?l02@3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo03<0oooo00<0003o0?ooo`3o
ool00`3o00000`3oool0o`000?ooo`050?ooo`80003o1@3oool20?l000@0
oooo00<000000?ooo`000?l01P3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo04P0
oooo00<0003o0?ooo`3oool0I`3oool00540oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`050?ooo`80003o0`3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00@0o`000?ooo`3oool0
o`00303oool00`000?l0oooo0000o`0E0?ooo`800000103oool00`000000
oooo0?ooo`0J0?ooo`030000o`3oool0003o00`0oooo00<0o`000?ooo`3o
00002P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00<0
003o1P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo03@0
oooo0`3o00050?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`00
0?l0003o103oool0103o0000oooo0?l0003o00020?ooo`03000000000?l0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo0080o`002P3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo01D0oooo0P3o00060?ooo`030?l0003oool0
oooo04T0oooo00<0003o0?ooo`3oool0I`3oool00540oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`80003o1@3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00H0oooo0P3o00020?oo
o`030?l0003oool0oooo00T0oooo00D0003o0?ooo`3oool0oooo0000o`0J
0?ooo`030000003oool0oooo01T0oooo00D0003o0?ooo`3oool0oooo0000
o`0;0?ooo`040?l0003oool0oooo0?l000T0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`040?ooo`80003o0`3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo03D0oooo00<0003o0?ooo`3oool0
103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0003o0?ooo`3o
ool0oooo0?l000030?ooo`80o`0000<000000000o`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo0`3o000=0?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0603oool20?l0
00@0oooo00<0o`000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`1W0?oo
o`00DP3oool00`3o0000oooo0?ooo`080?ooo`D0003o203oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00@0oooo0P3o00050?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo0080
oooo0P3o00060?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool01P3oool40000o``0oooo00<0o`000?ooo`3oool0=@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0003o00H0oooo00<0003o0?ooo`3o
00001P3oool00`3o0000003o0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool30?l000l0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0K0?ooo`80o`0000<0oooo0?l0003o
ool0BP3oool00`000?l0oooo0?ooo`1X0?ooo`00DP3oool00`3o0000oooo
0?ooo`070?ooo`80003o303oool00`3o0000oooo0?ooo`0:0?ooo`040000
o`3oool0oooo0?ooo`80o`00203oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool05P3oool00`000000
oooo0?ooo`0G0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`80o`000`3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo0`000?l90?ooo`03
0?l0003oool0oooo03H0oooo00<0003o0?ooo`3oool01@3oool20000o`P0
oooo00<0o`000000o`3oool01@3oool00`000?l0oooo0?l000060?l000P0
oooo00@0003o0?ooo`3oool0oooo103o00020?ooo`030?l0003oool0oooo
00h0oooo00@0003o0?ooo`3oool0003o803oool00`3o0000oooo0?ooo`1:
0?ooo`030000o`3oool0oooo06P0oooo001B0?ooo`030?l0003oool0oooo
00@0oooo0`000?l20?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool02@3oool010000?l0oooo0?ooo`3o000:0?ooo`030?l0003oool0
oooo00<0oooo0P000?l90?ooo`030000o`3o0000oooo01D0oooo00<00000
0?ooo`3oool05@3oool00`3o0000003o0?ooo`080?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0203oool20?l000030?ooo`000?l0
oooo00/0oooo00<0o`000?ooo`3oool02@3oool010000?l0oooo0?ooo`3o
ool20000o`L0oooo00<0o`000?ooo`3oool0=`3oool00`000?l0oooo0?oo
o`020?ooo`80003o0P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0003o00D0oooo00<0003o0?ooo`3oool01@3oool90?l000040000o`3o
0000o`000?l000L0oooo00<0o`000?ooo`3oool03P3oool20000ob00oooo
00<0o`000?ooo`3o0000B`3oool00`000?l0oooo0?ooo`1X0?ooo`00DP3o
ool00`3o0000oooo0?ooo`020?ooo`80003o1@3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?l0003oool02`3o
ool01@3o0000oooo0?ooo`3oool0003o00/0oooo00<0o`000000o`000?l0
5@3oool00`000000oooo0?ooo`0C0?ooo`80003o00<0o`000?ooo`3oool0
2@3oool01@000?l0oooo0?ooo`3oool0o`0000d0oooo00<0o`000?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00<0
oooo0`000?l40?ooo`030?l0003oool0oooo03L0oooo00D0003o0?ooo`3o
ool0oooo0000o`050?ooo`030?l0003oool0oooo00<0oooo00D0o`000?oo
o`3oool0oooo0000o`030?ooo`030000o`000000oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool07`3oool00`3o0000oooo0?ooo`02
0?l004T0oooo00<0003o0?ooo`3oool0J03oool005<0oooo00@0o`000?oo
o`000?l0003o203oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00T0oooo00<0o`000000o`3oool0303oool0103o0000oooo0?ooo`00
0?l;0?ooo`030?l0003oool0oooo0080003o4`3oool00`000000oooo0?oo
o`0B0?ooo`050000o`3oool0oooo0?ooo`3o00002`3oool00`000?l0oooo
0?l0000>0?ooo`030000o`3o0000oooo00X0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`070?ooo`80003o00<0oooo0?l0003oool0
>P3oool30000o`H0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`030?ooo`80003o00<0oooo0000o`0000001`3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2`3oool20000o`030?ooo`000?l0oooo01h0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`150?ooo`030000o`3oool0oooo06T0oooo
001C0?ooo`80003o2P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00L0oooo0P3o00020?ooo`030000o`3oool0oooo00/0oooo0P00
0?l;0?ooo`030?l0003oool0oooo00<0oooo0P000?lA0?ooo`030000003o
ool0oooo0140oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`090?ooo`80003o3@3oool00`000?l0oooo0?ooo`020?l000P0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`80003o>P3o
ool20000o`T0oooo00@0o`000?ooo`3oool0o`00203oool20000o`030000
003oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00T0oooo0P000?l40?ooo`030000
o`3oool0oooo01/0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`140?ooo`030000o`3oool0oooo06T0oooo001C0?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`040?ooo`80o`001@3oool00`000?l0oooo0?ooo`090?ooo`040000o`3o
ool0o`000?l000T0oooo00<0o`000?ooo`3oool01P3oool20000o`l0oooo
00<000000?ooo`3oool03P3oool30000o`L0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0000o`0=0?ooo`030000o`3oool0oooo0080oooo
0P3o00060?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0j0?ooo`030000o`3oool0oooo00P0oooo
0P3o00090?ooo`<0003o1P3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool01P3oool20000o`L0oooo
00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo0480oooo00<0003o0?ooo`3oool0JP3oool005@0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`090?ooo`050000o`3oool0oooo0?ooo`3o00001`3oool00`3o0000oooo
0?ooo`070?ooo`040000o`3oool0003o0000o`d0oooo00<000000?ooo`3o
ool0303oool30000o`T0oooo00<0o`000?ooo`3oool01P3oool01@3o0000
oooo0?ooo`3oool0003o00/0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`0k0?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3o0000203oool010000?l0oooo0?ooo`000002
0000o`@0oooo00<0o`000?ooo`3oool01`3oool20000o`/0oooo00<0o`00
0?ooo`3oool0103oool20000o`X0oooo00<0003o0?ooo`3oool05`3oool0
0`3o0000oooo0?ooo`090?ooo`80o`00@P3oool00`000?l0oooo0?ooo`1Z
0?ooo`00E03oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00X0oooo00D0o`000?ooo`3oool0oooo0?l000090?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo00L0oooo00@0003o0?ooo`3oool0oooo1P00
0?l70?ooo`030000003oool0oooo00L0oooo1@000?l30?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01`3o
ool01@3o0000oooo0?ooo`3oool0o`0000`0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0l0?ooo`030000o`3oool0oooo00D0oooo
00D0o`000?ooo`3oool0oooo0?l000060?ooo`050000o`3oool0oooo0?oo
o`0000000P3oool20000o`80oooo00<0o`000?ooo`3oool01`3oool20000
o`/0oooo00<0o`000?ooo`3oool00P3oool20000o``0oooo00<0003o0?oo
o`3oool05`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo
03h0oooo00<0003o0?ooo`3oool0J`3oool005D0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0:0?ooo`<0o`002`3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0
oooo00<0o`000000o`000?l010000?l00`3oool000000?ooo`070000o`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`090?ooo`<0o`00303oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo03d0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00D0003o0?ooo`3oool0oooo000000040?ooo`030000o`3o0000003o
00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000003o0000o`020000
o`l0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0=0?oo
o`030?l0003oool0oooo03d0oooo00<0003o0?ooo`3oool0J`3oool005D0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`<0
o`003@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0
oooo0P3o00020?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`040?ooo`@0003o1P3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00D0o`000?ooo`3o
ool0oooo0?l000090?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool02`3oool30?l000/0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0n0?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool01@3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<00000
0?ooo`3oool00`3oool00`3o0000oooo0000o`060000o`80oooo00<0003o
0?ooo`3oool01@3oool50000o`030?ooo`3o0000oooo0140oooo00<0003o
0?ooo`3oool0503oool00`3o0000oooo0?ooo`0?0?ooo`80o`00?03oool0
0`000?l0oooo0?ooo`1/0?ooo`00EP3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0?l0000=
0?ooo`050000o`3oool0oooo0?ooo`000?l0303oool20?l000X0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`080?ooo`<0o`002`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00/0oooo00@0o`000?ooo`3oool0o`002@3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo03l0oooo00@0003o0?ooo`3o0000
o`002@3oool0103o0000oooo0?ooo`000?l40?ooo`030000003oool0oooo
00<0oooo00<0o`000?ooo`3oool01P3oool:0000o`H0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`80o`00503oool00`3o
0000oooo0?ooo`0i0?ooo`030000o`3oool0oooo06`0oooo001G0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`00
0?l03@3oool20?l000X0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`080?ooo`80o`003@3oool010000?l0
oooo0?ooo`000?l=0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
0400oooo0P3o000<0?ooo`030?l000000?l0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0@0?oo
o`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0=`3oool00`00
0?l0oooo0?ooo`1]0?ooo`00E`3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00<0oooo0P3o00060?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?l000P0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`80o`0000<0oooo0?l0003oool03@3oool20000o`h0
oooo00<0o`000?ooo`3oool00`3oool20?l000D0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`110?ooo`030000o`3oool0oooo00X0
oooo00<0003o0?l0003oool0103oool00`000000oooo0?ooo`020?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool05`3oool00`3o0000oooo0?ooo`0f0?ooo`030000o`3oool0oooo06d0
oooo001H0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
0P3o00090?ooo`030?l0003oool0oooo00X0oooo0P000?l=0?ooo`030?l0
003oool0oooo0080oooo0P3o00050?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo00/0oooo0P000?l=0?ooo`030?l0
003oool0oooo00H0oooo0P3o00030?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`090?ooo`030000
o`3oool0oooo0080o`000`3oool00`000000oooo0?ooo`020?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
6@3oool00`3o0000oooo0?ooo`0d0?ooo`030000o`3oool0oooo06h0oooo
001H0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o0000303o
ool00`3o0000oooo0?ooo`070?ooo`80003o0P3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00D0oooo0P3o00030?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00P3o
ool20?l000D0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`020000o`X0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0000
o`0<0?ooo`030?l0003oool0oooo04<0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`030?ooo`040?l0003oool0oooo000000<0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo0180oooo00<0003o0?ooo`3oool02P3oool20?l001d0oooo
0P3o000d0?ooo`030000o`3oool0oooo06h0oooo001I0?ooo`030?l0003o
ool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`070?ooo`80o`0000<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?l000020?l000P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0:0?ooo`030?l0003oool0oooo04@0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0000000<0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo01<0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`0O0?ooo`030?l0003oool0oooo0300oooo00<0003o0?ooo`3oool0K`3o
ool005T0oooo00<0o`000?ooo`3oool0203oool20?l000030?ooo`000?l0
oooo00`0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0o`000?l000070?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`80o`0000<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`050?ooo`80003o1P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?l0003o00002P3oool00`3o0000oooo0?ooo`150?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool01`3oool20?l00080oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo01<0oooo00<0003o0?ooo`3oool01P3oool20?l002<0oooo00<0o`00
0?ooo`3oool0;P3oool00`000?l0oooo0?ooo`1`0?ooo`00FP3oool00`3o
0000oooo0?ooo`050?ooo`80o`000`3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool20000
o`D0oooo00<0o`000?ooo`3oool02P3oool010000?l0oooo0?ooo`3oool4
0?l000<0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`08
0?ooo`040?l0003oool0oooo0?ooo`@0o`000P3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00`0oooo00@0
003o0?ooo`3oool0oooo0P3o00070?ooo`030?l0003oool0oooo04H0oooo
00<0003o0?ooo`3oool00P3oool20000o`/0oooo00@000000?l0003oool0
o`003@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo01@0
oooo00<0003o0?ooo`3oool00`3oool20?l002H0oooo00<0o`000?ooo`3o
ool0;@3oool00`000?l0oooo0?ooo`1`0?ooo`00FP3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
303oool01@3o0000oooo0?ooo`3oool0003o00/0oooo00D0003o0?ooo`3o
ool0oooo0?l0000=0?ooo`030000o`3oool0oooo00D0oooo103o00090?oo
o`030000o`3oool0oooo00P0oooo00@0o`000?ooo`3o0000o`001`3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo04L0oooo00@0003o0?ooo`3oool0003o3@3o
ool010000000oooo0?l0003o000<0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo02L0oooo00<0o`000?ooo`3oool0:`3oool00`000?l0oooo
0?ooo`1a0?ooo`00F`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0303oool00`3o0000003o0000
o`0=0?ooo`040000o`3oool0oooo0?l000d0oooo00<0003o0?ooo`3oool0
203oool40?l000H0oooo00<0003o0?ooo`3oool01@3oool50?l000T0oooo
00<0003o0?ooo`3oool02`3oool0103o0000oooo0000o`000?l=0?ooo`80
003o00<0oooo0?l0003oool03@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0B@3oool20000o`h0
oooo00@000000?ooo`3o0000oooo0P3o000:0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool05@3oool010000?l0oooo0?l0003o000[
0?ooo`030?l0003oool0oooo02T0oooo00<0003o0?ooo`3oool0LP3oool0
05/0oooo00<0o`000?ooo`3oool00P3o00090?ooo`030000o`3oool0oooo
00`0oooo00<0003o0?l0003oool03P3oool00`000?l0o`000?ooo`0<0?oo
o`030000o`3oool0oooo00T0oooo00@0o`000?ooo`3oool0oooo1P3o0000
0`000?l0o`000?l000050?l000<0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l000000?l0oooo00l0oooo00<0003o
0?l0003oool03@3oool00`000?l0oooo0?ooo`070?ooo`80o`0000<0oooo
0?l0003oool0B`3oool00`000?l0oooo0?ooo`0=0?ooo`030000003o0000
oooo00<0oooo0`3o00070?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool0503oool00`000?l0o`000?ooo`0]0?ooo`030?l0003oool0
oooo02L0oooo00<0003o0?ooo`3oool0L`3oool005`0oooo0P3o000<0?oo
o`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3o00003`3oool00`3o
0000003o0?ooo`0;0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool02@3oool20000o`030?l0003oool0oooo
00h0oooo00<0o`000000o`3oool0303oool00`000?l0oooo0?ooo`0:0?oo
o`80o`00C@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00H0oooo0P3o00040?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool0403oool40?l000030?ooo`000?l0oooo02h0oooo00<0o`000?oo
o`3oool09P3oool00`000?l0oooo0?ooo`1c0?ooo`00G@3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00T0oooo00D0003o0?ooo`3o
ool0oooo0?l0000=0?ooo`030?l0003oool0oooo0080003o2@3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00L0oooo0P000?l20?ooo`030?l0003oool0oooo00d0oooo00@0o`000?oo
o`3oool0003o2`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo04d0oooo00<0003o0?ooo`3oool02P3oool00`3o000000000?ooo`09
0?ooo`@0o`0000<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0>
0?ooo`80o`001@3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0
oooo02@0oooo00<0003o0?ooo`3oool0M03oool005h0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?oo
o`80003o1`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0:0?ooo`80o`00103oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0C@3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0000000h0oooo00@0003o0?l0
003o0000o`003P3oool00`3o0000oooo0?ooo`0<0?ooo`80o`001`3oool0
0`000?l0oooo0?ooo`0_0?ooo`030?l0003oool0oooo0280oooo00<0003o
0?ooo`3oool0M@3oool005h0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`050?ooo`80003o1`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo00H0oooo0P000?l40?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool00`3oool20000
o`L0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`050?oo
o`80003o1P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
04l0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0000000=0?oo
o`030000o`3oool0oooo0080oooo0P3o000<0?ooo`030?l0003oool0oooo
00T0oooo0`3o000:0?ooo`030000o`3oool0oooo02l0oooo00<0o`000?oo
o`3oool0803oool00`000?l0oooo0?ooo`1f0?ooo`00G`3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00P0
oooo0P000?l20?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool00P000?l:0?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0D@3oool00`000?l0
oooo0?ooo`060?ooo`040?l0003oool0oooo000000d0oooo00<0003o0?oo
o`3oool0103ooolH0?l000d0oooo00<0003o0?ooo`3oool0<03oool00`3o
0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo07H0oooo001P0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`090?ooo`80o`001@3oool00`3o0000oooo0?ooo`0;0?ooo`80
003o3@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02P3oool30000o``0oooo00<0o`000?ooo`3o
ool0103oool20?l000/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo0580oooo00<0003o0?ooo`3o
ool0103oool01@3o0000oooo0?ooo`3oool0000000d0oooo00<0003o0?oo
o`3oool0403oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo
0340oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`1g0?oo
o`00H@3oool00`3o0000oooo0?ooo`0;0?ooo`040000o`3oool0oooo0000
o`h0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?oo
o`@0003o2P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool0203oool40000o`h0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`040000o`3oool0oooo
0000o`h0oooo00<0o`000?ooo`3oool0D`3oool00`000?l0oooo0?ooo`04
0?ooo`050?l0003oool0oooo0?ooo`0000003@3oool00`000?l0oooo0?oo
o`0@0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool0<@3o
ool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo07P0oooo001R
0?ooo`030?l0003oool0oooo00/0oooo0P000?l@0?ooo`040?l0003oool0
oooo0?l000h0oooo00<0003o0?ooo`3oool00P3oool50000o`@0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo0080oooo1@000?l30?ooo`030000o`3oool0oooo00`0oooo00D0
o`000?ooo`3oool0oooo0?l0000@0?ooo`80003o3P3oool00`3o0000oooo
0?ooo`1E0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0b0?ooo`030?l0
003oool0oooo01T0oooo00<0003o0?ooo`3oool0N@3oool006<0oooo00<0
o`000?ooo`3oool02@3oool40000oa00oooo0`3o000>0?ooo`030000o`3o
ool0oooo00L0oooo10000?l00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`000?l00P000?l90?ooo`030000o`3o
ool0oooo00`0oooo0`3o000A0?ooo`<0003o303oool00`3o0000oooo0?oo
o`1G0?ooo`040000o`3oool0o`000?l000D0oooo00<000000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo01P0oooo
00<0003o0?ooo`3oool0<P3oool00`3o0000oooo0?ooo`0H0?ooo`030000
o`3oool0oooo07T0oooo001S0?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0>0?ooo`80o`003@3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l000000?l0003o00T0oooo00<0
003o0?ooo`3oool0203oool20000o`030?l000000?l0oooo00/0oooo00<0
003o0?ooo`3oool0303oool20?l00140oooo00@0003o0?ooo`3oool0003o
2`3oool00`3o0000oooo0?ooo`1I0?ooo`030?l0003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0
003oool0oooo01P0oooo00<0003o0?ooo`3oool0<`3oool00`3o0000oooo
0?ooo`0F0?ooo`030000o`3oool0oooo07X0oooo001T0?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo0080o`002`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo01@0003o0P3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00/0oooo00@0o`000?ooo`3oool0o`00
3P3oool20000o`@0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`1K0?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo01T0oooo
00<0003o0?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0D0?ooo`030000
o`3oool0oooo07/0oooo001U0?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00<0oooo0P3o00090?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool20?l000<0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0G03oool00`000?l0oooo0?oo
o`040?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool04`3o
ool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo03<0oooo00<0
o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`1l0?ooo`00IP3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`050?ooo`80o`001`3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00H0oooo0P3o00060?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo05d0oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`08
0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool06@3oool0
0`000?l0oooo0?ooo`0d0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool0O@3oool006L0oooo00D0o`000?ooo`3oool0oooo0000o`0;
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool2
0?l000D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`040?ooo`80o`00203oool00`3o0000oooo0?ooo`07
0?ooo`80003o2`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo05l0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`07
0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool06P3oool0
0`000?l0oooo0?ooo`0d0?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool0OP3oool006P0oooo00<0o`000?ooo`000?l03@3oool20000
o`L0oooo00<0o`000?ooo`3oool02P3oool20?l00080oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool02`3oool010000?l0oooo0?ooo`3oool3
0?l000/0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0<
0?ooo`040000o`3oool0oooo0?l006<0oooo00D0003o0?ooo`3oool0oooo
000000090?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0
6P3oool00`000?l0oooo0?ooo`0e0?ooo`030?l0003oool0oooo00h0oooo
00<0003o0?ooo`3oool0OP3oool006T0oooo00<0003o0?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00d0oooo0P3o
00000`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
0000o`0000l0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0>0?ooo`030000o`3o0000oooo06@0oooo00@0003o0?ooo`3oool00000
203oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo01X0oooo
00<0003o0?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo07l0oooo001Z0?ooo`030?l0003oool0oooo00h0oooo00D0
003o0?ooo`3oool0oooo0?l0000A0?ooo`040000o`3o0000o`000?l000/0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00T0oooo0P3o00000`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo0080003o4@3oool00`3o0000oooo0?ooo`1U0?ooo`03
0000o`3oool0000000P0oooo00<0003o0?ooo`3oool0503oool00`3o0000
oooo0?ooo`0K0?ooo`030000o`3oool0oooo03H0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`200?ooo`00J`3oool00`3o0000oooo
0?ooo`0>0?ooo`80003o00<0o`000?ooo`3oool0403oool010000?l0oooo
0?ooo`3oool20?l000T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00L0oooo0P3o00030?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`000?l04P3oool00`3o0000
oooo0?ooo`1W0?ooo`030000o`000000oooo00H0oooo00<0003o0?ooo`3o
ool05@3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo03H0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`210?ooo`00
K03oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool0103oool40?l000D0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00<0oooo
103o00050?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0
3`3oool20?l006/0oooo0P000?l50?ooo`030000o`3oool0oooo01H0oooo
00<0o`000?ooo`3oool0703oool00`000?l0oooo0?ooo`0g0?ooo`030?l0
003oool0oooo00H0oooo0P000?n40?ooo`00K@3oool00`3o0000oooo0?oo
o`0=0?ooo`030?l0003oool0003o0100oooo00<0003o0?ooo`3oool0203o
ool60?l000d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`030?l000X0oooo00<0003o0?ooo`3oool03@3oool20000o`030?l0003o
ool0oooo00h0oooo00<0o`000?ooo`3oool0J`3oool00`000000oooo0000
o`040?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool0703o
ool00`000?l0oooo0?ooo`0h0?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0Q03oool006h0oooo00<0o`000?ooo`3oool0303oool0
0`3o0000oooo0?ooo`020000o`d0oooo00<0003o0?ooo`3oool03@3oool4
0?l000/0oooo00<0003o0?ooo`3oool02P3oool50?l000d0oooo00<0003o
0?ooo`3oool0303oool01@000?l0oooo0?ooo`3oool0o`0000h0oooo00<0
o`000?ooo`3oool0K03oool010000000oooo0?ooo`000?l20?ooo`030000
o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0703oool00`000?l0oooo
0?ooo`0i0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
Q@3oool006l0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?oo
o`030?ooo`80003o2`3oool00`000?l0oooo0?ooo`0=0?ooo`040?l0003o
ool0oooo0?ooo`/0o`0000<0003o0?l0003o00002P3o00030?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool02@3oool20000o`D0oooo
00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`1]0?ooo`070000
003oool0oooo0?ooo`000?l0oooo0000o`0I0?ooo`030?l0003oool0oooo
01`0oooo00<0003o0?ooo`3oool0>@3oool01@3o0000oooo0?ooo`3oool0
003o08P0oooo001`0?ooo`80o`002@3oool00`3o0000oooo0?ooo`060?oo
o`80003o203oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00L0oooo0P000?l80?ooo`030?l0003oool0oooo
00L0oooo0P3o001`0?ooo`030000003oool0oooo0080oooo00<0003o0?oo
o`3oool05`3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo
03X0oooo00<0o`000?ooo`000?l0R@3oool00780oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`090?ooo`80003o1P3oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00@0
oooo0P000?l;0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3o
ool0L03oool00`000000oooo0?ooo`030?ooo`80003o5`3oool00`3o0000
oooo0?ooo`0N0?ooo`030000o`3oool0oooo03T0oooo00<0003o0?l0003o
ool0R@3oool007<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0;0?ooo`80003o103oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo0080oooo0P000?l=0?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool0L@3oool00`000000oooo
0?ooo`050?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0
7P3oool00`000?l0oooo0?ooo`0h0?ooo`030000o`3oool0oooo08X0oooo
001d0?ooo`80o`000`3oool00`3o0000oooo0?ooo`0>0?ooo`80003o00<0
oooo0000o`3oool03`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool03`3oool010000?l0oooo0000
o`000?l@0?ooo`040?l0003oool0oooo0?ooo`80o`00K@3oool500000080
oooo00<000000?ooo`3oool01P3oool20000oa<0oooo00<0o`000?ooo`3o
ool07`3oool00`000?l0oooo0?ooo`0g0?ooo`030000o`3oool0oooo08/0
oooo001f0?ooo`040?l0003oool0oooo0?l00180oooo0P000?l@0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0>0?ooo`80003o4P3oool0103o0000oooo0?ooo`3o001a0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?oo
o`3oool0=@3oool20000ohh0oooo001g0?ooo`80o`004`3oool00`000?l0
oooo0000o`020000o`d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00/0oooo10000?lD0?ooo`80
o`00LP3oool00`000000oooo0?ooo`020?ooo`<000002@3oool20000oa00
oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0d0?ooo`03
0000o`3oool0oooo08h0oooo001i0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool00P3oool30000o`X0oooo00<0o`000?ooo`3oool0
1`3oool2000000@0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`090?ooo`80003o103oool00`000?l0oooo0?ooo`0@0?ooo`80o`00
L`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0P0?ooo`030000
o`3oool0oooo0340oooo0P000?nA0?ooo`00NP3oool20?l000l0oooo00<0
003o0?ooo`3oool01P3oool40000o`H0oooo00<0o`000?ooo`3oool01P3o
ool010000000oooo0?ooo`0000030?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool01@3oool40000o`H0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0303oool20000o``0oooo00<0o`000?ooo`3oool0
8@3oool00`000?l0oooo0?ooo`0`0?ooo`030000o`3oool0oooo0940oooo
001l0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02P3o
ool50000o`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool00P3o
ool00`000?l000000000000>0?ooo`030?l0003oool0oooo00D0003o2`3o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo07<0oooo0P00
00040?ooo`030000003oool0oooo00h0oooo0P000?l:0?ooo`030?l0003o
ool0oooo0240oooo00<0003o0?ooo`3oool0;P3oool20000oi@0oooo001m
0?ooo`80o`002`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l000000?l0
oooo00X0oooo00D000000?ooo`3oool0oooo0000o`0@0?ooo`030?l00000
0?l0003o0100oooo00<0003o0?ooo`3oool02`3oool20?l007`0oooo00<0
00000?ooo`3oool0403oool20000o`P0oooo00<0o`000?ooo`3oool08@3o
ool00`000?l0oooo0?ooo`0/0?ooo`80003oUP3oool007l0oooo0P3o0009
0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`000?l01`000?l0
10000000oooo0?ooo`0000030?ooo`030000o`3oool0oooo00D0oooo2@00
0?l00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool0O03oool00`000000oooo0?ooo`0B0?ooo`80003o1@3o
ool00`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo02T0oooo0P00
0?nH0?ooo`00P@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool01`3oool?0000o`X0oooo00<0o`00
0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`80o`00O`3oool0
0`000000oooo0?ooo`0D0?ooo`80003o0`3oool00`3o0000oooo0?ooo`0S
0?ooo`030000o`3oool0oooo02L0oooo0P000?nJ0?ooo`00PP3oool20?l0
00D0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0>0?oo
o`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`050?ooo`80o`00P@3oool00`000000oooo0?ooo`0F0?oo
o`80003o00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`0U0?oo
o`80003oW03oool008@0oooo0P3o00030?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool00P3oool30?l008<0
oooo00<000000?ooo`3oool0603oool00`3o0000003o0000o`0T0?ooo`03
0000o`3oool0oooo02<0oooo0P000?nN0?ooo`00QP3oool30?l000030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0003oool0oooo0140oooo00@0003o0?l0003o0000
o`00QP3oool00`000000oooo0?ooo`0K0?ooo`80003o8P3oool00`000?l0
oooo0?ooo`0P0?ooo`<0003oX03oool008T0oooo00<0003o0?l0003o0000
403oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0100oooo
00<0o`000?ooo`3oool03P3oool20?l000030000o`3oool0oooo08L0oooo
00<000000?ooo`3oool07@3oool30000oal0oooo00<0003o0?ooo`3oool0
7@3oool30000oj<0oooo002<0?ooo`80o`003P3oool00`3o0000oooo0?oo
o`0?0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0303o
ool20?l008`0oooo00<000000?ooo`3oool0803oool20000oad0oooo00<0
003o0?ooo`3oool06P3oool30000ojH0oooo002>0?ooo`80o`00303oool0
0`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0100oooo00<0o`00
0?ooo`3oool02P3oool20?l008h0oooo00<000000?ooo`3oool08P3oool4
0000oaT0oooo00<0003o0?ooo`3oool05P3oool40000ojT0oooo002@0?oo
o`D0o`001`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
0100oooo00<0o`000?ooo`3oool01@3oool50?l00900oooo00<000000?oo
o`3oool09P3oool50000oa@0oooo00<0003o0?ooo`3oool04@3oool50000
ojd0oooo002E0?ooo`D0o`0000<0oooo0?l0003oool04@3oool00`000?l0
oooo0?ooo`0@0?ooo`030?l0003oool0oooo00D0o`00U@3oool00`000000
oooo0?ooo`0[0?ooo`<0003o4@3oool00`000?l0oooo0?ooo`0=0?ooo`@0
003o/P3oool009X0oooo0`3o000A0?ooo`030000o`3oool0oooo0100oooo
0`3o002J0?ooo`030000003oool0oooo02h0oooo2@000?l80?ooo`030000
o`3oool0oooo00H0oooo1`000?nf0?ooo`00W@3oool60?l000/0oooo00<0
003o0?ooo`3oool02P3oool60?l009d0oooo00<000000?ooo`3oool0=`3o
oolA0000okd0oooo002S0?ooo`/0o`0000<0003o0?l0003o00002P3o002S
0?ooo`030000003oool0oooo0?l0oooo1P3oool00:h0oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`3o0?ooo`H0oooo002^0?ooo`03
0000003oool0oooo0:d0oooo00<000000?ooo`3oool0o`3oool60?ooo`00
[P3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0?l0oooo
1P3oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo0?ooofP0oooo003o0?oo
ool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo0?ooofP0oooo
003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00[03oool20000
0?l0oooo^@3oool00:d0oooo00<000000?ooo`3oool0o`3ooong0?ooo`00
[P3oool00`000000oooo0?ooo`2]0?ooo`800000o`3oool70?ooo`00[@3o
ool00`000000oooo0000002^0?ooo`800000o`3oool70?ooo`00[03oool0
10000000oooo0?ooo`00002]0?ooo`040000003oool0oooo00000?l0oooo
1P3oool00:/0oooo0`0000000`3oool000000000002[0?ooo`8000000P3o
ool200000?l0oooo1@3oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo0?oo
ofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{614, 250},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot the images of the disk   ",
  Cell[BoxData[
      \(\(\(3\/2\)\(\[LessEqual]\)\) | z | \(\(\[LessEqual]\)\(7\/2\)\)\)]],
  "  under the mappings  ",
  Cell[BoxData[
      \(\(S\_n\) \((z)\) = \[Sum]\+\(k = 1\)\%n z\^\(-n\)\)]],
  ".  \n\nHence we can view how the complex geometric series converges to its \
limit function ",
  Cell[BoxData[
      \(f \((z)\) = 1\/\(z - 1\)\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[g, k, m, n, s];\)\ \), "\[IndentingNewLine]", 
    \(\(s[z_, 
          n_] = \[Sum]\+\(k = 1\)\%n z\^\(-k\);\)\ \), "\[IndentingNewLine]", \

    \(\(f[z_] = 1\/\(z - 1\);\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(For\ [m = 1, 
        m \[LessEqual] 10, \(m++\), \[IndentingNewLine]g[z_] = 
          s[z, m]; \ \[IndentingNewLine]PolarMap[
          g\ , {1.5, 3.5, 0.4}, {0, 
            2  \[Pi], \[Pi]\/16}, \[IndentingNewLine]PlotRange \[Rule] \
{{\(-0.7\), 2.0}, {\(-1.35\), 1.35}}, 
          AspectRatio \[Rule] 
            2.7\/2.7, \[IndentingNewLine]Ticks \[Rule] {{1\/4, 1, 3\/2, 
                2}, {\(-1\), 1\/8, 1}}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          AxesOrigin \[Rule] {0, 
              0}]; \[IndentingNewLine]Print["\<w = \>", "\<S\>"\_m, "\<(z) = \
\>", Apart[s[z, m]]\ ];\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        f, {1.5, 3.5, 0.4}, {0, 
          2  \[Pi], \[Pi]\/16}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.7\
\), 2.0}, {\(-1.35\), 1.35}}, 
        AspectRatio \[Rule] 
          2.7\/2.7, \[IndentingNewLine]Ticks \[Rule] {{1\/4, 1, 3\/2, 
              2}, {\(-1\), 1\/8, 1}}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Red}, 
        AxesOrigin \[Rule] {0, 0}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<w = f(z) = \>", f[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Corollary 4.3. ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  " If  ",
  Cell[BoxData[
      \(z \[NotEqual] 1\)]],
  ",  then for all ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ",  \n\n\t\t\t",
  Cell[BoxData[
      \(1\/\(1\  - \ z\)\  = \ \(1 + z + z\^2 +  ... \) + z\^\(n - 1\) + 
          z\^n\/\(1\  - \ z\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 4.3 is mentioned in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "We can explore the situation for  ",
  Cell[BoxData[
      \(n = 1, 2,  ... , 10\)]],
  ". "
}], "Text"],

Cell[BoxData[
    \(\(For[m = 1, 
        m \[LessEqual] 
          10, \(m++\), \[IndentingNewLine]Print[\*"\"\<\!\(\[Sum]\+\(k = \
0\)\)\>\""\&\(m - 1\), \*"\"\<\!\(z\^k\) + \>\"", 
          z\^m\/\(1\  - \ z\), "\< = \>", \[Sum]\+\(k = 0\)\%\(m - 1\)z\^k, "\
\< + \>", 
          z\^m\/\(1\  - \ z\)]; \[IndentingNewLine]Print["\<             = \
\>", Together[
            Together[\[Sum]\+\(k = 0\)\%\(m - 1\)z\^k + \ 
                z\^m\/\(1\  - \ z\)]]];\ ];\)\)], "Input"],

Cell["In general we have.", "Text"],

Cell[BoxData[{
    \(\(Clear[n];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = 0\)\%\(n - \
1\)\)\!\(z\^k\)+\!\(z\^n\/\(1\\\  - \\\ z\)\) = \>\"", \[Sum]\+\(k = 0\)\%\(n \
- 1\)z\^k + z\^n\/\(1\  - \ z\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = 0\)\%\(n - \
1\)\)\!\(z\^k\)+\!\(z\^n\/\(1\\\  - \\\ z\)\) = \>\"", 
        Simplify[\[Sum]\+\(k = 0\)\%\(n - 1\)z\^k + 
            z\^n\/\(1\  - \ z\)]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.13.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\((1\  - \ \[ImaginaryI])\)\^n\/2\^n\  \
= \ 1 - \[ImaginaryI]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Solution.  If we set  ",
  Cell[BoxData[
      \(z = \(1 - \[ImaginaryI]\)\/2\)]],
  ",  then  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\)\  = \ \(\(\(|\)\(\(1 - \
\[ImaginaryI]\)\/2\)\(|\)\)\  = \ \@2\/2\  < \ 1\)\)]],
  ".  By Theorem 4.12, the sum is  \n\n\t\t\t",
  Cell[BoxData[
      \(1/\((1 - \(1 - \[ImaginaryI]\)\/2)\)\  = \ \(2\/\(2 - 1 + \
\[ImaginaryI]\)\  = \ \(2\/\(1 + \[ImaginaryI]\)\  = \ 
            1 - \[ImaginaryI]\)\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
We can use the definition of convergence of a series and find the limit of \
the partial sums.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{\(Remove[S, z];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Clear[k, lim, n, sum, Z];\), " "}], "\n", 
    RowBox[{\(z\_k_\  = \ \((1\  - \ \[ImaginaryI])\)\^k\/2\^k;\), 
      " "}], "\n", 
    RowBox[{
      RowBox[{\(S\_n_\  = \[Sum]\+\(k = 0\)\%n\((1 - \
\[ImaginaryI])\)\^k\/2\^k\), 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{
      RowBox[{\(sum\  = \[Sum]\+\(k = 0\)\%\[Infinity]\((1 - \[ImaginaryI])\)\
\^k\/2\^k\), 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"lim", " ", "=", " ", 
          RowBox[{"Limit", "[", 
            RowBox[{\(S\_n\), ",", 
              RowBox[{"n", 
                StyleBox["\[Rule]",
                  FontWeight->"Plain"], 
                StyleBox["\[Infinity]",
                  FontWeight->"Plain"]}]}], "]"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(z\_k\) = \>\"", z\_k];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(S\_n\) = \!\(\[Sum]\+\(k = 0\)\%n\)\!\(\((1 - \
\[ImaginaryI])\)\^k\/2\^k\) = \>\"", S\_n];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", \
\*"\"\<\!\(S\_n\) = \>\"", lim];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(\((1 - \
\[ImaginaryI])\)\^k\/2\^k\) = \>\"", sum];\), " "}]}], "Input"],

Cell[TextData[{
  "Or we can see that this is an infinite geometric series with ratio  ",
  Cell[BoxData[
      \(Z = 1\/2 - \[ImaginaryI]\/2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Z\  = \ z\_\(k + 1\)\/z\_k;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(z\_k\) = \>\"", z\_k];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_\(k + 1\)\) = \>\"", z\_\(k + 1\)];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<  Z = \!\(z\_\(k + 1\)\/z\_k\) = \>\"", 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["The sum of the infinite geometric series is now found.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<          Z = \>", Z];\)\ \), "\n", 
    \(\(Print["\<        |Z| = \>", Abs[Z]];\)\ \), "\n", 
    \(\(Print["\<     Is |Z| < 1 ?  \>", Abs[Z] < \ 1];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<      \!\(1\/\(1 - Z\)\) = \!\(1\/\(1 - \((1\/2 - \
\[ImaginaryI]\/2)\)\)\)\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<      \!\(1\/\(1 - Z\)\) = \>\"", \ 
        1\/\(1 - \((1\/2 - \(\(\ \)\(\[ImaginaryI]\)\)\/2)\)\)];\)\ \), "\n", \

    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(\((1 - \
\[ImaginaryI])\)\^k\/2\^k\) = \>\"", \[Sum]\+\(k = 0\)\%\[Infinity]\((1 - \
\[ImaginaryI])\)\^k\/2\^k];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The series of absolute values converges, therefore the series converges.\n\
\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\(S\_n_\  = \ \[Sum]\+\(k = 0\)\%n\((1 - \[ImaginaryI])\)\^k\/2\^k;\)\ \
\), "\[IndentingNewLine]", 
    \(\(table = 
        Table[FullSimplify[S\_n], {n, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(\((1 - \
\[ImaginaryI])\)\^k\/2\^k\) = \>\"", \[Sum]\+\(k = 0\)\%\[Infinity]\((1 - \
\[ImaginaryI])\)\^k\/2\^k];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\(set\  = \ \ Table[{Re[S\_n], Im[S\_n]}, {n, 0, 
            15}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{PointSize[0.021], Red, 
            Point[{1, \(-1\)}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(graph = 
        ListPlot[set, 
          Prolog \[Rule] {PointSize[0.021], 
              Blue}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
                1.55}, {\(-1.3\), 
                0.0}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", \
"\<y\>"}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 1.6, 0.2], 
              Range[\(-1.4\), 0, 0.2]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph, dot, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(\((1 - \
\[ImaginaryI])\)\^k\/2\^k\) = \>\"", sum];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the sum of the infinite geometric series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\((1\  - \ \
\[ImaginaryI])\)\^n\/2\^n\ \ \ is\ \ \ 1 - \[ImaginaryI]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.14.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Evaluate  ",
  Cell[BoxData[
      StyleBox[\(\[Sum]\+\(n = 3\)\%\[Infinity]\(\(\ \)\(\[ImaginaryI]\^n\)\)\
\/2\^n\),
        FontSize->14]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We can put this expression in the form of a geometric series:  \
\n\t\t\t\n\t\t\t",
  Cell[BoxData[{
      \(\[Sum]\+\(n = 3\)\%\[Infinity] \[ImaginaryI]\^n\/2\^n\ \  = \ \ \(\
\[Sum]\+\(n = 3\)\%\[Infinity]\((\[ImaginaryI]\/2)\)\^n\ \  = \ \ \ \
\[Sum]\+\(n = 3\)\%\[Infinity]\(\((\[ImaginaryI]\/2)\)\^3\) \
\((\[ImaginaryI]\/2)\)\^\(n - 3\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\((\[ImaginaryI]\
\/2)\)\^3\ \(\[Sum]\+\(n = 3\)\%\[Infinity]\((\[ImaginaryI]\/2)\)\^\(n - \
3\)\)\ \  = \ \ \((\[ImaginaryI]\/2)\)\^3\ 1\/\(1 - \[ImaginaryI]\/2\)\)\)\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(-\(\
\[ImaginaryI]\/8\)\) 
            1\/\(1 - \[ImaginaryI]\/2\)\ \  = \ \ \(-\[ImaginaryI]\)\/\(8 - 4 \
 \[ImaginaryI]\)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(-\[ImaginaryI]\
\)\/\(8 - 4  \[ImaginaryI]\)\ \(8 + 4  \[ImaginaryI]\)\/\(8 + 4  \
\[ImaginaryI]\)\ \  = \ \ \(4 - 8\ \[ImaginaryI]\)\/80\)\)\ \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(1\/20\)\(-\)\(\
\[ImaginaryI]\/10\)\(\ \)\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
We can use the definition of convergence of a series and find the limit of \
the partial sums.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{\(Remove[S, z];\), " "}], "\n", 
    RowBox[{\(Clear[k, lim, n, sum, Z];\), " "}], "\n", 
    RowBox[{\(z\_k_\  = \(\(\ \)\(\[ImaginaryI]\^k\)\)\/2\^k;\), " "}], "\n", 
  
    RowBox[{
      RowBox[{
        RowBox[{\(S\_n_\), " ", "=", " ", 
          StyleBox[\(\[Sum]\+\(k = 3\)\%\[Infinity] \[ImaginaryI]\^k\/2\^k\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"sum", " ", "=", " ", 
          
          StyleBox[\(\[Sum]\+\(k = 3\)\%\[Infinity]\(\(\ \)\(\[ImaginaryI]\^k\
\)\)\/2\^k\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"lim", " ", "=", " ", 
          RowBox[{"Limit", "[", 
            RowBox[{\(S\_n\), ",", 
              RowBox[{"n", 
                StyleBox["\[Rule]",
                  FontWeight->"Plain"], 
                StyleBox["\[Infinity]",
                  FontWeight->"Plain"]}]}], "]"}]}], ";"}], " "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(z\_k\) = \>\"", z\_k];\), " "}], "\n", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(S\_n\) = \!\(\[Sum]\+\(k = 3\)\%n\)\!\(\
\[ImaginaryI]\^k\/2\^k\) = \>\"", S\_n];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<      \!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", \
\*"\"\<\!\(S\_n\) = \>\"", lim];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<     \!\(\[Sum]\+\(k = 3\)\%\[Infinity]\)\!\(\
\[ImaginaryI]\^k\/2\^k\) = \>\"", sum];\), " "}]}], "Input"],

Cell[TextData[{
  "Or we can see that this is an infinite geometric series with ratio  ",
  Cell[BoxData[
      \(Z = \[ImaginaryI]\/2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Z\  = \ z\_\(k + 1\)\/z\_k;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(z\_k\) = \>\"", z\_k];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_\(k + 1\)\) = \>\"", z\_\(k + 1\)];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<  Z = \!\(z\_\(k + 1\)\/z\_k\) = \>\"", 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["The sum of the infinite geometric series is now found.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{\(a\  = \ z\_3;\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<        a = (\!\(\[ImaginaryI]\/2\)\!\(\()\^3\)\) \
= \>\"", a];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print["\<        Z = \>", Z];\), " "}], "\n", 
    RowBox[{\(Print["\<      |Z| = \>", Abs[Z]];\), " "}], "\n", 
    RowBox[{\(Print["\<   Is |Z| < 1 ?  \>", Abs[Z] < \ 1];\), " "}], "\n", 
    RowBox[{\(Print["\< \>"];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<     \!\(a\/\(1 - Z\)\) = \!\(\((\[ImaginaryI]\/2)\
\)\^3\/\(1 - \[ImaginaryI]\/2\)\)\>\""];\), " "}], "\n", 
    RowBox[{\(Print[\*"\"\<     \!\(a\/\(1 - Z\)\) = \>\"", a\/\(1 - Z\)];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<    \!\(\[Sum]\+\(k = \
3\)\%\[Infinity]\)\!\(\[ImaginaryI]\^k\/2\^k\) = \>\"", ",", 
            
            StyleBox[\(\[Sum]\+\(k = 3\)\%\[Infinity] \
\[ImaginaryI]\^k\/2\^k\),
              FontSize->14]}], "]"}], ";"}], " "}]}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(S\_n_\), " ", "=", " ", 
          StyleBox[\(\[Sum]\+\(k = 3\)\%n \[ImaginaryI]\^k\/2\^k\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\[IndentingNewLine]", 
    RowBox[{\(table = Table[FullSimplify[S\_n], {n, 0, 10}];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(table = Append[table, "\<...\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", table];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", N[table]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(\[Sum]\+\(k = 3\)\%\[Infinity]\)\!\(\[ImaginaryI]\^k\/2\^k\
\) = \>\"", ",", 
            StyleBox["sum",
              FontSize->14]}], "]"}], ";"}], " "}]}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(set\  = \ \ Table[{Re[S\_n], Im[S\_n]}, {n, 0, 10}];\), 
      " "}], "\[IndentingNewLine]", \(Needs["\<Graphics`Colors`\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{\(dot = 
          Graphics[{PointSize[0.023], Red, 
              Point[{1\/20, \(-\(1\/10\)\)}]}];\), 
      " "}], "\[IndentingNewLine]", \(graph = 
        ListPlot[set, 
          Prolog \[Rule] {PointSize[0.023], 
              Blue}, \[IndentingNewLine]PlotRange \[Rule] 
            All, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 0.5, 0.1], 
              Range[\(-0.5\), 0, 0.1]}, 
          DisplayFunction \[Rule] Identity];\), "\[IndentingNewLine]", \(Show[
        graph, dot, 
        DisplayFunction \[Rule] $DisplayFunction];\), "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", N[table]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(\[Sum]\+\(k = 3\)\%\[Infinity]\)\!\(\[ImaginaryI]\^k\/2\^k\
\) = \>\"", ",", 
            StyleBox["sum",
              FontSize->14]}], "]"}], ";"}], " "}]}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the sum of the infinite geometric series  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Sum]\+\(n = 3\)\%\[Infinity]\),
            FontSize->14], 
          RowBox[{
            StyleBox[\(\(\(\ \)\(\[ImaginaryI]\^n\)\)\/2\^n\),
              FontSize->14], 
            StyleBox["  ",
              FontSize->14], 
            StyleBox["is",
              FontSize->14], 
            StyleBox["  ",
              FontSize->14], \(1\/20\)}]}], "-", \(\[ImaginaryI]\/10\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark 4.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The equality given in Example 4.14 illustrates an important point when \
evaluating a geometric series whose beginning index is other than zero. The \
value of ",
  Cell[BoxData[
      \(\[Sum]\+\(n = r\)\%\[Infinity] z\^n\)]],
  " equals",
  Cell[BoxData[
      \(z\^r\/\(1\  - \ z\)\)]],
  ". If we think of z as the \"ratio'' by which a given term of the series is \
multiplied to generate successive terms, we see that the sum of a geometric \
series equals ",
  Cell[BoxData[
      \(\(first\ term\)\/\(1\  - \ ratio\)\)]],
  ", provided  ",
  Cell[BoxData[
      \(\(\(|\)\(ratio\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ".  "
}], "Text"],

Cell["\<\
\tThe geometric series is used in the proof of Theorem 4.12, which is known \
as the ratio test. It is one of the most commonly used tests for determining \
the convergence or divergence of series.  The proof is similar to the one \
used for real series, and we leave it for you to do.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 4.13 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["d'Alembert's Ratio Test",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RatioTest.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity] \[Zeta]\_n\)]],
  "  is a complex series with the property that  \n\n\t\t\t",
  Cell[BoxData[
      \(lim\+\(n\  \[Rule] \ \[Infinity]\)\ \(\(|\)\(\[Zeta]\_\(n + \
1\)\)\(|\)\)\/\(\(|\)\(\[Zeta]\_n\)\(|\)\) = L\)]],
  ",  \n\nthen the series converges absolutely if  ",
  Cell[BoxData[
      \(L < 1\)]],
  "  and diverges if  ",
  Cell[BoxData[
      \(L > 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.13 is left for the reader to do in \
the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.15.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\(\(\ \)\(\[Sum]\+\(n = 0\)\%\[Infinity]\((1\  - \ \
\[ImaginaryI])\)\^n\/\(n!\)\)\)\)]],
  "  converges."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  Using the ratio test, we find that  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(lim\+\(n\  \[Rule] \ \[Infinity]\)\ \(\(|\)\(\(\(\(\((1\  - \ \
\[ImaginaryI])\)\^\(n + 1\)\)\(\ \)\)\/\(\((n + 
                        1)\)!\)\)/\(\(\(\((1\  - \ \[ImaginaryI])\)\^n\)\(\ \
\)\)\/\(n!\)\)\)\(|\)\)\ \ \  = \ \ \ \(lim\+\(n\  \[Rule] \ \[Infinity]\)\ \
\(\(|\)\(\(\(n!\) \((1 - \[ImaginaryI])\)\(\ \)\)\/\(\((n + 
                      1)\)!\)\)\(|\)\)\[IndentingNewLine]\[IndentingNewLine]
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \ \)\(lim\+\(n\  \
\[Rule] \ \[Infinity]\)\ \(\(|\)\(\(\(n!\) \((1 - \[ImaginaryI])\)\(\ \
\)\)\/\(\((n + 1)\)!\)\)\(|\)\)\[IndentingNewLine]\[IndentingNewLine]
          \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \ \)\(lim\+\(n\  \
\[Rule] \ \[Infinity]\)\ \(\(n!\)\(|\)\(1 - \[ImaginaryI]\)\(|\)\(\ \
\)\)\/\(\((n + 1)\)!\)\)\)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \ \)\
\(lim\+\(n\  \[Rule] \ \[Infinity]\)\ \(\(n!\)\(|\)\(1 - \[ImaginaryI]\)\(|\)\
\(\ \)\)\/\(\((n + 1)\)!\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \ \)\
\(lim\+\(n\  \[Rule] \ \[Infinity]\)\ \(\(|\)\(1 - \[ImaginaryI]\)\(|\)\(\ \)\
\)\/\(n + 1\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \ \)\
\(lim\+\(n\  \[Rule] \ \[Infinity]\)\ \(\(\@2\)\(\ \)\)\/\(n + 1\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(\(0\)\(\ \ \)\(=\)\(\ \ \)\(L\)\(\ \)\)\)\)}]],
  "   \n\nBecause  ",
  Cell[BoxData[
      \(L < 1\)]],
  ",  the series converges."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.15.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the formula for the terms in the series.", "Text"],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[L, n, sum, r];\)\ \), "\n", 
    \(\(z\_n_\  = \ \(\(\((1\  - \ \[ImaginaryI])\)\^n\)\(\ \)\)\/\(n!\);\)\ \
\), "\n", 
    \(\(Print[\*"\"\<\!\(z\_n\) = \>\"", 
        z\_n];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
  Use d'Alembert's ratio test. First, find the ratio of consecutive terms.\
\>", "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<         \!\(z\_\(n + 1\)\) = \>\"", 
        z\_\(n + 1\)];\)\ \), "\n", 
    \(\(Print[\*"\"\<          \!\(z\_n\) = \>\"", z\_n];\)\ \), "\n", 
    \(\(r\  = \ z\_\(n + 1\)\/z\_n;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<        \!\(z\_\(n + 1\)\/z\_n\) = \>\"", 
        r];\)\ \), "\[IndentingNewLine]", 
    \(\(r\  = \ FullSimplify[r];\)\ \), "\n", 
    \(\(Print[\*"\"\<        \!\(z\_\(n + 1\)\/z\_n\) = \>\"", 
        r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<       |\!\(z\_\(n + 1\)\/z\_n\)| = \>\"", 
        Abs[Numerator[r]]\/Denominator[r]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(L\  = \ Limit[\ r\ , \ n \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(Print[\*"\"\<L = \!\(lim\+\(n \[Rule] \[Infinity]\)\) |\!\(z\_\(n + 1\
\)\/z\_n\)| = \>\"", L];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Since L < 1, the series converges.   \n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find the sum of series."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(sum\ \  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\((1 - \
\[ImaginaryI])\)\^n\/\(n!\);\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\((1 - \
\[ImaginaryI])\)\^n\/\(n!\)\) = \>\"", sum];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to construct some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\(S\_n_\  = \ \[Sum]\+\(k = 0\)\%n\((1 - \[ImaginaryI])\)\^k\/\(k!\);\)\
\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Table[FullSimplify[S\_n], {n, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\((1 - \
\[ImaginaryI])\)\^n\/\(n!\)\) = \>\"", sum];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the partial sums of the infinite series."
}], "Text"],

Cell[BoxData[{
    \(\(set\  = \ \ Table[{Re[S\_n], Im[S\_n]}, {n, 0, 
            10}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{PointSize[0.023], Red, 
            Point[{Re[sum], Im[sum]}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(graph = 
        ListPlot[set, 
          Prolog \[Rule] {PointSize[0.023], 
              Blue}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.05\), 
                2.35}, {\(-2.35\), 
                0.05}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", \
"\<y\>"}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2.5, 0.5], 
              Range[\(-2.5\), 0, 0.5]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph, dot, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(S\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\((1 - \
\[ImaginaryI])\)\^n\/\(n!\)\) = \>\"", sum];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the infinite series  ",
  Cell[BoxData[
      \(\(\(\ \)\(\[Sum]\+\(n = 0\)\%\[Infinity]\((1\  - \ \
\[ImaginaryI])\)\^n\/\(n!\)\)\)\)]],
  "  converges and that its sum is  ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(1 - \[ImaginaryI]\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.16.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\((z\  - \ \
\[ImaginaryI])\)\^n\/2\^n\)]],
  " converges for all  z  in the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z - \[ImaginaryI]\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  Using the ratio test, we find that  \n\n\t\t\t",
  Cell[BoxData[
      \(lim\+\(n\  \[Rule] \ \[Infinity]\)\ \(\(|\)\(\(\((z\  - \ \
\[ImaginaryI])\)\^\(n + 1\)\/2\^\(n + 1\)\)/\(\((z\  - \ \
\[ImaginaryI])\)\^n\/2\^n\)\)\(|\)\(\ \)\(\(\[Equal]\)\(\ \)\(lim\+\(n\  \
\[Rule] \ \[Infinity]\)\)\)\(\ \)\(|\)\(\(z - \[ImaginaryI]\)\/2\)\(|\)\(\ \)\
\(\(\[Equal]\)\(\ \)\(\(\(|\)\(z - \[ImaginaryI]\)\(|\)\)\/2\)\(\ \
\)\(\[Equal]\)\(\ \)\(L\)\)\)\)]],
  ".\n\nIf  ",
  Cell[BoxData[
      \(\(\(|\)\(z - \[ImaginaryI]\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  ",  then  ",
  Cell[BoxData[
      \(\(\(|\)\(z - \[ImaginaryI]\)\(|\)\)\/2\  = \ \ L\  < \ 1\)]],
  ",  and the series converges.  \n\nIf  ",
  Cell[BoxData[
      \(\(\(|\)\(z - \[ImaginaryI]\)\(|\)\(\(>\)\(\ \)\(2\)\)\)\)]],
  ",  then  ",
  Cell[BoxData[
      \(L > 1\)]],
  ",  and the series diverges."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.16.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the formula for the terms in the series.", "Text"],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[L, n, sum, r, Z];\)\ \), "\n", 
    \(\(z\_n_\  = \ \((z\  - \ \[ImaginaryI])\)\^n\/2\^n;\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_n\) = \>\"", 
        z\_n];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Use d'Alembert's ratio test. First, find the ratio of consecutive terms.\
\>", "Text"],

Cell[BoxData[{
    \(\(r\  = \ z\_\(n + 1\)\/z\_n;\)\ \), "\[IndentingNewLine]", 
    \(\(L\  = \ 
        Limit[\ r\ , \ n \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<         \!\(z\_\(n + 1\)\) = \>\"", 
        z\_\(n + 1\)];\)\ \), "\n", 
    \(\(Print[\*"\"\<          \!\(z\_n\) = \>\"", 
        z\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<        \!\(z\_\(n + 1\)\/z\_n\) = \>\"", 
        r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<L = \!\(lim\+\(n \[Rule] \[Infinity]\)\) |\!\(z\_\(n + 1\
\)\/z\_n\)| = \>\"", Abs[L]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "When  L < 1, the series will converge.  Solve ",
  Cell[BoxData[
      \(\(\(|\)\(\(z\  - \ \[ImaginaryI]\)\/2\)\(|\)\(\(<\)\(1\)\)\)\)]],
  "  and obtain the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z - \[ImaginaryI]\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  ".  \n\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find the sum of the infinite series."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(f[z_]\), " ", "=", " ", 
          
          StyleBox[\(\[Sum]\+\(n = 0\)\%\[Infinity]\((z - \[ImaginaryI])\)\^n\
\/2\^n\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{\(Print[\*"\"\<f[z] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(\((z - \[ImaginaryI])\)\^n\/2\^n\) = \>\"", f[z]];\), 
      " "}]}], "Input"],

Cell[TextData[{
  "We can investigate the convergence by plotting several partial sums of \
this series.\n\nSince convergence will be more rapid in a smaller disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z - \[ImaginaryI]\)\(|\)\(\(<\)\(\ \)\(r\)\)\)\)]],
  ",  the following plot will be a smaller disk with  ",
  Cell[BoxData[
      \(r = 1\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Clear[F, G, m];\), " "}], "\n", 
    RowBox[{\(F[z_]\  = \ f[z + \[ImaginaryI]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(S[z_, n_]\), "=", 
          StyleBox[\(\[Sum]\+\(n = 0\)\%n\((z - \[ImaginaryI])\)\^n\/2\^n\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\[IndentingNewLine]", \(For\ [m = 3, 
        m \[LessEqual] 5, \(m++\), \nG[z_]\  = \ S[z + \[ImaginaryI], m]; \ \n
        PolarMap[
          G\ , {0, 1.0, 0.2}, {0, 
            2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
                2}, {\(-0.7\), 0.7}}, 
          AspectRatio \[Rule] 
            7\/10, \[IndentingNewLine]Ticks \[Rule] {{1\/4, 1\/2, 3\/2, 2}, 
              Range[\(-1\), 1, 1\/4]}, AxesLabel \[Rule] {"\<u\>", "\<u\>"}, 
          PlotStyle \[Rule] {Red, 
              Blue}]; \ \[IndentingNewLine]Print["\<w = \>", "\<S\>"\_m, \
"\<(z) = \>", 
          Normal[Series[
              S[z, m], {z, \[ImaginaryI], 
                m}]]];\ \ ];\), "\[IndentingNewLine]", 
    RowBox[{\(PolarMap[
          F\ , {0, 1.0, 0.2}, {0, 
            2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
                2}, {\(-0.7\), 0.7}}, 
          AspectRatio \[Rule] 
            7\/10, \[IndentingNewLine]Ticks \[Rule] {{1\/4, 1\/2, 3\/2, 2}, 
              Range[\(-1\), 1, 1\/4]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Red, Blue}];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<w = f(z) = \>", f[z]];\), " "}]}], "Input"],

Cell[TextData[{
  "Convergence will be slower in a larger disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z - \[ImaginaryI]\)\(|\)\(\(<\)\(\ \)\(r\)\)\)\)]],
  ",  the following plot will be from a larger disk with  ",
  Cell[BoxData[
      \(r = 1.6\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Clear[F, G, j, m];\), " "}], "\n", 
    RowBox[{\(F[z_]\  = \ f[z + \[ImaginaryI]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(S[z_, n_]\), "=", 
          StyleBox[\(\[Sum]\+\(n = 0\)\%n\((z - \[ImaginaryI])\)\^n\/2\^n\),
            FontSize->14]}], 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\[IndentingNewLine]", \(For\ [j = 3, 
        j \[LessEqual] 5, \(j++\), \[IndentingNewLine]m = 
          5*j; \ \[IndentingNewLine]G[z_]\  = \ 
          S[z + \[ImaginaryI], 
            m]; \ \[IndentingNewLine]Needs["\<Graphics`ComplexMap`\>"]; \
\[IndentingNewLine]Needs["\<Graphics`Colors`\>"]; \[IndentingNewLine]PolarMap[
          G\ , {0, 1.6, 0.2}, {0, 
            2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
                2}, {\(-0.7\), 0.7}}, 
          AspectRatio \[Rule] 
            7\/10, \[IndentingNewLine]Ticks \[Rule] {{1\/4, 1\/2, 3\/2, 2}, 
              Range[\(-1\), 1, 1\/4]}, AxesLabel \[Rule] {"\<u\>", "\<u\>"}, 
          PlotStyle \[Rule] {Blue, 
              Red}]; \ \[IndentingNewLine]Print["\<w = \>", "\<S\>"\_m, \
"\<(z) = \>", 
          Normal[Series[
              S[z, m], {z, \[ImaginaryI], 
                m}]]];\ \ ];\), "\[IndentingNewLine]", 
    RowBox[{\(PolarMap[
          F\ , {0, 1.6, 0.2}, {0, 
            2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
                2}, {\(-0.7\), 0.7}}, 
          AspectRatio \[Rule] 
            7\/10, \[IndentingNewLine]Ticks \[Rule] {{1\/4, 1\/2, 3\/2, 2}, 
              Range[\(-1\), 1, 1\/4]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Blue, Red}];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<w = f(z) = \>", f[z]];\), " "}]}], "Input"],

Cell["\<\
We see that the sequence of functions {S[x,n]} is converging to f[z].\
\>", "Text"],

Cell[BoxData[{
    \(\(funs = 
        Table[{s\_m[z], "\<=\>", S[z, m]}, {m, 1, 
            5}];\)\ \), "\[IndentingNewLine]", 
    \(\(funs = 
        Append[funs, {"\<...\>", "\<\>", "\<...\>"}];\)\ \), "\
\[IndentingNewLine]", 
    \(\(funs = 
        Append[funs, {"\<f[z]\>", "\<=\>", 
            f[z]}];\)\ \), "\[IndentingNewLine]", 
    \(TableForm[funs]\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell["\<\
\tOur next result, known as the root test, is slightly more powerful than the \
ratio test. Before we present this test, we need to discuss a rather \
sophisticated idea used with it-the limit supremum.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Definition 4.10 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Limit Supremum",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/SupremumLimit.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \({t\_n}\)]],
  "  be a sequence of positive real numbers.  The ",
  StyleBox[ButtonBox["limit supremum",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/SupremumLimit.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " of the sequence  (denoted by ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n\  \[Rule] \ \[Infinity]\)\ t\_n\)]],
  ")  is the smallest real number  L  with the property that for any  ",
  Cell[BoxData[
      \(\[Epsilon] > 0\)]],
  "  there are at most finitely many terms in the sequence that are larger \
than  ",
  Cell[BoxData[
      \(L + \[Epsilon]\)]],
  ".  If there is no such number  L,  then we set  ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n\  \[Rule] \ \[Infinity]\)\ t\_n = \[Infinity]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 4.17.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The limit supremum of the sequence  ",
  Cell[BoxData[
      \({t\_n} = {4.1, 5.1, 4.01, 5.01, 4.001, 5.001,  ... }\)]],
  "  is   ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ t\_n = 5\)]],
  ",   because if we set  ",
  Cell[BoxData[
      \(L = 5\)]],
  ",  then for any  ",
  Cell[BoxData[
      \(\(\(\[Element]\)\(\(>\)\(0\)\)\)\)]],
  ",  there are only finitely many terms in the sequence larger than  ",
  Cell[BoxData[
      \(\(\(\(L\)\(+\)\)\(\[Element]\)\) = \
\(\(\(5\)\(+\)\)\(\[Element]\)\)\)]],
  ".  Additionally, if ",
  StyleBox["L",
    FontFamily->"Courier New"],
  " is smaller than ",
  StyleBox["5",
    FontFamily->"Courier New"],
  ", then by setting  ",
  Cell[BoxData[
      \(\(\(\[Element]\)\(\(=\)\(5 - L\)\)\)\)]],
  ",  we can find infinitely many terms in the sequence larger than  ",
  Cell[BoxData[
      \(\(\(\(L\)\(+\)\)\(\[Element]\)\)\)]],
  "  (because  ",
  Cell[BoxData[
      \(\(\(\(L\)\(+\)\)\(\[Element]\)\) = 5\)]],
  ")."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.17.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "In this case the even terms  ",
  Cell[BoxData[
      \(t\_\(2\ k\) = 4 + 10\^\(\(-1\) - k\)\)]],
  "  tend to the limit 4 and the odd terms  ",
  Cell[BoxData[
      \(t\_\(2\ k + 1\) = 5 + 10\^\(\(-1\) - k\)\)]],
  "  tend to the limit 5."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[limsup, k, n, table];\)\ \), "\[IndentingNewLine]", 
    \(\(t\_\(even, k_\) = 
        4 + 1\/10\^\(k + 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(t\_\(odd, k_\) = 5 + 1\/10\^\(k + 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(lim1 = 
        Limit[t\_\(even, k\), 
          k \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(lim2 = Limit[t\_\(odd, k\), k \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(limsup = Max[lim1, lim2];\)\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Flatten[Table[{t\_\(even, k\), t\_\(odd, k\)}, {k, 0, 
              4}]];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(t\_\(2  k\)\) = (\>\"", 
        t\_\(even, k\), "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(t\_\(2  k + 1\)\) = (\>\"", 
        t\_\(odd, k\)\ , "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(k \[Rule] \[Infinity]\)\) \!\(t\_\(2  k\)\) \
= \!\(lim\+\(k \[Rule] \[Infinity]\)\) (\>\"", t\_\(even, k\)\ , "\<) = \>", 
        lim1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(k \[Rule] \[Infinity]\)\) \!\(t\_\(2  k + 1\)\
\) = \!\(lim\+\(k \[Rule] \[Infinity]\)\) (\>\"", 
        t\_\(odd, k\)\ , "\<) = \>", lim2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(limsup\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \
Max[\>\"", lim1, "\<,\>", lim2, "\<]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(limsup\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \
\>\"", limsup];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The limit superior is the largest limit point of a subsequence of  ",
  Cell[BoxData[
      \({t\_n}\)]],
  ".  \n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph the sequence and look for the largest limit point of a \
subsequence."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(pts0 = 
        Table[{Green, Point[N[{2  k, t\_\(even, 2  k\)}]]}, {k, 0, 
            10}];\)\ \), "\[IndentingNewLine]", 
    \(\(pts1 = 
        Table[{Red, Point[N[{2  k + 1, t\_\(odd, 2  k + 1\)}]]}, {k, 0, 
            10}];\)\ \), "\[IndentingNewLine]", 
    \(\(pts = Union[pts0, pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[Graphics[pts], Axes \[Rule] Automatic, 
        Prolog \[Rule] PointSize[0.02], PlotRange \[Rule] {{0, 20}, {0, 6}}, 
        AxesLabel \[Rule] {"\<k\>", \*"\"\<\!\(t\_k\)\>\""}, \
\[IndentingNewLine]Ticks \[Rule] {Range[0, 20, 2], 
            Range[0, 6, 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We see that the limit supremum of the sequence ",
  Cell[BoxData[
      \({t\_n} = {4.1, 5.1, 4.01, 5.01, 4.001, 5.001,  ... }\)]],
  "  is  ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ t\_n = 5\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.18.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The limit supremum of the sequence ",
  Cell[BoxData[
      \({t\_n} = {1, 2, 3, 1, 2, 3, 1, 2, 3,  ... }\)]],
  "  is   ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ t\_n = 3\)]],
  ",   because if we set  ",
  Cell[BoxData[
      \(L = 3\)]],
  ",  then for any  ",
  Cell[BoxData[
      \(\(\(\[Element]\)\(\(>\)\(0\)\)\)\)]],
  ",  there are only finitely many terms (actually, there are none) in the \
sequence larger than  ",
  Cell[BoxData[
      \(\(\(\(L\)\(+\)\)\(\[Element]\)\) = \
\(\(\(3\)\(+\)\)\(\[Element]\)\)\)]],
  ".  Additionally, if ",
  StyleBox["L",
    FontFamily->"Courier New"],
  " is smaller than ",
  StyleBox["3",
    FontFamily->"Courier New"],
  ", then by setting  ",
  Cell[BoxData[
      \(\(\(\[Element]\)\(\(=\)\(\(3 - L\)\/2\)\)\)\)]],
  "  we can find infinitely many terms in the sequence larger than  ",
  Cell[BoxData[
      \(\(\(\(L\)\(+\)\)\(\[Element]\)\)\)]],
  ",  because  ",
  Cell[BoxData[
      \(\(\(L\)\(+\)\) \[Element] \(\(<\)\(\ \)\(3\)\)\)]],
  ",  as the following calculation shows:  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(\(L\)\(+\)\)\(\[Element]\)\)\  = \ \(L + \(3 - L\)\/2\  = \ \(\(3 \
+ L\)\/2\  = \ \(3\/2 + L\/2\  < \ 3\/2 + 3\/2\  = \ 3\)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
In this case there are only three different values for the terms in the \
sequence.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[k];\)\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Table[1 + Mod[k, 3], {k, 0, 15}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(limsup\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \
Max[1,2,3]\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(limsup\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \
\>\"", Max[1, 2, 3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The limit superior is the largest limit point of a subsequence of  ",
  Cell[BoxData[
      \({t\_n}\)]],
  ".  \n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph the sequence and look for the largest limit point of a \
subsequence."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(pts0 = 
        Table[{Green, Point[N[{3  k, 1}]]}, {k, 0, 
            10}];\)\ \), "\[IndentingNewLine]", 
    \(\(pts1 = 
        Table[{Blue, Point[N[{3  k + 1, 2}]]}, {k, 0, 
            10}];\)\ \), "\[IndentingNewLine]", 
    \(\(pts2 = 
        Table[{Red, Point[N[{3  k + 2, 3}]]}, {k, 0, 
            10}];\)\ \), "\[IndentingNewLine]", 
    \(\(pts = Union[pts0, pts1, pts2];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[Graphics[pts], Axes \[Rule] Automatic, 
        Prolog \[Rule] PointSize[0.02], 
        PlotRange \[Rule] {{0, 30}, {0, 3.5}}, 
        AxesLabel \[Rule] {"\<k\>", \*"\"\<\!\(t\_k\)\>\""}, \
\[IndentingNewLine]Ticks \[Rule] {Range[0, 30, 3], 
            Range[0, 4, 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We see that the limit supremum of the sequence ",
  Cell[BoxData[
      \({t\_n} = {1, 2, 3, 1, 2, 3, 1, 2, 3,  ... }\)]],
  "  is  ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ t\_n = 3\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.19.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The limit supremum of the Fibonacci sequence  ",
  Cell[BoxData[
      \(\(\({t\_n}\)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \({1, 1, 2, 3, 5, 8, 13, 21, 34,  ... }\)]],
  "  is   ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ t\_n\  = \ \[Infinity]\)]],
  ".  \n\n(The Fibonacci sequence satisfies the relation  ",
  Cell[BoxData[
      \(t\_n\  = \ t\_\(n - 1\) + t\_\(n - 2\)\)]],
  "  for  ",
  Cell[BoxData[
      \(n > 2\)]],
  ").  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "In this case the sequence has  ",
  Cell[BoxData[
      \(\[Infinity]\)]],
  "  as its limit, and hence the limit supremum  is also  ",
  Cell[BoxData[
      \(\[Infinity]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[n];\)\ \), "\n", 
    \(\(t\_n_ = \(-\@5\)\/5\ 2\^\(\(-1\) - n\)\ \((1 - \@5)\)\^\(n + 1\)\  + \
\((2\/\(1 + \@5\))\)\^\(\(-1\) - n\)\/\@5;\)\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Table[Simplify[t\_n], {n, 0, 12}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(t\_n\) = \>\"", 
        t\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \>\"", 
        Limit[t\_n, n \[Rule] \[Infinity]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(limsup\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \
\>\"", Limit[t\_n, n \[Rule] \[Infinity]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the terms in the sequence."
}], "Text"],

Cell[BoxData[{
    \(\(set\  = \ \ Table[{n, Simplify[t\_n]}, {n, 1, 
            12}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[set, Prolog \[Rule] {PointSize[0.02], Blue}, 
        PlotRange \[Rule] {{0, 12}, {0, 250}}, 
        AxesLabel \[Rule] {"\<n\>", \*"\"\<\!\(t\_n\)\>\""}, \
\[IndentingNewLine]Ticks \[Rule] {Range[0, 12, 1], 
            Range[0, 250, 50]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the limit supremum of the Fibonacci sequence ",
  Cell[BoxData[
      \({t\_n} = {1, 1, 2, 3, 5, 8, 13, 21, 34,  ... }\)]],
  " is  ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ t\_n = \[Infinity]\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell["\<\
\tThe limit supremum is a powerful idea because the limit supremum of a \
sequence always exists, which is not true for the ordinary limit.  However, \
Example 4.20 illustrates the fact that, if the limit of a sequence does \
exist, then it will be the same as the limit supremum.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 4.20.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The sequence  ",
  Cell[BoxData[
      \({t\_n} = \(\({1 + 1\/n}\)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \({2, 1.5, 1.3 \( \(3\)\(\ \)\)\&_, 1.25, 1.2,  ... }\)]],
  "  has  ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ t\_n = 1\)]],
  ".  \n",
  "We leave verification of this as an exercise."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.20.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
In this case the sequence has  1  as its limit, and hence the limit supremum  \
is also  1.\
\>", "Text"],

Cell[BoxData[{
    \(\(Remove[t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[n];\)\ \), "\n", 
    \(\(t\_n_ = 1 + 1\/n;\)\ \), "\[IndentingNewLine]", 
    \(\(table = Table[t\_n, {n, 1, 20}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        N[table]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(t\_n\) = \>\"", 
        t\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \>\"", 
        Limit[t\_n, n \[Rule] \[Infinity]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(limsup\+\(n \[Rule] \[Infinity]\)\) \!\(t\_n\) = \
\>\"", Limit[t\_n, n \[Rule] \[Infinity]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the terms in the sequence."
}], "Text"],

Cell[BoxData[{
    \(\(set\  = \ \ Table[{n, Simplify[t\_n]}, {n, 1, 
            20}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[set, Prolog \[Rule] {PointSize[0.02], Green}, 
        PlotRange \[Rule] {{0, 20}, {0, 2}}, 
        AxesLabel \[Rule] {"\<n\>", \*"\"\<\!\(t\_n\)\>\""}, \
\[IndentingNewLine]Ticks \[Rule] {Range[0, 20, 2], 
            Range[0, 2, 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(t\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
In this case the sequence has  1  as its limit, and hence the limit supremum  \
is also  1.\
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 4.14 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Root Test",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RootTest.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose that the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity] \[Zeta]\_n\)]],
  ",  has  ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n\  \[Rule] \ \[Infinity]\)\ \  | \[Zeta]\_n\( | \
\^\(1\/n\)\) = L\)]],
  "   (i.e.  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(lim\ sup\)\+\(n\  \[Rule] \ \[Infinity]\)\), "  ", 
          RadicalBox[
            
            StyleBox[\(\(\[VerticalSeparator]\)\(\(\[Zeta]\_n\)\(\
\[VerticalSeparator]\)\)\),
              FontSize->12], "n"]}], "=", "L"}]]],
  ").  \nThen the series is absolutely convergent if  ",
  Cell[BoxData[
      \(L < 1\)]],
  "  and divergent if  ",
  Cell[BoxData[
      \(L > 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.14 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  "\tNote that in applying either Theorems 4.13 or 4.14, if",
  "  ",
  Cell[BoxData[
      \(L = 1\)]],
  "  ",
  "the convergence or divergence of the series is unknown,  and further \
analysis is required to determine the true state of affairs. "
}], "Text"],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the radius of convergence of the infinite series  ",
  Cell[BoxData[
      \(S \((z)\) = 
        1 + z\/2 + z\^2\/3\^2 + z\^3\/2\^3 + z\^4\/3\^4 + z\^5\/2\^5 + 
            z\^6\/3\^6 + z\^7\/2\^7 + z\^8\/3\^8 + z\^9\/2\^9 + 
            z\^10\/3\^10 + z\^11\/2\^11 +  ... \)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "The sequence of coefficients is  ",
  Cell[BoxData[
      \({1, 1\/2, 1\/3\^2, 1\/2\^3, 1\/3\^4, 1\/2\^5, 1\/3\^6, 1\/2\^7, 
        1\/3\^8, 1\/2\^9, 1\/3\^10, 1\/2\^11,  ... }\)]],
  ".   \nThe coefficients with even subscripts are ",
  Cell[BoxData[
      \(a\_\(2  k\) = 1\/3\^\(2  k\)\)]],
  ", and the coefficients with odd subscripts are  ",
  Cell[BoxData[
      \(a\_\(2  k + 1\) = 1\/2\^\(2  k + 1\)\)]],
  ".  \nSo that we have \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[VerticalSeparator]", \(a\_\(2  k\)\), 
          StyleBox[\( \[VerticalSeparator] \^\(1\/\(2\ k\)\)\),
            FontSize->12]}], "=", 
        RowBox[{
          StyleBox[\(\((1\/3\^\(2  k\))\)\^\(1\/\(2\ k\)\)\),
            FontSize->12], "  ", "=", " ", \(1\/3\)}]}]]],
  "    and    ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[VerticalSeparator]", \(a\_\(2  k + 1\)\), 
          StyleBox[\( \[VerticalSeparator] \^\(1\/\(2\ k + 1\)\)\),
            FontSize->12]}], "=", " ", 
        RowBox[{
          StyleBox[\(\((1\/2\^\(2  k + 1\))\)\^\(1\/\(2\ k + 1\)\)\),
            FontSize->12], " ", "=", " ", \(1\/2\)}]}]]],
  ".  \n\nIt follows that   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(lim\ sup\)\+\(n\  \[Rule] \ \[Infinity]\)\), "  ", 
          RadicalBox[
            
            StyleBox[\(\(\[VerticalSeparator]\)\(\(a\_n\) 
                  z\^n\)\(\[VerticalSeparator]\)\),
              FontSize->12], "n"]}], " ", "=", 
        " ", \(1\/2 | z | \  = \ L\)}]]],
  ".   \nIf  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  ",  then  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\)\/2\  = \ \ L\  < \ 1\)]],
  ",  and the series converges.   \nIf  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(\ \)\(2\)\)\)\)]],
  ",  the series diverges.  "
}], "Text"],

Cell["\<\
We are done.
\
\>", "Text"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The given series is the sum of two geometric series:   ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 0\)\%\[Infinity] z\^\(2  k\)\/3\^\(2  k\)\)]],
  "   and   ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 0\)\%\[Infinity] z\^\(2  k + 1\)\/2\^\(2  k + 1\)\)]],
  ",  and are known to have radii of convergence ",
  Cell[BoxData[
      \(R\_1 = 3\)]],
  " and ",
  Cell[BoxData[
      \(R\_2 = 2\)]],
  ", respectively.  Hence their sum has radii of convergence ",
  Cell[BoxData[
      \(R = \(min {R\_1, R\_2} = 2\)\)]],
  ".\n\n\t\t\t",
  Cell[BoxData[{
      \(1 + z\/2 + z\^2\/3\^2 + z\^3\/2\^3 + z\^4\/3\^4 + z\^5\/2\^5 + 
          z\^6\/3\^6 + z\^7\/2\^7 + z\^8\/3\^8 + z\^9\/2\^9 + z\^10\/3\^10 + 
          z\^11\/2\^11 +  ... \[IndentingNewLine]\ \ \), 
    "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \ \)\(1 + z\/2 + z\^2\/9 + z\^3\/8 + z\^4\/81 + z\^5\/32 + 
            z\^6\/729 + z\^7\/128 + z\^8\/6561 + z\^9\/512 + z\^10\/59049 + 
            z\^11\/2048 +  ... \)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "The even and odd series are:\n\n\t\t\t",
  Cell[BoxData[{
      \(1 + z\^2\/9 + z\^4\/81 + z\^6\/729 + z\^8\/6561 + 
          z\^10\/59049 +  ... \ \ \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \ \)\(\[Sum]\+\(k = 0\)\%\[Infinity] z\^\(2  k\)\/3\^\(2  \
k\)\ \  = \ \ \(1/\((1 - z\^2\/3\^2)\)\  = \ 
            3\^2\/\(3\^2 - z\^2\)\)\)\)\ \ \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \)\(9\/\(9 - z\^2\)\)\)\)}]],
  "    \n\n\n\n\t\t\t",
  Cell[BoxData[{
      \(z\/2 + z\^3\/8 + z\^5\/32 + z\^7\/128 + z\^9\/512 + 
          z\^11\/2048 +  ... \ \ \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \ \)\(\[Sum]\+\(k = 0\)\%\[Infinity] z\^\(2  k + \
1\)\/2\^\(2  k + 1\)\  = \ \(z\/2\) \(\[Sum]\+\(k = 0\)\%\[Infinity] z\^\(2  \
k\)\/2\^\(2  k\)\)\)\)\ \[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \)\(\((z\/2)\)/\((1 - 
                z\^2\/2\^2)\)\  = \ \ \((z\/2)\) \((4\/\(4 - z\^2\))\)\)\)\ \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \)\(\(2  z\)\/\(4 - z\^2\)\)\)\)}]],
  "  \n\nTherefore, S(z) is the sum of two geometric series:\n\n\t\t\t",
  Cell[BoxData[
      \(S \((z)\)\ \  = \ \ 9\/\(9 - z\^2\)\  + \ \(2  z\)\/\(4 - z\^2\)\)]],
  "\n\nwhich might be printed by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as  ",
  Cell[BoxData[
      \(S \((z)\)\ \  = \ \ \ \(-\(9\/\(\(-9\) + 
                  z\^2\)\)\)\  + \ \(-\(\(2\ z\)\/\(\(-4\) + z\^2\)\)\)\)]]
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<S(z) = \!\(9\/\(9 - z\^2\)\) + \!\(\(2  z\)\/\(4 - \
z\^2\)\)\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S(z) = \>", 
        Series[9\/\(9 - z\^2\) + \(2  z\)\/\(4 - z\^2\), {z, 0, 
            11}]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(f[
          z_] = \[Sum]\+\(k = 0\)\%\[Infinity] z\^\(2  k\)\/3\^\(2  k\);\)\ \
\), "\[IndentingNewLine]", 
    \(\(g[
          z_] = \[Sum]\+\(k = 0\)\%\[Infinity] z\^\(2  k + 1\)\/2\^\(2  k + 1\
\);\)\ \), "\[IndentingNewLine]", 
    \(\(S[z_] = f[z]\  + \ g[z];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[z] = \!\(9\/\(9 - z\^2\)\) = \!\(\[Sum]\+\(k = 0\)\%\
\[Infinity]\)\!\(z\^\(2  k\)\/3\^\(2  k\)\) = \>\"", 
        Series[f[z], {z, 0, 11}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<g[z] = \!\(\(2  z\)\/\(4 - z\^2\)\) = \!\(\[Sum]\+\(k = \
0\)\%\[Infinity]\)\!\(z\^\(2  k + 1\)\/2\^\(2  k + 1\)\) = \>\"", 
        Series[g[z], {z, 0, 11}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[z] = \!\(9\/\(9 - z\^2\)\) + \!\(\(2  z\)\/\(4 - \
z\^2\)\) = \!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(z\^\(2  k\)\/3\^\(2  k\)\) \
+ \!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(z\^\(2  k + 1\)\/2\^\(2  k + \
1\)\)\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[z] = \>", 
        Series[S[z], {z, 0, 11}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[z] = \!\(9\/\(9 - z\^2\)\) = \!\(\[Sum]\+\(k = 0\)\%\
\[Infinity]\)\!\(z\^\(2  k\)\/3\^\(2  k\)\) = \>\"", 
        f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<g[z] = \!\(\(2  z\)\/\(4 - z\^2\)\) = \!\(\[Sum]\+\(k = \
0\)\%\[Infinity]\)\!\(z\^\(2  k + 1\)\/2\^\(2  k + 1\)\) = \>\"", 
        g[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[z] = \!\(9\/\(9 - z\^2\)\) + \!\(\(2  z\)\/\(4 - \
z\^2\)\) = \!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(z\^\(2  k\)\/3\^\(2  k\)\) \
+ \!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(z\^\(2  k + 1\)\/2\^\(2  k + \
1\)\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[z] = \>", S[z]\ ];\)\)}], "Input"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can investigate what happens as ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) \[Rule] \ 2\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<S[z] = \>", S[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[1] = \>", S[1]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(19\/10\)] = \>\"", 
        S[19\/10]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(199\/100\)] = \>\"", 
        S[199\/100]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(1999\/1000\)] = \>\"", 
        S[1999\/1000]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(19999\/10000\)] = \>\"", 
        S[19999\/10000]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[2] =  \!\(\[Sum]\+\(k = \
0\)\%\[Infinity]\)\!\(\((2)\)\^\(2  k\)\/3\^\(2  k\)\) + \!\(\[Sum]\+\(k = \
0\)\%\[Infinity]\)\!\(\((2)\)\^\(2  k + 1\)\/2\^\(2  k + 1\)\)\>\""\ ];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<S[2] = \>", \ \[Sum]\+\(k = 0\)\%\[Infinity]\((2)\)\^\(2  \
k\)\/3\^\(2  k\)\  + \ \[Sum]\+\(k = 0\)\%\[Infinity]\((2)\)\^\(2  k + 1\)\/2\
\^\(2  k + 1\)\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<S[z] = \>", S[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[\[ImaginaryI]] = \>", 
        S[\[ImaginaryI]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(19\/10\)\[ImaginaryI]] = \>\"", 
        S[\(19\/10\) \[ImaginaryI]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(199\/100\)\[ImaginaryI]] = \>\"", 
        S[\(199\/100\) \[ImaginaryI]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(1999\/1000\)\[ImaginaryI]] = \>\"", 
        S[\(1999\/1000\) \[ImaginaryI]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(19999\/10000\)\[ImaginaryI]] = \>\"", 
        S[\(19999\/10000\) \[ImaginaryI]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[2\[ImaginaryI]] =  \!\(\[Sum]\+\(k = \
0\)\%\[Infinity]\)\!\(\((2\\\ \[ImaginaryI])\)\^\(2  k\)\/3\^\(2  k\)\) + \
\!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(\((2\\\ \[ImaginaryI])\)\^\(2  k + \
1\)\/2\^\(2  k + 1\)\)\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[2\[ImaginaryI]] = \>", \ \[Sum]\+\(k = \
0\)\%\[Infinity]\((2\ \[ImaginaryI])\)\^\(2  k\)\/3\^\(2  k\)\  + \ \
\[Sum]\+\(k = 0\)\%\[Infinity]\((2\ \[ImaginaryI])\)\^\(2  k + 1\)\/2\^\(2  k \
+ 1\)\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Caveat.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  In some cases involving complex numbers, earlier versions of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will report a sum when the series actually diverges.  In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.1 the following series converges."
}], "Text"],

Cell[BoxData[
    \(\[Sum]\+\(n = 0\)\%\[Infinity]\((\(3 + 4  \[ImaginaryI]\)\/5)\)\^n\)], \
"Input"],

Cell[TextData[{
  "The above series actually diverges because ",
  Cell[BoxData[
      \(\(\(|\)\(\((\(3 + 4  \[ImaginaryI]\)\/5)\)\^n\)\(|\)\)\  = \ \
\(\(\(|\)\(\(3 + 4  \[ImaginaryI]\)\/5\)\( | \^n\)\)\  = \ 1\)\)]],
  "  for all ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ".\n\nMost likely this occurs because ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.2 is summing the series and then making a substitution."
}], "Text"],

Cell[BoxData[
    \(1/\((1 - \(3 + 4  \[ImaginaryI]\)\/5)\)\)], "Input"],

Cell["Now try another value.", "Text"],

Cell[BoxData[
    \(\[Sum]\+\(n = 0\)\%\[Infinity]\((\(3 + 4  \[ImaginaryI]\)\/4)\)\^n\)], \
"Input"],

Cell[TextData[{
  "Indeed, the above series diverges because ",
  Cell[BoxData[
      \(\(\(|\)\(\((\(3 + 4  \[ImaginaryI]\)\/5)\)\^n\)\(|\)\)\  = \ \
\(\(\(|\)\(\(3 + 4  \[ImaginaryI]\)\/4\)\( | \^n\)\)\  = \ 
          5\/4\  > \ 1\)\)]],
  "  for all ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ".\n\nThis bug has been correct in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.1 and the above series does not converge.\n\nHowever, you have been \
given a warning!"
}], "Text"],

Cell[TextData[{
  StyleBox["Caveat.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The mathematical analysis proves that the series ",
  Cell[BoxData[
      \(\(\(\ \ \)\(\[Sum]\+\(k = 0\)\%\[Infinity]\((\(6 + 8  \[ImaginaryI]\)\
\/5)\)\^\(2  k\)\/3\^\(2  k\)\  + \ \[Sum]\+\(k = 0\)\%\[Infinity]\((\(6 + 8  \
\[ImaginaryI]\)\/5)\)\^\(2  k + 1\)\/2\^\(2  k + 1\)\)\)\)]],
  " diverges.  But for some reason ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.1 will compute a sum.  For sure it is a mistake which is equivalent to \
substituting ",
  Cell[BoxData[
      \(Z = \(6 + 8  \[ImaginaryI]\)\/5\)]],
  " into the formula  ",
  Cell[BoxData[
      \(S[
          z]\  = \ \(-\(9\/\(\(-9\) + 
                  z\^2\)\)\) - \(2\ z\)\/\(\(-4\) + z\^2\)\)]],
  ".  This bug has been corrected in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.1."
}], "Text"],

Cell[BoxData[{
    \(\(Z = \(6 + 8  \[ImaginaryI]\)\/5;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<|\>", Z, "\<| = \>", Abs[Z]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(S[
          z_]\  = \ \(-\(9\/\(\(-9\) + 
                  z\^2\)\)\) - \(2\ z\)\/\(\(-4\) + z\^2\);\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<      S[z] = \>", S[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", Z, "\<] = \>", S[Z]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<S[z] = \>", S[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", \(1\/2\) Z, "\<] = \>", 
        S[\(1\/2\) Z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", \(19\/10\) Z, "\<] = \>", 
        S[\(19\/10\) Z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", \(199\/100\) Z, "\<] = \>", 
        S[\(199\/100\) Z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", \(1999\/1000\) Z, "\<] = \>", 
        S[\(1999\/1000\) Z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", \(19999\/10000\) Z, "\<] = \>", 
        S[\(19999\/10000\) Z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(\(6 + 8  \[ImaginaryI]\)\/5\)] =  \!\(\[Sum]\+\(k \
= 0\)\%\[Infinity]\)\!\(\((\(6 + 8  \[ImaginaryI]\)\/5)\)\^\(2  k\)\/3\^\(2  \
k\)\) + \!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(\((\(6 + 8  \
\[ImaginaryI]\)\/5)\)\^\(2  k + 1\)\/2\^\(2  k + 1\)\)\>\""\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(\(6 + 8  \[ImaginaryI]\)\/5\)] = \>\"", \ \[Sum]\+\
\(k = 0\)\%\[Infinity]\((\(6 + 8  \[ImaginaryI]\)\/5)\)\^\(2  k\)\/3\^\(2  \
k\)\  + \ \[Sum]\+\(k = 0\)\%\[Infinity]\((\(6 + 8  \
\[ImaginaryI]\)\/5)\)\^\(2  k + 1\)\/2\^\(2  k + 1\)\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<WARNING. The series diverges.\>"];\)\), \
"\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Geometric Series",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/GeometricSeriesBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Convergence of Series",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/SeriesConvergenceBib.html"],
     None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Power Series",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/PowerSeriesBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{991, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[130837, 2260, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[135049, 2384, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[263754, 4547, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[283372, 5105, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[317378, 6057, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 334699, 6509}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 136, 2, 33, "Text"],
Cell[2241, 66, 265, 7, 33, "Text"],

Cell[CellGroupData[{
Cell[2531, 77, 156, 4, 33, "Text",
  Evaluatable->False],
Cell[2690, 83, 618, 18, 58, "Text"],
Cell[3311, 103, 1753, 31, 402, "Input"],
Cell[5067, 136, 204, 6, 33, "Text"],
Cell[5274, 144, 1153, 21, 243, "Input"],
Cell[6430, 167, 135, 3, 33, "Text"],
Cell[6568, 172, 2998, 59, 574, "Input"],
Cell[9569, 233, 89, 2, 33, "Text"]
}, Closed]],
Cell[9673, 238, 119600, 1964, 261, 119486, 1960, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[129276, 2204, 1210, 40, 117, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[130511, 2248, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[130659, 2254, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[130837, 2260, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{
Cell[131219, 2274, 151, 4, 30, "Text",
  Evaluatable->False],
Cell[131373, 2280, 479, 15, 77, "Text"],
Cell[131855, 2297, 1688, 31, 456, "Input"]
}, Closed]],
Cell[133558, 2331, 1139, 37, 155, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[134722, 2372, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[134870, 2378, 176, 4, 33, "Text",
  Evaluatable->False],
Cell[135049, 2384, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[135409, 2396, 125207, 2055, 261, 125093, 2051, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[260641, 4455, 151, 4, 33, "Text",
  Evaluatable->False],
Cell[260795, 4461, 495, 15, 77, "Text"],
Cell[261293, 4478, 1591, 31, 449, "Input"]
}, Closed]],
Cell[262899, 4512, 493, 19, 72, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[263417, 4535, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[263565, 4541, 186, 4, 33, "Text",
  Evaluatable->False],
Cell[263754, 4547, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{
Cell[264136, 4561, 151, 4, 30, "Text",
  Evaluatable->False],
Cell[264290, 4567, 123, 5, 33, "Text"],
Cell[264416, 4574, 483, 10, 119, "Input"],
Cell[264902, 4586, 35, 0, 33, "Text"],
Cell[264940, 4588, 472, 8, 118, "Input"]
}, Closed]],
Cell[265427, 4599, 263, 9, 33, "Text"],
Cell[265693, 4610, 487, 14, 84, "Text"],

Cell[CellGroupData[{
Cell[266205, 4628, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[266369, 4634, 118, 3, 33, "Text"],
Cell[266490, 4639, 1615, 39, 391, "Input"],
Cell[268108, 4680, 214, 7, 36, "Text",
  Evaluatable->False],
Cell[268325, 4689, 385, 7, 157, "Input"],
Cell[268713, 4698, 118, 2, 33, "Text",
  Evaluatable->False],
Cell[268834, 4702, 718, 13, 257, "Input"],
Cell[269555, 4717, 234, 6, 71, "Text"],
Cell[269792, 4725, 791, 15, 257, "Input"],
Cell[270586, 4742, 151, 5, 33, "Text"],
Cell[270740, 4749, 1222, 27, 274, "Input"],
Cell[271965, 4778, 272, 8, 36, "Text",
  Evaluatable->False]
}, Closed]],
Cell[272252, 4789, 318, 12, 34, "Text",
  Evaluatable->False],
Cell[272573, 4803, 1328, 24, 270, "Text"],

Cell[CellGroupData[{
Cell[273926, 4831, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[274090, 4837, 118, 3, 33, "Text"],
Cell[274211, 4842, 1648, 42, 360, "Input"],
Cell[275862, 4886, 207, 7, 36, "Text",
  Evaluatable->False],
Cell[276072, 4895, 385, 7, 157, "Input"],
Cell[276460, 4904, 118, 2, 33, "Text",
  Evaluatable->False],
Cell[276581, 4908, 1135, 23, 321, "Input"],
Cell[277719, 4933, 156, 5, 33, "Text"],
Cell[277878, 4940, 1067, 27, 219, "Input"],
Cell[278948, 4969, 151, 5, 33, "Text"],
Cell[279102, 4976, 1308, 29, 266, "Input"],
Cell[280413, 5007, 603, 19, 37, "Text",
  Evaluatable->False]
}, Closed]],
Cell[281031, 5029, 739, 21, 72, "Text"],
Cell[281773, 5052, 309, 5, 52, "Text"],
Cell[282085, 5059, 908, 29, 114, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[283018, 5092, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[283166, 5098, 203, 5, 33, "Text",
  Evaluatable->False],
Cell[283372, 5105, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[283732, 5117, 312, 11, 33, "Text",
  Evaluatable->False],
Cell[284047, 5130, 2375, 40, 395, "Text"],

Cell[CellGroupData[{
Cell[286447, 5174, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[286611, 5180, 62, 0, 33, "Text"],
Cell[286676, 5182, 306, 7, 125, "Input"],
Cell[286985, 5191, 98, 2, 33, "Text"],
Cell[287086, 5195, 1003, 18, 342, "Input"],
Cell[288092, 5215, 217, 7, 71, "Text",
  Evaluatable->False],
Cell[288312, 5224, 285, 5, 114, "Input"],
Cell[288600, 5231, 156, 5, 33, "Text"],
Cell[288759, 5238, 734, 14, 245, "Input"],
Cell[289496, 5254, 151, 5, 33, "Text"],
Cell[289650, 5261, 1241, 27, 273, "Input"],
Cell[290894, 5290, 343, 11, 36, "Text",
  Evaluatable->False]
}, Closed]],
Cell[291252, 5304, 414, 14, 33, "Text",
  Evaluatable->False],
Cell[291669, 5320, 902, 22, 155, "Text"],

Cell[CellGroupData[{
Cell[292596, 5346, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[292760, 5352, 62, 0, 33, "Text"],
Cell[292825, 5354, 291, 6, 125, "Input"],
Cell[293119, 5362, 96, 2, 33, "Text"],
Cell[293218, 5366, 712, 14, 231, "Input"],
Cell[293933, 5382, 445, 13, 74, "Text",
  Evaluatable->False],
Cell[294381, 5397, 472, 14, 98, "Input"],
Cell[294856, 5413, 363, 9, 71, "Text"],
Cell[295222, 5424, 1643, 35, 381, "Input"],
Cell[296868, 5461, 269, 8, 33, "Text"],
Cell[297140, 5471, 1842, 38, 441, "Input"],
Cell[298985, 5511, 93, 2, 33, "Text"],
Cell[299081, 5515, 413, 11, 110, "Input"]
}, Closed]],
Cell[299509, 5529, 226, 4, 49, "Text"],
Cell[299738, 5535, 1237, 36, 68, "Text"],
Cell[300978, 5573, 1162, 38, 79, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[302165, 5615, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[302329, 5621, 272, 8, 33, "Text"],
Cell[302604, 5631, 1893, 34, 474, "Input"],
Cell[304500, 5667, 296, 9, 71, "Text"],
Cell[304799, 5678, 839, 16, 170, "Input"],
Cell[305641, 5696, 261, 8, 41, "Text"]
}, Closed]],
Cell[305917, 5707, 1416, 43, 120, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[307358, 5754, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[307522, 5760, 107, 3, 33, "Text"],
Cell[307632, 5765, 629, 12, 190, "Input"],
Cell[308264, 5779, 296, 9, 71, "Text"],
Cell[308563, 5790, 938, 20, 190, "Input"],
Cell[309504, 5812, 252, 8, 41, "Text"]
}, Closed]],
Cell[309771, 5823, 630, 21, 76, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[310426, 5848, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[310590, 5854, 215, 8, 33, "Text"],
Cell[310808, 5864, 976, 18, 307, "Input"],
Cell[311787, 5884, 137, 5, 33, "Text"],
Cell[311927, 5891, 614, 12, 130, "Input"],
Cell[312544, 5905, 274, 8, 41, "Text"]
}, Closed]],
Cell[312833, 5916, 304, 5, 49, "Text"],
Cell[313140, 5923, 486, 16, 60, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[313651, 5943, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[313815, 5949, 115, 3, 33, "Text"],
Cell[313933, 5954, 1063, 20, 342, "Input"],
Cell[314999, 5976, 137, 5, 33, "Text"],
Cell[315139, 5983, 610, 12, 130, "Input"],
Cell[315752, 5997, 115, 3, 33, "Text"]
}, Closed]],
Cell[315882, 6003, 1145, 38, 61, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[317052, 6045, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[317200, 6051, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[317378, 6057, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[317738, 6069, 277, 8, 49, "Text"],
Cell[318018, 6079, 462, 13, 37, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[318505, 6096, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[318672, 6102, 1851, 49, 210, "Text"],
Cell[320526, 6153, 37, 3, 52, "Text"],
Cell[320566, 6158, 1099, 29, 144, "Text"],
Cell[321668, 6189, 1540, 33, 500, "Text"],
Cell[323211, 6224, 267, 5, 76, "Input"],
Cell[323481, 6231, 1942, 33, 501, "Input"],
Cell[325426, 6266, 239, 9, 71, "Text"],
Cell[325668, 6277, 1018, 18, 305, "Input"],
Cell[326689, 6297, 1267, 20, 305, "Input"],
Cell[327959, 6319, 386, 11, 33, "Text"],
Cell[328348, 6332, 101, 2, 49, "Input"],
Cell[328452, 6336, 453, 12, 74, "Text"],
Cell[328908, 6350, 72, 1, 43, "Input"],
Cell[328983, 6353, 38, 0, 33, "Text"],
Cell[329024, 6355, 101, 2, 49, "Input"],
Cell[329128, 6359, 502, 14, 112, "Text"],
Cell[329633, 6375, 905, 25, 71, "Text"],
Cell[330541, 6402, 149, 2, 64, "Input"],
Cell[330693, 6406, 293, 6, 83, "Input"],
Cell[330989, 6414, 1358, 24, 352, "Input"]
}, Closed]],
Cell[332362, 6441, 290, 7, 30, "Text"],
Cell[332655, 6450, 289, 7, 33, "Text"],
Cell[332947, 6459, 296, 7, 33, "Text"],
Cell[333246, 6468, 281, 7, 33, "Text"],
Cell[333530, 6477, 257, 5, 33, "Text"],
Cell[333790, 6484, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

