(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     86429,       2266]*)
(*NotebookOutlinePosition[     87533,       2305]*)
(*  CellTagsIndexPosition[     87457,       2299]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["4.4  Power Series Functions",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tSuppose that we have a series ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity] \[Xi]\_n\)]],
  "  where ",
  Cell[BoxData[
      \(\[Xi]\_n = \(c\_n\) \((z - \[Alpha])\)\^n\)]],
  ".  If ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  " and the collection of ",
  Cell[BoxData[
      \(c\_n\)]],
  " are fixed complex numbers, we will get different series by selecting \
different values for z.  For example, if ",
  Cell[BoxData[
      \(\[Alpha] = 2\)]],
  " and ",
  Cell[BoxData[
      \(c\_n = 1\/\(n!\)\)]],
  " for all n, we get the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\( 
              1\/\(n!\)\) \((\[ImaginaryI]\/2 - 2)\)\^n\)]],
  " if ",
  Cell[BoxData[
      \(z = \[ImaginaryI]\/2\)]],
  ",  and  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\( 
              1\/\(n!\)\) \((2 + \[ImaginaryI])\)\^n\)]],
  " if ",
  Cell[BoxData[
      \(z = 4 + \[ImaginaryI]\)]],
  ".  Note that when  ",
  Cell[BoxData[
      \(\[Alpha] = 0\)]],
  " and ",
  Cell[BoxData[
      \(c\_n = 1\)]],
  " for all n, we get a geometric series.  The collection of points for which \
the series ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\( c\_n\) \((z - \[Alpha])\)\^n\)]],
  " converges is the domain of a function ",
  Cell[BoxData[
      \(f \((z)\) = \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                c\_n\) \((z - \[Alpha])\)\^n\)]],
  ", which we call a power series function.  Technically, this series is \
undefined if  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  " and n=0, since ",
  Cell[BoxData[
      \(0\^0\)]],
  " is undefined.  We get around this difficulty by stipulating that the \
series ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\( c\_n\) \((z - \[Alpha])\)\^n\)]],
  " is really compact notation for ",
  Cell[BoxData[
      \(c\_0 + \[Sum]\+\(n = 1\)\%\[Infinity]\( 
                c\_n\) \((z - \[Alpha])\)\^n\)]],
  ".  In this section we present some results that are useful in helping \
establish properties of functions defined by power series."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Power Series",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/PowerSeries.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The function  ",
  Cell[BoxData[
      \(f \((z)\) = \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                c\_n\) \((z - \[Alpha])\)\^n\)]],
  "  is called a power series, with center  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Theorem 4.15.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose  ",
  Cell[BoxData[
      \(f \((z)\) = \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                c\_n\) \((z - \[Alpha])\)\^n\)]],
  " .  Then the set of points z for which the series converges is one of the \
following:\n\n",
  StyleBox["(i)",
    FontColor->RGBColor[0, 0, 1]],
  "    The single point  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ".  \n\n",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  "   The disk  ",
  Cell[BoxData[
      \(\(D\_\[Rho]\) \((\[Alpha])\) = {z : \ \(\(|\)\(z - \
\[Alpha]\)\(|\)\(\(<\)\(\ \)\(\[Rho]\)\)\)}\)]],
  ",  along with part (either none, or some or all) of the circle  ",
  Cell[BoxData[
      \(\(C\_\[Rho]\) \((\[Alpha])\) = {z : \ \(\(|\)\(z - \[Alpha]\)\(|\)\) \
= \ \ \[Rho]}\)]],
  ".  \n\n",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  "  The entire complex plane."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.15 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  "\tAnother way to phrase case (ii) of Theorem 4.15 is to say that the power \
series ",
  Cell[BoxData[
      \(f \((z)\) = \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                c\_n\) \((z - \[Alpha])\)\^n\)]],
  " converges if ",
  Cell[BoxData[
      \(\(\(|\)\(z - \[Alpha]\)\(|\)\(\(<\)\(\ \)\(\[Rho]\)\)\)\)]],
  " and diverges if  ",
  Cell[BoxData[
      \(\(\(|\)\(z - \[Alpha]\)\(|\)\(\(>\)\(\ \)\(\[Rho]\)\)\)\)]],
  ".  We call the number ",
  Cell[BoxData[
      \(\[Rho]\)]],
  " the ",
  StyleBox[ButtonBox["radius of convergence",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RadiusofConvergence.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " of the power series (see Figure 4.3).  For case (i) of Theorem 4.15, we \
say that the radius of convergence is zero and that the radius of convergence \
is infinity for case (iii)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0.0869565 0.289855 0.0740741 0.246914 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.941 1 .941 r
0 0 m
.95652 0 L
.95652 .62963 L
0 .62963 L
0 0 L
F
0 1 1 r
.37681 .32099 m
matrix currentmatrix
0.217391 0.185185 scale
1.73333 1.73335 1 0 365.73 arc
setmatrix F
0 0 1 r
.022 w
.37681 .32099 Mdot
.5 Mabswid
[ .0265 .0265 ] 0 setdash
newpath
matrix currentmatrix
0.217391 0.185185 scale
1.73333 1.73335 1 0 365.73 arc
setmatrix s
[ ] 0 setdash
.37681 .32099 m
.22309 .19004 L
s
% Start of user PostScript
1. 1. 0.46967 0.46967 MAarrowhead1
% End of user PostScript
0 g
gsave
.66667 .55556 -98.9375 -9.96875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.9375 translate 1 -1 scale
63.000 12.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Divergence) show
134.875 12.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37681 .40741 -102.531 -9.71875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.4375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Convergence) show
142.063 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.98551 .09877 -66.5938 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.188 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.11594 .64198 -66.5938 -9.71875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.4375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
70.188 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41449 .32099 -66.5938 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34783 .24691 -66.5938 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
70.188 12.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 0 r
0 .07407 m
1 .07407 L
s
.08696 0 m
.08696 .66667 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 192},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000`2000`400?l00000o`00003o6@3oool0
0`000000oooo0?ooo`3o0?ooo`D0oooo000I0?3ol0030000003`oo00l?o`0?H0l?o`3P3oool001T0
l?o`00<000000?3ol03`oo00mP3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol03f0?3ol0h0oooo
000I0?3ol0030000003`oo00l?o`0?H0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00mP3`oo0>
0?ooo`006@3`oo000`000000l?o`0?3ol03f0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`0?H0
l?o`3P3oool001T0l?o`00<000000?3ol03`oo00mP3`oo0>0?ooo`006@3`oo000`000000l?o`0?3o
l03f0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`0?H0l?o`3P3oool001T0l?o`00<000000?3o
l03`oo00mP3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol03f0?3ol0h0oooo000I0?3ol0030000
003`oo00l?o`0?H0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00mP3`oo0>0?ooo`006@3`oo00
0`000000l?o`0?3ol03f0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`0?H0l?o`3P3oool001T0
l?o`00<000000?3ol03`oo00mP3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol03f0?3ol0h0oooo
000I0?3ol0030000003`oo00l?o`0?H0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00mP3`oo0>
0?ooo`006@3`oo000`000000l?o`0?3ol03f0?3ol0h0oooo003o0000020000000@3oool001T0l?o`
00<000000?3ol03`oo00mP3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol03f0?3ol0h0oooo000I
0?3ol0030000003`oo00l?o`0?H0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00mP3`oo0>0?oo
o`006@3`oo000`000000l?o`0?3ol03f0?3ol0D0oooo0P0000020?ooo`8000000`3oool001T0l?o`
00<000000?3ol03`oo00mP3`oo060?ooo`040000003oool0oooo000000@0oooo000I0?3ol0030000
003`oo00l?o`0?H0l?o`1`3oool2000000D0oooo000I0?3ol0030000003`oo00l?o`0?H0l?o`1`3o
ool2000000D0oooo000I0?3ol0030000003`oo00l?o`0?H0l?o`1P3oool010000000oooo0?ooo`00
00040?ooo`006@3`oo000`000000l?o`0?3ol03f0?3ol0D0oooo0P0000020?ooo`8000000`3oool0
01T0l?o`00<000000?3ol03`oo00mP3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol03f0?3ol0h0
oooo000I0?3ol0030000003`oo00l?o`0?H0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00mP3`
oo0>0?ooo`006@3`oo000`000000l?o`0?3ol03f0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`
0?H0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00D`3`oo000`000?l0l?o`0?3ol02P0?3ol0h0
oooo000I0?3ol0030000003`oo00l?o`04@0l?o`20000?l8003oo`L0003oV`3`oo0>0?ooo`006@3`
oo000`000000l?o`0?3ol0120?3ol1`00?ooV03`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00k
0?3ol080003o9@00ool30000oi40l?o`3P3oool001T0l?o`00<000000?3ol03`oo00>03`oo030000
obX00?oo0`000?n>0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`03H0l?o`0P000?l`003oo`80
003oS03`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00c0?3ol0800?oo00<0003o003oo`00ool0
=000oon:0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`0380l?o`?000oon80?3ol0h0oooo000I
0?3ol0030000003`oo00l?o`0340l?o`?P00ool00`3`oo00003o0?3ol0240?3ol0h0oooo000I0?3o
l0030000003`oo00l?o`02d0l?o`0P000?m2003oo`80003oP`3`oo0>0?ooo`006@3`oo000`000000
l?o`0?3ol00[0?3ol080003oAP00ool20000oh40l?o`3P3oool001T0l?o`00<000000?3ol03`oo00
:P3`oo000`000?l00?oo003oo`18003oo`030000o`3`oo00l?o`07h0l?o`3P3oool001T0l?o`00<0
00000?3ol03`oo00:@3`oo000`000?l00?oo003oo`1:003oo`030000o`3`oo00l?o`07d0l?o`3P3o
ool001T0l?o`00<000000?3ol03`oo00:03`oo000`000?l00?oo003oo`1=003oogh0l?o`3P3oool0
01T0l?o`00<000000?3ol03`oo009`3`oo1B003oogd0l?o`3P3oool001T0l?o`00<000000?3ol03`
oo00903`oo1G003oog/0l?o`3P3oool001T0l?o`00<000000?3ol03`oo008`3`oo000`00ool0003o
003oo`1F003oogX0l?o`3P3oool001T0l?o`00<000000?3ol03`oo008P3`oo03003oo`80003oE@00
ool20000ogP0l?o`3P3oool001T0l?o`00<000000?3ol03`oo008@3`oo001000ool0003o003oo`00
ool40000oeD00?oo00<0003o0?3ol03`oo00M@3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00P
0?3ol080003o1000ool50000oe@00?oo00<0003o0?3ol03`oo00M03`oo0>0?ooo`006@3`oo000`00
0000l?o`0?3ol00O0?3ol0030000o`00ool00?oo00D00?oo1P000?mC003oo`030000o`3`oo00l?o`
07<0l?o`3P3oool001T0l?o`00<000000?3ol03`oo007P3`oo000`000?l00?oo003oo`06003oo`P0
003oDP00ool00`000?l0l?o`0?3ol01b0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`01d0l?o`
00<0003o003oo`00ool02000ool90000oe400?oo00<0003o0?3ol03`oo00L@3`oo0>0?ooo`006@3`
oo000`000000l?o`0?3ol00M0?3ol0030000o`00ool00?oo00T00?oo2@000?mA003oog<0l?o`3P3o
ool001T0l?o`00<000000?3ol03`oo00703`oo0>003oo`L0003oDP00oomc0?3ol0h0oooo000I0?3o
l0030000003`oo00l?o`01`0l?o`3P00ool70000oe<00?ooLP3`oo0>0?ooo`006@3`oo000`000000
l?o`0?3ol00K0?3ol1000?oo1P000?mD003oog40l?o`3P3oool001T0l?o`00<000000?3ol03`oo00
6P3`oo0B003oo`<0003o0P00ool00`000?l00?oo003oo`1B003oog00l?o`3P3oool001T0l?o`00<0
00000?3ol03`oo006@3`oo0C003oo`<0003o0`00ool00`000?l00?oo003oo`1A003oo`030000o`3`
oo00l?o`06d0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00603`oo000`000?l00?oo003oo`0B
003oo`030000o`00ool00?oo00<00?oo0P000?l?003oo`0300000000ool00?oo04000?oo00<0003o
0?3ol03`oo00K03`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00H0?3ol0030000o`00ool00?oo
01X00?oo00<0003o003oo`00ool03000ool00`0000000?oo003oo`11003oo`030000o`3`oo00l?o`
06/0l?o`3P3oool001T0l?o`00<000000?3ol03`oo005`3`oo000`000?l00?oo003oo`0L003oo`03
0000o`00ool00?oo00/00?oo00<00000003oo`0000000P00000o003oo`030000o`3`oo00l?o`06/0
l?o`3P3oool001T0l?o`00<000000?3ol03`oo005`3`oo000`000?l00?oo003oo`0M003oo`030000
o`00ool00?oo00/00?oo00D00000003oo`00ool00?oo0000000o003oo`030000o`3`oo00l?o`06X0
l?o`3P3oool001T0l?o`00<000000?3ol03`oo005P3`oo000`000?l00?oo003oo`0O003oo`030000
o`00ool00?oo00X00?oo00D00000003oo`00ool00?oo0000000o003oo`030000o`3`oo00l?o`06X0
l?o`3P3oool001T0l?o`00<000000?3ol03`oo005@3`oo000`000?l00?oo003oo`0Q003oo`030000
o`00ool00?oo00T00?oo00D00000003oo`00ool00?oo0000000o003oo`030000o`3`oo00l?o`06X0
l?o`3P3oool001T0l?o`00<000000?3ol03`oo005@3`oo000`000?l00?oo003oo`0R003oo`80003o
2@00ool01@0000000?oo003oo`00ool0000004000?oo00<0003o0?3ol03`oo00J@3`oo0>0?ooo`00
6@3`oo000`000000l?o`0?3ol00E0?3ol0030000o`00ool00?oo02@00?oo00<0003o003oo`00ool0
1`00ool3000004800?ooJ`3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00E0?3ol2P00?oo00<0
003o003oo`00ool0B`00oom[0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`01@0l?o`:P00ool0
0`000?l00?oo003oo`1:003oof/0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00503`oo0[003o
o`030000o`00ool00?oo04X00?ooJP3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00C0?3ol2d0
0?oo0P000?m:003oofX0l?o`3P3oool001T0l?o`00<000000?3ol03`oo004`3`oo0_003oo`030000
o`00ool00?oo04P00?ooJ@3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00C0?3ol3000?oo00<0
003o003oo`00ool0AP00ool00`000?l0l?o`0?3ol01W0?3ol0h0oooo000I0?3ol0030000003`oo00
l?o`01<0l?o`00<0003o003oo`00ool0;P00ool00`000?l00?oo003oo`16003oo`030000o`3`oo00
l?o`06H0l?o`3P3oool001T0l?o`00<000000?3ol03`oo004`3`oo000`000?l00?oo003oo`0_003o
o`030000o`00ool00?oo04D00?oo00<0003o0?3ol03`oo00IP3`oo0>0?ooo`006@3`oo000`000000
l?o`0?3ol00B0?3ol0030000o`00ool00?oo03400?oo0P000?m5003oo`030000o`3`oo00l?o`06H0
l?o`3P3oool001T0l?o`00<000000?3ol03`oo004P3`oo000`000?l00?oo003oo`0c003oo`030000
o`00ool00?oo04800?oo00<0003o0?3ol03`oo00IP3`oo0>0?ooo`006@3`oo000`000000l?o`0?3o
l00B0?3ol0030000o`00ool00?oo03@00?oo00<0003o003oo`00ool0@@00ool00`000?l0l?o`0?3o
l01V0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`0180l?o`00<0003o003oo`00ool0=@00ool0
0`000?l00?oo003oo`11003oo`030000o`3`oo00l?o`06D0l?o`3P3oool001T0l?o`00<000000?3o
l03`oo004P3`oo000`000?l00?oo003oo`0f003oo`030000o`00ool00?oo04000?oo00<0003o0?3o
l03`oo00I@3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00B0?3ol0030000o`00ool00?oo03L0
0?oo0P000?m0003oofP0l?o`3P3oool001T0l?o`00<000000?3ol03`oo004P3`oo000`000?l00?oo
003oo`0i003oo`<0003o?@00oomX0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`0140l?o`00<0
003o003oo`00ool0>P00ool40000o`H00?oo0P000002003oo`0300000000ool00?oo02l00?ooJ03`
oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00A0?3ol0030000o`00ool00?oo03T00?oo1P000?l4
003oo`0300000000ool00?oo00800000<P00ool00`000?l0l?o`0?3ol01U0?3ol0h0oooo000I0?3o
l0030000003`oo00l?o`0180l?o`>`00ool60000o`@00?oo00D00000003oo`00ool00?oo0000000b
003oo`030000o`3`oo00l?o`06D0l?o`3P3oool001T0l?o`00<000000?3ol03`oo004P3`oo0l003o
o`@0003o1@00ool01@0000000?oo003oo`00ool0000003800?oo00<0003o0?3ol03`oo00I@3`oo0>
0?ooo`006@3`oo000`000000l?o`0?3ol00B0?3ol3d00?oo0P000?l6003oo`0500000000ool00?oo
003oo`000000<P00ool00`000?l0l?o`0?3ol01U0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`
0180l?o`AP00ool300000003003oo`0000000?oo03000?oo00<0003o0?3ol03`oo00I@3`oo0>0?oo
o`006@3`oo000`000000l?o`0?3ol00B0?3ol7`00?oo00<0003o0?3ol03`oo00I@3`oo0>0?ooo`00
6@3`oo000`000000l?o`0?3ol00B0?3ol7`00?oo00<0003o0?3ol03`oo00I@3`oo0>0?ooo`006@3`
oo000`000000l?o`0?3ol00B0?3ol0030000o`00ool00?oo07P00?oo00<0003o0?3ol03`oo00IP3`
oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00B0?3ol0030000o`00ool00?oo07P00?oo00<0003o
0?3ol03`oo00IP3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00B0?3ol0030000o`00ool00?oo
07P00?ooJ@3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00C0?3ol0030000o`00ool00?oo07L0
0?ooJ@3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00C0?3ol0030000o`00ool00?oo07L00?oo
J@3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00C0?3ol0030000o`00ool00?oo07L00?ooJ@3`
oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00C0?3ol0030000o`00ool00?oo07L00?ooJ@3`oo0>
0?ooo`006@3`oo000`000000l?o`0?3ol00C0?3ol0030000o`00ool00?oo07H00?ooJP3`oo0>0?oo
o`006@3`oo000`000000l?o`0?3ol00D0?3ol0030000o`00ool00?oo07@00?oo00<0003o0?3ol03`
oo00J03`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00D0?3ol7L00?oo00<0003o0?3ol03`oo00
J03`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00E0?3ol7H00?oo00<0003o0?3ol03`oo00J03`
oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00E0?3ol7D00?oo00<0003o0?3ol03`oo00J@3`oo0>
0?ooo`006@3`oo000`000000l?o`0?3ol00E0?3ol7D00?oo00<0003o0?3ol03`oo00J@3`oo0>0?oo
o`006@3`oo000`000000l?o`0?3ol00F0?3ol7<00?oo00<0003o0?3ol03`oo00JP3`oo0>0?ooo`00
6@3`oo000`000000l?o`0?3ol00F0?3ol7<00?oo00<0003o0?3ol03`oo00JP3`oo0>0?ooo`006@3`
oo000`000000l?o`0?3ol00G0?3ol0030000o`00ool00?oo03X00?oo0`00000a003oo`030000o`3`
oo00l?o`06/0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00603`oo000`000?l00?oo003oo`0l
003oo`0300000000ool00?oo02h00?ooKP3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00H0?3o
l0030000o`00ool00?oo00l00?oo0`000004003oo`<000000P00ool300000004003oo`0000000000
000000<00?oo00<00000003oo`00ool00`00ool4000000800?oo1@000003003oo`@000000`00ool4
00000005003oo`000000000000000000ool00`000002003oo`<000001000ool4000001@00?ooKP3`
oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00I0?3ol0030000o`00ool00?oo00d00?oo00D00000
003oo`00ool00?oo00000002003oo`0500000000ool00?oo003oo`0000000P00ool01@0000000?oo
003oo`00ool0000000<00?oo00<00000003oo`0000000`00ool00`0000000?oo003oo`05003oo`03
00000000ool00?oo00<00?oo00D00000003oo`00ool00?oo00000002003oo`0300000000ool00?oo
00@00?oo00D00000003oo`00ool00?oo00000002003oo`0500000000ool00?oo003oo`0000000P00
ool00`0000000?oo003oo`0E003oofl0l?o`3P3oool001T0l?o`00<000000?3ol03`oo006@3`oo00
0`000?l00?oo003oo`0=003oo`0300000000ool00?oo00@00?oo00D00000003oo`00ool00?oo0000
0002003oo`0500000000ool00?oo003oo`0000000`00ool00`0000000?oo00000003003oo`030000
0000ool00?oo00D00?oo00<00000003oo`00ool00`00ool01@0000000?oo003oo`00ool000000080
0?oo00<00000003oo`00ool01000ool01@0000000?oo003oo`00ool0000000800?oo00<00000003o
o`00ool01000ool00`0000000?oo003oo`0D003oog00l?o`3P3oool001T0l?o`00<000000?3ol03`
oo006P3`oo000`000?l00?oo003oo`0<003oo`0300000000ool00?oo00@00?oo00D00000003oo`00
ool00?oo00000002003oo`0500000000ool00?oo003oo`0000000P00ool01@0000000?oo003oo`00
ool0000000800?oo1@000003003oo`0300000000ool00?oo00<00?oo00D00000003oo`00ool00?oo
00000002003oo`D000000P00ool01@0000000?oo003oo`00ool0000000800?oo00<00000003oo`00
ool01000ool5000001800?ooL03`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00K0?3ol0030000
o`00ool00?oo00/00?oo00<00000003oo`00ool01000ool01@0000000?oo003oo`00ool000000080
0?oo0P000002003oo`0400000000ool00?oo000000<00?oo00@00000003oo`00ool000000`00ool0
100000000?oo003oo`00ool2000000@00?oo00<00000003oo`00ool00P000002003oo`0500000000
ool00?oo003oo`0000000P00ool2000000800?oo00@00000003oo`00ool000000`00ool010000000
0?oo003oo`000003003oo`0300000000ool00?oo00l00?ooL@3`oo0>0?ooo`006@3`oo000`000000
l?o`0?3ol00L0?3ol0d00?oo00<00000003oo`00ool01@00ool3000000800?oo0P0000000`00ool0
000000000002003oo`<0000000@00?oo00000000000000000P00ool3000000<00?oo0P0000000`00
ool0000000000003003oo`80000000<00?oo0000000000000P00ool3000000800?oo0P0000000`00
ool0000000000004003oo`@000000`00ool3000001400?oo00<0003o0?3ol03`oo00K`3`oo0>0?oo
o`006@3`oo000`000000l?o`0?3ol00L0?3ol0d00?oo00D00000003oo`00ool00?oo0000001E003o
o`030000o`3`oo00l?o`0700l?o`3P3oool001T0l?o`00<000000?3ol03`oo007@3`oo0=003oo`@0
0000E000ool00`000?l0l?o`0?3ol01a0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`01h0l?o`
H`00ool00`000?l0l?o`0?3ol01b0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`01l0l?o`H@00
ool00`000?l0l?o`0?3ol01c0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`01l0l?o`00<0003o
003oo`00ool0GP00ool00`000?l0l?o`0?3ol01c0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`
0200l?o`00<0003o003oo`00ool0G000ool00`000?l0l?o`0?3ol01d0?3ol0h0oooo000I0?3ol003
0000003`oo00l?o`0240l?o`00<0003o003oo`00ool0FP00oomh0?3ol0h0oooo000I0?3ol0030000
003`oo00l?o`0280l?o`00<0003o003oo`00ool0F000oomi0?3ol0h0oooo000I0?3ol0030000003`
oo00l?o`02<0l?o`0P000?mF003oog/0l?o`3P3oool001T0l?o`00<000000?3ol03`oo009@3`oo00
0`000?l00?oo003oo`1B003oog`0l?o`3P3oool001T0l?o`00<000000?3ol03`oo009P3`oo1C003o
o`80003oN`3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00X0?3ol5000?oo00<0003o0?3ol03`
oo00N`3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00Y0?3ol4h00?oo00<0003o0?3ol03`oo00
O03`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00Z0?3ol003003oo`000?l00?oo04P00?oo0P00
0?mo0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`02/0l?o`0P000?m7003oo`030000o`3`oo00
l?o`07l0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00;@3`oo030000od400?ooQ@3`oo0>0?oo
o`006@3`oo000`000000l?o`0?3ol00`0?3ol080003o?@00oon70?3ol0h0oooo000I0?3ol0030000
003`oo00l?o`0380l?o`00<0003o003oo`00ool0>000ool00`000?l0l?o`0?3ol0260?3ol0h0oooo
000I0?3ol0030000003`oo00l?o`03<0l?o`>000ool20000ohT0l?o`3P3oool001T0l?o`00<00000
0?3ol03`oo00=P3`oo0b003oo`<0003oR`3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00i0?3o
l080003o:`00ool20000ohh0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00>`3`oo030000obH0
0?ooTP3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol00n0?3ol0<0003o7000ool20000o`800?oo
U@3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol0150?3ol0<00?oo20000?l7003oo`H0003oV@3`
oo0>0?ooo`006@3`oo000`000000l?o`0?3ol03f0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`
0?H0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00mP3`oo0>0?ooo`006@3`oo000`000000l?o`
0?3ol03f0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`0?H0l?o`3P3oool001T0l?o`00<00000
0?3ol03`oo00mP3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol03f0?3ol0h0oooo000I0?3ol003
0000003`oo00l?o`0?H0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00mP3`oo0>0?ooo`006@3`
oo000`000000l?o`0?3ol03f0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`0:@0l?o`0`00001?
0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`0:L0l?o`00<000000?3ol03`oo00C03`oo0>0?oo
o`006@3`oo000`000000l?o`0?3ol01o0?3ol0@00000103`oo05000000@0l?o`00<000000?3ol03`
oo000`3`oo0400000080l?o`1@0000030?3ol0@000000`3`oo04000000050?3ol000000000000000
003`oo000`0000020?3ol0<00000103`oo0400000380l?o`3P3oool001T0l?o`00<000000?3ol03`
oo00P03`oo0010000000l?o`0?3ol00000050?3ol0030000003`oo00l?o`00<0l?o`00<000000?3o
l00000000`3`oo000`000000l?o`0?3ol0050?3ol0030000003`oo00l?o`00<0l?o`00D000000?3o
l03`oo00l?o`000000020?3ol0030000003`oo00l?o`00@0l?o`00D000000?3ol03`oo00l?o`0000
00020?3ol0050000003`oo00l?o`0?3ol00000000P3`oo000`000000l?o`0?3ol00d0?3ol0h0oooo
000I0?3ol0030000003`oo00l?o`0800l?o`00D000000?3ol03`oo00l?o`000000040?3ol0030000
003`oo00l?o`00<0l?o`00<000000?3ol00000000`3`oo000`000000l?o`0?3ol0050?3ol0030000
003`oo00l?o`00<0l?o`00D000000?3ol03`oo00l?o`000000020?3ol0030000003`oo00l?o`00@0
l?o`00D000000?3ol03`oo00l?o`000000020?3ol0030000003`oo00l?o`00@0l?o`00<000000?3o
l03`oo00=03`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol0200?3ol0050000003`oo00l?o`0?3o
l0000000103`oo000`000000l?o`0?3ol0020?3ol0050000003`oo00l?o`0?3ol00000000P3`oo05
000000<0l?o`00<000000?3ol03`oo000`3`oo001@000000l?o`0?3ol03`oo0000000080l?o`1@00
00020?3ol0050000003`oo00l?o`0?3ol00000000P3`oo000`000000l?o`0?3ol0040?3ol0D00000
<P3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol0200?3ol0050000003`oo00l?o`0?3ol0000000
103`oo000`000000l?o`0?3ol0020?3ol0050000003`oo00l?o`0?3ol00000000P3`oo001@000000
l?o`0?3ol03`oo00000000<0l?o`0P0000040?3ol0030000003`oo00l?o`008000000P3`oo001@00
0000l?o`0?3ol03`oo0000000080l?o`0P0000020?3ol0040000003`oo00l?o`000000<0l?o`00@0
00000?3ol03`oo0000000`3`oo000`000000l?o`0?3ol00`0?3ol0h0oooo000I0?3ol0030000003`
oo00l?o`0800l?o`00D000000?3ol03`oo00l?o`000000020?3ol0<000000`3`oo03000000040?3o
l0000000000000000080l?o`0`0000030?3ol080000000<0l?o`0000000000000`3`oo0200000003
0?3ol000000000000080l?o`0`0000020?3ol080000000<0l?o`000000000000103`oo04000000<0
l?o`0`00000c0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`0800l?o`00@000000?3ol03`oo00
0000LP3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol01o0?3ol0@000001P3`oo000`000000l?o`
0?3ol01Z0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`0?H0l?o`3P3oool001T0l?o`00<00000
0?3ol03`oo00mP3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol03f0?3ol0h0oooo000I0?3ol003
0000003`oo00l?o`0?H0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00mP3`oo0>0?ooo`006@3`
oo000`000000l?o`0?3ol03f0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`0?H0l?o`3P3oool0
01T0l?o`00<000000?3ol03`oo00mP3`oo0>0?ooo`006@3`oo000`000000l?o`0?3ol03f0?3ol0h0
oooo000I0?3ol0030000003`oo00l?o`0?H0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00mP3`
oo0>0?ooo`006@3`oo000`000000l?o`0?3ol03f0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`
0?H0l?o`3P3oool001T0l?o`00<000000?3ol03`oo00mP3`oo0>0?ooo`006@3`oo000`000000l?o`
0?3ol03f0?3ol0h0oooo000I0?3ol0030000003`oo00l?o`0080l?o`1000003`0?3ol0h0oooo000I
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o@3oool001T0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3m0?ooo`006@3oool00`000000oooo0?ooo`040?ooo`80
0000oP3oool001T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000003n0?ooo`006@3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000?d0oooo000I0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo0000003m0?ooo`006@3oool010000000oooo0?oo
o`3oool3000000040?ooo`000000000000000?`0oooo000I0?ooo`030000003oool0oooo0?l0oooo
1@3oool001T0oooo00<000000?ooo`3oool0o`3oool50?ooo`006@3oool00`000000oooo0?ooo`3o
0?ooo`D0oooo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {191, 0}} -> {0, 0, 0, 0}}],
  StyleBox["  \n\t\t\tFigure 4.3",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The radius of convergence of a power series.  \n\t\t\t    What happens \
on the boundary circle may be unknown. "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 4.16 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Radius of Convergence",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RadiusofConvergence.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  For the power series function ",
  Cell[BoxData[
      \(f \((z)\) = \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                c\_n\) \((z - \[Alpha])\)\^n\)]],
  ",  we can find  ",
  Cell[BoxData[
      \(\[Rho]\)]],
  " , its ",
  StyleBox[ButtonBox["radius of convergence",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RadiusofConvergence.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ", by any of the following methods:\n\n\t",
  StyleBox["(i)    ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Cauchy's Root Test",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RootTest.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  StyleBox[":",
    FontColor->RGBColor[0, 0, 1]],
  "   ",
  Cell[BoxData[
      \(\[Rho] = 
        1\/\(lim\+\(n \[Rule] \[Infinity]\)\ \ \(\(|\)\(c\_n\)\( | \^\(1\/n\)\
\)\)\)\)]],
  "     (provided that the limit exists.)  \n\n\t",
  StyleBox["(ii)   ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Cauchy-Hadamard Formula",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Cauchy-HadamardTheorem.html"], None},
    
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  StyleBox[":",
    FontColor->RGBColor[0, 0, 1]],
  "   ",
  Cell[BoxData[
      \(\[Rho] = 
        1\/\(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ \ \(\(|\)\(c\_n\)\( | \
\^\(1\/n\)\)\)\)\)]],
  "     (the limit superior always exists.)  \n\n\t",
  StyleBox["(iii)  ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["d'Alembert's Ratio Test",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RatioTest.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  StyleBox[":",
    FontColor->RGBColor[0, 0, 1]],
  "   ",
  Cell[BoxData[
      \(\[Rho] = \ 
        1\/\(lim\+\(n \[Rule] \[Infinity]\)\ \(\(|\)\(c\_\(n + 1\)\/c\_n\)\(|\
\)\)\)\)]],
  "     (provided that the limit exists.)\n\nWe set  ",
  Cell[BoxData[
      \(\[Rho] = \[Infinity]\)]],
  "  if the limit equals  0,  and  ",
  Cell[BoxData[
      \(\[Rho] = 0\)]],
  "  if the  limit equals  ",
  Cell[BoxData[
      \(\[Infinity]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.16 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\<\
\tWe now give an example illustrating each of these cases.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 4.21.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The infinite series  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(n\  + \ 2\)\/\(3 \
 n\  + \ 1\))\)\^n\) \((z - 4)\)\^n\)]],
  "  has radius of convergence ",
  Cell[BoxData[
      \(\[Rho] = 3\)]],
  " Cauchy's root test because  \n\n\t\t\t",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ \(\(|\)\(c\_n\)\( | \^\(1\/n\)\)\)\  \
= \ \(lim\+\(n \[Rule] \[Infinity]\)\ \((\((\(n + 2\)\/\(3  n + \
1\))\)\^n)\)\^\(1\/n\)\  = \ \(lim\+\(n \[Rule] \[Infinity]\)\ \(n + 2\)\/\(3 \
 n + 1\)\  = \ 1\/3\)\)\)]],
  ",  \n\nhence   ",
  Cell[BoxData[
      \(\[Rho] = \(1\/\(lim\+\(n \[Rule] \[Infinity]\)\ \ \(\(|\)\(c\_n\)\( | \
\^\(1\/n\)\)\)\) = \ \(1\/\(1\/3\)\  = \ 3\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the formula for the coefficients.  ", "Text"],

Cell[BoxData[{
    \(\(Remove[c];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[L, n, Pn, R];\)\ \), "\[IndentingNewLine]", 
    \(\(c\_n_\  = \ \((\(n + 2\)\/\(3  n + 1\))\)\^n;\)\ \), "\
\[IndentingNewLine]", 
    \(\(p\_n_ = \((c\_n)\)\^\(1/n\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\_n\) = \>\"", 
        c\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\@\(\(\[VerticalBar]\)\(c\_n\)\(\[VerticalBar]\)\)\%\
n\) = \>\"", p\_n\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\@\(\(\[VerticalBar]\)\(c\_n\)\(\[VerticalBar]\)\)\%\
n\) = \>\"", PowerExpand[p\_n]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Use the Cauchy root test and find the limit and then the radius of \
convergence R.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(L\  = \ Limit[\ p\_n, \ n \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(\[Rho]\  = \(\(\ \)\(1\)\)\/L;\)\ \), "\n", 
    \(\(Print[\*"\"\<L = \!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(\@\(\(\
\[VerticalBar]\)\(c\_n\)\(\[VerticalBar]\)\)\%n\) = \!\(lim\+\(n \[Rule] \
\[Infinity]\)\) \>\"", p\_n\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<L = \!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(\@\(\(\
\[VerticalBar]\)\(c\_n\)\(\[VerticalBar]\)\)\%n\) = \!\(lim\+\(n \[Rule] \
\[Infinity]\)\) \>\"", PowerExpand[p\_n]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<L = \!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(\@\(\(\
\[VerticalBar]\)\(c\_n\)\(\[VerticalBar]\)\)\%n\) = \>\"", 
        L];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The limit is  L = \>", L];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<The radius of convergence is \[Rho] = \!\(1\/L\) = \
\>\"", \[Rho]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The series  ",
  Cell[BoxData[
      \(f \((z)\) = \[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(n\  + \ 2\)\/\(3  n\ \
 + \ 1\))\)\^n\) \((z - 4)\)\^n\)]],
  "  will converge in the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z - 4\)\(|\)\(\(<\)\(3\)\)\)\)]],
  ".  \n\nWe can plot some of the partial sums and see that they converge. \
Convergence will be faster if we choose a smaller disk ",
  Cell[BoxData[
      \(\(\(|\)\(z - 4\)\(|\)\(\(<\)\(r\)\)\)\)]],
  "  the following graphs use the smaller disk with  ",
  Cell[BoxData[
      \(r = 1\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[g, k, m, n, s];\)\ \), "\[IndentingNewLine]", 
    \(\(s[z_, 
          n_] = \[Sum]\+\(k = 0\)\%n\(\((\(k + 2\)\/\(3  k + 1\))\)\^k\) \((z \
- 4)\)\^k;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(For\ [m = 2, 
        m \[LessEqual] 5, \(m++\), \[IndentingNewLine]g[z_] = 
          s[z + 4, m]; \ \[IndentingNewLine]PolarMap[
          g\ , {0, 1.0, 0.2}, {0, 
            2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
                3}, {\(-1.5\), 1.5}}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 3, 1], 
              Range[\(-\(3\/2\)\), 3\/2, 1\/2]}, 
          AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Red, 
              Blue}]; \ \[IndentingNewLine]Print["\<s[z,\>", m, "\<] = \>", 
          s[z, m]];\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We see that the series  ",
  Cell[BoxData[
      \(f \((z)\) = \[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(n\  + \ 2\)\/\(3  n\ \
 + \ 1\))\)\^n\) \((z - 4)\)\^n\)]],
  "  is converging in the smaller disk  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"|", \(z - 4\), "|", 
          RowBox[{"<", " ", 
            RowBox[{"r", "   ", 
              StyleBox["where",
                FontFamily->"Times New Roman"], "   ", "r"}]}]}], 
        "=", \(1 < 3\)}]]],
  ".  \n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " try to determine the \"sum\" of this series."
}], "Text"],

Cell[BoxData[
    \(\[Sum]\+\(k = 0\)\%\[Infinity]\(\((\(k + 2\)\/\(3  k + 1\))\)\^k\) \((z \
- 4)\)\^k\)], "Input"],

Cell["\<\
Unfortunately, there is no known closed formula.  This is an instance where \
the infinite series is \"the answer.\"\
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.22.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   The infinite series  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(\[Sum]\+\(n = 1\)\%\[Infinity]\( c\_n\) z\^n\  = \ 
          4  z + 5\^2\ z\^2 + \(4\^3\) z\^3 + 5\^4\ z\^4 + \(4\^5\) z\^5 + 
              5\^6\ z\^6 +  ... \)\)]],
  "  has radius of convergence ",
  Cell[BoxData[
      \(\[Rho] = 1\/5\)]],
  " by the Cauchy-Hadamard formula.  We see this by calculating   \n\n\t\t\t\
",
  Cell[BoxData[
      \({\(|\)\(c\_n\)\( | \^\(1\/n\)\)}\  = \ {4, 5, 4, 5, 4, 5,  ... }\)]],
  ",  so  \n\n\t\t\t",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\  | 
          c\_n\( | \^\(1\/n\)\)\  = \ \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\
\)\ {4, 5, 4, 5, 4, 5,  ... }\  = \ 5\)\)]],
  ", \n\nhence  ",
  Cell[BoxData[
      \(\[Rho] = \(1\/\(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ \ \(\(|\)\(c\
\_n\)\( | \^\(1\/n\)\)\)\)\  = \ 1\/5\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.22.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
Enter the formula for the coefficients.  There is a formula for the even \
subscripts and a different formula for the odd subscripts.\
\>", "Text"],

Cell[BoxData[{
    \(\(Remove[c];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[k, limsup, n, \[Rho], R];\)\ \), "\[IndentingNewLine]", 
    \(\(c\_\(even, k_\) = 5\^k;\)\ \), "\[IndentingNewLine]", 
    \(\(c\_\(odd, k_\) = 4\^k;\)\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Flatten[Table[{c\_\(even, 2  k\), c\_\(odd, 2  k + 1\)}, {k, 0, 
              4}]];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Append[table, "\<...\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<{\!\(c\_n\)} = \>\"", 
        table];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(c\_\(2  k\)\) = \>\"", 
        c\_\(even, 2  k\)\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(c\_\(2  k + 1\)\) = \>\"", 
        c\_\(odd, 2  k + 1\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Use the Cauchy-Hadamard formula and find the radius of convergence R.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(lim1 = 
        Limit[\((c\_\(even, 2  k\))\)\^\(1\/\(2  k\)\), 
          k \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(lim2 = 
        Limit[\((c\_\(odd, 2  k + 1\))\)\^\(1\/\(2  k + 1\)\), 
          k \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(L = Max[lim1, lim2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(lim\+\(k \[Rule] \[Infinity]\)\) \!\(\@\(\(\
\[VerticalBar]\)\(c\_\(2  k\)\)\(\[VerticalBar]\)\)\%\(2  k\)\) =   \>\"", \
\*"\"\<\!\(lim\+\(k \[Rule] \[Infinity]\)\) \>\"", \((c\_\(even, 2  \
k\))\)\^\(1\/\(2  k\)\), "\<  = \>", lim1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(k \[Rule] \[Infinity]\)\) \!\(\@\(\(\
\[VerticalBar]\)\(c\_\(2  k + 1\)\)\(\[VerticalBar]\)\)\%\(2  k + 1\)\) = \
\>\"", \*"\"\<\!\(lim\+\(k \[Rule] \[Infinity]\)\) \>\"", \((c\_\(odd, 2  k + \
1\))\)\^\(1\/\(2  k + 1\)\), "\< = \>", lim2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<L = \!\(limsup\+\(n \[Rule] \[Infinity]\)\) \!\(\@\(\(\
\[VerticalBar]\)\(c\_n\)\(\[VerticalBar]\)\)\%n\)  = Max[\>\"", 
        lim1, "\<,\>", lim2, "\<]\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<L = \!\(limsup\+\(n \[Rule] \[Infinity]\)\) \!\(\@\(\(\
\[VerticalBar]\)\(c\_n\)\(\[VerticalBar]\)\)\%n\)  = \>\"", \[Rho]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<The radius of convergence is \[Rho] = \!\(1\/L\) = \
\>\"", 1\/L];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The series  ",
  Cell[BoxData[
      \(f \((z)\) = \(\[Sum]\+\(n = 1\)\%\[Infinity]\( c\_n\) z\^n = 
          1 + 4  z + 5\^2\ z\^2 + \(4\^3\) z\^3 + 
              5\^4\ z\^4 + \(4\^5\) z\^5 + 5\^6\ z\^6 +  ... \)\)]],
  "  has radius of convergence  ",
  Cell[BoxData[
      \(\[Rho] = 1\/5\)]],
  "  by the Cauchy-Hadamard formula because   ",
  Cell[BoxData[
      \(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ \@\(\(\[VerticalBar]\)\(c\_n\
\)\(\[VerticalBar]\)\)\%n\  = 5\)]],
  ".  \n\nWe can let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " find the sum of this series."
}], "Text"],

Cell[BoxData[{
    \(\(f0[
          z_] = \[Sum]\+\(k = 0\)\%\[Infinity]\( 5\^\(2\ k\)\) 
            z\^\(2\ k\);\)\ \), "\n", 
    \(\(f1[
          z_] = \[Sum]\+\(k = 0\)\%\[Infinity]\( 4\^\(2\ k + 1\)\) 
            z\^\(2\ k + 1\);\)\ \), "\n", 
    \(\(f[z_] = f0[z] + f1[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(f\_1\)[z] = \!\(\[Sum]\+\(k = \
0\)\%\[Infinity]\)\!\(5\^\(2\\\ k\)\)\!\(z\^\(2\\\ k\)\) = \>\"", 
        f0[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(f\_2\)[z] = \!\(\[Sum]\+\(k = \
0\)\%\[Infinity]\)\!\(4\^\(2\\\ k + 1\)\)\!\(z\^\(2\\\ k + 1\)\) = \>\"", 
        f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[z] = \!\(f\_1\)[z] + \!\(f\_2\)[z]\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Thus we see that f[z] is composed of two \"infinite geometric series\"  ",
  Cell[BoxData[
      \(f\_1[z]\ \ and\ \ \ f\_2[z]\)]],
  ", whose radius of convergence are  ",
  Cell[BoxData[
      RowBox[{\(R\_1\), "=", 
        RowBox[{
          RowBox[{\(1\/5\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], "   ", \(R\_2\)}], 
          "=", \(1\/4\)}]}]]],
  ", respectively. Hence the radius of convergence of f[z] must be  ",
  Cell[BoxData[
      \(\[Rho] = \(min {1\/5, 1\/4} = 1\/5\)\)]],
  ".  \n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to compute the first few terms in the Maclaurin series for f[z] and \
compare them with the formula that was given."
}], "Text"],

Cell[BoxData[{
    \(\(s[z_] = Series[f[z], {z, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", s[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We can plot some of the partial sums and see that they converge. \
Convergence will be faster if we choose a smaller disk ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(r\)\)\)\)]],
  "  the following graphs use the smaller disk with  ",
  Cell[BoxData[
      \(r = 0.16 < 1\/5\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[g, k, m, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(For\ [m = 3, 
      m \[LessEqual] 7, \(m++\), \[IndentingNewLine]g[z_] = 
        Normal[Series[f[z], {z, 0, m}]]; \ \[IndentingNewLine]PolarMap[
        g\ , {0, 0.16, 0.02}, {0, 
          2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
              2.8}, {\(-1.4\), 1.4}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 3, 1], 
            Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, 
            Red}]; \ \[IndentingNewLine]Print["\<s[z,\>", m, "\<] = \>", 
        g[z]];\ \ ]\), "\[IndentingNewLine]", 
    \(\(PolarMap[
        f, {0, 0.16, 0.02}, {0, 
          2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
              2.8}, {\(-1.4\), 1.4}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 3, 1], 
            Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Red}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.23.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The infinite series  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \[Sum]\+\(n = 0\)\%\[Infinity] z\^n\/\(n!\)\)]],
  "  has radius of convergence ",
  Cell[BoxData[
      \(\[Rho] = 8\)]],
  " by the ratio test because \n\n\t\t\t",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ \(\(|\)\(c\_\(n + 1\)\/c\_n\)\(|\)\)\ \
\  = \ \ \(lim\+\(n \[Rule] \[Infinity]\)\ \(\(|\)\(\(n!\)\/\(\((n + 
                        1)\)!\)\)\(|\)\)\ \  = \ \ \(lim\+\(n \[Rule] \
\[Infinity]\)\ 1\/\(n + 1\)\  = \ 0\)\)\)]],
  ".\n\nSince the limit equals  0,  we set  ",
  Cell[BoxData[
      \(\[Rho] = \[Infinity]\)]],
  ".    "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.23.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the formula for the coefficients.", "Text"],

Cell[BoxData[{
    \(\(Remove[c, q];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[L, n, R, z];\)\ \), "\n", 
    \(\(c\_n_\  = \ 1\/\(n!\);\)\ \), "\n", 
    \(\(q\_n_\  = \ c\_\(n + 1\)\/c\_n;\)\ \), "\n", 
    \(\(Print[\*"\"\<    \!\(c\_n\) = \>\"", 
        c\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<|\!\(c\_\(n + 1\)\/c\_n\)| = \>\"", q\_n];\)\ \), "\n", 
    \(\(q\_n_\  = \ FullSimplify[q\_n];\)\ \), "\n", 
    \(\(Print[\*"\"\<|\!\(c\_\(n + 1\)\/c\_n\)| = \>\"", 
        q\_n];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Use d'Alembert's ratio test and find the limit and then the radius of \
convergence R.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(L\  = \ Limit[\ q\_n, \ n \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(R\  = \ Limit[\ 1\/q\_n, \ n \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(Print[\*"\"\<  L = \!\(lim\+\(n \[Rule] \[Infinity]\)\) |\!\(c\_\(n + \
1\)\/c\_n\)| = \!\(lim\+\(n \[Rule] \[Infinity]\)\) (\>\"", q\_n, "\<) = \>", 
        L];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The limit  is  L = \>", L];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The radius of convergence is R = \>"\ , 
        1\/"\<L\>", "\< = \>", R];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["The sum of the series is a well known function.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(f[z_]\  = \[Sum]\+\(n = 0\)\%\[Infinity] z\^n\/\(n!\)\), 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{\(Print[\*"\"\<f(z) = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(z\^n\/\(n!\)\) = \>\"", f[z]];\), 
      " "}], "\[IndentingNewLine]", "Null"}], "Input"],

Cell["\<\
We can plot some of the partial sums and see that they converge to f[z].\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[g, k, m, n, s];\)\ \), "\[IndentingNewLine]", 
    \(\(terms[n_] := 
        Table[z\^k\/\(k!\), {k, 0, n}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(For\ [m = 2, 
      m \[LessEqual] 5, \(m++\), \[IndentingNewLine]g[z_] = 
        ReplaceAll[terms[m], 
          List \[Rule] Plus]; \ \[IndentingNewLine]PolarMap[
        g\ , {0, 1.0, 0.2}, {0, 
          2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
              3}, {\(-1.5\), 1.5}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 3, 1], 
            Range[\(-\(3\/2\)\), 3\/2, 1\/2]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, 
            Blue}]; \ \[IndentingNewLine]Print["\<s[z,\>", m, "\<] = \>", 
        g[z]];\ \ ]\), "\[IndentingNewLine]", 
    \(\(PolarMap[
        f\ , {0, 1.0, 0.2}, {0, 
          2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
              3}, {\(-1.5\), 1.5}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 3, 1], 
            Range[\(-\(3\/2\)\), 3\/2, 1\/2]}, 
        AxesLabel \[Rule] {"\<u\>", "\<u\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[g, k, m, n, s];\)\ \), "\[IndentingNewLine]", 
    \(\(terms[n_] := 
        Table[z\^k\/\(k!\), {k, 0, n}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(For\ [m = 2, 
      m \[LessEqual] 5, \(m++\), \[IndentingNewLine]g[z_] = 
        ReplaceAll[terms[m], 
          List \[Rule] Plus]; \ \[IndentingNewLine]CartesianMap[
        g\ , {\(-1\), 1, 0.2}, {\(-1\), 1, 
          0.2}, \[IndentingNewLine]PlotRange \[Rule] {{0, 3}, {\(-2.5\), 
              2.5}}, AspectRatio \[Rule] 
          5\/3, \[IndentingNewLine]Ticks \[Rule] {Range[0, 3, 1], 
            Range[\(-2\), 2, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, 
            Blue}]; \ \[IndentingNewLine]Print["\<s[z,\>", m, "\<] = \>", 
        g[z]];\ \ ]\), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        f\ , {\(-1\), 1, 0.2}, {\(-1\), 1, 
          0.2}, \[IndentingNewLine]PlotRange \[Rule] {{0, 3}, {\(-2.5\), 
              2.5}}, AspectRatio \[Rule] 
          5\/3, \[IndentingNewLine]Ticks \[Rule] {Range[0, 3, 1], 
            Range[\(-2\), 2, 1]}, AxesLabel \[Rule] {"\<u\>", "\<u\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the radius of convergence of the infinite series  ",
  Cell[BoxData[
      \(S \((z)\) = 
        1 + z\/2 + z\^2\/3\^2 + z\^3\/2\^3 + z\^4\/3\^4 + z\^5\/2\^5 + 
            z\^6\/3\^6 + z\^7\/2\^7 + z\^8\/3\^8 + z\^9\/2\^9 + 
            z\^10\/3\^10 + z\^11\/2\^11 +  ... \)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "The sequence of coefficients is  ",
  Cell[BoxData[
      \({1, 1\/2, 1\/3\^2, 1\/2\^3, 1\/3\^4, 1\/2\^5, 1\/3\^6, 1\/2\^7, 
        1\/3\^8, 1\/2\^9, 1\/3\^10, 1\/2\^11,  ... }\)]],
  ".   \nThe coefficients with even subscripts are ",
  Cell[BoxData[
      \(a\_\(2  k\) = 1\/3\^\(2  k\)\)]],
  ", and the coefficients with odd subscripts are  ",
  Cell[BoxData[
      \(a\_\(2  k + 1\) = 1\/2\^\(2  k + 1\)\)]],
  ".  \nSo that we have \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[VerticalSeparator]", \(a\_\(2  k\)\), 
          StyleBox[\( \[VerticalSeparator] \^\(1\/\(2\ k\)\)\),
            FontSize->12]}], "=", 
        RowBox[{
          StyleBox[\(\((1\/3\^\(2  k\))\)\^\(1\/\(2\ k\)\)\),
            FontSize->12], "  ", "=", " ", \(1\/3\)}]}]]],
  "    and    ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[VerticalSeparator]", \(a\_\(2  k + 1\)\), 
          StyleBox[\( \[VerticalSeparator] \^\(1\/\(2\ k + 1\)\)\),
            FontSize->12]}], "=", " ", 
        RowBox[{
          StyleBox[\(\((1\/2\^\(2  k + 1\))\)\^\(1\/\(2\ k + 1\)\)\),
            FontSize->12], " ", "=", " ", \(1\/2\)}]}]]],
  ".  \n\nIt follows that   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(lim\ sup\)\+\(n\  \[Rule] \ \[Infinity]\)\), "  ", 
          RadicalBox[
            
            StyleBox[\(\(\[VerticalSeparator]\)\(\(a\_n\) 
                  z\^n\)\(\[VerticalSeparator]\)\),
              FontSize->12], "n"]}], " ", "=", 
        " ", \(\(lim\ sup\)\+\(n\  \[Rule] \ \[Infinity]\)\ {1, 1\/2, 1\/3, 
              1\/2, 1\/3, 1\/2, 1\/3,  ... }\  = \ 1\/2\)}]]],
  ".   \nhence  ",
  Cell[BoxData[
      \(\[Rho] = \(1\/\(\(lim\ sup\)\+\(n \[Rule] \[Infinity]\)\ \ \(\(|\)\(c\
\_n\)\( | \^\(1\/n\)\)\)\)\  = \ \(1\/\(1\/2\)\  = \ 2\)\)\)]],
  ".  "
}], "Text"],

Cell["We are done.", "Text"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The given series is the sum of two geometric series:   ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 0\)\%\[Infinity] z\^\(2  k\)\/3\^\(2  k\)\)]],
  "   and   ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 0\)\%\[Infinity] z\^\(2  k + 1\)\/2\^\(2  k + 1\)\)]],
  ",  and are known to have radii of convergence ",
  Cell[BoxData[
      \(R\_1 = 3\)]],
  " and ",
  Cell[BoxData[
      \(R\_2 = 2\)]],
  ", respectively.  Hence their sum has radii of convergence ",
  Cell[BoxData[
      \(R = \(min {R\_1, R\_2} = 2\)\)]],
  ".\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(1 + z\/2 + z\^2\/3\^2 + z\^3\/2\^3 + z\^4\/3\^4 + z\^5\/2\^5 + 
          z\^6\/3\^6 + z\^7\/2\^7 + z\^8\/3\^8 + z\^9\/2\^9 + z\^10\/3\^10 + 
          z\^11\/2\^11 +  ... \)\(\[IndentingNewLine]\)
      \)\ \ \), "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \ \)\(1 + z\/2 + z\^2\/9 + z\^3\/8 + z\^4\/81 + z\^5\/32 + 
            z\^6\/729 + z\^7\/128 + z\^8\/6561 + z\^9\/512 + z\^10\/59049 + 
            z\^11\/2048 +  ... \)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "The even and odd series are:\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(1 + z\^2\/9 + z\^4\/81 + z\^6\/729 + z\^8\/6561 + 
          z\^10\/59049 +  ... \)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\(\(\(=\)\(\ \ \)\(\[Sum]\+\(k = 0\)\%\[Infinity] z\^\(2  k\)\/3\^\(2 \
 k\)\ \  = \ \ \(1/\((1 - z\^2\/3\^2)\)\  = \ 
            3\^2\/\(3\^2 - z\^2\)\)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \)\(9\/\(9 - z\^2\)\)\)\)}]],
  "    \n\n\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(z\/2 + z\^3\/8 + z\^5\/32 + z\^7\/128 + z\^9\/512 + 
          z\^11\/2048 +  ... \)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\(\(\(=\)\(\ \ \)\(\[Sum]\+\(k = 0\)\%\[Infinity] z\^\(2  k + \
1\)\/2\^\(2  k + 1\)\  = \ \(z\/2\) \(\[Sum]\+\(k = 0\)\%\[Infinity] z\^\(2  \
k\)\/2\^\(2  k\)\)\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\(\(\(=\)\(\ \)\(\((z\/2)\)/\((1 - 
                z\^2\/2\^2)\)\  = \ \ \((z\/2)\) \((4\/\(4 - z\^2\))\)\)\)\(\ \
\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \)\(\(2  z\)\/\(4 - z\^2\)\)\)\)}]],
  "  \n\nTherefore, S(z) is the sum of two geometric series:\n\n\t\t\t",
  Cell[BoxData[
      \(S \((z)\)\ \  = \ \ 9\/\(9 - z\^2\)\  + \ \(2  z\)\/\(4 - z\^2\)\)]],
  "\n\nwhich might be printed by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as  ",
  Cell[BoxData[
      \(S \((z)\)\ \  = \ \ \ \(-\(9\/\(\(-9\) + 
                  z\^2\)\)\)\  + \ \(-\(\(2\ z\)\/\(\(-4\) + z\^2\)\)\)\)]]
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<S(z) = \!\(9\/\(9 - z\^2\)\) + \!\(\(2  z\)\/\(4 - \
z\^2\)\)\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S(z) = \>", 
        Series[9\/\(9 - z\^2\) + \(2  z\)\/\(4 - z\^2\), {z, 0, 
            11}]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(f[
          z_] = \[Sum]\+\(k = 0\)\%\[Infinity] z\^\(2  k\)\/3\^\(2  k\);\)\ \
\), "\[IndentingNewLine]", 
    \(\(g[
          z_] = \[Sum]\+\(k = 0\)\%\[Infinity] z\^\(2  k + 1\)\/2\^\(2  k + 1\
\);\)\ \), "\[IndentingNewLine]", 
    \(\(S[z_] = f[z]\  + \ g[z];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[z] = \!\(9\/\(9 - z\^2\)\) = \!\(\[Sum]\+\(k = 0\)\%\
\[Infinity]\)\!\(z\^\(2  k\)\/3\^\(2  k\)\) = \>\"", 
        Series[f[z], {z, 0, 11}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<g[z] = \!\(\(2  z\)\/\(4 - z\^2\)\) = \!\(\[Sum]\+\(k = \
0\)\%\[Infinity]\)\!\(z\^\(2  k + 1\)\/2\^\(2  k + 1\)\) = \>\"", 
        Series[g[z], {z, 0, 11}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[z] = \!\(9\/\(9 - z\^2\)\) + \!\(\(2  z\)\/\(4 - \
z\^2\)\) = \!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(z\^\(2  k\)\/3\^\(2  k\)\) \
+ \!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(z\^\(2  k + 1\)\/2\^\(2  k + \
1\)\)\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[z] = \>", 
        Series[S[z], {z, 0, 11}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[z] = \!\(9\/\(9 - z\^2\)\) = \!\(\[Sum]\+\(k = 0\)\%\
\[Infinity]\)\!\(z\^\(2  k\)\/3\^\(2  k\)\) = \>\"", 
        f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<g[z] = \!\(\(2  z\)\/\(4 - z\^2\)\) = \!\(\[Sum]\+\(k = \
0\)\%\[Infinity]\)\!\(z\^\(2  k + 1\)\/2\^\(2  k + 1\)\) = \>\"", 
        g[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[z] = \!\(9\/\(9 - z\^2\)\) + \!\(\(2  z\)\/\(4 - \
z\^2\)\) = \!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(z\^\(2  k\)\/3\^\(2  k\)\) \
+ \!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(z\^\(2  k + 1\)\/2\^\(2  k + \
1\)\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[z] = \>", S[z]\ ];\)\)}], "Input"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can investigate what happens as ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) \[Rule] \ 2\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<S[z] = \>", S[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[1] = \>", S[1]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(19\/10\)] = \>\"", 
        S[19\/10]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(199\/100\)] = \>\"", 
        S[199\/100]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(1999\/1000\)] = \>\"", 
        S[1999\/1000]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(19999\/10000\)] = \>\"", 
        S[19999\/10000]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[2] =  \!\(\[Sum]\+\(k = \
0\)\%\[Infinity]\)\!\(\((2)\)\^\(2  k\)\/3\^\(2  k\)\) + \!\(\[Sum]\+\(k = \
0\)\%\[Infinity]\)\!\(\((2)\)\^\(2  k + 1\)\/2\^\(2  k + 1\)\)\>\""\ ];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<S[2] = \>", \ \[Sum]\+\(k = 0\)\%\[Infinity]\((2)\)\^\(2  \
k\)\/3\^\(2  k\)\  + \ \[Sum]\+\(k = 0\)\%\[Infinity]\((2)\)\^\(2  k + 1\)\/2\
\^\(2  k + 1\)\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<S[z] = \>", S[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[\[ImaginaryI]] = \>", 
        S[\[ImaginaryI]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(19\/10\)\[ImaginaryI]] = \>\"", 
        S[\(19\/10\) \[ImaginaryI]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(199\/100\)\[ImaginaryI]] = \>\"", 
        S[\(199\/100\) \[ImaginaryI]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(1999\/1000\)\[ImaginaryI]] = \>\"", 
        S[\(1999\/1000\) \[ImaginaryI]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(19999\/10000\)\[ImaginaryI]] = \>\"", 
        S[\(19999\/10000\) \[ImaginaryI]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[2\[ImaginaryI]] =  \!\(\[Sum]\+\(k = \
0\)\%\[Infinity]\)\!\(\((2\\\ \[ImaginaryI])\)\^\(2  k\)\/3\^\(2  k\)\) + \
\!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(\((2\\\ \[ImaginaryI])\)\^\(2  k + \
1\)\/2\^\(2  k + 1\)\)\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[2\[ImaginaryI]] = \>", \ \[Sum]\+\(k = \
0\)\%\[Infinity]\((2\ \[ImaginaryI])\)\^\(2  k\)\/3\^\(2  k\)\  + \ \
\[Sum]\+\(k = 0\)\%\[Infinity]\((2\ \[ImaginaryI])\)\^\(2  k + 1\)\/2\^\(2  k \
+ 1\)\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Caveat.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  In some cases involving complex numbers, earlier versions of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will report a sum when the series actually diverges.  In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.1 the following series converges."
}], "Text"],

Cell[BoxData[
    \(\[Sum]\+\(n = 0\)\%\[Infinity]\((\(3 + 4  \[ImaginaryI]\)\/5)\)\^n\)], \
"Input"],

Cell[TextData[{
  "The above series actually diverges because ",
  Cell[BoxData[
      \(\(\(|\)\(\((\(3 + 4  \[ImaginaryI]\)\/5)\)\^n\)\(|\)\)\  = \ \
\(\(\(|\)\(\(3 + 4  \[ImaginaryI]\)\/5\)\( | \^n\)\)\  = \ 1\)\)]],
  "  for all ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ".\n\nMost likely this occurs because ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.2 is summing the series and then making a substitution."
}], "Text"],

Cell[BoxData[
    \(1/\((1 - \(3 + 4  \[ImaginaryI]\)\/5)\)\)], "Input"],

Cell["Now try another value.", "Text"],

Cell[BoxData[
    \(\[Sum]\+\(n = 0\)\%\[Infinity]\((\(3 + 4  \[ImaginaryI]\)\/4)\)\^n\)], \
"Input"],

Cell[TextData[{
  "Indeed, the above series diverges because ",
  Cell[BoxData[
      \(\(\(|\)\(\((\(3 + 4  \[ImaginaryI]\)\/5)\)\^n\)\(|\)\)\  = \ \
\(\(\(|\)\(\(3 + 4  \[ImaginaryI]\)\/4\)\( | \^n\)\)\  = \ 
          5\/4\  > \ 1\)\)]],
  "  for all ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ".\n\nThis bug has been correct in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.1 and the above series does not converge.\n\nHowever, you have been \
given a warning!"
}], "Text"],

Cell[TextData[{
  StyleBox["Caveat.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The mathematical analysis proves that the series ",
  Cell[BoxData[
      \(\(\(\ \ \)\(\[Sum]\+\(k = 0\)\%\[Infinity]\((\(6 + 8  \[ImaginaryI]\)\
\/5)\)\^\(2  k\)\/3\^\(2  k\)\  + \ \[Sum]\+\(k = 0\)\%\[Infinity]\((\(6 + 8  \
\[ImaginaryI]\)\/5)\)\^\(2  k + 1\)\/2\^\(2  k + 1\)\)\)\)]],
  " diverges.  But for some reason ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.1 will compute a sum.  For sure it is a mistake which is equivalent to \
substituting ",
  Cell[BoxData[
      \(Z = \(6 + 8  \[ImaginaryI]\)\/5\)]],
  " into the formula  ",
  Cell[BoxData[
      \(S[
          z]\  = \ \(-\(9\/\(\(-9\) + 
                  z\^2\)\)\) - \(2\ z\)\/\(\(-4\) + z\^2\)\)]],
  ".  This bug has been corrected in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.1."
}], "Text"],

Cell[BoxData[{
    \(\(Z = \(6 + 8  \[ImaginaryI]\)\/5;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<|\>", Z, "\<| = \>", Abs[Z]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(S[
          z_]\  = \ \(-\(9\/\(\(-9\) + 
                  z\^2\)\)\) - \(2\ z\)\/\(\(-4\) + z\^2\);\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<      S[z] = \>", S[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", Z, "\<] = \>", S[Z]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<S[z] = \>", S[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", \(1\/2\) Z, "\<] = \>", 
        S[\(1\/2\) Z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", \(19\/10\) Z, "\<] = \>", 
        S[\(19\/10\) Z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", \(199\/100\) Z, "\<] = \>", 
        S[\(199\/100\) Z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", \(1999\/1000\) Z, "\<] = \>", 
        S[\(1999\/1000\) Z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", \(19999\/10000\) Z, "\<] = \>", 
        S[\(19999\/10000\) Z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(\(6 + 8  \[ImaginaryI]\)\/5\)] =  \!\(\[Sum]\+\(k \
= 0\)\%\[Infinity]\)\!\(\((\(6 + 8  \[ImaginaryI]\)\/5)\)\^\(2  k\)\/3\^\(2  \
k\)\) + \!\(\[Sum]\+\(k = 0\)\%\[Infinity]\)\!\(\((\(6 + 8  \
\[ImaginaryI]\)\/5)\)\^\(2  k + 1\)\/2\^\(2  k + 1\)\)\>\""\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[\!\(\(6 + 8  \[ImaginaryI]\)\/5\)] = \>\"", \ \[Sum]\+\
\(k = 0\)\%\[Infinity]\((\(6 + 8  \[ImaginaryI]\)\/5)\)\^\(2  k\)\/3\^\(2  \
k\)\  + \ \[Sum]\+\(k = 0\)\%\[Infinity]\((\(6 + 8  \
\[ImaginaryI]\)\/5)\)\^\(2  k + 1\)\/2\^\(2  k + 1\)\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<WARNING. The series diverges.\>"];\)\), \
"\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell["\<\
\tWe come now to the main result of this section.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 4.17.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose the function  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                c\_n\) \((z - \[Alpha])\)\^n\)]],
  "  has radius of convergence  ",
  Cell[BoxData[
      \(\[Rho] > 0\)]],
  ".  Then\n\n",
  StyleBox["(i)",
    FontColor->RGBColor[0, 0, 1]],
  "    ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  "  is infinitely differentiable for all ",
  Cell[BoxData[
      \(z\ \[Epsilon]\ \(D\_\[Rho]\) \((\[Alpha])\)\)]],
  ".  In fact\n\n",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  "   for all  ",
  StyleBox["k",
    FontFamily->"Courier New"],
  ",   ",
  Cell[BoxData[
      RowBox[{\(\(f\^\((k)\)\) \((z)\)\), " ", "=", " ", 
        RowBox[{
          RowBox[{\(\[Sum]\+\(n = 0\)\%\[Infinity] n \((n - 1)\)\), 
            StyleBox["...",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}], \((n - k + 
              1)\), \(c\_n\), \(\((z - \[Alpha])\)\^\(n - k\)\)}]}]]],
  ";   and\n\n",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  Cell[BoxData[
      \(c\_k = \(\(f\^\((k)\)\) \((\[Alpha])\)\)\/\(k!\)\)]],
  "  where  ",
  Cell[BoxData[
      \(\(f\^\((k)\)\) \((\[Alpha])\)\)]],
  "  denotes the ",
  Cell[BoxData[
      \(k\^th\)]],
  " derivative of ",
  StyleBox["f",
    FontFamily->"Courier New"],
  ".  (When ",
  Cell[BoxData[
      \(k = 0\)]],
  ",  ",
  Cell[BoxData[
      \(f\^\((k)\)\)]],
  " denotes the function ",
  Cell[BoxData[
      \(f\)]],
  " itself so that ",
  Cell[BoxData[
      \(\(f\^\((0)\)\) \((z)\) = f \((z)\)\)]],
  " for all z.)"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 4.17 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.24.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that   ",
  Cell[BoxData[
      \(g \((z)\)\  = \ \(\[Sum]\+\(n = 0\)\%\[Infinity]\((n + 1)\) 
              z\^n\  = \ 1\/\((1\  - \ z)\)\^2\)\)]],
  "   for all  ",
  Cell[BoxData[
      \(z\ \[Epsilon]\ \(D\_1\) \((0)\)\)]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We know from Theorem 4.12 that  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(1\/\((1\  - \ z)\)\  = \ \(\(\[Sum]\+\(n = 
                  0\)\%\[Infinity]\)\(z\^n\)\(\ \)\)\)\)]],
  "  for all  ",
  Cell[BoxData[
      \(z\ \[Epsilon]\ \(D\_1\) \((0)\)\)]],
  ".  If we set k=1 in Theorem 4.16, part (ii), then\n\n\t\t\t  ",
  Cell[BoxData[
      \(f' \((z)\)\  = \ \(1\/\((1\  - \ z)\)\^2\  = \ \(\[Sum]\+\(n = 1\)\%\
\[Infinity]\ n\ z\^\(n - 1\)\ \  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\((n + 
                    1)\) z\^n\)\)\)]],
  ", \n\nfor all  ",
  Cell[BoxData[
      \(z\ \[Epsilon]\ \(D\_1\) \((0)\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Use the fact that  ",
  Cell[BoxData[
      \(S \((z)\) = \(\[Sum]\+\(n = 0\)\%\[Infinity] z\^n = 
          1\/\(1\  - \ z\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(S' \((z)\) = g \((z)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Remove[z];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Clear[f, n, f, f];\), " "}], "\n", 
    RowBox[{
      RowBox[{\(f[z_]\ \  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity] z\^n\), 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{\(Print[\*"\"\< f[z] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(z\^n\) = \>\"", f[z]];\), " "}], "\[IndentingNewLine]", 
  
    RowBox[{\(Print["\<\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Differentiate f[z] and obtain\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print["\<f'[z] = \>", \(f'\)[z]];\), " "}]}], "Input"],

Cell["Or sum the infinite series directly.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(g[z_]\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\((n + 1)\) z\^n\), 
        
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{\(Print["\<f'[z] = \>", \(f'\)[z]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<f'[z] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)(n+1)\!\(z\^n\) = \>\"", g[z]\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Also\>"];\), "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<f'[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\) \
\!\(nz\^\(n - 1\)\) = \>\"", \[Sum]\+\(n = 0\)\%\[Infinity]\ 
            n\ z\^\(n - 1\)];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<f'[z] = \!\(\[Sum]\+\(n = 1\)\%\[Infinity]\) \
\!\(nz\^\(n - 1\)\) = \>\"", \[Sum]\+\(n = 1\)\%\[Infinity]\ 
            n\ z\^\(n - 1\)];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<f'[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\) (n+1)\
\!\(z\^n\) = \>\"", \[Sum]\+\(n = 0\)\%\[Infinity]\ \((n + 1)\)\ z\^n];\), 
      " "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that   ",
  Cell[BoxData[
      \(h \((z)\)\  = \(\[Sum]\+\(n = 0\)\%\[Infinity]\((n + 2)\) \((n + 1)\) 
              z\^n\  = \ 2\/\((1 - z)\)\^3\)\)]],
  "   for all  ",
  Cell[BoxData[
      \(z\ \[Epsilon]\ \(D\_1\) \((0)\)\)]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Use the fact that  ",
  Cell[BoxData[
      \(f \((z)\) = \(\[Sum]\+\(n = 0\)\%\[Infinity] z\^n = 
          1\/\(1\  - \ z\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(f'' \((z)\) = h \((z)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Remove[z];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Clear[h, n, f, f];\), " "}], "\n", 
    RowBox[{
      RowBox[{\(f[z_]\ \  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity] z\^n\), 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{\(Print[\*"\"\<  f[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(z\
\^n\) = \>\"", f[z]];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Differentiate f[z] and obtain\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print["\< f'[z] = \>", \(f'\)[z]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\n", 
    RowBox[{\(Print["\<f''[z] = \>", \(f''\)[z]];\), " "}]}], "Input"],

Cell["Or sum the infinite series directly.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(h[
            z_]\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\((n + 2)\) \((n + 1)\) 
              z\^n\), 
        StyleBox[";",
          FontSize->14]}], 
      StyleBox[" ",
        FontSize->14]}], "\n", 
    RowBox[{\(Print["\<f''[z] = \>", \(f''\)[z]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<f''[z] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)(n+2)(n+1)\!\(z\^n\) = \>\"", h[z]\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Also\>"];\), "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<f''[z] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)(n+2)(n+1)\!\(z\^n\) = \>\"", \[Sum]\+\(n = \
0\)\%\[Infinity]\((n + 2)\) \((n + 1)\) z\^n];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<f''[z] =  \!\(\[Sum]\+\(n = 2\)\%\[Infinity]\) \
n(n-1)\!\(z\^\(n - 2\)\) = \>\"", \[Sum]\+\(n = 2\)\%\[Infinity]\ 
            n \((n - 1)\) z\^\(n - 2\)];\), " "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.25.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The Bessel function ",
  Cell[BoxData[
      \(\(J\_0\) \((z)\)\)]],
  " of order zero is defined by  \n\n\t\t",
  Cell[BoxData[
      \(\(J\_0\) \((z)\)\  = \ \(\[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\
\^n\/\((\(n!\))\)\^2\) \((z\/2)\)\^\(2  n\)\ \  = \ 
          1 - z\^2\/\((2)\)\^2 + z\^4\/\(\(\((2)\)\^2\) \((4)\)\^2\) - 
              z\^6\/\(\(\((2)\)\^2\) \(\((4)\)\^2\) \((6)\)\^2\) + 
              z\^8\/\(\(\((2)\)\^2\) \(\((4)\)\^2\) \(\((6)\)\^2\) \((8)\)\^2\
\) -  ... \)\)]],
  ",  \n\nand termwise differentiation shows that its derivative is  \n \n \t\
\t",
  Cell[BoxData[{
      \(\(\(\[Sum]\+\(n = 0\)\%\[Infinity]\( 
                d\/dz\) \((\(\((\(-1\))\)\^n\/\((\(n!\))\)\^2\) \
\((z\/2)\)\^\(2  n\))\)\ \  = \ \ \[Sum]\+\(n = \
0\)\%\[Infinity]\((\(\((\(-1\))\)\^n\/\((\(n!\))\)\^2\) 2  
              n \(\((z\/2)\)\^\(2  n - 
                    1\)\) \((1\/2)\))\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\[Sum]\+\(n = \
0\)\%\[Infinity]\((\(\((\(-1\))\)\^n\/\(\(\((n - 
                          1)\)!\)\ \ \(n!\)\)\) \((z\/2)\)\^\(2  n - 1\))\)\)\
\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\[Sum]\+\(n = \
1\)\%\[Infinity]\((\(\((\(-1\))\)\^n\/\(\(\((n - 
                          1)\)!\)\ \ \(n!\)\)\) \((z\/2)\)\^\(2  n - 1\))\)\)\
\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\[Sum]\+\(n = \
0\)\%\[Infinity]\((\(\((\(-1\))\)\^\(n + 1\)\/\(\(\ \)\(\(n!\) \(\((n + 
                          1)\)!\)\)\)\) \((z\/2)\)\^\(2  n + 1\))\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(-\(z\/2\)\) + \(1\/\(\(1!\)\ \
\(2!\)\)\) \((z\/2)\)\^3 - \(1\/\(\(2!\)\ \(3!\)\)\) \((z\/2)\)\^5 + \
\(1\/\(\(3!\)\ \(4!\)\)\) \((z\/2)\)\^7 -  ... \)\)\)}]],
  "    \n\nWe leave as an exercise to show that the radius of convergence of \
these series is infinity.  The Bessel function ",
  Cell[BoxData[
      \(\(J\_1\) \((z)\)\)]],
  " of order ",
  StyleBox["1",
    FontFamily->"Courier New"],
  " is known to satisfy the differential equation  ",
  Cell[BoxData[
      \(\(J\_1\) \((z)\)\  = \ \(-\(J\_0\%'\)\) \((z)\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 4.25.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Look at some of the coefficients of and observe the relationship between \
the coefficients of  ",
  Cell[BoxData[
      \(\(J\_0\) \((z)\), \ J\_0' \((z)\)\ \ and\ \ \ \(J\_1\) \((z)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(J0[z_]\  = \ Series[BesselJ[0, z], \ {z, 0, 10}];\)\ \), "\n", 
    \(\(J1[z_]\  = \ Series[BesselJ[1, z], \ {z, 0, 9}];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(J\_0\)(z) = \>\"", 
        J0[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(J\_0\)'[z] = \>\"", \(J0'\)[z]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(J\_1\)[z] = \>\"", 
        J1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that  ",
  Cell[BoxData[
      \(J\_0' \((z)\)\)]],
  " =",
  Cell[BoxData[
      \(\(\(\ \)\(\(-\ J\_1\) \((z)\)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  What does the Bessel function  ",
  Cell[BoxData[
      \(\(J\_0\) \((z)\)\)],
    AspectRatioFixed->True],
  "  look like ?  Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph the transformation  ",
  Cell[BoxData[
      \(w = \(J\_0\) \((z)\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(J0[z_] = BesselJ[0, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        J0\ , {0, 3.6, 0.2}, {\(-2.0\), 2.0, 
          0.2}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1.6\), 
              2.4}, {\(-2\), 2}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-3\), 3, 1], 
            Range[\(-2\), 2, 1]}, AxesLabel \[Rule] {"\<u\>", "\<u\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_0\)[z] = \>\"", 
        J0[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The rectangle ",
  Cell[BoxData[
      \(0 \[LessEqual] x \[LessEqual] 3.6, \(-2.2\) \[LessEqual] 
        y \[LessEqual] 2.2\)]],
  "  was used because the graph of the real function  ",
  Cell[BoxData[
      \(y = J\_0[x]\)]],
  "  is decreasing on the interval ",
  Cell[BoxData[
      \(\([0, 3.83171]\)\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Geometric Series",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/GeometricSeriesBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Convergence of Series",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/SeriesConvergenceBib.html"],
     None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Power Series",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/PowerSeriesBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{933, 607},
WindowMargins->{{12, Automatic}, {Automatic, 2}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[6366, 206, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[35754, 907, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[72698, 1872, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 87045, 2282}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 117, 2, 33, "Text"],
Cell[2222, 66, 2077, 65, 131, "Text"],
Cell[4302, 133, 696, 23, 33, "Text",
  Evaluatable->False],
Cell[5001, 158, 1014, 32, 147, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[6040, 194, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[6188, 200, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[6366, 206, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[6726, 218, 974, 26, 68, "Text",
  Evaluatable->False],
Cell[7703, 246, 25000, 559, 249, "Text"],
Cell[32706, 807, 2697, 84, 254, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[35428, 895, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[35576, 901, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[35754, 907, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[36114, 919, 82, 2, 30, "Text"],
Cell[36199, 923, 894, 24, 135, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[37118, 951, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[37282, 957, 57, 0, 33, "Text"],
Cell[37342, 959, 664, 12, 191, "Input"],
Cell[38009, 973, 155, 5, 33, "Text",
  Evaluatable->False],
Cell[38167, 980, 988, 16, 248, "Input"],
Cell[39158, 998, 581, 16, 94, "Text"],
Cell[39742, 1016, 1028, 20, 281, "Input"],
Cell[40773, 1038, 705, 22, 75, "Text"],
Cell[41481, 1062, 116, 2, 49, "Input"],
Cell[41600, 1066, 140, 3, 33, "Text"]
}, Closed]],
Cell[41755, 1072, 1037, 28, 207, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[42817, 1104, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[42981, 1110, 157, 3, 33, "Text"],
Cell[43141, 1115, 834, 16, 232, "Input"],
Cell[43978, 1133, 141, 4, 33, "Text",
  Evaluatable->False],
Cell[44122, 1139, 1544, 26, 316, "Input"],
Cell[45669, 1167, 620, 17, 101, "Text"],
Cell[46292, 1186, 904, 18, 280, "Input"],
Cell[47199, 1206, 760, 20, 96, "Text"],
Cell[47962, 1228, 242, 4, 90, "Input"],
Cell[48207, 1234, 375, 11, 55, "Text",
  Evaluatable->False],
Cell[48585, 1247, 1325, 25, 318, "Input"]
}, Closed]],
Cell[49925, 1275, 787, 22, 114, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[50737, 1301, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[50901, 1307, 55, 0, 33, "Text"],
Cell[50959, 1309, 593, 12, 267, "Input"],
Cell[51555, 1323, 158, 5, 33, "Text",
  Evaluatable->False],
Cell[51716, 1330, 654, 11, 214, "Input"],
Cell[52373, 1343, 111, 2, 33, "Text",
  Evaluatable->False],
Cell[52487, 1347, 369, 9, 114, "Input"],
Cell[52859, 1358, 144, 4, 33, "Text",
  Evaluatable->False],
Cell[53006, 1364, 1478, 30, 381, "Input"],
Cell[54487, 1396, 1420, 26, 361, "Input"]
}, Closed]],
Cell[55922, 1425, 462, 13, 34, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[56409, 1442, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[56576, 1448, 1823, 45, 211, "Text"],
Cell[58402, 1495, 28, 0, 33, "Text"],
Cell[58433, 1497, 1113, 29, 144, "Text"],
Cell[59549, 1528, 1628, 35, 500, "Text"],
Cell[61180, 1565, 267, 5, 76, "Input"],
Cell[61450, 1572, 1942, 33, 501, "Input"],
Cell[63395, 1607, 239, 9, 71, "Text"],
Cell[63637, 1618, 1018, 18, 305, "Input"],
Cell[64658, 1638, 1267, 20, 305, "Input"],
Cell[65928, 1660, 386, 11, 52, "Text"],
Cell[66317, 1673, 101, 2, 49, "Input"],
Cell[66421, 1677, 453, 12, 74, "Text"],
Cell[66877, 1691, 72, 1, 43, "Input"],
Cell[66952, 1694, 38, 0, 33, "Text"],
Cell[66993, 1696, 101, 2, 49, "Input"],
Cell[67097, 1700, 502, 14, 112, "Text"],
Cell[67602, 1716, 905, 25, 71, "Text"],
Cell[68510, 1743, 149, 2, 64, "Input"],
Cell[68662, 1747, 293, 6, 83, "Input"],
Cell[68958, 1755, 1358, 24, 352, "Input"]
}, Closed]],
Cell[70331, 1782, 73, 2, 30, "Text"],
Cell[70407, 1786, 1940, 70, 152, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[72372, 1860, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[72520, 1866, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[72698, 1872, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[73058, 1884, 399, 13, 35, "Text",
  Evaluatable->False],
Cell[73460, 1899, 664, 17, 119, "Text"],

Cell[CellGroupData[{
Cell[74149, 1920, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[74313, 1926, 236, 9, 36, "Text"],
Cell[74552, 1937, 724, 16, 216, "Input"],
Cell[75279, 1955, 100, 2, 33, "Text",
  Evaluatable->False],
Cell[75382, 1959, 1101, 22, 261, "Input"]
}, Closed]],
Cell[76498, 1984, 408, 13, 35, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[76931, 2001, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[77098, 2007, 237, 9, 36, "Text"],
Cell[77338, 2018, 860, 18, 256, "Input"],
Cell[78201, 2038, 100, 2, 33, "Text",
  Evaluatable->False],
Cell[78304, 2042, 974, 21, 218, "Input"]
}, Closed]],
Cell[79293, 2066, 2816, 60, 399, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[82134, 2130, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[82298, 2136, 229, 6, 33, "Text"],
Cell[82530, 2144, 499, 10, 150, "Input"],
Cell[83032, 2156, 168, 8, 33, "Text"],
Cell[83203, 2166, 419, 16, 33, "Text"],
Cell[83625, 2184, 741, 14, 170, "Input"],
Cell[84369, 2200, 351, 12, 33, "Text"]
}, Closed]],
Cell[84735, 2215, 290, 7, 30, "Text"],
Cell[85028, 2224, 289, 7, 33, "Text"],
Cell[85320, 2233, 296, 7, 33, "Text"],
Cell[85619, 2242, 281, 7, 33, "Text"],
Cell[85903, 2251, 257, 5, 33, "Text"],
Cell[86163, 2258, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

