(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    382890,      11593]*)
(*NotebookOutlinePosition[    383799,      11626]*)
(*  CellTagsIndexPosition[    383721,      11620]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 5  Elementary Functions",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Overview",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tHow should complex-valued functions such as  ",
  Cell[BoxData[
      \(\[ExponentialE]\^z, log \((z)\), \ sin \((z)\)\)]],
  ",  etc., be defined ?  Clearly, any responsible definition should satisfy \
the following criteria:  \n\n",
  StyleBox["(i)",
    FontColor->RGBColor[0, 0, 1]],
  "  The functions so defined must give the same values as the corresponding \
functions for real variables when the number ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " is a real number.\n\n",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  "  As far as possible, the properties of these new functions must \
correspond with their real counterparts.  For example, we would want  ",
  Cell[BoxData[
      \(\(\[ExponentialE]\^z\_1\) \[ExponentialE]\^z\_2 = \ \[ExponentialE]\^\
\(z\_1 + z\_2\)\)]],
  "  to be valid regardless of whether ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " were real or complex. \n\n\tThese requirements may seem like a tall order \
to fill.  There is a procedure, however that offers promising results.  It is \
to put in complex form the expansion of the real functions  ",
  Cell[BoxData[
      \(\[ExponentialE]\^x, ln \((x)\), \ sin \((x)\)\)]],
  ",  etc., as power series into complex form.  We use this strategy in this \
chapter."
}], "Text"],

Cell[TextData[StyleBox["5.1 The Complex Exponential Function",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tRecall that the real exponential function can be represented by the \
power series  ",
  Cell[BoxData[
      \(\[ExponentialE]\^x\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\( 1\/\(n!\)\) 
            x\^n\)]],
  ".  Thus it is only natural to define the complex exponential  ",
  Cell[BoxData[
      \(\[ExponentialE]\^z\)]],
  ",  also written as ",
  Cell[BoxData[
      \(exp \((z)\)\)]],
  ", in the following way: "
}], "Text"],

Cell[TextData[{
  "\n",
  StyleBox["Definition 5.1 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Exponential Function",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ExponentialFunction.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[")",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The definition of  ",
  StyleBox["exp(z)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 1]],
  " is  \n\n\t\t\t",
  Cell[BoxData[
      \(exp \((z)\)\  = \ \(\[ExponentialE]\^z\  = \ \[Sum]\+\(n = 0\)\%\
\[Infinity]\( 1\/\(n!\)\) z\^n\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Demonstration for Definition 5.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["  ",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to sum a power series."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[ExponentialE]\^z \[Equal] \[Sum]\+\(n = 0\)\%\[Infinity] z\^n\/\(n!\)\
\), "\n", 
    \(Exp[z] \[Equal] \[ExponentialE]\^z\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\

The ratio test can be used to show that the infinite series converges for all \
values of   z.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[z];\)\ \ \), "\n", 
    \(\(Clear[lim, n, q];\)\ \ \), "\n", 
    \(\(q1 = \((z\^\(n + 1\)\/\(\((n + 1)\)!\))\)/\((z\^n\/\(n!\))\);\)\ \ \
\), "\n", 
    \(\(q2 = FullSimplify[q1];\)\ \ \), "\n", 
    \(\(lim = Limit[q2, n \[Rule] \[Infinity]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\(z\^\(n + 1\)\/\(\((n + 1)\)!\)\)\/\(z\^n\/\(n!\)\)\
\) = \>\"", q1, "\< = \>", q2];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<L = \!\(lim\+\(n \[Rule] \[Infinity]\)\) \!\(\(z\^\(n + \
1\)\/\(\((n + 1)\)!\)\)\/\(z\^n\/\(n!\)\)\)\>\""];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<L = \!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", 
        q1];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<L = \!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", 
        q2, "\< = \>", lim];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print["\<The radius of convergence of the series is\>"];\)\ \ \), "\n\
", 
    \(\(Print[\*"\"\<R = \!\(1\/L\) = \[Infinity]\>\""];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\n\tClearly, this definition agrees with that of the real exponential \
function when z is a real number.  We now show that this complex exponential \
has two of the key properties associated with its real counterpart and verify \
the identity  ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\) = 
        cos\ \[Theta] + \[ImaginaryI]\ sin\ \[Theta]\)]],
  ",  which, back in Chapter 1 (see identity ",
  StyleBox["(1-30)",
    FontColor->RGBColor[0, 0, 1]],
  " of Section 1.4), we promised to establish."
}], "Text"],

Cell[TextData[{
  StyleBox["\nTheorem 5.1 (The exponential function).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The function  ",
  Cell[BoxData[
      \(exp \((z)\) = \[ExponentialE]\^z\)]],
  "  is an entire function satisfying the following conditions:\n\n",
  "  ",
  StyleBox["(i).",
    FontColor->RGBColor[0, 0, 1]],
  "   ",
  Cell[BoxData[
      \(\(d\/dz\) exp \((z)\) = \(exp \((z)\) = \[ExponentialE]\^z\)\)]],
  ",  using Leibniz notation  ",
  Cell[BoxData[
      \(\(d\/dz\) \[ExponentialE]\^z = \[ExponentialE]\^z\)]],
  ".  \n\n",
  " ",
  StyleBox["(ii).",
    FontColor->RGBColor[0, 0, 1]],
  "   ",
  Cell[BoxData[
      \(exp \((z\_1 + z\_2)\) = exp \((z\_1)\) exp \((z\_2)\)\)]],
  ",   i.e.   ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(z\_1 + z\_2\) = \(\[ExponentialE]\^z\_1\) \
\[ExponentialE]\^z\_2\)]],
  ".  \n\n",
  StyleBox["(iii).",
    FontColor->RGBColor[0, 0, 1]],
  "   If  ",
  Cell[BoxData[
      \(\[Theta]\)]],
  "  is a real number, then   ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\) = 
        cos\ \[Theta] + \[ImaginaryI]\ sin\ \[Theta]\)]],
  ".  \n\nThe exponential function is a solution to the differential equation \
 ",
  Cell[BoxData[
      \(f' \((z)\) = f \((z)\)\)]],
  "  with the initial condition  ",
  Cell[BoxData[
      \(f \((0)\) = 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof of Theorem 5.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tBy the ratio test, the series in Definition 5.1 has an infinite radius \
of convergence, so  ",
  Cell[BoxData[
      \(exp \((z)\)\)]],
  "  is an function.  Using termwise differentiation, we get  \n\n\t\t\t",
  Cell[BoxData[
      \(\(d\/dz\) 
          exp \((z)\)\  = \ \(\[Sum]\+\(n = 1\)\%\[Infinity]\( n\/\(n!\)\) 
              z\^\(n - 1\)\  = \ \(\[Sum]\+\(n = 1\)\%\[Infinity]\( 
                    1\/\(\((n - 1)\)!\)\) 
                z\^\(n - 1\)\  = \ \(\[Sum]\+\(n = 0\)\%\[Infinity]\( 
                      1\/\(n!\)\) z\^n\  = \ exp \((z)\)\)\)\)\)]],
  ",  \n\nwhich gives us part ",
  StyleBox["(i)",
    FontColor->RGBColor[0, 0, 1]],
  " of Theorem 5.1."
}], "Text"],

Cell[TextData[{
  "To prove part ",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  ", we let ",
  Cell[BoxData[
      \(\[Zeta]\)]],
  " be an arbitrary complex number and define ",
  Cell[BoxData[
      \(g \((z)\)\)]],
  " to be \n\n\t\t\t",
  Cell[BoxData[
      \(g \((z)\)\  = \ exp \((z)\) exp \((\[Zeta] - z)\)\)]],
  ".\n\nUsing the product rule, chain rule, and part (i), we have \n\n\t\t\t\
",
  Cell[BoxData[{\(g' \((z)\)\  = \ 
        exp \((z)\) exp \((\[Zeta] - z)\) + 
          exp \((z)\)[\(-exp\) \((\[Zeta] - z)\)]\), "\[IndentingNewLine]", 
      RowBox[{
        "              ", \(\(=\)\(exp \((z)\) exp \((\[Zeta] - z)\) - 
            exp \((z)\) exp \((\[Zeta] - z)\)\)\), "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{\(g' \((z)\)\), " ", "=", " ", 
        RowBox[{"0", "    ", 
          StyleBox["for",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["all",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", 
          RowBox[{"z", 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "."
}], "Text"],

Cell[TextData[{
  "Hence the function ",
  Cell[BoxData[
      \(g \((z)\)\)]],
  " must be a constant function.  Thus, for all z,  ",
  Cell[BoxData[
      \(g \((z)\) = g \((0)\)\)]],
  ".   Since  ",
  Cell[BoxData[
      \(exp \((0)\) = 1\)]],
  "  (for the reader to verify!), we deduce \n\n\t\t\t ",
  Cell[BoxData[{
      \(\(\(g \((z)\) = g \((0)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(exp \((0)\) 
          exp \((\[Zeta])\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(=\)\(exp \((\[Zeta])\)\)\)\)}]],
  ". \n\nHence, for all ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ", \n\n\t\t\t",
  Cell[BoxData[
      \(g \((z)\)\  = \ \(exp \((z)\) exp \((\[Zeta] - z)\) = 
          exp \((\[Zeta])\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Setting  ",
  Cell[BoxData[
      \(z = z\_1\)]],
  "  and letting  ",
  Cell[BoxData[
      \(\[Zeta] = z\_1 + z\_2\)]],
  ",  we get\n\n\t\t\t",
  Cell[BoxData[
      \(exp \((z\_1)\) exp \((z\_1 + z\_2 - z\_1)\) = 
        exp \((z\_1 + z\_2)\)\)]],
  ".\n\nwhich simplifies to be ",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  " which is our desired result, i.e.  ",
  Cell[BoxData[
      \(exp \((z\_1 + z\_2)\) = exp \((z\_1)\) exp \((z\_2)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "To prove part",
  StyleBox[" (iii)",
    FontColor->RGBColor[0, 0, 1]],
  ", we let  ",
  Cell[BoxData[
      \(\[Theta]\)]],
  "  be a real number.  By Definition 5.1,  \n\n\t\t\t",
  Cell[BoxData[{
      \(\ \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\  = \ \ exp \((\
\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\))\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\[Sum]\+\(k = 0\)\%\[Infinity]\( 
                1\/\(k!\)\) \((\[ImaginaryI]\ \[Theta])\)\^k\)\)\(\ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(\[Sum]\+\(n = 0\)\%\[Infinity]\((\(1\
\/\(\((2  n)\)!\)\) \((\[ImaginaryI]\ \[Theta])\)\^\(2  n\)\  + \ \(1\/\(\((2 
                             n + 1)\)!\)\) \((\[ImaginaryI]\ \[Theta])\)\^\(2 \
 n + 1\)\ )\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(\[Sum]\+\(n = 0\)\%\[Infinity]\((\(1\
\/\(\((2  
                          n)\)!\)\) \((\[ImaginaryI]\^2)\)\^n\ \[Theta]\^\(2  \
n\)\  + \ \(1\/\(\((2  n + 
                          1)\)!\)\) \[ImaginaryI] \(\((\[ImaginaryI]\^2)\)\^n\
\) \[Theta]\^\(2  n + 1\)\ )\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(\[Sum]\+\(n = 0\)\%\[Infinity]\((\(1\
\/\(\((2  
                          n)\)!\)\) \((\(-1\))\)\^n\ \[Theta]\^\(2  n\)\  + \ \
\[ImaginaryI] \( 1\/\(\((2  n + 
                          1)\)!\)\) \(\((\(-1\))\)\^n\) \[Theta]\^\(2  n + \
1\)\ )\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(\[Sum]\+\(n = \
0\)\%\[Infinity]\(\((\(-1\))\)\^n\/\(\((2  
                        n)\)!\)\) \[Theta]\^\(2  n\)\  + \ \[ImaginaryI] \(\
\[Sum]\+\(n = 0\)\%\[Infinity]\((\(-1\))\)\^n\/\(\((2  n + 1)\)!\)\ \
\[Theta]\^\(2  n + 1\)\)\)\)\(\[IndentingNewLine]\)
      \(\ \)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(cos\ \[Theta]\  + \ \[ImaginaryI]\ sin\
\ \[Theta]\)\)\)}]],
  "  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Demonstration for Theorem 5.1 (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the D.E. with the given initial condition and solve it. \nThen enter \
the function  ",
  Cell[BoxData[
      \(f[z] = \[ExponentialE]\^z\)]],
  ",  compute  ",
  Cell[BoxData[
      \(\(f'\)[z]\ \ and\ \ f[0]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[x, y, z];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Clear[f, s, u, U, v, V];\)\ \ \), "\[IndentingNewLine]", 
    \(\(de = \(f'\)[z] \[Equal] f[z];\)\ \ \), "\[IndentingNewLine]", 
    \(\(solset = DSolve[de, f[z], z];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[de];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\
\ \ \), "\[IndentingNewLine]", 
    \(\(ic = \(f'\)[0] \[Equal] 1;\)\ \ \), "\[IndentingNewLine]", 
    \(\(solset = 
        DSolve[Flatten[{de, ic}], f[z], z];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[de];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[ic];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\
\ \ \), "\n", 
    \(\(f[z_] = \[ExponentialE]\^z;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \ \), "\n", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]];\)\ \ \), "\n", 
    \(\(Print["\< f[0] = \>", f[0]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nConstruct the Maclaurin series for  ",
  Cell[BoxData[
      \(f[z] = \[ExponentialE]\^z\)]],
  ",  compute  ",
  Cell[BoxData[
      \(\(f'\)[z]\ \ and\ \ f[0]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\n\(s[z_] = Series[\[ExponentialE]\^z, {z, 0, 11}];\)\ \ \), "\n", 
    \(\(Print["\< f[z] = \>", s[z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print["\<f'[z] = \>", \(s'\)[z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print["\< f[0] = \>", s[0]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nDetermine the real and imaginary parts of  ",
  Cell[BoxData[
      \(f[
          z] = \(\[ExponentialE]\^z = \[ExponentialE]\^\(x\  + \ \
\[ImaginaryI]\ y\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(u[x_, y_] = 
        ComplexExpand[
          Re[\[ExponentialE]\^\(x + \[ImaginaryI]\ y\)]];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(v[x_, y_] = 
        ComplexExpand[
          Im[\[ExponentialE]\^\(x + \[ImaginaryI]\ y\)]];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<    f[z] = \>", f[z]];\)\ \ \), "\n", 
    \(\(Print["\< f[x+\[ImaginaryI]y] = \>", 
        f[x + \[ImaginaryI]\ y]];\)\ \ \), "\n", 
    \(\(Print["\< f[x+\[ImaginaryI]y] = \>", 
        ComplexExpand[
          f[x + \[ImaginaryI]\ y]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<u[x,y] = Re[\!\(\[ExponentialE]\^z\)] = \>\"", 
        u[x, y]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<v[x,y] = Im[\!\(\[ExponentialE]\^z\)] = \>\"", 
        v[x, y]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[0,0] = \>", u[0, 0]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[0,0] = \>", v[0, 0]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[0+0\[ImaginaryI]] = u[0,0] + \[ImaginaryI] v[0,0]\>"];\)\ \
\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[0+0\[ImaginaryI]] = (\>", 
        u[0, 0]\ , "\<) + \[ImaginaryI](\>", \ 
        v[0, 0], "\<)\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[0+0\[ImaginaryI]] = \>", 
        u[0, 0]\  + \ \[ImaginaryI]\ v[0, 
              0]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nDetermine the real and imaginary parts of the series ",
  Cell[BoxData[
      \(f[
          z] = \(\[ExponentialE]\^z = \[Sum]\+\(n = 0\)\%\[Infinity] \
z\^n\/\(n!\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\n\(s[z_] = Series[\[ExponentialE]\^z, {z, 0, 5}];\)\ \ \), "\n", 
    \(\(Print["\< f[z] = \>", 
        s[x + \[ImaginaryI]\ y]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  Re[\!\(\[ExponentialE]\^z\)] = \>\"", 
        ComplexExpand[
          Re[Normal[
              s[x + \[ImaginaryI]\ y]]]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  Im[\!\(\[ExponentialE]\^z\)] = \>\"", 
        ComplexExpand[
          Im[Normal[
              s[x + \[ImaginaryI]\ y]]]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nCompare the above results with the two variable Taylor series expansions \
for  ",
  Cell[BoxData[
      \(\(\[ExponentialE]\^\(\(\ \)\(x\)\)\) 
        Cos[y]\ \ \ and\ \ \ \(\[ExponentialE]\^\(\(\ \)\(x\)\)\) Sin[y]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(U = 
        Normal[Series[\(\[ExponentialE]\^\(x0 + t\ x\)\) Cos[y0 + t\ y], {t, 
              0, 5}]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(V = 
        Normal[Series[\(\[ExponentialE]\^\(x0 + t\ x\)\) Sin[y0 + t\ y], {t, 
              0, 5}]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(u[x_, y_] = 
        ReplaceAll[
          U, {t \[Rule] 1, x0 \[Rule] 0, 
            y0 \[Rule] 0}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(v[x_, y_] = 
        ReplaceAll[
          V, {t \[Rule] 1, x0 \[Rule] 0, 
            y0 \[Rule] 0}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  Re[\!\(\[ExponentialE]\^z\)] = \>\"", 
        u[x, y]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  Im[\!\(\[ExponentialE]\^z\)] = \>\"", 
        v[x, y]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Demonstration for Theorem 5.1 (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Remove[w, x, y, z];\)\ \ \), "\n", 
    \(\(w\_1\  = \ 
        ComplexExpand[\[ExponentialE]\^\(x\_1 + \[ImaginaryI]\ y\_1\)];\)\ \ \
\), "\n", 
    \(\(w\_2\  = \ 
        ComplexExpand[\[ExponentialE]\^\(x\_2 + \[ImaginaryI]\ y\_2\)];\)\ \ \
\), "\n", 
    \(\(Print[\*"\"\<\!\(\[ExponentialE]\^z\_1\) = \>\"", 
        w\_1];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[ExponentialE]\^z\_2\) = \>\"", 
        w\_2];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \ \), "\n", 
    \(\(w\_3\  = \ Expand[w\_1\ w\_2];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[ExponentialE]\^z\_1\)\!\(\[ExponentialE]\^z\_2\) = \
\>\"", w\_3];\)\ \ \), "\n", 
    \(\(w\_3\  = \ Simplify[w\_3, Trig \[Rule] False];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[ExponentialE]\^z\_1\)\!\(\[ExponentialE]\^z\_2\) = \
\>\"", w\_3];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \ \), "\n", 
    \(\(z\_4\  = \ \((x\_1 + \[ImaginaryI]\ y\_1)\) + \((x\_2 + \[ImaginaryI]\
\ y\_2)\);\)\ \ \), "\n", 
    \(\(w\_4\  = \ ComplexExpand[\[ExponentialE]\^z\_4];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[ExponentialE]\^\(z\_1 + z\_2\)\) = \>\"", 
        w\_4];\)\ \ \), "\n", 
    \(\(w\_4\  = \ Simplify[w\_4, Trig \[Rule] False];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[ExponentialE]\^\(z\_1 + z\_2\)\) = \>\"", 
        w\_4];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<Does \
\!\(\[ExponentialE]\^z\_1\)\!\(\[ExponentialE]\^z\_2\)= \!\(\[ExponentialE]\^\
\(z\_1 + z\_2\)\) ?\>\""];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print[w\_3, "\< = \>", w\_4];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \ \), "\n", 
    \(\(w\_3\  = \ ComplexExpand[w\_3];\)\ \ \), "\n", 
    \(\(w\_4\  = \ ComplexExpand[w\_4];\)\ \ \), "\n", 
    \(\(Print[w\_3, "\< = \>", w\_4];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \ \), "\n", 
    \(\(w\_3\  = \ 
        Simplify[ComplexExpand[w\_3], Trig \[Rule] True];\)\ \ \), "\n", 
    \(\(w\_4\  = \ 
        Simplify[ComplexExpand[w\_4], Trig \[Rule] True];\)\ \ \), "\n", 
    \(\(Print[w\_3, "\< = \>", w\_4];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print[TrigExpand[w\_3] \[Equal] TrigExpand[w\_4]];\)\ \ \)}], "Input",\

  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Demonstration for Theorem 5.1 (iii).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["This is DeMoivre's formula that was studied in Section 1.5. ", "Text"],

Cell[BoxData[
    \(\[ExponentialE]\^x\ \  \[Equal] \ \ \[Sum]\+\(k = 0\)\%\[Infinity]\( 
              1\/\(k!\)\) x\^k\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\  \[Equal] \ \[Sum]\+\(n \
= 0\)\%\[Infinity]\( 
                    1\/\(\((2  
                          n)\)!\)\) \((\[ImaginaryI]\ \[Theta])\)\^\(2  n\)\  \
+ \ \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                    1\/\(\((2  n + 
                          1)\)!\)\) \((\[ImaginaryI]\ \[Theta])\)\^\(2  n + 1\
\)\ \ \ \  // ComplexExpand\) // PowerExpand\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\  \[Equal] \ \[Sum]\+\(n \
= 0\)\%\[Infinity]\( 
                    1\/\(\((2  n)\)!\)\) \(\[ImaginaryI]\^\(2  
                      n\)\) \[Theta]\^\(2  n\)\  + \ \[Sum]\+\(n = 0\)\%\
\[Infinity]\( 1\/\(\((2  n + 1)\)!\)\) \(\[ImaginaryI]\^\(2  n + 
                      1\)\) \[Theta]\^\(2  n + 1\)\ \ \ \ \  // 
        ComplexExpand\) // PowerExpand\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\  \[Equal] \[Sum]\+\(n = \
0\)\%\[Infinity]\( 
                    1\/\(\((2  
                          n)\)!\)\) \(\((\(-1\))\)\^n\) \[Theta]\^\(2  n\)\  \
+ \[ImaginaryI] \(\[Sum]\+\(n = 0\)\%\[Infinity]\( 
                      1\/\(\((2  n + 
                            1)\)!\)\) \((\(-1\))\)\^n\ \[Theta]\^\(2  n + 1\)\
\)\ \ \ \ \  // ComplexExpand\) // PowerExpand\)], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = \
0\)\%\[Infinity]\)\!\(1\/\(k!\)\)\!\(\((\[ImaginaryI]\\\ \[Theta])\)\^k\) = \
\>\"", \[Sum]\+\(k = 0\)\%\[Infinity]\( 
                1\/\(k!\)\) \((\[ImaginaryI]\ \[Theta])\)\^k];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = \
0\)\%\[Infinity]\)\!\(1\/\(k!\)\)\!\(\((\[ImaginaryI]\\\ \[Theta])\)\^k\) = \
\>\"", ComplexExpand[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]];\)\ \ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tNote that parts ",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  " of the Theorem 5.1 combine to verify ",
  StyleBox[ButtonBox["De Moivre's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/De_Moivre.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " formula, which we introduced in Section 1.5. "
}], "Text"],

Cell[TextData[{
  "\tIf  ",
  Cell[BoxData[
      \(z = x\  + \[ImaginaryI]\ y\)]],
  ",  we also see from parts ",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  " that\n\t\n",
  StyleBox["(5-1)",
    FontColor->GrayLevel[1]],
  "\t\t\t",
  Cell[BoxData[
      \(exp \((z)\)\  = \ \(\[ExponentialE]\^z\  = \ \(\[ExponentialE]\^\(x\  \
+ \[ImaginaryI]\ y\)\  = \ \(\(\[ExponentialE]\^\(\(x\)\(\ \)\)\) \(\
\[ExponentialE]\^\(\[ImaginaryI]\ y\)\)\(\ \)\)\)\)\)]],
  "   \n\t\t\t\n",
  StyleBox["(5-1)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(exp \((z)\)\  = \ \(\[ExponentialE]\^\(\(x\)\(\ \)\)\) \((cos\ y + \
\[ImaginaryI]\ sin\ y)\)\)]],
  "   \n\nSome texts start with this identity as their definition for ",
  Cell[BoxData[
      \(\[ExponentialE]\^z\)]],
  ".  In the exercises, we show that this is a natural approach from the \
standpoint of differential equations.  "
}], "Text"],

Cell[TextData[{
  "\tThe notation  ",
  Cell[BoxData[
      \(exp \((z)\)\)]],
  "  is preferred over  ",
  Cell[BoxData[
      \(\[ExponentialE]\^z\)]],
  "  in some situations.  For example,  ",
  Cell[BoxData[
      RowBox[{\(exp \((1\/5)\)\), " ", "=", " ", 
        TagBox["\<\"1.22140275816016983392...\"\>",
          (NumberForm[ #, 70]&)]}]]],
  "  is the value of  ",
  Cell[BoxData[
      \(exp \((z)\)\)]],
  "  when  ",
  Cell[BoxData[
      \(z = 1\/5\)]],
  "  and equals the positive fifth root of  ",
  Cell[BoxData[
      \(\[ExponentialE]\  = 2.71828182845904523536 ... \)]],
  ".  Thus the notation  ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(1/5\)\)]],
  "  is ambiguous and might be interpreted as any of the complex fifth roots \
of the number ",
  Cell[BoxData[
      \(\[ExponentialE]\)]],
  " that we discussed in Section 1.5:\n\n\t\t\t",
  Cell[BoxData[
      \(\[ExponentialE]\^\(1/5\)\  = \ 
        1.22140275816016983392\ \((cos \( 2\ \[Pi]\ k\)\/5 + \
\[ImaginaryI]\ \ sin \( 2\ \[Pi]\ k\)\/5)\)\)]],
  "   for  ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "3", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "4"}]]],
  ".  \n\nTo prevent this confusion, we often use  ",
  Cell[BoxData[
      \(exp \((z)\)\)]],
  "  to denote the single-valued exponential function."
}], "Text"],

Cell[TextData[{
  "\tWe now explore some additional properties of  ",
  Cell[BoxData[
      \(exp \((z)\)\  = \ \[ExponentialE]\^z\)]],
  ".  Using identity ",
  StyleBox["(5-1)",
    FontColor->RGBColor[0, 0, 1]],
  ", we can easily establish that  \n\n",
  StyleBox["(5-2)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[ExponentialE]\^\(z + \[ImaginaryI]2\ n\ \[Pi]\) = \
\[ExponentialE]\^z\)]],
  ",  for all  z,  provided n is an integer,  \n\n",
  StyleBox["(5-3)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[ExponentialE]\^z = 1\)]],
  ",  if and only if  ",
  Cell[BoxData[
      \(z = \[ImaginaryI]\ 2\ n\ \[Pi]\)]],
  ",  where n  is an integer, and\n\n",
  StyleBox["(5-4)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[ExponentialE]\^z\_1 = \[ExponentialE]\^z\_2\)]],
  ",  if and only if  ",
  Cell[BoxData[
      \(z\_2 = z\_1 + \[ImaginaryI]\ 2\ n\ \[Pi]\)]],
  ",  for some integer n.  "
}], "Text"],

Cell[TextData[{
  "    For example, because Identity ",
  StyleBox["(5-1)",
    FontColor->RGBColor[0, 0, 1]],
  " involves the periodic functions  cos y  and  sin y,  any two points in \
the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane that lie on the same vertical line with their imaginary parts \
differing by an integral multiple of  ",
  Cell[BoxData[
      \(2\ \[Pi]\)]],
  "  are mapped onto the same point in the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane.  Thus the complex exponential function is periodic with period  ",
  Cell[BoxData[
      \(2\ \[Pi]\)]],
  ",  which establishes Equation ",
  StyleBox["(5-2)",
    FontColor->RGBColor[0, 0, 1]],
  ".  We leave the verification of Equations ",
  StyleBox["(5-3)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(5-4)",
    FontColor->RGBColor[0, 0, 1]],
  " as exercises for the reader."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 5.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  For any integer n, the points  ",
  Cell[BoxData[
      \(z\_n = 5\/4 + \[ImaginaryI] \((\(11\ \[Pi]\)\/6 + 2\ n\ \[Pi])\)\)]],
  "  are mapped onto a single point  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(w\_0\ \  = \ \ \(\[ExponentialE]\^z\_n\ \  = \ \ exp \((z\_n)\)\)\
\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(exp[
          5\/4 + \[ImaginaryI] \((\(11\ \[Pi]\)\/6 + 
                  2\ n\ \[Pi])\)]\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(\[ExponentialE]\^\(5/4\)\)\ [
          Cos \((\(11\ \[Pi]\)\/6 + 
                  2\ n\ \[Pi])\) + \[ImaginaryI]\ Sin \((\(11\ \[Pi]\)\/6 + 
                  2\ n\ \[Pi])\)]\)\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\[ExponentialE]\^\(5/4\)\ \((cos\ \(11\
\ \[Pi]\)\/6\  + \ \[ImaginaryI]\ sin\ \(11\ \[Pi]\)\/6)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(\(\ \)\(\@3\)\)\/2\ \
\[ExponentialE]\^\(5/4\)\  - \ \[ImaginaryI] 
             1\/2\ \ \[ExponentialE]\^\(5/4\)\n\[IndentingNewLine]
        \ \ \ \ \ \ \(\(=\)\(\ \ \)\(3.02272566908\ \  - \ \ 1.74517147873\
\ \ \[ImaginaryI]\)\)\)\)\)}]],
  "  \n\nin the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane, as indicated in Figure 5.1."
}], "Text",
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0.468085 0.212766 0.0398732 0.0398732 [
[.04255 .02737 -6.96875 -10.9375 ]
[.04255 .02737 6.96875 0 ]
[.25532 .02737 -6.96875 -10.9375 ]
[.25532 .02737 6.96875 0 ]
[.68085 .02737 -4.21875 -10.9375 ]
[.68085 .02737 4.21875 0 ]
[.89362 .02737 -4.21875 -10.9375 ]
[.89362 .02737 4.21875 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04255 .03987 m
.04255 .04612 L
s
gsave
.04255 .02737 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.25532 .03987 m
.25532 .04612 L
s
gsave
.25532 .02737 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.68085 .03987 m
.68085 .04612 L
s
gsave
.68085 .02737 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.89362 .03987 m
.89362 .04612 L
s
gsave
.89362 .02737 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .03987 m
1 .03987 L
s
.46809 0 m
.46809 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
0 .03987 m
.12121 .03987 L
.29703 .03987 L
.46608 .03987 L
.64609 .03987 L
.81933 .03987 L
s
.81933 .03987 m
1 .03987 L
s
0 1 1 r
.89362 .16514 m
.04255 .16514 L
.04255 .03987 L
.89362 .03987 L
.89362 .16514 L
F
.89362 .41567 m
.04255 .41567 L
.04255 .2904 L
.89362 .2904 L
.89362 .41567 L
F
.941 1 .941 r
.89362 .2904 m
.04255 .2904 L
.04255 .16514 L
.89362 .16514 L
.89362 .2904 L
F
.89362 .54093 m
.04255 .54093 L
.04255 .41567 L
.89362 .41567 L
.89362 .54093 L
F
0 g
.04255 .03987 m
.04255 .04495 L
.04255 .0505 L
.04255 .0557 L
.04255 .06071 L
.04255 .06604 L
.04255 .07116 L
.04255 .07662 L
.04255 .08187 L
.04255 .08692 L
.04255 .09229 L
.04255 .09747 L
.04255 .10245 L
.04255 .10775 L
.04255 .11285 L
.04255 .11827 L
.04255 .12349 L
.04255 .12851 L
.04255 .13386 L
.04255 .13901 L
.04255 .14448 L
.04255 .14975 L
.04255 .15482 L
.04255 .16021 L
.04255 .16514 L
s
.14894 .03987 m
.14894 .04495 L
.14894 .0505 L
.14894 .0557 L
.14894 .06071 L
.14894 .06604 L
.14894 .07116 L
.14894 .07662 L
.14894 .08187 L
.14894 .08692 L
.14894 .09229 L
.14894 .09747 L
.14894 .10245 L
.14894 .10775 L
.14894 .11285 L
.14894 .11827 L
.14894 .12349 L
.14894 .12851 L
.14894 .13386 L
.14894 .13901 L
.14894 .14448 L
.14894 .14975 L
.14894 .15482 L
.14894 .16021 L
.14894 .16514 L
s
.25532 .03987 m
.25532 .04495 L
.25532 .0505 L
.25532 .0557 L
.25532 .06071 L
.25532 .06604 L
.25532 .07116 L
.25532 .07662 L
.25532 .08187 L
.25532 .08692 L
.25532 .09229 L
.25532 .09747 L
.25532 .10245 L
.25532 .10775 L
.25532 .11285 L
.25532 .11827 L
.25532 .12349 L
.25532 .12851 L
.25532 .13386 L
.25532 .13901 L
.25532 .14448 L
.25532 .14975 L
.25532 .15482 L
.25532 .16021 L
.25532 .16514 L
s
.3617 .03987 m
.3617 .04495 L
.3617 .0505 L
.3617 .0557 L
.3617 .06071 L
.3617 .06604 L
.3617 .07116 L
.3617 .07662 L
.3617 .08187 L
.3617 .08692 L
.3617 .09229 L
.3617 .09747 L
.3617 .10245 L
.3617 .10775 L
.3617 .11285 L
.3617 .11827 L
.3617 .12349 L
.3617 .12851 L
.3617 .13386 L
.3617 .13901 L
.3617 .14448 L
.3617 .14975 L
.3617 .15482 L
.3617 .16021 L
.3617 .16514 L
s
.46809 .03987 m
.46809 .04495 L
.46809 .0505 L
.46809 .0557 L
.46809 .06071 L
.46809 .06604 L
.46809 .07116 L
.46809 .07662 L
.46809 .08187 L
.46809 .08692 L
.46809 .09229 L
.46809 .09747 L
.46809 .10245 L
.46809 .10775 L
.46809 .11285 L
.46809 .11827 L
.46809 .12349 L
.46809 .12851 L
.46809 .13386 L
.46809 .13901 L
.46809 .14448 L
.46809 .14975 L
.46809 .15482 L
.46809 .16021 L
.46809 .16514 L
s
.57447 .03987 m
.57447 .04495 L
.57447 .0505 L
.57447 .0557 L
.57447 .06071 L
.57447 .06604 L
.57447 .07116 L
.57447 .07662 L
.57447 .08187 L
.57447 .08692 L
.57447 .09229 L
.57447 .09747 L
.57447 .10245 L
.57447 .10775 L
.57447 .11285 L
.57447 .11827 L
.57447 .12349 L
.57447 .12851 L
.57447 .13386 L
.57447 .13901 L
.57447 .14448 L
.57447 .14975 L
.57447 .15482 L
.57447 .16021 L
.57447 .16514 L
s
.68085 .03987 m
.68085 .04495 L
.68085 .0505 L
.68085 .0557 L
.68085 .06071 L
.68085 .06604 L
.68085 .07116 L
.68085 .07662 L
.68085 .08187 L
.68085 .08692 L
.68085 .09229 L
.68085 .09747 L
.68085 .10245 L
.68085 .10775 L
.68085 .11285 L
.68085 .11827 L
.68085 .12349 L
.68085 .12851 L
.68085 .13386 L
.68085 .13901 L
.68085 .14448 L
.68085 .14975 L
.68085 .15482 L
.68085 .16021 L
.68085 .16514 L
s
.78723 .03987 m
.78723 .04495 L
.78723 .0505 L
.78723 .0557 L
.78723 .06071 L
.78723 .06604 L
.78723 .07116 L
.78723 .07662 L
.78723 .08187 L
.78723 .08692 L
.78723 .09229 L
.78723 .09747 L
.78723 .10245 L
.78723 .10775 L
.78723 .11285 L
.78723 .11827 L
.78723 .12349 L
.78723 .12851 L
.78723 .13386 L
.78723 .13901 L
.78723 .14448 L
.78723 .14975 L
.78723 .15482 L
.78723 .16021 L
.78723 .16514 L
s
.89362 .03987 m
.89362 .04495 L
.89362 .0505 L
.89362 .0557 L
.89362 .06071 L
.89362 .06604 L
.89362 .07116 L
.89362 .07662 L
.89362 .08187 L
.89362 .08692 L
.89362 .09229 L
.89362 .09747 L
.89362 .10245 L
.89362 .10775 L
.89362 .11285 L
.89362 .11827 L
.89362 .12349 L
.89362 .12851 L
.89362 .13386 L
.89362 .13901 L
.89362 .14448 L
.89362 .14975 L
.89362 .15482 L
.89362 .16021 L
.89362 .16514 L
s
.04255 .03987 m
.07708 .03987 L
.11473 .03987 L
.15009 .03987 L
.1841 .03987 L
.2203 .03987 L
.25514 .03987 L
.29218 .03987 L
.32786 .03987 L
.36219 .03987 L
.39871 .03987 L
.43387 .03987 L
.46768 .03987 L
.50369 .03987 L
.53833 .03987 L
.57517 .03987 L
.61066 .03987 L
.64479 .03987 L
.68111 .03987 L
.71607 .03987 L
.75323 .03987 L
.78904 .03987 L
.82349 .03987 L
.86013 .03987 L
.89362 .03987 L
s
.04255 .05553 m
.07708 .05553 L
.11473 .05553 L
.15009 .05553 L
.1841 .05553 L
.2203 .05553 L
.25514 .05553 L
.29218 .05553 L
.32786 .05553 L
.36219 .05553 L
.39871 .05553 L
.43387 .05553 L
.46768 .05553 L
.50369 .05553 L
.53833 .05553 L
.57517 .05553 L
.61066 .05553 L
.64479 .05553 L
.68111 .05553 L
.71607 .05553 L
.75323 .05553 L
.78904 .05553 L
.82349 .05553 L
.86013 .05553 L
.89362 .05553 L
s
.04255 .07119 m
.07708 .07119 L
.11473 .07119 L
.15009 .07119 L
.1841 .07119 L
.2203 .07119 L
.25514 .07119 L
.29218 .07119 L
.32786 .07119 L
.36219 .07119 L
.39871 .07119 L
.43387 .07119 L
.46768 .07119 L
.50369 .07119 L
.53833 .07119 L
.57517 .07119 L
.61066 .07119 L
.64479 .07119 L
.68111 .07119 L
.71607 .07119 L
.75323 .07119 L
.78904 .07119 L
.82349 .07119 L
.86013 .07119 L
.89362 .07119 L
s
.04255 .08685 m
.07708 .08685 L
.11473 .08685 L
.15009 .08685 L
.1841 .08685 L
.2203 .08685 L
.25514 .08685 L
.29218 .08685 L
.32786 .08685 L
.36219 .08685 L
.39871 .08685 L
.43387 .08685 L
.46768 .08685 L
.50369 .08685 L
.53833 .08685 L
.57517 .08685 L
.61066 .08685 L
.64479 .08685 L
.68111 .08685 L
.71607 .08685 L
.75323 .08685 L
.78904 .08685 L
.82349 .08685 L
.86013 .08685 L
.89362 .08685 L
s
.04255 .10251 m
.07708 .10251 L
.11473 .10251 L
.15009 .10251 L
.1841 .10251 L
.2203 .10251 L
.25514 .10251 L
.29218 .10251 L
.32786 .10251 L
.36219 .10251 L
.39871 .10251 L
.43387 .10251 L
.46768 .10251 L
.50369 .10251 L
.53833 .10251 L
.57517 .10251 L
.61066 .10251 L
.64479 .10251 L
.68111 .10251 L
.71607 .10251 L
.75323 .10251 L
.78904 .10251 L
.82349 .10251 L
.86013 .10251 L
.89362 .10251 L
s
.04255 .11816 m
.07708 .11816 L
.11473 .11816 L
.15009 .11816 L
.1841 .11816 L
.2203 .11816 L
.25514 .11816 L
.29218 .11816 L
.32786 .11816 L
.36219 .11816 L
.39871 .11816 L
.43387 .11816 L
.46768 .11816 L
.50369 .11816 L
.53833 .11816 L
.57517 .11816 L
.61066 .11816 L
.64479 .11816 L
.68111 .11816 L
.71607 .11816 L
.75323 .11816 L
.78904 .11816 L
.82349 .11816 L
.86013 .11816 L
.89362 .11816 L
s
.04255 .13382 m
.07708 .13382 L
.11473 .13382 L
.15009 .13382 L
.1841 .13382 L
.2203 .13382 L
.25514 .13382 L
.29218 .13382 L
.32786 .13382 L
.36219 .13382 L
.39871 .13382 L
.43387 .13382 L
.46768 .13382 L
.50369 .13382 L
.53833 .13382 L
.57517 .13382 L
.61066 .13382 L
.64479 .13382 L
.68111 .13382 L
.71607 .13382 L
.75323 .13382 L
.78904 .13382 L
.82349 .13382 L
.86013 .13382 L
.89362 .13382 L
s
.04255 .14948 m
.07708 .14948 L
.11473 .14948 L
.15009 .14948 L
.1841 .14948 L
.2203 .14948 L
.25514 .14948 L
.29218 .14948 L
.32786 .14948 L
.36219 .14948 L
.39871 .14948 L
.43387 .14948 L
.46768 .14948 L
.50369 .14948 L
.53833 .14948 L
.57517 .14948 L
.61066 .14948 L
.64479 .14948 L
.68111 .14948 L
.71607 .14948 L
.75323 .14948 L
.78904 .14948 L
.82349 .14948 L
.86013 .14948 L
.89362 .14948 L
s
.04255 .16514 m
.07708 .16514 L
.11473 .16514 L
.15009 .16514 L
.1841 .16514 L
.2203 .16514 L
.25514 .16514 L
.29218 .16514 L
.32786 .16514 L
.36219 .16514 L
.39871 .16514 L
.43387 .16514 L
.46768 .16514 L
.50369 .16514 L
.53833 .16514 L
.57517 .16514 L
.61066 .16514 L
.64479 .16514 L
.68111 .16514 L
.71607 .16514 L
.75323 .16514 L
.78904 .16514 L
.82349 .16514 L
.86013 .16514 L
.89362 .16514 L
s
.04255 .2904 m
.04255 .29549 L
.04255 .30103 L
.04255 .30623 L
.04255 .31124 L
.04255 .31657 L
.04255 .32169 L
.04255 .32715 L
.04255 .3324 L
.04255 .33745 L
.04255 .34283 L
.04255 .348 L
.04255 .35298 L
.04255 .35828 L
.04255 .36338 L
.04255 .3688 L
.04255 .37402 L
.04255 .37904 L
.04255 .38439 L
.04255 .38954 L
.04255 .39501 L
.04255 .40028 L
.04255 .40535 L
.04255 .41074 L
.04255 .41567 L
s
.14894 .2904 m
.14894 .29549 L
.14894 .30103 L
.14894 .30623 L
.14894 .31124 L
.14894 .31657 L
.14894 .32169 L
.14894 .32715 L
.14894 .3324 L
.14894 .33745 L
.14894 .34283 L
.14894 .348 L
.14894 .35298 L
.14894 .35828 L
.14894 .36338 L
.14894 .3688 L
.14894 .37402 L
.14894 .37904 L
.14894 .38439 L
.14894 .38954 L
.14894 .39501 L
.14894 .40028 L
.14894 .40535 L
.14894 .41074 L
.14894 .41567 L
s
.25532 .2904 m
.25532 .29549 L
.25532 .30103 L
.25532 .30623 L
.25532 .31124 L
.25532 .31657 L
.25532 .32169 L
.25532 .32715 L
.25532 .3324 L
.25532 .33745 L
.25532 .34283 L
.25532 .348 L
.25532 .35298 L
.25532 .35828 L
.25532 .36338 L
.25532 .3688 L
.25532 .37402 L
.25532 .37904 L
.25532 .38439 L
.25532 .38954 L
.25532 .39501 L
.25532 .40028 L
.25532 .40535 L
.25532 .41074 L
.25532 .41567 L
s
.3617 .2904 m
.3617 .29549 L
.3617 .30103 L
.3617 .30623 L
.3617 .31124 L
.3617 .31657 L
.3617 .32169 L
.3617 .32715 L
.3617 .3324 L
.3617 .33745 L
.3617 .34283 L
.3617 .348 L
.3617 .35298 L
.3617 .35828 L
.3617 .36338 L
.3617 .3688 L
.3617 .37402 L
.3617 .37904 L
.3617 .38439 L
.3617 .38954 L
.3617 .39501 L
.3617 .40028 L
.3617 .40535 L
.3617 .41074 L
.3617 .41567 L
s
.46809 .2904 m
.46809 .29549 L
.46809 .30103 L
.46809 .30623 L
.46809 .31124 L
.46809 .31657 L
.46809 .32169 L
.46809 .32715 L
.46809 .3324 L
.46809 .33745 L
.46809 .34283 L
.46809 .348 L
.46809 .35298 L
.46809 .35828 L
.46809 .36338 L
.46809 .3688 L
.46809 .37402 L
.46809 .37904 L
.46809 .38439 L
.46809 .38954 L
.46809 .39501 L
.46809 .40028 L
.46809 .40535 L
.46809 .41074 L
.46809 .41567 L
s
.57447 .2904 m
.57447 .29549 L
.57447 .30103 L
.57447 .30623 L
.57447 .31124 L
.57447 .31657 L
.57447 .32169 L
.57447 .32715 L
.57447 .3324 L
.57447 .33745 L
.57447 .34283 L
.57447 .348 L
.57447 .35298 L
.57447 .35828 L
.57447 .36338 L
.57447 .3688 L
.57447 .37402 L
.57447 .37904 L
.57447 .38439 L
.57447 .38954 L
.57447 .39501 L
.57447 .40028 L
.57447 .40535 L
.57447 .41074 L
.57447 .41567 L
s
.68085 .2904 m
.68085 .29549 L
.68085 .30103 L
.68085 .30623 L
.68085 .31124 L
.68085 .31657 L
.68085 .32169 L
.68085 .32715 L
.68085 .3324 L
.68085 .33745 L
.68085 .34283 L
.68085 .348 L
.68085 .35298 L
.68085 .35828 L
.68085 .36338 L
.68085 .3688 L
.68085 .37402 L
.68085 .37904 L
.68085 .38439 L
.68085 .38954 L
.68085 .39501 L
.68085 .40028 L
.68085 .40535 L
.68085 .41074 L
.68085 .41567 L
s
.78723 .2904 m
.78723 .29549 L
.78723 .30103 L
.78723 .30623 L
.78723 .31124 L
.78723 .31657 L
.78723 .32169 L
.78723 .32715 L
.78723 .3324 L
.78723 .33745 L
.78723 .34283 L
.78723 .348 L
.78723 .35298 L
.78723 .35828 L
.78723 .36338 L
.78723 .3688 L
.78723 .37402 L
.78723 .37904 L
.78723 .38439 L
.78723 .38954 L
.78723 .39501 L
.78723 .40028 L
.78723 .40535 L
.78723 .41074 L
.78723 .41567 L
s
.89362 .2904 m
.89362 .29549 L
.89362 .30103 L
.89362 .30623 L
.89362 .31124 L
.89362 .31657 L
.89362 .32169 L
.89362 .32715 L
.89362 .3324 L
.89362 .33745 L
.89362 .34283 L
.89362 .348 L
.89362 .35298 L
.89362 .35828 L
.89362 .36338 L
.89362 .3688 L
.89362 .37402 L
.89362 .37904 L
.89362 .38439 L
.89362 .38954 L
.89362 .39501 L
.89362 .40028 L
.89362 .40535 L
.89362 .41074 L
.89362 .41567 L
s
.04255 .2904 m
.07708 .2904 L
.11473 .2904 L
.15009 .2904 L
.1841 .2904 L
.2203 .2904 L
.25514 .2904 L
.29218 .2904 L
.32786 .2904 L
.36219 .2904 L
.39871 .2904 L
.43387 .2904 L
.46768 .2904 L
.50369 .2904 L
.53833 .2904 L
.57517 .2904 L
.61066 .2904 L
.64479 .2904 L
.68111 .2904 L
.71607 .2904 L
.75323 .2904 L
.78904 .2904 L
.82349 .2904 L
.86013 .2904 L
.89362 .2904 L
s
.04255 .30606 m
.07708 .30606 L
.11473 .30606 L
.15009 .30606 L
.1841 .30606 L
.2203 .30606 L
.25514 .30606 L
.29218 .30606 L
.32786 .30606 L
.36219 .30606 L
.39871 .30606 L
.43387 .30606 L
.46768 .30606 L
.50369 .30606 L
.53833 .30606 L
.57517 .30606 L
.61066 .30606 L
.64479 .30606 L
.68111 .30606 L
.71607 .30606 L
.75323 .30606 L
.78904 .30606 L
.82349 .30606 L
.86013 .30606 L
.89362 .30606 L
s
.04255 .32172 m
.07708 .32172 L
.11473 .32172 L
.15009 .32172 L
.1841 .32172 L
.2203 .32172 L
.25514 .32172 L
.29218 .32172 L
.32786 .32172 L
.36219 .32172 L
.39871 .32172 L
.43387 .32172 L
.46768 .32172 L
.50369 .32172 L
.53833 .32172 L
.57517 .32172 L
.61066 .32172 L
.64479 .32172 L
.68111 .32172 L
.71607 .32172 L
.75323 .32172 L
.78904 .32172 L
.82349 .32172 L
.86013 .32172 L
.89362 .32172 L
s
.04255 .33738 m
.07708 .33738 L
.11473 .33738 L
.15009 .33738 L
.1841 .33738 L
.2203 .33738 L
.25514 .33738 L
.29218 .33738 L
.32786 .33738 L
.36219 .33738 L
.39871 .33738 L
.43387 .33738 L
.46768 .33738 L
.50369 .33738 L
.53833 .33738 L
.57517 .33738 L
.61066 .33738 L
.64479 .33738 L
.68111 .33738 L
.71607 .33738 L
.75323 .33738 L
.78904 .33738 L
.82349 .33738 L
.86013 .33738 L
.89362 .33738 L
s
.04255 .35304 m
.07708 .35304 L
.11473 .35304 L
.15009 .35304 L
.1841 .35304 L
.2203 .35304 L
.25514 .35304 L
.29218 .35304 L
.32786 .35304 L
.36219 .35304 L
.39871 .35304 L
.43387 .35304 L
.46768 .35304 L
.50369 .35304 L
.53833 .35304 L
.57517 .35304 L
.61066 .35304 L
.64479 .35304 L
.68111 .35304 L
.71607 .35304 L
.75323 .35304 L
.78904 .35304 L
.82349 .35304 L
.86013 .35304 L
.89362 .35304 L
s
.04255 .36869 m
.07708 .36869 L
.11473 .36869 L
.15009 .36869 L
.1841 .36869 L
.2203 .36869 L
.25514 .36869 L
.29218 .36869 L
.32786 .36869 L
.36219 .36869 L
.39871 .36869 L
.43387 .36869 L
.46768 .36869 L
.50369 .36869 L
.53833 .36869 L
.57517 .36869 L
.61066 .36869 L
.64479 .36869 L
.68111 .36869 L
.71607 .36869 L
.75323 .36869 L
.78904 .36869 L
.82349 .36869 L
.86013 .36869 L
.89362 .36869 L
s
.04255 .38435 m
.07708 .38435 L
.11473 .38435 L
.15009 .38435 L
.1841 .38435 L
.2203 .38435 L
.25514 .38435 L
.29218 .38435 L
.32786 .38435 L
.36219 .38435 L
.39871 .38435 L
.43387 .38435 L
.46768 .38435 L
.50369 .38435 L
.53833 .38435 L
.57517 .38435 L
.61066 .38435 L
.64479 .38435 L
.68111 .38435 L
.71607 .38435 L
.75323 .38435 L
.78904 .38435 L
.82349 .38435 L
.86013 .38435 L
.89362 .38435 L
s
.04255 .40001 m
.07708 .40001 L
.11473 .40001 L
.15009 .40001 L
.1841 .40001 L
.2203 .40001 L
.25514 .40001 L
.29218 .40001 L
.32786 .40001 L
.36219 .40001 L
.39871 .40001 L
.43387 .40001 L
.46768 .40001 L
.50369 .40001 L
.53833 .40001 L
.57517 .40001 L
.61066 .40001 L
.64479 .40001 L
.68111 .40001 L
.71607 .40001 L
.75323 .40001 L
.78904 .40001 L
.82349 .40001 L
.86013 .40001 L
.89362 .40001 L
s
.04255 .41567 m
.07708 .41567 L
.11473 .41567 L
.15009 .41567 L
.1841 .41567 L
.2203 .41567 L
.25514 .41567 L
.29218 .41567 L
.32786 .41567 L
.36219 .41567 L
.39871 .41567 L
.43387 .41567 L
.46768 .41567 L
.50369 .41567 L
.53833 .41567 L
.57517 .41567 L
.61066 .41567 L
.64479 .41567 L
.68111 .41567 L
.71607 .41567 L
.75323 .41567 L
.78904 .41567 L
.82349 .41567 L
.86013 .41567 L
.89362 .41567 L
s
.04255 .16514 m
.04255 .17022 L
.04255 .17576 L
.04255 .18097 L
.04255 .18597 L
.04255 .1913 L
.04255 .19643 L
.04255 .20188 L
.04255 .20713 L
.04255 .21218 L
.04255 .21756 L
.04255 .22274 L
.04255 .22771 L
.04255 .23301 L
.04255 .23811 L
.04255 .24353 L
.04255 .24876 L
.04255 .25378 L
.04255 .25913 L
.04255 .26427 L
.04255 .26974 L
.04255 .27501 L
.04255 .28008 L
.04255 .28547 L
.04255 .2904 L
s
.14894 .16514 m
.14894 .17022 L
.14894 .17576 L
.14894 .18097 L
.14894 .18597 L
.14894 .1913 L
.14894 .19643 L
.14894 .20188 L
.14894 .20713 L
.14894 .21218 L
.14894 .21756 L
.14894 .22274 L
.14894 .22771 L
.14894 .23301 L
.14894 .23811 L
.14894 .24353 L
.14894 .24876 L
.14894 .25378 L
.14894 .25913 L
.14894 .26427 L
.14894 .26974 L
.14894 .27501 L
.14894 .28008 L
.14894 .28547 L
.14894 .2904 L
s
.25532 .16514 m
.25532 .17022 L
.25532 .17576 L
.25532 .18097 L
.25532 .18597 L
.25532 .1913 L
.25532 .19643 L
.25532 .20188 L
.25532 .20713 L
.25532 .21218 L
.25532 .21756 L
.25532 .22274 L
.25532 .22771 L
.25532 .23301 L
.25532 .23811 L
.25532 .24353 L
.25532 .24876 L
.25532 .25378 L
.25532 .25913 L
.25532 .26427 L
.25532 .26974 L
.25532 .27501 L
.25532 .28008 L
.25532 .28547 L
.25532 .2904 L
s
.3617 .16514 m
.3617 .17022 L
.3617 .17576 L
.3617 .18097 L
.3617 .18597 L
.3617 .1913 L
.3617 .19643 L
.3617 .20188 L
.3617 .20713 L
.3617 .21218 L
.3617 .21756 L
.3617 .22274 L
.3617 .22771 L
.3617 .23301 L
.3617 .23811 L
.3617 .24353 L
.3617 .24876 L
.3617 .25378 L
.3617 .25913 L
.3617 .26427 L
.3617 .26974 L
.3617 .27501 L
.3617 .28008 L
.3617 .28547 L
.3617 .2904 L
s
.46809 .16514 m
.46809 .17022 L
.46809 .17576 L
.46809 .18097 L
.46809 .18597 L
.46809 .1913 L
.46809 .19643 L
.46809 .20188 L
.46809 .20713 L
.46809 .21218 L
.46809 .21756 L
.46809 .22274 L
.46809 .22771 L
.46809 .23301 L
.46809 .23811 L
.46809 .24353 L
.46809 .24876 L
.46809 .25378 L
.46809 .25913 L
.46809 .26427 L
.46809 .26974 L
.46809 .27501 L
.46809 .28008 L
.46809 .28547 L
.46809 .2904 L
s
.57447 .16514 m
.57447 .17022 L
.57447 .17576 L
.57447 .18097 L
.57447 .18597 L
.57447 .1913 L
.57447 .19643 L
.57447 .20188 L
.57447 .20713 L
.57447 .21218 L
.57447 .21756 L
.57447 .22274 L
.57447 .22771 L
.57447 .23301 L
.57447 .23811 L
.57447 .24353 L
.57447 .24876 L
.57447 .25378 L
.57447 .25913 L
.57447 .26427 L
.57447 .26974 L
.57447 .27501 L
.57447 .28008 L
.57447 .28547 L
.57447 .2904 L
s
.68085 .16514 m
.68085 .17022 L
.68085 .17576 L
.68085 .18097 L
.68085 .18597 L
.68085 .1913 L
.68085 .19643 L
.68085 .20188 L
.68085 .20713 L
.68085 .21218 L
.68085 .21756 L
.68085 .22274 L
.68085 .22771 L
.68085 .23301 L
.68085 .23811 L
.68085 .24353 L
.68085 .24876 L
.68085 .25378 L
.68085 .25913 L
.68085 .26427 L
.68085 .26974 L
.68085 .27501 L
.68085 .28008 L
.68085 .28547 L
.68085 .2904 L
s
.78723 .16514 m
.78723 .17022 L
.78723 .17576 L
.78723 .18097 L
.78723 .18597 L
.78723 .1913 L
.78723 .19643 L
.78723 .20188 L
.78723 .20713 L
.78723 .21218 L
.78723 .21756 L
.78723 .22274 L
.78723 .22771 L
.78723 .23301 L
.78723 .23811 L
.78723 .24353 L
.78723 .24876 L
.78723 .25378 L
.78723 .25913 L
.78723 .26427 L
.78723 .26974 L
.78723 .27501 L
.78723 .28008 L
.78723 .28547 L
.78723 .2904 L
s
.89362 .16514 m
.89362 .17022 L
.89362 .17576 L
.89362 .18097 L
.89362 .18597 L
.89362 .1913 L
.89362 .19643 L
.89362 .20188 L
.89362 .20713 L
.89362 .21218 L
.89362 .21756 L
.89362 .22274 L
.89362 .22771 L
.89362 .23301 L
.89362 .23811 L
.89362 .24353 L
.89362 .24876 L
.89362 .25378 L
.89362 .25913 L
.89362 .26427 L
.89362 .26974 L
.89362 .27501 L
.89362 .28008 L
.89362 .28547 L
.89362 .2904 L
s
.04255 .16514 m
.07708 .16514 L
.11473 .16514 L
.15009 .16514 L
.1841 .16514 L
.2203 .16514 L
.25514 .16514 L
.29218 .16514 L
.32786 .16514 L
.36219 .16514 L
.39871 .16514 L
.43387 .16514 L
.46768 .16514 L
.50369 .16514 L
.53833 .16514 L
.57517 .16514 L
.61066 .16514 L
.64479 .16514 L
.68111 .16514 L
.71607 .16514 L
.75323 .16514 L
.78904 .16514 L
.82349 .16514 L
.86013 .16514 L
.89362 .16514 L
s
.04255 .1808 m
.07708 .1808 L
.11473 .1808 L
.15009 .1808 L
.1841 .1808 L
.2203 .1808 L
.25514 .1808 L
.29218 .1808 L
.32786 .1808 L
.36219 .1808 L
.39871 .1808 L
.43387 .1808 L
.46768 .1808 L
.50369 .1808 L
.53833 .1808 L
.57517 .1808 L
.61066 .1808 L
.64479 .1808 L
.68111 .1808 L
.71607 .1808 L
.75323 .1808 L
.78904 .1808 L
.82349 .1808 L
.86013 .1808 L
.89362 .1808 L
s
.04255 .19645 m
.07708 .19645 L
.11473 .19645 L
.15009 .19645 L
.1841 .19645 L
.2203 .19645 L
.25514 .19645 L
.29218 .19645 L
.32786 .19645 L
.36219 .19645 L
.39871 .19645 L
.43387 .19645 L
.46768 .19645 L
.50369 .19645 L
.53833 .19645 L
.57517 .19645 L
.61066 .19645 L
.64479 .19645 L
.68111 .19645 L
.71607 .19645 L
.75323 .19645 L
.78904 .19645 L
.82349 .19645 L
.86013 .19645 L
.89362 .19645 L
s
.04255 .21211 m
.07708 .21211 L
.11473 .21211 L
.15009 .21211 L
.1841 .21211 L
.2203 .21211 L
.25514 .21211 L
.29218 .21211 L
.32786 .21211 L
.36219 .21211 L
.39871 .21211 L
.43387 .21211 L
.46768 .21211 L
.50369 .21211 L
.53833 .21211 L
.57517 .21211 L
.61066 .21211 L
.64479 .21211 L
.68111 .21211 L
.71607 .21211 L
.75323 .21211 L
.78904 .21211 L
.82349 .21211 L
.86013 .21211 L
.89362 .21211 L
s
.04255 .22777 m
.07708 .22777 L
.11473 .22777 L
.15009 .22777 L
.1841 .22777 L
.2203 .22777 L
.25514 .22777 L
.29218 .22777 L
.32786 .22777 L
.36219 .22777 L
.39871 .22777 L
.43387 .22777 L
.46768 .22777 L
.50369 .22777 L
.53833 .22777 L
.57517 .22777 L
.61066 .22777 L
.64479 .22777 L
.68111 .22777 L
.71607 .22777 L
.75323 .22777 L
.78904 .22777 L
.82349 .22777 L
.86013 .22777 L
.89362 .22777 L
s
.04255 .24343 m
.07708 .24343 L
.11473 .24343 L
.15009 .24343 L
.1841 .24343 L
.2203 .24343 L
.25514 .24343 L
.29218 .24343 L
.32786 .24343 L
.36219 .24343 L
.39871 .24343 L
.43387 .24343 L
.46768 .24343 L
.50369 .24343 L
.53833 .24343 L
.57517 .24343 L
.61066 .24343 L
.64479 .24343 L
.68111 .24343 L
.71607 .24343 L
.75323 .24343 L
.78904 .24343 L
.82349 .24343 L
.86013 .24343 L
.89362 .24343 L
s
.04255 .25909 m
.07708 .25909 L
.11473 .25909 L
.15009 .25909 L
.1841 .25909 L
.2203 .25909 L
.25514 .25909 L
.29218 .25909 L
.32786 .25909 L
.36219 .25909 L
.39871 .25909 L
.43387 .25909 L
.46768 .25909 L
.50369 .25909 L
.53833 .25909 L
.57517 .25909 L
.61066 .25909 L
.64479 .25909 L
.68111 .25909 L
.71607 .25909 L
.75323 .25909 L
.78904 .25909 L
.82349 .25909 L
.86013 .25909 L
.89362 .25909 L
s
.04255 .27475 m
.07708 .27475 L
.11473 .27475 L
.15009 .27475 L
.1841 .27475 L
.2203 .27475 L
.25514 .27475 L
.29218 .27475 L
.32786 .27475 L
.36219 .27475 L
.39871 .27475 L
.43387 .27475 L
.46768 .27475 L
.50369 .27475 L
.53833 .27475 L
.57517 .27475 L
.61066 .27475 L
.64479 .27475 L
.68111 .27475 L
.71607 .27475 L
.75323 .27475 L
.78904 .27475 L
.82349 .27475 L
.86013 .27475 L
.89362 .27475 L
s
.04255 .2904 m
.07708 .2904 L
.11473 .2904 L
.15009 .2904 L
.1841 .2904 L
.2203 .2904 L
.25514 .2904 L
.29218 .2904 L
.32786 .2904 L
.36219 .2904 L
.39871 .2904 L
.43387 .2904 L
.46768 .2904 L
.50369 .2904 L
.53833 .2904 L
.57517 .2904 L
.61066 .2904 L
.64479 .2904 L
.68111 .2904 L
.71607 .2904 L
.75323 .2904 L
.78904 .2904 L
.82349 .2904 L
.86013 .2904 L
.89362 .2904 L
s
.04255 .41567 m
.04255 .42075 L
.04255 .42629 L
.04255 .4315 L
.04255 .4365 L
.04255 .44183 L
.04255 .44696 L
.04255 .45241 L
.04255 .45766 L
.04255 .46272 L
.04255 .46809 L
.04255 .47327 L
.04255 .47824 L
.04255 .48354 L
.04255 .48864 L
.04255 .49406 L
.04255 .49929 L
.04255 .50431 L
.04255 .50966 L
.04255 .5148 L
.04255 .52027 L
.04255 .52554 L
.04255 .53061 L
.04255 .536 L
.04255 .54093 L
s
.14894 .41567 m
.14894 .42075 L
.14894 .42629 L
.14894 .4315 L
.14894 .4365 L
.14894 .44183 L
.14894 .44696 L
.14894 .45241 L
.14894 .45766 L
.14894 .46272 L
.14894 .46809 L
.14894 .47327 L
.14894 .47824 L
.14894 .48354 L
.14894 .48864 L
.14894 .49406 L
.14894 .49929 L
.14894 .50431 L
.14894 .50966 L
.14894 .5148 L
.14894 .52027 L
.14894 .52554 L
.14894 .53061 L
.14894 .536 L
.14894 .54093 L
s
.25532 .41567 m
.25532 .42075 L
.25532 .42629 L
.25532 .4315 L
.25532 .4365 L
.25532 .44183 L
.25532 .44696 L
.25532 .45241 L
.25532 .45766 L
.25532 .46272 L
.25532 .46809 L
.25532 .47327 L
.25532 .47824 L
.25532 .48354 L
.25532 .48864 L
.25532 .49406 L
.25532 .49929 L
.25532 .50431 L
.25532 .50966 L
.25532 .5148 L
.25532 .52027 L
.25532 .52554 L
.25532 .53061 L
.25532 .536 L
.25532 .54093 L
s
.3617 .41567 m
.3617 .42075 L
.3617 .42629 L
.3617 .4315 L
.3617 .4365 L
.3617 .44183 L
.3617 .44696 L
.3617 .45241 L
.3617 .45766 L
.3617 .46272 L
.3617 .46809 L
.3617 .47327 L
.3617 .47824 L
.3617 .48354 L
.3617 .48864 L
.3617 .49406 L
.3617 .49929 L
.3617 .50431 L
.3617 .50966 L
.3617 .5148 L
.3617 .52027 L
.3617 .52554 L
.3617 .53061 L
.3617 .536 L
.3617 .54093 L
s
.46809 .41567 m
.46809 .42075 L
.46809 .42629 L
.46809 .4315 L
.46809 .4365 L
.46809 .44183 L
.46809 .44696 L
.46809 .45241 L
.46809 .45766 L
.46809 .46272 L
.46809 .46809 L
.46809 .47327 L
.46809 .47824 L
.46809 .48354 L
.46809 .48864 L
.46809 .49406 L
.46809 .49929 L
.46809 .50431 L
.46809 .50966 L
.46809 .5148 L
.46809 .52027 L
.46809 .52554 L
.46809 .53061 L
.46809 .536 L
.46809 .54093 L
s
.57447 .41567 m
.57447 .42075 L
.57447 .42629 L
.57447 .4315 L
.57447 .4365 L
.57447 .44183 L
.57447 .44696 L
.57447 .45241 L
.57447 .45766 L
.57447 .46272 L
.57447 .46809 L
.57447 .47327 L
.57447 .47824 L
.57447 .48354 L
.57447 .48864 L
.57447 .49406 L
.57447 .49929 L
.57447 .50431 L
.57447 .50966 L
.57447 .5148 L
.57447 .52027 L
.57447 .52554 L
.57447 .53061 L
.57447 .536 L
.57447 .54093 L
s
.68085 .41567 m
.68085 .42075 L
.68085 .42629 L
.68085 .4315 L
.68085 .4365 L
.68085 .44183 L
.68085 .44696 L
.68085 .45241 L
.68085 .45766 L
.68085 .46272 L
.68085 .46809 L
.68085 .47327 L
.68085 .47824 L
.68085 .48354 L
.68085 .48864 L
.68085 .49406 L
.68085 .49929 L
.68085 .50431 L
.68085 .50966 L
.68085 .5148 L
.68085 .52027 L
.68085 .52554 L
.68085 .53061 L
.68085 .536 L
.68085 .54093 L
s
.78723 .41567 m
.78723 .42075 L
.78723 .42629 L
.78723 .4315 L
.78723 .4365 L
.78723 .44183 L
.78723 .44696 L
.78723 .45241 L
.78723 .45766 L
.78723 .46272 L
.78723 .46809 L
.78723 .47327 L
.78723 .47824 L
.78723 .48354 L
.78723 .48864 L
.78723 .49406 L
.78723 .49929 L
.78723 .50431 L
.78723 .50966 L
.78723 .5148 L
.78723 .52027 L
.78723 .52554 L
.78723 .53061 L
.78723 .536 L
.78723 .54093 L
s
.89362 .41567 m
.89362 .42075 L
.89362 .42629 L
.89362 .4315 L
.89362 .4365 L
.89362 .44183 L
.89362 .44696 L
.89362 .45241 L
.89362 .45766 L
.89362 .46272 L
.89362 .46809 L
.89362 .47327 L
.89362 .47824 L
.89362 .48354 L
.89362 .48864 L
.89362 .49406 L
.89362 .49929 L
.89362 .50431 L
.89362 .50966 L
.89362 .5148 L
.89362 .52027 L
.89362 .52554 L
.89362 .53061 L
.89362 .536 L
.89362 .54093 L
s
.04255 .41567 m
.07708 .41567 L
.11473 .41567 L
.15009 .41567 L
.1841 .41567 L
.2203 .41567 L
.25514 .41567 L
.29218 .41567 L
.32786 .41567 L
.36219 .41567 L
.39871 .41567 L
.43387 .41567 L
.46768 .41567 L
.50369 .41567 L
.53833 .41567 L
.57517 .41567 L
.61066 .41567 L
.64479 .41567 L
.68111 .41567 L
.71607 .41567 L
.75323 .41567 L
.78904 .41567 L
.82349 .41567 L
.86013 .41567 L
.89362 .41567 L
s
.04255 .43133 m
.07708 .43133 L
.11473 .43133 L
.15009 .43133 L
.1841 .43133 L
.2203 .43133 L
.25514 .43133 L
.29218 .43133 L
.32786 .43133 L
.36219 .43133 L
.39871 .43133 L
.43387 .43133 L
.46768 .43133 L
.50369 .43133 L
.53833 .43133 L
.57517 .43133 L
.61066 .43133 L
.64479 .43133 L
.68111 .43133 L
.71607 .43133 L
.75323 .43133 L
.78904 .43133 L
.82349 .43133 L
.86013 .43133 L
.89362 .43133 L
s
.04255 .44699 m
.07708 .44699 L
.11473 .44699 L
.15009 .44699 L
.1841 .44699 L
.2203 .44699 L
.25514 .44699 L
.29218 .44699 L
.32786 .44699 L
.36219 .44699 L
.39871 .44699 L
.43387 .44699 L
.46768 .44699 L
.50369 .44699 L
.53833 .44699 L
.57517 .44699 L
.61066 .44699 L
.64479 .44699 L
.68111 .44699 L
.71607 .44699 L
.75323 .44699 L
.78904 .44699 L
.82349 .44699 L
.86013 .44699 L
.89362 .44699 L
s
.04255 .46264 m
.07708 .46264 L
.11473 .46264 L
.15009 .46264 L
.1841 .46264 L
.2203 .46264 L
.25514 .46264 L
.29218 .46264 L
.32786 .46264 L
.36219 .46264 L
.39871 .46264 L
.43387 .46264 L
.46768 .46264 L
.50369 .46264 L
.53833 .46264 L
.57517 .46264 L
.61066 .46264 L
.64479 .46264 L
.68111 .46264 L
.71607 .46264 L
.75323 .46264 L
.78904 .46264 L
.82349 .46264 L
.86013 .46264 L
.89362 .46264 L
s
.04255 .4783 m
.07708 .4783 L
.11473 .4783 L
.15009 .4783 L
.1841 .4783 L
.2203 .4783 L
.25514 .4783 L
.29218 .4783 L
.32786 .4783 L
.36219 .4783 L
.39871 .4783 L
.43387 .4783 L
.46768 .4783 L
.50369 .4783 L
.53833 .4783 L
.57517 .4783 L
.61066 .4783 L
.64479 .4783 L
.68111 .4783 L
.71607 .4783 L
.75323 .4783 L
.78904 .4783 L
.82349 .4783 L
.86013 .4783 L
.89362 .4783 L
s
.04255 .49396 m
.07708 .49396 L
.11473 .49396 L
.15009 .49396 L
.1841 .49396 L
.2203 .49396 L
.25514 .49396 L
.29218 .49396 L
.32786 .49396 L
.36219 .49396 L
.39871 .49396 L
.43387 .49396 L
.46768 .49396 L
.50369 .49396 L
.53833 .49396 L
.57517 .49396 L
.61066 .49396 L
.64479 .49396 L
.68111 .49396 L
.71607 .49396 L
.75323 .49396 L
.78904 .49396 L
.82349 .49396 L
.86013 .49396 L
.89362 .49396 L
s
.04255 .50962 m
.07708 .50962 L
.11473 .50962 L
.15009 .50962 L
.1841 .50962 L
.2203 .50962 L
.25514 .50962 L
.29218 .50962 L
.32786 .50962 L
.36219 .50962 L
.39871 .50962 L
.43387 .50962 L
.46768 .50962 L
.50369 .50962 L
.53833 .50962 L
.57517 .50962 L
.61066 .50962 L
.64479 .50962 L
.68111 .50962 L
.71607 .50962 L
.75323 .50962 L
.78904 .50962 L
.82349 .50962 L
.86013 .50962 L
.89362 .50962 L
s
.04255 .52528 m
.07708 .52528 L
.11473 .52528 L
.15009 .52528 L
.1841 .52528 L
.2203 .52528 L
.25514 .52528 L
.29218 .52528 L
.32786 .52528 L
.36219 .52528 L
.39871 .52528 L
.43387 .52528 L
.46768 .52528 L
.50369 .52528 L
.53833 .52528 L
.57517 .52528 L
.61066 .52528 L
.64479 .52528 L
.68111 .52528 L
.71607 .52528 L
.75323 .52528 L
.78904 .52528 L
.82349 .52528 L
.86013 .52528 L
.89362 .52528 L
s
.04255 .54093 m
.07708 .54093 L
.11473 .54093 L
.15009 .54093 L
.1841 .54093 L
.2203 .54093 L
.25514 .54093 L
.29218 .54093 L
.32786 .54093 L
.36219 .54093 L
.39871 .54093 L
.43387 .54093 L
.46768 .54093 L
.50369 .54093 L
.53833 .54093 L
.57517 .54093 L
.61066 .54093 L
.64479 .54093 L
.68111 .54093 L
.71607 .54093 L
.75323 .54093 L
.78904 .54093 L
.82349 .54093 L
.86013 .54093 L
.89362 .54093 L
s
gsave
.93617 .16514 -66.875 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.500 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
70.750 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .2904 -68.125 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
68.000 14.938 moveto
(p) show
73.250 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .41567 -68.125 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
68.000 14.938 moveto
(p) show
73.250 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .54093 -68.125 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
68.000 14.938 moveto
(p) show
73.250 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.02 w
.73404 .019 Mdot
.73404 .26953 Mdot
.73404 .52006 Mdot
0 g
.5 Mabswid
.89362 .03987 m
1 .03987 L
s
% Start of user PostScript
2. 0 2.5 0 MAarrowhead1
% End of user PostScript
.46809 .57816 m
.46809 .61803 L
s
% Start of user PostScript
0 13.5 0 14.5 MAarrowhead1
% End of user PostScript
gsave
.96809 .07576 -66 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .59411 -69 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3oool0101>CTh0000000000000000j0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0f0?ooo`04
04i>CP000000000000000240oooo000;0?ooo`@0000000<0d=3@08f=S@3oool0=03oool4000000<0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03H0
oooo00<0d=3@08f=S@3oool08P3oool00140oooo00<0YjNW0?ooo`3oool0>@3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`2WYjL0oooo
0?ooo`0P0?ooo`004@3oool00`3YjNT0SHf=0?ooo`0i0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`0;0?ooo`<0o`00:P3oool00`3YjNT0SHf=0?oo
o`0P0?ooo`003`3oool0101>CTh0jNWY0>WYj@00000i0?ooo`030:NWY`000000oooo03L0oooo00<0
00000?ooo`3oool0>03oool00`2WYjL000000?ooo`0;0?ooo`D0o`009`3oool0101>CTh0jNWY0>WY
j@00000Q0?ooo`003`3oool0103@d=00CTi>04i>CP3@d=0j0?ooo`0306QXJ03oool0oooo03H0oooo
00<000000?ooo`3oool0>@3oool00`1XJ6P0oooo0?ooo`0:0?ooo`D0o`009`3oool0103@d=00CTi>
04i>CP3@d=0Q0?ooo`00QP3oool00`000000oooo0?ooo`160?ooo`D0o`00C03oool008H0oooo00<0
00000?ooo`3oool0A`3oool30?l004d0oooo00260?ooo`030000003oool0oooo09L0oooo00260?oo
o`030000003oool0oooo08/0oooo0P00000:0?ooo`00QP3oool00`000000oooo0?ooo`2;0?ooo`H0
00001P3oool00080ooooo`00000L000000<0oooo000>0?ooo`0300000000ool00?oo01/00?oo00<0
0000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<0
0000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<0
0000003oo`00ool06`00ool00`000000oooo0?ooo`0C0?ooo`L000001@3oool000h0oooo00<00000
003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000
003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000
003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`030000003oool0oooo01<0oooo0`000009
0?ooo`003P3oool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003o
o`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003o
o`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<000000?oo
o`3oool07`3oool000h0ooool@00000Q0?ooo`003P3oool00`0000000?oo003oo`0K003oo`030000
0000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`030000
0000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`030000
0000ool00?oo01/00?oo00<000000?ooo`3oool07`3oool000h0oooo00<00000003oo`00ool06`00
ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00
ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00
ool00`0000000?oo003oo`0K003oo`030000003oool0oooo01l0oooo000>0?ooo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool06`00ool00`000000oooo0?ooo`0O0?ooo`003P3oool00`00
00000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`00
00000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`00
00000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<000000?ooo`3oool03`3oool20000
00030?ooo`000000000000/0oooo000>0?oooo4000004P3oool00`000000oooo0000000<0?ooo`00
3P3oool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool0
6`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool0
6`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0;0?ooo`003P3oool00`0000000?oo003oo`0K003oo`0300000000
ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000
ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000
ool00?oo01/00?oo00<000000?ooo`3oool03`3oool2000000030?ooo`000000000000/0oooo000>
0?ooo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K
003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K
003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`000000oooo0?ooo`0O
0?ooo`003P3ooooa00000240oooo000>0?ooo`0300000000ool00?oo01/00?oo00<00000003oo`00
ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00
ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00
ool06`00ool00`000000oooo0?ooo`0O0?ooo`003P3oool00`0000000?oo003oo`0K003oo`030000
0000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`030000
0000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`030000
0000ool00?oo01/00?oo00<000000?ooo`3oool07`3oool000h0oooo00<00000003oo`00ool06`00
ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00
ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00
ool00`0000000?oo003oo`0K003oo`030000003oool0oooo01l0oooo000>0?ooo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool06`00ool00`000000oooo0?ooo`0O0?ooo`003P3ooooa0000
0240oooo000>0?ooo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`000000
0?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`000000
0?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`000000
oooo0?ooo`0O0?ooo`003P3oool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo
00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo
00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo
00<000000?ooo`3oool07`3oool000h0oooo00<00000003oo`00ool06`00ool00`0000000?oo003o
o`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003o
o`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003o
o`0K003oo`030000003oool0oooo01l0oooo000>0?oooo4000008@3oool000h0oooo00<00000003o
o`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003o
o`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003o
o`00ool06`00ool00`0000000?oo003oo`0K003oo`030000003oool0oooo01l0oooo000>0?ooo`03
00000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`03
00000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`03
00000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`000000oooo0?ooo`0O0?ooo`00
3P3oool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool0
6`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool0
6`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<000000?ooo`3oool0
7`3oool000h0ooool@00000Q0?ooo`003P3oool00`0000000?oo003oo`0K003oo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool0
0?oo01/00?oo00<000000?ooo`3oool07`3oool000h0oooo00<00000003oo`00ool06`00ool00`00
00000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`00
00000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`00
00000?oo003oo`0K003oo`030000003oool0oooo01l0oooo000>0?ooo`0300000000ool00?oo01/0
0?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/0
0?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/0
0?oo00<00000003oo`00ool06`00ool00`000000oooo0?ooo`0O0?ooo`003P3oool00`0000000?oo
003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo
003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo
003oo`0K003oo`0300000000ool00?oo01/00?oo00<000000?ooo`3oool07`3oool000h0ooool@00
000Q0?ooo`003P3oool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000
003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000
003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0200000180oooo000>0?ooo`0300000000ool00?oo
01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo
01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo
01/00?oo00<00000003oo`00ool06`00ool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000
000000004P3oool000h0oooo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`03
00000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`03
00000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`03
0000003oool0oooo00T0oooo00<000000?ooo`0000004`3oool000h0ooool@00000;0?ooo`030000
003oool0000001<0oooo000>0?ooo`030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`
oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`
oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`
oo000`000000oooo0?ooo`070?ooo`H000004P3oool000h0oooo00<000000?3ol03`oo006`3`oo00
0`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo00
0`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo00
0`000000l?o`0?3ol00K0?3ol0030000003oool0oooo01l0oooo000>0?ooo`030000003`oo00l?o`
01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`
01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`
01/0l?o`00<000000?3ol03`oo006`3`oo000`000000oooo0?ooo`0O0?ooo`003P3oool00`000000
l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000
l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000
l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?ooo`3oool07`3oool000h0oooo
l@00000Q0?ooo`003P3oool00`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<0
00000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<0
00000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<0
00000?ooo`3oool07`3oool000h0oooo00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K
0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K
0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K
0?3ol0030000003oool0oooo01l0oooo000>0?ooo`030000003`oo00l?o`01/0l?o`00<000000?3o
l03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3o
l03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3o
l03`oo006`3`oo000`000000oooo0?ooo`0O0?ooo`003P3ooooa00000240oooo000>0?ooo`030000
003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000
003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000
003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000oooo0?ooo`0O0?ooo`003P3o
ool00`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`
oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`
oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?ooo`3oool07`3o
ool000h0oooo00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00
l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00
l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003oool0
oooo01l0oooo000>0?oooo4000008@3oool000h0oooo00<000000?3ol03`oo006`3`oo000`000000
l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000
l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000
l?o`0?3ol00K0?3ol0030000003oool0oooo01l0oooo000>0?ooo`030000003`oo00l?o`01/0l?o`
00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`
00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`
00<000000?3ol03`oo006`3`oo000`000000oooo0?ooo`0O0?ooo`003P3oool00`000000l?o`0?3o
l00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3o
l00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3o
l00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?ooo`3oool07`3oool000h0oooo00<00000
0?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<00000
0?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<00000
0?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003oool0oooo01l0oooo000>0?oo
oo4000008@3oool000h0oooo00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol003
0000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol003
0000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol003
0000003oool0oooo01l0oooo000>0?ooo`030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo00
6`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo00
6`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo00
6`3`oo000`000000oooo0?ooo`0O0?ooo`003P3oool00`000000l?o`0?3ol00K0?3ol0030000003`
oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`
oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`
oo00l?o`01/0l?o`00<000000?ooo`3oool07`3oool000h0ooool@00000Q0?ooo`003P3oool00`00
0000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`00
0000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`00
0000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?ooo`3oool07`3oool000h0
oooo00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0
l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0
l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003oool0oooo01l0
oooo000>0?ooo`030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`
0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`
0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000oooo
0?ooo`0O0?ooo`003P3oool00`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<0
00000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<0
00000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<0
00000?ooo`3oool07`3oool000h0ooool@00000Q0?ooo`003P3oool00`000000l?o`0?3ol00K0?3o
l0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3o
l0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00;0?3o
l0<0o`003@3`oo000`000000l?o`0?3ol00K0?3ol0030000003oool0oooo01l0oooo000>0?ooo`03
0000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol003
0000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol003
0000003`oo00l?o`00X0l?o`1@3o000<0?3ol0030000003`oo00l?o`01/0l?o`00<000000?ooo`3o
ool07`3oool000h0oooo00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000
003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000
003`oo00l?o`01/0l?o`00<000000?3ol03`oo002P3`oo050?l000`0l?o`00<000000?3ol03`oo00
6`3`oo000`000000oooo0?ooo`0O0?ooo`003P3oooo1000000D0o`00:`00000Q0?ooo`003P3oool0
0`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo00
0`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo00
0`000000l?o`0?3ol00;0?3ol0<0o`003@3`oo000`000000l?o`0?3ol00K0?3ol0030000003oool0
oooo01l0oooo000>0?ooo`030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`00
0000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`00
0000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`00
0000oooo0?ooo`030?ooo`@000000P3oool00`000000oooo0?ooo`0200000140oooo000>0?ooo`03
0000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol003
0000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol003
0000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo0P0000000`3oool000000000000A0?ooo`003P3ooooa000000H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0000000B0?ooo`003P3oool00`0000000?oo003o
o`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003o
o`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003o
o`0K003oo`0300000000ool00?oo01/00?oo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool000000180oooo000>0?ooo`0300000000ool00?oo01/00?oo00<00000
003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000
003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000
003oo`00ool06`00ool00`000000oooo0?ooo`060?ooo`030000003oool0000000D000004@3oool0
00h0oooo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo
01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo
01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000603oool000h0oooo00<00000003oo`00ool06`00ool00`00
00000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`00
00000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`00
00000?oo003oo`0K003oo`030000003oool0oooo00@0oooo0P00000I0?ooo`003P3ooooa00000240
oooo000>0?ooo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo
003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo
003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`000000oooo
0?ooo`0O0?ooo`003P3oool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<0
0000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<0
0000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<0
00000?ooo`3oool07`3oool000h0oooo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K
003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K
003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K
003oo`030000003oool0oooo01l0oooo000>0?oooo4000008@3oool000h0oooo00<00000003oo`00
ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00
ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00
ool06`00ool00`0000000?oo003oo`0K003oo`030000003oool0oooo01l0oooo000>0?ooo`030000
0000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`030000
0000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`030000
0000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`000000oooo0?ooo`0O0?ooo`003P3o
ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00
ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00
ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<000000?ooo`3oool07`3o
ool000h0oooo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`030000003oool0
oooo01l0oooo000>0?oooo4000008@3oool000h0oooo00<00000003oo`00ool06`00ool00`000000
0?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`000000
0?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`000000
0?oo003oo`0K003oo`030000003oool0oooo01l0oooo000>0?ooo`0300000000ool00?oo01/00?oo
00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo
00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo
00<00000003oo`00ool06`00ool00`000000oooo0?ooo`0O0?ooo`003P3oool00`0000000?oo003o
o`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003o
o`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003o
o`0K003oo`0300000000ool00?oo01/00?oo00<000000?ooo`3oool07`3oool000h0ooool@00000Q
0?ooo`003P3oool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003o
o`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003o
o`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<000000?oo
o`3oool07`3oool000h0oooo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`03
00000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`03
00000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`03
0000003oool0oooo01l0oooo000>0?ooo`0300000000ool00?oo01/00?oo00<00000003oo`00ool0
6`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool0
6`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool0
6`00ool00`000000oooo0?ooo`0O0?ooo`003P3ooooa00000240oooo000>0?ooo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool06`00ool00`000000oooo0?ooo`0O0?ooo`003P3oool00`00
00000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`00
00000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`00
00000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<000000?ooo`3oool07`3oool000h0
oooo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/0
0?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/0
0?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`030000003oool0oooo01l0
oooo000>0?ooo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo
003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo
003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`000000oooo
0?ooo`0O0?ooo`003P3ooooa00000240oooo000>0?ooo`0300000000ool00?oo01/00?oo00<00000
003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000
003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000
003oo`00ool06`00ool00`000000oooo0?ooo`0O0?ooo`003P3oool00`0000000?oo003oo`0K003o
o`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003o
o`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003o
o`0300000000ool00?oo01/00?oo00<000000?ooo`3oool07`3oool000h0oooo00<00000003oo`00
ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00
ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00
ool06`00ool00`0000000?oo003oo`0K003oo`030000003oool0oooo01l0oooo000>0?oooo400000
8@3oool000h0oooo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000
ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`0300000000
ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003oo`030000003o
ool0oooo01l0oooo000>0?ooo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool0
0`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool0
0`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool0
0`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`0200000140oooo000>0?oo
o`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003o
o`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0K003o
o`0300000000ool00?oo01/00?oo00<00000003oo`00ool06`00ool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080000000<0oooo0000000000004@3oool000h0oooo00<00000003oo`00
ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00
ool06`00ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01/00?oo00<00000003oo`00
ool06`00ool00`0000000?oo003oo`0K003oo`030000003oool0oooo00H0oooo00L000000?ooo`3o
ool0oooo0000003oool000000180oooo000>0?oooo4000001P3oool2000000@0oooo00<000000?oo
o`0000004P3oool000h0oooo00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol003
0000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol003
0000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol003
0000003oool0oooo00H0oooo00<000000?ooo`0000001@00000A0?ooo`003P3oool00`000000l?o`
0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`
0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`
0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`00000H0?ooo`003P3oool00`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`
00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`
00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`
00<000000?ooo`3oool0103oool3000001P0oooo000>0?oooo4000008@3oool000h0oooo00<00000
0?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<00000
0?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<00000
0?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003oool0oooo01l0oooo000>0?oo
o`030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3o
l0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3o
l0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000oooo0?ooo`0O0?oo
o`003P3oool00`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`
oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`
oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?ooo`3o
ool07`3oool000h0ooool@00000Q0?ooo`003P3oool00`000000l?o`0?3ol00K0?3ol0030000003`
oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`
oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`
oo00l?o`01/0l?o`00<000000?ooo`3oool07`3oool000h0oooo00<000000?3ol03`oo006`3`oo00
0`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo00
0`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo00
0`000000l?o`0?3ol00K0?3ol0030000003oool0oooo01l0oooo000>0?ooo`030000003`oo00l?o`
01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`
01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`
01/0l?o`00<000000?3ol03`oo006`3`oo000`000000oooo0?ooo`0O0?ooo`003P3oool00`000000
l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000
l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000
l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?ooo`3oool07`3oool000h0oooo
l@00000Q0?ooo`003P3oool00`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<0
00000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<0
00000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<0
00000?ooo`3oool07`3oool000h0oooo00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K
0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K
0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K
0?3ol0030000003oool0oooo01l0oooo000>0?ooo`030000003`oo00l?o`01/0l?o`00<000000?3o
l03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3o
l03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3o
l03`oo006`3`oo000`000000oooo0?ooo`0O0?ooo`003P3ooooa00000240oooo000>0?ooo`030000
003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000
003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000
003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000oooo0?ooo`0O0?ooo`003P3o
ool00`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`
oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`
oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?ooo`3oool07`3o
ool000h0oooo00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00
l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00
l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003oool0
oooo01l0oooo000>0?ooo`030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`00
0000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`00
0000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`00
0000oooo0?ooo`0O0?ooo`003P3ooooa00000240oooo000>0?ooo`030000003`oo00l?o`01/0l?o`
00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`
00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`
00<000000?3ol03`oo006`3`oo000`000000oooo0?ooo`0O0?ooo`003P3oool00`000000l?o`0?3o
l00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3o
l00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3o
l00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?ooo`3oool07`3oool000h0oooo00<00000
0?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<00000
0?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<00000
0?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003oool0oooo01l0oooo000>0?oo
oo4000008@3oool000h0oooo00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol003
0000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol003
0000003`oo00l?o`01/0l?o`00<000000?3ol03`oo002`3`oo030?l000d0l?o`00<000000?3ol03`
oo006`3`oo000`000000oooo0?ooo`0O0?ooo`003P3oool00`000000l?o`0?3ol00K0?3ol0030000
003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000
003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00:0?3ol0D0o`00
303`oo000`000000l?o`0?3ol00K0?3ol0030000003oool0oooo01l0oooo000>0?ooo`030000003`
oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`
oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`
oo00l?o`00X0l?o`1@3o000<0?3ol0030000003`oo00l?o`01/0l?o`00<000000?ooo`3oool07`3o
ool000h0oooo`@0000050?l002/000008@3oool000h0oooo00<000000?3ol03`oo006`3`oo000`00
0000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`00
0000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo002`3`oo030?l0
00d0l?o`00<000000?3ol03`oo006`3`oo000`000000oooo0?ooo`0O0?ooo`003P3oool00`000000
l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000
l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000
l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?ooo`3oool01P3oool010000000
oooo0?ooo`0000020?ooo`8000004@3oool000h0oooo00<000000?3ol03`oo006`3`oo000`000000
l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000
l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000
l?o`0?3ol00K0?3ol0030000003oool0oooo00H0oooo00<000000?ooo`3oool00P0000000`3oool0
00000000000A0?ooo`003P3oool00`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`
00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`
00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00K0?3ol0030000003`oo00l?o`01/0l?o`
00<000000?ooo`3oool00`3oool500000080oooo00<000000?ooo`0000004P3oool000h0ooool@00
00050?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000004P3oool008H0oooo00<0
00000?ooo`3oool0O03oool010000000oooo0000003oool600000140oooo00260?ooo`030000003o
ool0oooo07d0oooo0P00000H0?ooo`00QP3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo01H0oooo00260?ooo`030000003oool0oooo09L0oooo00260?ooo`030000003oool0oooo09L0
oooo00260?ooo`030000003oool0oooo09L0oooo00260?ooo`030000003oool0oooo09L0oooo0026
0?ooo`030000003oool0oooo09L0oooo00260?ooo`030000003oool0oooo09L0oooo00260?ooo`03
0000003oool0oooo09L0oooo00260?ooo`030000003oool0oooo00L0oooo0P00002>0?ooo`00QP3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo08`0oooo00240?ooo`D000002@3oool0
0`000000oooo0?ooo`2;0?ooo`00Q03oool5000000P0oooo00<000000?ooo`000000S03oool008@0
oooo100000080?ooo`040000003oool0oooo000008`0oooo00250?ooo`<000001`3oool300000003
0?ooo`000000000008/0oooo00250?ooo`<00000V03oool008D0oooo0`00002H0?ooo`00Q@3oool2
000009T0oooo00260?ooo`030000003oool0oooo09L0oooo00260?ooo`030000003oool0oooo09L0
oooo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2, -1, 0, 0}}],
  StyleBox["     ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0.49904 0.0959693 0.49904 0.0959693 [
[.11516 .48654 -6.96875 -10.9375 ]
[.11516 .48654 6.96875 0 ]
[.3071 .48654 -6.96875 -10.9375 ]
[.3071 .48654 6.96875 0 ]
[.69098 .48654 -4.21875 -10.9375 ]
[.69098 .48654 4.21875 0 ]
[.88292 .48654 -4.21875 -10.9375 ]
[.88292 .48654 4.21875 0 ]
[.48654 .11516 -13.9375 -5.46875 ]
[.48654 .11516 0 5.46875 ]
[.48654 .3071 -13.9375 -5.46875 ]
[.48654 .3071 0 5.46875 ]
[.48654 .69098 -8.4375 -5.46875 ]
[.48654 .69098 0 5.46875 ]
[.48654 .88292 -8.4375 -5.46875 ]
[.48654 .88292 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11516 .49904 m
.11516 .50529 L
s
gsave
.11516 .48654 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.3071 .49904 m
.3071 .50529 L
s
gsave
.3071 .48654 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.69098 .49904 m
.69098 .50529 L
s
gsave
.69098 .48654 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.88292 .49904 m
.88292 .50529 L
s
gsave
.88292 .48654 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .49904 m
1 .49904 L
s
.49904 .11516 m
.50529 .11516 L
s
gsave
.48654 .11516 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.49904 .3071 m
.50529 .3071 L
s
gsave
.48654 .3071 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.49904 .69098 m
.50529 .69098 L
s
gsave
.48654 .69098 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.49904 .88292 m
.50529 .88292 L
s
gsave
.48654 .88292 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.49904 0 m
.49904 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
0 .49904 m
.0188 .49904 L
.10233 .49904 L
.1828 .49904 L
.26022 .49904 L
.34258 .49904 L
.42189 .49904 L
.49814 .49904 L
.57933 .49904 L
.65747 .49904 L
.74055 .49904 L
.82058 .49904 L
.89755 .49904 L
.97947 .49904 L
s
.97947 .49904 m
1 .49904 L
s
0 1 1 r
1 1 m
-0.00192 1 L
-0.00192 .49904 L
1 .49904 L
1 1 L
F
.941 1 .941 r
-0.00192 -0.00192 m
1 -0.00192 L
1 .49904 L
-0.00192 .49904 L
-0.00192 -0.00192 L
F
0 g
.51203 .49904 m
.51203 .49909 L
.51203 .49914 L
.51203 .49919 L
.51203 .49924 L
.51203 .49933 L
.51202 .49942 L
.51202 .49953 L
.51201 .49964 L
.512 .49985 L
.51199 .50005 L
.51197 .50025 L
.51192 .50069 L
.51186 .50114 L
.51178 .50155 L
.51157 .50246 L
.51133 .50324 L
.51102 .50407 L
.51024 .50562 L
.5093 .50701 L
.50811 .50834 L
.50681 .50945 L
.50542 .51035 L
.50468 .51074 L
.50384 .51111 L
.50301 .51141 L
.50223 .51163 L
.50141 .51181 L
.50096 .51189 L
.50053 .51194 L
.50012 .51198 L
.49991 .512 L
.49968 .51201 L
.49948 .51202 L
.49937 .51202 L
.49932 .51203 L
.49927 .51203 L
.49923 .51203 L
.49918 .51203 L
.49914 .51203 L
.49909 .51203 L
.49904 .51203 L
.49899 .51203 L
.49894 .51203 L
.49889 .51203 L
.49884 .51203 L
.49879 .51203 L
.49869 .51202 L
.49859 .51202 L
.49847 .51202 L
Mistroke
.49827 .51201 L
.49809 .51199 L
.49766 .51195 L
.49721 .5119 L
.49677 .51183 L
.4963 .51174 L
.49546 .51153 L
.49465 .51126 L
.49381 .51093 L
.49237 .51018 L
.49094 .50919 L
.48971 .50807 L
.48856 .50672 L
.48765 .50528 L
.48695 .50379 L
.48667 .50299 L
.48642 .50212 L
.48633 .50173 L
.48625 .5013 L
.48619 .50093 L
.48614 .50053 L
.4861 .50015 L
.48607 .4998 L
.48606 .49961 L
.48606 .49943 L
.48606 .49934 L
.48605 .49929 L
.48605 .49923 L
.48605 .49918 L
.48605 .49913 L
.48605 .49908 L
.48605 .49904 L
Mfstroke
.52045 .49904 m
.52045 .49912 L
.52045 .4992 L
.52045 .49929 L
.52045 .49937 L
.52045 .49952 L
.52044 .49967 L
.52044 .49985 L
.52043 .50004 L
.52041 .50037 L
.52039 .50071 L
.52036 .50103 L
.52028 .50176 L
.52017 .5025 L
.52005 .50318 L
.5197 .50468 L
.51931 .50596 L
.51879 .50733 L
.5175 .50989 L
.51595 .51218 L
.51399 .51437 L
.51184 .5162 L
.50956 .51769 L
.50834 .51833 L
.50695 .51894 L
.50558 .51943 L
.5043 .5198 L
.50296 .52009 L
.50221 .52022 L
.50149 .52031 L
.50082 .52038 L
.50047 .52041 L
.50009 .52043 L
.49977 .52044 L
.49959 .52045 L
.4995 .52045 L
.49942 .52045 L
.49935 .52045 L
.49928 .52045 L
.4992 .52045 L
.49912 .52045 L
.49904 .52045 L
.49895 .52045 L
.49887 .52045 L
.49879 .52045 L
.4987 .52045 L
.49862 .52045 L
.49846 .52045 L
.49829 .52044 L
.49811 .52043 L
Mistroke
.49778 .52042 L
.49747 .5204 L
.49677 .52033 L
.49602 .52024 L
.4953 .52012 L
.49453 .51997 L
.49315 .51963 L
.4918 .51919 L
.49042 .51864 L
.48804 .51741 L
.48569 .51578 L
.48365 .51393 L
.48177 .5117 L
.48026 .50932 L
.47911 .50687 L
.47864 .50555 L
.47824 .50412 L
.47809 .50347 L
.47795 .50277 L
.47786 .50216 L
.47777 .50149 L
.47771 .50088 L
.47766 .5003 L
.47765 .49998 L
.47764 .49969 L
.47763 .49953 L
.47763 .49945 L
.47763 .49936 L
.47763 .49928 L
.47763 .49919 L
.47763 .49911 L
.47763 .49904 L
Mfstroke
.53435 .49904 m
.53435 .49918 L
.53434 .4993 L
.53434 .49945 L
.53434 .49958 L
.53434 .49982 L
.53433 .50009 L
.53432 .50037 L
.53431 .50068 L
.53428 .50123 L
.53424 .5018 L
.53419 .50232 L
.53406 .50353 L
.53388 .50475 L
.53368 .50586 L
.5331 .50834 L
.53245 .51045 L
.53159 .5127 L
.52948 .51693 L
.52692 .5207 L
.52369 .52431 L
.52015 .52734 L
.51639 .52979 L
.51437 .53084 L
.51209 .53185 L
.50982 .53266 L
.50771 .53326 L
.50549 .53375 L
.50426 .53396 L
.50309 .53411 L
.50197 .53422 L
.5014 .53427 L
.50078 .5343 L
.50024 .53432 L
.49995 .53433 L
.4998 .53434 L
.49967 .53434 L
.49954 .53434 L
.49943 .53434 L
.4993 .53434 L
.49916 .53435 L
.49903 .53435 L
.49889 .53435 L
.49876 .53434 L
.49863 .53434 L
.49849 .53434 L
.49835 .53434 L
.49809 .53433 L
.49781 .53432 L
.4975 .53431 L
Mistroke
.49696 .53428 L
.49645 .53425 L
.49529 .53415 L
.49406 .53399 L
.49287 .5338 L
.4916 .53355 L
.48932 .53298 L
.48711 .53227 L
.48483 .53136 L
.4809 .52933 L
.47703 .52664 L
.47367 .52359 L
.47056 .51991 L
.46807 .51599 L
.46618 .51194 L
.46541 .50977 L
.46474 .50741 L
.4645 .50635 L
.46428 .50519 L
.46411 .50419 L
.46397 .50308 L
.46387 .50207 L
.4638 .50112 L
.46377 .50059 L
.46375 .50011 L
.46374 .49985 L
.46374 .49971 L
.46374 .49956 L
.46374 .49943 L
.46374 .49929 L
.46374 .49916 L
.46374 .49904 L
Mfstroke
.55725 .49904 m
.55725 .49927 L
.55725 .49947 L
.55724 .49971 L
.55724 .49993 L
.55723 .50033 L
.55722 .50076 L
.55721 .50124 L
.55719 .50174 L
.55714 .50265 L
.55707 .50358 L
.557 .50446 L
.55678 .50644 L
.55648 .50845 L
.55615 .51029 L
.55519 .51437 L
.55413 .51785 L
.55271 .52157 L
.54922 .52854 L
.545 .53476 L
.53969 .5407 L
.53384 .5457 L
.52765 .54974 L
.52432 .55147 L
.52055 .55313 L
.51682 .55447 L
.51334 .55546 L
.50968 .55627 L
.50765 .55661 L
.50571 .55687 L
.50387 .55705 L
.50293 .55712 L
.5019 .55718 L
.50103 .55721 L
.50053 .55723 L
.5003 .55724 L
.50008 .55724 L
.49987 .55724 L
.49968 .55725 L
.49947 .55725 L
.49925 .55725 L
.49903 .55725 L
.49879 .55725 L
.49857 .55725 L
.49837 .55724 L
.49813 .55724 L
.4979 .55724 L
.49747 .55723 L
.49701 .55721 L
.49651 .55719 L
Mistroke
.4956 .55715 L
.49477 .55709 L
.49286 .55692 L
.49083 .55667 L
.48887 .55635 L
.48677 .55594 L
.48302 .555 L
.47937 .55382 L
.47561 .55232 L
.46913 .54897 L
.46275 .54455 L
.45721 .53952 L
.45209 .53345 L
.44798 .52699 L
.44486 .52032 L
.44359 .51673 L
.44249 .51285 L
.44209 .51109 L
.44172 .50918 L
.44145 .50753 L
.44122 .50571 L
.44105 .50403 L
.44093 .50246 L
.44089 .5016 L
.44086 .50081 L
.44085 .50037 L
.44084 .50014 L
.44084 .4999 L
.44084 .49969 L
.44083 .49945 L
.44083 .49924 L
.44083 .49904 L
Mfstroke
.59501 .49904 m
.59501 .49941 L
.59501 .49975 L
.595 .50014 L
.595 .50051 L
.59499 .50117 L
.59497 .50188 L
.59494 .50267 L
.59491 .5035 L
.59482 .50499 L
.59472 .50653 L
.59459 .50797 L
.59423 .51124 L
.59375 .51456 L
.5932 .51758 L
.59162 .52431 L
.58986 .53005 L
.58753 .53618 L
.58177 .54768 L
.57482 .55792 L
.56606 .56773 L
.55642 .57597 L
.5462 .58262 L
.54072 .58549 L
.5345 .58822 L
.52835 .59043 L
.52262 .59207 L
.51659 .59339 L
.51323 .59395 L
.51004 .59438 L
.507 .59468 L
.50546 .59479 L
.50376 .59489 L
.50231 .59495 L
.5015 .59498 L
.50111 .59499 L
.50075 .59499 L
.50041 .595 L
.5001 .595 L
.49975 .59501 L
.49938 .59501 L
.49902 .59501 L
.49863 .59501 L
.49827 .59501 L
.49793 .595 L
.49753 .595 L
.49716 .59499 L
.49645 .59497 L
.49569 .59495 L
.49486 .59492 L
Mistroke
.49337 .59484 L
.492 .59475 L
.48884 .59447 L
.4855 .59405 L
.48228 .59353 L
.47882 .59285 L
.47262 .5913 L
.4666 .58936 L
.46041 .58689 L
.44972 .58137 L
.4392 .57407 L
.43008 .56578 L
.42163 .55577 L
.41486 .54512 L
.40971 .53412 L
.40761 .52821 L
.40581 .5218 L
.40515 .51891 L
.40454 .51576 L
.4041 .51303 L
.4037 .51003 L
.40342 .50726 L
.40324 .50468 L
.40316 .50325 L
.40312 .50195 L
.4031 .50123 L
.40309 .50086 L
.40308 .50045 L
.40308 .5001 L
.40307 .49972 L
.40307 .49937 L
.40307 .49904 L
Mfstroke
.65727 .49904 m
.65727 .49965 L
.65726 .50021 L
.65726 .50086 L
.65725 .50147 L
.65723 .50255 L
.6572 .50372 L
.65715 .50502 L
.6571 .50639 L
.65696 .50885 L
.65678 .51139 L
.65658 .51376 L
.65598 .51915 L
.65518 .52463 L
.65429 .52961 L
.65168 .5407 L
.64878 .55017 L
.64494 .56028 L
.63544 .57923 L
.62398 .59612 L
.60953 .6123 L
.59365 .62587 L
.5768 .63684 L
.56776 .64157 L
.5575 .64607 L
.54736 .64971 L
.53791 .65242 L
.52797 .6546 L
.52244 .65553 L
.51718 .65622 L
.51216 .65672 L
.50962 .65691 L
.50682 .65708 L
.50444 .65717 L
.50309 .65721 L
.50246 .65723 L
.50186 .65724 L
.5013 .65725 L
.50078 .65726 L
.50021 .65726 L
.4996 .65727 L
.49901 .65727 L
.49837 .65727 L
.49777 .65726 L
.49721 .65726 L
.49656 .65725 L
.49594 .65724 L
.49477 .65721 L
.49352 .65717 L
.49215 .65712 L
Mistroke
.4897 .65699 L
.48743 .65684 L
.48223 .65637 L
.47672 .65568 L
.4714 .65483 L
.4657 .65371 L
.45548 .65115 L
.44556 .64795 L
.43534 .64388 L
.41773 .63477 L
.40038 .62274 L
.38534 .60908 L
.37141 .59257 L
.36024 .57501 L
.35176 .55687 L
.3483 .54713 L
.34533 .53657 L
.34424 .53179 L
.34323 .52661 L
.3425 .52211 L
.34186 .51716 L
.3414 .5126 L
.34109 .50834 L
.34097 .50599 L
.34089 .50384 L
.34086 .50266 L
.34084 .50203 L
.34083 .50137 L
.34082 .50079 L
.34082 .50016 L
.34081 .49958 L
.34081 .49904 L
Mfstroke
.75991 .49904 m
.75991 .50005 L
.7599 .50097 L
.75989 .50203 L
.75988 .50304 L
.75985 .50483 L
.7598 .50676 L
.75973 .5089 L
.75963 .51116 L
.75941 .51521 L
.75912 .5194 L
.75878 .52331 L
.7578 .5322 L
.75648 .54122 L
.755 .54944 L
.75071 .56773 L
.74592 .58334 L
.73958 .60001 L
.72392 .63126 L
.70504 .6591 L
.68121 .68577 L
.65502 .70815 L
.62724 .72624 L
.61233 .73403 L
.59543 .74145 L
.5787 .74745 L
.56313 .75192 L
.54673 .75552 L
.53762 .75704 L
.52894 .75819 L
.52067 .75901 L
.51649 .75933 L
.51187 .7596 L
.50794 .75976 L
.50573 .75983 L
.50467 .75985 L
.5037 .75987 L
.50276 .75989 L
.50191 .7599 L
.50097 .7599 L
.49996 .75991 L
.49899 .75991 L
.49793 .75991 L
.49694 .7599 L
.49602 .75989 L
.49494 .75988 L
.49392 .75986 L
.492 .75982 L
.48994 .75975 L
.48768 .75966 L
Mistroke
.48364 .75946 L
.47989 .75921 L
.47133 .75844 L
.46224 .7573 L
.45348 .7559 L
.44407 .75405 L
.42723 .74983 L
.41087 .74456 L
.39402 .73784 L
.36497 .72283 L
.33638 .70299 L
.31158 .68046 L
.28862 .65324 L
.2702 .62429 L
.25622 .59439 L
.25051 .57833 L
.24561 .56092 L
.24382 .55304 L
.24216 .54449 L
.24096 .53707 L
.23989 .52892 L
.23913 .52139 L
.23862 .51438 L
.23842 .51049 L
.23829 .50696 L
.23824 .505 L
.23822 .50397 L
.2382 .50288 L
.23818 .50193 L
.23818 .50088 L
.23817 .49993 L
.23817 .49904 L
Mfstroke
.92914 .49904 m
.92914 .50071 L
.92913 .50223 L
.92912 .50398 L
.92909 .50563 L
.92904 .50858 L
.92896 .51177 L
.92884 .51529 L
.92868 .51902 L
.92832 .52571 L
.92783 .5326 L
.92728 .53905 L
.92566 .55371 L
.92348 .56859 L
.92104 .58213 L
.91397 .61228 L
.90607 .63803 L
.89562 .66551 L
.86981 .71703 L
.83867 .76294 L
.79939 .8069 L
.7562 .8438 L
.7104 .87363 L
.68583 .88647 L
.65796 .89871 L
.63038 .9086 L
.6047 .91596 L
.57767 .9219 L
.56265 .92442 L
.54834 .92631 L
.53471 .92766 L
.52781 .92818 L
.52019 .92862 L
.51371 .92889 L
.51006 .929 L
.50833 .92904 L
.50672 .92908 L
.50518 .9291 L
.50377 .92912 L
.50222 .92913 L
.50055 .92914 L
.49895 .92914 L
.49722 .92914 L
.49558 .92913 L
.49406 .92912 L
.49229 .92909 L
.4906 .92906 L
.48743 .92899 L
.48403 .92888 L
.48032 .92874 L
Mistroke
.47365 .92839 L
.46747 .92798 L
.45335 .92671 L
.43836 .92484 L
.42392 .92253 L
.40841 .91949 L
.38064 .91253 L
.35367 .90383 L
.3259 .89275 L
.278 .868 L
.23085 .83529 L
.18997 .79815 L
.15211 .75327 L
.12175 .70554 L
.0987 .65625 L
.08928 .62977 L
.08121 .60106 L
.07825 .58807 L
.07551 .57398 L
.07353 .56174 L
.07177 .5483 L
.07052 .53589 L
.06968 .52433 L
.06935 .51792 L
.06913 .5121 L
.06905 .50887 L
.06901 .50717 L
.06898 .50538 L
.06896 .50381 L
.06895 .50208 L
.06894 .50051 L
.06894 .49904 L
Mfstroke
.51203 .49904 m
.51432 .49904 L
.51727 .49904 L
.52057 .49904 L
.5243 .49904 L
.52899 .49904 L
.53432 .49904 L
.54102 .49904 L
.54869 .49904 L
.55738 .49904 L
.56831 .49904 L
.58076 .49904 L
.59483 .49904 L
.61249 .49904 L
.63255 .49904 L
.65779 .49904 L
.6866 .49904 L
.71924 .49904 L
.76023 .49904 L
.80688 .49904 L
.86562 .49904 L
.93281 .49904 L
s
.93281 .49904 m
1 .49904 L
s
.51104 .50401 m
.51315 .50489 L
.51589 .50602 L
.51893 .50728 L
.52238 .50871 L
.52671 .5105 L
.53163 .51254 L
.53783 .51511 L
.54491 .51804 L
.55294 .52137 L
.56303 .52555 L
.57454 .53031 L
.58754 .5357 L
.60385 .54246 L
.62239 .55013 L
.64571 .55979 L
.67233 .57082 L
.70248 .58331 L
.74035 .59899 L
.78345 .61685 L
.83772 .63933 L
.89979 .66504 L
.97022 .69421 L
s
.97022 .69421 m
1 .70654 L
s
.50822 .50822 m
.50984 .50984 L
.51193 .51193 L
.51426 .51426 L
.5169 .5169 L
.52022 .52022 L
.52398 .52398 L
.52873 .52873 L
.53415 .53415 L
.54029 .54029 L
.54802 .54802 L
.55682 .55682 L
.56677 .56677 L
.57926 .57926 L
.59345 .59345 L
.61129 .61129 L
.63167 .63167 L
.65474 .65474 L
.68373 .68373 L
.71672 .71672 L
.75825 .75825 L
.80576 .80576 L
.85967 .85967 L
.92744 .92744 L
s
.92744 .92744 m
1 1 L
s
.50401 .51104 m
.50489 .51315 L
.50602 .51589 L
.50728 .51893 L
.50871 .52238 L
.5105 .52671 L
.51254 .53163 L
.51511 .53783 L
.51804 .54491 L
.52137 .55294 L
.52555 .56303 L
.53031 .57454 L
.5357 .58754 L
.54246 .60385 L
.55013 .62239 L
.55979 .64571 L
.57082 .67233 L
.58331 .70248 L
.59899 .74035 L
.61685 .78345 L
.63933 .83772 L
.66504 .89979 L
.69421 .97022 L
s
.69421 .97022 m
.70654 1 L
s
.49904 .51203 m
.49904 .51432 L
.49904 .51727 L
.49904 .52057 L
.49904 .5243 L
.49904 .52899 L
.49904 .53432 L
.49904 .54102 L
.49904 .54869 L
.49904 .55738 L
.49904 .56831 L
.49904 .58076 L
.49904 .59483 L
.49904 .61249 L
.49904 .63255 L
.49904 .65779 L
.49904 .6866 L
.49904 .71924 L
.49904 .76023 L
.49904 .80688 L
.49904 .86562 L
.49904 .93281 L
s
.49904 .93281 m
.49904 1 L
s
.49407 .51104 m
.49319 .51315 L
.49206 .51589 L
.4908 .51893 L
.48937 .52238 L
.48758 .52671 L
.48554 .53163 L
.48297 .53783 L
.48004 .54491 L
.47671 .55294 L
.47253 .56303 L
.46777 .57454 L
.46238 .58754 L
.45563 .60385 L
.44795 .62239 L
.43829 .64571 L
.42726 .67233 L
.41477 .70248 L
.39909 .74035 L
.38124 .78345 L
.35876 .83772 L
.33305 .89979 L
.30387 .97022 L
s
.30387 .97022 m
.29154 1 L
s
.48986 .50822 m
.48824 .50984 L
.48615 .51193 L
.48382 .51426 L
.48118 .5169 L
.47786 .52022 L
.4741 .52398 L
.46935 .52873 L
.46393 .53415 L
.45779 .54029 L
.45006 .54802 L
.44126 .55682 L
.43131 .56677 L
.41882 .57926 L
.40463 .59345 L
.38679 .61129 L
.36641 .63167 L
.34334 .65474 L
.31435 .68373 L
.28136 .71672 L
.23983 .75825 L
.19232 .80576 L
.13841 .85967 L
.07064 .92744 L
s
.07064 .92744 m
0 .99808 L
s
.48704 .50401 m
.48493 .50489 L
.48219 .50602 L
.47915 .50728 L
.4757 .50871 L
.47137 .5105 L
.46645 .51254 L
.46025 .51511 L
.45317 .51804 L
.44514 .52137 L
.43505 .52555 L
.42355 .53031 L
.41054 .5357 L
.39423 .54246 L
.37569 .55013 L
.35237 .55979 L
.32575 .57082 L
.2956 .58331 L
.25774 .59899 L
.21463 .61685 L
.16036 .63933 L
.09829 .66504 L
.02786 .69421 L
s
.02786 .69421 m
0 .70575 L
s
.48605 .49904 m
.48376 .49904 L
.48081 .49904 L
.47751 .49904 L
.47378 .49904 L
.46909 .49904 L
.46376 .49904 L
.45706 .49904 L
.44939 .49904 L
.4407 .49904 L
.42977 .49904 L
.41733 .49904 L
.40325 .49904 L
.38559 .49904 L
.36553 .49904 L
.34029 .49904 L
.31148 .49904 L
.27884 .49904 L
.23785 .49904 L
.1912 .49904 L
.13246 .49904 L
.06528 .49904 L
s
.06528 .49904 m
0 .49904 L
s
.48605 .49904 m
.48605 .49899 L
.48605 .49894 L
.48605 .49889 L
.48605 .49884 L
.48606 .49875 L
.48606 .49866 L
.48606 .49855 L
.48607 .49844 L
.48608 .49824 L
.48609 .49803 L
.48611 .49783 L
.48616 .49739 L
.48622 .49694 L
.4863 .49653 L
.48651 .49562 L
.48675 .49484 L
.48706 .49401 L
.48784 .49246 L
.48878 .49107 L
.48997 .48974 L
.49127 .48863 L
.49266 .48773 L
.4934 .48734 L
.49424 .48697 L
.49507 .48667 L
.49585 .48645 L
.49667 .48627 L
.49712 .4862 L
.49755 .48614 L
.49796 .4861 L
.49817 .48608 L
.4984 .48607 L
.4986 .48606 L
.49871 .48606 L
.49876 .48606 L
.49881 .48605 L
.49886 .48605 L
.4989 .48605 L
.49894 .48605 L
.49899 .48605 L
.49904 .48605 L
.4991 .48605 L
.49914 .48605 L
.49919 .48605 L
.49924 .48605 L
.4993 .48605 L
.49939 .48606 L
.49949 .48606 L
.49961 .48606 L
Mistroke
.49981 .48607 L
.49999 .48609 L
.50042 .48613 L
.50087 .48618 L
.50131 .48625 L
.50178 .48634 L
.50262 .48655 L
.50343 .48682 L
.50427 .48715 L
.50572 .4879 L
.50714 .48889 L
.50837 .49001 L
.50952 .49136 L
.51043 .4928 L
.51113 .49429 L
.51141 .49509 L
.51166 .49596 L
.51175 .49635 L
.51183 .49678 L
.51189 .49715 L
.51194 .49755 L
.51198 .49793 L
.51201 .49828 L
.51202 .49847 L
.51202 .49865 L
.51202 .49874 L
.51203 .49879 L
.51203 .49885 L
.51203 .4989 L
.51203 .49895 L
.51203 .499 L
.51203 .49904 L
Mfstroke
.47763 .49904 m
.47763 .49896 L
.47763 .49888 L
.47763 .49879 L
.47763 .49871 L
.47763 .49857 L
.47764 .49841 L
.47764 .49823 L
.47765 .49805 L
.47767 .49771 L
.47769 .49737 L
.47772 .49705 L
.4778 .49632 L
.47791 .49558 L
.47803 .4949 L
.47838 .4934 L
.47878 .49212 L
.4793 .49075 L
.48058 .48819 L
.48213 .4859 L
.48409 .48371 L
.48624 .48188 L
.48852 .48039 L
.48974 .47975 L
.49113 .47914 L
.4925 .47865 L
.49378 .47828 L
.49513 .47799 L
.49587 .47786 L
.49659 .47777 L
.49726 .4777 L
.49761 .47767 L
.49799 .47765 L
.49831 .47764 L
.49849 .47763 L
.49858 .47763 L
.49866 .47763 L
.49873 .47763 L
.4988 .47763 L
.49888 .47763 L
.49896 .47763 L
.49904 .47763 L
.49913 .47763 L
.49921 .47763 L
.49929 .47763 L
.49938 .47763 L
.49946 .47763 L
.49962 .47763 L
.49979 .47764 L
.49997 .47765 L
Mistroke
.5003 .47766 L
.50061 .47768 L
.50132 .47775 L
.50206 .47784 L
.50278 .47796 L
.50355 .47811 L
.50494 .47845 L
.50628 .47889 L
.50766 .47944 L
.51005 .48067 L
.51239 .4823 L
.51443 .48415 L
.51631 .48638 L
.51782 .48876 L
.51897 .49121 L
.51944 .49253 L
.51984 .49396 L
.51999 .49461 L
.52013 .49531 L
.52023 .49592 L
.52031 .49659 L
.52038 .49721 L
.52042 .49778 L
.52043 .4981 L
.52044 .49839 L
.52045 .49855 L
.52045 .49864 L
.52045 .49872 L
.52045 .4988 L
.52045 .49889 L
.52045 .49897 L
.52045 .49904 L
Mfstroke
.46374 .49904 m
.46374 .4989 L
.46374 .49878 L
.46374 .49864 L
.46374 .4985 L
.46374 .49826 L
.46375 .498 L
.46376 .49771 L
.46377 .4974 L
.4638 .49685 L
.46384 .49629 L
.46389 .49576 L
.46402 .49455 L
.4642 .49333 L
.4644 .49222 L
.46498 .48974 L
.46563 .48763 L
.46649 .48538 L
.46861 .48115 L
.47116 .47738 L
.47439 .47377 L
.47793 .47074 L
.48169 .46829 L
.48371 .46724 L
.486 .46623 L
.48826 .46542 L
.49037 .46482 L
.49259 .46433 L
.49382 .46412 L
.49499 .46397 L
.49611 .46386 L
.49668 .46381 L
.4973 .46378 L
.49784 .46376 L
.49814 .46375 L
.49828 .46374 L
.49841 .46374 L
.49854 .46374 L
.49865 .46374 L
.49878 .46374 L
.49892 .46374 L
.49905 .46374 L
.49919 .46374 L
.49932 .46374 L
.49945 .46374 L
.49959 .46374 L
.49973 .46374 L
.49999 .46375 L
.50027 .46376 L
.50058 .46377 L
Mistroke
.50112 .4638 L
.50163 .46383 L
.50279 .46393 L
.50402 .46409 L
.50521 .46428 L
.50648 .46453 L
.50876 .4651 L
.51097 .46581 L
.51325 .46672 L
.51718 .46875 L
.52105 .47144 L
.52441 .47449 L
.52752 .47817 L
.53001 .48209 L
.5319 .48614 L
.53268 .48831 L
.53334 .49067 L
.53358 .49173 L
.53381 .49289 L
.53397 .49389 L
.53411 .495 L
.53422 .49602 L
.53428 .49696 L
.53431 .49749 L
.53433 .49797 L
.53434 .49823 L
.53434 .49837 L
.53434 .49852 L
.53434 .49865 L
.53434 .49879 L
.53435 .49892 L
.53435 .49904 L
Mfstroke
.44083 .49904 m
.44083 .49881 L
.44083 .49861 L
.44084 .49837 L
.44084 .49815 L
.44085 .49775 L
.44086 .49732 L
.44087 .49684 L
.44089 .49634 L
.44094 .49543 L
.44101 .4945 L
.44108 .49363 L
.4413 .49164 L
.4416 .48963 L
.44193 .4878 L
.44289 .48371 L
.44396 .48023 L
.44537 .47651 L
.44886 .46954 L
.45308 .46333 L
.45839 .45738 L
.46424 .45238 L
.47044 .44835 L
.47376 .44661 L
.47753 .44495 L
.48126 .44361 L
.48474 .44262 L
.4884 .44181 L
.49043 .44147 L
.49237 .44122 L
.49421 .44103 L
.49515 .44096 L
.49618 .4409 L
.49706 .44087 L
.49755 .44085 L
.49778 .44085 L
.498 .44084 L
.49821 .44084 L
.4984 .44084 L
.49861 .44083 L
.49884 .44083 L
.49905 .44083 L
.49929 .44083 L
.49951 .44083 L
.49971 .44084 L
.49995 .44084 L
.50018 .44084 L
.50061 .44085 L
.50107 .44087 L
.50157 .44089 L
Mistroke
.50248 .44093 L
.50331 .44099 L
.50522 .44116 L
.50725 .44141 L
.50921 .44173 L
.51131 .44214 L
.51506 .44308 L
.51871 .44426 L
.52247 .44576 L
.52895 .44911 L
.53534 .45353 L
.54087 .45856 L
.54599 .46463 L
.5501 .47109 L
.55322 .47776 L
.55449 .48135 L
.55559 .48523 L
.55599 .48699 L
.55636 .4889 L
.55663 .49056 L
.55687 .49237 L
.55703 .49405 L
.55715 .49562 L
.55719 .49649 L
.55722 .49727 L
.55723 .49771 L
.55724 .49794 L
.55724 .49818 L
.55725 .4984 L
.55725 .49863 L
.55725 .49884 L
.55725 .49904 L
Mfstroke
.40307 .49904 m
.40307 .49867 L
.40307 .49833 L
.40308 .49794 L
.40308 .49757 L
.40309 .49691 L
.40311 .4962 L
.40314 .49541 L
.40317 .49458 L
.40326 .49309 L
.40336 .49155 L
.40349 .49011 L
.40385 .48684 L
.40433 .48352 L
.40488 .4805 L
.40646 .47377 L
.40822 .46803 L
.41055 .4619 L
.41631 .4504 L
.42326 .44016 L
.43202 .43035 L
.44166 .42211 L
.45188 .41546 L
.45736 .41259 L
.46358 .40986 L
.46973 .40766 L
.47546 .40601 L
.48149 .40469 L
.48485 .40413 L
.48804 .4037 L
.49108 .4034 L
.49262 .40329 L
.49432 .40319 L
.49577 .40313 L
.49658 .4031 L
.49697 .40309 L
.49733 .40309 L
.49767 .40308 L
.49798 .40308 L
.49833 .40307 L
.4987 .40307 L
.49906 .40307 L
.49945 .40307 L
.49981 .40307 L
.50015 .40308 L
.50055 .40308 L
.50092 .40309 L
.50163 .40311 L
.50239 .40313 L
.50322 .40316 L
Mistroke
.50471 .40324 L
.50608 .40333 L
.50924 .40361 L
.51258 .40403 L
.5158 .40455 L
.51926 .40523 L
.52546 .40678 L
.53148 .40872 L
.53767 .41119 L
.54836 .41671 L
.55888 .42401 L
.568 .4323 L
.57645 .44231 L
.58322 .45296 L
.58837 .46396 L
.59047 .46987 L
.59227 .47628 L
.59293 .47918 L
.59354 .48232 L
.59398 .48505 L
.59438 .48805 L
.59466 .49082 L
.59484 .4934 L
.59492 .49483 L
.59497 .49613 L
.59498 .49685 L
.59499 .49723 L
.595 .49763 L
.595 .49798 L
.59501 .49836 L
.59501 .49871 L
.59501 .49904 L
Mfstroke
.34081 .49904 m
.34081 .49843 L
.34082 .49787 L
.34082 .49722 L
.34083 .49661 L
.34085 .49553 L
.34088 .49436 L
.34093 .49306 L
.34098 .49169 L
.34112 .48923 L
.3413 .48669 L
.3415 .48432 L
.3421 .47893 L
.3429 .47346 L
.34379 .46847 L
.3464 .45738 L
.3493 .44791 L
.35315 .4378 L
.36264 .41885 L
.3741 .40196 L
.38855 .38579 L
.40443 .37221 L
.42128 .36124 L
.43032 .35651 L
.44058 .35201 L
.45072 .34837 L
.46017 .34566 L
.47011 .34348 L
.47564 .34255 L
.48091 .34186 L
.48592 .34136 L
.48846 .34117 L
.49126 .34101 L
.49364 .34091 L
.49499 .34087 L
.49562 .34085 L
.49622 .34084 L
.49678 .34083 L
.4973 .34082 L
.49787 .34082 L
.49848 .34081 L
.49907 .34081 L
.49971 .34082 L
.50031 .34082 L
.50087 .34082 L
.50152 .34083 L
.50215 .34084 L
.50331 .34087 L
.50456 .34091 L
.50593 .34096 L
Mistroke
.50838 .34109 L
.51065 .34124 L
.51585 .34171 L
.52136 .3424 L
.52668 .34325 L
.53238 .34437 L
.5426 .34693 L
.55252 .35013 L
.56274 .3542 L
.58036 .36331 L
.5977 .37534 L
.61274 .38901 L
.62667 .40551 L
.63784 .42307 L
.64632 .44121 L
.64978 .45095 L
.65275 .46151 L
.65384 .46629 L
.65485 .47147 L
.65558 .47598 L
.65623 .48092 L
.65669 .48548 L
.65699 .48974 L
.65711 .49209 L
.65719 .49424 L
.65723 .49542 L
.65724 .49605 L
.65725 .49671 L
.65726 .49729 L
.65726 .49792 L
.65727 .4985 L
.65727 .49904 L
Mfstroke
.23817 .49904 m
.23817 .49803 L
.23818 .49711 L
.23819 .49605 L
.2382 .49504 L
.23823 .49326 L
.23828 .49132 L
.23836 .48918 L
.23845 .48692 L
.23867 .48287 L
.23896 .47868 L
.2393 .47477 L
.24028 .46588 L
.2416 .45686 L
.24308 .44864 L
.24737 .43035 L
.25217 .41474 L
.2585 .39807 L
.27416 .36682 L
.29305 .33898 L
.31687 .31231 L
.34306 .28994 L
.37084 .27184 L
.38575 .26405 L
.40265 .25663 L
.41938 .25063 L
.43495 .24616 L
.45135 .24257 L
.46046 .24104 L
.46914 .23989 L
.47741 .23907 L
.48159 .23875 L
.48621 .23848 L
.49014 .23832 L
.49236 .23825 L
.49341 .23823 L
.49438 .23821 L
.49532 .2382 L
.49617 .23818 L
.49711 .23818 L
.49812 .23817 L
.49909 .23817 L
.50015 .23817 L
.50114 .23818 L
.50206 .23819 L
.50314 .2382 L
.50416 .23822 L
.50608 .23826 L
.50815 .23833 L
.5104 .23842 L
Mistroke
.51444 .23862 L
.51819 .23887 L
.52676 .23965 L
.53584 .24078 L
.5446 .24218 L
.55401 .24403 L
.57085 .24825 L
.58721 .25352 L
.60406 .26024 L
.63311 .27525 L
.6617 .29509 L
.6865 .31762 L
.70946 .34484 L
.72788 .37379 L
.74186 .40369 L
.74757 .41975 L
.75247 .43716 L
.75426 .44504 L
.75592 .45359 L
.75713 .46101 L
.7582 .46916 L
.75895 .47669 L
.75946 .4837 L
.75966 .48759 L
.75979 .49112 L
.75984 .49308 L
.75987 .49411 L
.75988 .4952 L
.7599 .49615 L
.75991 .4972 L
.75991 .49815 L
.75991 .49904 L
Mfstroke
.06894 .49904 m
.06894 .49737 L
.06895 .49585 L
.06896 .4941 L
.06899 .49245 L
.06904 .4895 L
.06912 .48631 L
.06924 .48279 L
.0694 .47906 L
.06976 .47237 L
.07025 .46548 L
.0708 .45903 L
.07242 .44437 L
.0746 .42949 L
.07704 .41595 L
.08411 .3858 L
.09201 .36005 L
.10246 .33257 L
.12827 .28105 L
.15941 .23514 L
.19869 .19118 L
.24188 .15428 L
.28768 .12445 L
.31225 .11161 L
.34012 .09937 L
.3677 .08948 L
.39338 .08212 L
.42041 .07618 L
.43543 .07366 L
.44974 .07177 L
.46337 .07042 L
.47027 .0699 L
.47789 .06946 L
.48437 .06919 L
.48802 .06908 L
.48975 .06904 L
.49136 .069 L
.4929 .06898 L
.49431 .06896 L
.49586 .06895 L
.49753 .06894 L
.49913 .06894 L
.50086 .06894 L
.5025 .06895 L
.50402 .06896 L
.50579 .06899 L
.50748 .06902 L
.51065 .06909 L
.51405 .0692 L
.51776 .06934 L
Mistroke
.52443 .06969 L
.53061 .0701 L
.54473 .07137 L
.55972 .07324 L
.57416 .07555 L
.58967 .07859 L
.61744 .08555 L
.64441 .09425 L
.67218 .10533 L
.72008 .13008 L
.76723 .16279 L
.80811 .19993 L
.84597 .24481 L
.87633 .29254 L
.89938 .34183 L
.9088 .36831 L
.91687 .39702 L
.91983 .41001 L
.92257 .4241 L
.92455 .43634 L
.92631 .44978 L
.92756 .46219 L
.9284 .47375 L
.92873 .48016 L
.92895 .48598 L
.92903 .48921 L
.92907 .49091 L
.9291 .4927 L
.92912 .49427 L
.92913 .496 L
.92914 .49757 L
.92914 .49904 L
Mfstroke
.48605 .49904 m
.48376 .49904 L
.48081 .49904 L
.47751 .49904 L
.47378 .49904 L
.46909 .49904 L
.46376 .49904 L
.45706 .49904 L
.44939 .49904 L
.4407 .49904 L
.42977 .49904 L
.41733 .49904 L
.40325 .49904 L
.38559 .49904 L
.36553 .49904 L
.34029 .49904 L
.31148 .49904 L
.27884 .49904 L
.23785 .49904 L
.1912 .49904 L
.13246 .49904 L
.06528 .49904 L
s
.06528 .49904 m
0 .49904 L
s
.48704 .49407 m
.48493 .49319 L
.48219 .49206 L
.47915 .4908 L
.4757 .48937 L
.47137 .48758 L
.46645 .48554 L
.46025 .48297 L
.45317 .48004 L
.44514 .47671 L
.43505 .47253 L
.42355 .46777 L
.41054 .46238 L
.39423 .45563 L
.37569 .44795 L
.35237 .43829 L
.32575 .42726 L
.2956 .41477 L
.25774 .39909 L
.21463 .38124 L
.16036 .35876 L
.09829 .33305 L
.02786 .30387 L
s
.02786 .30387 m
0 .29233 L
s
.48986 .48986 m
.48824 .48824 L
.48615 .48615 L
.48382 .48382 L
.48118 .48118 L
.47786 .47786 L
.4741 .4741 L
.46935 .46935 L
.46393 .46393 L
.45779 .45779 L
.45006 .45006 L
.44126 .44126 L
.43131 .43131 L
.41882 .41882 L
.40463 .40463 L
.38679 .38679 L
.36641 .36641 L
.34334 .34334 L
.31435 .31435 L
.28136 .28136 L
.23983 .23983 L
.19232 .19232 L
.13841 .13841 L
.07064 .07064 L
s
.07064 .07064 m
0 0 L
s
.49407 .48704 m
.49319 .48493 L
.49206 .48219 L
.4908 .47915 L
.48937 .4757 L
.48758 .47137 L
.48554 .46645 L
.48297 .46025 L
.48004 .45317 L
.47671 .44514 L
.47253 .43505 L
.46777 .42355 L
.46238 .41054 L
.45563 .39423 L
.44795 .37569 L
.43829 .35237 L
.42726 .32575 L
.41477 .2956 L
.39909 .25774 L
.38124 .21463 L
.35876 .16036 L
.33305 .09829 L
.30387 .02786 L
s
.30387 .02786 m
.29233 0 L
s
.49904 .48605 m
.49904 .48376 L
.49904 .48081 L
.49904 .47751 L
.49904 .47378 L
.49904 .46909 L
.49904 .46376 L
.49904 .45706 L
.49904 .44939 L
.49904 .4407 L
.49904 .42977 L
.49904 .41733 L
.49904 .40325 L
.49904 .38559 L
.49904 .36553 L
.49904 .34029 L
.49904 .31148 L
.49904 .27884 L
.49904 .23785 L
.49904 .1912 L
.49904 .13246 L
.49904 .06528 L
s
.49904 .06528 m
.49904 0 L
s
.50401 .48704 m
.50489 .48493 L
.50602 .48219 L
.50728 .47915 L
.50871 .4757 L
.5105 .47137 L
.51254 .46645 L
.51511 .46025 L
.51804 .45317 L
.52137 .44514 L
.52555 .43505 L
.53031 .42355 L
.5357 .41054 L
.54246 .39423 L
.55013 .37569 L
.55979 .35237 L
.57082 .32575 L
.58331 .2956 L
.59899 .25774 L
.61685 .21463 L
.63933 .16036 L
.66504 .09829 L
.69421 .02786 L
s
.69421 .02786 m
.70575 0 L
s
.50822 .48986 m
.50984 .48824 L
.51193 .48615 L
.51426 .48382 L
.5169 .48118 L
.52022 .47786 L
.52398 .4741 L
.52873 .46935 L
.53415 .46393 L
.54029 .45779 L
.54802 .45006 L
.55682 .44126 L
.56677 .43131 L
.57926 .41882 L
.59345 .40463 L
.61129 .38679 L
.63167 .36641 L
.65474 .34334 L
.68373 .31435 L
.71672 .28136 L
.75825 .23983 L
.80576 .19232 L
.85967 .13841 L
.92744 .07064 L
s
.92744 .07064 m
.99808 0 L
s
.51104 .49407 m
.51315 .49319 L
.51589 .49206 L
.51893 .4908 L
.52238 .48937 L
.52671 .48758 L
.53163 .48554 L
.53783 .48297 L
.54491 .48004 L
.55294 .47671 L
.56303 .47253 L
.57454 .46777 L
.58754 .46238 L
.60385 .45563 L
.62239 .44795 L
.64571 .43829 L
.67233 .42726 L
.70248 .41477 L
.74035 .39909 L
.78345 .38124 L
.83772 .35876 L
.89979 .33305 L
.97022 .30387 L
s
.97022 .30387 m
1 .29154 L
s
.51203 .49904 m
.51432 .49904 L
.51727 .49904 L
.52057 .49904 L
.5243 .49904 L
.52899 .49904 L
.53432 .49904 L
.54102 .49904 L
.54869 .49904 L
.55738 .49904 L
.56831 .49904 L
.58076 .49904 L
.59483 .49904 L
.61249 .49904 L
.63255 .49904 L
.65779 .49904 L
.6866 .49904 L
.71924 .49904 L
.76023 .49904 L
.80688 .49904 L
.86562 .49904 L
.93281 .49904 L
s
.93281 .49904 m
1 .49904 L
s
1 0 0 r
.02 w
.78913 .33156 Mdot
.78913 .33156 Mdot
0 g
.5 Mabswid
.97889 .49904 m
1 .49904 L
s
% Start of user PostScript
5. 0 5.22 0 MAarrowhead1
% End of user PostScript
.49904 .97889 m
.49904 1 L
s
% Start of user PostScript
0 5. 0 5.22 MAarrowhead1
% End of user PostScript
gsave
.97889 .53263 -66 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51823 .97889 -69 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47025 .88292 -66 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47025 .69098 -66 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47025 .3071 -69 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47025 .11516 -69 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
75.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.11516 .47025 -69 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
75.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.3071 .47025 -69 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69098 .47025 -66 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.88292 .47025 -66 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
69.000 12.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{239, 239},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003_0000kb000`400?l00000o`00003o00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0@`3oool100000040oooo00000`3`oo0000000?3ol0120?3ol0030000003`oo00l?o`
02h0l?o`00<000000?3ol03`oo00;P3`oo000`000000l?o`0?3ol0120?3ol04000000@3`oo010?oo
o`000P3`oo000`000000l?o`0?3ol0110?3ol0030000003`oo00l?o`02d0l?o`00<000000?3ol03`
oo00;@3`oo000`000000l?o`0?3ol0120?3ol0030000003`oo00l?o`0040oooo00030?3ol0030000
003`oo00l?o`0400l?o`00<000000?3ol03`oo00;@3`oo000`000000l?o`0?3ol00]0?3ol0030000
003`oo00l?o`0440l?o`00@000000?3ol03`oo00l?o`0@3oool000@0l?o`00<000000?3ol03`oo00
@03`oo000`000000l?o`0?3ol00/0?3ol0030000003`oo00l?o`02d0l?o`00<000000?3ol03`oo00
@03`oo000`000000l?o`0?3ol0020?3ol040oooo00050?3ol0030000003`oo00l?o`03l0l?o`00<0
00000?3ol03`oo00;03`oo000`000000l?o`0?3ol00]0?3ol0030000003`oo00l?o`03l0l?o`00<0
00000?3ol03`oo000`3`oo010?ooo`001P3`oo000`000000l?o`0?3ol00o0?3ol0030000003`oo00
l?o`02/0l?o`00<000000?3ol03`oo00;03`oo000`000000l?o`0?3ol00o0?3ol0030000003`oo00
l?o`00@0l?o`0@3oool000L0l?o`00<000000?3ol03`oo00?P3`oo000`000000l?o`0?3ol00[0?3o
l0030000003`oo00l?o`02`0l?o`00<000000?3ol03`oo00?P3`oo000`000000l?o`0?3ol0050?3o
l040oooo00080?3ol0030000003`oo00l?o`03d0l?o`00<000000?3ol03`oo00:`3`oo000`000000
l?o`0?3ol00/0?3ol0030000003`oo00l?o`03d0l?o`00<000000?3ol03`oo001P3`oo010?ooo`00
203`oo000`000000l?o`0?3ol00n0?3ol0030000003`oo00l?o`02X0l?o`00<000000?3ol03`oo00
:`3`oo000`000000l?o`0?3ol00m0?3ol0030000003`oo00l?o`00L0l?o`0@3oool000T0l?o`00<0
00000?3ol03`oo00?@3`oo000`000000l?o`0?3ol00Z0?3ol0030000003`oo00l?o`02/0l?o`00<0
00000?3ol03`oo00?03`oo000`000000l?o`0?3ol0080?3ol040oooo000:0?3ol0030000003`oo00
l?o`03d0l?o`00<000000?3ol03`oo00:@3`oo000`000000l?o`0?3ol00Z0?3ol0030000003`oo00
l?o`03`0l?o`00<000000?3ol03`oo002@3`oo010?ooo`002`3`oo000`000000l?o`0?3ol00l0?3o
l0030000003`oo00l?o`02T0l?o`00<000000?3ol03`oo00:P3`oo000`000000l?o`0?3ol00k0?3o
l0030000003`oo00l?o`00X0l?o`0@3oool000`0l?o`00<000000?3ol03`oo00>`3`oo000`000000
l?o`0?3ol00Y0?3ol0030000003`oo00l?o`02X0l?o`00<000000?3ol03`oo00>P3`oo000`000000
l?o`0?3ol00;0?3ol040oooo000=0?3ol0030000003`oo00l?o`03/0l?o`00<000000?3ol03`oo00
:03`oo000`000000l?o`0?3ol00Y0?3ol0030000003`oo00l?o`03X0l?o`00<000000?3ol03`oo00
303`oo010?ooo`003P3`oo000`000000l?o`0?3ol00j0?3ol0030000003`oo00l?o`02P0l?o`00<0
00000?3ol03`oo00:@3`oo000`000000l?o`0?3ol00i0?3ol0030000003`oo00l?o`00d0l?o`0@3o
ool000l0l?o`00<000000?3ol03`oo00>P3`oo000`000000l?o`0?3ol00W0?3ol0030000003`oo00
l?o`02P0l?o`00<000000?3ol03`oo00>@3`oo000`000000l?o`0?3ol00>0?3ol040oooo000@0?3o
l0030000003`oo00l?o`03T0l?o`00<000000?3ol03`oo007P3`oo0F000001h0l?o`00<000000?3o
l03`oo00>03`oo000`000000l?o`0?3ol00?0?3ol040oooo000A0?3ol0030000003`oo00l?o`03T0
l?o`00<000000?3ol03`oo005P3`oo07000000T0l?o`00<000000?3ol03`oo002P3`oo07000001H0
l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00@0?3ol040oooo000B0?3ol0030000
003`oo00l?o`03P0l?o`00<000000?3ol03`oo004@3`oo0500000100l?o`00<000000?3ol03`oo00
4@3`oo0400000180l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00A0?3ol040oooo
000C0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00303`oo05000001D0l?o`00<0
00000?3ol03`oo005@3`oo03000000l0l?o`00<000000?3ol03`oo00=P3`oo000`000000l?o`0?3o
l00B0?3ol040oooo000D0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00203`oo03
000001X0l?o`00<000000?3ol03`oo00603`oo03000000/0l?o`00<000000?3ol03`oo00=P3`oo00
0`000000l?o`0?3ol00C0?3ol040oooo000E0?3ol0030000003`oo00l?o`03H0l?o`00<000000?3o
l03`oo001@3`oo03000001d0l?o`00<000000?3ol03`oo006`3`oo04000000L0l?o`00<000000?3o
l03`oo00=@3`oo000`000000l?o`0?3ol00D0?3ol040oooo000F0?3ol0030000003`oo00l?o`03H0
l?o`00<000000?3ol03`oo001000000P0?3ol0030000003`oo00l?o`01l0l?o`0P0000040?3ol003
0000003`oo00l?o`03D0l?o`00<000000?3ol03`oo005@3`oo010?ooo`005`3`oo000`000000l?o`
0?3ol00e0?3ol0<00000903`oo000`000000l?o`0?3ol00Q0?3ol08000000P3`oo000`000000l?o`
0?3ol00d0?3ol0030000003`oo00l?o`01H0l?o`0@3oool001P0l?o`00<000000?3ol03`oo00<`3`
oo02000002H0l?o`00<000000?3ol03`oo008`3`oo03000003D0l?o`00<000000?3ol03`oo005`3`
oo010?ooo`006@3`oo000`000000l?o`0?3ol00`0?3ol08000000P3`oo000`000000l?o`0?3ol00O
0?3ol0<0000000<0l?o`0000003`oo009@3`oo0400000380l?o`00<000000?3ol03`oo00603`oo01
0?ooo`006P3`oo000`000000l?o`0?3ol00]0?3ol0800000103`oo000`000000l?o`0?3ol00G0?3o
l0@000001@3`oo0010000000l?o`0?3ol000000V0?3ol0040000003`oo00l?o`0?3ol0800000;`3`
oo000`000000l?o`0?3ol00I0?3ol040oooo000K0?3ol0030000003`oo00l?o`02X0l?o`0P000007
0?3ol0030000003`oo00l?o`01`0l?o`1@0000000`3`oo0000000?3ol00T0?3ol0030000003`oo00
l?o`00@0l?o`0P00000/0?3ol0030000003`oo00l?o`01X0l?o`0@3oool001`0l?o`00<000000?3o
l03`oo009`3`oo02000000T0l?o`00<000000?3ol03`oo00703`oo0010000000l?o`0?3ol0000002
0?3ol0030000003`oo00l?o`02<0l?o`00<000000?3ol03`oo001P3`oo03000002P0l?o`00<00000
0?3ol03`oo006`3`oo010?ooo`007@3`oo000`000000l?o`0?3ol00T0?3ol08000002`3`oo000`00
0000l?o`0?3ol00M0?3ol0030000003`oo0000000080l?o`00<000000?3ol03`oo008`3`oo000`00
0000l?o`0?3ol0090?3ol08000009@3`oo000`000000l?o`0?3ol00L0?3ol040oooo000N0?3ol003
0000003`oo00l?o`0240l?o`0P00000>0?3ol0030000003`oo00l?o`01d0l?o`0P0000020?3ol003
0000003`oo00l?o`0280l?o`00<000000?3ol03`oo00303`oo0200000280l?o`00<000000?3ol03`
oo007@3`oo010?ooo`007`3`oo000`000000l?o`0?3ol00O0?3ol0030000003`oo00l?o`00h0l?o`
00<000000?3ol03`oo008@3`oo000`000000l?o`0?3ol00R0?3ol0030000003`oo00l?o`00h0l?o`
0P00000O0?3ol0030000003`oo00l?o`01h0l?o`0@3oool00200l?o`00<000000?3ol03`oo00703`
oo0200000180l?o`00<000000?3ol03`oo00803`oo000`000000l?o`0?3ol00Q0?3ol0030000003`
oo00l?o`0140l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00O0?3ol040oooo000Q
0?3ol0030000003`oo00l?o`01T0l?o`0P00000D0?3ol0030000003`oo00l?o`0200l?o`00<00000
0?3ol03`oo008@3`oo000`000000l?o`0?3ol00B0?3ol0030000003`oo00l?o`01T0l?o`00<00000
0?3ol03`oo00803`oo010?ooo`008P3`oo000`000000l?o`0?3ol00G0?3ol0030000003`oo00l?o`
01@0l?o`00<000000?3ol03`oo00803`oo000`000000l?o`0?3ol00Q0?3ol0030000003`oo00l?o`
01<0l?o`0P00000H0?3ol0030000003`oo00l?o`0240l?o`0@3oool002<0l?o`00<000000?3ol03`
oo00503`oo02000001P0l?o`00<000000?3ol03`oo007`3`oo000`000000l?o`0?3ol00P0?3ol003
0000003`oo00l?o`01H0l?o`00<000000?3ol03`oo00503`oo000`000000l?o`0?3ol00R0?3ol040
oooo000T0?3ol0030000003`oo00l?o`0180l?o`00<000000?3ol03`oo00603`oo000`000000l?o`
0?3ol00O0?3ol0030000003`oo00l?o`0200l?o`00<000000?3ol03`oo005`3`oo000`000000l?o`
0?3ol00B0?3ol0030000003`oo00l?o`02<0l?o`0@3oool002D0l?o`00<000000?3ol03`oo00403`
oo000`000000l?o`0?3ol00J0?3ol0030000003`oo00l?o`01h0l?o`00<000000?3ol03`oo007`3`
oo000`000000l?o`0?3ol00I0?3ol08000004@3`oo000`000000l?o`0?3ol00T0?3ol040oooo000V
0?3ol0030000003`oo00l?o`00h0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00N
0?3ol0030000003`oo00l?o`01l0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00=
0?3ol0030000003`oo00l?o`02D0l?o`0@3oool002L0l?o`00<000000?3ol03`oo00303`oo000`00
0000l?o`0?3ol00L0?3ol0030000003`oo00l?o`01h0l?o`00<000000?3ol03`oo007`3`oo000`00
0000l?o`0?3ol00L0?3ol0030000003`oo00l?o`00/0l?o`00<000000?3ol03`oo009P3`oo010?oo
o`00:03`oo000`000000l?o`0?3ol00:0?3ol0030000003`oo00l?o`01h0l?o`00<000000?3ol03`
oo007@3`oo000`000000l?o`0?3ol00N0?3ol0030000003`oo00l?o`01h0l?o`00<000000?3ol03`
oo002@3`oo000`000000l?o`0?3ol00W0?3ol040oooo000Y0?3ol0030000003`oo00l?o`00L0l?o`
0P00000Q0?3ol0030000003`oo00l?o`01d0l?o`00<000000?3ol03`oo007P3`oo000`000000l?o`
0?3ol00O0?3ol0030000003`oo00l?o`00L0l?o`00<000000?3ol03`oo00:03`oo010?ooo`00:P3`
oo000`000000l?o`0?3ol0050?3ol0030000003`oo00l?o`0280l?o`00<000000?3ol03`oo00703`
oo000`000000l?o`0?3ol00M0?3ol0030000003`oo00l?o`0240l?o`00<000000?3ol03`oo001@3`
oo000`000000l?o`0?3ol00Y0?3ol040oooo000[0?3ol0030000003`oo00l?o`00<0l?o`00<00000
0?3ol03`oo008`3`oo000`000000l?o`0?3ol00L0?3ol0030000003`oo00l?o`01d0l?o`00<00000
0?3ol03`oo008P3`oo02000000@0l?o`00<000000?3ol03`oo00:P3`oo010?ooo`00;03`oo001@00
0000l?o`0?3ol03`oo00000002H0l?o`00<000000?3ol03`oo00703`oo000`000000l?o`0?3ol00L
0?3ol0030000003`oo00l?o`02D0l?o`00@000000?3ol03`oo000000;@3`oo010?ooo`00;@3`oo00
0`000000l?o`0000000X0?3ol0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo00703`oo00
0`000000l?o`0?3ol00V0?3ol0800000;P3`oo010?ooo`00;P3`oo000`000000l?o`0?3ol00W0?3o
l0030000003`oo00l?o`01/0l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00W0?3o
l0800000;P3`oo010?ooo`00;@3`oo000`000000l?o`0000000X0?3ol0030000003`oo00l?o`01/0
l?o`00<000000?3ol03`oo006`3`oo000`000000l?o`0?3ol00V0?3ol0040000003`oo00l?o`0000
02d0l?o`0@3oool002`0l?o`00D000000?3ol03`oo00l?o`0000000X0?3ol0030000003`oo00l?o`
01X0l?o`00<000000?3ol03`oo006P3`oo000`000000l?o`0?3ol00V0?3ol0030000003`oo00l?o`
0080l?o`00<000000?3ol03`oo00:P3`oo010?ooo`00:`3`oo000`000000l?o`0?3ol0030?3ol003
0000003`oo00l?o`02D0l?o`00<000000?3ol03`oo006P3`oo000`000000l?o`0?3ol00J0?3ol003
0000003`oo00l?o`02D0l?o`00<000000?3ol03`oo00103`oo000`000000l?o`0?3ol00Y0?3ol040
oooo000Z0?3ol0030000003`oo00l?o`00D0l?o`00<000000?3ol03`oo009@3`oo000`000000l?o`
0?3ol00I0?3ol0030000003`oo00l?o`01T0l?o`00<000000?3ol03`oo009@3`oo000`000000l?o`
0?3ol0050?3ol0030000003`oo00l?o`02T0l?o`0@3oool002T0l?o`00<000000?3ol03`oo001`3`
oo000`000000l?o`0?3ol00T0?3ol0030000003`oo00l?o`01T0l?o`00<000000?3ol03`oo006@3`
oo000`000000l?o`0?3ol00T0?3ol0030000003`oo00l?o`00L0l?o`00<000000?3ol03`oo00:03`
oo010?ooo`00:03`oo000`000000l?o`0?3ol0090?3ol0030000003`oo00l?o`02<0l?o`00<00000
0?3ol03`oo006@3`oo000`000000l?o`0?3ol00I0?3ol0030000003`oo00l?o`02@0l?o`00<00000
0?3ol03`oo00203`oo000`000000l?o`0?3ol00W0?3ol040oooo000W0?3ol0030000003`oo00l?o`
00/0l?o`00<000000?3ol03`oo008`3`oo000`000000l?o`0?3ol00H0?3ol0030000003`oo00l?o`
01P0l?o`00<000000?3ol03`oo00903`oo000`000000l?o`0?3ol00:0?3ol0030000003`oo00l?o`
02H0l?o`0@3oool002H0l?o`00<000000?3ol03`oo003@3`oo000`000000l?o`0?3ol00R0?3ol003
0000003`oo00l?o`01P0l?o`00<000000?3ol03`oo00603`oo000`000000l?o`0?3ol00S0?3ol003
0000003`oo00l?o`00`0l?o`00<000000?3ol03`oo009@3`oo010?ooo`009@3`oo000`000000l?o`
0?3ol00?0?3ol0030000003`oo00l?o`0280l?o`00<000000?3ol03`oo005`3`oo000`000000l?o`
0?3ol00G0?3ol0030000003`oo00l?o`02<0l?o`00<000000?3ol03`oo003P3`oo000`000000l?o`
0?3ol00T0?3ol040oooo000T0?3ol0030000003`oo00l?o`0140l?o`00<000000?3ol03`oo008@3`
oo000`000000l?o`0?3ol00B0?3ol0/00000503`oo000`000000l?o`0?3ol00R0?3ol0030000003`
oo00l?o`00l0l?o`00<000000?3ol03`oo00903`oo010?ooo`00903`oo000`000000l?o`0?3ol00B
0?3ol0030000003`oo00l?o`0200l?o`00<000000?3ol03`oo002`3`oo07000000D0l?o`00<00000
0?3ol03`oo000`3`oo06000000h0l?o`00<000000?3ol03`oo008@3`oo000`000000l?o`0?3ol00A
0?3ol0030000003`oo00l?o`02<0l?o`0@3oool002<0l?o`00<000000?3ol03`oo00503`oo000`00
0000l?o`0?3ol00P0?3ol0030000003`oo00l?o`00H0l?o`1000000<0?3ol0030000003`oo00l?o`
00T0l?o`0`00000:0?3ol0030000003`oo00l?o`0240l?o`00<000000?3ol03`oo004`3`oo000`00
0000l?o`0?3ol00R0?3ol040oooo000R0?3ol0030000003`oo00l?o`01H0l?o`00<000000?3ol03`
oo007`3`oo000`000000l?o`0?3ol0030?3ol0<00000403`oo000`000000l?o`0?3ol00<0?3ol0@0
00001P3`oo000`000000l?o`0?3ol00P0?3ol0030000003`oo00l?o`01D0l?o`00<000000?3ol03`
oo008@3`oo010?ooo`008P3`oo000`000000l?o`0?3ol00G0?3ol0030000003`oo00l?o`01l0l?o`
00<000000?3ol03`oo000P00000C0?3ol0030000003`oo00l?o`0100l?o`100000000`3`oo000000
0?3ol00Q0?3ol0030000003`oo00l?o`01H0l?o`00<000000?3ol03`oo008@3`oo010?ooo`008@3`
oo000`000000l?o`0?3ol00I0?3ol0030000003`oo00l?o`01h0l?o`0`00000E0?3ol0030000003`
oo00l?o`01@0l?o`0`00000P0?3ol0030000003`oo00l?o`01P0l?o`00<000000?3ol03`oo00803`
oo010?ooo`008@3`oo000`000000l?o`0?3ol00J0?3ol0030000003`oo00l?o`01X0l?o`1000000G
0?3ol0030000003`oo00l?o`01D0l?o`00@000000?3ol00000000000703`oo02000001`0l?o`00<0
00000?3ol03`oo007`3`oo010?ooo`00803`oo000`000000l?o`0?3ol00L0?3ol0030000003`oo00
l?o`01L0l?o`0P0000040?3ol0030000003`oo00l?o`01@0l?o`00<000000?3ol03`oo00503`oo00
0`000000l?o`0?3ol0020?3ol08000006@3`oo000`000000l?o`0?3ol00L0?3ol0030000003`oo00
l?o`01l0l?o`0@3oool001l0l?o`00<000000?3ol03`oo007P3`oo000`000000l?o`0?3ol00E0?3o
l0030000003`oo00l?o`00@0l?o`00<000000?3ol03`oo00503`oo000`000000l?o`0?3ol00D0?3o
l0030000003`oo00l?o`00@0l?o`0P00000F0?3ol0030000003`oo00l?o`01h0l?o`00<000000?3o
l03`oo007P3`oo010?ooo`007`3`oo000`000000l?o`0?3ol00O0?3ol0030000003`oo00l?o`0180
l?o`0P0000080?3ol0030000003`oo00l?o`01<0l?o`00<000000?3ol03`oo004`3`oo000`000000
l?o`0?3ol0070?3ol0030000003`oo00l?o`0180l?o`00<000000?3ol03`oo007`3`oo000`000000
l?o`0?3ol00N0?3ol040oooo000N0?3ol0030000003`oo00l?o`0240l?o`00<000000?3ol03`oo00
403`oo000`000000l?o`0?3ol0080?3ol0030000003`oo00l?o`01<0l?o`00<000000?3ol03`oo00
4`3`oo000`000000l?o`0?3ol0080?3ol08000004@3`oo000`000000l?o`0?3ol00Q0?3ol0030000
003`oo00l?o`01d0l?o`0@3oool001h0l?o`00<000000?3ol03`oo008P3`oo000`000000l?o`0?3o
l00>0?3ol0030000003`oo00l?o`00X0l?o`00<000000?3ol03`oo004P3`oo000`000000l?o`0?3o
l00B0?3ol0030000003`oo00l?o`00/0l?o`00<000000?3ol03`oo003@3`oo000`000000l?o`0?3o
l00S0?3ol0030000003`oo00l?o`01`0l?o`0@3oool001d0l?o`00<000000?3ol03`oo00903`oo00
0`000000l?o`0?3ol00;0?3ol08000003@3`oo000`000000l?o`0?3ol00B0?3ol0030000003`oo00
l?o`0180l?o`00<000000?3ol03`oo00303`oo000`000000l?o`0?3ol00;0?3ol0030000003`oo00
l?o`02@0l?o`00<000000?3ol03`oo00703`oo010?ooo`0000<000000?3ol03`oo006P3`oo000`00
0000l?o`0?3ol00U0?3ol0030000003`oo00l?o`00T0l?o`00<000000?3ol03`oo003P3`oo000`00
0000l?o`0?3ol00A0?3ol0030000003`oo00l?o`0140l?o`00<000000?3ol03`oo003P3`oo020000
00X0l?o`00<000000?3ol03`oo009P3`oo000`000000l?o`0?3ol00J0?3ol080000000000`3`oo00
00000000000I0?3ol0030000003`oo00l?o`02L0l?o`00<000000?3ol03`oo001`3`oo000`000000
l?o`0?3ol00?0?3ol0030000003`oo00l?o`0140l?o`00<000000?3ol03`oo004@3`oo000`000000
l?o`0?3ol00@0?3ol0030000003`oo00l?o`00H0l?o`00<000000?3ol03`oo009`3`oo000`000000
l?o`0?3ol00H0?3ol08000000@3`oo010?ooo`000`3`oo02000001L0l?o`00<000000?3ol03`oo00
:03`oo000`000000l?o`0?3ol0050?3ol0030000003`oo00l?o`0100l?o`00<000000?3ol03`oo00
2`3`oo0400000080l?o`00<000000?3ol03`oo004@3`oo000`000000l?o`0?3ol00A0?3ol0030000
003`oo00l?o`00@0l?o`00<000000?3ol03`oo00:@3`oo000`000000l?o`0?3ol00D0?3ol0<00000
0`3`oo010?ooo`001@3`oo03000001<0l?o`00<000000?3ol03`oo00:P3`oo000`000000l?o`0?3o
l0020?3ol0800000503`oo000`000000l?o`0?3ol0040?3ol0@000000P3`oo000`000000l?o`0?3o
l0030?3ol0030000003`oo00l?o`0100l?o`00<000000?3ol03`oo004`3`oo000`000000l?o`0?3o
l0020?3ol0030000003`oo00l?o`02X0l?o`00<000000?3ol03`oo004@3`oo03000000H0l?o`0@3o
ool000P0l?o`0P00000A0?3ol0030000003`oo00l?o`02/0l?o`00@000000?3ol03`oo0000005P3`
oo000`000000l?o`0?3ol00;0?3ol0030000003`oo00l?o`0080l?o`00<000000?3ol03`oo00403`
oo000`000000l?o`0?3ol00D0?3ol080000000<0l?o`0000003`oo00;@3`oo000`000000l?o`0?3o
l00>0?3ol08000002@3`oo010?ooo`002P3`oo03000000d0l?o`00<000000?3ol03`oo00;@3`oo02
000001P0l?o`00<000000?3ol03`oo002`3`oo001@000000l?o`0?3ol03`oo0000000140l?o`00<0
00000?3ol03`oo005`3`oo000`000000l?o`0?3ol00]0?3ol0030000003`oo00l?o`00`0l?o`0P00
000;0?3ol040oooo000=0?3ol08000002`3`oo000`000000l?o`0?3ol00]0?3ol0800000603`oo00
0`000000l?o`0?3ol0090?3ol0040000003`oo00l?o`00000080l?o`00<000000?3ol03`oo003`3`
oo000`000000l?o`0?3ol00F0?3ol0030000003`oo00000002l0l?o`00<000000?3ol03`oo002@3`
oo02000000d0l?o`0@3oool000l0l?o`0P0000080?3ol0030000003`oo00l?o`02d0l?o`00@00000
0?3ol03`oo000000603`oo000`000000l?o`0?3ol0090?3ol08000000`3`oo000`000000l?o`0?3o
l00>0?3ol0030000003`oo00l?o`01H0l?o`00D000000?3ol03`oo00l?o`0000000^0?3ol0030000
003`oo00l?o`00H0l?o`0`00000?0?3ol040oooo000A0?3ol0<000001@3`oo000`000000l?o`0?3o
l00/0?3ol0030000003`oo00l?o`0080l?o`00<000000?3ol03`oo005@3`oo000`000000l?o`0?3o
l00>0?3ol0030000003`oo00l?o`00h0l?o`00<000000?3ol03`oo005@3`oo000`000000l?o`0?3o
l0020?3ol0030000003`oo00l?o`01<0l?o`0P3o000H0?3ol0030000003`oo00l?o`00<0l?o`0P00
000B0?3ol040oooo000D0?3ol08000000P3`oo000`000000l?o`0?3ol00/0?3ol0030000003`oo00
l?o`00@0l?o`00<000000?3ol03`oo00503`oo000`000000l?o`0?3ol00>0?3ol0030000003`oo00
l?o`00h0l?o`00<000000?3ol03`oo00503`oo000`000000l?o`0?3ol0040?3ol0030000003`oo00
l?o`0140l?o`103o000G0?3ol0040000003`oo00l?o`0?3ol0800000503`oo010?ooo`005P3`oo03
000002d0l?o`00<000000?3ol03`oo001P3`oo000`000000l?o`0?3ol00D0?3ol0030000003`oo00
l?o`00d0l?o`00<000000?3ol03`oo003@3`oo000`000000l?o`0?3ol00D0?3ol0030000003`oo00
l?o`00H0l?o`00<000000?3ol03`oo00403`oo040?l001P0l?o`0`00000F0?3ol040oooo000G0?3o
l0040000003`oo000000000002X0l?o`00<000000?3ol03`oo00203`oo000`000000l?o`0?3ol00C
0?3ol0030000003`oo00l?o`00d0l?o`00<000000?3ol03`oo003@3`oo000`000000l?o`0?3ol00C
0?3ol0030000003`oo00l?o`00P0l?o`00<000000?3ol03`oo00403`oo020?l001L0l?o`0`00000H
0?3ol040oooo000G0?3ol0040000003`oo00l?o`0?3ol0<000009P3`oo000`000000l?o`0?3ol00:
0?3ol0030000003`oo00l?o`01<0l?o`00<000000?3ol03`oo001@3`oo0A000000H0l?o`00<00000
0?3ol03`oo004P3`oo000`000000l?o`0?3ol0090?3ol0030000003`oo00l?o`02H0l?o`0`000003
0?3ol0030000003`oo00l?o`01D0l?o`0@3oool001H0l?o`00<000000?3ol03`oo001@3`oo020000
02@0l?o`00<000000?3ol03`oo002`3`oo000`000000l?o`0?3ol00B0?3ol0030000003`oo00l?o`
00D000001`3`oo000`000000l?o`0?3ol0070?3ol08000000`3`oo000`000000l?o`0?3ol00B0?3o
l0030000003`oo00l?o`00/0l?o`00<000000?3ol03`oo008`3`oo02000000H0l?o`00<000000?3o
l03`oo005@3`oo010?ooo`005P3`oo000`000000l?o`0?3ol0070?3ol0<00000803`oo000`000000
l?o`0?3ol00=0?3ol0030000003`oo00l?o`0180l?o`0P00000<0?3ol0030000003`oo00l?o`00T0
l?o`0P0000000`3`oo0000000?3ol00B0?3ol0030000003`oo00l?o`00d0l?o`00<000000?3ol03`
oo007`3`oo03000000T0l?o`00<000000?3ol03`oo00503`oo010?ooo`005@3`oo000`000000l?o`
0?3ol00;0?3ol08000007P3`oo000`000000l?o`0?3ol00>0?3ol0030000003`oo00l?o`00l0l?o`
0`00000=0?3ol0030000003`oo00l?o`00/0l?o`0`00000A0?3ol0030000003`oo00l?o`00l0l?o`
00<000000?3ol03`oo00703`oo02000000`0l?o`00<000000?3ol03`oo00503`oo010?ooo`005@3`
oo000`000000l?o`0?3ol00=0?3ol0<000006P3`oo000`000000l?o`0?3ol00@0?3ol0030000003`
oo00l?o`00`0l?o`0P0000030?3ol0030000003`oo00l?o`00X0l?o`00<000000?3ol03`oo002`3`
oo000`000000l?o`0?3ol002000000l0l?o`00<000000?3ol03`oo003`3`oo000`000000l?o`0?3o
l00I0?3ol0<000003P3`oo000`000000l?o`0?3ol00D0?3ol040oooo000E0?3ol0030000003`oo00
l?o`0100l?o`0P00000H0?3ol0030000003`oo00l?o`0140l?o`00<000000?3ol03`oo002P3`oo00
0`000000l?o`0?3ol0030?3ol0030000003`oo00l?o`00X0l?o`00<000000?3ol03`oo002P3`oo00
0`000000l?o`0?3ol0030?3ol0800000303`oo000`000000l?o`0?3ol00A0?3ol0030000003`oo00
l?o`01H0l?o`0P00000B0?3ol0030000003`oo00l?o`01<0l?o`0@3oool001D0l?o`00<000000?3o
l03`oo004P3`oo03000001@0l?o`00<000000?3ol03`oo004`3`oo000`000000l?o`0?3ol0070?3o
l08000001P3`oo000`000000l?o`0?3ol00:0?3ol0030000003`oo00l?o`00X0l?o`00<000000?3o
l03`oo001@3`oo000`000000l?o`0?3ol0080?3ol0030000003`oo00l?o`01<0l?o`00<000000?3o
l03`oo004P3`oo03000001@0l?o`00<000000?3ol03`oo004`3`oo010?ooo`00503`oo000`000000
l?o`0?3ol00F0?3ol0<00000403`oo000`000000l?o`0?3ol00E0?3ol0030000003`oo00l?o`00D0
l?o`00<000000?3ol03`oo001`3`oo000`000000l?o`0?3ol0090?3ol0030000003`oo00l?o`00T0
l?o`00<000000?3ol03`oo001`3`oo02000000L0l?o`00<000000?3ol03`oo005@3`oo000`000000
l?o`0?3ol00>0?3ol0<000005`3`oo000`000000l?o`0?3ol00C0?3ol040oooo000D0?3ol0030000
003`oo00l?o`01T0l?o`0P00000>0?3ol0030000003`oo00l?o`01H0l?o`00<000000?3ol03`oo00
0`3`oo000`000000l?o`0?3ol0080?3ol0030000003`oo00l?o`00T0l?o`00<000000?3ol03`oo00
2@3`oo000`000000l?o`0?3ol0090?3ol0030000003`oo00l?o`00<0l?o`00<000000?3ol03`oo00
5P3`oo000`000000l?o`0?3ol00<0?3ol08000006`3`oo000`000000l?o`0?3ol00B0?3ol040oooo
000D0?3ol0030000003`oo00l?o`01/0l?o`0`00000:0?3ol0030000003`oo00l?o`01P0l?o`00<0
00000?3ol03`oo000P00000;0?3ol0030000003`oo00l?o`00T0l?o`00<000000?3ol03`oo002@3`
oo000`000000l?o`0?3ol00:0?3ol0050000003`oo00l?o`0?3ol00000006P3`oo000`000000l?o`
0?3ol0080?3ol0<000007@3`oo000`000000l?o`0?3ol00B0?3ol040oooo000D0?3ol0030000003`
oo00l?o`01h0l?o`0P0000080?3ol0030000003`oo00l?o`01T0l?o`0P00000>0?3ol0030000003`
oo00l?o`00P0l?o`00<000000?3ol03`oo00203`oo000`000000l?o`0?3ol00<0?3ol0030000003`
oo00000001/0l?o`00<000000?3ol03`oo001P3`oo0200000200l?o`00<000000?3ol03`oo004P3`
oo010?ooo`00503`oo000`000000l?o`0?3ol00P0?3ol0<00000103`oo000`000000l?o`0?3ol00J
0?3ol08000003P3`oo000`000000l?o`0?3ol0080?3ol0030000003`oo00l?o`00P0l?o`00<00000
0?3ol03`oo003@3`oo000`000000l?o`0?3ol00J0?3ol0030000003`oo00l?o`00<0l?o`0`00000R
0?3ol0030000003`oo00l?o`0180l?o`0@3oool001<0l?o`00<000000?3ol03`oo00903`oo020000
0080l?o`00<000000?3ol03`oo006@3`oo0010000000l?o`0?3ol000000>0?3ol0030000003`oo00
l?o`00L0l?o`00<000000?3ol03`oo00203`oo000`000000l?o`0?3ol00<0?3ol0030000003`oo00
000001`0l?o`00<000000?3ol03`oo000P00000V0?3ol0030000003`oo00l?o`0140l?o`0@3oool0
01<0l?o`00<000000?3ol03`oo009P3`oo03000001/0l?o`00D000000?3ol03`oo00l?o`0000000=
0?3ol0030000003`oo00l?o`00L0l?o`00<000000?3ol03`oo001`3`oo000`000000l?o`0?3ol00<
0?3ol0050000003`oo00l?o`0?3ol00000006`3`oo03000002P0l?o`00<000000?3ol03`oo004@3`
oo010?ooo`004`3`oo000`000000l?o`0?3ol00W0?3ol0040000003`oo000000000001P0l?o`00<0
00000?3ol03`oo000`3`oo000`000000l?o`0?3ol00;0?3ol0030000003`oo00l?o`00D0l?o`1000
00070?3ol0030000003`oo00l?o`00/0l?o`00<000000?3ol03`oo000`3`oo000`000000l?o`0?3o
l00F0?3ol080000000<0l?o`0000003`oo00:03`oo000`000000l?o`0?3ol00A0?3ol040oooo000C
0?3ol0030000003`oo00l?o`02H0l?o`00<000000?3ol03`oo000P3`oo02000001D0l?o`00<00000
0?3ol03`oo001@3`oo000`000000l?o`0?3ol00:0?3ol0040000003`oo00l?o`0?3ol0@0000000@0
l?o`0000003`oo00l?o`1@0000000`3`oo0000000?3ol00<0?3ol0030000003`oo00l?o`00D0l?o`
00<000000?3ol03`oo004`3`oo02000000<0l?o`00<000000?3ol03`oo009`3`oo000`000000l?o`
0?3ol00A0?3ol040oooo000B0?3ol0030000003`oo00l?o`02L0l?o`00<000000?3ol03`oo00103`
oo0200000180l?o`00<000000?3ol03`oo001`3`oo000`000000l?o`0?3ol00:0?3ol0<000001@3`
oo000`000000l?o`0?3ol0050?3ol0800000303`oo000`000000l?o`0?3ol0060?3ol0030000003`
oo00l?o`0140l?o`0P0000050?3ol0030000003`oo00l?o`02L0l?o`00<000000?3ol03`oo004@3`
oo010?ooo`004P3`oo000`000000l?o`0?3ol00W0?3ol0030000003`oo00l?o`00H0l?o`0`00000?
0?3ol0030000003`oo00l?o`00P0l?o`00<000000?3ol03`oo001P3`oo04000000L0l?o`00<00000
0?3ol03`oo001P3`oo03000000P0l?o`0P00000:0?3ol0030000003`oo00l?o`00d0l?o`0`000008
0?3ol0030000003`oo00l?o`02H0l?o`00<000000?3ol03`oo004@3`oo010?ooo`004P3`oo000`00
0000l?o`0?3ol00V0?3ol0030000003`oo00l?o`00X0l?o`0P00000<0?3ol0030000003`oo00l?o`
00X0l?o`00<000000?3ol03`oo00103`oo000`000000l?o`0?3ol0020?3ol0030000003`oo00l?o`
00@0l?o`00<000000?3ol03`oo001@3`oo0010000000l?o`0?3ol03`oo02000000D0l?o`00<00000
0?3ol03`oo002P3`oo000`000000l?o`0?3ol00;0?3ol08000002`3`oo000`000000l?o`0?3ol00W
0?3ol0030000003`oo00l?o`0100l?o`0@3oool00140l?o`00<000000?3ol03`oo009`3`oo000`00
0000l?o`0?3ol00<0?3ol08000002P3`oo000`000000l?o`0?3ol00;0?3ol0030000003`oo00l?o`
0080l?o`00<000000?3ol03`oo000`3`oo000`000000l?o`0?3ol0040?3ol0030000003`oo00l?o`
00D0l?o`00<000000?3ol03`oo000`3`oo0200000080l?o`00<000000?3ol03`oo00303`oo000`00
0000l?o`0?3ol0080?3ol08000003@3`oo000`000000l?o`0?3ol00W0?3ol0030000003`oo00l?o`
0100l?o`0@3oool00140l?o`00<000000?3ol03`oo009P3`oo000`000000l?o`0?3ol00?0?3ol080
00001`3`oo000`000000l?o`0?3ol00=0?3ol0040000003`oo000000000000H0l?o`00<000000?3o
l03`oo00103`oo000`000000l?o`0?3ol0050?3ol0030000003`oo00l?o`00D0l?o`0P00000?0?3o
l0030000003`oo00l?o`00D0l?o`0`00000@0?3ol0030000003`oo00l?o`02H0l?o`00<000000?3o
l03`oo00403`oo010?ooo`004@3`oo000`000000l?o`0?3ol00V0?3ol0030000003`oo00l?o`0140
l?o`0P0000050?3ol0030000003`oo00l?o`00h0l?o`00<000000?3ol03`oo001`3`oo000`000000
l?o`0?3ol0030?3ol0030000003`oo00l?o`00@0l?o`00<000000?3ol03`oo001P3`oo0200000100
l?o`00<000000?3ol03`oo000P3`oo02000001<0l?o`00<000000?3ol03`oo009`3`oo000`000000
l?o`0?3ol00?0?3ol040oooo000A0?3ol0030000003`oo00l?o`02H0l?o`00<000000?3ol03`oo00
4`3`oo0200000080l?o`00<000000?3ol03`oo003P3`oo000`000000l?o`000000080?3ol0030000
003`oo00l?o`00<0l?o`00<000000?3ol03`oo00103`oo000`000000l?o`0?3ol0050?3ol0040000
003`oo00l?o`000000l0l?o`00<000000?3ol03`oo000P00000F0?3ol0030000003`oo00l?o`02H0
l?o`00<000000?3ol03`oo003`3`oo010?ooo`004@3`oo000`000000l?o`0?3ol00U0?3ol0030000
003`oo00l?o`01H0l?o`0`00000?0?3ol0050000003`oo00l?o`0?3ol00000001`3`oo000`000000
l?o`0?3ol0020?3ol0@000000`3`oo000`000000l?o`0?3ol0060?3ol0040000003`oo00l?o`0000
00l0l?o`0`00000H0?3ol0030000003`oo00l?o`02H0l?o`00<000000?3ol03`oo003`3`oo010?oo
o`004@3`oo000`000000l?o`0?3ol00U0?3ol0030000003`oo00l?o`01L0l?o`00<000000?3ol000
00000P00000<0?3ol0030000003`oo00l?o`0080l?o`00<000000?3ol03`oo001@3`oo0600000003
0?3ol0000000000000<000001`3`oo000`000000l?o`0?3ol0020?3ol0030000003`oo00l?o`00X0
l?o`0P0000000`3`oo0000000?3ol00H0?3ol0030000003`oo00l?o`02H0l?o`00<000000?3ol03`
oo003`3`oo010?ooo`004@3`oo000`000000l?o`0?3ol00U0?3ol0030000003`oo00l?o`01L0l?o`
00<000000?3ol03`oo000P3`oo02000000T0l?o`00<000000?3ol03`oo00103`oo000`000000l?o`
0?3ol0020?3ol0<00000103`oo000`000000l?o`0?3ol0020?3ol0<000001@3`oo000`000000l?o`
0?3ol0030?3ol0030000003`oo00l?o`00L0l?o`0`0000030?3ol0030000003`oo00l?o`01L0l?o`
00<000000?3ol03`oo009P3`oo000`000000l?o`0?3ol00?0?3ol040oooo000@0?3ol0030000003`
oo00l?o`02H0l?o`00<000000?3ol03`oo005P3`oo000`000000l?o`0?3ol0050?3ol08000001`3`
oo000`000000l?o`0?3ol0050?3ol0040000003`oo00l?o`000000<0l?o`00D000000?3ol03`oo00
l?o`000000040?3ol0030000003`oo00l?o`008000000P3`oo000`000000l?o`0?3ol0050?3ol003
0000003`oo00l?o`00@0l?o`0P0000070?3ol0030000003`oo00l?o`01H0l?o`00<000000?3ol03`
oo009P3`oo000`000000l?o`0?3ol00?0?3ol040oooo000@0?3ol0030000003`oo00l?o`02H0l?o`
00<000000?3ol03`oo005P3`oo000`000000l?o`0?3ol0070?3ol0800000103`oo000`000000l?o`
0?3ol0070?3ol0800000103`oo001@000000l?o`0?3ol03`oo00000000<0l?o`00<000000?3ol03`
oo000P3`oo03000000T0l?o`00@000000?3ol03`oo00l?o`0P0000090?3ol0030000003`oo00l?o`
01H0l?o`00<000000?3ol03`oo009P3`oo000`000000l?o`0?3ol00?0?3ol040oooo000@0?3ol003
0000003`oo00l?o`02H0l?o`00<000000?3ol03`oo005P3`oo000`000000l?o`0?3ol0090?3ol080
000000<0l?o`0000003`oo002@3`oo02000000@0l?o`00D000000?3ol03`oo00l?o`000000030?3o
l0030000003`oo00l?o`0080l?o`0P00000:0?3ol0040000003`oo000000000000`0l?o`00<00000
0?3ol03`oo005P3`oo000`000000l?o`0?3ol00U0?3ol0030000003`oo00l?o`00l0l?o`0@3oool0
0100l?o`00<000000?3ol03`oo002`3`oo03000001P0l?o`00<000000?3ol03`oo003P3`oo040000
00<0l?o`00<000000?3ol03`oo00303`oo03000000P0l?o`00@000000?3ol03`oo0000000`3`oo08
000000D0l?o`00<000000?3ol0000000203`oo03000000h0l?o`00<000000?3ol03`oo00103`oo04
000000h0l?o`00<000000?3ol03`oo006`3`oo03000000L0l?o`00<000000?3ol03`oo003`3`oo01
0?ooo`00403`oo000`000000l?o`0?3ol0030?3ol0@000001@3`oo000`000000l?o`0?3ol00F0?3o
l0030000003`oo00l?o`00T0l?o`100000020?3ol0030000003`oo00l?o`00@0l?o`00<000000?3o
l03`oo003@3`oo000`000000l?o`00000002000000@0l?o`00<000000?3ol03`oo000P3`oo000`00
0000l?o`0?3ol00200000080l?o`00<000000?3ol03`oo000`0000000`3`oo000000000000020?3o
l0030000003`oo00l?o`00@0l?o`0P0000020?3ol0030000003`oo00l?o`00`0l?o`00<000000?3o
l03`oo00103`oo000`000000l?o`0?3ol00?0?3ol0030000003`oo00l?o`01`0l?o`00<000000?3o
l03`oo001P3`oo000`000000l?o`0?3ol00?0?3ol040oooo000@0?3ol0030000003`oo00l?o`00T0
l?o`1@00000G0?3ol0030000003`oo00l?o`0100l?o`00<000000?3ol03`oo000`3`oo000`000000
l?o`0?3ol00<0?3ol0030000003`oo00l?o`00<0l?o`0P0000020?3ol0030000003`oo00l?o`00<0
l?o`0P0000020?3ol0030000003`oo0000000080l?o`00@000000?3ol03`oo0000001@3`oo000`00
0000l?o`0?3ol003000000@0l?o`00<000000?3ol03`oo00303`oo000`000000l?o`0?3ol0050?3o
l0030000003`oo00l?o`00h0l?o`00<000000?3ol03`oo006@3`oo05000000L0l?o`00<000000?3o
l03`oo003`3`oo010?ooo`00403`oo000`000000l?o`0?3ol0090?3ol0040000003`oo00l?o`0000
01P0l?o`00<000000?3ol03`oo004@3`oo000`000000l?o`0?3ol0020?3ol0030000003`oo00l?o`
00`0l?o`00<000000?3ol03`oo001@3`oo03000000D0l?o`0P0000020?3ol0H0000000@0l?o`0000
003`oo0000001@3`oo02000000L0l?o`00<000000?3ol03`oo003@3`oo000`000000l?o`0?3ol005
0?3ol0030000003`oo00l?o`00d0l?o`00<000000?3ol03`oo006@3`oo0010000000l?o`0?3ol000
00080?3ol0030000003`oo00l?o`00l0l?o`0@3oool00100l?o`00<000000?3ol03`oo002P3`oo00
0`000000l?o`0000000H0?3ol0030000003`oo00l?o`00l0l?o`00@000000?3ol03`oo0000000`3`
oo000`000000l?o`0?3ol00<0?3ol0030000003`oo00l?o`00H0l?o`1@000000103`oo0000000?3o
l03`oo05000000050?3ol000000000000?3ol00000000P3`oo000`000000l?o`00000003000000T0
l?o`00<000000?3ol03`oo00303`oo000`000000l?o`0?3ol0030?3ol0040000003`oo00l?o`0000
00h0l?o`00<000000?3ol03`oo006P3`oo000`000000l?o`000000090?3ol0030000003`oo00l?o`
00h0l?o`0@3oool00100l?o`00<000000?3ol03`oo002`3`oo02000001P0l?o`00<000000?3ol03`
oo00403`oo02000000@0l?o`00<000000?3ol03`oo00303`oo000`000000l?o`0?3ol0060?3ol003
0000003`oo00l?o`0080l?o`0P0000020?3ol080000000<0l?o`000000000000100000030?3ol080
0000103`oo000`000000l?o`0?3ol0060?3ol0030000003`oo00l?o`00`0l?o`00<000000?3ol03`
oo00103`oo02000000l0l?o`00<000000?3ol03`oo006`3`oo02000000T0l?o`00<000000?3ol03`
oo003P3`oo010?ooo`00403`oo000`000000l?o`0?3ol00U0?3ol0030000003`oo00l?o`01H0l?o`
00<000000?3ol03`oo00303`oo000`000000l?o`0?3ol0060?3ol0030000003`oo00l?o`0080l?o`
00<000000?3ol00000000P0000000`3`oo000000000000020?3ol080000000<0l?o`000000000000
0P0000050?3ol0030000003`oo00l?o`00H0l?o`00<000000?3ol03`oo00303`oo000`000000l?o`
0?3ol00E0?3ol0030000003`oo00l?o`02H0l?o`00<000000?3ol03`oo001P3`oo02000000H0l?o`
0@3oool00100l?o`00<000000?3ol03`oo009@3`oo000`000000l?o`0?3ol00F0?3ol0030000003`
oo00l?o`00/0l?o`00<000000?3ol03`oo001P3`oo02000000@0l?o`00<000000?3ol03`oo001000
00040?3ol0<000000P3`oo02000000@0l?o`00<000000?3ol03`oo001P3`oo000`000000l?o`0?3o
l00<0?3ol0030000003`oo00l?o`01D0l?o`00<000000?3ol03`oo009P3`oo000`000000l?o`0?3o
l0060?3ol0H000000P3`oo010?ooo`00M00000050?3ol7H00000000@003oo`0300000000ool00?oo
02D00?oo00<00000003oo`00ool05P00ool00`0000000?oo003oo`0;003oo`0300000000ool00?oo
00H00?oo00<00000003oo`00ool00`00ool01P0000000?oo003oo`0000000?oo000000D00?oo00<0
0000003oo`0000000`00ool00`0000000?oo003oo`02003oo`0300000000ool00?oo00H00?oo00<0
0000003oo`00ool03000ool00`0000000?oo003oo`0E003oo`0300000000ool00?oo02H00?oo00<0
0000003oo`00ool01P00ool7000000400?oo0@3oool001000?oo00<00000003oo`00ool09@00ool0
0`0000000?oo003oo`0F003oo`0300000000ool00?oo00/00?oo0P000008003oo`0300000000ool0
0?oo00800?oo00<00000003oo`00ool010000003003oo`@000000P00ool2000000@00?oo00<00000
003oo`00ool01P00ool00`0000000?oo003oo`0<003oo`0300000000ool00?oo01D00?oo00<00000
003oo`00ool09P00ool00`0000000?oo003oo`06003oo`<000001@00ool10?ooo`004000ool00`00
00000?oo003oo`0U003oo`0300000000ool00?oo01H00?oo00<00000003oo`00ool03000ool00`00
00000?oo003oo`06003oo`0300000000ool00?oo00800?oo4@000005003oo`0300000000ool00?oo
00H00?oo00<00000003oo`00ool03000ool00`0000000?oo003oo`0E003oo`0300000000ool00?oo
02H00?oo00<00000003oo`00ool03P00ool10?ooo`004000ool00`0000000?oo003oo`0U003oo`03
00000000ool00?oo01H00?oo00<00000003oo`00ool03000ool00`0000000?oo003oo`06003oo`04
00000000ool00?oo003oo`<000000`00ool01@0000000?oo0000000000000?oo00<000000`00ool3
000000<00?oo00<00000003oo`00ool01P00ool00`0000000?oo003oo`0<003oo`0300000000ool0
0?oo01D00?oo00<00000003oo`00ool09P00ool00`0000000?oo003oo`0>003oo`40oooo000@003o
o`0300000000ool00?oo02D00?oo00<00000003oo`00ool05P00ool00`0000000?oo003oo`0<003o
o`0300000000ool00?oo00H00?oo00@00000003oo`00000000000P00ool01@0000000?oo00000000
00000?oo00H0000000<00?oo00000000ool00P000002003oo`0300000000ool0000000T00?oo00<0
0000003oo`00ool03000ool00`0000000?oo003oo`0E003oo`0300000000ool00?oo02H00?oo00<0
0000003oo`00ool03P00ool10?ooo`004000ool00`0000000?oo003oo`0U003oo`0300000000ool0
0?oo01H00?oo00<00000003oo`00ool03000ool00`0000000?oo003oo`06003oo`8000001@00ool0
1`0000000?oo003oo`00ool00000003oo`0000000P00ool0100000000?oo003oo`000005003oo`<0
00001`00ool00`0000000?oo003oo`0<003oo`0300000000ool00?oo01H00?oo00<00000003oo`00
ool09@00ool00`0000000?oo003oo`0?003oo`40oooo000@003oo`0300000000ool00?oo02H00?oo
00<00000003oo`00ool05@00ool00`0000000?oo003oo`0=003oo`0300000000ool00?oo00800?oo
0`0000000`00ool00000003oo`03003oo`0800000000ool0000000000000ool00000003oo`000002
003oo`0500000000ool00000003oo`0000001000ool00`0000000?oo003oo`02000000D00?oo00<0
0000003oo`00ool03000ool00`0000000?oo003oo`0F003oo`0300000000ool00?oo02D00?oo00<0
0000003oo`00ool01P00ool200000003003oo`000000000000@00?oo0@3oool001000?oo00<00000
003oo`00ool09P00ool00`0000000?oo003oo`0E003oo`0300000000ool00?oo00d00?oo00<00000
003oo`0000000P000005003oo`0400000000ool00?oo000000@00?oo20000003003oo`0400000000
ool00?oo000000D00?oo0`000002003oo`0300000000ool00?oo00`00?oo00<00000003oo`00ool0
5P00ool00`0000000?oo003oo`0U003oo`0300000000ool00?oo00L00?oo00<00000003oo`000000
1@00ool10?ooo`004000ool00`0000000?oo003oo`0V003oo`0300000000ool00?oo01H00?oo00<0
0000003oo`00ool03000ool2000000P00?oo00@00000003oo`00ool000000`00ool00`0000000?oo
003oo`05000000D00?oo00<00000003oo`0000002000ool2000000l00?oo00<00000003oo`00ool0
5P00ool00`0000000?oo003oo`0U003oo`0300000000ool00?oo00P00?oo00<00000003oo`00ool0
1000ool10?ooo`004000ool00`0000000?oo003oo`0V003oo`0300000000ool00?oo01H00?oo00<0
0000003oo`00ool02P00ool3000000X00?oo0P000004003oo`0500000000ool00?oo003oo`000000
0`00ool00`0000000?oo003oo`03003oo`0300000000ool00?oo00P00?oo0`00000=003oo`030000
0000ool00?oo01H00?oo00<00000003oo`00ool09@00ool00`0000000?oo003oo`06003oo`800000
00<00?oo0000000000001000ool10?ooo`004@00ool00`0000000?oo003oo`0U003oo`0300000000
ool00?oo01H00?oo00<00000003oo`00ool01`00ool3000000<00?oo00<00000003oo`00ool01P00
ool0100000000?oo000000000003003oo`0500000000ool00?oo003oo`0000001000ool01`000000
0?oo003oo`00ool00000003oo`0000002000ool0100000000?oo003oo`00ool4000000P00?oo00<0
0000003oo`00ool05P00ool00`0000000?oo003oo`0V003oo`0300000000ool00?oo00l00?oo0@3o
ool001400?oo00<00000003oo`00ool09@00ool00`0000000?oo003oo`0F003oo`0300000000ool0
0?oo00@00?oo0`000007003oo`0300000000ool00?oo00D00?oo00L00000003oo`00ool00?oo0000
0000ool0000000@00?oo00<00000003oo`00ool00P00ool0100000000?oo000000000003003oo`03
00000000ool00?oo00D00?oo00<00000003oo`00ool01@00ool3000000D00?oo00<00000003oo`00
ool05P00ool00`0000000?oo003oo`0V003oo`0300000000ool00?oo00l00?oo0@3oool001400?oo
00<00000003oo`00ool09P00ool00`0000000?oo003oo`0E003oo`0300000000ool00?oo00800?oo
0P00000:003oo`0300000000ool00?oo00@00?oo00<00000003oo`00ool00`00ool3000000<00?oo
00<00000003oo`00ool00P00ool2000000H00?oo00<00000003oo`00ool00`00ool00`0000000?oo
003oo`09003oo`8000000`00ool00`0000000?oo003oo`0F003oo`0300000000ool00?oo02H00?oo
00<00000003oo`00ool03`00ool10?ooo`004@00ool00`0000000?oo003oo`0V003oo`0300000000
ool00?oo01H00?oo00@00000003oo`00000000003@00ool00`0000000?oo003oo`02003oo`030000
0000ool00?oo00@00?oo00<00000003oo`000000200000000`00ool00000003oo`06003oo`050000
0000ool00?oo003oo`0000003P00ool3000001T00?oo00<00000003oo`00ool09P00ool00`000000
0?oo003oo`0?003oo`40oooo000A003oo`0300000000ool00?oo02H00?oo00<00000003oo`00ool0
5@00ool3000001000?oo00@00000003oo`00000000001`00ool00`0000000?oo003oo`03003oo`03
00000000ool00?oo00@00?oo00<00000003oo`00ool01@00ool00`0000000?oo0000000A003oo`80
00005`00ool00`0000000?oo003oo`0V003oo`0300000000ool00?oo01000?oo0@3oool001400?oo
00<00000003oo`00ool09P00ool00`0000000?oo003oo`0B003oo`<000000P00ool00`0000000?oo
003oo`0?003oo`0300000000ool00?oo00L00?oo00<00000003oo`00ool00`00ool00`0000000?oo
003oo`04003oo`0300000000ool00?oo00H00?oo0P00000@003oo`0300000000ool00?oo00@00000
4`00ool00`0000000?oo003oo`0V003oo`0300000000ool00?oo01000?oo0@3oool001400?oo00<0
0000003oo`00ool09P00ool00`0000000?oo003oo`0?003oo`<000001@00ool00`0000000?oo003o
o`0>003oo`0300000000ool0000000L00?oo00<00000003oo`00ool01000ool00`0000000?oo003o
o`05003oo`0300000000ool00?oo00D00?oo0P00000@003oo`0300000000ool00?oo00@00?oo0`00
000@003oo`0300000000ool00?oo02H00?oo00<00000003oo`00ool04000ool10?ooo`004@00ool0
0`0000000?oo003oo`0W003oo`0300000000ool00?oo00`00?oo0P000009003oo`0300000000ool0
0?oo00`00?oo00D00000003oo`00ool00?oo00000006003oo`0300000000ool00?oo00@00?oo00<0
0000003oo`00ool01@00ool00`0000000?oo003oo`04003oo`0400000000ool00?oo000000h00?oo
00<00000003oo`00ool02000ool2000000h00?oo00<00000003oo`00ool09P00ool00`0000000?oo
003oo`0@003oo`40oooo000A003oo`0300000000ool00?oo02L00?oo00<00000003oo`00ool02P00
ool2000000`00?oo00<00000003oo`00ool02P00ool00`0000000?oo003oo`03003oo`8000001000
ool00`0000000?oo003oo`04003oo`0300000000ool00?oo00D00?oo00<00000003oo`00ool00P00
ool2000000@00?oo00<00000003oo`00ool02`00ool00`0000000?oo003oo`0:003oo`8000002`00
ool00`0000000?oo003oo`0W003oo`0300000000ool00?oo01000?oo0@3oool001800?oo00<00000
003oo`00ool09P00ool00`0000000?oo003oo`07003oo`<000003P00ool00`0000000?oo003oo`09
003oo`0300000000ool00?oo00H00?oo00@00000003oo`00ool000001`00ool00`0000000?oo003o
o`06003oo`0400000000ool00000000000L00?oo00<00000003oo`00ool02@00ool00`0000000?oo
003oo`0=003oo`<000002000ool00`0000000?oo003oo`0W003oo`0300000000ool00?oo01000?oo
0@3oool001800?oo00<00000003oo`00ool09P00ool00`0000000?oo003oo`05003oo`8000004P00
ool00`0000000?oo003oo`07003oo`0300000000ool00?oo00P00?oo0`000007003oo`0300000000
ool00?oo00H00?oo0P00000:003oo`0300000000ool00?oo00L00?oo00<00000003oo`00ool04@00
ool2000000H00?oo00<00000003oo`00ool09`00ool00`0000000?oo003oo`0@003oo`40oooo000B
003oo`0300000000ool00?oo02L00?oo00<00000003oo`00ool00P00ool2000001@00?oo00<00000
003oo`00ool01`00ool00`0000000?oo003oo`09003oo`@000001@00ool00`0000000?oo003oo`03
003oo`@000003000ool00`0000000?oo003oo`06003oo`0300000000ool00?oo01<00?oo0P000003
003oo`0300000000ool00?oo02L00?oo00<00000003oo`00ool04@00ool10?ooo`004P00ool00`00
00000?oo003oo`0W003oo`0300000000ool00?oo008000005`00ool00`0000000?oo003oo`05003o
o`0300000000ool00?oo00X00?oo00@00000003oo`00ool00?oo2`000004003oo`0300000000ool0
0?oo00X00?oo00<00000003oo`00ool01000ool00`0000000?oo003oo`0F003oo`80000000<00?oo
00000000ool0:000ool00`0000000?oo003oo`0A003oo`40oooo000C003oo`0300000000ool00?oo
02H00?oo0`00000J003oo`0300000000ool00?oo00<00?oo00<00000003oo`00ool02P00ool00`00
00000?oo003oo`07003oo`0300000000ool00?oo00L00?oo00<00000003oo`00ool02`00ool00`00
00000?oo003oo`02003oo`0300000000ool00?oo01T00?oo0`00000X003oo`0300000000ool00?oo
01400?oo0@3oool001<00?oo00<00000003oo`00ool09000ool200000003003oo`0000000?oo01/0
0?oo00D00000003oo`00ool00?oo0000000=003oo`0300000000ool00?oo00L00?oo00<00000003o
o`00ool02000ool00`0000000?oo003oo`0;003oo`0400000000ool00?oo000001`00?oo00<00000
003oo`00ool00P00000V003oo`0300000000ool00?oo01400?oo0@3oool001<00?oo00<00000003o
o`00ool08@00ool3000000@00?oo00<00000003oo`00ool06P00ool00`0000000?oo0000000>003o
o`0300000000ool00?oo00L00?oo00<00000003oo`00ool02000ool00`0000000?oo003oo`0<003o
o`0300000000ool0000001`00?oo00<00000003oo`00ool00P00ool3000002800?oo00<00000003o
o`00ool04P00ool10?ooo`005000ool00`0000000?oo003oo`0N003oo`8000001`00ool00`000000
0?oo003oo`0K003oo`0300000000ool00?oo00`00?oo00<00000003oo`00ool02000ool00`000000
0?oo003oo`08003oo`0300000000ool00?oo00d00?oo00<00000003oo`00ool06P00ool00`000000
0?oo003oo`06003oo`8000008000ool00`0000000?oo003oo`0B003oo`40oooo000D003oo`030000
0000ool00?oo01/00?oo0`00000:003oo`0300000000ool00?oo01T00?oo00<00000003oo`000000
3@00ool00`0000000?oo003oo`08003oo`0300000000ool00?oo00T00?oo00<00000003oo`00ool0
2`00ool00`0000000?oo0000000K003oo`0300000000ool00?oo00P00?oo0`00000M003oo`030000
0000ool00?oo01800?oo0@3oool001@00?oo00<00000003oo`00ool06@00ool2000000d00?oo00<0
0000003oo`00ool06000ool01@0000000?oo003oo`00ool0000000/00?oo00<00000003oo`00ool0
2@00ool00`0000000?oo003oo`09003oo`0300000000ool00?oo00T00?oo0P000003003oo`030000
0000ool00?oo01L00?oo00<00000003oo`00ool03000ool2000001X00?oo00<00000003oo`00ool0
4`00ool10?ooo`005@00ool00`0000000?oo003oo`0F003oo`8000004000ool00`0000000?oo003o
o`0F003oo`0300000000ool00?oo00<00?oo00<00000003oo`00ool02000ool00`0000000?oo003o
o`09003oo`0300000000ool00?oo00T00?oo00<00000003oo`00ool02000ool00`0000000?oo003o
o`04003oo`0300000000ool00?oo01H00?oo00<00000003oo`00ool03P00ool2000001P00?oo00<0
0000003oo`00ool04`00ool10?ooo`005@00ool00`0000000?oo003oo`0D003oo`8000004`00ool0
0`0000000?oo003oo`0D003oo`0300000000ool00?oo00D00?oo00<00000003oo`00ool01`00ool0
0`0000000?oo003oo`09003oo`0300000000ool00?oo00X00?oo00<00000003oo`00ool01P00ool0
0`0000000?oo003oo`06003oo`0300000000ool00?oo01@00?oo00<00000003oo`00ool04@00ool2
000001H00?oo00<00000003oo`00ool04`00ool10?ooo`005@00ool00`0000000?oo003oo`0B003o
o`8000005@00ool00`0000000?oo003oo`0C003oo`0300000000ool00?oo00L00?oo0P000006003o
o`0300000000ool00?oo00X00?oo00<00000003oo`00ool02P00ool00`0000000?oo003oo`04003o
o`8000002P00ool00`0000000?oo003oo`0C003oo`0300000000ool00?oo01<00?oo0P00000C003o
o`0300000000ool00?oo01@00?oo0@3oool001H00?oo00<00000003oo`00ool03`00ool2000001P0
0?oo00<00000003oo`00ool04@00ool00`0000000?oo003oo`0:003oo`0300000000ool00?oo00<0
0?oo00<00000003oo`00ool02P00ool00`0000000?oo003oo`0;003oo`0300000000ool00?oo0080
0?oo00<00000003oo`00ool02`00ool00`0000000?oo003oo`0A003oo`0300000000ool00?oo01H0
0?oo0P00000A003oo`0300000000ool00?oo01@00?oo0@3oool001H00?oo00<00000003oo`00ool0
3000ool3000001X00?oo00<00000003oo`00ool04000ool00`0000000?oo003oo`0<003oo`800000
0P00ool00`0000000?oo003oo`0;003oo`0300000000ool00?oo00/00?oo00<00000003oo`000000
0P00000?003oo`0300000000ool00?oo00l00?oo00<00000003oo`00ool06@00ool3000000h00?oo
00<00000003oo`00ool05000ool10?ooo`005P00ool00`0000000?oo003oo`0:003oo`8000007P00
ool00`0000000?oo003oo`0=003oo`8000004@00ool3000000d00?oo00<00000003oo`00ool02`00
ool2000001<00?oo00<00000003oo`00ool03@00ool00`0000000?oo003oo`0M003oo`8000002`00
ool00`0000000?oo003oo`0E003oo`40oooo000F003oo`0300000000ool00?oo00L00?oo0`00000P
003oo`0300000000ool00?oo00`00?oo00<00000003oo`00ool04`00ool5000000T00?oo00<00000
003oo`00ool02@00ool200000003003oo`0000000?oo01<00?oo00<00000003oo`00ool03000ool0
0`0000000?oo003oo`0O003oo`<000002000ool00`0000000?oo003oo`0E003oo`40oooo000G003o
o`0300000000ool00?oo00@00?oo0P00000T003oo`0300000000ool00?oo00X00?oo00<00000003o
o`00ool04`00ool00`0000000?oo003oo`03003oo`@000001@00ool00`0000000?oo003oo`04003o
o`D000001000ool00`0000000?oo003oo`0B003oo`0300000000ool00?oo00X00?oo00<00000003o
o`00ool08`00ool2000000H00?oo00<00000003oo`00ool05@00ool10?ooo`005`00ool010000000
0?oo003oo`00ool3000002L00?oo00<00000003oo`00ool02000ool00`0000000?oo003oo`0D003o
o`0300000000ool00?oo00L00?oo30000009003oo`0300000000ool00?oo01<00?oo00<00000003o
o`00ool02000ool00`0000000?oo003oo`0V003oo`<000000`00ool00`0000000?oo003oo`0E003o
o`40oooo000G003oo`0400000000ool00000000002/00?oo00<00000003oo`00ool01P00ool00`00
00000?oo003oo`0D003oo`0300000000ool00?oo00d00?oo00<00000003oo`00ool03@00ool00`00
00000?oo003oo`0D003oo`0300000000ool00?oo00H00?oo00<00000003oo`00ool0:P00ool30000
01P00?oo0@3oool001H00?oo0`00000^003oo`0300000000ool00?oo00@00?oo00<00000003oo`00
ool05@00ool00`0000000?oo003oo`0=003oo`0300000000ool00?oo00d00?oo00<00000003oo`00
ool05@00ool00`0000000?oo003oo`05003oo`0300000000ool00?oo02`00?oo0`00000F003oo`40
oooo000D003oo`8000000P00ool00`0000000?oo003oo`0]003oo`0300000000ool00?oo00800?oo
00<00000003oo`00ool05@00ool00`0000000?oo003oo`0>003oo`0300000000ool00?oo00h00?oo
00<00000003oo`00ool05@00ool00`0000000?oo003oo`03003oo`0300000000ool00?oo02`00?oo
00@00000003oo`00ool00?oo0P00000D003oo`40oooo000A003oo`<000001@00ool00`0000000?oo
003oo`0]003oo`0400000000ool00?oo000001P00?oo00<00000003oo`00ool03P00ool00`000000
0?oo003oo`0>003oo`0300000000ool00?oo01H00?oo00D00000003oo`00ool00?oo0000000_003o
o`0300000000ool00?oo00<00?oo0P00000B003oo`40oooo000?003oo`8000002000ool00`000000
0?oo003oo`0^003oo`8000006@00ool00`0000000?oo003oo`0>003oo`0300000000ool00?oo00h0
0?oo00<00000003oo`00ool05`00ool00`0000000?oo0000000_003oo`0300000000ool00?oo00H0
0?oo0P00000@003oo`40oooo000=003oo`8000002`00ool00`0000000?oo003oo`0]003oo`800000
6000ool00`0000000?oo003oo`06003oo`@000001@00ool00`0000000?oo003oo`0?003oo`030000
0000ool00?oo01L00?oo0P00000_003oo`0300000000ool00?oo00P00?oo0`00000=003oo`40oooo
000:003oo`<000003@00ool00`0000000?oo003oo`0/003oo`0400000000ool00?oo000001L00?oo
00<00000003oo`00ool01P00ool00`0000000?oo003oo`06003oo`0300000000ool00?oo00l00?oo
00<00000003oo`00ool05`00ool2000002h00?oo00<00000003oo`00ool03000ool2000000/00?oo
0@3oool000P00?oo0P00000A003oo`0300000000ool00?oo02X00?oo00<00000003oo`00ool00P00
ool00`0000000?oo003oo`0C003oo`0300000000ool00?oo00P00?oo00<00000003oo`00ool01@00
ool00`0000000?oo003oo`0@003oo`0300000000ool00?oo01@00?oo0P000002003oo`0300000000
ool00?oo02/00?oo00<00000003oo`00ool03P00ool2000000T00?oo0@3oool000D00?oo0`00000C
003oo`0300000000ool00?oo02T00?oo00<00000003oo`00ool01000ool00`0000000?oo003oo`0B
003oo`0300000000ool00?oo00T00?oo00<00000003oo`00ool01000ool00`0000000?oo003oo`0@
003oo`0300000000ool00?oo01<00?oo00<00000003oo`00ool00`00ool00`0000000?oo003oo`0Y
003oo`0300000000ool00?oo01400?oo0`000006003oo`40oooo0002003oo`<000005`00ool00`00
00000?oo003oo`0W003oo`0300000000ool00?oo00H00?oo00<00000003oo`00ool04000ool00`00
00000?oo003oo`08003oo`0400000000ool00?oo000000D00?oo00<00000003oo`00ool04@00ool0
0`0000000?oo003oo`0A003oo`0300000000ool00?oo00D00?oo00<00000003oo`00ool0:000ool0
0`0000000?oo003oo`0D003oo`8000001000ool10?ooo`000P00000J003oo`0300000000ool00?oo
02H00?oo00<00000003oo`00ool02000ool00`0000000?oo003oo`0?003oo`0300000000ool00?oo
00T00?oo0P000006003oo`0300000000ool00?oo01400?oo00<00000003oo`00ool03`00ool20000
00T00?oo00<00000003oo`00ool09P00ool00`0000000?oo003oo`0G003oo`<000000@00ool10?oo
o`007@00ool00`0000000?oo003oo`0T003oo`0300000000ool00?oo00X00?oo00<00000003oo`00
ool03P00ool00`0000000?oo003oo`0A003oo`0300000000ool00?oo01400?oo00<00000003oo`00
ool03P00ool00`0000000?oo003oo`0:003oo`0300000000ool00?oo02D00?oo00<00000003oo`00
ool06P00ool2000000007@00ool00`0000000?oo003oo`0S003oo`0300000000ool00?oo00`00?oo
00<00000003oo`00ool03000ool00`0000000?oo003oo`0B003oo`0300000000ool00?oo01800?oo
00<00000003oo`00ool02`00ool2000000h00?oo00<00000003oo`00ool08`00ool00`0000000?oo
003oo`0L003oo`40oooo000N003oo`0300000000ool00?oo02400?oo00<00000003oo`00ool03P00
ool2000000`00?oo00<00000003oo`00ool04P00ool00`0000000?oo003oo`0B003oo`0300000000
ool00?oo00X00?oo00<00000003oo`00ool03`00ool00`0000000?oo003oo`0R003oo`0300000000
ool00?oo01`00?oo0@3oool001l00?oo00<00000003oo`00ool07`00ool00`0000000?oo003oo`0A
003oo`0300000000ool00?oo00P00?oo00<00000003oo`00ool04`00ool00`0000000?oo003oo`0C
003oo`0300000000ool00?oo00L00?oo0P00000C003oo`0300000000ool00?oo02000?oo00<00000
003oo`00ool07@00ool10?ooo`007`00ool00`0000000?oo003oo`0N003oo`0300000000ool00?oo
01<00?oo0P000008003oo`0300000000ool00?oo01<00?oo00<00000003oo`00ool04`00ool00`00
00000?oo003oo`06003oo`0300000000ool00?oo01@00?oo00<00000003oo`00ool07`00ool00`00
00000?oo003oo`0M003oo`40oooo000P003oo`0300000000ool00?oo01`00?oo00<00000003oo`00
ool05P00ool2000000D00?oo00<00000003oo`00ool05000ool00`0000000?oo003oo`0D003oo`03
00000000ool00?oo00<00?oo0P00000H003oo`0300000000ool00?oo01d00?oo00<00000003oo`00
ool07P00ool10?ooo`008@00ool00`0000000?oo003oo`0J003oo`0300000000ool00?oo01T00?oo
0P000003003oo`0300000000ool00?oo01@00?oo00<00000003oo`00ool05000ool0100000000?oo
003oo`00ool2000001/00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0O003oo`40
oooo000Q003oo`0300000000ool00?oo01T00?oo00<00000003oo`00ool07000ool3000001L00?oo
00<00000003oo`00ool05@00ool3000001h00?oo00<00000003oo`00ool06@00ool00`0000000?oo
003oo`0P003oo`40oooo000R003oo`0300000000ool00?oo01P00?oo00<00000003oo`00ool07P00
ool2000001H00?oo00<00000003oo`00ool04`00ool3000002400?oo00<00000003oo`00ool06000
ool00`0000000?oo003oo`0P003oo`40oooo000S003oo`0300000000ool00?oo01H00?oo00<00000
003oo`00ool07`00ool00`0000000?oo00000002000001<00?oo00<00000003oo`00ool03`00ool4
000000800?oo00<00000003oo`00ool08000ool00`0000000?oo003oo`0F003oo`0300000000ool0
0?oo02400?oo0@3oool002<00?oo00<00000003oo`00ool05@00ool00`0000000?oo003oo`0O003o
o`0300000000ool00?oo00<00?oo1000000?003oo`0300000000ool00?oo00`00?oo0`000007003o
o`0300000000ool00?oo02000?oo00<00000003oo`00ool05000ool00`0000000?oo003oo`0R003o
o`40oooo000T003oo`0300000000ool00?oo01<00?oo00<00000003oo`00ool08000ool00`000000
0?oo003oo`07003oo`H000002@00ool00`0000000?oo003oo`08003oo`@000002P00ool00`000000
0?oo003oo`0Q003oo`0300000000ool00?oo01800?oo00<00000003oo`00ool08`00ool10?ooo`00
9@00ool00`0000000?oo003oo`0A003oo`0300000000ool00?oo02000?oo00<00000003oo`00ool0
3P00oolD000000l00?oo00<00000003oo`00ool08@00ool00`0000000?oo003oo`0A003oo`030000
0000ool00?oo02<00?oo0@3oool002H00?oo00<00000003oo`00ool03`00ool00`0000000?oo003o
o`0Q003oo`0300000000ool00?oo01L00?oo00<00000003oo`00ool05`00ool00`0000000?oo003o
o`0R003oo`0300000000ool00?oo00l00?oo00<00000003oo`00ool09000ool10?ooo`009`00ool0
0`0000000?oo003oo`0=003oo`0300000000ool00?oo02800?oo00<00000003oo`00ool05`00ool0
0`0000000?oo003oo`0G003oo`0300000000ool00?oo02<00?oo00<00000003oo`00ool03@00ool0
0`0000000?oo003oo`0U003oo`40oooo000X003oo`0300000000ool00?oo00/00?oo00<00000003o
o`00ool08P00ool00`0000000?oo003oo`0H003oo`0300000000ool00?oo01P00?oo00<00000003o
o`00ool08`00ool00`0000000?oo003oo`0;003oo`0300000000ool00?oo02H00?oo0@3oool002P0
0?oo00<00000003oo`00ool02P00ool00`0000000?oo003oo`0S003oo`0300000000ool00?oo01P0
0?oo00<00000003oo`00ool06000ool00`0000000?oo003oo`0T003oo`0300000000ool00?oo00X0
0?oo00<00000003oo`00ool09P00ool10?ooo`00:@00ool00`0000000?oo003oo`08003oo`030000
0000ool00?oo02<00?oo00<00000003oo`00ool06@00ool00`0000000?oo003oo`0I003oo`030000
0000ool00?oo02@00?oo00<00000003oo`00ool02000ool00`0000000?oo003oo`0W003oo`40oooo
000Z003oo`0300000000ool00?oo00D00?oo0P00000V003oo`0300000000ool00?oo01T00?oo00<0
0000003oo`00ool06@00ool00`0000000?oo003oo`0U003oo`0300000000ool00?oo00H00?oo00<0
0000003oo`00ool0:000ool10?ooo`00:`00ool00`0000000?oo003oo`03003oo`0300000000ool0
0?oo02H00?oo00<00000003oo`00ool06@00ool00`0000000?oo003oo`0I003oo`0300000000ool0
0?oo02H00?oo00<00000003oo`00ool01000ool00`0000000?oo003oo`0Y003oo`40oooo000/003o
o`0500000000ool00?oo003oo`000000:000ool00`0000000?oo003oo`0J003oo`0300000000ool0
0?oo01X00?oo00<00000003oo`00ool09P00ool00`0000000?oo003oo`02003oo`0300000000ool0
0?oo02X00?oo0@3oool002d00?oo00<00000003oo`000000:@00ool00`0000000?oo003oo`0J003o
o`0300000000ool00?oo01X00?oo00<00000003oo`00ool09`00ool0100000000?oo003oo`00000]
003oo`40oooo000^003oo`0300000000ool00?oo02L00?oo00<00000003oo`00ool06`00ool00`00
00000?oo003oo`0K003oo`0300000000ool00?oo02L00?oo00<00000003oo`000000;@00ool10?oo
o`00;@00ool00`0000000?oo0000000X003oo`0300000000ool00?oo01/00?oo00<00000003oo`00
ool06`00ool00`0000000?oo003oo`0X003oo`0300000000ool00?oo02`00?oo0@3oool002`00?oo
00D00000003oo`00ool00?oo0000000W003oo`0300000000ool00?oo01/00?oo00<00000003oo`00
ool07000ool00`0000000?oo003oo`0V003oo`0300000000ool0000002d00?oo0@3oool002/00?oo
00<00000003oo`00ool00`00ool00`0000000?oo003oo`0S003oo`0300000000ool00?oo01`00?oo
00<00000003oo`00ool07000ool00`0000000?oo003oo`0T003oo`8000000`00ool00`0000000?oo
003oo`0Z003oo`40oooo000Z003oo`0300000000ool00?oo00D00?oo00<00000003oo`00ool08P00
ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo01d00?oo00<00000003oo`00ool08P00
ool00`0000000?oo003oo`04003oo`0300000000ool00?oo02T00?oo0@3oool002T00?oo00<00000
003oo`00ool01`00ool00`0000000?oo003oo`0Q003oo`0300000000ool00?oo01`00?oo00<00000
003oo`00ool07@00ool00`0000000?oo003oo`0Q003oo`0300000000ool00?oo00H00?oo00<00000
003oo`00ool0:000ool10?ooo`00:000ool00`0000000?oo003oo`09003oo`0300000000ool00?oo
01l00?oo00<00000003oo`00ool07@00ool00`0000000?oo003oo`0N003oo`0300000000ool00?oo
01h00?oo0P00000:003oo`0300000000ool00?oo02L00?oo0@3oool002L00?oo00<00000003oo`00
ool02`00ool00`0000000?oo003oo`0N003oo`0300000000ool00?oo01d00?oo00<00000003oo`00
ool07P00ool00`0000000?oo003oo`0M003oo`0300000000ool00?oo00/00?oo00<00000003oo`00
ool09P00ool10?ooo`009P00ool00`0000000?oo003oo`0=003oo`0300000000ool00?oo01`00?oo
00<00000003oo`00ool07P00ool00`0000000?oo003oo`0O003oo`0300000000ool00?oo01/00?oo
00<00000003oo`00ool03@00ool00`0000000?oo003oo`0U003oo`40oooo000U003oo`0300000000
ool00?oo00l00?oo0P00000L003oo`0300000000ool00?oo01h00?oo00<00000003oo`00ool07`00
ool00`0000000?oo003oo`0I003oo`8000004@00ool00`0000000?oo003oo`0T003oo`40oooo000T
003oo`0300000000ool00?oo01800?oo00<00000003oo`00ool06@00ool00`0000000?oo003oo`0N
003oo`0300000000ool00?oo01l00?oo00<00000003oo`00ool06000ool00`0000000?oo003oo`0B
003oo`0300000000ool00?oo02<00?oo0@3oool002<00?oo00<00000003oo`00ool05000ool20000
01P00?oo00<00000003oo`00ool07`00ool00`0000000?oo003oo`0P003oo`0300000000ool00?oo
01D00?oo0P00000F003oo`0300000000ool00?oo02800?oo0@3oool002800?oo00<00000003oo`00
ool05`00ool00`0000000?oo003oo`0E003oo`0300000000ool00?oo01l00?oo00<00000003oo`00
ool08000ool00`0000000?oo003oo`0D003oo`0300000000ool00?oo01L00?oo00<00000003oo`00
ool08@00ool10?ooo`008@00ool00`0000000?oo003oo`0I003oo`8000005000ool00`0000000?oo
003oo`0P003oo`0300000000ool00?oo02400?oo00<00000003oo`00ool04P00ool00`0000000?oo
003oo`0I003oo`0300000000ool00?oo02000?oo0@3oool002000?oo00<00000003oo`00ool07000
ool00`0000000?oo003oo`0A003oo`0300000000ool00?oo02000?oo00<00000003oo`00ool08@00
ool00`0000000?oo003oo`0@003oo`8000007@00ool00`0000000?oo003oo`0O003oo`40oooo000O
003oo`0300000000ool00?oo01h00?oo0P00000A003oo`0300000000ool00?oo02000?oo00<00000
003oo`00ool08@00ool00`0000000?oo003oo`0?003oo`0300000000ool00?oo01h00?oo00<00000
003oo`00ool07P00ool10?ooo`007P00ool00`0000000?oo003oo`0Q003oo`0300000000ool00?oo
00d00?oo00<00000003oo`00ool08@00ool00`0000000?oo003oo`0R003oo`0300000000ool00?oo
00`00?oo0P00000R003oo`0300000000ool00?oo01d00?oo0@3oool001d00?oo00<00000003oo`00
ool08`00ool2000000d00?oo00<00000003oo`00ool08@00ool00`0000000?oo003oo`0R003oo`03
00000000ool00?oo00/00?oo00<00000003oo`00ool08`00ool00`0000000?oo003oo`0L003oo`40
oooo000L003oo`0300000000ool00?oo02H00?oo0P00000:003oo`0300000000ool00?oo01/00?oo
0`000004003oo`0300000000ool00?oo02<00?oo00<00000003oo`00ool02000ool2000002L00?oo
00<00000003oo`00ool06`00ool10?ooo`006`00ool00`0000000?oo003oo`0Y003oo`8000002000
ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo00<00?oo00<00000003oo`00ool08`00
ool00`0000000?oo003oo`06003oo`800000:P00ool00`0000000?oo003oo`0J003oo`40oooo000J
003oo`0300000000ool00?oo02`00?oo0P000006003oo`0300000000ool00?oo01T00?oo1@000004
003oo`0300000000ool00?oo02<00?oo00<00000003oo`00ool00`00ool3000002d00?oo00<00000
003oo`00ool06@00ool10?ooo`006@00ool00`0000000?oo003oo`0_003oo`8000000`00ool00`00
00000?oo003oo`0J003oo`0400000000ool00?oo000000D00?oo00<00000003oo`00ool09000ool0
0`0000000?oo003oo`02000003400?oo00<00000003oo`00ool06000ool10?ooo`006000ool00`00
00000?oo003oo`0b003oo`80000000<00?oo00000000ool07000ool00`0000000?oo00000005003o
o`0300000000ool00?oo02@00?oo0`00000d003oo`0300000000ool00?oo01L00?oo0@3oool001L0
0?oo00<00000003oo`00ool0=@00ool2000001h00?oo0P000005003oo`0300000000ool00?oo02<0
0?oo0`00000f003oo`0300000000ool00?oo01H00?oo0@3oool001H00?oo00<00000003oo`00ool0
=P00ool0100000000?oo00000000000S003oo`0300000000ool00?oo02400?oo0P000002003oo`03
00000000ool00?oo03D00?oo00<00000003oo`00ool05@00ool10?ooo`005@00ool00`0000000?oo
003oo`0g003oo`0400000000ool00?oo003oo`<000008000ool00`0000000?oo003oo`0O003oo`80
00001000ool00`0000000?oo003oo`0f003oo`0300000000ool00?oo01@00?oo0@3oool001@00?oo
00<00000003oo`00ool0=`00ool00`0000000?oo003oo`05003oo`<000007@00ool00`0000000?oo
003oo`0J003oo`D000001`00ool00`0000000?oo003oo`0f003oo`0300000000ool00?oo01<00?oo
0@3oool001<00?oo00<00000003oo`00ool0>000ool00`0000000?oo003oo`08003oo`D000006000
ool00`0000000?oo003oo`0E003oo`D000003000ool00`0000000?oo003oo`0g003oo`0300000000
ool00?oo01800?oo0@3oool001800?oo00<00000003oo`00ool0>000ool00`0000000?oo003oo`0>
003oo`D000004`00ool00`0000000?oo003oo`0B003oo`<000004P00ool00`0000000?oo003oo`0g
003oo`0300000000ool00?oo01400?oo0@3oool001400?oo00<00000003oo`00ool0>@00ool00`00
00000?oo003oo`0C003oo`<000004000ool00`0000000?oo003oo`0?003oo`<000005@00ool00`00
00000?oo003oo`0h003oo`0300000000ool00?oo01000?oo0@3oool001000?oo00<00000003oo`00
ool0>@00ool00`0000000?oo003oo`0G003oo`/000001@00ool00`0000000?oo003oo`04003oo`/0
00006@00ool00`0000000?oo003oo`0h003oo`0300000000ool00?oo00l00?oo0@3oool000l00?oo
00<00000003oo`00ool0>P00ool00`0000000?oo003oo`0R003oo``000009000ool00`0000000?oo
003oo`0i003oo`0300000000ool00?oo00h00?oo0@3oool000h00?oo00<00000003oo`00ool0>P00
ool00`0000000?oo003oo`0X003oo`0300000000ool00?oo02P00?oo00<00000003oo`00ool0>P00
ool00`0000000?oo003oo`0=003oo`40oooo000=003oo`0300000000ool00?oo03/00?oo00<00000
003oo`00ool0:000ool00`0000000?oo003oo`0Y003oo`0300000000ool00?oo03X00?oo00<00000
003oo`00ool03000ool10?ooo`003000ool00`0000000?oo003oo`0l003oo`0300000000ool00?oo
02P00?oo00<00000003oo`00ool0:@00ool00`0000000?oo003oo`0k003oo`0300000000ool00?oo
00/00?oo0@3oool000/00?oo00<00000003oo`00ool0?000ool00`0000000?oo003oo`0Y003oo`03
00000000ool00?oo02X00?oo00<00000003oo`00ool0>`00ool00`0000000?oo003oo`0:003oo`40
oooo000:003oo`0300000000ool00?oo03d00?oo00<00000003oo`00ool0:@00ool00`0000000?oo
003oo`0Z003oo`0300000000ool00?oo03`00?oo00<00000003oo`00ool02@00ool10?ooo`002@00
ool00`0000000?oo003oo`0m003oo`0300000000ool00?oo02X00?oo00<00000003oo`00ool0:`00
ool00`0000000?oo003oo`0l003oo`0300000000ool00?oo00P00?oo0@3oool000P00?oo00<00000
003oo`00ool0?P00ool00`0000000?oo003oo`0Z003oo`0300000000ool00?oo02/00?oo00<00000
003oo`00ool0?@00ool00`0000000?oo003oo`07003oo`40oooo0008003oo`0300000000ool00?oo
03d00?oo00<00000003oo`00ool0:@00ool5000000<00?oo0P00000W003oo`0300000000ool00?oo
03d00?oo0P000007003oo`40oooo0007003oo`0300000000ool00?oo03h00?oo00<00000003oo`00
ool0:@00ool5000000@00?oo00<00000003oo`00ool09@00ool00`0000000?oo003oo`0o003oo`03
00000000ool00?oo00@00?oo0@3oool000H00?oo00<00000003oo`00ool0?`00ool00`0000000?oo
003oo`0Y003oo`@000001P00ool00`0000000?oo003oo`0T003oo`0300000000ool00?oo04000?oo
00<00000003oo`00ool00`00ool10?ooo`001@00ool00`0000000?oo003oo`0o003oo`0300000000
ool00?oo02/00?oo0`000005003oo`0300000000ool0000002H00?oo00<00000003oo`00ool0@000
ool00`0000000?oo003oo`02003oo`40oooo0004003oo`0300000000ool00?oo04000?oo00<00000
003oo`00ool0:`00ool3000000@00?oo00@00000003oo`00ool000009P00ool00`0000000?oo003o
o`11003oo`0400000000ool00?oo003oo`40oooo0003003oo`0300000000ool00?oo04000?oo00<0
0000003oo`00ool0;000ool3000000<00?oo0`0000000`00ool000000000000V003oo`0300000000
ool00?oo04400?oo00<00000003oo`00ool00@3oool000800?oo00<00000003oo`00ool0@@00ool0
0`0000000?oo003oo`0/003oo`800000<000ool00`0000000?oo003oo`12003oo`4000000@00ool1
0?ooo`0000<00?oo00000000ool0@P00ool00`0000000?oo003oo`0^003oo`0300000000ool00?oo
02l00?oo00<00000003oo`00ool0@P00ool100000040oooo00000`0000000?oo003oo`12003oo`03
00000000ool00?oo02h00?oo00<00000003oo`00ool0;`00ool00`0000000?oo003oo`13003oo`40
00000000\
\>"],
    ImageRangeCache->{{{0, 238}, {238, 0}} -> {-5, -5, 0, 0}}],
  StyleBox["  \nFigure 5.1",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The points ",
  Cell[BoxData[
      \({z\_n}\)]],
  " in the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane (i.e., the ",
  StyleBox["xy",
    FontFamily->"Courier New"],
  " plane) and their image  ",
  Cell[BoxData[
      \(w\_0\  = \ exp \((z\_n)\)\)]],
  " in the w plane (i.e., the ",
  StyleBox["uv",
    FontFamily->"Courier New"],
  " plane)."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the formula for the points.", "Text"],

Cell[BoxData[{
    \(\(Clear[e, n, z, w];\)\ \ \), "\n", 
    \(\(z\_0\  = \ 
        5\/4\  + \(\(\ \)\(\[ImaginaryI]\ 11\ \[Pi]\)\)\/6;\)\ \ \), "\n", 
    \(\(z\_n_\  = \ z\_0\  + \ \[ImaginaryI]\ 2  \[Pi]\ n;\)\ \ \ \), "\n", 
    \(\(w = \[ExponentialE]\^z\_n;\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_n\) = \>\"", z\_n];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<w = \!\(e\^z\_n\)\>\""];\)\ \ \), "\[IndentingNewLine]", \

    \(\(Print["\<w = \>", w];\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\  = \ ComplexExpand[w]\ ;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = \>", w];\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\  = \ 
        Simplify[w, Element[n, Integers]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = \>", w];\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\  = \ ComplexExpand[w]\ ;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = \>", w];\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\  = \ Simplify[w]\ ;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = \>", w];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Here is another way to look at it.", "Text"],

Cell[BoxData[{
    \(\(Remove[z];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Clear[e, n];\)\ \ \), "\[IndentingNewLine]", 
    \(\(z\_0\  = \ 
        5\/4\  + \(\(\ \)\(\[ImaginaryI]\ 11\ \[Pi]\)\)\/6;\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(z\_n_\  = \ z\_0\  + \ \[ImaginaryI]\ 2  \[Pi]\ n\ ;\)\ \ \), "\n", 
    \(Print[\*"\"\<\!\(z\_0\) = \>\"", z\_0]\), "\[IndentingNewLine]", 
    \(Print[\*"\"\<\!\(z\_n\) = \>\"", z\_n]\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(For[n = 0, 
        n \[LessEqual] 
          5, \(n++\), \[IndentingNewLine]\(Print[
            e\^z\_n, "\< = \>", \[IndentingNewLine]Factor[
              ComplexExpand[\[ExponentialE]\^z\_n]]];\)\ \ \ ];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tLet's look at the range of the exponential function.  If ",
  Cell[BoxData[
      \(z = x\  + \[ImaginaryI]\ y\)]],
  ", we see from identity ",
  StyleBox["(5-1)",
    FontColor->RGBColor[0, 0, 1]],
  " that  ",
  Cell[BoxData[
      \(\[ExponentialE]\^z\)]],
  "  can never equal zero, as  ",
  Cell[BoxData[
      \(\[ExponentialE]\^x\)]],
  "  is never zero, and the cosine and sine functions are never zero at the \
same point.  Suppose, then, that  ",
  Cell[BoxData[
      \(w = \[ExponentialE]\^z \[NotEqual] 0\)]],
  ".  If we write w in its exponential form as  ",
  Cell[BoxData[
      \(w = \[Rho]\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\)\)]],
  ",  identity ",
  StyleBox["(5-1)",
    FontColor->RGBColor[0, 0, 1]],
  " gives \n\t\n\t\t\t",
  Cell[BoxData[
      \(\[Rho]\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\) = \
\(\[ExponentialE]\^\(\(x\)\(\ \)\)\) \[ExponentialE]\^\(\[ImaginaryI]\ \
y\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Using identity ",
  StyleBox["(5-1)",
    FontColor->RGBColor[0, 0, 1]],
  ", and property ",
  StyleBox["(1-39)",
    FontColor->RGBColor[0, 0, 1]],
  " of Section 1.5 we get \n\n\t\t\t",
  Cell[BoxData[
      \(\[Rho] = \[ExponentialE]\^\(\(x\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(\[Phi] = y + 2  n\ \[Pi]\)]],
  ", where n is an integer.\nTherefore,\n\t\t\t",
  Cell[BoxData[
      \(\[Rho] = \(\(\(|\)\(\[ExponentialE]\^\(\(z\)\(\ \)\)\)\(|\)\) = \
\[ExponentialE]\^\(\(x\)\(\ \)\)\)\)]],
  ", \n\t\tand\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(\[Phi] \[Element] 
          arg \((\[ExponentialE]\^\(\(z\)\(\ \)\))\)\), "=", 
        RowBox[{"{", 
          RowBox[{\(Arg \((\[ExponentialE]\^\(\(z\)\(\ \)\))\)\), "+", 
            RowBox[{"2", "n", " ", 
              RowBox[{"\[Pi]", ":", "  ", 
                RowBox[{"n", " ", 
                  StyleBox["is",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["an",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["integer",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]}]}]}], "}"}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\n\tSolving these equations for x and y, yields\n\n\t\t\t",
  Cell[BoxData[
      \(x = ln\ \[Rho]\)]],
  " and  ",
  Cell[BoxData[
      \(y = \[Phi] + 2  n\ \[Pi]\)]],
  ", \n\t\t\t\nwhere ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is an integer. Thus, for any complex number  ",
  Cell[BoxData[
      \(w \[NotEqual] 0\)]],
  ",  there are infinitely many complex numbers ",
  Cell[BoxData[
      \(z = x\  + \[ImaginaryI]\ y\)]],
  " such that  ",
  Cell[BoxData[
      \(w = \[ExponentialE]\^z\)]],
  ".  From the previous equations, we see that the numbers ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " are  \n\n\t\t\t",
  Cell[BoxData[
      \(z = \(x + \[ImaginaryI]\ y = 
          ln\ \[Rho] + \[ImaginaryI] \((\[Phi] + 2  n\ \[Pi])\)\)\)]],
  "  \n\t\tor\n\t\t\t",
  Cell[BoxData[
      \(z = ln\  | w | \(+\[ImaginaryI]\) \((Arg\ w + 2  n\ \[Pi])\)\)]],
  ",  \n\nwhere ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is an integer. Hence \n\n\t\t\t",
  Cell[BoxData[{
      \(exp[
          ln\  | w | \(+\[ImaginaryI]\) \((Arg\ w + 
                  2  n\ \[Pi])\)]\  = \ \ w\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\
\[ExponentialE]\^\(ln\  | 
              w | \(+\[ImaginaryI]\) \((Arg\ w + 
                    2  n\ \[Pi])\)\)\)\(\ \ \)\(=\)\(\ \ \)\(w\)\(\ \
\)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "\n\tIn summary, the transformation ",
  Cell[BoxData[
      \(w = \[ExponentialE]\^z\)]],
  " maps the complex plane (infinitely often) onto the set of nonzero complex \
numbers.\n\t\n\tIf we restrict the solutions in equation ",
  StyleBox["(5-9)",
    FontColor->RGBColor[0, 0, 1]],
  " so that only the principal value of the argument,  ",
  Cell[BoxData[
      \(\(-\[Pi]\) < Arg\ w \[LessEqual] \[Pi]\)]],
  ",  is used, the transformation  ",
  Cell[BoxData[
      \(w = \(\[ExponentialE]\^z = \[ExponentialE]\^\(x\  + \(\(\[ImaginaryI]\
\)\(\ \)\(y\)\(\ \)\)\)\)\)]],
  " maps the horizontal strip  ",
  Cell[BoxData[
      \({\((x, y)\) : \ \(-\[Pi]\) < \ y \[LessEqual] \[Pi]}\)]],
  ",  one-to-one and onto the range set  ",
  Cell[BoxData[
      \(S = {w : \ w \[NotEqual] 0}\)]],
  ".  This strip is called the fundamental period strip and is shown in \
Figure 5.2."
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.489796 0.408163 0.302624 0.0852461 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30262 m
1 .30262 L
s
.4898 0 m
.4898 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
0 .30262 m
.16165 .30262 L
.48595 .30262 L
.83127 .30262 L
s
.83127 .30262 m
1 .30262 L
s
.941 1 .941 r
0 .03482 m
.97959 .03482 L
.97959 .57043 L
0 .57043 L
0 .03482 L
F
0 g
.97959 .30262 m
1 .30262 L
s
% Start of user PostScript
1.2 0 1.25 0 MAarrowhead1
% End of user PostScript
.4898 .60098 m
.4898 .60951 L
s
% Start of user PostScript
0 3.5 0 3.6 MAarrowhead1
% End of user PostScript
0 .30262 m
.97959 .30262 L
s
.4898 .03482 m
.4898 .57043 L
s
1 0 1 r
0 .50348 m
.97959 .50348 L
s
1 0 0 r
0 .36958 m
.97959 .36958 L
s
0 0 1 r
[ .025 .025 ] 0 setdash
0 .07945 m
.97959 .07945 L
s
.56 .37 .6 r
.2449 .03482 m
.2449 .57043 L
s
1 .5 0 r
[ ] 0 setdash
.79592 .03482 m
.79592 .57043 L
s
.5 .165 .165 r
.85714 .03482 m
.85714 .57043 L
s
0 1 0 r
0 .57043 m
.97959 .57043 L
s
[ .025 .025 ] 0 setdash
0 .03482 m
.97959 .03482 L
s
0 g
gsave
.97143 .33672 -66 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5102 .60951 -69 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.44898 .59601 -78 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344p) show
93.000 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.44898 .00924 -78 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344p) show
93.000 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{260, 160.625},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000440000X2000`400?l00000o`00003oK03oool6
000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`230?ooo`00IP3oool40000
00<0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0
oooo08<0oooo001]0?ooo`030000003oool0000000<0oooo00<000000?ooo`000000203oool00`00
0000oooo0?ooo`230?ooo`00K@3oool00`000000oooo000000030?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool0P`3oool006`0oooo100000020?ooo`D000001`3oool00`000000oooo
0?ooo`230?ooo`00OP3oool00`000000oooo0?ooo`230?ooo`00KP3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo08<0oooo001n0?ooo`030000003oool0oooo08<0oooo001n0?ooo`03
0000003oool0oooo08<0oooo0007003o00H0oooo1`00o`060?ooo`L00?l01P3oool7003o00D0oooo
2000o`040?ooo`0308mNV@00o`000?l000H00?l01@3oool8003o00D0oooo2000o`050?ooo`P00?l0
1@3oool7003o00<0oooo00<000000?ooo`3oool01`00o`060?ooo`L00?l01P3oool7003o00H0oooo
1`00o`060?ooo`L00?l01P3oool7003o00@0oooo00<0ogl0003o0000o`001P00o`050?ooo`P00?l0
1@3oool8003o00D0oooo2000o`070?ooo`00?`3`oo000`2?GYT0l?o`0?3ol00l0?3ol0030000003`
oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo000o
0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=
0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool003l0l?o`00<0SejI0?3ol03`oo00?03`oo000`00
0000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?oo
o`00?`3`oo000`2?GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`
oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`
00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`
1`3oool003l0l?o`00<0SejI0?3ol03`oo00?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`
oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00OP3`oo000`000000l?o`0?3ol01<
0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00OP3`oo000`00
0000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?oo
o`00OP3`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`
oo007@3`oo070?ooo`00OP3`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`
00<0ObXZ0?3ol03`oo007@3`oo070?ooo`001`000?l60?3ol0L0003o1P3`oo070000o`H0l?o`1`00
0?l50?3ol0P0003o1@3`oo080000o`D0l?o`20000?l50?3ol0P0003o1@3`oo080000o`D0l?o`1`00
0?l30?3ol0030000003`oo00l?o`00L0003o1P3`oo070000o`H0l?o`1`000?l60?3ol0L0003o1P3`
oo070000o`H0l?o`1`000?l40?3ol0030?mo00000?l0003o00H0003o1@3`oo020000o`0307lZ:P00
0?l0003o00<0003o1@3`oo080000o`D0l?o`20000?l70?ooo`00OP3`oo000`000000l?o`0?3ol01<
0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00?`3`oo000`2?
GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o
:RX0l?o`0?3ol00M0?3ol0L0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`
oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool003l0l?o`
00<0SejI0?3ol03`oo00?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`
00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00?`3`oo000`2?GYT0l?o`0?3ol00l0?3ol0030000003`
oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo000o
0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=
0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool003l0l?o`00<0SejI0?3ol03`oo00?03`oo000`00
0000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?oo
o`00?`3`oo000`2?GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`
oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo001n0?3ol0030000003`oo00l?o`04`0l?o`
00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo001n0?3ol0030000003`
oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo001n
0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M
0?3ol0L0oooo001n0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o
:RX0l?o`0?3ol00M0?3ol0L0oooo001n0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`
oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo001n0?3ol0030000003`oo00l?o`04`0l?o`
00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo000o0?3ol00308mNV@3`
oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`
oo00l?o`01d0l?o`1`3oool003l0l?o`00<0SejI0?3ol03`oo00?03`oo000`000000l?o`0?3ol01<
0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00?`3`oo000`2?
GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o
:RX0l?o`0?3ol00M0?3ol0L0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`
oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool003l0l?o`
00<0SejI0?3ol03`oo00?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`
00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00?`3`oo000`2?GYT0l?o`0?3ol00l0?3ol0030000003`
oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo000o
0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=
0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool007h0l?o`00<000000?3ol03`oo00C03`oo000`3o
O`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool007h0l?o`00<000000?3ol03`
oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool007h0l?o`
00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`
1`3oool007h0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`
oo00l?o`01d0l?o`1`3oool007h0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=
0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool007h0l?o`00<000000?3ol03`oo00C03`oo000`3o
O`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool003l0l?o`00<0SejI0?3ol03`
oo00?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`
oo007@3`oo070?ooo`00?`3`oo000`2?GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`
00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo000o0?3ol00308mNV@3`
oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`
oo00l?o`01d0l?o`1`3oool003l0l?o`00<0SejI0?3ol03`oo00?03`oo000`000000l?o`0?3ol01<
0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00?`3`oo000`2?
GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o
:RX0l?o`0?3ol00M0?3ol0L0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`
oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool003l0l?o`
00<0SejI0?3ol03`oo00?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`
00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00OP3`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`
oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00OP3`oo000`000000l?o`0?3ol01<
0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00OP3`oo000`00
0000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?oo
o`00OP3`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`
oo007@3`oo070?ooo`00OP3`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`
00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00OP3`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`
oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00?`3`oo000`2?GYT0l?o`0?3ol00l
0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M
0?3ol0L0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3o
O`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool003l0l?o`00<0SejI0?3ol03`
oo00?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`
oo007@3`oo070?ooo`00?`3`oo000`2?GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`
00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo000o0?3ol00308mNV@3`
oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`
oo00l?o`01d0l?o`1`3oool003l0l?o`00<0SejI0?3ol03`oo00?03`oo000`000000l?o`0?3ol01<
0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00?`3`oo000`2?
GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o
:RX0l?o`0?3ol00M0?3ol0L0oooo001n0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`
oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo001n0?3ol0030000003`oo00l?o`04`0l?o`
00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo001n0?3ol0030000003`
oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo001n
0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M
0?3ol0L0oooo001n0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o
:RX0l?o`0?3ol00M0?3ol0L0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`
oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool003l0l?o`
00<0SejI0?3ol03`oo00?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`
00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00?`3`oo000`2?GYT0l?o`0?3ol00l0?3ol0030000003`
oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo000o
0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=
0?3ol00307lZ:P3`oo00l?o`01X0l?o`0P0000000`3`oo00oooo0?ooo`050?ooo`00?`3`oo000`2?
GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o
:RX0l?o`0?3ol00J0?3ol0H00000103oool003l0000000<0SejI000000000000R`0000000`3oO`00
00000000000=0000000307lZ:P000000000002<000000@3oool003l0l?o`00<0SejI0?3ol03`oo00
?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo00
6P3`oo07000000<0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`
oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01X0l?o`0`0000070?ooo`00OP3`oo00
0`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo07
0?ooo`00OP3`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3o
l03`oo007@3`oo070?ooo`00OP3`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0
l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00OP3`oo000`000000l?o`0?3ol01<0?3ol0030?mo
003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo00603`oo02000000030?3ol0000000000000L0oooo
001n0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3o
l00I0?3ol0040000003`oo0000000?3ol0L0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`00<0
00000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01X0l?o`00<0
00000?3ol03`oo001`3oool003l0l?o`00<0SejI0?3ol03`oo00?03`oo000`000000l?o`0?3ol01<
0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo00603`oo02000000030?3ol0000000
000000L0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3o
O`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool003l0l?o`00<0SejI0?3ol03`
oo00?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`
oo007@3`oo070?ooo`00?`3`oo000`2?GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`
00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo000o0?3ol00308mNV@3`
oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`
oo00l?o`01d0l?o`1`3oool003l0l?o`00<0SejI0?3ol03`oo00?03`oo000`000000l?o`0?3ol01<
0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00?`3`oo000`2?
GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o
:RX0l?o`0?3ol00M0?3ol0L0oooo001n0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`
oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo003=0?l000030?mo003o0000o`0000d0o`00
00<0ObXZ0?l0003o00007P3o00060?ooo`00OP3`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`
oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00OP3`oo000`000000l?o`0?3ol01<
0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00OP3`oo000`00
0000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?oo
o`00?`3`oo000`2?GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`
oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`
00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`
1`3oool003l0l?o`00<0SejI0?3ol03`oo00?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`
oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00?`3`oo000`2?GYT0l?o`0?3ol00l
0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M
0?3ol0L0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3o
O`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool003l0l?o`00<0SejI0?3ol03`
oo00?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`
oo007@3`oo070?ooo`00?`3`oo000`2?GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`
00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo000o0?3ol00308mNV@3`
oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`
oo00l?o`01d0l?o`1`3oool007h0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=
0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool007h0l?o`00<000000?3ol03`oo00C03`oo000`3o
O`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool007h0l?o`00<000000?3ol03`
oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool007h0l?o`
00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`
1`3oool007h0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`
oo00l?o`01d0l?o`1`3oool003l0l?o`00<0SejI0?3ol03`oo00?03`oo000`000000l?o`0?3ol01<
0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00?`3`oo000`2?
GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o
:RX0l?o`0?3ol00M0?3ol0L0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`
oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool003l0l?o`
00<0SejI0?3ol03`oo00?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`
00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00?`3`oo000`2?GYT0l?o`0?3ol00l0?3ol0030000003`
oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo000o
0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=
0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool003l0l?o`00<0SejI0?3ol03`oo00?03`oo000`00
0000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?oo
o`00?`3`oo000`2?GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`
oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo001n0?3ol0030000003`oo00l?o`04`0l?o`
00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo001n0?3ol0030000003`
oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo001n
0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M
0?3ol0L0oooo001n0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o
:RX0l?o`0?3ol00M0?3ol0L0oooo001n0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`
oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`
00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`
1`3oool003l0l?o`00<0SejI0?3ol03`oo00?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`
oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00?`3`oo000`2?GYT0l?o`0?3ol00l
0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M
0?3ol0L0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3o
O`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool003l0l?o`00<0SejI0?3ol03`
oo00?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`
oo007@3`oo070?ooo`00?`3o0?l00`2?GYT0o`3o0?l0o`2;0?l0o`030?mo003o0?l0o`3o00d0o`3o
00<0ObXZ0?l0o`3o0?l07P3o0?l60?ooo`00?`3`oo000`2?GYT0l?o`0?3ol00l0?3ol0030000003`
oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo000o
0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=
0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool007h0l?o`00<000000?3ol03`oo00C03`oo000`3o
O`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool007h0l?o`00<000000?3ol03`
oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool007h0l?o`
00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`
1`3oool007h0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`
oo00l?o`01d0l?o`1`3oool007h0l?o`00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=
0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool003l0l?o`00<0SejI0?3ol03`oo00?03`oo000`00
0000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?oo
o`00?`3`oo000`2?GYT0l?o`0?3ol00l0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`
oo003@3`oo000`1o:RX0l?o`0?3ol00M0?3ol0L0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`
00<000000?3ol03`oo00C03`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`
1`3oool003l0l?o`00<0SejI0?3ol03`oo00?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`
oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00?`3`oo000`2?GYT0l?o`0?3ol00l
0?3ol0030000003`oo00l?o`04`0l?o`00<0ogl00?3ol03`oo003@3`oo000`1o:RX0l?o`0?3ol00M
0?3ol0L0oooo000o0?3ol00308mNV@3`oo00l?o`03`0l?o`00<000000?3ol03`oo00C03`oo000`3o
O`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`01d0l?o`1`3oool003l0l?o`00<0SejI0?3ol03`
oo00?03`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`00<0ObXZ0?3ol03`
oo007@3`oo070?ooo`00OP3`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`oo00l?o`00d0l?o`
00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00OP3`oo000`000000l?o`0?3ol01<0?3ol0030?mo003`
oo00l?o`00d0l?o`00<0ObXZ0?3ol03`oo007@3`oo070?ooo`00oP00o`060?ooo`00OP3oool00`00
0000oooo0?ooo`230?ooo`00O03oool5000008<0oooo001l0?ooo`D00000P`3oool006`0oooo1P00
00040?ooo`030000003oool0oooo00<0oooo100000240?ooo`00K@3oool00`000000oooo00000002
0?ooo`040000003oool0oooo000000L0oooo0`0000240?ooo`00K@3oool00`000000oooo00000003
0?ooo`030000003oool0000000L0oooo0`0000050?ooo`800000O@3oool006d0oooo00<000000?oo
o`0000000`3oool00`000000oooo000000070?ooo`<000001P3oool00`000000oooo0?ooo`1k0?oo
o`00K03oool400000080oooo1@0000060?ooo`800000203oool00`000000oooo0?ooo`1j0?ooo`00
OP3oool00`000000oooo0?ooo`050?ooo`030000003oool0000007/0oooo001^0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00001k0?ooo`00OP3o
ool00`000000oooo0?ooo`030?ooo`<0000000<0oooo000000000000NP3oool007h0oooo00<00000
0?ooo`3oool0P`3oool00001\
\>"],
    ImageRangeCache->{{{0, 259}, {159.625, 0}} -> {-1, -3, 0, 0}}],
  "     ",
  StyleBox["      ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.493275 0.134504 0.493275 0.134504 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.941 1 .941 r
.49327 .49327 m
.49327 .49327 .44657 0 365.73 arc
F
1 1 1 r
.49327 .49327 m
.49327 .49327 .04051 0 365.73 arc
F
1 0 1 r
.5 Mabswid
[ ] 0 setdash
.49327 .49327 m
.1775 .80905 L
s
1 0 0 r
.49327 .49327 m
.80905 .80905 L
s
0 0 1 r
[ .025 .025 ] 0 setdash
.49327 .49327 m
.10653 .26999 L
s
0 0 0 r
[ ] 0 setdash
.49327 .49327 m
.49327 .96274 L
s
.49327 .49327 m
.96274 .49327 L
s
.49327 .49327 m
.49327 .02381 L
s
.56 .37 .6 r
.0012 w
[ .025 .025 ] 0 setdash
newpath
.49327 .49327 .07382 0 365.73 arc
s
1 .5 0 r
[ ] 0 setdash
newpath
.49327 .49327 .28475 0 365.73 arc
s
.5 .165 .165 r
newpath
.49327 .49327 .33083 0 365.73 arc
s
0 1 0 r
.5 Mabswid
.02381 .49731 m
.49327 .49731 L
s
[ .025 .025 ] 0 setdash
.02381 .48924 m
.49327 .48924 L
s
0 g
[ ] 0 setdash
.94929 .49327 m
.97619 .49327 L
s
% Start of user PostScript
3.39034 0 3.59034 0 MAarrowhead1
% End of user PostScript
.49327 .94929 m
.49327 .97619 L
s
% Start of user PostScript
0 3.39034 0 3.59034 MAarrowhead1
% End of user PostScript
gsave
.96274 .5269 -66 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51345 .96274 -69 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
75.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{249, 249},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003i0000nB000`400?l00000o`00003on@3oool0
0?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00NP3oool00`000000oooo0?ooo`1l0?oo
o`00NP3oool00`000000oooo0?ooo`1l0?ooo`00NP3oool00`000000oooo0?ooo`1l0?ooo`00NP3o
ool00`000000oooo0?ooo`1l0?ooo`00NP3oool00`000000oooo0?ooo`1l0?ooo`00NP3oool00`00
0000oooo0?ooo`1l0?ooo`00NP3oool00`000000oooo0?ooo`1l0?ooo`00K`3oool;0?3ol0030000
003`oo00l?o`00P0l?o`M03oool006L0oooo4`3`oo000`000000l?o`0?3ol00@0?3ol6`0oooo001Q
0?oooaT0l?o`00<000000?3ol03`oo005@3`oo1W0?ooo`00G`3ooolK0?3ol0030000003`oo00l?o`
01P0l?o`I03oool005T0oooo8@3`oo000`000000l?o`0?3ol00M0?3ol5l0oooo001G0?ooob<0l?o`
00<000000?3ol03`oo00803`oo1L0?ooo`00E03ooolV0?3ol0030000003`oo00l?o`02<0l?o`F@3o
ool00540oooo:@3`oo000`000000l?o`0?3ol00U0?3ol5L0oooo001?0?ooob/0l?o`00<000000?3o
l03`oo00:03`oo1D0?ooo`00C03oool^0?3ol0030000003`oo00l?o`02X0l?o`DP3oool004X0oooo
<03`oo000`000000l?o`0?3ol00]0?3ol4l0oooo00170?oooc<0l?o`00<000000?3ol03`oo00;`3`
oo1=0?ooo`00AP3ooold0?3ol0030000003`oo00l?o`0340l?o`B`3oool004D0oooo=@3`oo000`00
0000l?o`0?3ol00b0?3ol4X0oooo00120?ooocP0l?o`00<000000?3ol03`oo00=03`oo180?ooo`00
@03ooolj0?3ol0030000003`oo00l?o`03L0l?o`A@3oool003l0oooo>`3`oo000`000000l?o`0?3o
l00h0?3ol4@0oooo000n0?oooc`0l?o`00<000000?3ol03`oo00>@3`oo130?ooo`00>`3ooolo0?3o
l0030000003`oo00l?o`03/0l?o`@@3oool003X0oooo@03`oo000`000000l?o`0?3ol00m0?3ol3l0
oooo000i0?oood40l?o`00<000000?3ol03`oo00?P3`oo0n0?ooo`00>03ooom20?3ol0030000003`
oo00l?o`03l0l?o`?@3oool003L0oooo@`3`oo000`000000l?o`0?3ol0100?3ol3`0oooo000e0?oo
odD0l?o`00<000000?3ol03`oo00@P3`oo0j0?ooo`00=03ooom60?3ol0030000003`oo00l?o`04<0
l?o`>@3oool003<0ooooA`3`oo000`000000l?o`0?3ol0140?3ol3P0oooo000b0?ooodP0l?o`00<0
00000?3ol03`oo00A@3`oo0g0?ooo`00<@3ooom90?3ol0030000003`oo00l?o`04H0l?o`=P3oool0
0300oooo@03`oo0E07lZ:Sl0l?o`=@3oool002l0oooo>`3`oo0607lZ:PX0l?o`00<000000?3ol03`
oo00203`oo0607lZ:SX0l?o`=03oool002h0oooo>03`oo0407lZ:Q00l?o`00<000000?3ol03`oo00
3P3`oo0407lZ:SL0l?o`<`3oool002d0oooo=@3`oo0407lZ:Q@0l?o`00<000000?3ol03`oo004P3`
oo0407lZ:S@0l?o`<P3oool002/0oooo=@3`oo0207lZ:QP0l?o`00<000000?3ol03`oo005P3`oo02
07lZ:S<0l?o`<@3oool002X0oooo<P3`oo0407lZ:QX0l?o`00<000000?3ol03`oo00603`oo0407lZ
:S00l?o`<03oool002T0oooo<@3`oo0207lZ:Qh0l?o`00<000000?3ol03`oo00703`oo0207lZ:Rl0
l?o`;`3oool002T0oooo;`3`oo0207lZ:R00l?o`00<000000?3ol03`oo007P3`oo0207lZ:Rh0l?o`
;P3oool002P0oooo;P3`oo0207lZ:R80l?o`00<000000?3ol03`oo00803`oo000`1o:RX0l?o`0?3o
l00/0?3ol2d0oooo000W0?ooobd0l?o`0P1o:RXT0?3ol0030000003`oo00l?o`0240l?o`0P1o:RX]
0?3ol2`0oooo000V0?ooobd0l?o`00<0ObXZ0?3ol03`oo00903`oo000`000000l?o`0?3ol00S0?3o
l080ObXZ;03`oo0[0?ooo`009@3oool/0?3ol080ObXZ8P3`oo0;0?mo0280l?o`0P1o:RX[0?3ol2X0
oooo000T0?ooob/0l?o`0P1o:RXM0?3ol0L0ogl01@3`oo000`000000l?o`0?3ol0030?3ol0L0ogl0
7@3`oo0207lZ:RX0l?o`:@3oool002<0oooo:P3`oo0207lZ:QT0l?o`1P3oO`0<0?3ol0030000003`
oo00l?o`00X0l?o`1@3oO`0J0?3ol00307lZ:P3`oo00l?o`02L0l?o`:@3oool002<0oooo:@3`oo00
0`1o:RX0l?o`0?3ol00F0?3ol0<0ogl04P3`oo000`000000l?o`0?3ol00?0?3ol0@0ogl05`3`oo02
07lZ:RP0l?o`:03oool00280oooo:03`oo0207lZ:QH0l?o`0`3oO`0E0?3ol0030000003`oo00l?o`
01<0l?o`0`3oO`0F0?3ol080ObXZ9`3`oo0W0?ooo`008@3ooolW0?3ol080ObXZ5P3`oo020?mo01P0
l?o`00<000000?3ol03`oo005P3`oo020?mo01H0l?o`00<0ObXZ0?3ol03`oo009@3`oo0V0?ooo`00
803ooolW0?3ol00307lZ:P3`oo00l?o`01<0l?o`0`3oO`0J0?3ol0030000003`oo00l?o`01P0l?o`
0`3oO`0D0?3ol00307lZ:P3`oo00l?o`02D0l?o`9@3oool001l0oooo:03`oo000`1o:RX0l?o`0?3o
l00A0?3ol080ogl07@3`oo000`000000l?o`0?3ol00K0?3ol0030?mo003`oo00l?o`0180l?o`00<0
ObXZ0?3ol03`oo009@3`oo0T0?ooo`007P3ooolW0?3ol080ObXZ4`3`oo000`3oO`00l?o`0?3ol00M
0?3ol0030000003`oo00l?o`01`0l?o`0P3oO`0C0?3ol080ObXZ9@3`oo0T0?ooo`007P3ooolV0?3o
l00307lZ:P3`oo00l?o`0140l?o`0P3oO`0P0?3ol0030000003`oo00l?o`01h0l?o`0P3oO`0C0?3o
l00307lZ:P3`oo00l?o`02<0l?o`8`3oool001h0oooo9@3`oo000`1o:RX0l?o`0?3ol00A0?3ol003
0?mo003`oo00l?o`0200l?o`00<000000?3ol03`oo00803`oo000`3oO`00l?o`0?3ol00A0?3ol003
07lZ:P3`oo00l?o`02<0l?o`8P3oool001d0oooo9@3`oo000`1o:RX0l?o`0?3ol00@0?3ol080ogl0
8`3`oo000`000000l?o`0?3ol00Q0?3ol080ogl04P3`oo000`1o:RX0l?o`0?3ol00R0?3ol280oooo
000L0?ooobD0l?o`00<0ObXZ0?3ol03`oo003`3`oo020?mo02D0l?o`00<000000?3ol03`oo008`3`
oo000`3oO`00l?o`0?3ol00@0?3ol00307lZ:P3`oo00l?o`0280l?o`8@3oool001/0oooo9@3`oo00
0`1o:RX0l?o`0?3ol00>0?3ol080ogl09`3`oo000`000000l?o`0?3ol00T0?3ol080ogl04@3`oo00
0`1o:RX0l?o`0?3ol00Q0?3ol240oooo000K0?ooob@0l?o`00<0ObXZ0?3ol03`oo003P3`oo000`3o
O`00l?o`0?3ol00W0?3ol0030000003`oo00l?o`02H0l?o`00<0ogl00?3ol03`oo003`3`oo000`1o
:RX0l?o`0?3ol00Q0?3ol200oooo000J0?ooob@0l?o`00<0ObXZ0?3ol03`oo003P3`oo000`3oO`00
l?o`0?3ol00X0?3ol0030000003`oo00l?o`02L0l?o`0P3oO`0@0?3ol00307lZ:P3`oo00l?o`0240
l?o`7`3oool001X0oooo8`3`oo000`1o:RX0l?o`0?3ol00>0?3ol0030?mo003`oo00l?o`02T0l?o`
00<000000?3ol03`oo00:@3`oo000`3oO`00l?o`0?3ol00=0?3ol00307lZ:P3`oo00l?o`0280l?o`
7P3oool001X0oooo8P3`oo000`1o:RX0l?o`0?3ol00=0?3ol080ogl0;03`oo000`000000l?o`0?3o
l00Z0?3ol080ogl03P3`oo000`1o:RX0l?o`0?3ol00Q0?3ol1h0oooo000I0?ooo`H0l?o`00<0003o
0?3ol03`oo006@3`oo000`1o:RX0l?o`0?3ol00=0?3ol0030?mo003`oo00l?o`02`0l?o`00<00000
0?3ol03`oo00;03`oo000`3oO`00l?o`0?3ol00<0?3ol080ObXZ8@3`oo0N0?ooo`00603oool80?3o
l080003o603`oo000`1o:RX0l?o`0?3ol00=0?3ol0030?mo003`oo00l?o`02d0l?o`00<000000?3o
l03`oo00;@3`oo000`3oO`00l?o`0?3ol00<0?3ol00307lZ:P3`oo00l?o`0200l?o`7@3oool001L0
oooo2`3`oo020000oaH0l?o`00<0ObXZ0?3ol03`oo00303`oo000`3oO`00l?o`0?3ol00^0?3ol003
0000003`oo00l?o`02h0l?o`00<0ogl00?3ol03`oo00303`oo000`1o:RX0l?o`0?3ol00O0?3ol1d0
oooo000G0?ooo`d0l?o`00<0003o0?3ol03`oo004@3`oo0207lZ:Ph0l?o`00<0ogl00?3ol03`oo00
;`3`oo000`000000l?o`0?3ol00_0?3ol0030?mo003`oo00l?o`00`0l?o`00<0ObXZ0?3ol03`oo00
7`3`oo0L0?ooo`005`3ooolP0?3ol00307lZ:P3`oo00l?o`00d0l?o`00<0ogl00?3ol03`oo00<03`
oo000`000000l?o`0?3ol00`0?3ol0030?mo003`oo00l?o`00/0l?o`00<0ObXZ0?3ol03`oo00803`
oo0K0?ooo`005P3ooolQ0?3ol00307lZ:P3`oo00l?o`00`0l?o`00<0ogl00?3ol03`oo00<@3`oo00
0`000000l?o`0?3ol00a0?3ol0030?mo003`oo00l?o`00/0l?o`00<0ObXZ0?3ol03`oo007`3`oo0K
0?ooo`005P3ooolC0?3ol0030000o`3`oo00l?o`00X0l?o`00<0ObXZ0?3ol03`oo00303`oo000`3o
O`00l?o`0?3ol00b0?3ol0030000003`oo00l?o`0380l?o`00<0ogl00?3ol03`oo002`3`oo000`1o
:RX0l?o`0?3ol00O0?3ol1X0oooo000E0?oooaD0l?o`0P000?l:0?3ol00307lZ:P3`oo00l?o`00/0
l?o`00<0ogl00?3ol03`oo00<`3`oo000`000000l?o`0?3ol00c0?3ol0030?mo003`oo00l?o`00/0
l?o`00<0ObXZ0?3ol03`oo007P3`oo0J0?ooo`005@3ooolG0?3ol080003o1`3`oo000`1o:RX0l?o`
0?3ol00;0?3ol0030?mo003`oo00l?o`03@0l?o`00<000000?3ol03`oo00=03`oo000`3oO`00l?o`
0?3ol00;0?3ol00307lZ:P3`oo00l?o`01h0l?o`6@3oool001D0oooo6@3`oo020000o`@0l?o`00<0
ObXZ0?3ol03`oo00303`oo000`3oO`00l?o`0?3ol00d0?3ol0030000003`oo00l?o`03@0l?o`00<0
ogl00?3ol03`oo002`3`oo000`1o:RX0l?o`0?3ol00N0?3ol1T0oooo000D0?ooob00l?o`00<0ObXZ
0?3ol03`oo002`3`oo000`3oO`00l?o`0?3ol00e0?3ol0030000003`oo00l?o`03D0l?o`00<0ogl0
0?3ol03`oo002`3`oo000`1o:RX0l?o`0?3ol00M0?3ol1T0oooo000D0?oooal0l?o`00<0ObXZ0?3o
l03`oo002`3`oo000`3oO`00l?o`0?3ol00f0?3ol0030000003`oo00l?o`03H0l?o`00<0ogl00?3o
l03`oo002P3`oo000`1o:RX0l?o`0?3ol00N0?3ol1P0oooo000C0?ooob00l?o`00<0ObXZ0?3ol03`
oo002P3`oo000`3oO`00l?o`0?3ol00g0?3ol0030000003`oo00l?o`03H0l?o`00<0ogl00?3ol03`
oo002`3`oo000`1o:RX0l?o`0?3ol00M0?3ol1P0oooo000C0?oooal0l?o`00<0ObXZ0?3ol0000?l0
2P3`oo000`3oO`00l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<0ogl00?3ol03`oo00
2P3`oo000`1o:RX0l?o`0?3ol00N0?3ol1L0oooo000C0?oooal0l?o`00<0ObXZ0?3ol03`oo000P00
0?l80?3ol0030?mo003`oo00l?o`03P0l?o`00<000000?3ol03`oo00>03`oo000`3oO`00l?o`0?3o
l00:0?3ol00307lZ:P3`oo00l?o`01d0l?o`5`3oool00180oooo7`3`oo000`1o:RX0l?o`0?3ol003
0?3ol080003o1@3`oo000`3oO`00l?o`0?3ol00i0?3ol0030000003`oo00l?o`03P0l?o`00<0ogl0
0?3ol03`oo002`3`oo000`1o:RX0l?o`0?3ol00L0?3ol1L0oooo000B0?oooah0l?o`00<0ObXZ0?3o
l03`oo001P3`oo000`000?l0l?o`0?3ol0020?3ol0030?mo003`oo00l?o`03T0l?o`00<000000?3o
l03`oo00>@3`oo000`3oO`00l?o`0?3ol00:0?3ol00307lZ:P3`oo00l?o`01d0l?o`5P3oool00180
oooo7P3`oo000`1o:RX0l?o`0?3ol00:0?3ol0030?mo003`oo00l?o`03X0l?o`00<000000?3ol03`
oo00>P3`oo000`3oO`00l?o`0?3ol00:0?3ol00307lZ:P3`oo00l?o`01`0l?o`5P3oool00140oooo
7P3`oo000`1o:RX0l?o`0?3ol00;0?3ol0030?mo003`oo00l?o`03X0l?o`00<000000?3ol03`oo00
>P3`oo000`3oO`00l?o`0?3ol00:0?3ol00307lZ:P3`oo00l?o`01`0l?o`5P3oool00140oooo7P3`
oo000`1o:RX0l?o`0?3ol00:0?3ol0040?mo003`oo00l?o`0000ocX0l?o`00<000000?3ol03`oo00
>`3`oo000`3oO`00l?o`0?3ol00:0?3ol00307lZ:P3`oo00l?o`01`0l?o`5@3oool00100oooo7P3`
oo000`1o:RX0l?o`0?3ol00:0?3ol0030?mo003`oo00l?o`0080l?o`0P000?lh0?3ol0030000003`
oo00l?o`03/0l?o`00<0ogl00?3ol03`oo002P3`oo000`1o:RX0l?o`0?3ol00L0?3ol1D0oooo000@
0?oooah0l?o`00<0ObXZ0?3ol03`oo002P3`oo000`3oO`00l?o`0?3ol0040?3ol080003o=P3`oo00
0`000000l?o`0?3ol00l0?3ol0030?mo003`oo00l?o`00T0l?o`00<0ObXZ0?3ol03`oo00703`oo0E
0?ooo`00403ooolM0?3ol00307lZ:P3`oo00l?o`00X0l?o`00<0ogl00?3ol03`oo001`3`oo000`00
0?l0l?o`0?3ol00c0?3ol0030000003`oo00l?o`03`0l?o`00<0ogl00?3ol03`oo002@3`oo000`1o
:RX0l?o`0?3ol00L0?3ol1D0oooo000?0?oooah0l?o`00<0ObXZ0?3ol03`oo002@3`oo000`3oO`00
l?o`0?3ol00n0?3ol0030000003`oo00l?o`03`0l?o`00<0ogl00?3ol03`oo002P3`oo000`1o:RX0
l?o`0?3ol00K0?3ol1D0oooo000?0?oooah0l?o`00<0ObXZ0?3ol03`oo002@3`oo000`3oO`00l?o`
0?3ol00n0?3ol0030000003`oo00l?o`03d0l?o`00<0ogl00?3ol03`oo002@3`oo000`1o:RX0l?o`
0?3ol00L0?3ol1@0oooo000?0?oooah0l?o`00<0ObXZ0?3ol03`oo002@3`oo000`3oO`00l?o`0?3o
l00=0?3ol0030000o`3`oo00l?o`02h0l?o`00<000000?3ol03`oo00?P3`oo000`3oO`00l?o`0?3o
l0090?3ol00307lZ:P3`oo00l?o`01/0l?o`503oool000l0oooo7@3`oo000`1o:RX0l?o`0?3ol009
0?3ol0030?mo003`oo00l?o`00l0l?o`0P000?l^0?3ol0030000003`oo00l?o`03h0l?o`00<0ogl0
0?3ol03`oo002@3`oo000`1o:RX0l?o`0?3ol00K0?3ol1@0oooo000?0?oooad0l?o`00<0ObXZ0?3o
l03`oo002@3`oo000`3oO`00l?o`0?3ol00A0?3ol080003o;03`oo000`000000l?o`0?3ol00o0?3o
l0030?mo003`oo00l?o`00T0l?o`00<0ObXZ0?3ol03`oo006`3`oo0C0?ooo`003P3ooolM0?3ol003
07lZ:P3`oo00l?o`00T0l?o`00<0ogl00?3ol03`oo00503`oo020000obX0l?o`00<000000?3ol03`
oo00?`3`oo000`3oO`00l?o`0?3ol0090?3ol00307lZ:P3`oo00l?o`01/0l?o`4`3oool000h0oooo
7@3`oo000`1o:RX0l?o`0?3ol0090?3ol0030?mo003`oo00l?o`0400l?o`00<000000?3ol03`oo00
?`3`oo000`3oO`00l?o`0?3ol0090?3ol00307lZ:P3`oo00l?o`01/0l?o`4`3oool000h0oooo7@3`
oo000`1o:RX0l?o`0?3ol0090?3ol0030?mo003`oo00l?o`0400l?o`00<000000?3ol03`oo00@03`
oo000`3oO`00l?o`0?3ol0080?3ol00307lZ:P3`oo00l?o`01/0l?o`4`3oool000d0oooo7P3`oo00
0`1o:RX0l?o`0?3ol0080?3ol0030?mo003`oo00l?o`01/0l?o`00<0003o0?3ol03`oo008`3`oo00
0`000000l?o`0?3ol0100?3ol0030?mo003`oo00l?o`00T0l?o`00<0ObXZ0?3ol03`oo006P3`oo0C
0?ooo`003@3ooolM0?3ol00307lZ:P3`oo00l?o`00T0l?o`00<0ogl00?3ol03`oo00703`oo020000
ob<0l?o`00<000000?3ol03`oo00@03`oo000`3oO`00l?o`0?3ol0090?3ol00307lZ:P3`oo00l?o`
01/0l?o`4P3oool000d0oooo7@3`oo000`1o:RX0l?o`0?3ol0090?3ol0030?mo003`oo00l?o`01h0
l?o`0P000?lQ0?3ol0030000003`oo00l?o`0400l?o`00<0ogl00?3ol03`oo002@3`oo000`1o:RX0
l?o`0?3ol00K0?3ol180oooo000=0?oooad0l?o`00<0ObXZ0?3ol03`oo002@3`oo000`3oO`00l?o`
0?3ol00P0?3ol080003o7`3`oo000`000000l?o`0?3ol0110?3ol0030?mo003`oo00l?o`00P0l?o`
00<0ObXZ0?3ol03`oo006`3`oo0B0?ooo`003@3ooolM0?3ol00307lZ:P3`oo00l?o`00P0l?o`00<0
ogl00?3ol03`oo00?`3`oo0708mNVD00l?o`00<0ogl00?3ol03`oo002@3`oo000`1o:RX0l?o`0?3o
l00J0?3ol180oooo000<0?oooad0l?o`00<0ObXZ0?3ol03`oo002@3`oo000`3oO`00l?o`0?3ol012
0?3ol0030000003`oo00l?o`0440l?o`00<0ogl00?3ol03`oo002@3`oo000`1o:RX0l?o`0?3ol00J
0?3ol180oooo000<0?oooad0l?o`00<0ObXZ0?3ol03`oo002@3`oo000`3oO`00l?o`0?3ol00W0?3o
l0030000o`3`oo00l?o`00l0l?o`00<0SejI0?3ol03`oo001P3`oo000`000000l?o`0?3ol0060?3o
l080SejI>P3`oo000`3oO`00l?o`0?3ol0080?3ol00307lZ:P3`oo00l?o`01/0l?o`4@3oool000`0
oooo7@3`oo000`1o:RX0l?o`0?3ol0090?3ol0030?mo003`oo00l?o`02P0l?o`0P000?l=0?3ol080
SejI2@3`oo000`000000l?o`0?3ol0070?3ol00308mNV@3`oo00l?o`03P0l?o`00<0ogl00?3ol03`
oo00203`oo000`1o:RX0l?o`0?3ol00K0?3ol140oooo000<0?oooad0l?o`00<0ObXZ0?3ol03`oo00
2@3`oo000`3oO`00l?o`0?3ol00Z0?3ol080003o2P3`oo000`2?GYT0l?o`0?3ol0090?3ol0030000
003`oo00l?o`00P0l?o`00<0SejI0?3ol03`oo00=`3`oo000`3oO`00l?o`0?3ol0090?3ol00307lZ
:P3`oo00l?o`01X0l?o`4@3oool000`0oooo7@3`oo000`1o:RX0l?o`0?3ol0080?3ol0030?mo003`
oo00l?o`02d0l?o`00<0003o0?3ol03`oo001P3`oo000`2?GYT0l?o`0?3ol00:0?3ol0030000003`
oo00l?o`00T0l?o`0P2?GYTg0?3ol0030?mo003`oo00l?o`00T0l?o`00<0ObXZ0?3ol03`oo006P3`
oo0A0?ooo`00303ooolM0?3ol00307lZ:P3`oo00l?o`00P0l?o`00<0ogl00?3ol03`oo00=@3`oo00
0`2?GYT0l?o`0?3ol00;0?3ol0030000003`oo00l?o`00/0l?o`00<0SejI0?3ol03`oo00=03`oo00
0`3oO`00l?o`0?3ol0090?3ol00307lZ:P3`oo00l?o`01X0l?o`4@3oool000`0oooo703`oo000`1o
:RX0l?o`0?3ol0090?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00@`3`oo000`3o
O`00l?o`0?3ol0080?3ol00307lZ:P3`oo00l?o`01X0l?o`4@3oool000`0oooo703`oo000`1o:RX0
l?o`0?3ol0090?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00@`3`oo000`3oO`00
l?o`0?3ol0080?3ol00307lZ:P3`oo00l?o`01X0l?o`4@3oool000`0oooo703`oo000`1o:RX0l?o`
0?3ol0090?3ol0030?mo003`oo00l?o`03<0l?o`00<0003o0?3ol03`oo00203`oo050?ooo`040000
003oool0oooo0?oood80l?o`00<0ogl00?3ol03`oo00203`oo000`1o:RX0l?o`0?3ol00J0?3ol140
oooo000;0?oooad0l?o`00<0ObXZ0?3ol03`oo002@3`oo000`3oO`00l?o`0?3ol00d0?3ol080003o
1P3`oo070?ooo`030000003oool0oooo00<0oooo@03`oo000`3oO`00l?o`0?3ol0080?3ol00307lZ
:P3`oo00l?o`01X0l?o`4@3oool000/0oooo7@3`oo000`1o:RX0l?o`0?3ol0090?3ol0030?mo003`
oo00l?o`0380l?o`00@0SejI0?3ol03`oo00l?o`0P000?l40?3ol0L0oooo00<000000?ooo`3oool0
1@3oool90?3ol00308mNV@3`oo00l?o`0380l?o`00<0ogl00?3ol03`oo00203`oo000`1o:RX0l?o`
0?3ol00J0?3ol140oooo000;0?oooad0l?o`00<0ObXZ0?3ol03`oo00203`oo000`3oO`00l?o`0?3o
l00c0?3ol00308mNV@3`oo00l?o`00<0l?o`00<0003o0?3ol03`oo00203oool00`000000oooo0?oo
o`060?ooo`P0l?o`00<0SejI0?3ol03`oo00<P3`oo000`3oO`00l?o`0?3ol0090?3ol00307lZ:P3`
oo00l?o`01T0l?o`4@3oool000/0oooo7@3`oo000`1o:RX0l?o`0?3ol0080?3ol0030?mo003`oo00
l?o`0380l?o`00<0SejI0?3ol03`oo001P3`oo090?ooo`030000003oool0oooo00H0oooo203`oo00
0`2?GYT0l?o`0?3ol00b0?3ol0030?mo003`oo00l?o`00T0l?o`00<0ObXZ0?3ol03`oo006P3`oo0@
0?ooo`002`3ooolM0?3ol00307lZ:P3`oo00l?o`00P0l?o`00<0ogl00?3ol03`oo00<P3`oo000`2?
GYT0l?o`0?3ol0060?3ol0T0oooo00<000000?ooo`3oool01P3oool90?3ol00308mNV@3`oo00l?o`
0340l?o`00<0ogl00?3ol03`oo002@3`oo000`1o:RX0l?o`0?3ol00J0?3ol100oooo000;0?oooad0
l?o`00<0ObXZ0?3ol03`oo00203`oo000`3oO`00l?o`0?3ol00b0?3ol00308mNV@3`oo00l?o`00D0
l?o`103oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo2@3`oo000`2?GYT0
l?o`0?3ol00a0?3ol0030?mo003`oo00l?o`00T0l?o`00<0ObXZ0?3ol03`oo006P3`oo0@0?ooo`00
2`3ooolM0?3ol00307lZ:P3`oo00l?o`00P0l?o`00<0ogl00?3ol03`oo00<P3`oo000`2?GYT0l?o`
0?3ol0050?3ol0D0oooo0P000?l30?ooo`030000003oool0oooo00L0oooo203`oo000`2?GYT0l?o`
0?3ol00a0?3ol0030?mo003`oo00l?o`00T0l?o`00<0ObXZ0?3ol03`oo006P3`oo000`3oool00000
0000000=0?ooo`001@3oool8003o00D0l?o`1`00o`050?3ol0L00?l00`3`oo000`1o:RX0l?o`0?3o
l007003o00030?3ol03oO`00l?o`0080l?o`1`00o`050?3ol0P00?l01@3`oo07003o00D0l?o`1`00
o`050?3ol00308mNV@00o`000?l000D00?l01@3oool6003o00T0oooo203`oo000`2?GYT0l?o`0?3o
l00a0?3ol0030?mo003`oo00l?o`00T0l?o`00<0ObXZ0?3ol03`oo006P3`oo000`3oool000000000
0004000000T0oooo000;0?oooad0l?o`00<0ObXZ0?3ol03`oo00203`oo000`3oO`00l?o`0?3ol00j
0?3ol0T0oooo00<0003o000000000000400000000`2?GYT000000000000a000000030?mo00000000
000000T0000000<0ObXZ000000000000900000060?ooo`001@3ooomf003o00030?l0003oool0oooo
00H0oooo203`oo000`2?GYT0l?o`0?3ol00a0?3ol0030?mo003`oo00l?o`00T0l?o`00<0ObXZ0?3o
l03`oo006P3`oo000`3oool0000000000005000000P0oooo000;0?oooad0l?o`00<0ObXZ0?3ol03`
oo00203`oo000`3oO`00l?o`0?3ol00b0?3ol00308mNV@3`oo00l?o`00D0l?o`203oool01@3o0?l0
oooo0000003oool0o`0000L0oooo203`oo000`2?GYT0l?o`0?3ol00a0?3ol0030?mo003`oo00l?o`
00T0l?o`00<0ObXZ0?3ol03`oo006P3`oo00103oool0000000000000000<0?ooo`002`3ooolM0?3o
l00307lZ:P3`oo00l?o`00P0l?o`00<0ogl00?3ol03`oo00<P3`oo000`2?GYT0l?o`0?3ol0050?3o
l0L0oooo00@0o`3o0?ooo`3oool000000P3oool00`3o0000oooo0?ooo`040?ooo`P0l?o`00<0SejI
0?3ol03`oo00<@3`oo000`3oO`00l?o`0?3ol0090?3ol00307lZ:P3`oo00l?o`01X0l?o`403oool0
00/0oooo7@3`oo000`1o:RX0l?o`0?3ol0080?3ol0030?mo003`oo00l?o`0380l?o`00<0SejI0?3o
l03`oo001P3`oo050?ooo`050?l0o`3oool0oooo0?ooo`0000000`3oool00`3o0000oooo0?ooo`02
0?ooo`P0l?o`00<0SejI0?3ol03`oo00<P3`oo000`3oO`00l?o`0?3ol0090?3ol00307lZ:P3`oo00
l?o`01X0l?o`403oool000/0oooo7@3`oo000`1o:RX0l?o`0?3ol0080?3ol0030?mo003`oo00l?o`
0380l?o`00<0SejI0?3ol03`oo001P3`oo040?ooo`030?l0o`3oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`090?3ol00308mNV@3`oo00l?o`0380l?o`00<0ogl00?3o
l03`oo002@3`oo000`1o:RX0l?o`0?3ol00I0?3ol140oooo000;0?oooad0l?o`00<0ObXZ0?3ol03`
oo00203`oo000`3oO`00l?o`0?3ol00c0?3ol00308mNV@3`oo00l?o`00H0l?o`0P3oool00`3o0?l0
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3`oo00203`oo000`2?GYT0
l?o`0?3ol00b0?3ol0030?mo003`oo00l?o`00T0l?o`00<0ObXZ0?3ol03`oo006@3`oo050?ooo`@0
0000203oool000/0oooo7@3`oo000`1o:RX0l?o`0?3ol0090?3ol0030?mo003`oo00l?o`0380l?o`
00<0SejI0?3ol03`oo001P3`oo000`3oool0o`3o0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<0o`000?3ol03`oo00?03`oo000`3oO`00l?o`0?3ol0080?3ol00307lZ:P3`oo00l?o`01X0l?o`
103oool010000000oooo0?ooo`0000090?ooo`002`3ooolM0?3ol00307lZ:P3`oo00l?o`00T0l?o`
00<0ogl00?3ol03`oo00>`3`oo000`3o0?l0l?o`0?ooo`050?ooo`030000003oool0oooo0080oooo
0`3`oo000`3o0000l?o`0?3ol00k0?3ol0030?mo003`oo00l?o`00P0l?o`00<0ObXZ0?3ol03`oo00
6P3`oo040?ooo`040000003oool0oooo000000T0oooo000<0?oooa`0l?o`00<0ObXZ0?3ol03`oo00
2@3`oo000`3oO`00l?o`0?3ol00j0?3ol0030?l0o`3`oo00l?o`0080l?o`103oool010000000oooo
0?ooo`3oool50?3ol0030?l0003`oo00l?o`03X0l?o`00<0ogl00?3ol03`oo00203`oo000`1o:RX0
l?o`0?3ol00J0?3ol0<0oooo0P0000000`3oool00000000000090?ooo`00303ooolL0?3ol00307lZ
:P3`oo00l?o`00T0l?o`00<0ogl00?3ol03`oo00>@3`oo000`3o0?l0l?o`0?3ol0050?3ol080oooo
00<000000?ooo`3`oo001`3`oo000`3o0000l?o`0?3ol00i0?3ol0030?mo003`oo00l?o`00P0l?o`
00<0ObXZ0?3ol03`oo006P3`oo0A0?ooo`00303ooolL0?3ol00307lZ:P3`oo00l?o`00T0l?o`00<0
ogl00?3ol03`oo00>03`oo000`3o0?l0l?o`0?3ol0080?3ol0030000003`oo00l?o`00P0l?o`00@0
o`000?3ol03`oo00SejI=P3`oo000`3oO`00l?o`0?3ol0090?3ol00307lZ:P3`oo00l?o`01X0l?o`
4@3oool000`0oooo7@3`oo000`1o:RX0l?o`0?3ol0080?3ol0030?mo003`oo00l?o`03L0l?o`00<0
o`3o0?3ol03`oo002@3`oo000`000000l?o`0?3ol0090?3ol0030?l0002?GYT0l?o`03H0l?o`00<0
ogl00?3ol03`oo002@3`oo000`1o:RX0l?o`0?3ol00J0?3ol140oooo000<0?oooad0l?o`00<0ObXZ
0?3ol03`oo00203`oo000`3oO`00l?o`0?3ol00f0?3ol00308mNV@3`oo00l?o`00X0l?o`00<00000
0?3ol03`oo002P3`oo000`2?GYT0l?o`0?3ol00e0?3ol0030?mo003`oo00l?o`00T0l?o`00<0ObXZ
0?3ol03`oo006P3`oo0A0?ooo`00303ooolM0?3ol00307lZ:P3`oo00l?o`00T0l?o`00<0ogl00?3o
l03`oo00=03`oo000`3o0?l0l?o`08mNV@0;0?3ol0030000003`oo00l?o`00P0l?o`0P2?GYT00`3`
oo00o`000?3ol00e0?3ol0030?mo003`oo00l?o`00T0l?o`00<0ObXZ0?3ol03`oo006P3`oo0A0?oo
o`00303ooolM0?3ol00307lZ:P3`oo00l?o`00T0l?o`00<0ogl00?3ol03`oo00<`3`oo001@3o0?l0
l?o`0?3ol03`oo00SejI00X0l?o`00<000000?3ol03`oo001P3`oo0208mNV@@0l?o`00<0o`000?3o
l03`oo00<`3`oo000`3oO`00l?o`0?3ol0080?3ol00307lZ:P3`oo00l?o`01/0l?o`4@3oool000`0
oooo7@3`oo000`1o:RX0l?o`0?3ol0090?3ol0030?mo003`oo00l?o`0380l?o`00<0o`3o0?3ol03`
oo000`3`oo0308mNV@L0l?o`00<000000?3ol03`oo003@3`oo000`3o0000l?o`0?3ol00b0?3ol003
0?mo003`oo00l?o`00P0l?o`00<0ObXZ0?3ol03`oo006P3`oo0B0?ooo`003@3ooolL0?3ol00307lZ
:P3`oo00l?o`00T0l?o`00<0ogl00?3ol03`oo00<@3`oo000`3o0?l0l?o`0?3ol00>0?3ol0030000
003`oo00l?o`00h0l?o`00<0o`000?3ol03`oo00<03`oo000`3oO`00l?o`0?3ol0090?3ol00307lZ
:P3`oo00l?o`01X0l?o`4P3oool000d0oooo7@3`oo000`1o:RX0l?o`0?3ol0080?3ol0030?mo003`
oo00l?o`0300l?o`00<0o`3o0?3ol03`oo003@3`oo0708mNV@d0l?o`00<0o`000?3ol03`oo00;`3`
oo000`3oO`00l?o`0?3ol0090?3ol00307lZ:P3`oo00l?o`01X0l?o`4P3oool000d0oooo7@3`oo00
0`1o:RX0l?o`0?3ol0090?3ol0030?mo003`oo00l?o`02h0l?o`00<0o`3o0?3ol03`oo00403`oo00
0`000000l?o`0?3ol00@0?3ol0030?l0003`oo00l?o`02h0l?o`00<0ogl00?3ol03`oo00203`oo00
0`1o:RX0l?o`0?3ol00K0?3ol180oooo000=0?oooad0l?o`00<0ObXZ0?3ol03`oo002@3`oo000`3o
O`00l?o`0?3ol00]0?3ol0030?l0o`3`oo00l?o`0140l?o`00<000000?3ol03`oo004@3`oo000`3o
0000l?o`0?3ol00/0?3ol0030?mo003`oo00l?o`00T0l?o`00<0ObXZ0?3ol03`oo006`3`oo0B0?oo
o`003@3ooolM0?3ol00307lZ:P3`oo00l?o`00T0l?o`00<0ogl00?3ol03`oo00;03`oo000`3o0?l0
l?o`0?3ol00B0?3ol0030000003`oo00l?o`0180l?o`00<0o`000?3ol03`oo00:`3`oo000`3oO`00
l?o`0?3ol0090?3ol00307lZ:P3`oo00l?o`01/0l?o`4P3oool000d0oooo7P3`oo000`1o:RX0l?o`
0?3ol0090?3ol0030?mo003`oo00l?o`02X0l?o`00<0o`3o0?3ol03`oo004`3`oo000`000000l?o`
0?3ol00C0?3ol0030?l0003`oo00l?o`02X0l?o`00<0ogl00?3ol03`oo002@3`oo000`1o:RX0l?o`
0?3ol00J0?3ol1<0oooo000>0?oooad0l?o`00<0ObXZ0?3ol03`oo002@3`oo000`3oO`00l?o`0?3o
l00Y0?3ol0030?l0o`3`oo00l?o`01@0l?o`00<000000?3ol03`oo00503`oo000`3o0000l?o`0?3o
l00X0?3ol0030?mo003`oo00l?o`00T0l?o`00<0ObXZ0?3ol03`oo006`3`oo0C0?ooo`003P3ooolM
0?3ol00307lZ:P3`oo00l?o`00T0l?o`00<0ogl00?3ol03`oo00:03`oo000`3o0?l0l?o`0?3ol00E
0?3ol0030000003`oo00l?o`01D0l?o`00<0o`000?3ol03`oo009`3`oo000`3oO`00l?o`0?3ol009
0?3ol00307lZ:P3`oo00l?o`01/0l?o`4`3oool000l0oooo703`oo000`1o:RX0l?o`0?3ol0090?3o
l0030?mo003`oo00l?o`02L0l?o`00<0o`3o0?3ol03`oo005P3`oo000`000000l?o`0?3ol00F0?3o
l0030?l0003`oo00l?o`02H0l?o`00<0ogl00?3ol03`oo002@3`oo000`1o:RX0l?o`0?3ol00K0?3o
l1<0oooo000?0?oooad0l?o`00<0ObXZ0?3ol03`oo002@3`oo000`3oO`00l?o`0?3ol00U0?3ol003
0?l0o`3`oo00l?o`01L0l?o`00<000000?3ol03`oo005`3`oo000`3o0000l?o`0?3ol00U0?3ol003
0?mo003`oo00l?o`00T0l?o`00<0ObXZ0?3ol03`oo006`3`oo0C0?ooo`003`3ooolM0?3ol00307lZ
:P3`oo00l?o`00X0l?o`00<0ogl00?3ol03`oo008`3`oo000`3o0?l0l?o`0?3ol00H0?3ol0030000
003`oo00l?o`01P0l?o`00<0o`000?3ol03`oo008`3`oo000`3oO`00l?o`0?3ol0090?3ol00307lZ
:P3`oo00l?o`01/0l?o`503oool000l0oooo7P3`oo000`1o:RX0l?o`0?3ol0090?3ol0030?mo003`
oo00l?o`0280l?o`00<0o`3o0?3ol03`oo006@3`oo000`000000l?o`0?3ol00I0?3ol0030?l0003`
oo00l?o`0240l?o`00<0ogl00?3ol03`oo002P3`oo000`1o:RX0l?o`0?3ol00K0?3ol1@0oooo000?
0?oooah0l?o`00<0ObXZ0?3ol03`oo002@3`oo000`3oO`00l?o`0?3ol00Q0?3ol0030?l0o`3`oo00
l?o`01X0l?o`00<000000?3ol03`oo006P3`oo000`3o0000l?o`0?3ol00P0?3ol0030?mo003`oo00
l?o`00T0l?o`00<0ObXZ0?3ol03`oo00703`oo0D0?ooo`003`3ooolN0?3ol00307lZ:P3`oo00l?o`
00X0l?o`00<0ogl00?3ol03`oo007`3`oo000`3o0?l0l?o`0?3ol00K0?3ol0030000003`oo00l?o`
01/0l?o`00<0o`000?3ol03`oo007P3`oo000`3oO`00l?o`0?3ol00:0?3ol00307lZ:P3`oo00l?o`
01/0l?o`5@3oool00100oooo7@3`oo000`1o:RX0l?o`0?3ol00:0?3ol0030?mo003`oo00l?o`01h0
l?o`00<0o`3o0?3ol03`oo00703`oo000`000000l?o`0?3ol00L0?3ol0030?l0003`oo00l?o`01d0
l?o`00<0ogl00?3ol03`oo002@3`oo000`1o:RX0l?o`0?3ol00L0?3ol1D0oooo000@0?oooah0l?o`
00<0ObXZ0?3ol03`oo002P3`oo000`3oO`00l?o`0?3ol00L0?3ol0030?l0o`3`oo00l?o`01d0l?o`
00<000000?3ol03`oo007@3`oo000`3o0000l?o`0?3ol00L0?3ol0030?mo003`oo00l?o`00T0l?o`
00<0ObXZ0?3ol03`oo00703`oo0E0?ooo`004@3ooolM0?3ol00307lZ:P3`oo00l?o`00X0l?o`00<0
ogl00?3ol03`oo006`3`oo000`3o0?l0l?o`0?3ol00N0?3ol0030000003`oo00l?o`01h0l?o`00<0
o`000?3ol03`oo006P3`oo000`3oO`00l?o`0?3ol00:0?3ol00307lZ:P3`oo00l?o`01`0l?o`5@3o
ool00140oooo7P3`oo000`1o:RX0l?o`0?3ol00:0?3ol0030?mo003`oo00l?o`01T0l?o`00<0o`3o
0?3ol03`oo007`3`oo000`000000l?o`0?3ol00O0?3ol0030?l0003`oo00l?o`01T0l?o`00<0ogl0
0?3ol03`oo002P3`oo000`1o:RX0l?o`0?3ol00L0?3ol1D0oooo000A0?oooal0l?o`00<0ObXZ0?3o
l03`oo002P3`oo000`3oO`00l?o`0?3ol00G0?3ol0030?l0o`3`oo00l?o`0200l?o`00<000000?3o
l03`oo00803`oo000`3o0000l?o`0?3ol00G0?3ol0030?mo003`oo00l?o`00X0l?o`00<0ObXZ0?3o
l03`oo00703`oo0F0?ooo`004P3ooolN0?3ol00307lZ:P3`oo00l?o`00X0l?o`00<0ogl00?3ol03`
oo005P3`oo000`3o0?l0l?o`0?3ol00Q0?3ol0030000003`oo00l?o`0240l?o`00<0o`000?3ol03`
oo005@3`oo000`3oO`00l?o`0?3ol00:0?3ol00307lZ:P3`oo00l?o`01d0l?o`5P3oool00180oooo
7`3`oo000`1o:RX0l?o`0?3ol00:0?3ol0030?mo003`oo00l?o`01@0l?o`00<0o`3o0?3ol03`oo00
8P3`oo000`000000l?o`0?3ol00R0?3ol0030?l0003`oo00l?o`01@0l?o`00<0ogl00?3ol03`oo00
2P3`oo000`1o:RX0l?o`0?3ol00M0?3ol1H0oooo000B0?oooal0l?o`00<0ObXZ0?3ol03`oo002P3`
oo000`3oO`00l?o`0?3ol00C0?3ol0030?l0o`3`oo00l?o`02<0l?o`00<000000?3ol03`oo008`3`
oo000`3o0000l?o`0?3ol00B0?3ol0030?mo003`oo00l?o`00X0l?o`00<0ObXZ0?3ol03`oo007@3`
oo0G0?ooo`004`3ooolO0?3ol00307lZ:P3`oo00l?o`00X0l?o`00<0ogl00?3ol03`oo004@3`oo00
0`3o0?l0l?o`0?3ol00T0?3ol0030000003`oo00l?o`02@0l?o`00<0o`000?3ol03`oo004@3`oo00
0`3oO`00l?o`0?3ol00:0?3ol00307lZ:P3`oo00l?o`01d0l?o`5`3oool001<0oooo7`3`oo000`1o
:RX0l?o`0?3ol00:0?3ol0030?mo003`oo00l?o`0100l?o`00<0o`3o0?3ol03`oo009@3`oo000`00
0000l?o`0?3ol00U0?3ol0030?l0003`oo00l?o`00l0l?o`00<0ogl00?3ol03`oo002P3`oo000`1o
:RX0l?o`0?3ol00M0?3ol1P0oooo000D0?oooal0l?o`00<0ObXZ0?3ol03`oo002P3`oo020?mo00l0
l?o`00<0o`3o0?3ol03`oo009P3`oo000`000000l?o`0?3ol00V0?3ol0030?l0003`oo00l?o`00d0
l?o`00<0ogl00?3ol03`oo002`3`oo000`1o:RX0l?o`0?3ol00M0?3ol1P0oooo000D0?oooal0l?o`
00<0ObXZ0?3ol03`oo00303`oo000`3oO`00l?o`0?3ol00;0?3ol0030?l0o`3`oo00l?o`02L0l?o`
00<000000?3ol03`oo009`3`oo000`3o0000l?o`0?3ol00;0?3ol0030?mo003`oo00l?o`00/0l?o`
00<0ObXZ0?3ol03`oo007P3`oo0H0?ooo`00503ooolP0?3ol00307lZ:P3`oo00l?o`00`0l?o`00<0
ogl00?3ol03`oo002@3`oo000`3o0?l0l?o`0?3ol00X0?3ol0030000003`oo00l?o`02P0l?o`00<0
o`000?3ol03`oo002@3`oo000`3oO`00l?o`0?3ol00<0?3ol00307lZ:P3`oo00l?o`01d0l?o`6@3o
ool001D0oooo803`oo000`1o:RX0l?o`0?3ol00;0?3ol0030?mo003`oo00l?o`00P0l?o`00<0o`3o
0?3ol03`oo00:@3`oo000`000000l?o`0?3ol00Y0?3ol0030?l0003`oo00l?o`00P0l?o`00<0ogl0
0?3ol03`oo002`3`oo000`1o:RX0l?o`0?3ol00N0?3ol1T0oooo000E0?ooob00l?o`00<0ObXZ0?3o
l03`oo00303`oo000`3oO`00l?o`0?3ol0060?3ol0030?l0o`3`oo00l?o`02X0l?o`00<000000?3o
l03`oo00:P3`oo000`3o0000l?o`0?3ol0060?3ol0030?mo003`oo00l?o`00/0l?o`00<0ObXZ0?3o
l03`oo007P3`oo0J0?ooo`005P3ooolP0?3ol00307lZ:P3`oo00l?o`00`0l?o`00<0ogl00?3ol03`
oo00103`oo000`3o0?l0l?o`0?3ol00[0?3ol0030000003`oo00l?o`02/0l?o`00<0o`000?3ol03`
oo00103`oo000`3oO`00l?o`0?3ol00<0?3ol00307lZ:P3`oo00l?o`01h0l?o`6P3oool001H0oooo
803`oo000`1o:RX0l?o`0?3ol00<0?3ol0030?mo003`oo00l?o`00<0l?o`00<0o`3o0?3ol03`oo00
;03`oo000`000000l?o`0?3ol00/0?3ol0030?l0003`oo00l?o`00<0l?o`00<0ogl00?3ol03`oo00
2`3`oo000`1o:RX0l?o`0?3ol00O0?3ol1X0oooo000F0?ooob40l?o`00<0ObXZ0?3ol03`oo00303`
oo001@3oO`00l?o`0?3ol03`oo00o`3o02l0l?o`00<000000?3ol03`oo00;@3`oo001@3o0000l?o`
0?3ol03`oo00ogl000d0l?o`00<0ObXZ0?3ol03`oo007`3`oo0K0?ooo`005`3ooolQ0?3ol00307lZ
:P3`oo00l?o`00`0l?o`0P3oO`000`3o0?l0l?o`0?3ol00^0?3ol0030000003`oo00l?o`02h0l?o`
00<0o`000?mo003oO`003@3`oo000`1o:RX0l?o`0?3ol00O0?3ol1`0oooo000G0?ooob80l?o`00<0
ObXZ0?3ol03`oo00303`oo000`3o0?l0ogl00?3ol00_0?3ol0030000003`oo00l?o`02h0l?o`00<0
ogl00?l0003`oo00303`oo000`1o:RX0l?o`0?3ol00O0?3ol1d0oooo000H0?ooob80l?o`00<0ObXZ
0?3ol03`oo002P3`oo00103o0?l0l?o`0?3ol03oO`0_0?3ol0030000003`oo00l?o`02d0l?o`00@0
ogl00?3ol03`oo00o`00303`oo000`1o:RX0l?o`0?3ol00O0?3ol1d0oooo000I0?ooob40l?o`00<0
ObXZ0?3ol03`oo002@3`oo001@3o0?l0l?o`0?3ol03`oo00ogl002l0l?o`00<000000?3ol03`oo00
;@3`oo001@3oO`00l?o`0?3ol03`oo00o`0000X0l?o`00<0ObXZ0?3ol03`oo00803`oo0M0?ooo`00
6@3ooolR0?3ol00307lZ:P3`oo00l?o`00L0l?o`00<0o`3o0?3ol03`oo000`3`oo000`3oO`00l?o`
0?3ol00/0?3ol0030000003`oo00l?o`02`0l?o`00<0ogl00?3ol03`oo000`3`oo000`3o0000l?o`
0?3ol0070?3ol00307lZ:P3`oo00l?o`01l0l?o`7P3oool001X0oooo8P3`oo000`1o:RX0l?o`0?3o
l0050?3ol0030?l0o`3`oo00l?o`00D0l?o`0P3oO`0/0?3ol0030000003`oo00l?o`02X0l?o`0P3o
O`070?3ol0030?l0003`oo00l?o`00@0l?o`0P1o:RXR0?3ol1h0oooo000J0?ooob<0l?o`00<0ObXZ
0?3ol03`oo000`3`oo000`3o0?l0l?o`0?3ol0080?3ol0030?mo003`oo00l?o`02T0l?o`00<00000
0?3ol03`oo00:@3`oo000`3oO`00l?o`0?3ol0080?3ol0030?l0003`oo00l?o`0080l?o`00<0ObXZ
0?3ol03`oo008@3`oo0O0?ooo`006`3ooolS0?3ol00507lZ:P3`oo00l?o`0?3ol03o0?l0303`oo02
0?mo02T0l?o`00<000000?3ol03`oo009`3`oo020?mo00`0l?o`00D0o`000?3ol03`oo00l?o`07lZ
:P0S0?3ol1l0oooo000K0?ooob@0l?o`00<0ObXZ0?3ol03o0?l03`3`oo000`3oO`00l?o`0?3ol00V
0?3ol0030000003`oo00l?o`02H0l?o`00<0ogl00?3ol03`oo003@3`oo000`3o0000l?o`07lZ:P0S
0?3ol200oooo000K0?ooobD0l?o`00<0ObXZ0?3ol03`oo003`3`oo020?mo02H0l?o`00<000000?3o
l03`oo00903`oo020?mo0140l?o`00<0ObXZ0?3ol03`oo008@3`oo0Q0?ooo`00703ooolS0?3ol003
0?l0o`3`oo00ObXZ0180l?o`00<0ogl00?3ol03`oo008`3`oo000`000000l?o`0?3ol00S0?3ol003
0?mo003`oo00l?o`0100l?o`00<0ObXZ0?3ol03o00008P3`oo0Q0?ooo`007@3ooolQ0?3ol0040?l0
o`3`oo00l?o`0?3ol080ObXZ4@3`oo020?mo02<0l?o`00<000000?3ol03`oo008P3`oo000`3oO`00
l?o`0?3ol00?0?3ol080ObXZ0`3`oo000`3o0000l?o`0?3ol00N0?3ol280oooo000N0?oooal0l?o`
00<0o`3o0?3ol03`oo00103`oo000`1o:RX0l?o`0?3ol00@0?3ol0030?mo003`oo00l?o`0200l?o`
00<000000?3ol03`oo00803`oo020?mo0140l?o`00<0ObXZ0?3ol03`oo00103`oo000`3o0000l?o`
0?3ol00L0?3ol2<0oooo000N0?oooah0l?o`00<0o`3o0?3ol03`oo001@3`oo000`1o:RX0l?o`0?3o
l00A0?3ol0030?mo003`oo00l?o`01l0l?o`00<000000?3ol03`oo007`3`oo000`3oO`00l?o`0?3o
l00@0?3ol00307lZ:P3`oo00l?o`00H0l?o`00<0o`000?3ol03`oo006P3`oo0T0?ooo`007`3ooolL
0?3ol0030?l0o`3`oo00l?o`00L0l?o`00<0ObXZ0?3ol03`oo004@3`oo030?mo01h0l?o`00<00000
0?3ol03`oo006`3`oo040?mo01<0l?o`00<0ObXZ0?3ol03`oo001`3`oo000`3o0000l?o`0?3ol00I
0?3ol2@0oooo000P0?oooaX0l?o`00<0o`3o0?3ol03`oo002@3`oo0207lZ:Q@0l?o`0P3oO`0L0?3o
l0030000003`oo00l?o`01X0l?o`00<0ogl00?3ol03`oo004`3`oo0207lZ:P/0l?o`00<0o`000?3o
l03`oo005`3`oo0U0?ooo`008@3ooolH0?3ol0030?l0o`3`oo00l?o`00`0l?o`00<0ObXZ0?3ol03`
oo004`3`oo000`3oO`00l?o`0?3ol00I0?3ol0030000003`oo00l?o`01P0l?o`0P3oO`0D0?3ol080
ObXZ3P3`oo000`3o0000l?o`0?3ol00F0?3ol2D0oooo000R0?oooaH0l?o`00<0o`3o0?3ol03`oo00
3P3`oo0207lZ:Q@0l?o`103oO`0G0?3ol0030000003`oo00l?o`01D0l?o`0`3oO`0E0?3ol00307lZ
:P3`oo00l?o`00l0l?o`00<0o`000?3ol03`oo00503`oo0V0?ooo`008P3ooolE0?3ol0030?l0o`3`
oo00l?o`0140l?o`00<0ObXZ0?3ol03`oo005@3`oo030?mo01@0l?o`00<000000?3ol03`oo004P3`
oo030?mo01L0l?o`00<0ObXZ0?3ol03`oo004@3`oo000`3o0000l?o`0?3ol00B0?3ol2L0oooo000S
0?oooa<0l?o`00<0o`3o0?3ol03`oo004`3`oo000`1o:RX0l?o`0?3ol00G0?3ol0<0ogl04@3`oo00
0`000000l?o`0?3ol00>0?3ol0@0ogl06@3`oo000`1o:RX0l?o`0?3ol00C0?3ol0030?l0003`oo00
l?o`0100l?o`:03oool002<0oooo4P3`oo000`3o0?l0l?o`0?3ol00E0?3ol00307lZ:P3`oo00l?o`
01T0l?o`1P3oO`0;0?3ol0030000003`oo00l?o`00T0l?o`1@3oO`0K0?3ol080ObXZ5`3`oo000`3o
0000l?o`0?3ol00>0?3ol2T0oooo000T0?oooa00l?o`00<0o`3o0?3ol03`oo005`3`oo0207lZ:Ql0
l?o`5`3oO`0O0?3ol00307lZ:P3`oo00l?o`01P0l?o`00<0o`000?3ol03`oo003@3`oo0Y0?ooo`00
9@3oool>0?3ol0030?l0o`3`oo00l?o`01X0l?o`0P1o:RXX0?3ol0030000003`oo00l?o`02H0l?o`
0P1o:RXL0?3ol0030?l0003`oo00l?o`00/0l?o`:P3oool002H0oooo303`oo000`3o0?l0l?o`0?3o
l00M0?3ol080ObXZ9P3`oo000`000000l?o`0?3ol00T0?3ol080ObXZ7`3`oo000`3o0000l?o`0?3o
l0090?3ol2/0oooo000W0?ooo`X0l?o`00<0o`3o0?3ol03`oo00803`oo000`1o:RX0l?o`0?3ol00S
0?3ol0030000003`oo00l?o`0280l?o`0P1o:RXR0?3ol0030?l0003`oo00l?o`00L0l?o`;03oool0
02P0oooo203`oo000`3o0?l0l?o`0?3ol00R0?3ol080ObXZ8`3`oo000`000000l?o`0?3ol00P0?3o
l080ObXZ9@3`oo000`3o0000l?o`0?3ol0050?3ol2d0oooo000Y0?ooo`H0l?o`00<0o`3o0?3ol03`
oo009@3`oo0407lZ:Ql0l?o`00<000000?3ol03`oo007@3`oo0307lZ:RP0l?o`00<0o`000?3ol03`
oo000`3`oo0^0?ooo`00:P3oool40?3ol0030?l0o`3`oo00l?o`02X0l?o`0P1o:RXM0?3ol0030000
003`oo00l?o`01/0l?o`0P1o:RX/0?3ol0040?l0003`oo00l?o`0?3ol2l0oooo000[0?ooo`80l?o`
00<0o`3o0?3ol03`oo00;@3`oo0207lZ:Q/0l?o`00<000000?3ol03`oo006@3`oo0207lZ:Rl0l?o`
00<0o`000?3ol03oool0;`3oool002`0oooo00<0o`3o0?3ol03`oo00<03`oo0407lZ:QL0l?o`00<0
00000?3ol03`oo005@3`oo0407lZ:S80l?o`00<0o`000?ooo`3oool0;P3oool002`0oooo=`3`oo04
07lZ:Q<0l?o`00<000000?3ol03`oo004@3`oo0407lZ:SD0l?o`<P3oool002d0oooo>P3`oo0407lZ
:Pl0l?o`00<000000?3ol03`oo003@3`oo0407lZ:SP0l?o`<`3oool002h0oooo?@3`oo0807lZ:PL0
l?o`00<000000?3ol03`oo001@3`oo0807lZ:S/0l?o`=03oool00300oooo@`3`oo0?07lZ:T80l?o`
=@3oool00340ooooB@3`oo000`000000l?o`0?3ol0160?3ol3H0oooo000b0?ooodP0l?o`00<00000
0?3ol03`oo00A@3`oo0g0?ooo`00<`3ooom70?3ol0030000003`oo00l?o`04@0l?o`>03oool003D0
ooooA@3`oo000`000000l?o`0?3ol0120?3ol3X0oooo000f0?oood@0l?o`00<000000?3ol03`oo00
@@3`oo0k0?ooo`00=`3ooom30?3ol0030000003`oo00l?o`0400l?o`?03oool003P0oooo@P3`oo00
0`000000l?o`0?3ol00o0?3ol3d0oooo000i0?oood40l?o`00<000000?3ol03`oo00?@3`oo0o0?oo
o`00>`3ooolo0?3ol0030000003`oo00l?o`03/0l?o`@@3oool003d0oooo?@3`oo000`000000l?o`
0?3ol00j0?3ol480oooo000n0?oooc`0l?o`00<000000?3ol03`oo00>@3`oo130?ooo`00@03ooolj
0?3ol0030000003`oo00l?o`03L0l?o`A@3oool00440oooo>@3`oo000`000000l?o`0?3ol00f0?3o
l4H0oooo00120?ooocP0l?o`00<000000?3ol03`oo00=03`oo180?ooo`00A@3ooole0?3ol0030000
003`oo00l?o`0380l?o`BP3oool004L0oooo<`3`oo000`000000l?o`0?3ol00_0?3ol4d0oooo0019
0?oooc40l?o`00<000000?3ol03`oo00;P3`oo1>0?ooo`00BP3oool`0?3ol0030000003`oo00l?o`
02d0l?o`C`3oool004`0oooo;P3`oo000`000000l?o`0?3ol00Z0?3ol580oooo001?0?ooob/0l?o`
00<000000?3ol03`oo00:03`oo1D0?ooo`00D@3ooolY0?3ol0030000003`oo00l?o`02D0l?o`E`3o
ool005@0oooo9P3`oo000`000000l?o`0?3ol00S0?3ol5T0oooo001G0?ooob<0l?o`00<000000?3o
l03`oo00803`oo1L0?ooo`00F@3ooolQ0?3ol0030000003`oo00l?o`01d0l?o`G`3oool005h0oooo
703`oo000`000000l?o`0?3ol00H0?3ol6@0oooo001Q0?oooaT0l?o`00<000000?3ol03`oo005@3`
oo1W0?ooo`00I`3ooolC0?3ol0030000003`oo00l?o`0100l?o`K03oool006`0oooo3P3`oo000`00
0000l?o`0?3ol00;0?3ol740oooo001g0?ooo`<0l?o`00<000000?3ol03`oo00O03oool007P0oooo
1@00001l0?ooo`00N03oool5000007`0oooo001h0?ooo`@000001@3oool2000007H0oooo001i0?oo
o`<000001@3oool2000007H0oooo001i0?ooo`<00000103oool010000000oooo0?ooo`00001e0?oo
o`00N@3oool3000000<0oooo0P0000020?ooo`800000M03oool007T0oooo0P00001n0?ooo`00NP3o
ool00`000000oooo0?ooo`1l0?ooo`00NP3oool00`000000oooo0?ooo`1l0?ooo`00n@3oool00?T0
oooo003i0?ooo`00n@3oool00?T0oooo0000\
\>"],
    ImageRangeCache->{{{0, 248}, {248, 0}} -> {-3, -3, 0, 0}}],
  StyleBox["  \n\t\t\tFigure 5.2",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The fundamental period strip for the mapping  ",
  Cell[BoxData[
      \(w\  = \ \(\[ExponentialE]\^z\  = \ exp \((z)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe horizontal line  ",
  Cell[BoxData[
      \(z = t + \[ImaginaryI]\ b\)]],
  ",  for  ",
  Cell[BoxData[
      \(\(-\[Infinity]\) < t < \[Infinity]\)]],
  "   in the z plane, is mapped onto the ray   ",
  Cell[BoxData[
      \(w\  = \ \ \(\(\[ExponentialE]\^\(\(t\)\(\ \)\)\) \[ExponentialE]\^\(\
\[ImaginaryI]\ b\)\  = \ \ \(\[ExponentialE]\^t\) \((cos\ b + \[ImaginaryI]\ \
sin\ b)\)\)\)]],
  "  that is inclined at an angle  ",
  Cell[BoxData[
      \(\[Phi] = b\)]],
  "  in the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane. The vertical segment  ",
  Cell[BoxData[
      \(z = a + \[ImaginaryI]\ \[Theta]\)]],
  ",  for  ",
  Cell[BoxData[
      \(\(-\[Pi]\) < \[Theta] \[LessEqual] \[Pi]\)]],
  "  in the z plane, is mapped onto the circle centered at the origin with \
radius  ",
  Cell[BoxData[
      \(\[ExponentialE]\^a\)]],
  "  in the w plane.  That is,   ",
  Cell[BoxData[
      \(w\  = \ \ \(\(\[ExponentialE]\^\(\(a\)\(\ \)\)\) \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Theta]\)\  = \ \ \(\[ExponentialE]\^a\) \((cos\ \[Theta] + \
\[ImaginaryI]\ sin\ \[Theta])\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 5.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider a rectangle  ",
  Cell[BoxData[
      \(R = {\((x, y)\) : 
            a \[LessEqual] x \[LessEqual] b\ \ and\ \ c \[LessEqual] 
              y \[LessEqual] d}\)]],
  ", where  ",
  Cell[BoxData[
      \(\(-\[Pi]\) < c < d \[LessEqual] \[Pi]\)]],
  ".  Show that the transformation  ",
  Cell[BoxData[
      \(w = \(\[ExponentialE]\^z = \[ExponentialE]\^\(x\  + \[ImaginaryI]\ \
y\)\)\)]],
  "  maps the rectangle ",
  Cell[BoxData[
      \(R\)]],
  " onto a portion of an annular region bounded by two rays. \n\nSolution.  \
The image points in the w plane satisfy the following relationships involving \
the modulus and argument of w:  \n\n\t\t\t",
  Cell[BoxData[
      \(\[ExponentialE]\^a\  = \ \(\(\(|\)\(\[ExponentialE]\^\(a + \
\[ImaginaryI]\ y\)\)\(|\)\(\(\[LessEqual]\)\(\(|\)\(\[ExponentialE]\^\(x\  + \
\[ImaginaryI]\ y\)\)\(|\)\(\(\[LessEqual]\)\(\(|\)\(\[ExponentialE]\^\(b + \
\[ImaginaryI]\ y\)\)\(|\)\)\)\)\)\) = \ \[ExponentialE]\^b\)\)]],
  ",   and \n\n\t\t\t",
  Cell[BoxData[
      \(c = 
        Arg \((\[ExponentialE]\^\(x + \[ImaginaryI]\ c\))\) \[LessEqual] 
          Arg \((\[ExponentialE]\^\(x + \[ImaginaryI]\ y\))\) \[LessEqual] 
          Arg \((\[ExponentialE]\^\(x + \[ImaginaryI]\ d\))\) \[LessEqual] 
          d\)]],
  ",  \n\nwhich is a portion of the annulus  ",
  Cell[BoxData[
      \({\[Rho]\ \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\)\) : \ \
\[ExponentialE]\^a \[LessEqual] \[Rho] \[LessEqual] \
\[ExponentialE]\^b\)}\)]],
  "  in the w plane subtended by the rays  ",
  Cell[BoxData[
      RowBox[{"\[Phi]", "=", 
        RowBox[{
          RowBox[{"c", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "\[Phi]"}], "=", "d"}]}]]],
  ".   In Figure 5.3, we show the image of the rectangle  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(R\^*\), "=", 
        RowBox[{"{", 
          RowBox[{\((x, y)\), ":", " ", 
            RowBox[{\(-1\), "\[LessEqual]", "x", "\[LessEqual]", 
              RowBox[{"1", "  ", 
                StyleBox["and",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "  ", \(\(-\[Pi]\)\/4\)}], 
              "\[LessEqual]", "y", "\[LessEqual]", \(\[Pi]\/3\)}]}], 
          "}"}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.488889 0.444444 0.268203 0.23322 [
[1.025 .2682 0 -6.5 ]
[1.025 .2682 9 6.5 ]
[.48889 .64303 -4.34375 0 ]
[.48889 .64303 4.34375 13 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .2682 m
1 .2682 L
s
gsave
1.025 .2682 -61 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.48889 0 m
.48889 .61803 L
s
gsave
.48889 .64303 -65.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
67.688 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
0 .2682 m
.13158 .2682 L
.4847 .2682 L
.86072 .2682 L
s
.86072 .2682 m
1 .2682 L
s
.941 1 .941 r
.04444 .08503 m
.93333 .08503 L
.93333 .51243 L
.04444 .51243 L
.04444 .08503 L
F
0 g
.04444 .08503 m
.04444 .10237 L
.04444 .12128 L
.04444 .13904 L
.04444 .15612 L
.04444 .1743 L
.04444 .19179 L
.04444 .21039 L
.04444 .22831 L
.04444 .24555 L
.04444 .26389 L
.04444 .28155 L
.04444 .29853 L
.04444 .31661 L
.04444 .33401 L
.04444 .35251 L
.04444 .37033 L
.04444 .38747 L
.04444 .40571 L
.04444 .42327 L
.04444 .44193 L
.04444 .45991 L
.04444 .47721 L
.04444 .49561 L
.04444 .51243 L
s
.26667 .08503 m
.26667 .10237 L
.26667 .12128 L
.26667 .13904 L
.26667 .15612 L
.26667 .1743 L
.26667 .19179 L
.26667 .21039 L
.26667 .22831 L
.26667 .24555 L
.26667 .26389 L
.26667 .28155 L
.26667 .29853 L
.26667 .31661 L
.26667 .33401 L
.26667 .35251 L
.26667 .37033 L
.26667 .38747 L
.26667 .40571 L
.26667 .42327 L
.26667 .44193 L
.26667 .45991 L
.26667 .47721 L
.26667 .49561 L
.26667 .51243 L
s
.48889 .08503 m
.48889 .10237 L
.48889 .12128 L
.48889 .13904 L
.48889 .15612 L
.48889 .1743 L
.48889 .19179 L
.48889 .21039 L
.48889 .22831 L
.48889 .24555 L
.48889 .26389 L
.48889 .28155 L
.48889 .29853 L
.48889 .31661 L
.48889 .33401 L
.48889 .35251 L
.48889 .37033 L
.48889 .38747 L
.48889 .40571 L
.48889 .42327 L
.48889 .44193 L
.48889 .45991 L
.48889 .47721 L
.48889 .49561 L
.48889 .51243 L
s
.71111 .08503 m
.71111 .10237 L
.71111 .12128 L
.71111 .13904 L
.71111 .15612 L
.71111 .1743 L
.71111 .19179 L
.71111 .21039 L
.71111 .22831 L
.71111 .24555 L
.71111 .26389 L
.71111 .28155 L
.71111 .29853 L
.71111 .31661 L
.71111 .33401 L
.71111 .35251 L
.71111 .37033 L
.71111 .38747 L
.71111 .40571 L
.71111 .42327 L
.71111 .44193 L
.71111 .45991 L
.71111 .47721 L
.71111 .49561 L
.71111 .51243 L
s
.93333 .08503 m
.93333 .10237 L
.93333 .12128 L
.93333 .13904 L
.93333 .15612 L
.93333 .1743 L
.93333 .19179 L
.93333 .21039 L
.93333 .22831 L
.93333 .24555 L
.93333 .26389 L
.93333 .28155 L
.93333 .29853 L
.93333 .31661 L
.93333 .33401 L
.93333 .35251 L
.93333 .37033 L
.93333 .38747 L
.93333 .40571 L
.93333 .42327 L
.93333 .44193 L
.93333 .45991 L
.93333 .47721 L
.93333 .49561 L
.93333 .51243 L
s
.04444 .08503 m
.0805 .08503 L
.11983 .08503 L
.15676 .08503 L
.19228 .08503 L
.23009 .08503 L
.26648 .08503 L
.30517 .08503 L
.34243 .08503 L
.37829 .08503 L
.41643 .08503 L
.45316 .08503 L
.48847 .08503 L
.52607 .08503 L
.56226 .08503 L
.60074 .08503 L
.6378 .08503 L
.67344 .08503 L
.71138 .08503 L
.7479 .08503 L
.78671 .08503 L
.82411 .08503 L
.86009 .08503 L
.89836 .08503 L
.93333 .08503 L
s
.04444 .14609 m
.0805 .14609 L
.11983 .14609 L
.15676 .14609 L
.19228 .14609 L
.23009 .14609 L
.26648 .14609 L
.30517 .14609 L
.34243 .14609 L
.37829 .14609 L
.41643 .14609 L
.45316 .14609 L
.48847 .14609 L
.52607 .14609 L
.56226 .14609 L
.60074 .14609 L
.6378 .14609 L
.67344 .14609 L
.71138 .14609 L
.7479 .14609 L
.78671 .14609 L
.82411 .14609 L
.86009 .14609 L
.89836 .14609 L
.93333 .14609 L
s
.04444 .20715 m
.0805 .20715 L
.11983 .20715 L
.15676 .20715 L
.19228 .20715 L
.23009 .20715 L
.26648 .20715 L
.30517 .20715 L
.34243 .20715 L
.37829 .20715 L
.41643 .20715 L
.45316 .20715 L
.48847 .20715 L
.52607 .20715 L
.56226 .20715 L
.60074 .20715 L
.6378 .20715 L
.67344 .20715 L
.71138 .20715 L
.7479 .20715 L
.78671 .20715 L
.82411 .20715 L
.86009 .20715 L
.89836 .20715 L
.93333 .20715 L
s
.04444 .2682 m
.0805 .2682 L
.11983 .2682 L
.15676 .2682 L
.19228 .2682 L
.23009 .2682 L
.26648 .2682 L
.30517 .2682 L
.34243 .2682 L
.37829 .2682 L
.41643 .2682 L
.45316 .2682 L
.48847 .2682 L
.52607 .2682 L
.56226 .2682 L
.60074 .2682 L
.6378 .2682 L
.67344 .2682 L
.71138 .2682 L
.7479 .2682 L
.78671 .2682 L
.82411 .2682 L
.86009 .2682 L
.89836 .2682 L
.93333 .2682 L
s
.04444 .32926 m
.0805 .32926 L
.11983 .32926 L
.15676 .32926 L
.19228 .32926 L
.23009 .32926 L
.26648 .32926 L
.30517 .32926 L
.34243 .32926 L
.37829 .32926 L
.41643 .32926 L
.45316 .32926 L
.48847 .32926 L
.52607 .32926 L
.56226 .32926 L
.60074 .32926 L
.6378 .32926 L
.67344 .32926 L
.71138 .32926 L
.7479 .32926 L
.78671 .32926 L
.82411 .32926 L
.86009 .32926 L
.89836 .32926 L
.93333 .32926 L
s
.04444 .39032 m
.0805 .39032 L
.11983 .39032 L
.15676 .39032 L
.19228 .39032 L
.23009 .39032 L
.26648 .39032 L
.30517 .39032 L
.34243 .39032 L
.37829 .39032 L
.41643 .39032 L
.45316 .39032 L
.48847 .39032 L
.52607 .39032 L
.56226 .39032 L
.60074 .39032 L
.6378 .39032 L
.67344 .39032 L
.71138 .39032 L
.7479 .39032 L
.78671 .39032 L
.82411 .39032 L
.86009 .39032 L
.89836 .39032 L
.93333 .39032 L
s
.04444 .45137 m
.0805 .45137 L
.11983 .45137 L
.15676 .45137 L
.19228 .45137 L
.23009 .45137 L
.26648 .45137 L
.30517 .45137 L
.34243 .45137 L
.37829 .45137 L
.41643 .45137 L
.45316 .45137 L
.48847 .45137 L
.52607 .45137 L
.56226 .45137 L
.60074 .45137 L
.6378 .45137 L
.67344 .45137 L
.71138 .45137 L
.7479 .45137 L
.78671 .45137 L
.82411 .45137 L
.86009 .45137 L
.89836 .45137 L
.93333 .45137 L
s
.04444 .51243 m
.0805 .51243 L
.11983 .51243 L
.15676 .51243 L
.19228 .51243 L
.23009 .51243 L
.26648 .51243 L
.30517 .51243 L
.34243 .51243 L
.37829 .51243 L
.41643 .51243 L
.45316 .51243 L
.48847 .51243 L
.52607 .51243 L
.56226 .51243 L
.60074 .51243 L
.6378 .51243 L
.67344 .51243 L
.71138 .51243 L
.7479 .51243 L
.78671 .51243 L
.82411 .51243 L
.86009 .51243 L
.89836 .51243 L
.93333 .51243 L
s
gsave
.42222 .55441 -73.8438 -14.5313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.813 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 16.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
67.875 16.813 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
76.875 9.563 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.750 16.813 moveto
(\\200\\200) show
78.500 16.813 moveto
(\\200\\200) show
81.250 16.813 moveto
(\\200) show
81.625 16.813 moveto
(\\200) show
77.000 24.000 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
84.688 16.813 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.42222 .03606 -77.0313 -14.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.813 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 16.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
67.875 16.813 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
74.313 16.813 moveto
(-) show
83.250 9.563 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
82.125 16.813 moveto
(\\200\\200) show
84.875 16.813 moveto
(\\200\\200) show
87.625 16.813 moveto
(\\200) show
88.000 16.813 moveto
(\\200) show
83.375 24.000 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
91.063 16.813 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.02222 .23322 -68.9375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.375 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
74.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.95556 .23322 -67.125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.750 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
71.250 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.93333 .2682 m
1 .2682 L
s
% Start of user PostScript
1. 0 1.15 0 MAarrowhead1
% End of user PostScript
.48889 .59471 m
.48889 .61803 L
s
% Start of user PostScript
0 1.4 0 1.5 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{296, 182.875},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004X0000]R000`400?l00000o`00003oR03oool0
0`000000oooo0?ooo`2M0?ooo`00P03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
09d0oooo00200?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0W@3oool007d0oooo
1@0000060?ooo`030000003oool0oooo09d0oooo001m0?ooo`040000003oool0oooo000000L0oooo
00<000000?ooo`3oool0W@3oool007h0oooo00<000000?ooo`0000001`3oool00`000000oooo0?oo
o`2M0?ooo`00J03oool2000001D0oooo0P0000070?ooo`030000003oool0oooo09d0oooo001Z0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2M0?oo
o`00JP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo09d0oooo001Z0?ooo`800000
0`3oool4000001D0oooo00<000000?ooo`3oool0W@3oool006X0oooo0P0000090?ooo`@000000`3o
ool8000000@0oooo00<000000?ooo`3oool0W@3oool006T0oooo00@000000?ooo`3oool000000P3o
ool4000001D0oooo00<000000?ooo`3oool0W@3oool006P0oooo0P0000020?ooo`8000006P3oool0
0`000000oooo0?ooo`2M0?ooo`00R03oool00`000000oooo0?ooo`2M0?ooo`00R03oool00`000000
oooo0?ooo`2M0?ooo`00OP3oool00`000000oooo0?ooo`02000000D0oooo00<000000?ooo`3oool0
W@3oool007h0oooo0P0000000`3oool00000000000050?ooo`030000003oool0oooo09d0oooo001o
0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0W@3oool007l0oooo00<000000?oo
o`0000001P3oool00`000000oooo0?ooo`2M0?ooo`00O@3oool6000000D0oooo00<000000?ooo`3o
ool0W@3oool008P0oooo00<000000?ooo`3oool0W@3oool008P0oooo00<000000?ooo`3oool0W@3o
ool001@0oooojP00000Z0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`
03L0l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo
02P0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000
l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0oooo
00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`
00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00503oool00`000000l?o`0?3o
l00g0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3o
l00g0?3ol0030000003oool0oooo02P0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<00000
0?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<00000
0?ooo`3oool0:03oool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3o
l0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?oo
o`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`
oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0oooo000D0?ooo`030000
003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000
003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0oooo00<000000?3ol03`oo00=`3`
oo000`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`
oo000`000000oooo0?ooo`0X0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00
l?o`03L0l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0
oooo02P0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`00
0000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0
oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0
l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00503oool00`000000l?o`
0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`
0?3ol00g0?3ol0030000003oool0oooo02P0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<0
00000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<0
00000?ooo`3oool0:03oool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g
0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X
0?ooo`00503ooooZ000002X0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`
oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3o
ool0:03oool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol0030000
003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00503o
ool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00>03`
oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0oooo000D0?ooo`030000003`oo00
l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00
l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0oooo00<000000?3ol03`oo00=`3`oo000`00
0000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`00
0000oooo0?ooo`0X0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0
l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0
oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`
0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0oooo00<0
00000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<0
00000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00503oool00`000000l?o`0?3ol00g
0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g
0?3ol0030000003oool0oooo02P0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3o
l03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?oo
o`3oool0:03oool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol003
0000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00
503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00
>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0oooo000D0?ooo`030000003`
oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`
oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0oooo00<000000?3ol03`oo00=`3`oo00
0`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo00
0`000000oooo0?ooo`0X0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`
03L0l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo
02P0oooo000D0?ooonX00000:P3oool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`
0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo
0?ooo`0X0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`00<0
00000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0oooo000D
0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h
0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool00140oooo00@000000?oo
o`3oool00000>@3`oo000`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<00000
0?3ol03`oo00=`3`oo000`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo000A0?oo
o`040000003oool0oooo000003T0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h
0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q
0?ooo`002@3oool4000000@0oooo00@000000?ooo`3oool00000>@3`oo000`000000l?o`0?3ol00g
0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0240oooo000A0?ooo`040000003oool0oooo000003T0l?o`00<00000
0?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`003`3oool00`000000oooo000000020?oo
o`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3o
l0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool00P3oool00`000000oooo0000000S0?oo
o`00403oool200000080oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol003
0000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`030?ooo`80
00008`3oool00140oooo00@000000?ooo`3oool00000>@3`oo000`000000l?o`0?3ol00g0?3ol003
0000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0240oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00
=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0
:03oool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol0030000003`
oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00503oool0
0`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00>03`oo00
0`000000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0oooo000D0?ooo`030000003`oo00l?o`
03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`
03L0l?o`00<000000?ooo`3oool01`3oool2000000h0oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3o
l03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo00L0oooo1P00000;0?oo
o`030000003oool0000000d0oooo00080?ooool000002@0000090?ooo`030000003oool0oooo00`0
oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`
0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool01`3oool7000000X0oooo
00<000000?ooo`0000003@3oool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3o
l00g0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?oo
o`070?ooo`<000003@3oool01@000000oooo0?ooo`3oool0000000`0oooo000D0?ooo`030000003`
oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`
oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0oooo00<000000?3ol03`oo00=`3`oo00
0`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo00
0`000000oooo0?ooo`0X0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`
03L0l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo
02P0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000
l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0oooo
00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`
00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00503oool00`000000l?o`0?3o
l00g0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3o
l00g0?3ol0030000003oool0oooo02P0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<00000
0?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<00000
0?ooo`3oool0:03oool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3o
l0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?oo
o`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`
oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0oooo000D0?ooo`030000
003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000
003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0oooo00<000000?3ol03`oo00=`3`
oo000`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`
oo000`000000oooo0?ooo`0X0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00
l?o`03L0l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0
oooo02P0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`00
0000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0
oooojP00000Z0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`
00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0oooo
000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3o
l00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0oooo00<00000
0?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<00000
0?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00503oool00`000000l?o`0?3ol00g0?3o
l0030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3o
l0030000003oool0oooo02P0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`
oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3o
ool0:03oool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol0030000
003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00503o
ool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00>03`
oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0oooo000D0?ooo`030000003`oo00
l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00
l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0oooo00<000000?3ol03`oo00=`3`oo000`00
0000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`00
0000oooo0?ooo`0X0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0
l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0
oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`
0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0oooo00<0
00000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<0
00000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00503oool00`000000l?o`0?3ol00g
0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g
0?3ol0030000003oool0oooo02P0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3o
l03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?oo
o`3oool0:03oool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol003
0000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00
503ooooZ000002X0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`
oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03o
ool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol0030000003`oo00
l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00503oool00`00
0000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00>03`oo000`00
0000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0oooo000D0?ooo`030000003`oo00l?o`03L0
l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0
l?o`00<000000?ooo`3oool0:03oool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`
0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo
0?ooo`0X0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`00<0
00000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0oooo000D
0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h
0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0oooo00<000000?3o
l03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3o
l03`oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol003
0000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol003
0000003oool0oooo02P0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00
=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0
:03oool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol0030000003`
oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00503oool0
0`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00>03`oo00
0`000000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0oooo000D0?ooo`030000003`oo00l?o`
03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`
03L0l?o`00<000000?ooo`3oool0:03oool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000
l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000
oooo0?ooo`0X0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`
00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0oooo
000D0?ooonX00000:P3oool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g
0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X
0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3o
l03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0oooo000D0?ooo`03
0000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol003
0000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0oooo00<000000?3ol03`oo00
=`3`oo000`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00
=`3`oo000`000000oooo0?ooo`0X0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`
oo00l?o`03L0l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003o
ool0oooo02P0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo00
0`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool0
01@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`
03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00503oool00`000000
l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00>03`oo000`000000
l?o`0?3ol00g0?3ol0030000003oool0oooo02P0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`
00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`
00<000000?ooo`3oool0:03oool001@0oooo00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3o
l00g0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`oo00=`3`oo000`000000oooo0?oo
o`0X0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03L0l?o`00<00000
0?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000003oool0oooo02P0oooo000D0?oo
o`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`oo000`000000l?o`0?3ol00h0?3o
l0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03oool001@0oooo00<000000?3ol03`
oo00=`3`oo000`000000l?o`0?3ol00g0?3ol0030000003`oo00l?o`03P0l?o`00<000000?3ol03`
oo00=`3`oo000`000000oooo0?ooo`0X0?ooo`00503oool00`000000l?o`0?3ol00g0?3ol0030000
003`oo00l?o`03L0l?o`00<000000?3ol03`oo00>03`oo000`000000l?o`0?3ol00g0?3ol0030000
003oool0oooo02P0oooo000D0?ooo`030000003`oo00l?o`03L0l?o`00<000000?3ol03`oo00=`3`
oo000`000000l?o`0?3ol00h0?3ol0030000003`oo00l?o`03L0l?o`00<000000?ooo`3oool0:03o
ool001@0oooojP00000Z0?ooo`00R03oool00`000000oooo0?ooo`2M0?ooo`00R03oool00`000000
oooo0?ooo`2M0?ooo`00NP3oool3000000/0oooo00<000000?ooo`3oool0W@3oool007d0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`2M0?ooo`00O@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo09d0oooo001k0?ooo`8000002`3oool00`000000oooo0?ooo`2M0?oo
o`00O@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09d0oooo001[0?ooo`800000
3@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo09d0oooo001]0?ooo`030000
003oool0oooo00/0oooo0`00000:0?ooo`030000003oool0oooo09d0oooo001]0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0W@3oool006d0oooo0P0000030?ooo`@000004P3oool0
0`000000oooo0?ooo`2M0?ooo`00K@3oool2000000X0oooo200000070?ooo`030000003oool0oooo
09d0oooo001/0?ooo`040000003oool0oooo00000080oooo1000000B0?ooo`030000003oool0oooo
09d0oooo001[0?ooo`8000000P3oool2000001L0oooo00<000000?ooo`3oool0W@3oool008P0oooo
00<000000?ooo`3oool0W@3oool008P0oooo00<000000?ooo`3oool0W@3oool007/0oooo00<00000
0?ooo`3oool00P0000080?ooo`030000003oool0oooo09d0oooo001k0?ooo`80000000<0oooo0000
00000000203oool00`000000oooo0?ooo`2M0?ooo`00O03oool00`000000oooo000000090?ooo`03
0000003oool0oooo09d0oooo001l0?ooo`030000003oool0000000L0oooo1@00002M0?ooo`00NP3o
ool6000000H0oooo1@00002M0?ooo`00QP3oool4000009h0oooo00270?ooo`<00000WP3oool008L0
oooo0`00002N0?ooo`00Q`3oool3000009h0oooo00270?ooo`800000W`3oool008P0oooo00<00000
0?ooo`3oool0W@3oool008P0oooo00<000000?ooo`3oool0W@3oool00?l0oooo:@3oool00?l0oooo
:@3oool00?l0oooo:@3oool00?l0oooo:@3oool00?l0oooo:@3oool00?l0oooo:@3oool00?l0oooo
:@3oool00?l0oooo:@3oool008L0oooo00<000000?ooo`3oool0WP3oool008P0oooo00<000000?oo
o`3oool0W@3oool008P0oooo00<000000?ooo`3oool0W@3oool008L0oooo00<000000?ooo`000000
WP3oool008L0oooo00<000000?ooo`000000WP3oool008L0oooo00<000000?ooo`000000WP3oool0
08H0oooo00D000000?ooo`3oool0oooo0000002M0?ooo`00o`3ooolY0?ooo`00o`3ooolY0?ooo`00
o`3ooolY0?ooo`00o`3ooolY0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 295}, {181.875, 0}} -> {-1, -1, 0, 0}}],
  StyleBox["     ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.28571 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.0571429 0.285714 0.571429 0.285714 [
[.91429 .55893 -7.5 -13 ]
[.91429 .55893 7.5 0 ]
[.04464 0 -16.375 -6.5 ]
[.04464 0 0 6.5 ]
[.04464 .28571 -16.375 -6.5 ]
[.04464 .28571 0 6.5 ]
[.04464 .85714 -9.5 -6.5 ]
[.04464 .85714 0 6.5 ]
[.04464 1.14286 -9.5 -6.5 ]
[.04464 1.14286 0 6.5 ]
[ 0 0 0 0 ]
[ 1 1.28571 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.91429 .57143 m
.91429 .57768 L
s
gsave
.91429 .55893 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
74.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .57143 m
1 .57143 L
s
.05714 0 m
.06339 0 L
s
gsave
.04464 0 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.05714 .28571 m
.06339 .28571 L
s
gsave
.04464 .28571 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.05714 .85714 m
.06339 .85714 L
s
gsave
.04464 .85714 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.05714 1.14286 m
.06339 1.14286 L
s
gsave
.04464 1.14286 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.05714 0 m
.05714 1.28571 L
s
0 0 m
1 0 L
1 1.28571 L
0 1.28571 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
.13147 .49711 m
.13678 .50283 L
.14207 .50951 L
.14654 .51615 L
.15034 .52284 L
.15385 .53024 L
.15666 .53761 L
.15904 .54564 L
.15999 .54973 L
.16072 .55354 L
.16129 .55727 L
.16153 .55918 L
.16176 .56124 L
.16194 .56329 L
.16207 .56517 L
.16212 .56608 L
.16216 .56707 L
.16219 .56794 L
.16222 .56887 L
.16223 .56943 L
.16224 .56995 L
.16224 .5702 L
.16225 .57044 L
.16225 .57069 L
.16225 .57082 L
.16225 .57096 L
.16225 .5712 L
.16225 .57147 L
.16225 .57172 L
.16225 .57195 L
.16225 .57216 L
.16225 .57239 L
.16224 .57285 L
.16224 .57312 L
.16223 .5734 L
.16222 .5739 L
.16219 .57504 L
.16215 .57602 L
.1621 .57709 L
.16197 .57916 L
.16181 .58105 L
.16134 .58526 L
.16076 .58909 L
.15997 .59322 L
.15793 .60124 L
.15539 .60879 L
.1524 .61585 L
.14867 .6231 L
.14456 .62979 L
.13965 .63654 L
Mistroke
.13444 .64266 L
.12899 .64815 L
.12277 .65353 L
.1164 .65824 L
.1097 .66246 L
Mfstroke
.17968 .44889 m
.18844 .45833 L
.19717 .46934 L
.20453 .48028 L
.21081 .49131 L
.21658 .50352 L
.22122 .51566 L
.22514 .52891 L
.2267 .53566 L
.22791 .54193 L
.22886 .54808 L
.22926 .55123 L
.22962 .55462 L
.22992 .55801 L
.23013 .56112 L
.23021 .56261 L
.23029 .56424 L
.23034 .56567 L
.23039 .56721 L
.23041 .56814 L
.23042 .56899 L
.23043 .56941 L
.23043 .5698 L
.23043 .57021 L
.23043 .57042 L
.23044 .57065 L
.23044 .57106 L
.23044 .57149 L
.23044 .5719 L
.23044 .57229 L
.23043 .57263 L
.23043 .57301 L
.23042 .57377 L
.23041 .57422 L
.23041 .57468 L
.23039 .57551 L
.23034 .57738 L
.23027 .579 L
.23019 .58076 L
.22997 .58418 L
.22971 .58728 L
.22893 .59423 L
.22797 .60055 L
.22667 .60736 L
.22332 .62059 L
.21912 .63303 L
.2142 .64467 L
.20805 .65662 L
.20127 .66765 L
.19318 .67878 L
Mistroke
.18458 .68887 L
.1756 .69792 L
.16534 .7068 L
.15483 .71456 L
.14379 .72151 L
Mfstroke
.25917 .3694 m
.27362 .38496 L
.28801 .40311 L
.30015 .42116 L
.31049 .43934 L
.32001 .45947 L
.32766 .47949 L
.33412 .50133 L
.3367 .51245 L
.33869 .5228 L
.34025 .53293 L
.34091 .53812 L
.34151 .54372 L
.342 .54931 L
.34235 .55443 L
.34249 .55689 L
.34261 .55958 L
.3427 .56193 L
.34277 .56448 L
.34281 .566 L
.34283 .5674 L
.34284 .56809 L
.34284 .56874 L
.34285 .56941 L
.34285 .56977 L
.34285 .57015 L
.34286 .57081 L
.34286 .57153 L
.34286 .57221 L
.34285 .57284 L
.34285 .57341 L
.34285 .57403 L
.34283 .5753 L
.34282 .57602 L
.34281 .57679 L
.34278 .57816 L
.34269 .58124 L
.34258 .58391 L
.34244 .58682 L
.34208 .59246 L
.34166 .59757 L
.34037 .60902 L
.33879 .61944 L
.33665 .63067 L
.33112 .65247 L
.32419 .673 L
.31609 .69218 L
.30594 .71189 L
.29477 .73007 L
.28143 .74843 L
Mistroke
.26725 .76505 L
.25244 .77997 L
.23553 .79461 L
.21821 .80742 L
.2 .81886 L
Mfstroke
.39023 .23834 m
.41406 .264 L
.43778 .29391 L
.45779 .32367 L
.47484 .35365 L
.49053 .38684 L
.50315 .41984 L
.51381 .45586 L
.51806 .47419 L
.52133 .49125 L
.52391 .50795 L
.52499 .51652 L
.52599 .52575 L
.52679 .53496 L
.52737 .5434 L
.5276 .54746 L
.5278 .55189 L
.52795 .55577 L
.52807 .55997 L
.52812 .56248 L
.52816 .56479 L
.52817 .56593 L
.52819 .56699 L
.52819 .56811 L
.5282 .56869 L
.5282 .56933 L
.5282 .57042 L
.52821 .5716 L
.5282 .57272 L
.5282 .57376 L
.52819 .57469 L
.52819 .57572 L
.52816 .5778 L
.52815 .579 L
.52812 .58027 L
.52808 .58252 L
.52793 .58761 L
.52776 .592 L
.52752 .5968 L
.52693 .6061 L
.52623 .61453 L
.52411 .6334 L
.52151 .65059 L
.51797 .66911 L
.50886 .70505 L
.49744 .73888 L
.48407 .77051 L
.46735 .80302 L
.44892 .83299 L
.42693 .86325 L
Mistroke
.40354 .89066 L
.37913 .91526 L
.35125 .9394 L
.3227 .96051 L
.29267 .97938 L
Mfstroke
.60632 .02225 m
.64559 .06456 L
.68471 .11388 L
.7177 .16295 L
.74581 .21237 L
.77168 .26709 L
.79248 .32151 L
.81006 .38088 L
.81707 .41111 L
.82246 .43924 L
.82671 .46678 L
.8285 .48089 L
.83013 .49612 L
.83146 .5113 L
.83242 .52522 L
.83279 .53191 L
.83313 .53922 L
.83337 .54562 L
.83357 .55254 L
.83365 .55668 L
.83372 .56048 L
.83374 .56236 L
.83376 .56412 L
.83378 .56595 L
.83378 .56692 L
.83379 .56796 L
.83379 .56976 L
.83379 .57172 L
.83379 .57356 L
.83379 .57527 L
.83378 .57681 L
.83376 .57851 L
.83372 .58194 L
.83369 .58392 L
.83366 .586 L
.83358 .58972 L
.83334 .5981 L
.83305 .60534 L
.83267 .61326 L
.83169 .62859 L
.83054 .64249 L
.82704 .6736 L
.82275 .70195 L
.81691 .73247 L
.80189 .79174 L
.78307 .84752 L
.76103 .89966 L
.73346 .95325 L
.70307 1.00267 L
.66682 1.05255 L
Mistroke
.62826 1.09775 L
.58802 1.13831 L
.54204 1.17811 L
.49497 1.21291 L
.44547 1.24403 L
Mfstroke
.13147 .49711 m
.13775 .49082 L
.1452 .48337 L
.15284 .47574 L
.1608 .46777 L
.17 .45857 L
.17963 .44894 L
.19077 .4378 L
.20246 .42611 L
.21467 .41391 L
.22878 .39979 L
.24357 .385 L
.25898 .36959 L
.2768 .35177 L
.29544 .33314 L
.31698 .31159 L
.33958 .28899 L
.36317 .2654 L
.39044 .23814 L
.41898 .20959 L
.452 .17657 L
.48666 .14191 L
.52288 .1057 L
.56476 .06382 L
.60632 .02225 L
s
.14817 .51887 m
.15586 .51443 L
.165 .50916 L
.17434 .50376 L
.18409 .49813 L
.19536 .49163 L
.20716 .48482 L
.2208 .47694 L
.23512 .46868 L
.25007 .46004 L
.26736 .45006 L
.28546 .43961 L
.30435 .42871 L
.32617 .41611 L
.34899 .40293 L
.37538 .38769 L
.40306 .37171 L
.43195 .35504 L
.46534 .33575 L
.5003 .31557 L
.54074 .29222 L
.58319 .26772 L
.62755 .24211 L
.67884 .21249 L
.72974 .1831 L
s
.15867 .54422 m
.16725 .54193 L
.17744 .5392 L
.18786 .5364 L
.19874 .53349 L
.21131 .53012 L
.22446 .5266 L
.23968 .52252 L
.25565 .51824 L
.27232 .51377 L
.2916 .5086 L
.3118 .50319 L
.33286 .49755 L
.3572 .49103 L
.38266 .48421 L
.41209 .47632 L
.44296 .46805 L
.47518 .45942 L
.51243 .44943 L
.55142 .43899 L
.59652 .4269 L
.64387 .41422 L
.69335 .40096 L
.75056 .38563 L
.80733 .37042 L
s
.16225 .57143 m
.17113 .57143 L
.18168 .57143 L
.19247 .57143 L
.20373 .57143 L
.21675 .57143 L
.23037 .57143 L
.24612 .57143 L
.26265 .57143 L
.27991 .57143 L
.29988 .57143 L
.32079 .57143 L
.34259 .57143 L
.36779 .57143 L
.39414 .57143 L
.42461 .57143 L
.45657 .57143 L
.48993 .57143 L
.52849 .57143 L
.56886 .57143 L
.61555 .57143 L
.66457 .57143 L
.71579 .57143 L
.77502 .57143 L
.83379 .57143 L
s
.15867 .59863 m
.16725 .60093 L
.17744 .60366 L
.18786 .60645 L
.19874 .60937 L
.21131 .61274 L
.22446 .61626 L
.23968 .62034 L
.25565 .62462 L
.27232 .62909 L
.2916 .63425 L
.3118 .63966 L
.33286 .64531 L
.3572 .65183 L
.38266 .65865 L
.41209 .66654 L
.44296 .67481 L
.47518 .68344 L
.51243 .69342 L
.55142 .70387 L
.59652 .71596 L
.64387 .72864 L
.69335 .7419 L
.75056 .75723 L
.80733 .77244 L
s
.14817 .62398 m
.15586 .62842 L
.165 .6337 L
.17434 .63909 L
.18409 .64472 L
.19536 .65123 L
.20716 .65804 L
.2208 .66592 L
.23512 .67418 L
.25007 .68281 L
.26736 .69279 L
.28546 .70325 L
.30435 .71415 L
.32617 .72675 L
.34899 .73993 L
.37538 .75516 L
.40306 .77114 L
.43195 .78782 L
.46534 .8071 L
.5003 .82729 L
.54074 .85063 L
.58319 .87514 L
.62755 .90075 L
.67884 .93037 L
.72974 .95975 L
s
.13147 .64575 m
.13775 .65203 L
.1452 .65949 L
.15284 .66712 L
.1608 .67508 L
.17 .68429 L
.17963 .69392 L
.19077 .70505 L
.20246 .71674 L
.21467 .72895 L
.22878 .74307 L
.24357 .75785 L
.25898 .77327 L
.2768 .79109 L
.29544 .80972 L
.31698 .83127 L
.33958 .85387 L
.36317 .87745 L
.39044 .90472 L
.41898 .93327 L
.452 .96628 L
.48666 1.00094 L
.52288 1.03716 L
.56476 1.07904 L
.60632 1.1206 L
s
.1097 .66246 m
.11414 .67015 L
.11941 .67928 L
.12481 .68863 L
.13044 .69838 L
.13694 .70965 L
.14375 .72144 L
.15163 .73509 L
.1599 .7494 L
.16853 .76435 L
.17851 .78164 L
.18896 .79975 L
.19987 .81863 L
.21247 .84046 L
.22564 .86328 L
.24088 .88967 L
.25686 .91734 L
.27354 .94623 L
.29282 .97963 L
.313 1.01459 L
.33635 1.05502 L
.36086 1.09747 L
.38647 1.14183 L
.41608 1.19313 L
.44547 1.24403 L
s
.941 1 .941 r
.13147 .49711 m
.60632 .02225 L
.72974 .1831 L
.80733 .37042 L
.83379 .57143 L
.80733 .77244 L
.72974 .95975 L
.60632 1.1206 L
.44547 1.24403 L
.1097 .66246 L
.13147 .64575 L
.14817 .62398 L
.15867 .59863 L
.16225 .57143 L
.15867 .54422 L
.14817 .51887 L
F
0 g
.13147 .49711 m
.13678 .50283 L
.14207 .50951 L
.14654 .51615 L
.15034 .52284 L
.15385 .53024 L
.15666 .53761 L
.15904 .54564 L
.15999 .54973 L
.16072 .55354 L
.16129 .55727 L
.16153 .55918 L
.16176 .56124 L
.16194 .56329 L
.16207 .56517 L
.16212 .56608 L
.16216 .56707 L
.16219 .56794 L
.16222 .56887 L
.16223 .56943 L
.16224 .56995 L
.16224 .5702 L
.16225 .57044 L
.16225 .57069 L
.16225 .57082 L
.16225 .57096 L
.16225 .5712 L
.16225 .57147 L
.16225 .57172 L
.16225 .57195 L
.16225 .57216 L
.16225 .57239 L
.16224 .57285 L
.16224 .57312 L
.16223 .5734 L
.16222 .5739 L
.16219 .57504 L
.16215 .57602 L
.1621 .57709 L
.16197 .57916 L
.16181 .58105 L
.16134 .58526 L
.16076 .58909 L
.15997 .59322 L
.15793 .60124 L
.15539 .60879 L
.1524 .61585 L
.14867 .6231 L
.14456 .62979 L
.13965 .63654 L
Mistroke
.13444 .64266 L
.12899 .64815 L
.12277 .65353 L
.1164 .65824 L
.1097 .66246 L
Mfstroke
.17968 .44889 m
.18844 .45833 L
.19717 .46934 L
.20453 .48028 L
.21081 .49131 L
.21658 .50352 L
.22122 .51566 L
.22514 .52891 L
.2267 .53566 L
.22791 .54193 L
.22886 .54808 L
.22926 .55123 L
.22962 .55462 L
.22992 .55801 L
.23013 .56112 L
.23021 .56261 L
.23029 .56424 L
.23034 .56567 L
.23039 .56721 L
.23041 .56814 L
.23042 .56899 L
.23043 .56941 L
.23043 .5698 L
.23043 .57021 L
.23043 .57042 L
.23044 .57065 L
.23044 .57106 L
.23044 .57149 L
.23044 .5719 L
.23044 .57229 L
.23043 .57263 L
.23043 .57301 L
.23042 .57377 L
.23041 .57422 L
.23041 .57468 L
.23039 .57551 L
.23034 .57738 L
.23027 .579 L
.23019 .58076 L
.22997 .58418 L
.22971 .58728 L
.22893 .59423 L
.22797 .60055 L
.22667 .60736 L
.22332 .62059 L
.21912 .63303 L
.2142 .64467 L
.20805 .65662 L
.20127 .66765 L
.19318 .67878 L
Mistroke
.18458 .68887 L
.1756 .69792 L
.16534 .7068 L
.15483 .71456 L
.14379 .72151 L
Mfstroke
.25917 .3694 m
.27362 .38496 L
.28801 .40311 L
.30015 .42116 L
.31049 .43934 L
.32001 .45947 L
.32766 .47949 L
.33412 .50133 L
.3367 .51245 L
.33869 .5228 L
.34025 .53293 L
.34091 .53812 L
.34151 .54372 L
.342 .54931 L
.34235 .55443 L
.34249 .55689 L
.34261 .55958 L
.3427 .56193 L
.34277 .56448 L
.34281 .566 L
.34283 .5674 L
.34284 .56809 L
.34284 .56874 L
.34285 .56941 L
.34285 .56977 L
.34285 .57015 L
.34286 .57081 L
.34286 .57153 L
.34286 .57221 L
.34285 .57284 L
.34285 .57341 L
.34285 .57403 L
.34283 .5753 L
.34282 .57602 L
.34281 .57679 L
.34278 .57816 L
.34269 .58124 L
.34258 .58391 L
.34244 .58682 L
.34208 .59246 L
.34166 .59757 L
.34037 .60902 L
.33879 .61944 L
.33665 .63067 L
.33112 .65247 L
.32419 .673 L
.31609 .69218 L
.30594 .71189 L
.29477 .73007 L
.28143 .74843 L
Mistroke
.26725 .76505 L
.25244 .77997 L
.23553 .79461 L
.21821 .80742 L
.2 .81886 L
Mfstroke
.39023 .23834 m
.41406 .264 L
.43778 .29391 L
.45779 .32367 L
.47484 .35365 L
.49053 .38684 L
.50315 .41984 L
.51381 .45586 L
.51806 .47419 L
.52133 .49125 L
.52391 .50795 L
.52499 .51652 L
.52599 .52575 L
.52679 .53496 L
.52737 .5434 L
.5276 .54746 L
.5278 .55189 L
.52795 .55577 L
.52807 .55997 L
.52812 .56248 L
.52816 .56479 L
.52817 .56593 L
.52819 .56699 L
.52819 .56811 L
.5282 .56869 L
.5282 .56933 L
.5282 .57042 L
.52821 .5716 L
.5282 .57272 L
.5282 .57376 L
.52819 .57469 L
.52819 .57572 L
.52816 .5778 L
.52815 .579 L
.52812 .58027 L
.52808 .58252 L
.52793 .58761 L
.52776 .592 L
.52752 .5968 L
.52693 .6061 L
.52623 .61453 L
.52411 .6334 L
.52151 .65059 L
.51797 .66911 L
.50886 .70505 L
.49744 .73888 L
.48407 .77051 L
.46735 .80302 L
.44892 .83299 L
.42693 .86325 L
Mistroke
.40354 .89066 L
.37913 .91526 L
.35125 .9394 L
.3227 .96051 L
.29267 .97938 L
Mfstroke
.60632 .02225 m
.64559 .06456 L
.68471 .11388 L
.7177 .16295 L
.74581 .21237 L
.77168 .26709 L
.79248 .32151 L
.81006 .38088 L
.81707 .41111 L
.82246 .43924 L
.82671 .46678 L
.8285 .48089 L
.83013 .49612 L
.83146 .5113 L
.83242 .52522 L
.83279 .53191 L
.83313 .53922 L
.83337 .54562 L
.83357 .55254 L
.83365 .55668 L
.83372 .56048 L
.83374 .56236 L
.83376 .56412 L
.83378 .56595 L
.83378 .56692 L
.83379 .56796 L
.83379 .56976 L
.83379 .57172 L
.83379 .57356 L
.83379 .57527 L
.83378 .57681 L
.83376 .57851 L
.83372 .58194 L
.83369 .58392 L
.83366 .586 L
.83358 .58972 L
.83334 .5981 L
.83305 .60534 L
.83267 .61326 L
.83169 .62859 L
.83054 .64249 L
.82704 .6736 L
.82275 .70195 L
.81691 .73247 L
.80189 .79174 L
.78307 .84752 L
.76103 .89966 L
.73346 .95325 L
.70307 1.00267 L
.66682 1.05255 L
Mistroke
.62826 1.09775 L
.58802 1.13831 L
.54204 1.17811 L
.49497 1.21291 L
.44547 1.24403 L
Mfstroke
.13147 .49711 m
.13775 .49082 L
.1452 .48337 L
.15284 .47574 L
.1608 .46777 L
.17 .45857 L
.17963 .44894 L
.19077 .4378 L
.20246 .42611 L
.21467 .41391 L
.22878 .39979 L
.24357 .385 L
.25898 .36959 L
.2768 .35177 L
.29544 .33314 L
.31698 .31159 L
.33958 .28899 L
.36317 .2654 L
.39044 .23814 L
.41898 .20959 L
.452 .17657 L
.48666 .14191 L
.52288 .1057 L
.56476 .06382 L
.60632 .02225 L
s
.14817 .51887 m
.15586 .51443 L
.165 .50916 L
.17434 .50376 L
.18409 .49813 L
.19536 .49163 L
.20716 .48482 L
.2208 .47694 L
.23512 .46868 L
.25007 .46004 L
.26736 .45006 L
.28546 .43961 L
.30435 .42871 L
.32617 .41611 L
.34899 .40293 L
.37538 .38769 L
.40306 .37171 L
.43195 .35504 L
.46534 .33575 L
.5003 .31557 L
.54074 .29222 L
.58319 .26772 L
.62755 .24211 L
.67884 .21249 L
.72974 .1831 L
s
.15867 .54422 m
.16725 .54193 L
.17744 .5392 L
.18786 .5364 L
.19874 .53349 L
.21131 .53012 L
.22446 .5266 L
.23968 .52252 L
.25565 .51824 L
.27232 .51377 L
.2916 .5086 L
.3118 .50319 L
.33286 .49755 L
.3572 .49103 L
.38266 .48421 L
.41209 .47632 L
.44296 .46805 L
.47518 .45942 L
.51243 .44943 L
.55142 .43899 L
.59652 .4269 L
.64387 .41422 L
.69335 .40096 L
.75056 .38563 L
.80733 .37042 L
s
.16225 .57143 m
.17113 .57143 L
.18168 .57143 L
.19247 .57143 L
.20373 .57143 L
.21675 .57143 L
.23037 .57143 L
.24612 .57143 L
.26265 .57143 L
.27991 .57143 L
.29988 .57143 L
.32079 .57143 L
.34259 .57143 L
.36779 .57143 L
.39414 .57143 L
.42461 .57143 L
.45657 .57143 L
.48993 .57143 L
.52849 .57143 L
.56886 .57143 L
.61555 .57143 L
.66457 .57143 L
.71579 .57143 L
.77502 .57143 L
.83379 .57143 L
s
.15867 .59863 m
.16725 .60093 L
.17744 .60366 L
.18786 .60645 L
.19874 .60937 L
.21131 .61274 L
.22446 .61626 L
.23968 .62034 L
.25565 .62462 L
.27232 .62909 L
.2916 .63425 L
.3118 .63966 L
.33286 .64531 L
.3572 .65183 L
.38266 .65865 L
.41209 .66654 L
.44296 .67481 L
.47518 .68344 L
.51243 .69342 L
.55142 .70387 L
.59652 .71596 L
.64387 .72864 L
.69335 .7419 L
.75056 .75723 L
.80733 .77244 L
s
.14817 .62398 m
.15586 .62842 L
.165 .6337 L
.17434 .63909 L
.18409 .64472 L
.19536 .65123 L
.20716 .65804 L
.2208 .66592 L
.23512 .67418 L
.25007 .68281 L
.26736 .69279 L
.28546 .70325 L
.30435 .71415 L
.32617 .72675 L
.34899 .73993 L
.37538 .75516 L
.40306 .77114 L
.43195 .78782 L
.46534 .8071 L
.5003 .82729 L
.54074 .85063 L
.58319 .87514 L
.62755 .90075 L
.67884 .93037 L
.72974 .95975 L
s
.13147 .64575 m
.13775 .65203 L
.1452 .65949 L
.15284 .66712 L
.1608 .67508 L
.17 .68429 L
.17963 .69392 L
.19077 .70505 L
.20246 .71674 L
.21467 .72895 L
.22878 .74307 L
.24357 .75785 L
.25898 .77327 L
.2768 .79109 L
.29544 .80972 L
.31698 .83127 L
.33958 .85387 L
.36317 .87745 L
.39044 .90472 L
.41898 .93327 L
.452 .96628 L
.48666 1.00094 L
.52288 1.03716 L
.56476 1.07904 L
.60632 1.1206 L
s
.1097 .66246 m
.11414 .67015 L
.11941 .67928 L
.12481 .68863 L
.13044 .69838 L
.13694 .70965 L
.14375 .72144 L
.15163 .73509 L
.1599 .7494 L
.16853 .76435 L
.17851 .78164 L
.18896 .79975 L
.19987 .81863 L
.21247 .84046 L
.22564 .86328 L
.24088 .88967 L
.25686 .91734 L
.27354 .94623 L
.29282 .97963 L
.313 1.01459 L
.33635 1.05502 L
.36086 1.09747 L
.38647 1.14183 L
.41608 1.19313 L
.44547 1.24403 L
s
gsave
.98286 .61429 -65.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.1 1.26571 -65.4375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
67.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.86857 .51429 -66.5938 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
70.188 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.10571 .51429 -70.3438 -16.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.3125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.563 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.750 12.563 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
65.125 19.563 moveto
(\\200\\200) show
70.375 19.563 moveto
(\\200) show
72.688 19.563 moveto
(\\200) show
66.750 27.125 moveto
(\\343) show
77.688 19.563 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.91429 .57143 m
1 .57143 L
s
% Start of user PostScript
3. 0 3.3 0 MAarrowhead1
% End of user PostScript
.05714 1.25714 m
.05714 1.28571 L
s
% Start of user PostScript
0 2.4 0 2.5 MAarrowhead1
% End of user PostScript
gsave
.2 1.14286 -61 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
70.188 17.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.125 10.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
79.500 17.250 moveto
(\\200\\200) show
84.750 17.250 moveto
(\\200) show
87.063 17.250 moveto
(\\200) show
81.125 24.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
92.063 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.28571 .08571 -61 -14.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
70.188 17.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 17.250 moveto
(-) show
88.313 10.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
86.688 17.250 moveto
(\\200\\200) show
91.938 17.250 moveto
(\\200) show
94.250 17.250 moveto
(\\200) show
88.313 24.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
99.250 17.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{224, 287.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003P00017b000`400?l00000o`00003oh03oool0
0>00oooo003P0?ooo`00h03oool00>00oooo00080?ooo`D00000d`3oool000T0oooo00<000000?oo
o`3oool0e03oool000<0oooo100000030?ooo`030000003oool0oooo00H0oooo0P00003;0?ooo`00
2`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0<X0oooo000<0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0bP3oool000P0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo0<X0oooo00090?ooo`<000001`3oool00`000000oooo0?ooo`3:
0?ooo`004`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo05@0oooo000C0?ooo`03
0000003oool0oooo0780oooo00<000000?3ol0000000E@3oool001<0oooo00<000000?ooo`3oool0
L@3oool01@000000l?o`0?3ol03`oo00000005@0oooo000C0?ooo`030000003oool0oooo0700oooo
00<000000?3ol03`oo000`3`oo000`000000oooo0?ooo`1A0?ooo`004`3oool00`000000oooo0?oo
o`1_0?ooo`030000003`oo00l?o`00D0l?o`00<000000?ooo`3oool0D03oool001<0oooo00<00000
0?ooo`3oool0C@3oool3000001h0oooo00<000000?3ol03`oo001P3`oo000`3oool000000?ooo`1@
0?ooo`004`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01`0oooo00<000000?3o
l03`oo00203`oo000`3oool000000?ooo`1?0?ooo`004`3oool00`000000oooo0?ooo`1:0?ooo`H0
0000703oool00`000000l?o`0?3ol00:0?3ol0030?ooo`000000oooo04h0oooo000C0?ooo`030000
003oool0oooo04X0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000003`oo00l?o`00`0
l?o`00<0oooo0000003oool0C@3oool001<0oooo00<000000?ooo`3oool0B`3oool010000000oooo
0?ooo`00000K0?ooo`030000003`oo00l?o`00d0l?o`0P3oool00`000000oooo0?ooo`1;0?ooo`00
4`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`000000
6P3oool00`000000l?o`0?3ol00?0?3ol080oooo00<000000?ooo`3oool0BP3oool001<0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0000001T0oooo00<0
00000?3ol03`oo004@3`oo000`3oool000000?ooo`1;0?ooo`004`3oool00`000000oooo0?ooo`0b
0?ooo`<00000603oool2000001P0oooo00<000000?3ol03`oo004`3`oo000`3oool000000?ooo`1:
0?ooo`004`3oool00`000000oooo0?ooo`0a0?ooo`050000003oool000000?ooo`0000000P3oool5
000002T0oooo00<000000?3ol03`oo005@3`oo000`3oool000000?ooo`190?ooo`004`3oool00`00
0000oooo0?ooo`0a0?ooo`050000003oool000000?ooo`0000002@3oool5000000@0oooo2P00000C
0?ooo`030000003`oo00l?o`01H0l?o`0P3oool00`000000oooo0?ooo`170?ooo`004`3oool00`00
0000oooo0?ooo`0a0?ooo`050000003oool000000?ooo`0000000P3oool5000002L0oooo00<00000
0?3ol03`oo00603`oo000`3oool000000?ooo`180?ooo`004`3oool00`000000oooo0?ooo`0a0?oo
o`050000003oool000000?ooo`000000;@3oool00`000000l?o`0?3ol00J0?3ol0030?ooo`000000
oooo04L0oooo000C0?ooo`030000003oool0oooo0380oooo0`00000]0?ooo`030000003`oo00l?o`
01`0l?o`00<0oooo0000003oool0AP3oool001<0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0Z0?ooo`030000003`oo00l?o`01d0l?o`0P3oool00`000000oooo0?ooo`140?ooo`00
4`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0>0?ooo`030000003`oo00l?o`01l0l?o`00<0oooo0000003oool0
A@3oool001<0oooo00<000000?ooo`3oool0BP3oool01@000000oooo0?ooo`3oool000000100oooo
00<000000?3ol03`oo008@3`oo000`3oool000000?ooo`140?ooo`004`3oool00`000000oooo0?oo
o`1;0?ooo`040000003oool0oooo000000l0oooo00<000000?3ol03`oo008`3`oo000`3oool00000
0?ooo`130?ooo`004`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0000000h0oooo00<0
00000?3ol03`oo00903`oo000`3oool000000?ooo`130?ooo`004`3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0000000d0oooo00<000000?3ol03`oo009P3`oo000`3oool000000?ooo`12
0?ooo`004`3oool00`000000oooo0?ooo`1:0?ooo`L000002P3oool00`000000l?o`0?3ol00X0?3o
l0030?ooo`000000oooo0440oooo000C0?ooo`030000003oool0oooo05X0oooo00<000000?3ol03`
oo00:P3`oo000`000000oooo0?ooo`100?ooo`004`3oool00`000000oooo0?ooo`1I0?ooo`030000
003`oo00l?o`02`0l?o`00<000000?ooo`3oool0?`3oool001<0oooo00<000000?ooo`3oool0F03o
ool00`000000l?o`0?3ol00]0?3ol0030?ooo`000000oooo03l0oooo000C0?ooo`030000003oool0
oooo05L0oooo00<000000?3ol03`oo00;`3`oo000`3oool000000?ooo`0n0?ooo`004`3oool00`00
0000oooo0?ooo`1F0?ooo`030000003`oo00l?o`0340l?o`00<000000?ooo`3oool0?@3oool001<0
oooo00<000000?ooo`3oool0E@3oool00`000000l?o`0?3ol00c0?3ol0030000003oool0oooo03`0
oooo000C0?ooo`030000003oool0oooo05@0oooo00<000000?3ol03`oo00=03`oo000`3oool00000
0?ooo`0l0?ooo`004`3oool00`000000oooo0?ooo`1C0?ooo`030000003`oo00l?o`03H0l?o`00<0
00000?ooo`3oool0>`3oool001<0oooo00<000000?ooo`3oool0DP3oool00`000000l?o`0?3ol00h
0?3ol0030000003oool0oooo03X0oooo000C0?ooo`030000003oool0oooo0540oooo00<000000?3o
l03`oo00>P3`oo000`000000oooo0?ooo`0i0?ooo`004`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003`oo00l?o`03/0l?o`00<000000?ooo`3oool0>@3oool001<0oooo00<000000?ooo`3oool0
C`3oool00`000000l?o`0?3ol00j0?3ol080000000<0l?o`0000003oool0>@3oool001<0oooo00<0
00000?ooo`3oool0CP3oool00`000000l?o`0?3ol00i0?3ol08000000`3`oo000`000000oooo0?oo
o`0h0?ooo`004`3oool00`000000oooo0?ooo`1>0?ooo`030000003`oo00l?o`03L0l?o`0P000006
0?3ol0030000003oool0oooo03L0oooo000C0?ooo`030000003oool0oooo04d0oooo00<000000?3o
l03`oo00=P3`oo02000000P0l?o`00<0oooo0000003oool0=`3oool001<0oooo00<000000?ooo`3o
ool0C03oool00`000000l?o`0?3ol00e0?3ol08000002`3`oo000`000000oooo0?ooo`0f0?ooo`00
4`3oool00`000000oooo0?ooo`1;0?ooo`030000003`oo00l?o`03D0l?o`00<000000?3ol03`oo00
2`3`oo000`3oool000000?ooo`0f0?ooo`004`3oool00`000000oooo0?ooo`1:0?ooo`030000003`
oo00l?o`03@0l?o`0P00000>0?3ol0030?ooo`000000oooo03H0oooo000C0?ooo`030000003oool0
oooo04T0oooo00<000000?3ol03`oo00=03`oo000`000000l?o`0?3ol00?0?3ol0030?ooo`000000
oooo03D0oooo000C0?ooo`030000003oool0oooo04P0oooo00<000000?3ol03`oo00<`3`oo020000
0180l?o`00<0oooo0000003oool0=@3oool001<0oooo00<000000?ooo`3oool0A`3oool00`000000
l?o`0?3ol00b0?3ol08000005@3`oo000`3oool000000?ooo`0d0?ooo`004`3oool00`000000oooo
0?ooo`160?ooo`030000003`oo00l?o`0380l?o`00<000000?3ol03`oo005@3`oo000`3oool00000
0?ooo`0d0?ooo`004`3oool00`000000oooo0?ooo`150?ooo`030000003`oo00l?o`0340l?o`0P00
000I0?3ol0030000003oool0oooo03<0oooo000C0?ooo`030000003oool0oooo04@0oooo00<00000
0?3ol0000000<@3`oo000`000000l?o`0?3ol00I0?3ol0030?ooo`000000oooo03<0oooo000C0?oo
o`030000003oool0oooo04<0oooo00D000000?3ol03`oo00l?o`0000000^0?3ol0800000703`oo00
0`3oool000000?ooo`0c0?ooo`004`3oool00`000000oooo0?ooo`120?ooo`030000003`oo00l?o`
00<0l?o`00<000000?3ol03`oo00:@3`oo02000001l0l?o`00<0oooo0000003oool0<P3oool001<0
oooo00<000000?ooo`3oool0@@3oool00`000000l?o`0?3ol0050?3ol0030000003`oo00l?o`02H0
l?o`0P00000Q0?3ol0030?ooo`000000oooo0380oooo000C0?ooo`030000003oool0oooo0400oooo
00<000000?3ol03`oo001`3`oo000`000000l?o`0?3ol00S0?3ol0800000903`oo000`3oool00000
0?ooo`0a0?ooo`004`3oool00`000000oooo0?ooo`0o0?ooo`030000003`oo00l?o`00T0l?o`00<0
00000?3ol03`oo00803`oo02000002H0l?o`00<0oooo0000003oool0<@3oool001<0oooo00<00000
0?ooo`3oool0?P3oool00`000000l?o`0?3ol00:0?3ol0030000003`oo00l?o`01h0l?o`0P00000Y
0?3ol0030000003oool0oooo0300oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0?@3oool00`000000l?o`0?3ol00<0?3ol0030000003`oo00l?o`01/0l?o`0P00000[0?3o
l0030?ooo`000000oooo0300oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0?03oool00`000000l?o`0?3ol00>0?3ol0030000003`oo00l?o`01P0l?o`0P00000]0?3ol003
0?ooo`000000oooo0300oooo00030?ooo`@00000103oool00`000000oooo0?ooo`050?ooo`800000
?03oool00`000000l?o`0?3ol00@0?3ol0030000003`oo00l?o`01D0l?o`0P00000`0?3ol0030?oo
o`000000oooo02l0oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0>P3o
ool00`000000l?o`0?3ol00A0?3ol0030000003`oo00l?o`01@0l?o`00<000000?3ol03`oo00<03`
oo000`3oool000000?ooo`0_0?ooo`002@3oool00`000000oooo000000070?ooo`030000003oool0
oooo03T0oooo00<000000?3ol03`oo004`3`oo000`000000l?o`0?3ol00A0?3ol0800000=03`oo00
0`000000oooo0?ooo`0^0?ooo`002P3oool2000000L0oooo00<000000?ooo`3oool0>03oool00`00
0000l?o`0?3ol00E0?3ol0030000003`oo00l?o`00h0l?o`0P00000f0?3ol0030?ooo`000000oooo
02h0oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0=`3oool00`000000
l?o`0?3ol00F0?3ol0030000003`oo00l?o`00`0l?o`0P00000i0?3ol0030000003oool0oooo02d0
oooo000C0?ooo`030000003oool0oooo03H0oooo00<000000?3ol03`oo00603`oo000`000000l?o`
0?3ol0090?3ol0800000>`3`oo000`3oool000000?ooo`0]0?ooo`004`3oool00`000000oooo0?oo
o`0e0?ooo`030000003`oo00l?o`01X0l?o`00<000000?3ol03`oo001`3`oo000`000000l?o`0?3o
l00k0?3ol0030?ooo`000000oooo02d0oooo000C0?ooo`030000003oool0oooo03@0oooo00<00000
0?3ol03`oo006`3`oo000`000000l?o`0?3ol0050?3ol0800000?`3`oo000`3oool000000?ooo`0/
0?ooo`004`3oool00`000000oooo0?ooo`0b0?ooo`8000007`3`oo000`000000l?o`0?3ol0030?3o
l0030000003`oo00l?o`03l0l?o`00<0oooo0000003oool0;03oool001<0oooo00<000000?ooo`3o
ool0<@3oool00`000000l?o`0?3ol00P0?3ol0050000003`oo00l?o`0?3ol0000000@`3`oo000`00
0000oooo0?ooo`0[0?ooo`004`3oool00`000000oooo0?ooo`0`0?ooo`030000003`oo00l?o`0240
l?o`00@000000?3ol00000000000A03`oo000`000000oooo0?ooo`0[0?ooo`004`3oool00`000000
oooo0?ooo`0_0?ooo`030000003`oo00l?o`02<0l?o`00<000000?3ol03`oo00A@3`oo000`000000
oooo0?ooo`0Z0?ooo`004`3oool00`000000oooo0?ooo`0^0?ooo`030000003`oo00l?o`0280l?o`
0`0000170?3ol0030000003oool0oooo02X0oooo000C0?ooo`030000003oool0oooo02d0oooo00<0
00000?3ol03`oo008@3`oo02000000<0l?o`00<000000?3ol03`oo00A03`oo000`000000oooo0?oo
o`0Z0?ooo`004`3oool00`000000oooo0?ooo`0/0?ooo`030000003`oo00l?o`0200l?o`0P000005
0?3ol0030000003`oo00l?o`04@0l?o`00<000000?ooo`3oool0:P3oool001<0oooo00<000000?oo
o`3oool0:`3oool00`000000l?o`0?3ol00P0?3ol0030000003`oo00l?o`00H0l?o`00<000000?3o
l03`oo00A03`oo000`000000oooo0?ooo`0Y0?ooo`004`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003`oo00l?o`01l0l?o`0P0000090?3ol0030000003`oo00l?o`04@0l?o`00<000000?ooo`3o
ool0:@3oool001<0oooo00<000000?ooo`3oool0:@3oool00`000000l?o`0?3ol00N0?3ol0800000
303`oo000`000000l?o`0?3ol0130?3ol0030000003oool0oooo02T0oooo000C0?ooo`030000003o
ool0oooo02P0oooo00<000000?3ol03`oo007@3`oo02000000h0l?o`00<000000?3ol03`oo00@`3`
oo02000002X0oooo000C0?ooo`030000003oool0oooo02L0oooo00<000000?3ol00000007@3`oo00
0`000000l?o`0?3ol00?0?3ol0030000003`oo00l?o`03l0l?o`0`0000000`3`oo0000000?ooo`0Y
0?ooo`004`3oool00`000000oooo0?ooo`0V0?ooo`040000003`oo00l?o`000001/0l?o`0P00000B
0?3ol0030000003`oo00l?o`03`0l?o`0`0000040?3ol0030000003oool0oooo02P0oooo000C0?oo
o`030000003oool0oooo02H0oooo00D000000?3ol03`oo00l?o`0000000H0?3ol08000005@3`oo00
0`000000l?o`0?3ol00h0?3ol0<000001`3`oo000`000000oooo0?ooo`0X0?ooo`004`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003`oo00l?o`00<0l?o`00<000000?3ol03`oo004`3`oo020000
01L0l?o`00<000000?3ol03`oo00=03`oo04000000X0l?o`00<000000?ooo`3oool0:03oool001<0
oooo00<000000?ooo`3oool0903oool00`000000l?o`0?3ol0050?3ol0030000003`oo00l?o`0100
l?o`0P00000I0?3ol0030000003`oo00l?o`0300l?o`1000000?0?3ol0030000003oool0oooo02L0
oooo000C0?ooo`030000003oool0oooo02<0oooo00<000000?3ol03`oo001`3`oo02000000h0l?o`
0P00000L0?3ol0030000003`oo00l?o`02/0l?o`1000000C0?3ol0030000003oool0oooo02L0oooo
000C0?ooo`030000003oool0oooo0280oooo00<000000?3ol03`oo002P3`oo000`000000l?o`0?3o
l00:0?3ol0030000003`oo00l?o`01`0l?o`00<000000?3ol03`oo009`3`oo04000001L0l?o`00<0
00000?ooo`3oool09`3oool001<0oooo00<000000?ooo`3oool08@3oool00`000000l?o`0?3ol00;
0?3ol0030000003`oo00l?o`00P0l?o`0P00000P0?3ol0030000003`oo00l?o`0280l?o`1000000L
0?3ol0030000003oool0oooo02H0oooo000C0?ooo`030000003oool0oooo0200oooo00<000000?3o
l03`oo003@3`oo000`000000l?o`0?3ol0050?3ol08000008P3`oo000`000000l?o`0?3ol00N0?3o
l0@00000803`oo000`000000oooo0?ooo`0V0?ooo`004`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003`oo00l?o`00h0l?o`00<000000?3ol03`oo00103`oo000`000000l?o`0?3ol00S0?3ol003
0000003`oo00l?o`01X0l?o`0`00000T0?3ol0030000003oool0oooo02H0oooo000C0?ooo`030000
003oool0oooo01d0oooo0P00000B0?3ol0040000003`oo00l?o`0?3ol08000009P3`oo000`000000
l?o`0?3ol00G0?3ol0<000009`3`oo000`000000oooo0?ooo`0V0?ooo`004`3oool00`000000oooo
0?ooo`0L0?ooo`030000003`oo00l?o`0180l?o`00@000000?3ol00000000000:03`oo000`000000
l?o`0?3ol00C0?3ol0@00000:P3`oo000`000000oooo0?ooo`0V0?ooo`004`3oool00`000000oooo
0?ooo`0K0?ooo`030000003`oo00l?o`01@0l?o`00<000000?3ol03`oo00:03`oo000`000000l?o`
0?3ol00?0?3ol0@00000;P3`oo000`3oool000000?ooo`0V0?ooo`004`3oool00`000000oooo0?oo
o`0J0?ooo`030000003`oo00l?o`01<0l?o`0`00000[0?3ol0030000003`oo00l?o`00T0l?o`1@00
000b0?3ol0030?ooo`000000oooo02H0oooo000C0?ooo`030000003oool0oooo01T0oooo00<00000
0?3ol03`oo004P3`oo02000000<0l?o`00<000000?3ol03`oo00:03`oo000`000000l?o`0?3ol005
0?3ol0@00000>03`oo000`000000oooo0?ooo`0U0?ooo`004`3oool00`000000oooo0?ooo`0H0?oo
o`030000003`oo00l?o`0180l?o`00<000000?3ol03`oo000`3`oo000`000000l?o`0?3ol00X0?3o
l0040000003`oo00l?o`0?3ol0@00000?03`oo000`000000oooo0?ooo`0U0?ooo`004`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003`oo00l?o`0140l?o`0P0000070?3ol0030000003`oo00l?o`
02L0l?o`100000100?3ol0030000003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo01H0
oooo00<000000?3ol00000004@3`oo000`000000l?o`0?3ol0070?3ol0030000003`oo00l?o`02D0
l?o`0P0000000`3`oo0000000?3ol0110?3ol0030000003oool0oooo02D0oooo000C0?ooo`030000
003oool0oooo01D0oooo00D000000?3ol03`oo00l?o`0000000>0?3ol08000002`3`oo000`000000
l?o`0?3ol00Q0?3ol0<000000`3`oo000`000000l?o`0?3ol0100?3ol0030?ooo`000000oooo02D0
oooo000C0?ooo`030000003oool0oooo01@0oooo00<000000?3ol03`oo000`3`oo000`000000l?o`
0?3ol0090?3ol08000003@3`oo000`000000l?o`0?3ol00L0?3ol0D000001P3`oo000`000000l?o`
0?3ol0100?3ol0030?ooo`000000oooo02D0oooo000C0?ooo`030000003oool0oooo01<0oooo00<0
00000?3ol03`oo00103`oo000`000000l?o`0?3ol0070?3ol08000003`3`oo000`000000l?o`0?3o
l00G0?3ol0D000002`3`oo000`000000l?o`0?3ol0100?3ol0030?ooo`000000oooo02D0oooo000C
0?ooo`030000003oool0oooo00D0oooo1@0000080?ooo`030000003`oo00l?o`00H0l?o`00<00000
0?3ol03`oo00103`oo0200000180l?o`00<000000?3ol03`oo004P3`oo0400000140l?o`00<00000
0?3ol03`oo00?`3`oo000`3oool000000?ooo`0U0?ooo`004`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0000000X0oooo00<000000?3ol03`oo001`3`oo000`000000l?o`0?3ol0020?3o
l0800000503`oo000`000000l?o`0?3ol00?0?3ol0<000005@3`oo000`000000l?o`0?3ol0100?3o
l0030000003oool0oooo02@0oooo000C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`00
00002@3oool00`000000l?o`0?3ol0090?3ol0040000003`oo000000000001L0l?o`00<000000?3o
l03`oo002`3`oo03000001P0l?o`00<000000?3ol03`oo00@03`oo000`000000oooo0?ooo`0T0?oo
o`004`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<000001P3oool00`000000
l?o`0?3ol00:0?3ol0030000003`oo00l?o`01L0l?o`00<000000?3ol03`oo001`3`oo04000001`0
l?o`00<000000?3ol03`oo00?`3`oo000`000000oooo0?ooo`0T0?ooo`004`3oool00`000000oooo
0?ooo`040?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool2000000/0l?o`
0`00000I0?3ol0030000003`oo00l?o`0080l?o`1@00000P0?3ol0030000003`oo00l?o`03l0l?o`
00<000000?ooo`3oool0903oool001<0oooo00<000000?ooo`3oool01@3oool4000000@0oooo00<0
00000?3ol03`oo002P3`oo001@000000l?o`0?3ol03`oo00000001T0l?o`00@000000?3ol0000000
00009@3`oo000`000000l?o`0?3ol00o0?3ol0030?ooo`000000oooo02@0oooo000C0?ooo`030000
003oool0oooo00d0oooo00<000000?3ol03`oo00203`oo02000000@0l?o`00<000000?3ol03`oo00
5P3`oo03000002L0l?o`00<000000?3ol03`oo00?`3`oo000`3oool000000?ooo`0T0?ooo`004`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003`oo00l?o`00D0l?o`0P0000070?3ol0030000003`
oo00l?o`0100l?o`1@0000000`3`oo0000000?3ol00X0?3ol0030000003`oo00l?o`03h0l?o`00<0
oooo0000003oool00`3oool5000001`0oooo000C0?ooo`030000003oool0oooo00l0oooo00<00000
0?3ol03`oo000P3`oo02000000T0l?o`00<000000?3ol03`oo00303`oo04000000H0l?o`00<00000
0?3ol03`oo009`3`oo000`000000l?o`0?3ol00o0?3ol0070000003oool0oooo0?ooo`000000oooo
0000000O0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`X000000`3oool01@000000l?o`0?3o
l03`oo00000000`0l?o`00<000000?3ol03`oo001`3`oo04000000/0l?o`00<000000?3ol03`oo00
9P3`oo000`000000l?o`0?3ol00o0?3ol0070000003oool0oooo0?ooo`000000oooo0000000O0?oo
o`004`3oool00`000000oooo0?ooo`0@0?ooo`<000003@3`oo000`000000l?o`0?3ol0040?3ol0<0
00003`3`oo000`000000l?o`0?3ol00V0?3ol0030000003`oo00l?o`03l0l?o`00H000000?ooo`3o
ool0oooo0000003oool4000000T0oooo0`00000@0?ooo`004`3oool00`000000oooo0?ooo`0A0?oo
o`030000003`oo00l?o`00`0l?o`00<000000?3ol03`oo001000000B0?3ol0030000003`oo00l?o`
02H0l?o`00<000000?3ol03`oo00?`3`oo001`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000003`3oool001<0oooo00<0
00000?ooo`3oool04@3oool00`000000l?o`0?3ol00<0?3ol0<000005P3`oo000`000000l?o`0?3o
l00V0?3ol0030000003`oo00l?o`03l0l?o`00<000000?ooo`3oool00P3oool4000000d0oooo00<0
00000?ooo`3oool03@3oool001<0oooo00<000000?ooo`3oool04@3oool00`000000l?o`0?3ol009
0?3ol0<0000000<0l?o`0000003`oo005`3`oo000`000000l?o`0?3ol00U0?3ol0030000003`oo00
l?o`03l0l?o`00<000000?ooo`3oool04@3oool200000100oooo000C0?ooo`030000003oool0oooo
00D0oooo1@0000070?ooo`030000003`oo00l?o`00D0l?o`100000040?3ol0030000003`oo00l?o`
01H0l?o`00<000000?3ol03`oo009@3`oo000`000000l?o`0?3ol00o0?3ol0030000003oool0oooo
01<0oooo00<000000?ooo`3oool03@3oool001<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003`oo00000000@000002@3`oo000`000000l?o`0?3ol00E0?3ol003
0000003`oo00l?o`02D0l?o`00<000000?3ol03`oo00?`3`oo000`000000oooo0?ooo`0?0?ooo`05
0000003oool0oooo0?ooo`0000003`3oool001<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`090?ooo`030000003`oo00l?o`00`0l?o`00<000000?3ol03`oo005@3`oo000`000000
l?o`0?3ol00U0?3ol0030000003`oo00l?o`03l0l?o`00<000000?ooo`3oool0403oool300000100
oooo000C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000l?o`
0?3ol00<0?3ol0030000003`oo00l?o`01D0l?o`00<000000?3ol03`oo009@3`oo000`000000l?o`
0?3ol00o0?3ol0030000003oool0oooo02<0oooo000C0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool00`000000l?o`0?3ol00<0?3ol0030000003`oo00l?o`01D0l?o`00<0
00000?3ol03`oo009@3`oo000`000000l?o`0?3ol0100?3ol0030000003oool0oooo0280oooo000C
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000l?o`0?3ol00<
0?3ol0030000003`oo00l?o`01D0l?o`00<000000?3ol03`oo009@3`oo000`000000l?o`0?3ol010
0?3ol0030000003oool0oooo0280oooo000C0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02@3oool00`000000l?o`0?3ol00<0?3ol0030000003`oo00l?o`01D0l?o`00<000000?3o
l03`oo009@3`oo000`000000l?o`0?3ol0100?3ol0030000003oool0oooo01T0oooo0P0000070?oo
o`004`3oool00`000000oooo0?ooo`060?ooo`8000002`3oool2000000d0l?o`00<000000?3ol03`
oo005@3`oo000`000000l?o`0?3ol00U0?3ol0030000003`oo00l?o`0400l?o`00<000000?ooo`3o
ool06@3oool6000000<0oooo00060?ooomX00000000C0?ooo`030000003oool0oooo01<0oooo00<0
00000?3ol03`oo00303`oo000`000000l?o`0?3ol00E0?3ol0030000003`oo00l?o`02D0l?o`00<0
00000?3ol03`oo00@03`oo000`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo1`00
00020?ooo`004`3oool00`000000oooo0?ooo`0C0?ooo`030000003`oo00l?o`00`0l?o`00<00000
0?3ol03`oo005@3`oo000`000000l?o`0?3ol00U0?3ol0030000003`oo00l?o`0400l?o`00<00000
0?ooo`3oool06@3oool3000000H0oooo000C0?ooo`030000003oool0oooo01<0oooo00<000000?3o
l03`oo00303`oo000`000000l?o`0?3ol00E0?3ol0030000003`oo00l?o`02D0l?o`00<000000?3o
l03`oo00@03`oo000`000000oooo0?ooo`0R0?ooo`004`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003`oo00l?o`00`0l?o`00<000000?3ol03`oo005@3`oo000`000000l?o`0?3ol00U0?3ol003
0000003`oo00l?o`0400l?o`00<000000?ooo`3oool08P3oool001<0oooo00<000000?ooo`3oool0
4`3oool00`000000l?o`0?3ol00<0?3ol0030000003`oo00l?o`01D0l?o`00<000000?3ol03`oo00
9@3`oo000`000000l?o`0?3ol00o0?3ol0030000003oool0oooo02<0oooo000C0?ooo`030000003o
ool0oooo0180oooo1000000<0?3ol0030000003`oo00l?o`01D0l?o`00<000000?3ol03`oo009@3`
oo000`000000l?o`0?3ol00o0?3ol0030000003oool0oooo02<0oooo000C0?ooo`030000003oool0
oooo0180oooo00@000000?3ol03`oo00l?o`100000070?3ol0030000003`oo00l?o`01H0l?o`00<0
00000?3ol03`oo009@3`oo000`000000l?o`0?3ol00o0?3ol0030000003oool0oooo01d0oooo0`00
00030?ooo`004`3oool00`000000oooo0?ooo`0B0?ooo`030000003`oo00l?o`00D0l?o`0`000004
0?3ol0030000003`oo00l?o`01H0l?o`00<000000?3ol03`oo009@3`oo000`000000l?o`0?3ol00o
0?3ol0030000003oool0oooo01`0oooo00@000000?ooo`3oool000000`3oool001<0oooo00<00000
0?ooo`3oool04@3oool00`000000l?o`0?3ol0090?3ol0<0000000<0l?o`0000003`oo005P3`oo00
0`000000l?o`0?3ol00V0?3ol0030000003`oo00l?o`03l0l?o`00<000000?ooo`3oool0703oool0
10000000oooo0?ooo`0000030?ooo`004`3oool00`000000oooo0?ooo`0@0?ooo`030000003`oo00
l?o`00d0l?o`1P00000C0?3ol0030000003`oo00l?o`02H0l?o`00<000000?3ol03`oo00?`3`oo00
0`000000oooo0?ooo`0L0?ooo`040000003oool0oooo000000<0oooo000C0?ooo`030000003oool0
oooo0100oooo00<000000?3ol03`oo003P3`oo000`000000l?o`0?3ol0020?3ol0@000003`3`oo00
0`000000l?o`0?3ol00V0?3ol0030000003`oo00l?o`03l0l?o`00<000000?ooo`3oool0703oool0
10000000oooo0?ooo`0000030?ooo`004`3oool00`000000oooo0?ooo`0?0?ooo`040000003`oo00
0000000000d0l?o`00<000000?3ol03`oo001`3`oo03000000`0l?o`00<000000?3ol03`oo009P3`
oo000`000000l?o`0?3ol00o0?3ol0030000003oool0oooo02<0oooo000C0?ooo`030000003oool0
oooo00h0oooo00<000000?3ol03`oo000P3`oo02000000/0l?o`00<000000?3ol03`oo002P3`oo04
000000P0l?o`00<000000?3ol03`oo009P3`oo000`000000l?o`0?3ol00o0?3ol0030000003oool0
oooo02<0oooo000C0?ooo`030000003oool0oooo00h0oooo00<000000?3ol03`oo00103`oo020000
00T0l?o`00<000000?3ol03`oo003P3`oo02000000H0l?o`00<000000?3ol03`oo009P3`oo000`00
0000l?o`0?3ol00o0?3ol0030000003oool0oooo02<0oooo000C0?ooo`030000003oool0oooo00d0
oooo00<000000?3ol03`oo001`3`oo000`000000l?o`0?3ol0050?3ol0030000003`oo00l?o`0140
l?o`0`0000020?3ol0030000003`oo00l?o`02H0l?o`00<000000?3ol03`oo00?`3`oo000`3oool0
00000?ooo`0T0?ooo`004`3oool00`000000oooo0?ooo`0<0?ooo`8000002P3`oo000`000000l?o`
0?3ol0040?3ol0030000003`oo00l?o`01@0l?o`1@00000V0?3ol0030000003`oo00l?o`03l0l?o`
00<0oooo0000003oool0903oool001<0oooo00<000000?ooo`3oool02`3oool010000000l?o`0?3o
l000000:0?3ol08000000`3`oo000`000000l?o`0?3ol00G0?3ol0030000003`oo00l?o`00@00000
8P3`oo000`000000l?o`0?3ol00o0?3ol0030?ooo`000000oooo02@0oooo000C0?ooo`030000003o
ool0oooo00/0oooo00D000000?3ol03`oo00l?o`0000000;0?3ol0<000006P3`oo000`000000l?o`
0?3ol0040?3ol0<000007`3`oo000`000000l?o`0?3ol00o0?3ol0030?ooo`000000oooo02@0oooo
000C0?ooo`030000003oool0oooo00T0oooo0P0000050?3ol0030000003`oo00l?o`00X0l?o`0P00
000H0?3ol0030000003`oo00l?o`00P0l?o`1000000J0?3ol0030000003`oo00l?o`0400l?o`00<0
00000?ooo`3oool0903oool001<0oooo00<000000?ooo`3oool0203oool00`000000l?o`0?3ol005
0?3ol0030000003`oo00l?o`00T0l?o`00<000000?3ol03`oo000P00000F0?3ol0030000003`oo00
l?o`00`0l?o`1@00000E0?3ol0030000003`oo00l?o`0400l?o`00<000000?ooo`3oool0903oool0
01<0oooo00<000000?ooo`3oool02@3oool00`000000l?o`0?3ol0050?3ol0030000003`oo00l?o`
00P0l?o`00<000000?3ol03`oo000P3`oo02000001<0l?o`00<000000?3ol03`oo004P3`oo040000
0140l?o`00<000000?3ol03`oo00@03`oo000`000000oooo0?ooo`0T0?ooo`004`3oool00`000000
oooo0?ooo`090?ooo`030000003`oo00l?o`00H0l?o`0P0000070?3ol0030000003`oo00l?o`00D0
l?o`00<000000?3ol03`oo00403`oo000`000000l?o`0?3ol00F0?3ol0<000003P3`oo000`000000
l?o`0?3ol00o0?3ol0030?ooo`000000oooo02D0oooo000C0?ooo`030000003oool0oooo00X0oooo
00<000000?3ol03`oo001`3`oo000`000000l?o`0?3ol0030?3ol0030000003`oo00l?o`00L0l?o`
0P00000@0?3ol0030000003`oo00l?o`01T0l?o`100000090?3ol0030000003`oo00l?o`0400l?o`
00<0oooo0000003oool09@3oool001<0oooo00<000000?ooo`3oool02P3oool00`000000l?o`0?3o
l0080?3ol0050000003`oo00l?o`0?3ol0000000303`oo000`000000l?o`0?3ol00<0?3ol0030000
003`oo00l?o`01h0l?o`0`0000060?3ol0030000003`oo00l?o`0400l?o`00<0oooo0000003oool0
9@3oool001<0oooo00<000000?ooo`3oool02`3oool00`000000l?o`0?3ol0080?3ol0030000003`
oo00000000h0l?o`0P00000<0?3ol0030000003`oo00l?o`0240l?o`100000020?3ol0030000003`
oo00l?o`0400l?o`00<000000?ooo`3oool09@3oool001<0oooo00<000000?ooo`3oool02`3oool0
0`000000l?o`0?3ol0090?3ol0030000003`oo00l?o`00l0l?o`0P00000:0?3ol0030000003`oo00
l?o`02D0l?o`100000110?3ol0030000003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo
00`0oooo00<000000?3ol03`oo001`3`oo000`000000l?o`0000000B0?3ol08000001`3`oo000`00
0000l?o`0?3ol00W0?3ol0030000003`oo00l?o`00@00000?@3`oo000`000000oooo0?ooo`0U0?oo
o`004`3oool00`000000oooo0?ooo`0=0?ooo`030000003`oo00l?o`00D0l?o`00@000000?3ol03`
oo000000503`oo02000000@0l?o`00<000000?3ol03`oo00:03`oo000`000000l?o`0?3ol0040?3o
l0@00000>@3`oo000`000000oooo0?ooo`0U0?ooo`004`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003`oo00l?o`00@0l?o`00<000000?3ol03`oo000P3`oo000`000000l?o`0?3ol00C0?3ol005
0000003`oo00l?o`0?3ol0000000:P3`oo000`000000l?o`0?3ol0080?3ol0<00000=@3`oo000`3o
ool000000?ooo`0V0?ooo`004`3oool00`000000oooo0?ooo`0>0?ooo`030000003`oo00l?o`0080
l?o`00<000000?3ol03`oo00103`oo02000001@0l?o`0`00000[0?3ol0030000003`oo00l?o`00/0
l?o`1000000a0?3ol0030?ooo`000000oooo02H0oooo000C0?ooo`030000003oool0oooo00h0oooo
00<000000?3ol03`oo000P0000090?3ol0030000003`oo00l?o`0180l?o`0`00000Y0?3ol0030000
003`oo00l?o`0100l?o`0`00000^0?3ol0030?ooo`000000oooo02H0oooo000C0?ooo`030000003o
ool0oooo00l0oooo0P00000<0?3ol0030000003`oo00l?o`0140l?o`00<000000?3ol03`oo000P00
000W0?3ol0030000003`oo00l?o`01<0l?o`0`00000[0?3ol0030000003oool0oooo02H0oooo000C
0?ooo`030000003oool0oooo0100oooo00<000000?3ol03`oo002`3`oo000`000000l?o`0?3ol00?
0?3ol0030000003`oo00l?o`00<0l?o`0P00000U0?3ol0030000003`oo00l?o`01H0l?o`1000000W
0?3ol0030000003oool0oooo02H0oooo000C0?ooo`030000003oool0oooo0100oooo00<000000?3o
l03`oo00303`oo000`000000l?o`0?3ol00>0?3ol0030000003`oo00l?o`00D0l?o`0P00000S0?3o
l0030000003`oo00l?o`01X0l?o`0`00000T0?3ol0030000003oool0oooo02H0oooo000C0?ooo`03
0000003oool0oooo0140oooo00<000000?3ol03`oo00303`oo000`000000l?o`0?3ol00<0?3ol003
0000003`oo00l?o`00P0l?o`0P00000P0?3ol0030000003`oo00l?o`01h0l?o`1000000P0?3ol003
0000003oool0oooo02H0oooo000C0?ooo`030000003oool0oooo0180oooo00<000000?3ol03`oo00
303`oo000`000000l?o`0?3ol00:0?3ol0030000003`oo00l?o`00/0l?o`00<000000?3ol03`oo00
7@3`oo000`000000l?o`0?3ol00R0?3ol0@000006`3`oo000`3oool000000?ooo`0W0?ooo`004`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003`oo00l?o`00d0l?o`00<000000?3ol03`oo002@3`
oo000`000000l?o`0?3ol00<0?3ol0030000003`oo00l?o`01`0l?o`00<000000?3ol03`oo009P3`
oo04000001L0l?o`00<000000?ooo`3oool09`3oool001<0oooo00<000000?ooo`3oool04`3oool0
0`000000l?o`0?3ol00=0?3ol0030000003`oo00l?o`00L0l?o`00<000000?3ol03`oo003P3`oo02
000001/0l?o`00<000000?3ol03`oo00:`3`oo04000001<0l?o`00<000000?ooo`3oool09`3oool0
01<0oooo00<000000?ooo`3oool04`3oool00`000000l?o`0?3ol00>0?3ol0030000003`oo00l?o`
00D0l?o`00<000000?3ol03`oo004@3`oo000`000000l?o`0?3ol00H0?3ol0030000003`oo00l?o`
02l0l?o`1000000?0?3ol0030000003oool0oooo02L0oooo000C0?ooo`030000003oool0oooo01@0
oooo00<000000?3ol03`oo003P3`oo000`000000l?o`0?3ol0030?3ol0030000003`oo00l?o`01<0
l?o`00<000000?3ol03`oo005P3`oo000`000000l?o`0?3ol00d0?3ol0@000002`3`oo000`000000
oooo0?ooo`0W0?ooo`004`3oool00`000000oooo0?ooo`0D0?ooo`030000003`oo00l?o`00l0l?o`
00<000000?3ol03`oo000P3`oo000`000000l?o`0?3ol00D0?3ol08000005P3`oo000`000000l?o`
0?3ol00h0?3ol0@000001P3`oo000`000000oooo0?ooo`0X0?ooo`004`3oool00`000000oooo0?oo
o`0E0?ooo`030000003`oo00l?o`00l0l?o`00@000000?3ol03`oo0000006@3`oo02000001<0l?o`
00<000000?3ol03`oo00?@3`oo0400000080l?o`00<000000?ooo`3oool0:03oool001<0oooo00<0
00000?ooo`3oool05P3oool00`000000l?o`0?3ol00?0?3ol0800000703`oo0200000140l?o`00<0
00000?3ol03`oo00@@3`oo03000002X0oooo000C0?ooo`030000003oool0oooo01H0oooo00<00000
0?3ol03`oo003`3`oo02000001h0l?o`0P00000>0?3ol0030000003`oo00l?o`04@0l?o`00<00000
0?ooo`3oool0:03oool001<0oooo00<000000?ooo`3oool05`3oool00`000000l?o`0?3ol00=0?3o
l0040000003`oo00l?o`000001l0l?o`0P00000<0?3ol0030000003`oo00l?o`04<0l?o`00<00000
0?ooo`3oool0:@3oool001<0oooo00<000000?ooo`3oool05`3oool00`000000l?o`0?3ol00<0?3o
l0030000003`oo00l?o`0080l?o`00<000000?3ol03`oo007P3`oo02000000T0l?o`00<000000?3o
l03`oo00A03`oo000`000000oooo0?ooo`0Y0?ooo`004`3oool00`000000oooo0?ooo`0H0?ooo`03
0000003`oo00l?o`00T0l?o`0P0000060?3ol0030000003`oo00l?o`01l0l?o`00<000000?3ol03`
oo001P3`oo000`000000l?o`0?3ol0140?3ol0030000003oool0oooo02T0oooo000C0?ooo`030000
003oool0oooo01P0oooo00<000000?3ol03`oo00203`oo000`000000l?o`0?3ol0070?3ol0030000
003`oo00l?o`01l0l?o`0P0000050?3ol0030000003`oo00l?o`04@0l?o`00<0oooo0000003oool0
:P3oool001<0oooo00<000000?ooo`3oool06@3oool00`000000l?o`0?3ol0060?3ol0030000003`
oo00l?o`00T0l?o`00<000000?3ol03`oo00803`oo02000000<0l?o`00<000000?3ol03`oo00A03`
oo000`000000oooo0?ooo`0Z0?ooo`004`3oool00`000000oooo0?ooo`0I0?ooo`030000003`oo00
l?o`00@0l?o`0P00000=0?3ol0030000003`oo00l?o`0240l?o`0`0000170?3ol0030000003oool0
oooo02X0oooo000C0?ooo`030000003oool0oooo01X0oooo00<000000?3ol03`oo000P3`oo000`00
0000l?o`0?3ol00>0?3ol0030000003`oo00l?o`0240l?o`0P0000160?3ol0030?ooo`000000oooo
02/0oooo000C0?ooo`030000003oool0oooo01X0oooo00<000000?3ol03`oo000P00000B0?3ol003
0000003`oo00l?o`0200l?o`00@000000?3ol00000000000A03`oo000`000000oooo0?ooo`0[0?oo
o`004`3oool00`000000oooo0?ooo`0K0?ooo`8000005@3`oo000`000000l?o`0?3ol00N0?3ol003
0000003`oo00l?o`0080l?o`0P0000110?3ol0030?ooo`000000oooo02`0oooo000C0?ooo`030000
003oool0oooo01`0oooo00<000000?3ol03`oo00503`oo000`000000l?o`0?3ol00L0?3ol0030000
003`oo00l?o`00D0l?o`0P00000o0?3ol0030?ooo`000000oooo02`0oooo000C0?ooo`030000003o
ool0oooo01`0oooo00<000000?3ol03`oo005@3`oo000`000000l?o`0?3ol00K0?3ol0030000003`
oo00l?o`00L0l?o`00<000000?3ol03`oo00?03`oo000`3oool000000?ooo`0/0?ooo`004`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003`oo00l?o`01D0l?o`00<000000?3ol03`oo006@3`oo00
0`000000l?o`0?3ol0090?3ol0800000>`3`oo000`3oool000000?ooo`0]0?ooo`004`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003`oo00l?o`01H0l?o`00<000000?3ol03`oo005`3`oo000`00
0000l?o`0?3ol00<0?3ol0800000>@3`oo000`3oool000000?ooo`0]0?ooo`004`3oool00`000000
oooo0?ooo`0N0?ooo`030000003`oo00l?o`01H0l?o`00<000000?3ol03`oo005P3`oo000`000000
l?o`0?3ol00>0?3ol0800000=P3`oo020?ooo`030000003oool0oooo02`0oooo000;0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool07`3oool00`000000l?o`0?3ol00F0?3ol0030000
003`oo00l?o`01@0l?o`00<000000?3ol03`oo004@3`oo02000003@0l?o`00<0oooo0000003oool0
;P3oool000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?ooo`030000003`
oo00l?o`01L0l?o`00<000000?3ol03`oo004`3`oo000`000000l?o`0?3ol00C0?3ol0030000003`
oo00l?o`0300l?o`0P3oool00`000000oooo0?ooo`0]0?ooo`002`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0200oooo00<000000?3ol03`oo005`3`oo000`000000l?o`0?3ol00A
0?3ol0030000003`oo00l?o`01D0l?o`0P00000`0?3ol080oooo00<000000?ooo`3oool0;@3oool0
00/0oooo00<000000?ooo`3oool01@3oool200000240oooo00<000000?3ol03`oo00603`oo000`00
0000l?o`0?3ol00@0?3ol0030000003`oo00l?o`01L0l?o`00<000000?3ol03`oo00;@3`oo000`3o
ool000000?ooo`0_0?ooo`002@3oool00`000000oooo000000070?ooo`030000003oool0oooo0240
oooo00<000000?3ol03`oo00603`oo000`000000l?o`0?3ol00>0?3ol0030000003`oo00l?o`01T0
l?o`0P00000/0?3ol080oooo00<000000?ooo`3oool0;P3oool000X0oooo0P0000070?ooo`030000
003oool0oooo0240oooo00<000000?3ol03`oo006@3`oo000`000000l?o`0?3ol00<0?3ol0030000
003`oo00l?o`01`0l?o`00<000000?3ol03`oo00:@3`oo000`3oool000000?ooo`0`0?ooo`002`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<000000?3ol03`oo006@3`
oo000`000000l?o`0?3ol00:0?3ol0030000003`oo00l?o`01h0l?o`0P00000X0?3ol080oooo00<0
00000?ooo`3oool0;`3oool001<0oooo00<000000?ooo`3oool08P3oool00`000000l?o`0?3ol00J
0?3ol0030000003`oo00l?o`00P0l?o`00<000000?3ol03`oo008@3`oo000`000000l?o`0?3ol00U
0?3ol0030?ooo`000000oooo0340oooo000C0?ooo`030000003oool0oooo02<0oooo00<000000?3o
l03`oo006P3`oo000`000000l?o`0?3ol0070?3ol0030000003`oo00l?o`0280l?o`0P00000U0?3o
l0030?ooo`000000oooo0340oooo000C0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3`
oo006`3`oo000`000000l?o`0?3ol0050?3ol0030000003`oo00l?o`02D0l?o`0P00000R0?3ol003
0?ooo`000000oooo0380oooo000C0?ooo`030000003oool0oooo02@0oooo00<000000?3ol03`oo00
6`3`oo000`000000l?o`0?3ol0030?3ol0030000003`oo00l?o`02P0l?o`0P00000P0?3ol0030?oo
o`000000oooo0380oooo000C0?ooo`030000003oool0oooo02D0oooo00<000000?3ol03`oo006`3`
oo001@000000l?o`0?3ol03`oo00000002d0l?o`0P00000M0?3ol0030?ooo`000000oooo03<0oooo
000C0?ooo`030000003oool0oooo02D0oooo00<000000?3ol03`oo00703`oo000`000000l?o`0000
000`0?3ol08000006`3`oo000`3oool000000?ooo`0c0?ooo`004`3oool00`000000oooo0?ooo`0V
0?ooo`030000003`oo00l?o`01/0l?o`0P00000c0?3ol0800000603`oo000`3oool000000?ooo`0d
0?ooo`004`3oool00`000000oooo0?ooo`0W0?ooo`030000003`oo00l?o`01T0l?o`00@000000?3o
l03`oo000000=03`oo02000001H0l?o`00<0oooo0000003oool0=03oool001<0oooo00<000000?oo
o`3oool09`3oool00`000000l?o`0?3ol00H0?3ol0030000003`oo00l?o`0080l?o`00<000000?3o
l03`oo00<`3`oo02000001@0l?o`00<000000?ooo`3oool0=03oool001<0oooo00<000000?ooo`3o
ool0:03oool00`000000l?o`0?3ol00F0?3ol0030000003`oo00l?o`00@0l?o`00<000000?3ol03`
oo00=03`oo0200000140l?o`00<0oooo0000003oool0=@3oool001<0oooo00<000000?ooo`3oool0
:03oool00`000000l?o`0?3ol00E0?3ol0030000003`oo00l?o`00H0l?o`00<000000?3ol03`oo00
=@3`oo02000000l0l?o`00<000000?ooo`3oool0=@3oool001<0oooo00<000000?ooo`3oool0:@3o
ool00`000000l?o`0?3ol00B0?3ol08000002P3`oo000`000000l?o`0?3ol00f0?3ol0030000003`
oo00l?o`00/0l?o`00<0oooo0000003oool0=P3oool001<0oooo00<000000?ooo`3oool0:@3oool0
0`000000l?o`0?3ol00A0?3ol0030000003`oo00l?o`00/0l?o`00<000000?3ol03`oo00=P3`oo02
000000/0l?o`00<000000?ooo`3oool0=P3oool001<0oooo00<000000?ooo`3oool0:P3oool00`00
0000l?o`0?3ol00?0?3ol0030000003`oo00l?o`00d0l?o`00<000000?3ol03`oo00=`3`oo000`00
0000l?o`0?3ol0080?3ol0030000003oool0oooo03H0oooo000C0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3`oo003P3`oo000`000000l?o`0?3ol00?0?3ol0030000003`oo00l?o`03L0
l?o`0P0000070?3ol0030000003oool0oooo03L0oooo000C0?ooo`030000003oool0oooo02/0oooo
00<000000?3ol03`oo00303`oo000`000000l?o`0?3ol00A0?3ol0030000003`oo00l?o`03P0l?o`
0P0000050?3ol0030000003oool0oooo03L0oooo000C0?ooo`030000003oool0oooo02`0oooo00<0
00000?3ol03`oo002@3`oo02000001D0l?o`00<000000?3ol03`oo00>@3`oo001@000000l?o`0?3o
l03`oo00000003X0oooo000C0?ooo`030000003oool0oooo02`0oooo00<000000?3ol03`oo00203`
oo000`000000l?o`0?3ol00F0?3ol0030000003`oo00l?o`03T0l?o`0`00000k0?ooo`004`3oool0
0`000000oooo0?ooo`0]0?ooo`030000003`oo00l?o`00H0l?o`00<000000?3ol03`oo00603`oo00
0`000000l?o`0?3ol00j0?3ol0030000003oool0oooo03T0oooo000C0?ooo`030000003oool0oooo
02h0oooo00<000000?3ol03`oo000`3`oo02000001`0l?o`00<000000?3ol03`oo00>03`oo000`00
0000oooo0?ooo`0j0?ooo`004`3oool00`000000oooo0?ooo`0_0?ooo`050000003`oo00l?o`0?3o
l00000007`3`oo000`000000l?o`0?3ol00f0?3ol0030000003oool0oooo03/0oooo000C0?ooo`03
0000003oool0oooo02l0oooo00@000000?3ol000000000008@3`oo000`000000l?o`0?3ol00e0?3o
l0030000003oool0oooo03/0oooo000C0?ooo`030000003oool0oooo0300oooo00<000000?3ol03`
oo008P3`oo000`000000l?o`0?3ol00c0?3ol0030000003oool0oooo03`0oooo000C0?ooo`030000
003oool0oooo0300oooo00<000000?3ol03`oo008P3`oo000`000000l?o`0?3ol00c0?3ol0030000
003oool0oooo03`0oooo000C0?ooo`030000003oool0oooo0340oooo00<000000?3ol03`oo008P3`
oo000`000000l?o`0?3ol00a0?3ol0030000003oool0oooo03d0oooo000C0?ooo`030000003oool0
oooo0340oooo00<000000?3ol03`oo008`3`oo000`000000l?o`0?3ol00_0?3ol0030000003oool0
oooo03h0oooo000C0?ooo`030000003oool0oooo0380oooo00<000000?3ol03`oo008`3`oo000`00
0000l?o`0?3ol00]0?3ol0030?ooo`000000oooo03l0oooo000C0?ooo`030000003oool0oooo0380
oooo00<000000?3ol03`oo00903`oo000`000000l?o`0?3ol00/0?3ol0030000003oool0oooo03l0
oooo000C0?ooo`030000003oool0oooo03<0oooo00<000000?3ol03`oo00903`oo000`000000l?o`
0?3ol00Z0?3ol0030000003oool0oooo0400oooo000C0?ooo`030000003oool0oooo03<0oooo00<0
00000?3ol03`oo009@3`oo000`000000l?o`0?3ol00X0?3ol0030?ooo`000000oooo0440oooo000C
0?ooo`030000003oool0oooo03@0oooo00<000000?3ol03`oo009@3`oo000`000000l?o`0?3ol00V
0?3ol0030?ooo`000000oooo0480oooo000C0?ooo`030000003oool0oooo03D0oooo00<000000?3o
l03`oo009@3`oo000`000000l?o`0?3ol00T0?3ol0030?ooo`000000oooo04<0oooo000C0?ooo`03
0000003oool0oooo03D0oooo00<000000?3ol03`oo009P3`oo000`000000l?o`0?3ol00S0?3ol003
0000003oool0oooo04<0oooo000C0?ooo`030000003oool0oooo03H0oooo00<000000?3ol03`oo00
9P3`oo000`000000l?o`0?3ol00Q0?3ol0030?ooo`000000oooo04@0oooo000C0?ooo`030000003o
ool0oooo03H0oooo00<000000?3ol03`oo009`3`oo000`000000l?o`0?3ol00O0?3ol0030?ooo`00
0000oooo04D0oooo000C0?ooo`030000003oool0oooo03L0oooo00<000000?3ol03`oo009`3`oo00
0`000000l?o`0?3ol00M0?3ol0030?ooo`000000oooo04H0oooo000C0?ooo`030000003oool0oooo
03P0oooo00<000000?3ol03`oo009`3`oo000`000000l?o`0?3ol00L0?3ol0030000003oool0oooo
04H0oooo000C0?ooo`030000003oool0oooo03P0oooo00<000000?3ol03`oo00:03`oo000`000000
l?o`0?3ol00J0?3ol0030?ooo`000000oooo04L0oooo000C0?ooo`030000003oool0oooo03T0oooo
00<000000?3ol03`oo00:03`oo000`000000l?o`0?3ol00H0?3ol0030?ooo`000000oooo04P0oooo
000C0?ooo`030000003oool0oooo03T0oooo00<000000?3ol03`oo00:@3`oo000`000000l?o`0?3o
l00F0?3ol0030?ooo`000000oooo04T0oooo000C0?ooo`030000003oool0oooo03X0oooo00<00000
0?3ol03`oo00:@3`oo000`000000l?o`0?3ol00E0?3ol0030000003oool0oooo04T0oooo000C0?oo
o`030000003oool0oooo03X0oooo00<000000?3ol03`oo00:P3`oo000`000000l?o`0?3ol00C0?3o
l0030?ooo`000000oooo04X0oooo000C0?ooo`030000003oool0oooo03/0oooo00<000000?3ol03`
oo00:P3`oo000`000000l?o`0?3ol00A0?3ol0030?ooo`000000oooo04/0oooo000C0?ooo`030000
003oool0oooo03/0oooo00<000000?3ol03`oo00:`3`oo000`000000l?o`0?3ol00?0?3ol0030?oo
o`000000oooo04`0oooo000C0?ooo`030000003oool0oooo03`0oooo00<000000?3ol03`oo00:`3`
oo000`000000l?o`0?3ol00=0?3ol0030?ooo`000000oooo04d0oooo000C0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3`oo00;03`oo000`000000l?o`0?3ol00<0?3ol0030000003oool0
oooo04d0oooo000C0?ooo`030000003oool0oooo03d0oooo00<000000?3ol03`oo00;03`oo000`00
0000l?o`0?3ol00:0?3ol0030?ooo`000000oooo04h0oooo000C0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3`oo00;@3`oo000`000000l?o`0?3ol0080?3ol0030?ooo`000000oooo04l0
oooo000C0?ooo`030000003oool0oooo03h0oooo00<000000?3ol03`oo00;@3`oo000`000000l?o`
0?3ol0060?3ol0030?ooo`000000oooo0500oooo000C0?ooo`030000003oool0oooo0380oooo0`00
000:0?ooo`030000003`oo00l?o`02d0l?o`00<000000?3ol03`oo001@3`oo000`000000oooo0?oo
o`1@0?ooo`004`3oool00`000000oooo0?ooo`0a0?ooo`050000003oool0oooo0?ooo`0000002@3o
ool00`000000oooo0?3ol00^0?3ol0030000003`oo00l?o`00<0l?o`00<000000?ooo`3oool0D@3o
ool001<0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`080?ooo`030000003`oo00
l?o`02h0l?o`00D000000?3ol03`oo00l?o`0000001D0?ooo`004`3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo00T0oooo00<000000?3ol03`oo00;P3`oo03000005D0oooo000C0?oo
o`030000003oool0oooo03<0oooo0P00000<0?ooo`030000003`oo00l?o`02h0l?o`0P00001F0?oo
o`004`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool02P3oool00`000000l?o`0?3ol00/0?3ol0030000003oool0oooo05H0oooo00080?ooo`D00000
1P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0
oooo0000000=0?ooo`030000003`oo00l?o`02X0l?o`00<000000?ooo`3oool0E`3oool000T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?ooo`<000003`3oool3000000h0oooo
00<000000?3ol03`oo00:@3`oo000`000000oooo0?ooo`1H0?ooo`002P3oool00`000000oooo0?oo
o`060?ooo`800000803oool01@000000oooo0000003oool000000080oooo1@00000I0?ooo`030000
003`oo00l?o`02L0l?o`00<000000?ooo`3oool0F@3oool000/0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0O0?ooo`050000003oool000000?ooo`0000002P3oool;000000`0oooo
00<000000?3ol03`oo009@3`oo000`000000oooo0?ooo`1J0?ooo`00303oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01l0oooo00D000000?ooo`000000oooo000000020?ooo`D00000
6P3oool00`000000l?o`0?3ol00T0?3ol0030000003oool0oooo05/0oooo00080?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0O0?ooo`050000003oool000000?ooo`00
00008P3oool00`000000l?o`0?3ol00Q0?3ol0030?ooo`000000oooo05d0oooo00090?ooo`<00000
1`3oool00`000000oooo0?ooo`0P0?ooo`<000008`3oool00`000000l?o`0?3ol00P0?3ol0800000
G`3oool001<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003`
oo00l?o`01h0l?o`00<000000?ooo`3oool0G`3oool001<0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool0
0`000000l?o`0?3ol00L0?3ol0030?ooo`000000oooo0640oooo000C0?ooo`030000003oool0oooo
0340oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003`oo00l?o`01X0l?o`00<0oooo
0000003oool0HP3oool001<0oooo00<000000?ooo`3oool0<P3oool010000000oooo0?ooo`00000B
0?ooo`030000003`oo00l?o`01T0l?o`00<0oooo0000003oool0H`3oool001<0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0000000C0?ooo`030000003`oo00l?o`01H0l?o`0P3oool00`00
0000oooo0?ooo`1S0?ooo`004`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0000001<0
oooo00<000000?3ol03`oo005@3`oo000`3oool000000000001V0?ooo`004`3oool00`000000oooo
0?ooo`0a0?ooo`L000004P3oool00`000000l?o`0?3ol00C0?3ol0030?ooo`000000oooo06L0oooo
000C0?ooo`030000003oool0oooo04/0oooo00<000000?3ol03`oo004@3`oo000`3oool000000?oo
o`1X0?ooo`004`3oool00`000000oooo0?ooo`1;0?ooo`030000003`oo00l?o`00l0l?o`0P3oool0
0`000000oooo0?ooo`1X0?ooo`004`3oool00`000000oooo0?ooo`1<0?ooo`030000003`oo00l?o`
00d0l?o`00<0oooo000000000000J`3oool001<0oooo00<000000?ooo`3oool0C@3oool00`000000
l?o`0?3ol00;0?3ol0030?ooo`000000oooo06`0oooo000C0?ooo`030000003oool0oooo04d0oooo
00<000000?3ol03`oo002@3`oo020?ooo`030000003oool0oooo06`0oooo000C0?ooo`030000003o
ool0oooo04h0oooo00<000000?3ol03`oo001`3`oo000`3oool000000000001_0?ooo`004`3oool0
0`000000oooo0?ooo`1>0?ooo`030000003`oo00l?o`00H0l?o`0P00001a0?ooo`004`3oool00`00
0000oooo0?ooo`1?0?ooo`030000003`oo00l?o`00<0l?o`00<0oooo0000003oool0LP3oool001<0
oooo00<000000?ooo`3oool0D03oool010000000l?o`0?3ol03`oo02000007@0oooo000C0?ooo`03
0000003oool0oooo0500oooo00@000000?3ol00000000000MP3oool001<0oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`1f0?ooo`004@3oool500000<X0oooo000A0?ooo`D00000bP3o
ool00140oooo100000060?ooo`030000003oool0oooo0<80oooo000B0?ooo`<000001@3oool00`00
0000oooo000000330?ooo`004P3oool3000000D0oooo00<000000?ooo`000000``3oool00180oooo
0`0000050?ooo`030000003oool000000<<0oooo000B0?ooo`8000001@3oool01@000000oooo0?oo
o`3oool000000<80oooo000C0?ooo`030000003oool0oooo0<X0oooo000C0?ooo`030000003oool0
oooo0<X0oooo003P0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 223}, {286.938, 0}} -> {0, -2, 0, 0}}],
  StyleBox["  \n\t\tFigure 5.3",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The image of  ",
  Cell[BoxData[
      \(\(R\^*\)\)]],
  " under the transformation  ",
  Cell[BoxData[
      \(w\  = \ \(\[ExponentialE]\^z\  = \ exp \((z)\)\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(w = \(f[z] = \[ExponentialE]\^z\)\)]],
  ".  \n",
  StyleBox["For illustration.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We graph the image of  the rectangle ",
  Cell[BoxData[
      \(R = {\((x, y)\) : \(-1\) \[LessEqual] x \[LessEqual] 
              1\ \ and\ \ \(-\[Pi]\)\/3 \[LessEqual] 
              y \[LessEqual] \[Pi]\/4}\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z];\)\ \ \), "\[IndentingNewLine]", 
    \(Clear[f]\), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \ \), "\n", 
    \(\(f[z_]\  = \ \[ExponentialE]\^z;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {\(-1\), 1, 
          0.25}, {\(-\[Pi]\)\/3, \[Pi]\/4, \[Pi]\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-1.2\), 1.2}, {\(-1.2\), 1.2}}, 
        AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], {\(-\[Pi]\)\/3, \[Pi]\/4}}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Magenta, 
            Pink}];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The rectangle R = {(x,y): -1 \[LessEqual] x \[LessEqual] \
1 and \!\(\(-\[Pi]\)\/3\) \[LessEqual] y \[LessEqual] \!\(\[Pi]\/4\)}.\>\""];\
\)\ \ \), "\n", 
    \(\(CartesianMap[
        f, {\(-1\), 1, 
          0.25}, {\(-\[Pi]\)\/3, \[Pi]\/4, \[Pi]\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-0.2\), 3}, {\(-2.5\), 2.3}}, 
        AspectRatio \[Rule] 4.8\/3.2, 
        Ticks \[Rule] {Range[0, 3, 1], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Magenta, 
            Pink}];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The image sector \!\(1\/\[ExponentialE]\) < \[Rho] < \
\[ExponentialE]  and  \!\(\(-\[Pi]\)\/3\) \[LessEqual] \[Phi] \[LessEqual] \!\
\(\[Pi]\/4\),\>\""];\)\ \ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the transformation  ",
  Cell[BoxData[
      \(w = \[ExponentialE]\^z\)]],
  "  maps the rectangle  ",
  Cell[BoxData[
      \(R = {\((x, y)\) : \(-1\) \[LessEqual] x \[LessEqual] 
              1\ \ and\ \ \(-\[Pi]\)\/3 \[LessEqual] 
              y \[LessEqual] \[Pi]\/4}\)]],
  "  onto a portion of an annular region  ",
  Cell[BoxData[
      \(\(\(\[ExponentialE]\^\(-1\)\)\(<\)\) | 
        w | \(\(<\)\(\[ExponentialE]\)\)\)]],
  "  bounded by two rays  ",
  Cell[BoxData[
      \(\(-\[Pi]\)\/3 \[LessEqual] arg[w] \[LessEqual] \[Pi]\/4\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["History of Complex Numbers",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/HistoryComplexBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Numbers",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexNumbersBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russel W. Howell",
  
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{963, 629},
WindowMargins->{{8, Automatic}, {Automatic, 3}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[2102, 62, 194, 5, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 383505, 11609}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 194, 5, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2299, 69, 98, 2, 33, "Text"],
Cell[2400, 73, 1313, 30, 185, "Text"],
Cell[3716, 105, 126, 2, 33, "Text"],
Cell[3845, 109, 447, 13, 55, "Text"],
Cell[4295, 124, 868, 30, 95, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5188, 158, 185, 6, 33, "Text"],
Cell[5376, 166, 172, 7, 33, "Text",
  Evaluatable->False],
Cell[5551, 175, 193, 4, 91, "Input"],
Cell[5747, 181, 167, 6, 52, "Text",
  Evaluatable->False],
Cell[5917, 189, 1051, 21, 424, "Input"]
}, Closed]],
Cell[6983, 213, 560, 12, 68, "Text"],
Cell[7546, 227, 1421, 48, 207, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[8992, 279, 111, 2, 33, "Text"],
Cell[9106, 283, 713, 17, 114, "Text"],
Cell[9822, 302, 2047, 58, 202, "Text"],
Cell[11872, 362, 850, 26, 221, "Text"],
Cell[12725, 390, 502, 18, 109, "Text"],
Cell[13230, 410, 2111, 44, 340, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[15378, 459, 124, 2, 30, "Text"],
Cell[15505, 463, 307, 11, 52, "Text",
  Evaluatable->False],
Cell[15815, 476, 1202, 23, 370, "Input"],
Cell[17020, 501, 254, 10, 52, "Text",
  Evaluatable->False],
Cell[17277, 513, 402, 7, 170, "Input"],
Cell[17682, 522, 254, 9, 52, "Text",
  Evaluatable->False],
Cell[17939, 533, 1607, 33, 354, "Input"],
Cell[19549, 568, 262, 9, 55, "Text",
  Evaluatable->False],
Cell[19814, 579, 626, 13, 150, "Input"],
Cell[20443, 594, 311, 9, 52, "Text",
  Evaluatable->False],
Cell[20757, 605, 862, 19, 172, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[21656, 629, 125, 2, 30, "Text"],
Cell[21784, 633, 2253, 47, 614, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[24074, 685, 126, 2, 30, "Text"],
Cell[24203, 689, 76, 0, 33, "Text"],
Cell[24282, 691, 133, 2, 49, "Input"],
Cell[24418, 695, 438, 8, 49, "Input"],
Cell[24859, 705, 436, 7, 49, "Input"],
Cell[25298, 714, 453, 8, 49, "Input"],
Cell[25754, 724, 516, 10, 114, "Input"]
}, Closed]],
Cell[26285, 737, 498, 16, 30, "Text"],
Cell[26786, 755, 995, 30, 147, "Text"],
Cell[27784, 787, 2345, 72, 153, "Text"],
Cell[30132, 861, 1000, 33, 147, "Text"],
Cell[31135, 896, 911, 28, 71, "Text"],
Cell[32049, 926, 1521, 35, 330, "Text"],
Cell[33573, 963, 170108, 5933, 277, "Text"],

Cell[CellGroupData[{
Cell[203706, 6900, 111, 2, 33, "Text"],
Cell[203820, 6904, 49, 0, 33, "Text"],
Cell[203872, 6906, 1096, 20, 366, "Input"],
Cell[204971, 6928, 50, 0, 33, "Text"],
Cell[205024, 6930, 785, 16, 246, "Input"]
}, Closed]],
Cell[205824, 6949, 958, 29, 87, "Text"],
Cell[206785, 6980, 2650, 67, 147, "Text"],
Cell[209438, 7049, 1433, 44, 335, "Text"],
Cell[210874, 7095, 909, 23, 109, "Text"],
Cell[211786, 7120, 60556, 1175, 287, "Text"],
Cell[272345, 8297, 1140, 34, 71, "Text"],
Cell[273488, 8333, 2859, 72, 245, "Text",
  Evaluatable->False],
Cell[276350, 8407, 102240, 3064, 326, "Text"],

Cell[CellGroupData[{
Cell[378615, 11475, 111, 2, 33, "Text"],
Cell[378729, 11479, 447, 14, 55, "Text"],
Cell[379179, 11495, 1683, 34, 406, "Input"],
Cell[380865, 11531, 600, 17, 77, "Text"]
}, Closed]],
Cell[381480, 11551, 290, 7, 30, "Text"],
Cell[381773, 11560, 298, 7, 33, "Text"],
Cell[382074, 11569, 287, 7, 33, "Text"],
Cell[382364, 11578, 257, 5, 33, "Text"],
Cell[382624, 11585, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

