(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    352296,      12496]*)
(*NotebookOutlinePosition[    353111,      12526]*)
(*  CellTagsIndexPosition[    353033,      12520]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["5.2  The Complex Logarithm",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tIn Section 5.1, we showed that, if ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " is a nonzero complex number, then the equation  ",
  Cell[BoxData[
      \(w = \[ExponentialE]\^z\)]],
  "  has infinitely many solutions.  Because the function  ",
  Cell[BoxData[
      \(f \((z)\) = \[ExponentialE]\^z\)]],
  "  is a many-to-one function, its inverse (the logarithm) is multivalued.  \
"
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 5.2.  (Multivalued Logarithm)  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "For ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ", we define the function  ",
  Cell[BoxData[
      \(log \((z)\)\)]],
  "  as the inverse of the exponential function;  that is,  \n\n ",
  StyleBox["(5-10)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(log \((z)\) = w\)]],
  "   if and only if   ",
  Cell[BoxData[
      \(z = \[ExponentialE]\^w\)]],
  ".  \n\n\tIf we go through the same steps as we did in equations (5-8) and \
(5-9), we find that, for any complex number  ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ",  the solutions w to equation (5-10) take the form  \n\n",
  StyleBox["(5-11)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(w\  = \ \(log \((z)\)\  = \ 
          ln | z | \ \(+\ \ \[ImaginaryI]\)\ \[Theta]\)\)]],
  ",   for   ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ",  \n\nwhere  ",
  Cell[BoxData[
      \(\[Theta] \[Element] arg \((z)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(ln | z | \)]],
  "  denotes the natural logarithm of the positive number ",
  StyleBox["|z|",
    FontFamily->"Courier New"],
  ".  Because  ",
  Cell[BoxData[
      \(arg \((z)\)\)]],
  "  is the set  ",
  Cell[BoxData[
      RowBox[{\(arg \((z)\)\), " ", "=", 
        RowBox[{"{", 
          RowBox[{\(Arg \((z)\)\), "+", 
            RowBox[{"2", "n", " ", 
              RowBox[{"\[Pi]", ":", " ", 
                StyleBox[\(where\ n\ is\ an\ integer\),
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}]}], "}"}]}]]],
  ",  we can express the set of values comprising ",
  Cell[BoxData[
      \(log \((z)\)\)]],
  " as  \n\n",
  StyleBox["(5-12)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{\(log \((z)\)\), " ", "=", 
        RowBox[{"{", 
          
          RowBox[{\(ln | z | \(+\ \[ImaginaryI]\) \((Arg\  + 2  n\ \[Pi])\)\),
             ":", " ", 
            RowBox[{
              StyleBox["where",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], " ", "n", " ", 
              StyleBox["is",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["an",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["integer",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}], "}"}]}]]],
  ",  \n\t\tor\n",
  StyleBox["(5-13)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(log \((z)\) = ln | z | \(+\ \[ImaginaryI]\)\ arg \((z)\)\)]],
  "   for   ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ",   \n\nwhere it is understood that identity ",
  StyleBox["(5-13)",
    FontColor->RGBColor[0, 0, 1]],
  " refers to the same set of numbers given in identity ",
  StyleBox["(5-12)",
    FontColor->RGBColor[0, 0, 1]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tRecall that Arg is defined so that for  ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ",  we have  ",
  Cell[BoxData[
      \(\(-\[Pi]\)\  < \ Arg \((z)\)\  \[LessEqual] \ \[Pi]\)]],
  ".  We call any one of the values given in Identities ",
  StyleBox["(5-12)",
    FontColor->RGBColor[0, 0, 1]],
  " or ",
  StyleBox["(5-13)",
    FontColor->RGBColor[0, 0, 1]],
  " a logarithm of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ".  Notice that the different values of  ",
  Cell[BoxData[
      \(log \((z)\)\)]],
  "  all have the same real part and that their imaginary parts differ by the \
amount  ",
  Cell[BoxData[
      \(2  \[Pi]\ n\)]],
  ",  where n is an integer.  When  ",
  Cell[BoxData[
      \(n = 0\)]],
  ",  we have a special situation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Definition 5.3.  (Principal Value of the ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Logarithm",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Logarithm.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[")  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "For  ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ",  we define the principal value of the logarithm as follows:",
  StyleBox["\n\n",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["(5-14)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\t\t",
    FontColor->RGBColor[1, 0, 1]],
  Cell[BoxData[
      \(Log \((z)\) = 
        ln | z | \(\(+\ \[ImaginaryI]\)\(\ \)\(Arg\) \((z)\)\(\ \)\)\)]],
  " where  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(\ \)\(0\)\)\)\)]],
  " and ",
  Cell[BoxData[
      \(\(\(-\[Pi]\)\(\ \)\(<\)\(\ \)\(Arg \((z)\)\)\(\ \)\(\[LessEqual]\)\(\ \
\)\(\[Pi]\)\(\ \)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe domain for the function  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\) = Log \((z)\)\)\)]],
  "  is the set of all nonzero complex numbers in the  ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-plane, and its range is the horizontal strip  ",
  Cell[BoxData[
      \({w : \ \(-\[Pi]\)\  < \ Im \((w)\)\  \[LessEqual] \ \[Pi]}\)]],
  "  in the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  "-plane, and is shown in Figure 5.A.  We stress again that  ",
  Cell[BoxData[
      \(Log \((z)\)\)]],
  "  is a single-valued function and corresponds to setting  ",
  Cell[BoxData[
      \(n = 0\)]],
  "  in equation ",
  StyleBox["(5-12)",
    FontColor->RGBColor[0, 0, 1]],
  ".  As we demonstrated in Chapter 2, the function  ",
  Cell[BoxData[
      \(Arg \((z)\)\)]],
  "  is discontinuous at each point along the negative x-axis, hence so is \
the function  ",
  Cell[BoxData[
      \(Log \((z)\)\)]],
  ".  In fact, because any branch of the multi-valued function  ",
  Cell[BoxData[
      \(Arg \((z)\)\)]],
  "  is discontinuous along some ray, a corresponding branch of the logarithm \
will have a discontinuity along that same ray.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.493933 0.134321 0.493933 0.134321 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.941 1 .941 r
.02381 .02381 m
.96406 .02381 L
.96406 .96406 L
.02381 .96406 L
.02381 .02381 L
F
.49393 .49393 m
.49393 .49393 .44596 0 365.73 arc
F
.8 1 .8 r
.49393 .49393 m
.49393 .49393 .33038 0 365.73 arc
F
.941 1 .941 r
.49393 .49393 m
.49393 .49393 .07372 0 365.73 arc
F
1 1 1 r
.49393 .49393 m
.49393 .49393 .00672 0 365.73 arc
F
1 0 1 r
.5 Mabswid
[ ] 0 setdash
.48728 .50058 m
.17859 .80927 L
s
1 0 0 r
.49868 .49868 m
.80927 .80927 L
s
0 0 1 r
[ .025 .025 ] 0 setdash
.4823 .48722 m
.10772 .27095 L
s
0 0 0 r
[ ] 0 setdash
.49393 .50065 m
.49393 .96276 L
s
.50065 .49393 m
.96276 .49393 L
s
.49393 .48722 m
.49393 .02511 L
s
.56 .37 .6 r
.0012 w
[ .025 .025 ] 0 setdash
newpath
.49393 .49393 .07372 0 365.73 arc
s
1 .5 0 r
[ ] 0 setdash
newpath
.49393 .49393 .28436 0 365.73 arc
s
.5 .165 .165 r
newpath
.49393 .49393 .33038 0 365.73 arc
s
0 1 0 r
.5 Mabswid
.02511 .50065 m
.49393 .50065 L
s
[ .025 .025 ] 0 setdash
.02511 .48722 m
.49393 .48722 L
s
0 g
[ ] 0 setdash
.94933 .49393 m
.97619 .49393 L
s
% Start of user PostScript
3.39034 0 3.59034 0 MAarrowhead1
% End of user PostScript
.49393 .94933 m
.49393 .97619 L
s
% Start of user PostScript
0 3.39034 0 3.59034 MAarrowhead1
% End of user PostScript
gsave
.96276 .52751 -66 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51408 .96276 -69 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 0 r
.0012 w
newpath
.49393 .49393 .00672 -90 90 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{258, 258},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004200010R000`400?l00000o`00003oo`3oool3
0?ooo`00o`3oool30?ooo`00o`3oool30?ooo`00o`3oool30?ooo`00o`3oool30?ooo`00o`3oool3
0?ooo`00o`3oool30?ooo`00OP3oool00`000000oooo0?ooo`210?ooo`001P3ooomh0?3ol0030000
003`oo00l?o`07H0l?o`2`3oool000H0ooooN03`oo000`000000l?o`0?3ol01f0?3ol0/0oooo0006
0?ooogP0l?o`00<000000?3ol03`oo00MP3`oo0;0?ooo`001P3ooomh0?3ol0030000003`oo00l?o`
07H0l?o`2`3oool000H0ooooN03`oo000`000000l?o`0?3ol01f0?3ol0/0oooo00060?ooogP0l?o`
00<000000?3ol03`oo00MP3`oo0;0?ooo`001P3ooomh0?3ol0030000003`oo00l?o`07H0l?o`2`3o
ool000H0ooooN03`oo000`000000l?o`0?3ol01f0?3ol0/0oooo00060?ooogP0l?o`00<000000?3o
l03`oo00MP3`oo0;0?ooo`001P3ooomh0?3ol0030000003`oo00l?o`07H0l?o`2`3oool000H0oooo
N03`oo000`000000l?o`0?3ol01f0?3ol0/0oooo00060?ooogP0l?o`00<000000?3ol03`oo00MP3`
oo0;0?ooo`001P3ooomh0?3ol0030000003`oo00l?o`07H0l?o`2`3oool000H0ooooN03`oo000`00
0000l?o`0?3ol01f0?3ol0/0oooo00060?ooogP0l?o`00<000000?3ol03`oo00MP3`oo0;0?ooo`00
1P3ooomh0?3ol0030000003`oo00l?o`07H0l?o`2`3oool000H0ooooN03`oo000`000000l?o`0?3o
l01f0?3ol0/0oooo00060?ooogP0l?o`00<000000?3ol03`oo00MP3`oo0;0?ooo`001P3ooomh0?3o
l0030000003`oo00l?o`07H0l?o`2`3oool000H0ooooN03`oo000`000000l?o`0?3ol01f0?3ol0/0
oooo00060?ooogP0l?o`00<000000?3ol03`oo00MP3`oo0;0?ooo`001P3ooomh0?3ol0030000003`
oo00l?o`07H0l?o`2`3oool000H0ooooN03`oo000`000000l?o`0?3ol01f0?3ol0/0oooo00060?oo
ogP0l?o`00<000000?3ol03`oo00MP3`oo0;0?ooo`001P3ooomh0?3ol0030000003`oo00l?o`07H0
l?o`2`3oool000H0ooooN03`oo000`000000l?o`0?3ol01f0?3ol0/0oooo00060?ooogP0l?o`00<0
00000?3ol03`oo00MP3`oo0;0?ooo`001P3ooomh0?3ol0030000003`oo00l?o`07H0l?o`2`3oool0
00H0ooooN03`oo000`000000l?o`0?3ol01f0?3ol0/0oooo00060?ooogP0l?o`00<000000?3ol03`
oo00MP3`oo0;0?ooo`001P3ooomh0?3ol0030000003`oo00l?o`07H0l?o`2`3oool000H0ooooN03`
oo000`000000l?o`0?3ol01f0?3ol0/0oooo00060?ooogP0l?o`00<000000?3ol03`oo00MP3`oo0;
0?ooo`001P3ooomh0?3ol0030000003`oo00l?o`07H0l?o`2`3oool000H0ooooN03`oo000`000000
l?o`0?3ol01f0?3ol0/0oooo00060?ooof`0l?o`6P1o:RY[0?3ol0/0oooo00060?ooofP0l?o`101o
:RX<0<coc0030000003<ol`0c?o<00/0c?o<101o:RYW0?3ol0/0oooo00060?ooof<0l?o`1@1o:RX@
0<coc0030000003<ol`0c?o<00l0c?o<101o:RYS0?3ol0/0oooo00060?oooel0l?o`101o:RXE0<co
c0030000003<ol`0c?o<01<0c?o<1@1o:RYN0?3ol0/0oooo00060?oooed0l?o`0P1o:RXI0<coc003
0000003<ol`0c?o<01P0c?o<0P1o:RYL0?3ol0/0oooo00060?oooeT0l?o`101o:RXK0<coc0030000
003<ol`0c?o<01X0c?o<0`1o:RYI0?3ol0/0oooo00060?oooeL0l?o`0P1o:RXO0<coc0030000003<
ol`0c?o<01d0c?o<0P1o:RYG0?3ol0/0oooo00060?oooeH0l?o`00<0ObXZ0<coc03<ol`07`3<ol`0
0`000000c?o<0<coc00O0<coc080ObXZE@3`oo0;0?ooo`001P3ooomD0?3ol080ObXZ8P3<ol`00`00
0000c?o<0<coc00Q0<coc080ObXZD`3`oo0;0?ooo`001P3ooomB0?3ol080ObXZ903<ol`00`000000
c?o<0<coc00S0<coc080ObXZD@3`oo0;0?ooo`001P3ooom@0?3ol080ObXZ9P3<ol`00`000000c?o<
0<coc00U0<coc080ObXZC`3`oo0;0?ooo`001P3ooom>0?3ol080ObXZ9@3<ol`80?mo02D0c?o<0P1o
:RY=0?3ol0/0oooo00060?oood`0l?o`0P1o:RXN0<coc0T0ogl00`3<ol`00`000000c?o<0<coc002
0<coc0T0ogl07P3<ol`207lZ:T/0l?o`2`3oool000H0ooooBP3`oo0207lZ:Q`0c?o<103oO`0<0<co
c0030000003<ol`0c?o<00/0c?o<103oO`0L0<coc080ObXZB@3`oo0;0?ooo`001P3ooom90?3ol003
07lZ:P3<ol`0c?o<01T0c?o<0`3oO`0@0<coc0030000003<ol`0c?o<00l0c?o<0`3oO`0K0<coc003
07lZ:P3`oo00l?o`04H0l?o`2`3oool000H0ooooA`3`oo0207lZ:QP0c?o<103oO`0C0<coc0030000
003<ol`0c?o<0180c?o<103oO`0H0<coc00307lZ:P3`oo00l?o`04D0l?o`2`3oool000H0ooooAP3`
oo000`1o:RX0c?o<0<coc00E0<coc0<0ogl05`3<ol`00`000000c?o<0<coc00F0<coc0<0ogl05P3<
ol`00`1o:RX0l?o`0?3ol0140?3ol0/0oooo00060?ooodD0l?o`00<0ObXZ0<coc03<ol`0503<ol`2
0?mo01X0c?o<00<000000<coc03<ol`06@3<ol`20?mo01D0c?o<0P1o:RY40?3ol0/0oooo00060?oo
od@0l?o`00<0ObXZ0<coc03<ol`04`3<ol`20?mo01`0c?o<00<000000<coc03<ol`06`3<ol`20?mo
01D0c?o<00<0ObXZ0?3ol03`oo00@@3`oo0;0?ooo`001P3ooom20?3ol080ObXZ4`3<ol`30?mo01h0
c?o<00<000000<coc03<ol`07@3<ol`30?mo01<0c?o<0P1o:RY10?3ol0/0oooo00060?oood40l?o`
00<0ObXZ0<coc03<ol`04P3<ol`00`3oO`00c?o<0<coc00O0<coc0030000003<ol`0c?o<0200c?o<
00<0ogl00<coc03<ol`04P3<ol`00`1o:RX0l?o`0?3ol00n0?3ol0/0oooo00060?oood00l?o`00<0
ObXZ0<coc03<ol`04@3<ol`20?mo0280c?o<00<000000<coc03<ol`08@3<ol`20?mo01<0c?o<00<0
ObXZ0?3ol03`oo00?@3`oo0;0?ooo`001P3ooolo0?3ol00307lZ:P3<ol`0c?o<0100c?o<0P3oO`0T
0<coc0030000003<ol`0c?o<02<0c?o<0P3oO`0B0<coc00307lZ:P3`oo00l?o`03`0l?o`2`3oool0
00H0oooo?P3`oo000`1o:RX0c?o<0<coc00@0<coc0030?mo003<ol`0c?o<02@0c?o<00<000000<co
c03<ol`09@3<ol`00`3oO`00c?o<0<coc00@0<coc00307lZ:P3`oo00l?o`03/0l?o`2`3oool000H0
oooo?@3`oo000`1o:RX0c?o<0<coc00?0<coc080ogl09`3<ol`00`000000c?o<0<coc00V0<coc080
ogl04@3<ol`00`1o:RX0l?o`0?3ol00j0?3ol0/0oooo00060?oooc`0l?o`00<0ObXZ0<coc03<ol`0
3`3<ol`00`3oO`00c?o<0<coc00W0<coc0030000003<ol`0c?o<02P0c?o<00<0ogl00<coc03<ol`0
3`3<ol`00`1o:RX0l?o`0?3ol00i0?3ol0/0oooo00060?oooc/0l?o`00<0ObXZ0<coc03<ol`03P3<
ol`20?mo02X0c?o<00<000000<coc03<ol`0:@3<ol`20?mo0100c?o<00<0ObXZ0?3ol03`oo00>03`
oo0;0?ooo`001P3ooolj0?3ol00307lZ:P3<ol`0c?o<00h0c?o<00<0ogl00<coc03<ol`0:P3<ol`0
0`000000c?o<0<coc00[0<coc0030?mo003<ol`0c?o<00h0c?o<00<0ObXZ0?3ol03`oo00=`3`oo0;
0?ooo`001P3ooolG0?3ol0030000o`3`oo00l?o`01l0l?o`00<0ObXZ0<coc03<ol`03P3<ol`00`3o
O`00c?o<0<coc00[0<coc0030000003<ol`0c?o<02`0c?o<00<0ogl00<coc03<ol`03P3<ol`00`1o
:RX0l?o`0?3ol00f0?3ol0/0oooo00060?oooaP0l?o`0P000?lN0?3ol00307lZ:P3<ol`0c?o<00h0
c?o<00<0ogl00<coc03<ol`0;03<ol`00`000000c?o<0<coc00]0<coc0030?mo003<ol`0c?o<00d0
c?o<00<0ObXZ0?3ol03`oo00=P3`oo0;0?ooo`001P3ooolJ0?3ol080003o6`3`oo000`1o:RX0c?o<
0<coc00>0<coc0030?mo003<ol`0c?o<02d0c?o<00<000000<coc03<ol`0;P3<ol`00`3oO`00c?o<
0<coc00=0<coc00307lZ:P3`oo00l?o`03D0l?o`2`3oool000H0oooo703`oo000`000?l0l?o`0?3o
l00G0?3ol00307lZ:P3<ol`0c?o<00d0c?o<0P3oO`0`0<coc0030000003<ol`0c?o<02l0c?o<00<0
ogl00<coc03<ol`03@3<ol`00`1o:RX0l?o`0?3ol00d0?3ol0/0oooo00060?ooocD0l?o`00<0ObXZ
0<coc03<ol`03@3<ol`00`3oO`00c?o<0<coc00`0<coc0030000003<ol`0c?o<0300c?o<00<0ogl0
0<coc03<ol`03@3<ol`00`1o:RX0l?o`0?3ol00c0?3ol0/0oooo00060?ooocD0l?o`00<0ObXZ0<co
c03<ol`0303<ol`00`3oO`00c?o<0<coc00a0<coc0030000003<ol`0c?o<0340c?o<00<0ogl00<co
c03<ol`03@3<ol`00`1o:RX0l?o`0?3ol00b0?3ol0/0oooo00060?oooc@0l?o`00<0ObXZ0<coc03<
ol`03@3<ol`00`3oO`00c?o<0<coc00a0<coc0030000003<ol`0c?o<0380c?o<00<0ogl00<coc03<
ol`0303<ol`00`1o:RX0l?o`0?3ol00b0?3ol0/0oooo00060?ooob80l?o`00<0003o0?3ol03`oo00
3`3`oo000`1o:RX0c?o<0<coc00<0<coc0030?mo003<ol`0c?o<0380c?o<00<000000<coc03<ol`0
<`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`0340l?o`2`3oool000H0oooo8`3`
oo020000o`h0l?o`00<0ObXZ0<coc03<ol`02`3<ol`20?mo03D0c?o<00<000000<coc03<ol`0=03<
ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`0300l?o`2`3oool000H0oooo9@3`oo02
0000o`/0l?o`00<0ObXZ0<coc03<ol`02`3<ol`00`3oO`00c?o<0<coc00e0<coc0030000003<ol`0
c?o<03D0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00_0?3ol0/0oooo00060?oo
obL0l?o`0P000?l80?3ol00307lZ:P3<ol`0c?o<00/0c?o<00<0ogl00<coc03<ol`0=P3<ol`00`00
0000c?o<0<coc00f0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00;P3`oo0;0?oo
o`001P3oool`0?3ol00307lZ:P3<ol`0c?o<00`0c?o<00<0ogl00<coc03<ol`0=P3<ol`00`000000
c?o<0<coc00g0<coc0030?mo003<ol`0c?o<00/0c?o<00<0ObXZ0?3ol03`oo00;P3`oo0;0?ooo`00
1P3oool`0?3ol00307lZ:P3<ol`0c?o<00/0c?o<00<0ogl00<coc03<ol`0=`3<ol`00`000000c?o<
0<coc00h0<coc0030?mo003<ol`0c?o<00/0c?o<00<0ObXZ0?3ol03`oo00;@3`oo0;0?ooo`001P3o
ool]0?3ol0030000o`3`oo00ObXZ00d0c?o<00<0ogl00<coc03<ol`0>03<ol`00`000000c?o<0<co
c00i0<coc0030?mo003<ol`0c?o<00X0c?o<00<0ObXZ0?3ol03`oo00;@3`oo0;0?ooo`001P3oool^
0?3ol0030000o`1o:RX0c?o<00`0c?o<00<0ogl00<coc03<ol`0>03<ol`00`000000c?o<0<coc00i
0<coc0030?mo003<ol`0c?o<00/0c?o<00<0ObXZ0?3ol03`oo00;03`oo0;0?ooo`001P3oool^0?3o
l00407lZ:P3<ol`0003o0000o`X0c?o<00<0ogl00<coc03<ol`0>@3<ol`00`000000c?o<0<coc00j
0<coc0030?mo003<ol`0c?o<00X0c?o<00<0ObXZ0?3ol03`oo00;03`oo0;0?ooo`001P3oool^0?3o
l00407lZ:P3<ol`0c?o<0<coc080003o1`3<ol`00`3oO`00c?o<0<coc00j0<coc0030000003<ol`0
c?o<03X0c?o<00<0ogl00<coc03<ol`02`3<ol`00`1o:RX0l?o`0?3ol00[0?3ol0/0oooo00060?oo
obd0l?o`00<0ObXZ0<coc03<ol`02`3<ol`00`3oO`00c?o<0<coc00j0<coc0030000003<ol`0c?o<
03/0c?o<00<0ogl00<coc03<ol`02P3<ol`00`1o:RX0l?o`0?3ol00[0?3ol0/0oooo00060?ooobd0
l?o`00<0ObXZ0<coc03<ol`02P3<ol`00`3oO`00c?o<0<coc00k0<coc0030000003<ol`0c?o<03`0
c?o<00<0ogl00<coc03<ol`02P3<ol`00`1o:RX0l?o`0?3ol00Z0?3ol0/0oooo00060?ooob`0l?o`
00<0ObXZ0<coc03<ol`02@3<ol`00`000?l0ogl00<coc00m0<coc0030000003<ol`0c?o<03`0c?o<
00<0ogl00<coc03<ol`02P3<ol`00`1o:RX0l?o`0?3ol00Z0?3ol0/0oooo00060?ooob`0l?o`00<0
ObXZ0<coc03<ol`02P3<ol`00`3oO`00003o0<coc00l0<coc0030000003<ol`0c?o<03d0c?o<00<0
ogl00<coc03<ol`02P3<ol`00`1o:RX0l?o`0?3ol00Y0?3ol0/0oooo00060?ooob/0l?o`00<0ObXZ
0<coc03<ol`02P3<ol`0103oO`00c?o<0<coc0000?ll0<coc0030000003<ol`0c?o<03d0c?o<00<0
ogl00<coc03<ol`02P3<ol`00`1o:RX0l?o`0?3ol00Y0?3ol0/0oooo00060?ooob/0l?o`00<0ObXZ
0<coc03<ol`02@3<ol`00`3oO`00c?o<0<coc0020<coc080003o>P3<ol`00`000000c?o<0<coc00n
0<coc0030?mo003<ol`0c?o<00X0c?o<00<0ObXZ0?3ol03`oo00:03`oo0;0?ooo`001P3ooolZ0?3o
l00307lZ:P3<ol`0c?o<00X0c?o<00<0ogl00<coc03<ol`0103<ol`00`000?l0c?o<0<coc00g0<co
c0030000003<ol`0c?o<03h0c?o<00<0ogl00<coc03<ol`02`3<ol`00`1o:RX0l?o`0?3ol00W0?3o
l0/0oooo00060?ooobT0l?o`00<0ObXZ0<coc03<ol`02`3<ol`00`3oO`00c?o<0<coc00n0<coc003
0000003<ol`0c?o<03h0c?o<00<0ogl00<coc03<ol`02`3<ol`00`1o:RX0l?o`0?3ol00W0?3ol0/0
oooo00060?ooobT0l?o`00<0ObXZ0<coc03<ol`02`3<ol`00`3oO`00c?o<0<coc00n0<coc0030000
003<ol`0c?o<03l0c?o<00<0ogl00<coc03<ol`02P3<ol`00`1o:RX0l?o`0?3ol00W0?3ol0/0oooo
00060?ooobT0l?o`00<0ObXZ0<coc03<ol`02P3<ol`00`3oO`00c?o<0<coc00:0<coc0030000o`3<
ol`0c?o<0380c?o<00<000000<coc03<ol`0@03<ol`00`3oO`00c?o<0<coc0090<coc00307lZ:P3`
oo00l?o`02L0l?o`2`3oool000H0oooo:@3`oo000`1o:RX0c?o<0<coc0090<coc0030?mo003<ol`0
c?o<00`0c?o<0P000?lb0<coc0030000003<ol`0c?o<0400c?o<00<0ogl00<coc03<ol`02P3<ol`0
0`1o:RX0l?o`0?3ol00V0?3ol0/0oooo00060?ooobP0l?o`00<0ObXZ0<coc03<ol`02P3<ol`00`3o
O`00c?o<0<coc00>0<coc080003o<03<ol`00`000000c?o<0<coc0110<coc0030?mo003<ol`0c?o<
00T0c?o<00<0ObXZ0?3ol03`oo009P3`oo0;0?ooo`001P3ooolX0?3ol00307lZ:P3<ol`0c?o<00T0
c?o<00<0ogl00<coc03<ol`04@3<ol`20000obh0c?o<00<000000<coc03<ol`0@@3<ol`00`3oO`00
c?o<0<coc00:0<coc00307lZ:P3`oo00l?o`02D0l?o`2`3oool000H0oooo9`3`oo000`1o:RX0c?o<
0<coc00:0<coc0030?mo003<ol`0c?o<0440c?o<00<000000<coc03<ol`0@@3<ol`00`3oO`00c?o<
0<coc00:0<coc00307lZ:P3`oo00l?o`02D0l?o`2`3oool000H0oooo9`3`oo000`1o:RX0c?o<0<co
c00:0<coc0030?mo003<ol`0c?o<0440c?o<00<000000<coc03<ol`0@P3<ol`00`3oO`00c?o<0<co
c00:0<coc00307lZ:P3`oo00l?o`02@0l?o`2`3oool000H0oooo9`3`oo000`1o:RX0c?o<0<coc009
0<coc0030?mo003<ol`0c?o<01P0c?o<00<0003o0<coc03<ol`09`3<ol`00`000000c?o<0<coc012
0<coc0030?mo003<ol`0c?o<00X0c?o<00<0ObXZ0?3ol03`oo00903`oo0;0?ooo`001P3ooolW0?3o
l00307lZ:P3<ol`0c?o<00T0c?o<00<0ogl00<coc03<ol`06@3<ol`20000obL0c?o<00<000000<co
c03<ol`0@`3<ol`00`3oO`00c?o<0<coc0090<coc00307lZ:P3`oo00l?o`02@0l?o`2`3oool000H0
oooo9P3`oo000`1o:RX0c?o<0<coc00:0<coc0030?mo003<ol`0c?o<01/0c?o<0P000?lU0<coc003
0000003<ol`0c?o<04<0c?o<00<0ogl00<coc03<ol`02@3<ol`00`1o:RX0l?o`0?3ol00T0?3ol0/0
oooo00060?ooobH0l?o`00<0ObXZ0<coc03<ol`02P3<ol`00`3oO`00c?o<0<coc00M0<coc080003o
8`3<ol`00`000000c?o<0<coc0130<coc0030?mo003<ol`0c?o<00X0c?o<00<0ObXZ0?3ol03`oo00
8`3`oo0;0?ooo`001P3ooolV0?3ol00307lZ:P3<ol`0c?o<00T0c?o<00<0ogl00<coc03<ol`0@`3<
ol`00`000000c?o<0<coc0130<coc0030?mo003<ol`0c?o<00X0c?o<00<0ObXZ0?3ol03`oo008`3`
oo0;0?ooo`001P3ooolV0?3ol00307lZ:P3<ol`0c?o<00T0c?o<00<0ogl00<coc03<ol`0@`3<ol`0
0`2?GYT0c?o<0<coc0140<coc0030?mo003<ol`0c?o<00T0c?o<00<0ObXZ0?3ol03`oo008`3`oo0;
0?ooo`001P3ooolV0?3ol00307lZ:P3<ol`0c?o<00T0c?o<00<0ogl00<coc03<ol`0@03<ol`308mN
V@030000002?GYT0SejI0080SejI@P3<ol`00`3oO`00c?o<0<coc0090<coc00307lZ:P3`oo00l?o`
02<0l?o`2`3oool000H0oooo9@3`oo000`1o:RX0c?o<0<coc0090<coc0030?mo003<ol`0c?o<02H0
c?o<00<0003o0<coc03<ol`0503<ol`70?3ol0030000003`oo00l?o`00@0l?o`@03<ol`00`3oO`00
c?o<0<coc0090<coc00307lZ:P3`oo00l?o`02<0l?o`2`3oool000H0oooo9@3`oo000`1o:RX0c?o<
0<coc0090<coc0030?mo003<ol`0c?o<02L0c?o<0P000?lB0<coc00308mNV@3`oo00l?o`00H0l?o`
00<000000?3ol03`oo001P3`oo000`3<ol`0SejI0<coc00l0<coc0030?mo003<ol`0c?o<00T0c?o<
00<0ObXZ0?3ol03`oo008P3`oo0;0?ooo`001P3ooolU0?3ol00307lZ:P3<ol`0c?o<00T0c?o<00<0
ogl00<coc03<ol`0:@3<ol`20000o`h0c?o<0P2?GYT90?3ol0030000003`oo00l?o`00P0l?o`00<0
SejI0<coc03<ol`0>P3<ol`00`3oO`00c?o<0<coc0090<coc00307lZ:P3`oo00l?o`0280l?o`2`3o
ool000H0oooo9@3`oo000`1o:RX0c?o<0<coc0090<coc0030?mo003<ol`0c?o<02/0c?o<00<0003o
0<coc03<ol`02P3<ol`00`2?GYT0l?o`0?3ol0090?3ol0030000003`oo00l?o`00T0l?o`00<0SejI
0<coc03<ol`0>@3<ol`00`3oO`00c?o<0<coc0090<coc00307lZ:P3`oo00l?o`0280l?o`2`3oool0
00H0oooo903`oo000`1o:RX0c?o<0<coc0090<coc0030?mo003<ol`0c?o<03P0c?o<00<0SejI0?3o
l03`oo002P3`oo000`000000l?o`0?3ol00:0?3ol080SejI>@3<ol`00`3oO`00c?o<0<coc0090<co
c00307lZ:P3`oo00l?o`0280l?o`2`3oool000H0oooo903`oo000`1o:RX0c?o<0<coc0090<coc003
0?mo003<ol`0c?o<03L0c?o<00<0SejI0?3ol03`oo002`3`oo000`000000l?o`0?3ol00<0?3ol003
08mNV@3<ol`0c?o<03H0c?o<00<0ogl00<coc03<ol`02@3<ol`00`1o:RX0l?o`0?3ol00R0?3ol0/0
oooo00060?ooob@0l?o`00<0ObXZ0<coc03<ol`02@3<ol`00`3oO`00c?o<0<coc00b0<coc0040000
o`3<ol`0c?o<0<coc0l0l?o`00<000000?3ol03`oo003@3`oo0h0<coc0030?mo003<ol`0c?o<00T0
c?o<00<0ObXZ0?3ol03`oo008P3`oo0;0?ooo`001P3ooolT0?3ol00307lZ:P3<ol`0c?o<00T0c?o<
00<0ogl00<coc03<ol`0<`3<ol`20000o`030<coc03`oo00l?o`00d0l?o`00<000000?3ol03`oo00
3@3`oo0i0<coc0030?mo003<ol`0c?o<00T0c?o<00<0ObXZ0?3ol03`oo008@3`oo0;0?ooo`001P3o
oolT0?3ol00307lZ:P3<ol`0c?o<00T0c?o<00<0ogl00<coc03<ol`0=@3<ol`20000o`h0l?o`00<0
00000?3ol03`oo003P3`oo0h0<coc0030?mo003<ol`0c?o<00T0c?o<00<0ObXZ0?3ol03`oo008@3`
oo0;0?ooo`001P3ooolT0?3ol00307lZ:P3<ol`0c?o<00T0c?o<00<0ogl00<coc03<ol`0=03<ol`3
0?3ol0030000o`3`oo00l?o`00/0l?o`00<000000?3ol03`oo003`3`oo0g0<coc0030?mo003<ol`0
c?o<00T0c?o<00<0ObXZ0?3ol03`oo008@3`oo0;0?ooo`001P3ooolT0?3ol00307lZ:P3<ol`0c?o<
00T0c?o<00<0ogl00<coc03<ol`0=03<ol`00`2?GYT0l?o`0?3ol00>0?3ol0030000003`oo00l?o`
00l0l?o`=`3<ol`00`3oO`00c?o<0<coc0090<coc00307lZ:P3`oo00l?o`0240l?o`2`3oool000H0
oooo903`oo000`1o:RX0c?o<0<coc0090<coc0030?mo003<ol`0c?o<03@0c?o<00<0SejI0?3ol03`
oo003P3`oo000`000000l?o`0?3ol00?0?3ol00308mNV@3<ol`0c?o<03@0c?o<00<0ogl00<coc03<
ol`02@3<ol`00`1o:RX0l?o`0?3ol00Q0?3ol0/0oooo00060?ooob@0l?o`00<0ObXZ0<coc03<ol`0
2@3<ol`00`3oO`00c?o<0<coc00c0<coc00308mNV@3`oo00l?o`00l0l?o`00<000000?3ol03`oo00
403`oo000`2?GYT0c?o<0<coc00c0<coc0030?mo003<ol`0c?o<00T0c?o<00<0ObXZ0?3ol03`oo00
8@3`oo0;0?ooo`001P3ooolT0?3ol00307lZ:P3<ol`0c?o<00P0c?o<00<0ogl00<coc03<ol`0=03<
ol`00`2?GYT0l?o`0?3ol0070?3ol0030000o`3`oo00l?o`00D0l?o`00<000000?3ol03`oo00403`
oo000`2?GYT0c?o<0<coc00c0<coc0030?mo003<ol`0c?o<00T0c?o<00<0ObXZ0?3ol03`oo008@3`
oo0;0?ooo`001P3ooolT0?3ol00307lZ:P3<ol`0c?o<00P0c?o<00<0ogl00<coc03<ol`0=03<ol`0
0`2?GYT0l?o`0?3ol0080?3ol080003o1@3`oo000`000000l?o`0?3ol00@0?3ol00308mNV@3<ol`0
c?o<03<0c?o<00<0ogl00<coc03<ol`02@3<ol`00`1o:RX0l?o`0?3ol00Q0?3ol0/0oooo00060?oo
ob@0l?o`00<0ObXZ0<coc03<ol`0203<ol`00`3oO`00c?o<0<coc00d0<coc00308mNV@3`oo00l?o`
00X0l?o`0P000?l30?3ol0030000003`oo00l?o`0100l?o`00<0SejI0<coc03<ol`0<`3<ol`00`3o
O`00c?o<0<coc0090<coc00307lZ:P3`oo00l?o`01`0l?o`0P0000030?3ol0/0oooo00060?ooo`L0
0?l01P3`oo07003o00H0l?o`1`00o`030?3ol00307lZ:P3<ol`00?l000L00?l000<0c?o<0?mo003<
ol`00P3<ol`8003o00D0c?o<2000o`050<coc0L00?l01P3<ol`7003o00D0c?o<00<0SejI003o0000
o`001@00o`060?3ol0L00?l0403`oo000`2?GYT0c?o<0<coc00c0<coc0030?mo003<ol`0c?o<00T0
c?o<00<0ObXZ0?3ol03`oo00703`oo06000000X0oooo00060?ooob@0l?o`00<0ObXZ0<coc03<ol`0
203<ol`00`3oO`00c?o<0<coc00d0<coc140l?o`0`3oool00`00o`0000000000000>0000000308mN
V@000000000003@0000000<0ogl0000000000000200000000`1o:RX000000000000U000000L0oooo
00060?ooob@0l?o`00<0ObXZ0<coc03<ol`0203<ol`00`3oO`00c?o<0<coc00d0<coc140l?o`0`3o
ool00`00o`00l?o`0?3ol00>0?3ol00308mNV@3<ol`0c?o<03<0c?o<00<0ogl00<coc03<ol`02@3<
ol`00`1o:RX0l?o`0?3ol00L0?3ol0L000002@3oool000H0ooooN`00o`0@0?3ol00308mNV@3<ol`0
c?o<03<0c?o<00<0ogl00<coc03<ol`02@3<ol`00`1o:RX0l?o`0?3ol00L0?3ol0<000000P3`oo0;
0?ooo`001P3ooolT0?3ol00307lZ:P3<ol`0c?o<00P0c?o<00<0ogl00<coc03<ol`0=03<ol`00`2?
GYT0l?o`0?3ol00=0?3ol0030?l0o`3`oo0000000080l?o`00<0o`000?3ol03`oo003@3`oo000`2?
GYT0c?o<0<coc00c0<coc0030?mo003<ol`0c?o<00T0c?o<00<0ObXZ0?3ol03`oo008@3`oo0;0?oo
o`001P3ooolT0?3ol00307lZ:P3<ol`0c?o<00P0c?o<00<0ogl00<coc03<ol`0=03<ol`00`2?GYT0
l?o`0?3ol00<0?3ol0040?l0o`3`oo00l?o`000000<0l?o`00<0o`000?3ol03`oo00303`oo000`2?
GYT0c?o<0<coc00c0<coc0030?mo003<ol`0c?o<00T0c?o<00<0ObXZ0?3ol03`oo008@3`oo0;0?oo
o`001P3ooolT0?3ol00307lZ:P3<ol`0c?o<00P0c?o<00<0ogl00<coc03<ol`0=03<ol`00`2?GYT0
l?o`0?3ol00;0?3ol0050?l0o`3`oo00l?o`0?3ol0000000103`oo000`3o0000l?o`0?3ol00;0?3o
l00308mNV@3<ol`0c?o<03<0c?o<00<0ogl00<coc03<ol`02@3<ol`00`1o:RX0l?o`0?3ol00Q0?3o
l0/0oooo00060?ooob@0l?o`00<0ObXZ0<coc03<ol`02@3<ol`00`3oO`00c?o<0<coc00c0<coc003
08mNV@3`oo00l?o`00X0l?o`00<0o`3o0?3ol03`oo000P3`oo000`000000l?o`0?3ol0030?3ol003
0?l0003`oo00l?o`00X0l?o`00<0SejI0<coc03<ol`0<`3<ol`00`3oO`00c?o<0<coc0090<coc003
07lZ:P3`oo00l?o`0240l?o`2`3oool000H0oooo903`oo000`1o:RX0c?o<0<coc0090<coc0030?mo
003<ol`0c?o<03@0c?o<00<0SejI0?3ol03`oo00203`oo000`3o0?l0l?o`0?3ol0030?3ol0030000
003`oo00l?o`00@0l?o`00<0o`000?3ol03`oo00203`oo000`2?GYT0c?o<0<coc00d0<coc0030?mo
003<ol`0c?o<00T0c?o<00<0ObXZ0?3ol03`oo007P3`oo02000000030?3ol0000000000000T0oooo
00060?ooob@0l?o`00<0ObXZ0<coc03<ol`02@3<ol`00`3oO`00c?o<0<coc00d0<coc00308mNV@3`
oo00l?o`00L0l?o`00<0o`3o0?3ol03`oo00103`oo000`000000l?o`0?3ol0050?3ol0030?l0003`
oo00l?o`00L0l?o`=`3<ol`00`3oO`00c?o<0<coc0090<coc00307lZ:P3`oo00l?o`01l0l?o`00<0
00000?3ol00000002P3oool000H0oooo903`oo000`1o:RX0c?o<0<coc0090<coc0030?mo003<ol`0
c?o<03@0c?o<2@3`oo000`3o0?l0l?o`0?3ol0050?3ol0030000003`oo00l?o`00H0l?o`00<0o`00
0?3ol03`oo001@3`oo0h0<coc0030?mo003<ol`0c?o<00T0c?o<00<0ObXZ0?3ol03`oo00803`oo00
0`000000oooo0?ooo`090?ooo`001P3ooolT0?3ol00307lZ:P3<ol`0c?o<00T0c?o<00<0ogl00<co
c03<ol`0=@3<ol`70?3ol0030?l0o`3`oo00l?o`00H0l?o`00<000000?3ol03`oo001`3`oo000`3o
0000l?o`0?3ol0040?3ol3P0c?o<00<0ogl00<coc03<ol`02@3<ol`00`1o:RX0l?o`0?3ol00N0?3o
l080000000<0l?o`0000000000002@3oool000H0oooo903`oo000`1o:RX0c?o<0<coc0090<coc003
0?mo003<ol`0c?o<03H0c?o<1@3`oo000`3o0?l0l?o`0?3ol0070?3ol0030000003`oo00l?o`00P0
l?o`00<0o`000?3ol03`oo000P3`oo0i0<coc0030?mo003<ol`0c?o<00T0c?o<00<0ObXZ0?3ol03`
oo008@3`oo0;0?ooo`001P3ooolT0?3ol00307lZ:P3<ol`0c?o<00T0c?o<00<0ogl00<coc03<ol`0
=`3<ol`30?3ol0030?l0o`3`oo00l?o`00P0l?o`00<000000?3ol03`oo002@3`oo00103o0000l?o`
0?3ol02?GYTh0<coc0030?mo003<ol`0c?o<00T0c?o<00<0ObXZ0?3ol03`oo008P3`oo0;0?ooo`00
1P3ooolT0?3ol00307lZ:P3<ol`0c?o<00T0c?o<00<0ogl00<coc03<ol`0>03<ol`00`3`oo00o`3o
0?3ol00:0?3ol0030000003`oo00l?o`00X0l?o`00<0o`0008mNV@3<ol`0>03<ol`00`3oO`00c?o<
0<coc0090<coc00307lZ:P3`oo00l?o`0280l?o`2`3oool000H0oooo903`oo000`1o:RX0c?o<0<co
c0090<coc0030?mo003<ol`0c?o<03P0c?o<00<0SejI0?3ol03`oo002P3`oo000`000000l?o`0?3o
l00;0?3ol00308mNV@3<ol`0c?o<03L0c?o<00<0ogl00<coc03<ol`02@3<ol`00`1o:RX0l?o`0?3o
l00R0?3ol0/0oooo00060?ooobD0l?o`00<0ObXZ0<coc03<ol`02@3<ol`00`3oO`00c?o<0<coc00f
0<coc0030?l0o`3<ol`0SejI00/0l?o`00<000000?3ol03`oo002@3`oo0208mNV@030<coc03o0000
c?o<03L0c?o<00<0ogl00<coc03<ol`02@3<ol`00`1o:RX0l?o`0?3ol00R0?3ol0/0oooo00060?oo
obD0l?o`00<0ObXZ0<coc03<ol`02@3<ol`00`3oO`00c?o<0<coc00e0<coc0050?l0o`3<ol`0c?o<
0<coc02?GYT02P3`oo000`000000l?o`0?3ol0080?3ol00308mNV@3<ol`0c?o<0080c?o<00<0o`00
0<coc03<ol`0=@3<ol`00`3oO`00c?o<0<coc0090<coc00307lZ:P3`oo00l?o`0280l?o`2`3oool0
00H0oooo9@3`oo000`1o:RX0c?o<0<coc0090<coc0030?mo003<ol`0c?o<03@0c?o<00<0o`3o0<co
c03<ol`00`3<ol`308mNV@L0l?o`00<000000?3ol03`oo001P3`oo000`3<ol`0SejI0<coc0050<co
c0030?l0003<ol`0c?o<03@0c?o<00<0ogl00<coc03<ol`02@3<ol`00`1o:RX0l?o`0?3ol00R0?3o
l0/0oooo00060?ooobD0l?o`00<0ObXZ0<coc03<ol`02P3<ol`00`3oO`00c?o<0<coc00b0<coc003
0?l0o`3<ol`0c?o<00L0c?o<1`3`oo000`000000l?o`0?3ol0040?3ol0/0c?o<00<0o`000<coc03<
ol`0<P3<ol`00`3oO`00c?o<0<coc0090<coc00307lZ:P3`oo00l?o`02<0l?o`2`3oool000H0oooo
9P3`oo000`1o:RX0c?o<0<coc0090<coc0030?mo003<ol`0c?o<0340c?o<00<0o`3o0<coc03<ol`0
2`3<ol`20?3ol0L0SejI00<0l?o`0<coc03<ol`02`3<ol`00`3o0000c?o<0<coc00a0<coc0030?mo
003<ol`0c?o<00T0c?o<00<0ObXZ0?3ol03`oo008`3`oo0;0?ooo`001P3ooolV0?3ol00307lZ:P3<
ol`0c?o<00T0c?o<00<0ogl00<coc03<ol`0<03<ol`00`3o0?l0c?o<0<coc00@0<coc0030000003<
ol`0c?o<0140c?o<00<0o`000<coc03<ol`0<03<ol`00`3oO`00c?o<0<coc0090<coc00307lZ:P3`
oo00l?o`02<0l?o`2`3oool000H0oooo9P3`oo000`1o:RX0c?o<0<coc0090<coc0030?mo003<ol`0
c?o<02l0c?o<00<0o`3o0<coc03<ol`04@3<ol`00`000000c?o<0<coc00B0<coc0030?l0003<ol`0
c?o<02h0c?o<00<0ogl00<coc03<ol`02P3<ol`00`1o:RX0l?o`0?3ol00S0?3ol0/0oooo00060?oo
obH0l?o`00<0ObXZ0<coc03<ol`02P3<ol`00`3oO`00c?o<0<coc00]0<coc0030?l0o`3<ol`0c?o<
0180c?o<00<000000<coc03<ol`04`3<ol`00`3o0000c?o<0<coc00]0<coc0030?mo003<ol`0c?o<
00T0c?o<00<0ObXZ0?3ol03`oo00903`oo0;0?ooo`001P3ooolW0?3ol00307lZ:P3<ol`0c?o<00T0
c?o<00<0ogl00<coc03<ol`0;03<ol`00`3o0?l0c?o<0<coc00C0<coc0030000003<ol`0c?o<01@0
c?o<00<0o`000<coc03<ol`0;03<ol`00`3oO`00c?o<0<coc0090<coc00307lZ:P3`oo00l?o`02@0
l?o`2`3oool000H0oooo9`3`oo000`1o:RX0c?o<0<coc0090<coc0030?mo003<ol`0c?o<02/0c?o<
00<0o`3o0<coc03<ol`0503<ol`00`000000c?o<0<coc00E0<coc0030?l0003<ol`0c?o<02/0c?o<
00<0ogl00<coc03<ol`02@3<ol`00`1o:RX0l?o`0?3ol00T0?3ol0/0oooo00060?ooobL0l?o`00<0
ObXZ0<coc03<ol`02P3<ol`00`3oO`00c?o<0<coc00Y0<coc0030?l0o`3<ol`0c?o<01D0c?o<00<0
00000<coc03<ol`05P3<ol`00`3o0000c?o<0<coc00Y0<coc0030?mo003<ol`0c?o<00X0c?o<00<0
ObXZ0?3ol03`oo00903`oo0;0?ooo`001P3ooolW0?3ol00307lZ:P3<ol`0c?o<00X0c?o<00<0ogl0
0<coc03<ol`0:03<ol`00`3o0?l0c?o<0<coc00F0<coc0030000003<ol`0c?o<01L0c?o<00<0o`00
0<coc03<ol`09`3<ol`00`3oO`00c?o<0<coc00:0<coc00307lZ:P3`oo00l?o`02D0l?o`2`3oool0
00H0oooo:03`oo000`1o:RX0c?o<0<coc0090<coc0030?mo003<ol`0c?o<02L0c?o<00<0o`3o0<co
c03<ol`05`3<ol`00`000000c?o<0<coc00H0<coc0030?l0003<ol`0c?o<02H0c?o<00<0ogl00<co
c03<ol`02P3<ol`00`1o:RX0l?o`0?3ol00U0?3ol0/0oooo00060?ooobP0l?o`00<0ObXZ0<coc03<
ol`02@3<ol`00`3oO`00c?o<0<coc00V0<coc0030?l0o`3<ol`0c?o<01P0c?o<00<000000<coc03<
ol`06@3<ol`00`3o0000c?o<0<coc00U0<coc0030?mo003<ol`0c?o<00T0c?o<00<0ObXZ0?3ol03`
oo009P3`oo0;0?ooo`001P3ooolY0?3ol00307lZ:P3<ol`0c?o<00T0c?o<00<0ogl00<coc03<ol`0
903<ol`00`3o0?l0c?o<0<coc00I0<coc0030000003<ol`0c?o<01X0c?o<00<0o`000<coc03<ol`0
903<ol`00`3oO`00c?o<0<coc0090<coc00307lZ:P3`oo00l?o`02H0l?o`2`3oool000H0oooo:@3`
oo000`1o:RX0c?o<0<coc00:0<coc0030?mo003<ol`0c?o<0280c?o<00<0o`3o0<coc03<ol`06P3<
ol`00`000000c?o<0<coc00K0<coc0030?l0003<ol`0c?o<0280c?o<00<0ogl00<coc03<ol`02@3<
ol`00`1o:RX0l?o`0?3ol00W0?3ol0/0oooo00060?ooobT0l?o`00<0ObXZ0<coc03<ol`02P3<ol`0
0`3oO`00c?o<0<coc00Q0<coc0030?l0o`3<ol`0c?o<01/0c?o<00<000000<coc03<ol`0703<ol`0
0`3o0000c?o<0<coc00P0<coc0030?mo003<ol`0c?o<00X0c?o<00<0ObXZ0?3ol03`oo009`3`oo0;
0?ooo`001P3ooolY0?3ol00307lZ:P3<ol`0c?o<00/0c?o<00<0ogl00<coc03<ol`07`3<ol`00`3o
0?l0c?o<0<coc00L0<coc0030000003<ol`0c?o<01d0c?o<00<0o`000<coc03<ol`07`3<ol`00`3o
O`00c?o<0<coc00:0<coc00307lZ:P3`oo00l?o`02L0l?o`2`3oool000H0oooo:P3`oo000`1o:RX0
c?o<0<coc00:0<coc0030?mo003<ol`0c?o<01h0c?o<00<0o`3o0<coc03<ol`07@3<ol`00`000000
c?o<0<coc00N0<coc0030?l0003<ol`0c?o<01d0c?o<00<0ogl00<coc03<ol`02`3<ol`00`1o:RX0
l?o`0?3ol00W0?3ol0/0oooo00060?ooobX0l?o`00<0ObXZ0<coc03<ol`02P3<ol`00`3oO`00c?o<
0<coc00M0<coc0030?l0o`3<ol`0c?o<01h0c?o<00<000000<coc03<ol`07`3<ol`00`3o0000c?o<
0<coc00L0<coc0030?mo003<ol`0c?o<00X0c?o<00<0ObXZ0?3ol03`oo00:03`oo0;0?ooo`001P3o
ool[0?3ol00307lZ:P3<ol`0c?o<00X0c?o<00<0ogl00<coc03<ol`06`3<ol`00`3o0?l0c?o<0<co
c00O0<coc0030000003<ol`0c?o<0200c?o<00<0o`000<coc03<ol`06`3<ol`00`3oO`00c?o<0<co
c00:0<coc00307lZ:P3`oo00l?o`02P0l?o`2`3oool000H0oooo:`3`oo000`1o:RX0c?o<0<coc00:
0<coc0030?mo003<ol`0c?o<01X0c?o<00<0o`3o0<coc03<ol`0803<ol`00`000000c?o<0<coc00Q
0<coc0030?l0003<ol`0c?o<01T0c?o<00<0ogl00<coc03<ol`02P3<ol`00`1o:RX0l?o`0?3ol00Y
0?3ol0/0oooo00060?ooob`0l?o`00<0ObXZ0<coc03<ol`02P3<ol`00`3oO`00c?o<0<coc00H0<co
c0030?l0o`3<ol`0c?o<0240c?o<00<000000<coc03<ol`08P3<ol`00`3o0000c?o<0<coc00H0<co
c0030?mo003<ol`0c?o<00X0c?o<00<0ObXZ0?3ol03`oo00:@3`oo0;0?ooo`001P3oool/0?3ol003
07lZ:P3<ol`0c?o<00X0c?o<00<0ogl00<coc03<ol`05`3<ol`00`3o0?l0c?o<0<coc00R0<coc003
0000003<ol`0c?o<02<0c?o<00<0o`000<coc03<ol`05P3<ol`00`3oO`00c?o<0<coc00:0<coc003
07lZ:P3`oo00l?o`02X0l?o`2`3oool000H0oooo;@3`oo000`1o:RX0c?o<0<coc00:0<coc0030?mo
003<ol`0c?o<01D0c?o<00<0o`3o0<coc03<ol`08`3<ol`00`000000c?o<0<coc00T0<coc0030?l0
003<ol`0c?o<01D0c?o<00<0ogl00<coc03<ol`02P3<ol`00`1o:RX0l?o`0?3ol00Z0?3ol0/0oooo
00060?ooobd0l?o`00<0ObXZ0<coc03<ol`02`3<ol`00`3oO`00c?o<0<coc00C0<coc0030?l0o`3<
ol`0c?o<02@0c?o<00<000000<coc03<ol`09@3<ol`00`3o0000c?o<0<coc00C0<coc0030?mo003<
ol`0c?o<00X0c?o<00<0ObXZ0?3ol03`oo00:`3`oo0;0?ooo`001P3oool^0?3ol00307lZ:P3<ol`0
c?o<00X0c?o<00<0ogl00<coc03<ol`04P3<ol`00`3o0?l0c?o<0<coc00U0<coc0030000003<ol`0
c?o<02H0c?o<00<0o`000<coc03<ol`04@3<ol`00`3oO`00c?o<0<coc00;0<coc00307lZ:P3`oo00
l?o`02/0l?o`2`3oool000H0oooo;P3`oo000`1o:RX0c?o<0<coc00;0<coc0030?mo003<ol`0c?o<
00l0c?o<0P3o0?lX0<coc0030000003<ol`0c?o<02L0c?o<00<0o`000<coc03<ol`0403<ol`00`3o
O`00c?o<0<coc00:0<coc00307lZ:P3`oo00l?o`02`0l?o`2`3oool000H0oooo;`3`oo000`1o:RX0
c?o<0<coc00;0<coc0030?mo003<ol`0c?o<00d0c?o<00<0o`3o0<coc03<ol`0:03<ol`00`000000
c?o<0<coc00X0<coc0030?l0003<ol`0c?o<00h0c?o<00<0ogl00<coc03<ol`02`3<ol`00`1o:RX0
l?o`0?3ol00/0?3ol0/0oooo00060?ooobl0l?o`00<0ObXZ0<coc03<ol`02`3<ol`00`3oO`00c?o<
0<coc00<0<coc0030?l0o`3<ol`0c?o<02T0c?o<00<000000<coc03<ol`0:@3<ol`00`3o0000c?o<
0<coc00=0<coc0030?mo003<ol`0c?o<00X0c?o<00<0ObXZ0?3ol03`oo00;@3`oo0;0?ooo`001P3o
ool`0?3ol00307lZ:P3<ol`0c?o<00/0c?o<00<0ogl00<coc03<ol`02P3<ol`00`3o0?l0c?o<0<co
c00Z0<coc0030000003<ol`0c?o<02X0c?o<00<0o`000<coc03<ol`02`3<ol`00`3oO`00c?o<0<co
c00;0<coc00307lZ:P3`oo00l?o`02d0l?o`2`3oool000H0oooo<@3`oo000`1o:RX0c?o<0<coc00;
0<coc0030?mo003<ol`0c?o<00P0c?o<00<0o`3o0<coc03<ol`0:`3<ol`00`000000c?o<0<coc00[
0<coc0030?l0003<ol`0c?o<00P0c?o<0P3oO`0=0<coc00307lZ:P3`oo00l?o`02h0l?o`2`3oool0
00H0oooo<@3`oo000`1o:RX0c?o<0<coc00<0<coc0030?mo003<ol`0c?o<00H0c?o<00<0o`3o0<co
c03<ol`0;03<ol`00`000000c?o<0<coc00/0<coc0030?l0003<ol`0c?o<00H0c?o<00<0ogl00<co
c03<ol`03@3<ol`00`1o:RX0l?o`0?3ol00^0?3ol0/0oooo00060?oooc80l?o`00<0ObXZ0<coc03<
ol`0303<ol`00`3oO`00c?o<0<coc0040<coc0030?l0o`3<ol`0c?o<02d0c?o<00<000000<coc03<
ol`0;@3<ol`00`3o0000c?o<0<coc0040<coc0030?mo003<ol`0c?o<00d0c?o<00<0ObXZ0?3ol03`
oo00;`3`oo0;0?ooo`001P3ooolb0?3ol00307lZ:P3<ol`0c?o<00d0c?o<00<0ogl00<coc03<ol`0
0P3<ol`00`3o0?l0c?o<0<coc00^0<coc0030000003<ol`0c?o<02h0c?o<00<0o`000<coc03<ol`0
0`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`0300l?o`2`3oool000H0oooo<`3`
oo000`1o:RX0c?o<0<coc00=0<coc0040?mo003<ol`0c?o<0?l0oc40c?o<00<000000<coc03<ol`0
;`3<ol`01@3o0000c?o<0<coc03<ol`0ogl000h0c?o<00<0ObXZ0?3ol03`oo00<@3`oo0;0?ooo`00
1P3ooold0?3ol00307lZ:P3<ol`0c?o<00d0c?o<00<0ogl00?l0o`3<ol`0<@3<ol`00`000000c?o<
0<coc00`0<coc0030?l0003<ol`0ogl000h0c?o<00<0ObXZ0?3ol03`oo00<P3`oo0;0?ooo`001P3o
oole0?3ol00307lZ:P3<ol`0c?o<00`0c?o<00<0ogl00<coc03<ol`0<@3<ol`00`000000c?o<0<co
c00a0<coc0030?mo003<ol`0c?o<00d0c?o<00<0ObXZ0?3ol03`oo00<P3`oo0;0?ooo`001P3ooolf
0?3ol00307lZ:P3<ol`0c?o<00X0c?o<00<0o`3o0<coc03oO`00<P3<ol`00`000000c?o<0<coc00`
0<coc0030?mo003<ol`0o`0000d0c?o<00<0ObXZ0?3ol03`oo00<`3`oo0;0?ooo`001P3ooolf0?3o
l00307lZ:P3<ol`0c?o<00T0c?o<00@0o`3o0<coc03<ol`0c?o<0P3oO`0`0<coc0030000003<ol`0
c?o<02l0c?o<00D0ogl00<coc03<ol`0c?o<0?l0000;0<coc00307lZ:P3`oo00l?o`03@0l?o`2`3o
ool000H0oooo=`3`oo000`1o:RX0c?o<0<coc0070<coc0030?l0o`3<ol`0c?o<00@0c?o<00<0ogl0
0<coc03<ol`0;@3<ol`00`000000c?o<0<coc00^0<coc0030?mo003<ol`0c?o<00<0c?o<00<0o`00
0<coc03<ol`01`3<ol`00`1o:RX0l?o`0?3ol00e0?3ol0/0oooo00060?ooocP0l?o`00<0ObXZ0<co
c03<ol`01@3<ol`00`3o0?l0c?o<0<coc0060<coc0030?mo003<ol`0c?o<02`0c?o<00<000000<co
c03<ol`0;@3<ol`00`3oO`00c?o<0<coc0050<coc0030?l0003<ol`0c?o<00D0c?o<00<0ObXZ0?3o
l03`oo00=P3`oo0;0?ooo`001P3oooli0?3ol00307lZ:P3<ol`0c?o<00<0c?o<00<0o`3o0<coc03<
ol`0203<ol`00`3oO`00c?o<0<coc00[0<coc0030000003<ol`0c?o<02`0c?o<00<0ogl00<coc03<
ol`01`3<ol`00`3o0000c?o<0<coc0040<coc00307lZ:P3`oo00l?o`03H0l?o`2`3oool000H0oooo
>P3`oo001@1o:RX0c?o<0<coc03<ol`0o`3o00`0c?o<00<0ogl00<coc03<ol`0:P3<ol`00`000000
c?o<0<coc00[0<coc0030?mo003<ol`0c?o<00T0c?o<00<0o`000<coc03<ol`00P3<ol`00`1o:RX0
l?o`0?3ol00g0?3ol0/0oooo00060?oooc/0l?o`00<0ObXZ0<coc03o0?l03P3<ol`20?mo02X0c?o<
00<000000<coc03<ol`0:@3<ol`20?mo00d0c?o<00@0o`000<coc03<ol`0ObXZ>P3`oo0;0?ooo`00
1P3oooll0?3ol00307lZ:P3<ol`0c?o<00l0c?o<00<0ogl00<coc03<ol`09`3<ol`00`000000c?o<
0<coc00X0<coc0030?mo003<ol`0c?o<00h0c?o<00<0o`0007lZ:P3`oo00>P3`oo0;0?ooo`001P3o
oolk0?3ol0030?l0o`3`oo00ObXZ0140c?o<0P3oO`0W0<coc0030000003<ol`0c?o<02H0c?o<0P3o
O`0A0<coc00307lZ:P3o0000l?o`03X0l?o`2`3oool000H0oooo>P3`oo001@3o0?l0l?o`0?3ol03`
oo00ObXZ0180c?o<00<0ogl00<coc03<ol`0903<ol`00`000000c?o<0<coc00U0<coc0030?mo003<
ol`0c?o<0100c?o<00@0ObXZ0?3ol03`oo00o`00>P3`oo0;0?ooo`001P3oooli0?3ol0030?l0o`3`
oo00l?o`00<0l?o`00<0ObXZ0<coc03<ol`0403<ol`00`3oO`00c?o<0<coc00S0<coc0030000003<
ol`0c?o<02@0c?o<00<0ogl00<coc03<ol`0403<ol`00`1o:RX0l?o`0?3ol0020?3ol0030?l0003`
oo00l?o`03L0l?o`2`3oool000H0oooo>03`oo000`3o0?l0l?o`0?3ol0050?3ol00307lZ:P3<ol`0
c?o<0100c?o<0P3oO`0S0<coc0030000003<ol`0c?o<0280c?o<0P3oO`0B0<coc00307lZ:P3`oo00
l?o`00@0l?o`00<0o`000?3ol03`oo00=P3`oo0;0?ooo`001P3ooolg0?3ol0030?l0o`3`oo00l?o`
00L0l?o`0P1o:RXB0<coc0<0ogl0803<ol`00`000000c?o<0<coc00O0<coc0<0ogl04P3<ol`207lZ
:PP0l?o`00<0o`000?3ol03`oo00=@3`oo0;0?ooo`001P3ooolf0?3ol0030?l0o`3`oo00l?o`00T0
l?o`00<0ObXZ0<coc03<ol`04`3<ol`20?mo01h0c?o<00<000000<coc03<ol`07@3<ol`20?mo01@0
c?o<00<0ObXZ0?3ol03`oo002@3`oo000`3o0000l?o`0?3ol00d0?3ol0/0oooo00060?ooocD0l?o`
00<0o`3o0?3ol03`oo002`3`oo000`1o:RX0c?o<0<coc00D0<coc0030?mo003<ol`0c?o<01/0c?o<
00<000000<coc03<ol`06`3<ol`20?mo01D0c?o<00<0ObXZ0?3ol03`oo002`3`oo000`3o0000l?o`
0?3ol00c0?3ol0/0oooo00060?oooc@0l?o`00<0o`3o0?3ol03`oo003@3`oo0207lZ:QD0c?o<103o
O`0I0<coc0030000003<ol`0c?o<01P0c?o<0`3oO`0F0<coc00307lZ:P3`oo00l?o`00d0l?o`00<0
o`000?3ol03`oo00<P3`oo0;0?ooo`001P3ooolc0?3ol0030?l0o`3`oo00l?o`0100l?o`0P1o:RXG
0<coc0030?mo003<ol`0c?o<01H0c?o<00<000000<coc03<ol`05P3<ol`20?mo01L0c?o<0P1o:RXA
0?3ol0030?l0003`oo00l?o`0340l?o`2`3oool000H0oooo<P3`oo000`3o0?l0l?o`0?3ol00C0?3o
l00307lZ:P3<ol`0c?o<01D0c?o<103oO`0D0<coc0030000003<ol`0c?o<01<0c?o<0`3oO`0H0<co
c00307lZ:P3`oo00l?o`0180l?o`00<0o`000?3ol03`oo00<03`oo0;0?ooo`001P3ooola0?3ol003
0?l0o`3`oo00l?o`01D0l?o`00<0ObXZ0<coc03<ol`0603<ol`30?mo0140c?o<00<000000<coc03<
ol`03`3<ol`40?mo01X0c?o<00<0ObXZ0?3ol03`oo00503`oo000`3o0000l?o`0?3ol00_0?3ol0/0
oooo00060?oooc00l?o`00<0o`3o0?3ol03`oo005`3`oo000`1o:RX0c?o<0<coc00J0<coc0H0ogl0
2`3<ol`00`000000c?o<0<coc00:0<coc0D0ogl07@3<ol`00`1o:RX0l?o`0?3ol00F0?3ol0030?l0
003`oo00l?o`02h0l?o`2`3oool000H0oooo;`3`oo000`3o0?l0l?o`0?3ol00I0?3ol080ObXZ803<
ol`;0?mo00030000003<ol`0ogl000X0ogl0803<ol`207lZ:QX0l?o`00<0o`000?3ol03`oo00;@3`
oo0;0?ooo`001P3oool^0?3ol0030?l0o`3`oo00l?o`01`0l?o`0P1o:RXY0<coc080ogl0:@3<ol`2
07lZ:Qd0l?o`00<0o`000?3ol03`oo00;03`oo0;0?ooo`001P3oool]0?3ol0030?l0o`3`oo00l?o`
01l0l?o`0P1o:RXW0<coc0030000003<ol`0c?o<02H0c?o<0P1o:RXP0?3ol0030?l0003`oo00l?o`
02/0l?o`2`3oool000H0oooo;03`oo000`3o0?l0l?o`0?3ol00R0?3ol080ObXZ9@3<ol`00`000000
c?o<0<coc00T0<coc080ObXZ8`3`oo000`3o0000l?o`0?3ol00Z0?3ol0/0oooo00060?ooob/0l?o`
00<0o`3o0?3ol03`oo009@3`oo0207lZ:R<0c?o<00<000000<coc03<ol`08P3<ol`207lZ:RH0l?o`
00<0o`000?3ol03`oo00:@3`oo0;0?ooo`001P3ooolZ0?3ol0030?l0o`3`oo00l?o`02P0l?o`0P1o
:RXQ0<coc0030000003<ol`0c?o<0200c?o<0P1o:RXY0?3ol0030?l0003`oo00l?o`02P0l?o`2`3o
ool000H0oooo:@3`oo000`3o0?l0l?o`0?3ol00[0?3ol0<0ObXZ7P3<ol`00`000000c?o<0<coc00L
0<coc0@0ObXZ;03`oo000`3o0000l?o`0?3ol00W0?3ol0/0oooo00060?ooobP0l?o`00<0o`3o0?3o
l03`oo00;`3`oo0207lZ:Q`0c?o<00<000000<coc03<ol`06P3<ol`207lZ:S40l?o`00<0o`000?3o
l03`oo009P3`oo0;0?ooo`001P3ooolW0?3ol0030?l0o`3`oo00l?o`0380l?o`0P1o:RXJ0<coc003
0000003<ol`0c?o<01P0c?o<0P1o:RXd0?3ol0030?l0003`oo00l?o`02D0l?o`2`3oool000H0oooo
GP3`oo0407lZ:QH0c?o<00<000000<coc03<ol`0503<ol`407lZ:Uh0l?o`2`3oool000H0ooooHP3`
oo0507lZ:Q40c?o<00<000000<coc03<ol`0403<ol`407lZ:V80l?o`2`3oool000H0ooooI`3`oo06
07lZ:P/0c?o<00<000000<coc03<ol`02P3<ol`607lZ:VH0l?o`2`3oool000H0ooooK@3`oo0H07lZ
:V`0l?o`2`3oool000H0ooooN03`oo000`000000l?o`0?3ol01f0?3ol0/0oooo00060?ooogP0l?o`
00<000000?3ol03`oo00MP3`oo0;0?ooo`001P3ooomh0?3ol0030000003`oo00l?o`07H0l?o`2`3o
ool000H0ooooN03`oo000`000000l?o`0?3ol01f0?3ol0/0oooo00060?ooogP0l?o`00<000000?3o
l03`oo00MP3`oo0;0?ooo`001P3ooomh0?3ol0030000003`oo00l?o`07H0l?o`2`3oool000H0oooo
N03`oo000`000000l?o`0?3ol01f0?3ol0/0oooo00060?ooogP0l?o`00<000000?3ol03`oo00MP3`
oo0;0?ooo`001P3ooomh0?3ol0030000003`oo00l?o`07H0l?o`2`3oool000H0ooooN03`oo000`00
0000l?o`0?3ol01f0?3ol0/0oooo00060?ooogP0l?o`00<000000?3ol03`oo00MP3`oo0;0?ooo`00
1P3ooomh0?3ol0030000003`oo00l?o`07H0l?o`2`3oool000H0ooooN03`oo000`000000l?o`0?3o
l01f0?3ol0/0oooo00060?ooogP0l?o`00<000000?3ol03`oo00MP3`oo0;0?ooo`001P3ooomh0?3o
l0030000003`oo00l?o`07H0l?o`2`3oool000H0ooooN03`oo000`000000l?o`0?3ol01f0?3ol0/0
oooo00060?ooogP0l?o`00<000000?3ol03`oo00MP3`oo0;0?ooo`001P3ooomh0?3ol0030000003`
oo00l?o`07H0l?o`2`3oool000H0ooooN03`oo000`000000l?o`0?3ol01f0?3ol0/0oooo00060?oo
ogP0l?o`00<000000?3ol03`oo00MP3`oo0;0?ooo`001P3ooomh0?3ol0030000003`oo00l?o`07H0
l?o`2`3oool000H0ooooN03`oo000`000000l?o`0?3ol01f0?3ol0/0oooo00060?ooogP0l?o`00<0
00000?3ol03`oo00MP3`oo0;0?ooo`001P3ooomh0?3ol0030000003`oo00l?o`07H0l?o`2`3oool0
00H0ooooN03`oo000`000000l?o`0?3ol01f0?3ol0/0oooo00060?ooogP0l?o`00<000000?3ol03`
oo00MP3`oo0;0?ooo`001P3ooomh0?3ol0030000003`oo00l?o`07H0l?o`2`3oool000H0ooooN03`
oo000`000000l?o`0?3ol01f0?3ol0/0oooo00060?ooogP0l?o`00<000000?3ol03`oo00MP3`oo0;
0?ooo`001P3ooomh0?3ol0030000003`oo00l?o`07H0l?o`2`3oool000H0ooooMP3`oo05000007H0
l?o`2`3oool000H0ooooMP3`oo05000000@0l?o`0P00001`0?3ol0/0oooo00060?ooogH0l?o`1000
00060?3ol0030000003`oo00l?o`06h0l?o`2`3oool000H0ooooM`3`oo03000000L0l?o`00<00000
0?3ol03`oo00K@3`oo0;0?ooo`001P3ooomg0?3ol0<000001P3`oo000`000000l?o`0000001^0?3o
l0/0oooo00060?ooogL0l?o`0`0000050?3ol0040000003`oo00l?o`000006h0l?o`2`3oool007d0
oooo0P0000050?ooo`<0000000<0oooo000000000000N03oool007h0oooo00<000000?ooo`3oool0
P@3oool007h0oooo00<000000?ooo`3oool0P@3oool00?l0oooo0`3oool00?l0oooo0`3oool00?l0
oooo0`3oool00?l0oooo0`3oool00?l0oooo0`3oool00?l0oooo0`3oool00001\
\>"],
    ImageRangeCache->{{{0, 257}, {257, 0}} -> {-3, -3, 0, 0}}],
  "       ",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.436364 0.363636 0.302624 0.0852461 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30262 m
1 .30262 L
s
.43636 0 m
.43636 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
0 .30262 m
.14402 .30262 L
.43294 .30262 L
.74059 .30262 L
s
.74059 .30262 m
1 .30262 L
s
.941 1 .941 r
0 .03482 m
.98182 .03482 L
.98182 .57043 L
0 .57043 L
0 .03482 L
F
.8 1 .8 r
.21818 .03482 m
.76364 .03482 L
.76364 .57043 L
.21818 .57043 L
.21818 .03482 L
F
0 g
.98182 .30262 m
1 .30262 L
s
% Start of user PostScript
1.5 0 1.55 0 MAarrowhead1
% End of user PostScript
.43636 .60098 m
.43636 .60951 L
s
% Start of user PostScript
0 3.5 0 3.6 MAarrowhead1
% End of user PostScript
0 .30262 m
.98182 .30262 L
s
.43636 .03482 m
.43636 .57043 L
s
1 0 1 r
0 .50348 m
.98182 .50348 L
s
1 0 0 r
0 .36958 m
.98182 .36958 L
s
0 0 1 r
[ .025 .025 ] 0 setdash
0 .07945 m
.98182 .07945 L
s
.56 .37 .6 r
.21818 .03482 m
.21818 .57043 L
s
1 .5 0 r
[ ] 0 setdash
.70909 .03482 m
.70909 .57043 L
s
.5 .165 .165 r
.76364 .03482 m
.76364 .57043 L
s
0 1 0 r
0 .57043 m
.98182 .57043 L
s
[ .025 .025 ] 0 setdash
0 .03482 m
.98182 .03482 L
s
0 g
gsave
.97455 .33672 -66 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45455 .60951 -69 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
75.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4 .59601 -78 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344p) show
93.000 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4 .00924 -78 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344p) show
93.000 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oJP3oool6
000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2P0?ooo`00I03oool40000
00<0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo0:00oooo001[0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000002@3oool00`00
0000oooo0?ooo`2P0?ooo`00J`3oool00`000000oooo000000030?ooo`030000003oool0000000T0
oooo00<000000?ooo`3oool0X03oool006X0oooo100000020?ooo`D00000203oool00`000000oooo
0?ooo`2P0?ooo`00O@3oool00`000000oooo0?ooo`2P0?ooo`00K03oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0:00oooo001m0?ooo`030000003oool0oooo0:00oooo001m0?ooo`03
0000003oool0oooo0:00oooo001m0?ooo`030000003oool0oooo0:00oooo0008003o00H0oooo2000
o`060?ooo`T00?l01P3oool8003o00H0oooo2000o`060?ooo`T00?l01P3oool8003o00H0oooo2000
o`060?ooo`P00?l00`3oool010000000oooo0?ooo`3oool8003o00H0oooo2000o`060?ooo`P00?l0
1`3oool8003o00H0oooo2000o`060?ooo`P00?l01`3oool8003o00H0oooo2000o`060?ooo`P00?l0
1P3oool9003o00H0oooo2000o`080?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<
ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n
0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<
0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI0<coc03<ol`0?03<ol`00`00
0000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?oo
o`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<
ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<
00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`
1`3oool003h0l?o`00<0SejI0<coc03<ol`0?03<ol`00`000000c?o<0<coc01;0<coc0030?mo003<
ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l
0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l
0?3ol0L0oooo000n0?3ol3l0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<co
c00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`?`3<ol`00`000000c?o<0<coc01;0<coc003
0?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo0o0<coc0030000
003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo
000n0?3ol3l0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`
oo00l?o`03`0l?o`1`3oool000P0003o1P3`oo080000o`H0l?o`2@000?l60?3ol0P0003o1P3`oo08
0000o`H0c?o<2@000?l60<coc0P0003o1P3<ol`80000o`H0c?o<20000?l30<coc0040000003<ol`0
c?o<0<coc0P0003o1P3<ol`80000o`H0c?o<20000?l70<coc0P0003o1P3<ol`80000o`H0c?o<0`00
0?l00`3oO`00003o0000o`020000o`L0c?o<0`000?l00`1o:RX0003o0000o`020000o`H0l?o`2000
0?l60?3ol0P0003o1P3`oo090000o`H0l?o`20000?l00`3`oo00oooo0?ooo`050?ooo`00?P3`oo0o
0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l
0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3o
O`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI0<coc03<
ol`0?03<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`
oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<
00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol00308mNV@3<
ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`
oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI0<coc03<ol`0?03<ol`00`000000c?o<0<coc01;
0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?
GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o
:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<
ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`
00<0SejI0<coc03<ol`0?03<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<
00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo0o0<coc0030000003<ol`0c?o<04/0c?o<00<0
ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol3l0c?o<00<00000
0<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool0
03h0l?o`?`3<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3o
l03`oo00?03`oo070?ooo`00?P3`oo0o0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<
ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol3l0c?o<00<000000<coc03<ol`0
B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`?`3<
ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`
oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl0
0<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<
03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`
03`0l?o`1`3oool003h0l?o`00<0SejI0<coc03<ol`0?03<ol`00`000000c?o<0<coc01;0<coc003
0?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<
0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`
0?3ol00l0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<
ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI
0<coc03<ol`0?03<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ
0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<
04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol003
08mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc003
07lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`?`3<ol`00`000000c?o<0<coc01;0<coc0030?mo
003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo0o0<coc0030000003<
ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n
0?3ol3l0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00
l?o`03`0l?o`1`3oool003h0l?o`?`3<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<
00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo0o0<coc0030000003<ol`0c?o<04/0
c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol3l0c?o<
00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`
1`3oool003h0l?o`?`3<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0
ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0
c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3o
l00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<co
c00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI0<coc03<ol`0?03<ol`00`000000
c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00
?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0
303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<0
00000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3o
ool003h0l?o`00<0SejI0<coc03<ol`0?03<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0
c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<co
c0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3o
l0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00
c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`?`3<ol`00`000000c?o<
0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`
oo0o0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3o
l00l0?3ol0L0oooo000n0?3ol3l0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<
0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`?`3<ol`00`000000c?o<0<coc01;0<co
c0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo0o0<coc003
0000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0
oooo000n0?3ol3l0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ
:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI0<coc03<ol`0?03<ol`00`000000c?o<0<co
c01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo00
0`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`0
0`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<co
c03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0
l?o`00<0SejI0<coc03<ol`0?03<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0
c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000
003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo
000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<co
c00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI0<coc03<ol`0?03<ol`0
0`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo07
0?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<co
c03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol3l0c?o<00<000000<coc03<
ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`
?`3<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00
?03`oo070?ooo`00?P3`oo0o0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<
ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol3l0c?o<00<000000<coc03<ol`0B`3<ol`0
0`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`?`3<ol`00`00
0000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?oo
o`00?P3`oo0o0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0
l?o`0?3ol00l0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0
B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`00<0
SejI0<coc03<ol`0?03<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0
ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0
c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3o
l00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<co
c00307lZ:P3`oo00l?o`03T0l?o`0P0000000`3`oo00oooo0?ooo`050?ooo`00?P3`oo000`2?GYT0
c?o<0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0
l?o`0?3ol00i0?3ol0H00000103oool003h0000000<0SejI000000000000RP0000000`3oO`000000
0000000<0000000307lZ:P0000000000048000000@3oool003h0l?o`00<0SejI0<coc03<ol`0?03<
ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00>@3`
oo07000000<0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`0
0`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03T0l?o`0`0000070?ooo`00?P3`oo0o0<co
c0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3o
l0L0oooo000n0?3ol3l0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc003
07lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`?`3<ol`00`000000c?o<0<coc01;0<coc0030?mo
003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo0o0<coc0030000003<
ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n
0?3ol3l0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00
l?o`03`0l?o`1`3oool003h0l?o`?`3<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<
00`0c?o<00<0ObXZ0?3ol03`oo00>@3`oo04000000H0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0
c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03P0
l?o`00@000000?3ol03`oo0000001`3oool003h0l?o`00<0SejI0<coc03<ol`0?03<ol`00`000000
c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00>03`oo0010000000
l?o`0?3ol00000070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<04/0
c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00g0?3ol080000000<0l?o`00000000
00001`3oool003h0l?o`00<0SejI0<coc03<ol`0?03<ol`00`000000c?o<0<coc01;0<coc0030?mo
003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<0<co
c00l0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3o
l00l0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`0
0`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI0<co
c03<ol`0?03<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3o
l03`oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<04/0
c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol00308mN
V@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ
:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`?`3<ol`00`000000c?o<0<coc01;0<coc0030?mo003<
ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00b`3o00000`3oO`00o`000?l0000<
0?l0000307lZ:P3o0000o`0003d0o`001P3oool003h0l?o`?`3<ol`00`000000c?o<0<coc01;0<co
c0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo0o0<coc003
0000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0
oooo000n0?3ol3l0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ
:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`?`3<ol`00`000000c?o<0<coc01;0<coc0030?mo003<
ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l
0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l
0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3o
O`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI0<coc03<
ol`0?03<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`
oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<
00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol00308mNV@3<
ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`
oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI0<coc03<ol`0?03<ol`00`000000c?o<0<coc01;
0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?
GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o
:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<
ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`
?`3<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00
?03`oo070?ooo`00?P3`oo0o0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<
ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol3l0c?o<00<000000<coc03<ol`0B`3<ol`0
0`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`?`3<ol`00`00
0000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?oo
o`00?P3`oo0o0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0
l?o`0?3ol00l0?3ol0L0oooo000n0?3ol3l0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<
0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI0<coc03<ol`0?03<
ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`
oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl0
0<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<
03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`
03`0l?o`1`3oool003h0l?o`00<0SejI0<coc03<ol`0?03<ol`00`000000c?o<0<coc01;0<coc003
0?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<
0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`
0?3ol00l0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<
ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI
0<coc03<ol`0?03<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ
0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<
04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol3l0
c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0
l?o`1`3oool003h0l?o`?`3<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<
00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo0o0<coc0030000003<ol`0c?o<04/0c?o<00<0
ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol3l0c?o<00<00000
0<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool0
03h0l?o`?`3<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3o
l03`oo00?03`oo070?ooo`00?P3`oo0o0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<
ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<
00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`
1`3oool003h0l?o`00<0SejI0<coc03<ol`0?03<ol`00`000000c?o<0<coc01;0<coc0030?mo003<
ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l
0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l
0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3o
O`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI0<coc03<
ol`0?03<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`
oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<
00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?l0o`0308mNV@3o
0?l0o`3o08X0o`3o00<0ogl00?l0o`3o0?l0303o0?l00`1o:RX0o`3o0?l0o`0m0?l0o`H0oooo000n
0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<
0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI0<coc03<ol`0?03<ol`00`00
0000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?oo
o`00?P3`oo0o0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0
l?o`0?3ol00l0?3ol0L0oooo000n0?3ol3l0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<
0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`?`3<ol`00`000000c?o<0<co
c01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo0o
0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l
0?3ol0L0oooo000n0?3ol3l0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<co
c00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`?`3<ol`00`000000c?o<0<coc01;0<coc003
0?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<
0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`
0?3ol00l0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<
ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI
0<coc03<ol`0?03<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ
0?3ol03`oo00?03`oo070?ooo`00?P3`oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<
04/0c?o<00<0ogl00<coc03<ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol003
08mNV@3<ol`0c?o<03`0c?o<00<000000<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc003
07lZ:P3`oo00l?o`03`0l?o`1`3oool003h0l?o`00<0SejI0<coc03<ol`0?03<ol`00`000000c?o<
0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3ol03`oo00?03`oo070?ooo`00?P3`
oo000`2?GYT0c?o<0<coc00l0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<ol`0303<
ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo000n0?3ol00308mNV@3<ol`0c?o<03`0c?o<00<00000
0<coc03<ol`0B`3<ol`00`3oO`00c?o<0<coc00<0<coc00307lZ:P3`oo00l?o`03`0l?o`1`3oool0
03h0l?o`?`3<ol`00`000000c?o<0<coc01;0<coc0030?mo003<ol`0c?o<00`0c?o<00<0ObXZ0?3o
l03`oo00?03`oo070?ooo`00?P3`oo0o0<coc0030000003<ol`0c?o<04/0c?o<00<0ogl00<coc03<
ol`0303<ol`00`1o:RX0l?o`0?3ol00l0?3ol0L0oooo003o003o01/00?l01P3oool007d0oooo00<0
00000?ooo`3oool0X03oool007d0oooo00<000000?ooo`3oool0X03oool007/0oooo1@00002P0?oo
o`00N`3oool500000:00oooo001Z0?ooo`H00000103oool00`000000oooo0?ooo`040?ooo`@00000
X@3oool006/0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000080?ooo`<00000
X@3oool006/0oooo00<000000?ooo`0000000`3oool00`000000oooo000000080?ooo`<00000X@3o
ool006/0oooo00<000000?ooo`0000000`3oool00`000000oooo000000080?ooo`<00000X@3oool0
06X0oooo100000020?ooo`D000001`3oool2000000H0oooo0P00002J0?ooo`00O@3oool00`000000
oooo0?ooo`040?ooo`800000VP3oool006`0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000009T0oooo001m0?ooo`030000003oool0oooo0080oooo
0P0000020?ooo`800000V03oool007d0oooo00<000000?ooo`3oool0X03oool00001\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1, -3, 0, 0}}],
  "  \n\t\t\t\t",
  StyleBox["Figure 5.A",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The principal branch of the logarithm ",
  Cell[BoxData[
      \(w = Log \((z)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Caution.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  A phenomenon inherent in constructing an logarithm function:  It must \
have a discontinuity!  This is the case because as we saw in Chapter 2, any \
branch we choose for  ",
  Cell[BoxData[
      \(\(\(\ \)\(arg \((z)\)\)\)\)]],
  "  is necessarily a discontinuous function.  The principal branch,  ",
  Cell[BoxData[
      \(Log \((z)\)\)]],
  ",  is discontinuous at each point along the negative x-axis.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Investigate the complex logarithm function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution for Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(w = \(f[z] = Log[x + \[ImaginaryI]\ y]\)\)]],
  "  and find its real and imaginary parts"
}], "Text"],

Cell[BoxData[{
    \(\(Remove[x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, u, v];\)\ \), "\n", 
    \(\(f[z_]\  = \ Log[z];\)\ \), "\n", 
    \(\(u[x_, y_]\  = \ 
        ComplexExpand[Re[f[x + \[ImaginaryI]\ y]], 
          TargetFunctions \[Rule] {Re, Im}];\)\ \), "\n", 
    \(\(v[x_, y_]\  = \ 
        ComplexExpand[Im[f[x + \[ImaginaryI]\ y]], 
          TargetFunctions \[Rule] {Re, Im}];\)\ \), "\n", 
    \(\(Print["\<    Log[x+\[ImaginaryI]y] = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    Log[x+\[ImaginaryI]y] = \>", 
        ComplexExpand[f[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(Print["\<    Log[x+\[ImaginaryI]y] = \>", 
        u[x, y] + \ \[ImaginaryI]\ v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Re[Log[x+\[ImaginaryI]y]] = \>", u[x, y]];\)\ \), "\n", 
    \(\(Print["\<Im[Log[x+\[ImaginaryI]y]] = \>", 
        v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Find the polar form of the real and imaginary parts of the logarithm \
function.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[f, r, \[Theta], u, U, v, V, w, 
        z];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_]\  = \ Log[z];\)\ \), "\[IndentingNewLine]", 
    \(\(U[r_, \[Theta]_]\  = \ Log[r];\)\ \), "\n", 
    \(\(V[r_, \[Theta]_]\  = \ \[Theta];\)\ \), "\n", 
    \(\(W\  = \ 
        U[r, \[Theta]]\  + \ \[ImaginaryI]\ V[r, \[Theta]];\)\ \), "\n", 
    \(\(u[r_, \[Theta]_]\  = \ 
        PowerExpand[
          ComplexExpand[
            Re[f[r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]], 
            TargetFunctions \[Rule] {Re, Im}]];\)\ \), "\n", 
    \(\(v[r_, \[Theta]_]\  = \ 
        ComplexExpand[Im[f[r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]], 
          TargetFunctions \[Rule] {Re, Im}];\)\ \), "\n", 
    \(\(Print[\*"\"\<    Log[r \!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)] \
= \>\"", f[
          r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    Log[r \!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)] \
= \>\"", ComplexExpand[
          f[r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<    Log[r \!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)] \
= \>\"", u[
            r, \[Theta]] + \ \[ImaginaryI]\ v[
              r, \[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    Log[r \!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)] \
= \>\"", U[
            r, \[Theta]] + \ \[ImaginaryI]\ V[
              r, \[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Re[Log[r \!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)]] \
= \>\"", u[r, \[Theta]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<Im[Log[r \!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)]] \
= \>\"", v[r, \[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Im[Log[r \!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)]] \
= \>\"", V[r, \[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 5.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Find the values of  ",
  Cell[BoxData[
      \(Log \((1 + \[ImaginaryI])\)\ \ \ and\ \ \ log \((1 + \[ImaginaryI])\)\
\)]],
  ".  \n\nSolution.  By standard computations, we have  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(log \((1 + \[ImaginaryI])\)\), " ", "=", 
          RowBox[{"{", 
            
            RowBox[{\(ln | 
                1 + \[ImaginaryI] | \(+\ \[ImaginaryI]\) \((Arg \((1 + \
\[ImaginaryI])\) + 2  n\ \[Pi])\)\), ":", " ", 
              RowBox[{
                StyleBox["where",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], " ", "n", " ", 
                StyleBox["is",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["an",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["integer",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}], "}"}]}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"                       ", 
        RowBox[{"=", 
          RowBox[{"{", 
            
            RowBox[{\(ln \@ 2 + \ \[ImaginaryI] \((\[Pi]\/4 + 
                      2  n\ \[Pi])\)\), ":", " ", 
              RowBox[{
                StyleBox["where",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], " ", "n", " ", 
                StyleBox["is",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["an",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["integer",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}], "}"}]}]}]}]],
  "  \n\t\t\tand\n\t\t\t",
  Cell[BoxData[{
      RowBox[{"       ", 
        RowBox[{\(log \((\[ImaginaryI])\)\), " ", "=", 
          RowBox[{"{", 
            
            RowBox[{\(ln | \[ImaginaryI] | \(+\ \[ImaginaryI]\) \((Arg \((\
\[ImaginaryI])\) + 2  n\ \[Pi])\)\), ":", " ", 
              RowBox[{
                StyleBox["where",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], " ", "n", " ", 
                StyleBox["is",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["an",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["integer",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}], "}"}]}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"                       ", 
        RowBox[{"=", 
          RowBox[{"{", " ", 
            
            RowBox[{\(\[ImaginaryI] \((\[Pi]\/2 + 2  n\ \[Pi])\)\), ":", " ", 
              
              RowBox[{
                StyleBox["where",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], " ", "n", " ", 
                StyleBox["is",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["an",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["integer",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}], "}"}]}]}]}]],
  "    \nThe principal values are\n\n\t\t\t",
  Cell[BoxData[{
      \(Log \((1 + \[ImaginaryI])\)\  = \(ln \@ 2 + \ \[ImaginaryI]  \[Pi]\/4 \
= \(ln\ 2\)\/2 + \ \[ImaginaryI]  \[Pi]\/4\)\), "\[IndentingNewLine]", 
      \(and\), "\[IndentingNewLine]", 
      \(Log \((\[ImaginaryI])\)\  = \ \[ImaginaryI]  \[Pi]\/2\)}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter  ",
  Cell[BoxData[
      \(z = 1 + \[ImaginaryI]\)]],
  "  and take its logarithm. "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[w, z];\)\ \), "\[IndentingNewLine]", 
    \(\(z = 1 + \[ImaginaryI];\)\ \), "\n", 
    \(\(w\  = \ ComplexExpand[Log[z]];\)\ \), "\n", 
    \(\(Print["\<Log[\>", z, "\<] = \>", w];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The best we can do for the multivalued  ",
  Cell[BoxData[
      \(log \((1 + \[ImaginaryI])\)\)]],
  "  is to add  ",
  Cell[BoxData[
      \(\[ImaginaryI]\ 2  \[Pi]\ n\ \ \ to\ \ \ Log \((1 + \
\[ImaginaryI])\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[w];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[n];\)\ \), "\n", 
    \(\(w\_1\  = \ ComplexExpand[Log[z]];\)\ \), "\n", 
    \(\(w\_2\  = \ 
        ComplexExpand[
          Log[z]\  + \ \[ImaginaryI]\ 2\ \[Pi]\ n\ ];\)\ \), "\n", 
    \(\(Print["\<Log[\>", z, "\<] = \>", Log[z]];\)\ \), "\n", 
    \(\(Print["\<Log[\>", z, "\<] = \>", w\_1];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<log[\>", z, "\<] = \>", 
        Log[z]\  + \ \[ImaginaryI]\ 2\ \[Pi]\ n];\)\ \), "\n", 
    \(\(Print["\<log[\>", z, "\<] = \>", 
        w\_2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The transformation  ",
  StyleBox["w = Log(z)",
    FontFamily->"Courier New"],
  "  maps the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-plane punctured at the origin onto the horizontal strip in the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  "-plane."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore Solution for Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ Log[z];\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Iden, \ {1.0\/150, 150.1, 15}, {\(-3.141\), 3.141, 3.141\/6}, 
        PlotRange \[Rule] {{\(-150\), 150}, {\(-150\), 150}}, 
        AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-150\), 150, 150], Range[\(-150\), 150, 150]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The z-plane punctured at the origin  {z: |z| > 0}.\>"];\)\ \
\), "\n", 
    \(\(PolarMap[f, {1.0\/150, 150.1, 15}, {\(-3.141\), 3.141, 3.141\/6}, 
        PlotRange \[Rule] {{\(-5.3\), 5.3}, {\(-3.3\), 3.3}}, 
        AspectRatio \[Rule] 3.3\/5.3, 
        Ticks \[Rule] {Range[\(-5\), 5, 5], Range[\(-\[Pi]\), \[Pi], \[Pi]]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image is the horizontal strip - \[Pi] < v \[LessEqual] \
\[Pi],\>"];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tWe now investigate some of the properties of ",
  StyleBox["log(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Log(z)",
    FontFamily->"Courier New"],
  ".  From Equations ",
  StyleBox["(5-10)",
    FontColor->RGBColor[0, 0, 1]],
  ", ",
  StyleBox["(5-12)",
    FontColor->RGBColor[0, 0, 1]],
  ", and ",
  StyleBox["(5-14)",
    FontColor->RGBColor[0, 0, 1]],
  ", it follows that\n\n",
  StyleBox["(5-15)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(exp \((Log\ z)\)\  = \ z\)]],
  "   for all z\[NotEqual]0   \n\t\t\tand \n",
  StyleBox["(5-16)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(Log \((exp\ z)\)\  = \ z\)]],
  ",   provided   ",
  Cell[BoxData[
      \(\(-\[Pi]\)\  < \ Arg \((z)\)\  \[LessEqual] \ \[Pi]\)]],
  ",    \n\nand that the mapping  ",
  StyleBox["w = Log(z)",
    FontFamily->"Courier New"],
  "  is one-to-one from domain  ",
  Cell[BoxData[
      \(D = {z : \(\(|\)\(z\)\(|\)\(\(>\)\(0\)\)\)}\)]],
  "  in the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane onto the horizontal strip  ",
  Cell[BoxData[
      \({w : \(-\[Pi]\)\  < \ Im \((w)\) \[LessEqual] \ \[Pi]}\)]],
  "  in the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane.\n    The following example illustrates that, even though ",
  StyleBox["Log(z)",
    FontFamily->"Courier New"],
  " is not continuous along the negative real axis, it is still defined \
there."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 5.4.  ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "Identity  reveals that  \n\n\t",
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  Cell[BoxData[
      \(Log \((\(-\[ExponentialE]\))\)\  = \ \ \(ln | \(-\[ExponentialE]\) | \
\ \(+\ \[ImaginaryI]\)\ Arg \((\(-\[ExponentialE]\))\)\  = \ \ \(\(1\)\(+\)\(\
\ \)\(\[ImaginaryI]\)\(\ \)\)\)\)]],
  ",   and  \n\n\t",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  Cell[BoxData[
      \(Log \((\(-1\))\)\  = \ \ \(\(ln | \(-1\) | \ \(+\ \ \
\[ImaginaryI]\)\ \ Arg \((\(-1\))\)\)\(\ \ \)\(=\)\(\ \ \)\(\[ImaginaryI]\)\(\
\ \ \)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Enter  ",
  Cell[BoxData[
      \(z = \(-\[ExponentialE]\)\)]],
  "  and take its logarithm. "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, w];\)\ \), "\n", 
    \(\(z\ \  = \ \(-\ \[ExponentialE]\);\)\ \), "\n", 
    \(\(w\_1\  = \ Log[Abs[z]]\  + \ \[ImaginaryI]\ Arg[z];\)\ \), "\n", 
    \(\(w\_2\  = \ ComplexExpand[Log[z]];\)\ \), "\n", 
    \(\(Print["\<z = \>", z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Log[Abs[\>", z, "\<]] = \>", "\<Log[\>", 
        Abs[z], "\<] = \>", \ Log[Abs[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Arg[\>", z, "\<]  = \>", 
        Arg[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Log[Abs[\>", z, "\<]] + \[ImaginaryI] Arg[\>", 
        z, "\<] = \>", w\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Log[\>", z, "\<] = (\>", 
        Log[Abs[z]], "\<) + \[ImaginaryI] (\>", \ 
        Arg[z], "\<)\>"];\)\ \), "\n", 
    \(\(Print["\<Log[\>", z, "\<] = \>", 
        w\_2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Enter  ",
  Cell[BoxData[
      \(z = \(-1\)\)]],
  "  and take its logarithm. "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, w];\)\ \), "\n", 
    \(\(z\ \  = \ \(-\ 1\);\)\ \), "\n", 
    \(\(w\_1\  = \ Log[Abs[z]]\  + \ \[ImaginaryI]\ Arg[z];\)\ \), "\n", 
    \(\(w\_2\  = \ ComplexExpand[Log[z]];\)\ \), "\n", 
    \(\(Print["\<z = \>", z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Log[Abs[\>", z, "\<]] = \>", "\<Log[\>", 
        Abs[z], "\<] = \>", \ Log[Abs[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Arg[\>", z, "\<]  = \>", 
        Arg[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Log[Abs[\>", z, "\<]] + \[ImaginaryI] Arg[\>", 
        z, "\<] = \>", w\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Log[\>", z, "\<] = (\>", 
        Log[Abs[z]], "\<) + \[ImaginaryI] (\>", \ 
        Arg[z], "\<)\>"];\)\ \), "\n", 
    \(\(Print["\<Log[\>", z, "\<] = \>", 
        w\_2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tWhen  ",
  Cell[BoxData[
      \(z = x + \[ImaginaryI]\ y\)]],
  ",  where ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " is a positive real number, the principal value of the complex logarithm \
of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " is  \n\n\t\t\t",
  Cell[BoxData[
      \(Log \((x + \[ImaginaryI]\ 0)\)\  = \ \(ln\ x + \[ImaginaryI]\ Arg \
\((x)\)\  = \ \(ln\ x + \[ImaginaryI]\ 0\  = \ ln\ x\)\)\)]],
  ",  \n\t\t\nwhere ",
  Cell[BoxData[
      \(x > 0\)]],
  ".  Hence ",
  StyleBox["Log",
    FontFamily->"Courier New"],
  " is an extension of the real function ",
  StyleBox["ln(x)",
    FontFamily->"Courier New"],
  " to the complex case.  Are there other similarities?  Let's use complex \
function theory to find the derivative of ",
  StyleBox["Log(z)",
    FontFamily->"Courier New"],
  ".   \nWhen we use polar coordinates for  ",
  Cell[BoxData[
      \(z = 
        r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\  \[NotEqual] \ 
          0\)]],
  ",  equation ",
  StyleBox["(5-14)",
    FontColor->RGBColor[0, 0, 1]],
  " becomes  "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[BoxData[{
      RowBox[{\(Log \((z)\)\ \  = \ \ Log \((r\ \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Theta]\))\)\), " ", "\n"}], "\[IndentingNewLine]", 
      RowBox[{
        "                 ", \(\(=\)\(\ \ \)\(ln\  | 
            r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\) | \ \ \(+\ \ \
\[ImaginaryI]\)\ Arg \((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\))\)\)\), "\n", "                     "}], "\[IndentingNewLine]", 
      RowBox[{"                 ", 
        RowBox[{\(\(=\)\(\ \)\(ln\ r\ \  + \ \[ImaginaryI]\ \ \[Theta]\)\), 
          ",", "   ", 
          RowBox[{
            RowBox[{
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "r"}], ">", 
            RowBox[{
              RowBox[{"0", "  ", 
                StyleBox["and",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}], "   ", "-", "\[Pi]"}], " ", "<",
             " ", "\[Theta]", " ", "\[LessEqual]", " ", "\[Pi]"}]}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "                 ", \(\(=\)\(U \((r, \[Theta])\)\  + \ \[ImaginaryI]\
\ V \((r, \[Theta])\)\)\)}]}]],
  "  "
}], "Text"],

Cell[TextData[{
  "where  ",
  Cell[BoxData[
      RowBox[{\(U \((r, \[Theta])\)\), " ", "=", 
        RowBox[{
          RowBox[{"ln", " ", "r", "   ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "   ", "V", \((r, \[Theta])\)}], "=", 
          "\[Theta]"}]}]]],
  ".  Because ",
  Cell[BoxData[
      \(Arg \((z)\)\)]],
  " is discontinuous only at points in its domain that lie on the negative \
real axis, U and V have continuous partials for any point ",
  Cell[BoxData[
      \(\((r, \[Theta])\)\)]],
  " in their domain, provided ",
  Cell[BoxData[
      \(r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)]],
  " is not on the negative real axis, that is, provided  ",
  Cell[BoxData[
      \(\(-\[Pi]\)\  < \ \[Theta]\  < \ \[Pi]\)]],
  "  (Note the strict inequality for  here.).   In addition, the polar form \
of the Cauchy-Riemann equations holds in this region (see Equation ",
  StyleBox["(3-22)",
    FontColor->RGBColor[0, 0, 1]],
  " of Section 3.2), since  ",
  Cell[BoxData[
      \(\(U\_r\) \((r, \[Theta])\)\  = 
        1\/r, \ \(U\_\[Theta]\) \((r, \[Theta])\)\  = 
        0, \ \(V\_r\) \((r, \[Theta])\) = 
        0, \ \(V\_\[Theta]\) \((r, \[Theta])\) = 1\)]],
  "  it follows that  \n\n\t\t\t",
  Cell[BoxData[
      \(\(U\_r\) \((r, \[Theta])\)\  = \ \(1\/r\  = \ \(1\/r\) \
\(V\_\[Theta]\) \((r, \[Theta])\)\)\)]],
  "\n\t\tand\n\t\t\t",
  Cell[BoxData[
      \(\(U\_\[Theta]\) \((r, \[Theta])\)\  = \ \(0\  = \ \(\(\(-1\)\/r\) 
              0 = \(-\(\(-1\)\/r\)\) \(V\_r\) \((r, \[Theta])\)\)\)\)]]
}], "Text"],

Cell[TextData[{
  "Using Theorem 3.5 of Section 3,2, we see that  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(d\/dz\) 
          Log \((z)\)\ \  = \ \ \(\[ExponentialE]\^\(\(-\ \[ImaginaryI]\)\ \
\[Theta]\)\) \((\(U\_r\) \((r, \[Theta])\)\  + \[ImaginaryI]\ \ \(U\_\[Theta]\
\) \((r, \[Theta])\))\)\ \[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(\
\[ExponentialE]\^\(\(-\ \[ImaginaryI]\)\ \[Theta]\)\) \((1\/r\  + 
                0\ \[ImaginaryI])\)\ \  = \ \ 1\/\(r\ \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Theta]\)\)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(1\/z\)\)\
\)}]],
  "  \n\nprovided   ",
  Cell[BoxData[
      RowBox[{"r", ">", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}], "  ", "-", "\[Pi]"}], " ", "<", " ",
         "\[Theta]", " ", "<", " ", "\[Pi]"}]]],
  ".  Thus the principal branch of the complex logarithm has the derivative \
we would expect.  Other properties of the logarithm carry over, but only in \
specified regions of the complex plane.  "
}], "Text"],

Cell[TextData[{
  "\n",
  StyleBox["Example 5.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the identity  ",
  Cell[BoxData[
      \(Log \((\(z\_1\) z\_2)\)\  = \ 
        Log \((z\_1)\)\  + \ Log \((z\_2)\)\)]],
  "  is not always valid.  \n\nSolution.  Let  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), "=", 
        RowBox[{
          RowBox[{\(-\@3\), "+", 
            RowBox[{"\[ImaginaryI]", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(z\_2\)}]}], 
          "=", \(\(-1\) + \[ImaginaryI]\ \@3\)}]}]]],
  ".  Then  \n\n\t\t\t",
  Cell[BoxData[{
      \(Log \((z\_1\ z\_2)\)\ \  = \ \ Log[\((\(-\@3\) + \[ImaginaryI])\)\ \
\((\(-1\) + \[ImaginaryI]\ \@3)\)]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(Log \
\((\(-4\)\ \[ImaginaryI])\)\ \  = \ \ \ ln\ 4\  + \ \[ImaginaryI] \(\(\ \)\(-\
\[Pi]\)\)\/2\)\)\ \ \), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(ln\ \
4\  - \ \[ImaginaryI]  \[Pi]\/2\)\)\)}]],
  "  \n\t\tbut\n\t\t\t",
  Cell[BoxData[{
      \(\ Log \((z\_1)\) + 
          Log \((z\_2)\)\ \  = \ \ \((\ 
            Log[2] + \[ImaginaryI] \( 5\ \[Pi]\)\/6\ )\) + \((\ 
            Log[2] + \[ImaginaryI] \( 2\ \[Pi]\)\/3)\)\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \(\(=\)\(\ \ \)\(2 
             Log[2] + \[ImaginaryI] \((\(5\ \[Pi]\)\/6 + \(2\ \[Pi]\)\/3)\)\)\
\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \(\(=\)\(\ \ \)\(ln\ 4\ \  + \ \[ImaginaryI] \( 3\ \[Pi]\)\/2\)\)\
\)}]],
  "   \n\nSince  ",
  Cell[BoxData[
      \(ln\ 4\  - \ \[ImaginaryI]  \[Pi]\/2 \[NotEqual] 
        ln\ 4\ \  + \ \[ImaginaryI] \( 3\ \[Pi]\)\/2\)]],
  ",  this is a counterexample for which   ",
  Cell[BoxData[
      \(Log \((\(z\_1\) z\_2)\)\  \[NotEqual] \ 
        Log \((z\_1)\)\  + \ Log \((z\_2)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter  ",
  Cell[BoxData[
      \(z\_1 = \(\(-\@3\) + \[ImaginaryI]\ \ and\ \ z\_2 = \(-1\) + \
\[ImaginaryI]\ \@3\)\)]],
  "  and take their logarithms. "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, w];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_1\  = \ \(-\ \@3\)\  + \ \[ImaginaryI];\)\ \), "\n", 
    \(\(z\_2\  = \ \(-\ 1\)\  + \ \[ImaginaryI]\ \@3;\)\ \), "\n", 
    \(\(z\_3\  = \ Expand[z\_1\ z\_2];\)\ \), "\n", 
    \(\(w\_1\  = \ ComplexExpand[Log[z\_1]];\)\ \), "\n", 
    \(\(w\_2\  = \ ComplexExpand[Log[z\_2]];\)\ \), "\n", 
    \(\(w\_3\  = \ ComplexExpand[Log[z\_3]];\)\ \), "\n", 
    \(\(Print[\*"\"\<             \!\(z\_1\) = \>\"", z\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<             \!\(z\_2\) = \>\"", 
        z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<          \!\(z\_1\) \!\(z\_2\) = \>\"", 
        z\_3];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<        Log[\!\(z\_1\)] = \>\"", w\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<        Log[\!\(z\_2\)] = \>\"", w\_2];\)\ \), "\n", 
    \(\(Print[\*"\"\<     Log[\!\(z\_1\) \!\(z\_2\)] = \>\"", 
        w\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<Log[\!\(z\_1\)]+Log[\!\(z\_2\)] = \>\"", 
        w\_1 + w\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[w\_1 + w\_2, "\< =? \>", w\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<  Is Log[\!\(z\_1\) \!\(z\_2\)] = Log[\!\(z\_1\)] + Log[\
\!\(z\_2\)] = ?  \>\"", 
        w\_3\  \[Equal] w\_1 + w\_2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "So we find in this counter example that it is possible for  ",
  Cell[BoxData[
      \(Log[\(z\_1\) z\_2] \[NotEqual] \ Log[z\_1] + Log[z\_2]\)]],
  ",\nthis is in contrast to the multivalued logarithm for which  ",
  Cell[BoxData[
      \(log \((z\_1\ z\_2)\) = log \((z\_1)\) + log \((z\_2)\)\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\tOur next result explains why the identity  ",
  Cell[BoxData[
      \(Log \((\(z\_1\) z\_2)\)\  = \ 
        Log \((z\_1)\)\  + \ Log \((z\_2)\)\)]],
  "  did not hold for the particular numbers we chose."
}], "Text"],

Cell[TextData[{
  StyleBox["\nTheorem 5.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The identity  ",
  Cell[BoxData[
      \(Log \((\(z\_1\) z\_2)\)\  = \ Log \((z\_1)\)\  + \ Log \((z\_2)\)\)],
    Evaluatable->False,
    AspectRatioFixed->True],
  "  holds true if and only if  ",
  Cell[BoxData[
      \(\(-\[Pi]\) < Arg \((z\_1)\) + Arg \((z\_2)\) \[LessEqual] \[Pi]\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof of Theorem 5.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Suppose first that  ",
  Cell[BoxData[
      \(\(-\[Pi]\) < Arg \((z\_1)\) + Arg \((z\_2)\) \[LessEqual] \[Pi]\)]],
  ".   By definition,  ",
  Cell[BoxData[
      \(Log \((\(z\_1\) z\_2)\)\  = \ \(ln | \(z\_1\) 
              z\_2 | \(+\ \[ImaginaryI]\)\ Arg \((\(z\_1\) 
                  z\_2)\)\  = \ \ ln | z\_1 | \(+ln\) | 
            z\_2 | \(+\ \[ImaginaryI]\)\ Arg \((\(z\_1\) z\_2)\)\)\)]],
  ".   As  ",
  Cell[BoxData[
      \(\(-\[Pi]\) < Arg \((z\_1)\) + Arg \((z\_2)\) \[LessEqual] \[Pi]\)]],
  ",  it follows that  ",
  Cell[BoxData[
      \(Arg \((\(z\_1\) z\_2)\) = Arg \((z\_1)\) + Arg \((z\_2)\)\)]],
  "  (explain!),  and so  ",
  Cell[BoxData[
      \(Log \((\(z\_1\) z\_2)\)\ \  = \ \ \(ln | z\_1 | \(+\ ln\) | 
            z\_2 | \ \(+\ \ \[ImaginaryI]\)\ Arg \((z\_1)\) + \ \ \
\[ImaginaryI]\ Arg \((z\_2)\)\  = \ \(Log \((\(z\_1\) z\_2)\)\  = \ 
            Log \((z\_1)\)\  + \ Log \((z\_2)\)\)\)\)]],
  ".  The \"only if\" part is left as an exercise."
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\tAs Example 5.5 and Theorem 5.2 illustrate, properties of the complex \
logarithm don't carry over when arguments of products combine in such a way \
that they drop down to ",
  Cell[BoxData[
      \(\(-\[Pi]\)\)]],
  " or rise above ",
  Cell[BoxData[
      \(\(-\[Pi]\)\)]],
  ". This is because of the restrictions placed on the domain of the function \
",
  Cell[BoxData[
      \(Arg \((z)\)\)]],
  ".  From the set of numbers associated with the multivalued logarithm, \
however, we can formulate properties that look exactly the same as those \
corresponding with the real logarithm."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 5.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  Cell[BoxData[
      \(z\_1\ and\ z\_2\)]],
  " be nonzero complex numbers. The multivalued function ",
  Cell[BoxData[
      \(log \((z)\)\)]],
  " obeys the familiar properties of logarithms: \n\n",
  StyleBox["(5-17)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(log \((z\_1\ z\_2)\) = log \((z\_1)\) + log \((z\_2)\)\)]],
  ",  \n\n",
  StyleBox["(5-18)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(log \((z\_1\/\(\(\ \)\(z\_2\)\))\) = 
        log \((z\_1)\) - log \((z\_2)\)\)]],
  ", and\n\n",
  StyleBox["(5-19)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(log \((1\/\(\(\ \)\(z\)\))\) = \(-log\) \((z)\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof of Theorem 5.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Identity ",
  StyleBox["(5-17)",
    FontColor->RGBColor[0, 0, 1]],
  " is easy to establish:  Using Identity  ",
  StyleBox["(1-38)",
    FontColor->RGBColor[0, 0, 1]],
  " in Section 1.4 concerning the argument of a product (and keeping in mind \
we are dealing with sets of numbers), we write  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(log \((z\_1\ z\_2)\)\  = \ 
          ln | z\_1 || 
              z\_2 | \ \ \(+\ \ \[ImaginaryI]\)\ arg \((z\_1\ z\_2)\)\), 
        "\[IndentingNewLine]"}], "\n", 
      RowBox[{
        "\t              ", \(\(=\)\(\ \)\(ln | z\_1 | \(+ln\) | 
            z\_2 | \ \ \(+\ \ \[ImaginaryI]\)\ arg \((z\_1)\) + \[ImaginaryI]\
\ arg \((z\_2)\)\)\), "\n"}], "\[IndentingNewLine]", 
      RowBox[{"\t              ", 
        RowBox[{"=", " ", 
          RowBox[{
            RowBox[{
              StyleBox["(",
                FontSize->16], \(ln | 
                z\_1 | \(+\[ImaginaryI]\)\ arg \((z\_1)\)\), 
              StyleBox[")",
                FontSize->16]}], "+", " ", 
            RowBox[{
              StyleBox["(",
                FontSize->16], \(ln | 
                z\_2 | \(+\[ImaginaryI]\)\ arg \((z\_2)\)\), 
              StyleBox[")",
                FontSize->16]}]}]}], "\[IndentingNewLine]"}], "\n", 
      RowBox[{
        "                       ", \(\(=\)\(\ \)\(log \((z\_1)\)\  + \ 
            log \((z\_2)\)\)\)}]}]],
  "   \n\nIdentities ",
  StyleBox["(5-18)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(5-19)",
    FontColor->RGBColor[0, 0, 1]],
  " are left as exercises."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Property of  Log(z).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  We know that ",
  Cell[BoxData[
      \(log \((z\_1\ z\_2)\) = log \((z\_1)\) + log \((z\_2)\)\)]],
  ", what about ",
  StyleBox["Log(z)",
    FontFamily->"Courier New"],
  "?"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Demonstration of Property of  Log(z).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Since the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function  Log[z]  is the principal value of the logarithm, we will \
investigate the relationship for  ",
  Cell[BoxData[
      \(Log[z\_1\ z\_2]\ \ and\ \ Log[z\_1] + Log[z\_2]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[v, x, y, z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_1 = x\_1 + \[ImaginaryI]\ y\_1;\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_2 = x\_2 + \[ImaginaryI]\ y\_2;\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_3 = 
        ComplexExpand[\((x\_1 + \[ImaginaryI]\ y\_1)\) \((x\_2 + \
\[ImaginaryI]\ y\_2)\)];\)\ \), "\[IndentingNewLine]", 
    \(\(v\_1\  = \ 
        ComplexExpand[
          Log[\((x\_1 + \[ImaginaryI]\ y\_1)\)], \n\ \ \ \ \ \ \ \
TargetFunctions \[Rule] {Im, Re}];\)\ \), "\n", 
    \(\(v\_2\  = \ 
        ComplexExpand[
          Log[\((x\_2 + \[ImaginaryI]\ y\_2)\)], \n\ \ \ \ \ \ \ \
TargetFunctions \[Rule] {Im, Re}];\)\ \), "\n", 
    \(\(v\_3\  = \ 
        ComplexExpand[
          Log[\((x\_1 + \[ImaginaryI]\ y\_1)\) \((x\_2 + \[ImaginaryI]\ y\_2)\
\)], \n\ \ \ \ \ \ \ TargetFunctions \[Rule] {Im, 
              Re}];\)\ \), "\[IndentingNewLine]", 
    \(\(U = 
        ComplexExpand[
          Log[Abs[\((x\_1 + \[ImaginaryI]\ y\_1)\) \((x\_2 + \[ImaginaryI]\ y\
\_2)\)]], \n\ \ \ \ \ \ \ TargetFunctions \[Rule] {Im, 
              Re}];\)\ \), "\[IndentingNewLine]", 
    \(\(V = 
        ComplexExpand[
          Arg[\((x\_1 + \[ImaginaryI]\ y\_1)\) \((x\_2 + \[ImaginaryI]\ y\_2)\
\)], \n\ \ \ \ \ \ \ TargetFunctions \[Rule] {Im, 
              Re}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", 
        Z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Log[\!\(z\_1\)] = \>\"", v\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<Log[\!\(z\_2\)] = \>\"", 
        v\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) \!\(z\_2\) = \>\"", 
        Z\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Log[Abs[\!\(z\_1\) \!\(z\_2\)]] = \>\"", 
        U];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Arg[\!\(z\_1\) \!\(z\_2\)] = \>\"", 
        V];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Log[\!\(z\_1\) \!\(z\_2\)] = \>\"", 
        v\_3];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The above formulas are for  Log[z]  and not  log(z).  What do you think \
about those pesky ArcTan's ? They are functions of two variables and evaluate \
properly throughout the complex plane to find  Arg[z].\n\n\t",
  Cell[BoxData[{
      \(Arg[\(-1\)]\ \ \ \ \ \ \ \  = \ \(ArcTan[\(-1\), 
            0]\ \ \ \  = \ \[Pi]\)\), "\n", 
      \(Arg[\(-1\) + \[ImaginaryI]]\  = \ \(ArcTan[\(-1\), 
            1]\ \ \ \  = \ \(3  \[Pi]\)\/4\)\), "\n", 
      \(Arg[\[ImaginaryI]]\ \ \ \ \ \ \ \ \ \  = \ \(ArcTan[0, 
            1]\ \ \ \ \ \ \  = \ \[Pi]\/2\)\), "\n", 
      \(Arg[
          1 + \[ImaginaryI]]\ \ \  = \ \(ArcTan[1, 
            1]\ \ \ \ \ \ \  = \ \[Pi]\/4\)\), "\n", 
      \(Arg[1]\ \ \ \ \ \ \ \ \ \  = \ \(ArcTan[1, 0]\ \ \ \ \ \ \  = \ 0\)\),
     "\n", 
      \(Arg[
          1 - \[ImaginaryI]]\ \ \  = \ \(ArcTan[
            1, \(-1\)]\ \ \ \  = \ \(-\[Pi]\)\/4\)\), "\n", 
      \(Arg[\(-\[ImaginaryI]\)]\ \ \ \ \ \ \  = \ \(ArcTan[
            0, \(-1\)]\ \ \ \  = \ \(-\[Pi]\)\/2\)\), "\n", 
      \(Arg[\(-1\) - \[ImaginaryI]]\  = \ \(ArcTan[\(-1\), \(-1\)]\  = \ \
\(\(-3\) \[Pi]\)\/4\)\)}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tWe can construct many different branches of the multivalued logarithm \
function that are continuous and differentiable except at points along any \
preassigned ray  ",
  Cell[BoxData[
      \({r\ \(\(\[ExponentialE]\^\[ImaginaryI]\[Alpha]\) : \ r > 0\)}\)]],
  ".  If we let ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  " denote a real fixed number and choose the value of  ",
  Cell[BoxData[
      \(\[Theta] \[Element] arg \((z)\)\)]],
  ",  that lies in the range  ",
  Cell[BoxData[
      \(\[Alpha] < \[Theta] \[LessEqual] \[Alpha] + 2  \[Pi]\)]],
  ",  then the function  ",
  Cell[BoxData[
      \(\(log\_\[Alpha]\) \((z)\)\)]],
  "  defined by  \n\n\t\t\t",
  Cell[BoxData[
      \(\(log\_\[Alpha]\) \((z)\)\ \  = \ \ ln\ r\ \  + \ \[ImaginaryI]\ \
\[Theta]\)]],
  "\n\nwhere  ",
  Cell[BoxData[
      \(z = r\ \[ExponentialE]\^\[ImaginaryI]\[Theta] \[NotEqual] 0\)]],
  ",  and  ",
  Cell[BoxData[
      \(\[Alpha] < \[Theta] \[LessEqual] \[Alpha] + 2  \[Pi]\)]],
  ",  is a single-valued branch of the logarithm function. The branch cut for \
 ",
  Cell[BoxData[
      \(\(log\_\[Alpha]\) \((z)\)\)]],
  "  is the ray  ",
  Cell[BoxData[
      \({r\ \(\(\[ExponentialE]\^\[ImaginaryI]\[Alpha]\) : \ r > 0\)}\)]],
  ",  and each point along this ray is a point of discontinuity of ",
  Cell[BoxData[
      \(\(log\_\[Alpha]\) \((z)\)\)]],
  ".  Because  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"exp", 
          RowBox[{
            StyleBox["(",
              FontSize->16], \(\(log\_\[Alpha]\) \((z)\)\), 
            StyleBox[")",
              FontSize->16]}]}], " ", "=", " ", "z"}]]],
  ",  we conclude that the mapping  ",
  Cell[BoxData[
      \(w = \(log\_\[Alpha]\) \((z)\)\)]],
  "  is a one-to-one mapping of the domain ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(0\)\)\)\)]],
  " onto the horizontal strip  ",
  Cell[BoxData[
      \({w : \ \ \[Alpha] < Im \((w)\) \[LessEqual] \[Alpha] + 2  \[Pi]}\)]],
  ".  If  ",
  Cell[BoxData[
      \(\(\(\ \)\(\[Alpha] < c < d < \[Alpha] + 2  \[Pi]\)\)\)]],
  ",  then the function  ",
  Cell[BoxData[
      \(w = \(log\_\[Alpha]\) \((z)\)\)]],
  "  maps the set  ",
  Cell[BoxData[
      RowBox[{"D", "=", 
        RowBox[{"{", 
          
          RowBox[{\(r\ \(\(\[ExponentialE]\^\[ImaginaryI]\[Alpha]\) : \ 
                0 < a < r < b\)\), ",", "  ", 
            RowBox[{
              RowBox[{
                StyleBox["and",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "  ", "c"}], "<", "\[Theta]", "<",
               "d"}]}], "}"}]}]]],
  "  one-to-one and onto the rectangle  ",
  Cell[BoxData[
      RowBox[{"R", "=", 
        RowBox[{"{", 
          
          RowBox[{\(u\  + \[ImaginaryI]\ \(v : \ ln\ a < u < ln\ b\)\), ",", 
            "  ", 
            RowBox[{
              RowBox[{
                StyleBox["and",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "  ", "c"}], "<", "v", "<", 
              "d"}]}], "}"}]}]]],
  ".  Figure 5.4 shows the mapping ",
  Cell[BoxData[
      \(w = \(log\_\[Alpha]\) \((z)\)\)]],
  ", its branch cut ",
  Cell[BoxData[
      \({r\ \(\(\[ExponentialE]\^\[ImaginaryI]\[Alpha]\) : \ r > 0\)}\)]],
  ", the set ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", and its image ",
  StyleBox["R",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.493933 0.134321 0.493933 0.134321 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.941 1 .941 r
.02381 .02381 m
.96406 .02381 L
.96406 .96406 L
.02381 .96406 L
.02381 .02381 L
F
.49393 .49393 m
.49393 .49393 .44596 0 365.73 arc
F
.8 1 .8 r
.49393 .49393 m
.49393 .49393 .33038 135 315 arc
F
.941 1 .941 r
.49393 .49393 m
.49393 .49393 .07372 0 365.73 arc
F
1 1 1 r
.49393 .49393 m
.49393 .49393 .00672 0 365.73 arc
F
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.44181 .44181 m
.26032 .26032 L
s
0 0 0 r
.48722 .49393 m
.02511 .49393 L
s
.49393 .50468 m
.49393 .96276 L
s
.50468 .49393 m
.96276 .49393 L
s
.49393 .48722 m
.49393 .02511 L
s
0 0 1 r
.012 w
.54606 .44181 m
.72754 .26032 L
s
1 0 1 r
.44181 .54606 m
.26032 .72754 L
s
1 .5 0 r
.0012 w
newpath
.49393 .49393 .07372 0 365.73 arc
s
.5 .165 .165 r
newpath
.49393 .49393 .33038 0 365.73 arc
s
0 1 0 r
newpath
.49393 .49393 .41639 0 43.2811 arc
s
1 .5 0 r
.012 w
newpath
.49393 .49393 .07372 135 315 arc
s
.5 .165 .165 r
newpath
.49393 .49393 .33038 135 315 arc
s
0 1 0 r
.5 Mabswid
.50343 .49393 m
.96912 .95962 L
s
[ .025 .025 ] 0 setdash
.49393 .50343 m
.95962 .96912 L
s
0 g
[ ] 0 setdash
.94933 .49393 m
.97619 .49393 L
s
% Start of user PostScript
3.39034 0 3.59034 0 MAarrowhead1
% End of user PostScript
.49393 .94933 m
.49393 .97619 L
s
% Start of user PostScript
0 3.39034 0 3.59034 MAarrowhead1
% End of user PostScript
gsave
.88346 .70885 -66.5938 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.96276 .52751 -66 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51408 .96276 -69 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 0 r
.0012 w
newpath
.49393 .49393 .00672 135 315 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{280, 280},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H000162000`400?l00000o`00003oo`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`001P3ooon30?3ol0030000003`oo00l?o`0800l?o`
303oool000H0ooooP`3`oo000`000000l?o`0?3ol0200?3ol0`0oooo00060?oooh<0l?o`00<00000
0?3ol03`oo00P03`oo0<0?ooo`001P3ooon30?3ol0030000003`oo00l?o`0800l?o`303oool000H0
ooooP`3`oo000`000000l?o`0?3ol0200?3ol0`0oooo00060?oooh<0l?o`00<000000?3ol03`oo00
P03`oo0<0?ooo`001P3ooon30?3ol0030000003`oo00l?o`0800l?o`303oool000H0ooooP`3`oo00
0`000000l?o`0?3ol0200?3ol0`0oooo00060?oooh<0l?o`00<000000?3ol03`oo00P03`oo0<0?oo
o`001P3ooon30?3ol0030000003`oo00l?o`0800l?o`303oool000H0ooooP`3`oo000`000000l?o`
0?3ol0200?3ol0`0oooo00060?oooh<0l?o`00<000000?3ol03`oo00P03`oo0<0?ooo`001P3ooon3
0?3ol0030000003`oo00l?o`0800l?o`303oool000H0ooooP`3`oo000`000000l?o`0?3ol0200?3o
l0`0oooo00060?oooh<0l?o`00<000000?3ol03`oo00P03`oo0<0?ooo`001P3ooon30?3ol0030000
003`oo00l?o`0800l?o`303oool000H0ooooP`3`oo000`000000l?o`0?3ol0200?3ol0`0oooo0006
0?oooh<0l?o`00<000000?3ol03`oo00P03`oo0<0?ooo`001P3ooon30?3ol0030000003`oo00l?o`
0800l?o`303oool000H0ooooP`3`oo000`000000l?o`0?3ol0200?3ol0`0oooo00060?oooh<0l?o`
00<000000?3ol03`oo00P03`oo0<0?ooo`001P3ooon30?3ol0030000003`oo00l?o`0800l?o`303o
ool000H0ooooP`3`oo000`000000l?o`0?3ol0200?3ol0`0oooo00060?oooh<0l?o`00<000000?3o
l03`oo00P03`oo0<0?ooo`001P3ooon30?3ol0030000003`oo00l?o`0800l?o`303oool000H0oooo
P`3`oo000`000000l?o`0?3ol0200?3ol0`0oooo00060?oooh<0l?o`00<000000?3ol03`oo00P03`
oo0<0?ooo`001P3ooon30?3ol0030000003`oo00l?o`0800l?o`303oool000H0ooooP`3`oo000`00
0000l?o`0?3ol0200?3ol0`0oooo00060?oooh<0l?o`00<000000?3ol03`oo00P03`oo0<0?ooo`00
1P3ooon30?3ol0030000003`oo00l?o`0800l?o`303oool000H0ooooP`3`oo000`000000l?o`0?3o
l0200?3ol0`0oooo00060?oooh<0l?o`00<000000?3ol03`oo00P03`oo0<0?ooo`001P3ooon30?3o
l0030000003`oo00l?o`0800l?o`303oool000H0ooooP`3`oo000`000000l?o`0?3ol0200?3ol0`0
oooo00060?oooh<0l?o`00<000000?3ol03`oo00P03`oo0<0?ooo`001P3ooon30?3ol0030000003`
oo00l?o`0800l?o`303oool000H0ooooN`3`oo0A07lZ:WX0l?o`303oool000H0ooooLP3`oo0S07lZ
:W40l?o`303oool000H0ooooKP3`oo0/07lZ:V`0l?o`303oool000H0ooooJP3`oo0B07lZ:PL0c?o<
00<000000<coc03<ol`01@3<ol`C07lZ:VP0l?o`303oool000H0ooooI`3`oo0<07lZ:Q00c?o<00<0
00000<coc03<ol`03P3<ol`<07lZ:VH0l?o`303oool000H0ooooI@3`oo0:07lZ:Q@0c?o<00<00000
0<coc03<ol`04`3<ol`907lZ:V@0l?o`303oool000H0ooooH@3`oo0:07lZ:QP0c?o<00<000000<co
c03<ol`05`3<ol`907lZ:V00l?o`303oool000H0ooooG`3`oo0907lZ:Q/0c?o<00<000000<coc03<
ol`06@3<ol`:07lZ:Ud0l?o`303oool000H0ooooG@3`oo0907lZ:Qd0c?o<00<000000<coc03<ol`0
6`3<ol`:07lZ:U/0l?o`303oool000H0ooooF`3`oo0707lZ:R40c?o<00<000000<coc03<ol`07`3<
ol`807lZ:UT0l?o`303oool000H0ooooF@3`oo0707lZ:R<0c?o<00<000000<coc03<ol`08P3<ol`7
07lZ:UL0l?o`303oool000H0ooooE`3`oo0707lZ:RD0c?o<00<000000<coc03<ol`0903<ol`707lZ
:UD0l?o`303oool000H0ooooE@3`oo0707lZ:RL0c?o<00<000000<coc03<ol`09P3<ol`707lZ:U<0
l?o`303oool000H0ooooD`3`oo0707lZ:RT0c?o<00<000000<coc03<ol`0:03<ol`707lZ:U40l?o`
303oool000H0ooooD@3`oo0707lZ:R/0c?o<00<000000<coc03<ol`0:P3<ol`607lZ:U00l?o`303o
ool000H0ooooD03`oo0607lZ:Rd0c?o<00<000000<coc03<ol`0;03<ol`507lZ:Tl0l?o`303oool0
00H0ooooC`3`oo0507lZ:Rl0c?o<00<000000<coc03<ol`0;P3<ol`407lZ:Th0l?o`303oool000H0
ooooC@3`oo0507lZ:S40c?o<00<000000<coc03<ol`0;`3<ol`507lZ:T`0l?o`303oool000H0oooo
B`3`oo0607lZ:S80c?o<00<000000<coc03<ol`0<03<ol`507lZ:T/0l?o`303oool000H0ooooB`3`
oo0507lZ:S<0c?o<00<000000<coc03<ol`0<@3<ol`507lZ:TX0l?o`303oool000H0ooooBP3`oo04
07lZ:SD0c?o<00<000000<coc03<ol`0<`3<ol`507lZ:TP0l?o`303oool000H0ooooB03`oo0507lZ
:SH0c?o<00<000000<coc03<ol`0=03<ol`507lZ:TL0l?o`303oool000H0ooooA`3`oo0607lZ:SH0
c?o<00<000000<coc03<ol`0=@3<ol`507lZ:TH0l?o`303oool000H0ooooAP3`oo0507lZ:SP0c?o<
00<000000<coc03<ol`0=`3<ol`407lZ:TD0l?o`303oool000H0ooooA03`oo0507lZ:SX0c?o<00<0
00000<coc03<ol`0>03<ol`407lZ:T@0l?o`303oool000H0ooooA03`oo0407lZ:S/0c?o<00<00000
0<coc03<ol`0>@3<ol`407lZ:T<0l?o`303oool000H0oooo@`3`oo0407lZ:S`0c?o<00<000000<co
c03<ol`0>P3<ol`407lZ:T80l?o`303oool000H0oooo@@3`oo0507lZ:Sd0c?o<00<000000<coc03<
ol`0>`3<ol`407lZ:P030000o`3`oo00l?o`03h0l?o`303oool000H0oooo@@3`oo0507lZ:Sd0c?o<
00<000000<coc03<ol`0?03<ol`407lZ:P030000o`3`oo00l?o`03d0l?o`303oool000H0oooo@03`
oo0407lZ:Sl0c?o<00<000000<coc03<ol`0?03<ol`010000?l0ObXZ07lZ:P1o:RY00?3ol0`0oooo
00060?oooch0l?o`1@1o:RX00`3<ol`0o`000<coc00m0<coc0030000003<ol`0c?o<03/0c?o<0`00
0?l00`1o:RX0l?o`07lZ:P0o0?3ol0`0oooo00060?oooch0l?o`1@1o:RX20<coc0030?l0003<ol`0
c?o<03/0c?o<00<000000<coc03<ol`0>P3<ol`40000o`<0l?o`00<0ObXZ0?3ol03`oo00?03`oo0<
0?ooo`001P3ooolm0?3ol0@0ObXZ1@3<ol`00`3o0000c?o<0<coc00j0<coc0030000003<ol`0c?o<
03T0c?o<10000?l50?3ol00307lZ:P3`oo00l?o`03/0l?o`303oool000H0oooo?03`oo0407lZ:PL0
c?o<00<0o`000<coc03<ol`0>@3<ol`00`000000c?o<0<coc00h0<coc0@0003o1`3`oo000`1o:RX0
l?o`0?3ol00j0?3ol0`0oooo00060?oooc/0l?o`101o:RX90<coc0030?l0003<ol`0c?o<03P0c?o<
00<000000<coc03<ol`0=`3<ol`40000o`T0l?o`00<0ObXZ0?3ol03`oo00>@3`oo0<0?ooo`001P3o
oolk0?3ol0<0ObXZ2`3<ol`00`3o0000c?o<0<coc00g0<coc0030000003<ol`0c?o<03H0c?o<1000
0?l:0?3ol00307lZ:P3`oo00l?o`03T0l?o`303oool000H0oooo>P3`oo0407lZ:P`0c?o<00<0o`00
0<coc03<ol`0=P3<ol`00`000000c?o<0<coc00e0<coc0@0003o303`oo000`1o:RX0l?o`0?3ol00h
0?3ol0`0oooo00060?ooocP0l?o`1@1o:RX>0<coc0030?l0003<ol`0c?o<03D0c?o<00<000000<co
c03<ol`0=03<ol`40000o`h0l?o`00<0ObXZ0?3ol03`oo00=`3`oo0<0?ooo`001P3ooolh0?3ol0D0
ObXZ3`3<ol`00`3o0000c?o<0<coc00d0<coc0030000003<ol`0c?o<03<0c?o<10000?l@0?3ol003
07lZ:P3`oo00l?o`03H0l?o`303oool000H0oooo=`3`oo0407lZ:Q80c?o<00<0o`000<coc03<ol`0
<`3<ol`00`000000c?o<0<coc00b0<coc0@0003o4@3`oo000`1o:RX0l?o`0?3ol00f0?3ol0`0oooo
00060?ooocL0l?o`0`1o:RXD0<coc0030?l0003<ol`0c?o<0380c?o<00<000000<coc03<ol`0<@3<
ol`40000oa<0l?o`00<0ObXZ0?3ol03`oo00=@3`oo0<0?ooo`001P3ooolf0?3ol0@0ObXZ5@3<ol`0
0`3o0000c?o<0<coc00a0<coc0030000003<ol`0c?o<0300c?o<10000?lE0?3ol00307lZ:P3`oo00
l?o`03@0l?o`303oool000H0oooo=@3`oo0407lZ:QL0c?o<00<0o`000<coc03<ol`0<03<ol`00`00
0000c?o<0<coc00_0<coc0@0003o5`3`oo000`1o:RX0l?o`0?3ol00c0?3ol0`0oooo00060?oooc@0
l?o`101o:RXI0<coc0030?l0003<ol`0c?o<02l0c?o<00<000000<coc03<ol`0;P3<ol`40000oaT0
l?o`00<0ObXZ0?3ol03`oo00<P3`oo0<0?ooo`001P3ooold0?3ol0<0ObXZ6`3<ol`00`3o0000c?o<
0<coc00^0<coc0030000003<ol`0c?o<02d0c?o<10000?lJ0?3ol00307lZ:P3`oo00l?o`0380l?o`
303oool000H0oooo<`3`oo0407lZ:Q`0c?o<00<0o`000<coc03<ol`0;@3<ol`00`000000c?o<0<co
c00/0<coc0@0003o703`oo000`1o:RX0l?o`0?3ol00a0?3ol0`0oooo00060?oooc<0l?o`0`1o:RXN
0<coc0030?l0003<ol`0c?o<02`0c?o<00<000000<coc03<ol`0:`3<ol`40000oad0l?o`00<0ObXZ
0?3ol03`oo00<@3`oo0<0?ooo`001P3ooolb0?3ol0@0ObXZ7`3<ol`00`3o0000c?o<0<coc00[0<co
c0030000003<ol`0c?o<02X0c?o<10000?lO0?3ol00307lZ:P3`oo00l?o`0300l?o`303oool000H0
oooo<P3`oo0307lZ:R40c?o<00<0o`000<coc03<ol`0:P3<ol`00`000000c?o<0<coc00Y0<coc0@0
003o803`oo000`1o:RX0l?o`0?3ol00`0?3ol0`0oooo00060?oooc40l?o`101o:RXR0<coc0030?l0
003<ol`0c?o<02T0c?o<00<000000<coc03<ol`0:03<ol`40000ob80l?o`00<0ObXZ0?3ol03`oo00
;`3`oo0<0?ooo`001P3ooola0?3ol0<0ObXZ903<ol`00`3o0000c?o<0<coc00X0<coc0030000003<
ol`0c?o<02L0c?o<10000?lS0?3ol00307lZ:P3`oo00l?o`02l0l?o`303oool000H0oooo<03`oo04
07lZ:RD0c?o<00<0o`000<coc03<ol`09`3<ol`00`000000c?o<0<coc00V0<coc0@0003o9@3`oo00
0`1o:RX0l?o`0?3ol00^0?3ol0`0oooo00060?oooc00l?o`0`1o:RXW0<coc0030?l0003<ol`0c?o<
02H0c?o<00<000000<coc03<ol`09@3<ol`40000obH0l?o`00<0ObXZ0?3ol03`oo00;P3`oo0<0?oo
o`001P3oool_0?3ol0@0ObXZ:03<ol`00`3o0000c?o<0<coc00U0<coc0030000003<ol`0c?o<02@0
c?o<10000?lX0?3ol00307lZ:P3`oo00l?o`02d0l?o`303oool000H0oooo;`3`oo0307lZ:RX0c?o<
00<0o`000<coc03<ol`0903<ol`00`000000c?o<0<coc00S0<coc0@0003o:@3`oo000`1o:RX0l?o`
0?3ol00]0?3ol0`0oooo00060?ooobh0l?o`101o:RX[0<coc0030?l0003<ol`0c?o<02<0c?o<00<0
00000<coc03<ol`08P3<ol`40000ob/0l?o`00<0ObXZ0?3ol03`oo00;03`oo0<0?ooo`001P3oool^
0?3ol0<0ObXZ;@3<ol`00`3o0000c?o<0<coc00R0<coc0030000003<ol`0c?o<0240c?o<10000?l/
0?3ol00307lZ:P3`oo00l?o`02`0l?o`303oool000H0oooo;@3`oo0407lZ:Rh0c?o<00<0o`000<co
c03<ol`08@3<ol`00`000000c?o<0<coc00P0<coc0@0003o;P3`oo000`1o:RX0l?o`0?3ol00[0?3o
l0`0oooo00060?ooobd0l?o`0`1o:RX`0<coc0030?l0003<ol`0c?o<0200c?o<00<000000<coc03<
ol`07`3<ol`40000obl0l?o`00<0ObXZ0?3ol03`oo00:`3`oo0<0?ooo`001P3oool/0?3ol0@0ObXZ
<@3<ol`00`3o0000c?o<0<coc00O0<coc0030000003<ol`0c?o<01h0c?o<10000?l`0?3ol00307lZ
:P3`oo00l?o`02/0l?o`303oool000H0oooo;03`oo0307lZ:S<0c?o<00<0o`000<coc03<ol`07P3<
ol`00`000000c?o<0<coc00M0<coc0@0003o<P3`oo000`1o:RX0l?o`0?3ol00Z0?3ol0`0oooo0006
0?ooob`0l?o`0`1o:RXd0<coc0030?l0003<ol`0c?o<01d0c?o<00<000000<coc03<ol`0703<ol`4
0000oc<0l?o`00<0ObXZ0?3ol03`oo00:P3`oo0<0?ooo`001P3oool/0?3ol0<0ObXZ=@3<ol`00`3o
0000c?o<0<coc00L0<coc0030000003<ol`0c?o<01/0c?o<10000?le0?3ol00307lZ:P3`oo00l?o`
02T0l?o`303oool000H0oooo:`3`oo0407lZ:SH0c?o<00<0o`000<coc03<ol`06`3<ol`00`000000
c?o<0<coc00J0<coc0@0003o=P3`oo000`1o:RX0l?o`0?3ol00Y0?3ol0`0oooo00060?ooob/0l?o`
0`1o:RXh0<coc0030?l0003<ol`0c?o<01X0c?o<00<000000<coc03<ol`06@3<ol`40000ocP0l?o`
00<0ObXZ0?3ol03`oo00:03`oo0<0?ooo`001P3ooolZ0?3ol0@0ObXZ>@3<ol`00`3o0000c?o<0<co
c00I0<coc0030000003<ol`0c?o<01P0c?o<10000?li0?3ol00307lZ:P3`oo00l?o`02P0l?o`303o
ool000H0oooo:P3`oo0307lZ:S/0c?o<00<0o`000<coc03<ol`0603<ol`00`000000c?o<0<coc00G
0<coc0@0003o>P3`oo000`1o:RX0l?o`0?3ol00X0?3ol0`0oooo00060?ooobX0l?o`0`1o:RXl0<co
c0030?l0003<ol`0c?o<01L0c?o<00<000000<coc03<ol`05P3<ol`40000oc/0l?o`00<0ObXZ0?3o
l03`oo00:03`oo0<0?ooo`001P3ooolY0?3ol0@0ObXZ?@3<ol`00`3o0000c?o<0<coc00F0<coc003
0000003<ol`0c?o<01D0c?o<10000?lm0?3ol00307lZ:P3`oo00l?o`02L0l?o`303oool000H0oooo
:@3`oo0307lZ:Sl0c?o<00<0o`000<coc03<ol`05@3<ol`00`000000c?o<0<coc00D0<coc0@0003o
?P3`oo000`1o:RX0l?o`0?3ol00W0?3ol0`0oooo00060?ooobT0l?o`0`1o:RY00<coc0030?l0003<
ol`0c?o<01@0c?o<00<000000<coc03<ol`04`3<ol`40000od00l?o`00<0ObXZ0?3ol03`oo009P3`
oo0<0?ooo`001P3ooolY0?3ol0<0ObXZ@@3<ol`00`3o0000c?o<0<coc00C0<coc0030000003<ol`0
c?o<0180c?o<10000?m10?3ol00307lZ:P3`oo00l?o`02H0l?o`303oool000H0oooo:03`oo0407lZ
:T80c?o<00<0o`000<coc03<ol`03@3<ol`;0?mo00h0c?o<10000?m20?3ol00307lZ:P3`oo00l?o`
02H0l?o`303oool000H0oooo:03`oo0307lZ:T@0c?o<00<0o`000<coc03<ol`0203<ol`C0?mo00T0
c?o<10000?m30?3ol00307lZ:P3`oo00l?o`02H0l?o`303oool000H0oooo:03`oo0307lZ:TD0c?o<
00<0o`000<coc03<ol`01P3<ol`F0?mo00H0c?o<10000?m40?3ol00307lZ:P3`oo00l?o`02H0l?o`
303oool000H0oooo:03`oo0307lZ:TH0c?o<00<0o`000<coc03<ol`00`3<ol`80?mo00@0l?o`00<0
00000?3ol03`oo000P3`oo080?mo00@0c?o<10000?m60?3ol00307lZ:P3`oo00l?o`02D0l?o`303o
ool000H0oooo9`3`oo0407lZ:TL0c?o<00<0o`000<coc03<ol`01P3oO`080?3ol0030000003`oo00
l?o`00H0l?o`1@3oO`020<coc0@0003oA`3`oo000`1o:RX0l?o`0?3ol00U0?3ol0`0oooo00060?oo
obL0l?o`0`1o:RY90<coc0030?l0003<ol`0ogl000@0ogl02@3`oo000`000000l?o`0?3ol0080?3o
l0@0ogl010000?m80?3ol00307lZ:P3`oo00l?o`02D0l?o`303oool000H0oooo9`3`oo0307lZ:TX0
c?o<103oO`0;0?3ol0030000003`oo00l?o`00T0l?o`103oO`020000odT0l?o`00<0ObXZ0?3ol03`
oo009@3`oo0<0?ooo`001P3ooolW0?3ol0<0ObXZB03<ol`50?mo00`0l?o`00<000000?3ol03`oo00
2P3`oo040?mo04X0l?o`00<0ObXZ0?3ol03`oo009@3`oo0<0?ooo`001P3ooolW0?3ol0<0ObXZB03<
ol`50?mo00`0l?o`00<000000?3ol03`oo002`3`oo030?mo04X0l?o`00<0ObXZ0?3ol03`oo009@3`
oo0<0?ooo`001P3ooolW0?3ol0<0ObXZA`3<ol`40?mo00h0l?o`00<000000?3ol03`oo00303`oo02
0?mo04X0l?o`00<0ObXZ0?3ol03`oo009@3`oo0<0?ooo`001P3ooolW0?3ol0<0ObXZA`3<ol`30?mo
00l0l?o`00<000000?3ol03`oo003P3`oo000`3oO`00l?o`0?3ol0180?3ol00307lZ:P3`oo00l?o`
02@0l?o`303oool000H0oooo9`3`oo0307lZ:TH0c?o<103oO`0?0?3ol0030000003`oo00l?o`00l0
l?o`00<0ogl00?3ol03`oo00A`3`oo000`1o:RX0l?o`0?3ol00T0?3ol0`0oooo00060?ooobL0l?o`
0`1o:RY50<coc0@0ogl0403`oo000`000000l?o`0?3ol00?0?3ol0030?mo003`oo00l?o`04L0l?o`
00<0ObXZ0?3ol03`oo00903`oo0<0?ooo`001P3ooolV0?3ol0@0ObXZA@3<ol`30?mo0140l?o`00<0
00000?3ol03`oo00403`oo000`3oO`00l?o`0?3ol0160?3ol00307lZ:P3`oo00l?o`02@0l?o`303o
ool000H0oooo9P3`oo0307lZ:TH0c?o<0`3oO`0A0?3ol0030000003`oo00l?o`0100l?o`00<0ogl0
0?3ol03`oo00AP3`oo000`1o:RX0l?o`0?3ol00T0?3ol0`0oooo00060?ooobH0l?o`0`1o:RY60<co
c0<0ogl04@3`oo000`000000l?o`0?3ol00A0?3ol0030?mo003`oo00l?o`04D0l?o`00<0ObXZ0?3o
l03`oo00903`oo0<0?ooo`001P3ooolV0?3ol0<0ObXZA@3<ol`40?mo0140l?o`00<000000?3ol03`
oo004@3`oo000`3oO`00l?o`0?3ol0150?3ol00307lZ:P3`oo00l?o`02@0l?o`303oool000H0oooo
9P3`oo0307lZ:TD0c?o<0`3oO`0B0?3ol0030000003`oo00l?o`0140l?o`00<0ogl00?3ol03`oo00
A@3`oo000`1o:RX0l?o`0?3ol00T0?3ol0`0oooo00060?ooobH0l?o`0`1o:RY50<coc0<0ogl04P3`
oo000`000000l?o`0?3ol00A0?3ol0030?mo003`oo00l?o`04D0l?o`00<0ObXZ0?3ol03`oo00903`
oo0<0?ooo`001P3ooolV0?3ol0<0ObXZA@3<ol`30?mo0180l?o`00<00?l00?3ol03`oo004P3`oo00
0`3oO`00l?o`0?3ol0140?3ol00307lZ:P3`oo00l?o`0200l?o`0P0000020?3ol0`0oooo00060?oo
obH0l?o`0`1o:RY50<coc0<0ogl04@3`oo001000o`00oooo003o0000o`0B0?3ol0030?mo003`oo00
l?o`04@0l?o`00<0ObXZ0?3ol03`oo00803`oo06000000X0oooo00060?ooo`030?3ol00000000000
02<000000`1o:RY5000000<0ogl0400000001P00o`00oooo0?ooo`3oool0l?o`003o0140000000<0
ogl0000000000000A00000000`1o:RX000000000000E00000003003o000000000000014000001`3o
ool000H0oooo9P3`oo0307lZ:TD0c?o<0`3oO`0@0?3ol004003o003oool0oooo0?ooo`80l?o`00<0
0?l00?3ol03`oo003P3`oo000`3oO`00l?o`0?3ol0140?3ol00307lZ:P3`oo00l?o`01D0l?o`00<0
0?l00?3ol03`oo00203`oo07000000T0oooo00060?ooobH0l?o`0`1o:RY50<coc0<0ogl04@3`oo00
0`00o`00oooo0?ooo`030?3ol003003o003`oo00l?o`00d0l?o`00<0ogl00?3ol03`oo00A03`oo00
0`1o:RX0l?o`0?3ol00E0?3ol003003o003`oo00l?o`00P0l?o`0`0000000`3`oo00oooo0?ooo`0:
0?ooo`001P3ooolV0?3ol0<0ObXZA@3<ol`30?mo0180l?o`00<00?l00?3ol03`oo000`3`oo000`00
o`00l?o`0?3ol00;0?3ol0030?mo003`oo00l?o`04D0l?o`00<0ObXZ0?3ol03`oo005@3`oo000`00
o`00l?o`0?3ol00<0?3ol0`0oooo00060?ooobH0l?o`0`1o:RY50<coc0<0ogl04P3`oo000`000000
0?l00?3ol0040?3ol003003o003`oo00l?o`00X0l?o`00<0ogl00?3ol03`oo00A@3`oo000`1o:RX0
l?o`0?3ol00E0?3ol003003o003`oo00l?o`00`0l?o`303oool000H0oooo9P3`oo0307lZ:TD0c?o<
103oO`0A0?3ol0030000003`oo000?l000D0l?o`00<00?l00?3ol03`oo002@3`oo000`3oO`00l?o`
0?3ol0150?3ol00307lZ:P3`oo00l?o`01D0l?o`00<00?l00?3ol03`oo00303`oo0<0?ooo`001P3o
oolV0?3ol0<0ObXZAP3<ol`30?mo0140l?o`00@000000?3ol03`oo000?l01@3`oo000`00o`00l?o`
0?3ol0080?3ol0030?mo003`oo00l?o`04D0l?o`00<0ObXZ0?3ol03`oo005@3`oo000`00o`00l?o`
0?3ol00<0?3ol0`0oooo00060?ooobH0l?o`0`1o:RY60<coc0<0ogl04@3`oo001@000000l?o`0?3o
l03`oo000?l000D0l?o`00<00?l00?3ol03`oo001P3`oo000`3oO`00l?o`0?3ol0160?3ol00307lZ
:P3`oo00l?o`01D0l?o`00<00?l00?3ol03`oo002@3`oo02000000030?3ol0000000000000X0oooo
00060?ooobH0l?o`101o:RY50<coc0<0ogl04@3`oo000`000000l?o`0?3ol0020?3ol003003o003`
oo00l?o`00<0l?o`00<00?l00?3ol03`oo001@3`oo000`3oO`00l?o`0?3ol0160?3ol00307lZ:P3`
oo00l?o`01D0l?o`00<00?l00?3ol03`oo002P3`oo000`000000l?o`0000000;0?ooo`001P3ooolW
0?3ol0<0ObXZA@3<ol`40?mo0100l?o`00<000000?3ol03`oo002@3`oo000`00o`00l?o`0?3ol003
0?3ol0030?mo003`oo00l?o`04L0l?o`00<0ObXZ0?3ol03`oo005@3`oo000`00o`00l?o`0?3ol00;
0?3ol0030000003oool0oooo00X0oooo00060?ooobL0l?o`0`1o:RY60<coc0<0ogl0403`oo000`00
0000l?o`0?3ol00:0?3ol003003o003`oo00l?o`0080l?o`00<0ogl00?3ol03`oo00A`3`oo000`1o
:RX0l?o`0?3ol00E0?3ol003003o003`oo00l?o`00T0l?o`0P0000000`3`oo0000000000000:0?oo
o`001P3ooolW0?3ol0<0ObXZAP3<ol`40?mo00l0l?o`00<000000?3ol03`oo002`3`oo001000o`00
l?o`0?3ol03oO`1:0?3ol00307lZ:P3`oo00l?o`01D0l?o`00<00?l00?3ol03`oo00303`oo0<0?oo
o`001P3ooolW0?3ol0<0ObXZA`3<ol`30?mo00l0l?o`00<000000?3ol03`oo00303`oo000`00o`00
l?o`0?mo001:0?3ol00307lZ:P3`oo00l?o`01D0l?o`00<00?l00?3ol03`oo00303`oo0<0?ooo`00
1P3ooolW0?3ol0<0ObXZA`3<ol`40?mo00030?l0o`3`oo00l?o`00/0l?o`00<000000?3ol03`oo00
1`3`oo000`00o`00l?o`0?3ol0030?3ol003003o003`oo00l?o`04P0l?o`00<0ObXZ0?3ol03`oo00
5P3`oo000`00o`00l?o`0?3ol00<0?3ol0`0oooo00060?ooobL0l?o`0`1o:RY80<coc0@0ogl000<0
o`3o0?3ol03`oo002P3`oo000`000000l?o`0?3ol0080?3ol003003o003`oo00l?o`0080l?o`00<0
ogl0003o003`oo00B03`oo000`1o:RX0l?o`0?3ol00F0?3ol003003o003`oo00l?o`00`0l?o`303o
ool000H0oooo9`3`oo0307lZ:TT0c?o<103oO`0<0?3ol0030000003`oo00l?o`00T0l?o`00@00?l0
0?3ol03`oo00ogl00P3`oo000`00o`00l?o`0?3ol0160?3ol00307lZ:P3`oo00l?o`01H0l?o`00<0
0?l00?3ol03`oo00303`oo0<0?ooo`001P3ooolW0?3ol0<0ObXZB03<ol`20?l0o`<0ogl0303`oo00
0`000000l?o`0?3ol00:0?3ol003003o003oO`00l?o`00<0l?o`00<00?l00?3ol03`oo00A@3`oo00
0`1o:RX0l?o`0?3ol00E0?3ol003003o003`oo00l?o`00d0l?o`303oool000H0oooo9`3`oo0407lZ
:TH0c?o<103o0?l00`3oO`00l?o`0?mo000;0?3ol0030000003`oo00l?o`00T0l?o`00<0ogl00?3o
l000o`001@3`oo000`00o`00l?o`0?3ol0140?3ol00307lZ:P3`oo00l?o`01D0l?o`00<00?l00?3o
l03`oo003@3`oo0<0?ooo`001P3ooolX0?3ol0<0ObXZA@3<ol`40?l0o`@0l?o`0P3oO`090?3ol003
0000003`oo00l?o`00P0l?o`00D0ogl00?3ol03`oo00l?o`003o00050?3ol003003o003`oo00l?o`
04<0l?o`00<0ObXZ0?3ol03`oo005@3`oo000`00o`00l?o`0?3ol00=0?3ol0`0oooo00060?ooobP0
l?o`0`1o:RY40<coc0@0o`3o1`3`oo020?mo00L0l?o`00<000000?3ol03`oo001@3`oo030?mo00/0
l?o`00<00?l00?3ol03`oo00@P3`oo000`1o:RX0l?o`0?3ol00E0?3ol003003o003`oo00l?o`00d0
l?o`303oool000H0oooo:03`oo0307lZ:T<0c?o<103o0?l:0?3ol0@0ogl00`3`oo000`000000l?o`
0?3ol0030?3ol080ogl03`3`oo000`00o`00l?o`0?3ol0100?3ol00307lZ:P3`oo00l?o`01H0l?o`
00<00?l00?3ol03`oo003@3`oo0<0?ooo`001P3ooolX0?3ol0<0ObXZ@P3<ol`40?l0o`l0l?o`2@3o
O`0B0?3ol003003o003`oo00l?o`03l0l?o`00<0ObXZ0?3ol03`oo005@3`oo000`00o`00l?o`0?3o
l00>0?3ol0`0oooo00060?ooobP0l?o`101o:RY00<coc0@0o`3o4`3`oo000`000000l?o`0?3ol00F
0?3ol003003o003`oo00l?o`03h0l?o`00<0ObXZ0?3ol03`oo005@3`oo000`00o`00l?o`0?3ol00>
0?3ol0`0oooo00060?ooobT0l?o`0`1o:RXo0<coc0@0o`3o503`oo000`000000l?o`0?3ol00A0?3o
l003003o003`oo00l?o`00<0l?o`00<00?l00?3ol03`oo00?@3`oo000`1o:RX0l?o`0?3ol00E0?3o
l003003o003`oo00l?o`00h0l?o`303oool000H0oooo:@3`oo0307lZ:Sh0c?o<103o0?lE0?3ol003
0000003`oo00l?o`0180l?o`00<00?l00?3ol03`oo000`3`oo000`00o`00l?o`0?3ol00k0?3ol003
07lZ:P3`oo00l?o`01H0l?o`00<00?l00?3ol03`oo003P3`oo0<0?ooo`001P3ooolY0?3ol0<0ObXZ
?@3<ol`40?l0oaH0l?o`00<000000?3ol03`oo004`3`oo000`00o`00l?o`0?3ol0030?3ol003003o
003`oo00l?o`03X0l?o`00<0ObXZ0?3ol03`oo005P3`oo000`00o`00l?o`0?3ol00>0?3ol0`0oooo
00060?ooobT0l?o`101o:RXk0<coc0@0o`3o5`3`oo000`000000l?o`0?3ol00D0?3ol003003o003`
oo00l?o`00<0l?o`00<00?l00?3ol03`oo00>03`oo000`1o:RX0l?o`0?3ol00F0?3ol003003o003`
oo00l?o`00l0l?o`303oool000H0oooo:P3`oo0307lZ:SX0c?o<103o0?lH0?3ol0030000003`oo00
l?o`01D0l?o`00<00?l00?3ol03`oo000`3`oo000`00o`00l?o`0?3ol00g0?3ol00307lZ:P3`oo00
l?o`01H0l?o`00<00?l00?3ol03`oo003`3`oo0<0?ooo`001P3ooolZ0?3ol0@0ObXZ>03<ol`40?l0
oaT0l?o`00<000000?3ol03`oo005P3`oo000`00o`00l?o`0?3ol0030?3ol003003o003`oo00l?o`
03H0l?o`00<0ObXZ0?3ol03`oo005P3`oo000`00o`00l?o`0?3ol00?0?3ol0`0oooo00060?ooob/0
l?o`0`1o:RXg0<coc0@0o`3o6P3`oo000`000000l?o`0?3ol00M0?3ol003003o003`oo00l?o`03D0
l?o`00<0ObXZ0?3ol03`oo005P3`oo000`00o`00l?o`0?3ol00?0?3ol0`0oooo00060?ooob/0l?o`
101o:RXe0<coc0@0o`3o6`3`oo000`000000l?o`0?3ol00N0?3ol003003o003`oo00l?o`03@0l?o`
00<0ObXZ0?3ol03`oo005P3`oo000`00o`00l?o`0?3ol00?0?3ol0`0oooo00060?ooob`0l?o`0`1o
:RXd0<coc0@0o`3o703`oo000`000000l?o`0?3ol00O0?3ol003003o003`oo00l?o`0380l?o`00<0
ObXZ0?3ol03`oo005`3`oo000`00o`00l?o`0?3ol00?0?3ol0`0oooo00060?ooob`0l?o`0`1o:RXc
0<coc0@0o`3o7@3`oo000`000000l?o`0?3ol00P0?3ol003003o003`oo00l?o`0340l?o`00<0ObXZ
0?3ol03`oo005P3`oo000`00o`00l?o`0?3ol00@0?3ol0`0oooo00060?ooob`0l?o`0`1o:RXb0<co
c0@0o`3o7P3`oo000`000000l?o`0?3ol00K0?3ol003003o003`oo00l?o`00<0l?o`00<00?l00?3o
l03`oo00;`3`oo000`1o:RX0l?o`0?3ol00G0?3ol003003o003`oo00l?o`0100l?o`303oool000H0
oooo;03`oo0307lZ:S40c?o<103o0?lO0?3ol0030000003`oo00l?o`01`0l?o`00<00?l00?3ol03`
oo000`3`oo000`00o`00l?o`0?3ol00^0?3ol00307lZ:P3`oo00l?o`01H0l?o`00<00?l00?3ol03`
oo004@3`oo0<0?ooo`001P3oool/0?3ol0@0ObXZ;`3<ol`40?l0ob00l?o`00<000000?3ol03`oo00
7@3`oo000`00o`00l?o`0?3ol0030?3ol003003o003`oo00l?o`02`0l?o`00<0ObXZ0?3ol03`oo00
5`3`oo000`00o`00l?o`0?3ol00A0?3ol0`0oooo00060?ooobd0l?o`0`1o:RX^0<coc0@0o`3o8@3`
oo000`000000l?o`0?3ol00N0?3ol003003o003`oo00l?o`00<0l?o`00<00?l00?3ol03`oo00:`3`
oo000`1o:RX0l?o`0?3ol00G0?3ol003003o003`oo00l?o`0140l?o`303oool000H0oooo;@3`oo04
07lZ:R`0c?o<103o0?lR0?3ol0030000003`oo00l?o`01l0l?o`00<00?l00?3ol03`oo000`3`oo00
0`00o`00l?o`0?3ol00Y0?3ol00307lZ:P3`oo00l?o`01L0l?o`00<00?l00?3ol03`oo004P3`oo0<
0?ooo`001P3oool^0?3ol0<0ObXZ:`3<ol`40?l0ob<0l?o`00<000000?3ol03`oo00803`oo000`00
o`00l?o`0?3ol0030?3ol003003o003`oo00l?o`02P0l?o`00<0ObXZ0?3ol03`oo005`3`oo000`00
o`00l?o`0?3ol00B0?3ol0`0oooo00060?ooobh0l?o`101o:RXY0<coc0@0o`3o903`oo000`000000
l?o`0?3ol00W0?3ol003003o003`oo00l?o`02H0l?o`00<0ObXZ0?3ol03`oo00603`oo000`00o`00
l?o`0?3ol00B0?3ol0`0oooo00060?ooobl0l?o`0`1o:RXX0<coc0@0o`3o9@3`oo000`000000l?o`
0?3ol00X0?3ol003003o003`oo00l?o`02D0l?o`00<0ObXZ0?3ol03`oo005`3`oo000`00o`00l?o`
0?3ol00C0?3ol0`0oooo00060?ooobl0l?o`101o:RXV0<coc0@0o`3o9P3`oo000`000000l?o`0?3o
l00Y0?3ol003003o003`oo00l?o`02<0l?o`00<0ObXZ0?3ol03`oo00603`oo000`00o`00l?o`0?3o
l00C0?3ol0`0oooo00060?oooc00l?o`0`1o:RXU0<coc0@0o`3o9`3`oo000`000000l?o`0?3ol00U
0?3ol003003o003`oo00l?o`0080l?o`00<00?l00?3ol03`oo008P3`oo000`1o:RX0l?o`0?3ol00G
0?3ol003003o003`oo00l?o`01@0l?o`303oool000H0oooo<03`oo0407lZ:R<0c?o<103o0?lX0?3o
l0030000003`oo00l?o`02H0l?o`00<00?l00?3ol03`oo000P3`oo000`00o`00l?o`0?3ol00P0?3o
l00307lZ:P3`oo00l?o`01P0l?o`00<00?l00?3ol03`oo00503`oo0<0?ooo`001P3ooola0?3ol0<0
ObXZ8P3<ol`40?l0obT0l?o`00<000000?3ol03`oo009`3`oo000`00o`00l?o`0?3ol0020?3ol003
003o003`oo00l?o`01l0l?o`00<0ObXZ0?3ol03`oo00603`oo000`00o`00l?o`0?3ol00D0?3ol0`0
oooo00060?oooc40l?o`101o:RXP0<coc0@0o`3o:P3`oo000`000000l?o`0?3ol00X0?3ol003003o
003`oo00l?o`0080l?o`00<00?l00?3ol03`oo007@3`oo000`1o:RX0l?o`0?3ol00H0?3ol003003o
003`oo00l?o`01D0l?o`303oool000H0oooo<P3`oo0307lZ:Ql0c?o<103o0?l[0?3ol0030000003`
oo00l?o`02T0l?o`00<00?l00?3ol03`oo000P3`oo000`00o`00l?o`0?3ol00L0?3ol00307lZ:P3`
oo00l?o`01P0l?o`00<00?l00?3ol03`oo005@3`oo0<0?ooo`001P3ooolb0?3ol0@0ObXZ7@3<ol`4
0?l0ob`0l?o`00<000000?3ol03`oo00:P3`oo000`00o`00l?o`0?3ol0020?3ol003003o003`oo00
l?o`01X0l?o`00<0ObXZ0?3ol03`oo00603`oo000`00o`00l?o`0?3ol00F0?3ol0`0oooo00060?oo
oc<0l?o`0`1o:RXL0<coc0@0o`3o;@3`oo000`000000l?o`0?3ol00`0?3ol003003o003`oo00l?o`
01T0l?o`00<0ObXZ0?3ol03`oo00603`oo000`00o`00l?o`0?3ol00F0?3ol0`0oooo00060?oooc<0
l?o`101o:RXJ0<coc0@0o`3o;P3`oo000`000000l?o`0?3ol00a0?3ol003003o003`oo00l?o`01L0
l?o`00<0ObXZ0?3ol03`oo006@3`oo000`00o`00l?o`0?3ol00F0?3ol0`0oooo00060?oooc@0l?o`
0`1o:RXI0<coc0@0o`3o;`3`oo000`000000l?o`0?3ol00b0?3ol003003o003`oo00l?o`01H0l?o`
00<0ObXZ0?3ol03`oo00603`oo000`00o`00l?o`0?3ol00G0?3ol0`0oooo00060?oooc@0l?o`101o
:RXG0<coc0@0o`3o<03`oo000`000000l?o`0?3ol00c0?3ol003003o003`oo00l?o`01@0l?o`00<0
ObXZ0?3ol03`oo006@3`oo000`00o`00l?o`0?3ol00G0?3ol0`0oooo00060?ooocD0l?o`101o:RXE
0<coc0@0o`3o<@3`oo000`000000l?o`0?3ol00_0?3ol003003o003`oo00l?o`0080l?o`00<00?l0
0?3ol03`oo004P3`oo000`1o:RX0l?o`0?3ol00I0?3ol003003o003`oo00l?o`01P0l?o`303oool0
00H0oooo=P3`oo0407lZ:Q<0c?o<103o0?lb0?3ol0030000003`oo00l?o`0300l?o`00<00?l00?3o
l03`oo000P3`oo000`00o`00l?o`0?3ol00@0?3ol00307lZ:P3`oo00l?o`01X0l?o`00<00?l00?3o
l03`oo00603`oo0<0?ooo`001P3ooolg0?3ol0@0ObXZ4@3<ol`40?l0oc<0l?o`00<000000?3ol03`
oo00<@3`oo000`00o`00l?o`0?3ol0020?3ol003003o003`oo00l?o`00l0l?o`00<0ObXZ0?3ol03`
oo006@3`oo000`00o`00l?o`0?3ol00I0?3ol0`0oooo00060?ooocP0l?o`0`1o:RX@0<coc0@0o`3o
=03`oo000`000000l?o`0?3ol00b0?3ol003003o003`oo00l?o`0080l?o`00<00?l00?3ol03`oo00
3@3`oo000`1o:RX0l?o`0?3ol00J0?3ol003003o003`oo00l?o`01T0l?o`303oool000H0oooo>03`
oo0407lZ:Ph0c?o<103o0?le0?3ol0030000003`oo00l?o`03<0l?o`00<00?l00?3ol03`oo000P3`
oo000`00o`00l?o`0?3ol00<0?3ol00307lZ:P3`oo00l?o`01T0l?o`00<00?l00?3ol03`oo006P3`
oo0<0?ooo`001P3oooli0?3ol0@0ObXZ303<ol`40?l0ocH0l?o`00<000000?3ol03`oo00=03`oo00
0`00o`00l?o`0?3ol0020?3ol003003o003`oo00l?o`00X0l?o`00<0ObXZ0?3ol03`oo006@3`oo00
0`00o`00l?o`0?3ol00K0?3ol0`0oooo00060?ooocX0l?o`101o:RX:0<coc0@0o`3o=`3`oo000`00
0000l?o`0?3ol00j0?3ol003003o003`oo00l?o`00P0l?o`00<0ObXZ0?3ol03`oo006P3`oo000`00
o`00l?o`0?3ol0020?3ol08000000P3`oo000`000000l?o`0?3ol00B0?3ol0`0oooo00060?oooc/0
l?o`0`1o:RX90<coc0@0o`3o>03`oo000`000000l?o`0?3ol00k0?3ol003003o003`oo00l?o`00H0
l?o`00<0ObXZ0?3ol03`oo006P3`oo000`00o`00l?o`0?3ol0020?3ol0030000003`oo00l?o`0080
00005@3`oo0<0?ooo`001P3ooolk0?3ol0@0ObXZ1`3<ol`40?l0ocT0l?o`00<000000?3ol03`oo00
?03`oo000`00o`00l?o`0?3ol0050?3ol00307lZ:P3`oo00l?o`01X0l?o`00<00?l00?3ol03`oo00
0P3`oo001@000000l?o`0?3ol03`oo00000001D0l?o`303oool000H0oooo?03`oo0407lZ:PD0c?o<
103o0?lj0?3ol0030000003`oo00l?o`03d0l?o`00<00?l00?3ol03`oo000P3`oo0207lZ:Q`0l?o`
00<00?l00?3ol03`oo000`3`oo001@000000l?o`0?3ol03`oo00000001D0l?o`303oool000H0oooo
?@3`oo0407lZ:P<0c?o<103o0?lk0?3ol0030000003`oo00l?o`03P0l?o`00<00?l00?3ol03`oo00
0`3`oo001000o`00l?o`0?3ol01o:RXN0?3ol003003o003`oo00l?o`00<0l?o`00D000000?3ol03`
oo00l?o`0000000E0?3ol0`0oooo00060?oooch0l?o`101o:RX00`3<ol`0o`3o0?l0o`020?l0oc`0
l?o`00<000000?3ol03`oo00>@3`oo000`00o`00l?o`0?3ol0030?3ol003003o003`oo00ObXZ01d0
l?o`00<00?l00?3ol03`oo001@3`oo03000000030?3ol0000000l?o`01<0l?o`303oool000H0oooo
?`3`oo0407lZ:P<0o`3o?@3`oo000`000000l?o`0?3ol00j0?3ol003003o003`oo00l?o`00<0l?o`
00<00?l00?3ol03`oo006`3`oo000`00o`00l?o`0?3ol00O0?3ol0`0oooo00060?oood00l?o`101o
:RX00`3o0?l0l?o`0?3ol00l0?3ol0030000003`oo00l?o`03/0l?o`00L00?l00?3ol03`oo00l?o`
07lZ:P3`oo000?l001`0l?o`00<00?l00?3ol03`oo007`3`oo0<0?ooo`001P3ooom10?3ol0<0ObXZ
?`3`oo000`000000l?o`0?3ol00l0?3ol003003o003`oo00ObXZ00<0l?o`00<00?l00?3ol03`oo00
603`oo000`00o`00l?o`0?3ol00P0?3ol0`0oooo00060?oood80l?o`00<0ObXZ0?3ol01o:RX0?P3`
oo000`000000l?o`0?3ol00m0?3ol003003o003`oo00l?o`00<0l?o`00<00?l00?3ol03`oo005P3`
oo000`00o`00l?o`0?3ol00Q0?3ol0`0oooo00060?ooodD0l?o`00<0ObXZ0?3ol03`oo00>`3`oo00
0`000000l?o`0?3ol00l0?3ol00307lZ:P3`oo00l?o`00D0l?o`00<00?l00?3ol03`oo00503`oo00
0`00o`00l?o`0?3ol00R0?3ol0`0oooo00060?ooodH0l?o`00<0ObXZ0?3ol03`oo00>P3`oo000`00
0000l?o`0?3ol00j0?3ol080ObXZ2@3`oo000`00o`00l?o`0?3ol00C0?3ol003003o003`oo00l?o`
0280l?o`303oool000H0ooooA`3`oo000`1o:RX0l?o`0?3ol00i0?3ol0030000003`oo00l?o`03T0
l?o`00<0ObXZ0?3ol03`oo002P3`oo000`00o`00l?o`0?3ol00A0?3ol003003o003`oo00l?o`02<0
l?o`303oool000H0ooooB03`oo000`1o:RX0l?o`0?3ol00h0?3ol0030000003`oo00l?o`03T0l?o`
00<0ObXZ0?3ol03`oo002`3`oo000`00o`00l?o`0?3ol00@0?3ol003003o003`oo00l?o`02<0l?o`
303oool000H0ooooB@3`oo0207lZ:SP0l?o`00<000000?3ol03`oo00=`3`oo0207lZ:PT0l?o`00<0
0?l00?3ol03`oo000`3`oo000`00o`00l?o`0?3ol00>0?3ol003003o003`oo00l?o`02@0l?o`303o
ool000H0ooooB`3`oo000`1o:RX0l?o`0?3ol00e0?3ol0030000003`oo00l?o`03H0l?o`00<0ObXZ
0?3ol03`oo002P3`oo000`00o`00l?o`0?3ol0030?3ol003003o003`oo00l?o`00`0l?o`00<00?l0
0?3ol03`oo009@3`oo0<0?ooo`001P3ooom<0?3ol00307lZ:P3`oo00l?o`03@0l?o`00<000000?3o
l03`oo00=@3`oo000`1o:RX0l?o`0?3ol00<0?3ol003003o003`oo00l?o`00<0l?o`00<00?l00?3o
l03`oo002P3`oo000`00o`00l?o`0?3ol00V0?3ol0`0oooo00060?ooodd0l?o`00<0ObXZ0?3ol03`
oo00<`3`oo000`000000l?o`0?3ol00c0?3ol080ObXZ403`oo000`00o`00l?o`0?3ol0030?3ol003
003o003`oo00l?o`00P0l?o`00<00?l00?3ol03`oo009`3`oo0<0?ooo`001P3ooom>0?3ol080ObXZ
<`3`oo000`000000l?o`0?3ol00a0?3ol080ObXZ4`3`oo000`00o`00l?o`0?3ol0030?3ol003003o
003`oo00l?o`00L0l?o`00<00?l00?3ol03`oo009`3`oo0<0?ooo`001P3ooom@0?3ol00307lZ:P3`
oo00l?o`0300l?o`00<000000?3ol03`oo00<03`oo000`1o:RX0l?o`0?3ol00D0?3ol003003o003`
oo00l?o`00<0l?o`00<00?l00?3ol03`oo001@3`oo000`00o`00l?o`0?3ol00X0?3ol0`0oooo0006
0?oooe40l?o`00<0ObXZ0?3ol03`oo00;`3`oo000`000000l?o`0?3ol00_0?3ol00307lZ:P3`oo00
l?o`01`0l?o`00<00?l00?3ol03`oo000`3`oo000`00o`00l?o`0?3ol00Y0?3ol0`0oooo00060?oo
oe80l?o`0P1o:RX_0?3ol0030000003`oo00l?o`02d0l?o`0P1o:RXP0?3ol005003o003`oo00l?o`
0?3ol000o`00;03`oo0<0?ooo`001P3ooomD0?3ol080ObXZ;@3`oo000`000000l?o`0?3ol00[0?3o
l080ObXZ8`3`oo000`00o`00l?o`003o000]0?3ol0`0oooo00060?oooeH0l?o`0P1o:RX[0?3ol003
0000003`oo00l?o`02T0l?o`0P1o:RXV0?3ol003003o003`oo00l?o`02`0l?o`303oool000H0oooo
F03`oo0207lZ:RT0l?o`00<000000?3ol03`oo009`3`oo0207lZ:R<0l?o`00<00?l00?3ol03`oo00
0`3`oo000`00o`00l?o`0?3ol00[0?3ol0`0oooo00060?oooeX0l?o`0P1o:RXW0?3ol0030000003`
oo00l?o`02D0l?o`0P1o:RXV0?3ol003003o003`oo00l?o`00<0l?o`00<00?l00?3ol03`oo00:P3`
oo0<0?ooo`001P3ooomL0?3ol080ObXZ9@3`oo000`000000l?o`0?3ol00S0?3ol080ObXZ:@3`oo00
0`00o`00l?o`0?3ol0030?3ol003003o003`oo00l?o`02T0l?o`303oool000H0ooooGP3`oo0307lZ
:R80l?o`00<000000?3ol03`oo008@3`oo0207lZ:R`0l?o`00<00?l00?3ol03`oo000`3`oo000`00
o`00l?o`0?3ol00X0?3ol0`0oooo00060?ooof40l?o`0P1o:RXP0?3ol0030000003`oo00l?o`01l0
l?o`0P1o:RX_0?3ol003003o003`oo00l?o`00<0l?o`00<00?l00?3ol03`oo009`3`oo0<0?ooo`00
1P3ooomS0?3ol080ObXZ7P3`oo000`000000l?o`0?3ol00M0?3ol080ObXZ<P3`oo000`00o`00l?o`
0?3ol0030?3ol003003o003`oo00l?o`02H0l?o`303oool000H0ooooI@3`oo0407lZ:QX0l?o`00<0
00000?3ol03`oo00603`oo0507lZ:S/0l?o`00<00?l00?3ol03`oo009@3`oo0<0?ooo`001P3ooomY
0?3ol0<0ObXZ5`3`oo000`000000l?o`0?3ol00F0?3ol080ObXZ@@3`oo000`00o`00l?o`0?3ol00T
0?3ol0`0oooo00060?ooof`0l?o`101o:RXC0?3ol0030000003`oo00l?o`0180l?o`101o:RY40?3o
l003003o003`oo00l?o`02<0l?o`303oool000H0ooooL03`oo0707lZ:P`0l?o`00<000000?3ol03`
oo002`3`oo0707lZ:TT0l?o`00<00?l00?3ol03`oo008P3`oo0<0?ooo`001P3ooomg0?3ol1X0ObXZ
B`3`oo000`00o`00l?o`0?3ol0030?3ol003003o003`oo00l?o`0240l?o`303oool000H0ooooP`3`
oo000`000000l?o`0?3ol01G0?3ol003003o003`oo00l?o`00<0l?o`00<00?l00?3ol03`oo00803`
oo0<0?ooo`001P3ooon30?3ol0030000003`oo00l?o`05P0l?o`00<00?l00?3ol03`oo000`3`oo00
0`00o`00l?o`0?3ol00O0?3ol0`0oooo00060?oooh<0l?o`00<000000?3ol03`oo00F@3`oo000`00
o`00l?o`0?3ol0030?3ol003003o003`oo00l?o`01h0l?o`303oool000H0ooooP`3`oo000`000000
l?o`0?3ol01J0?3ol003003o003`oo00l?o`00<0l?o`00<00?l00?3ol03`oo007@3`oo0<0?ooo`00
1P3ooon30?3ol0030000003`oo00l?o`05/0l?o`00<00?l00?3ol03`oo000`3`oo000`00o`00l?o`
0?3ol00L0?3ol0`0oooo00060?oooh<0l?o`00<000000?3ol03`oo00HP3`oo000`00o`00l?o`0?3o
l00K0?3ol0`0oooo00060?oooh<0l?o`00<000000?3ol03`oo00H`3`oo000`00o`00l?o`0?3ol00J
0?3ol0`0oooo00060?oooh<0l?o`00<000000?3ol03`oo00I03`oo000`00o`00l?o`0?3ol00I0?3o
l0`0oooo00060?oooh<0l?o`00<000000?3ol03`oo00I@3`oo000`00o`00l?o`0?3ol00H0?3ol0`0
oooo00060?oooh<0l?o`00<000000?3ol03`oo00H03`oo000`00o`00l?o`0?3ol0030?3ol003003o
003`oo00l?o`01L0l?o`303oool000H0ooooP`3`oo000`000000l?o`0?3ol01Q0?3ol003003o003`
oo00l?o`00<0l?o`00<00?l00?3ol03`oo005P3`oo0<0?ooo`001P3ooon30?3ol0030000003`oo00
l?o`0680l?o`00<00?l00?3ol03`oo000`3`oo000`00o`00l?o`0?3ol00E0?3ol0`0oooo00060?oo
oh<0l?o`00<000000?3ol03`oo00H`3`oo000`00o`00l?o`0?3ol0030?3ol003003o003`oo00l?o`
01@0l?o`303oool000H0ooooP`3`oo000`000000l?o`0?3ol01T0?3ol003003o003`oo00l?o`00<0
l?o`00<00?l00?3ol03`oo004`3`oo0<0?ooo`001P3ooon30?3ol0030000003`oo00l?o`06D0l?o`
00<00?l00?3ol03`oo000`3`oo000`00o`00l?o`0?3ol00B0?3ol0`0oooo00060?oooh<0l?o`00<0
00000?3ol03`oo00K03`oo000`00o`00l?o`0?3ol00A0?3ol0`0oooo00060?oooh<0l?o`00<00000
0?3ol03`oo00K@3`oo000`00o`00l?o`0?3ol00@0?3ol0`0oooo00060?oooh<0l?o`00<000000?3o
l03`oo00KP3`oo000`00o`00l?o`0?3ol00?0?3ol0`0oooo00060?oooh<0l?o`00<000000?3ol03`
oo00K`3`oo000`00o`00l?o`0?3ol00>0?3ol0`0oooo00060?oooh<0l?o`00<000000?3ol03`oo00
JP3`oo000`00o`00l?o`0?3ol0030?3ol003003o003`oo00l?o`00d0l?o`303oool000H0ooooP`3`
oo000`000000l?o`0?3ol01[0?3ol003003o003`oo00l?o`00<0l?o`00<00?l00?3ol03`oo00303`
oo0<0?ooo`001P3ooon30?3ol0030000003`oo00l?o`06`0l?o`0P00o`040?3ol003003o003`oo00
l?o`00/0l?o`303oool000H0ooooP`3`oo000`000000l?o`0?3ol01^0?3ol003003o003`oo00l?o`
0080l?o`00<00?l00?3ol03`oo002P3`oo0<0?ooo`001P3ooon30?3ol0030000003`oo00l?o`06l0
l?o`00<00?l00?3ol03`oo000P3`oo000`00o`00l?o`0?3ol0090?3ol0`0oooo00060?oooh<0l?o`
00<000000?3ol03`oo00M@3`oo000`00o`00l?o`0?3ol0080?3ol0`0oooo00060?oooh<0l?o`00<0
00000?3ol03`oo00MP3`oo000`00o`00l?o`0?3ol0070?3ol0`0oooo00060?oooh<0l?o`00<00000
0?3ol03`oo00M`3`oo000`00o`00l?o`0?3ol0060?3ol0`0oooo00060?oooh<0l?o`00<000000?3o
l03`oo00N03`oo000`00o`00l?o`0?3ol0050?3ol0`0oooo00060?oooh<0l?o`00<000000?3ol03`
oo00M03`oo000`00o`00l?o`0?3ol0020?3ol003003o003`oo00l?o`00@0l?o`303oool000H0oooo
P`3`oo000`000000l?o`0?3ol01e0?3ol003003o003`oo00l?o`0080l?o`00<00?l00?3ol03`oo00
0`3`oo0<0?ooo`001P3ooon30?3ol0030000003`oo00l?o`07H0l?o`00<00?l00?3ol03`oo000P3`
oo000`00o`00l?o`0?3ol0020?3ol0`0oooo00060?oooh<0l?o`00<000000?3ol03`oo00M`3`oo00
0`00o`00l?o`0?3ol0020?3ol004003o003`oo00l?o`0?3ol0`0oooo00060?oooh<0l?o`00<00000
0?3ol03`oo00N03`oo000`00o`00l?o`0?3ol0020?3ol003003o003`oo00l?o`00`0oooo00060?oo
oh<0l?o`00<000000?3ol03`oo00N@3`oo000`00o`00l?o`0?3ol0020?3ol003003o003`oo00oooo
00/0oooo00060?oooh40l?o`1@0000040?3ol0800000N@3`oo000`00o`00oooo0?ooo`0:0?ooo`00
1P3ooon10?3ol0D000001@3`oo000`000000l?o`0?3ol01h0?3ol003003o003oool0oooo00T0oooo
00060?oooh40l?o`100000070?3ol0030000003`oo00l?o`07L0l?o`00<0oooo003o003oool02@3o
ool000H0ooooPP3`oo03000000H0l?o`00<000000?3ol0000000N03`oo020?ooo`03003o003oool0
oooo00L0oooo00060?oooh80l?o`0`0000050?3ol0040000003`oo00l?o`000007D0l?o`00<00?l0
0?3ol03`oo00303oool008P0oooo0`0000040?ooo`<0000000<0oooo000000000000M@3oool00`00
o`00oooo0?ooo`0;0?ooo`00R03oool200000840oooo00<00?l00?ooo`3oool02P3oool008T0oooo
00<000000?ooo`3oool0S03oool008T0oooo00<000000?ooo`3oool0S03oool00?l0oooo6@3oool0
0?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool0
0001\
\>"],
    ImageRangeCache->{{{0, 279}, {279, 0}} -> {-3, -3, 0, 0}}],
  StyleBox["       ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.436364 0.363636 0.0367877 0.0735755 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .03679 m
1 .03679 L
s
.43636 0 m
.43636 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
0 .03679 m
.14402 .03679 L
.43294 .03679 L
.74059 .03679 L
s
.74059 .03679 m
1 .03679 L
s
.941 1 .941 r
0 .09457 m
.98182 .09457 L
.98182 .55686 L
0 .55686 L
0 .09457 L
F
.8 1 .8 r
.21818 .21015 m
.76364 .21015 L
.76364 .44129 L
.21818 .44129 L
.21818 .21015 L
F
0 g
.98182 .03679 m
1 .03679 L
s
% Start of user PostScript
1.5 0 1.55 0 MAarrowhead1
% End of user PostScript
.43636 .61068 m
.43636 .61803 L
s
% Start of user PostScript
0 7.8 0 7.9 MAarrowhead1
% End of user PostScript
0 .03679 m
.98182 .03679 L
s
.43636 0 m
.43636 .61068 L
s
1 .5 0 r
.21818 .09457 m
.21818 .55686 L
s
.5 .165 .165 r
.76364 .09457 m
.76364 .55686 L
s
0 1 0 r
0 .55686 m
.98182 .55686 L
s
[ .025 .025 ] 0 setdash
0 .09457 m
.98182 .09457 L
s
1 0 1 r
[ ] 0 setdash
.21818 .21015 m
.76364 .21015 L
s
1 0 0 r
.21818 .32572 m
.76364 .32572 L
s
0 0 1 r
.21818 .44129 m
.76364 .44129 L
s
1 0 1 r
.012 w
.21818 .21015 m
.76364 .21015 L
s
0 0 1 r
.21818 .44129 m
.76364 .44129 L
s
.5 .165 .165 r
.76364 .21015 m
.76364 .44129 L
s
1 .5 0 r
.21818 .21015 m
.21818 .44129 L
s
0 g
gsave
.97455 .06622 -66 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45455 .59596 -69 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
75.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4 .57389 -93 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.875 moveto
(H) show
75.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
81.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
87.000 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 13.875 moveto
(L) show
123.000 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4 .07358 -84 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
87.000 13.875 moveto
(a) show
105.000 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{323, 199.625},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000530000ab000`400?l00000o`00003oS03oool0
0`000000oooo0?ooo`2d0?ooo`00S03oool00`000000oooo0?ooo`2d0?ooo`00S03oool00`000000
oooo0?ooo`2d0?ooo`00S03oool00`000000oooo0?ooo`2d0?ooo`00S03oool00`000000oooo0?oo
o`2d0?ooo`00S03oool00`000000oooo0?ooo`2d0?ooo`00S03oool00`000000oooo0?ooo`2d0?oo
o`00S03oool00`000000oooo0?ooo`2d0?ooo`00S03oool00`000000oooo0?ooo`2d0?ooo`00S03o
ool00`000000oooo0?ooo`2d0?ooo`00S03oool00`000000oooo0?ooo`2Z0?ooo`800000203oool0
08`0oooo00<000000?ooo`3oool0ZP3oool6000000@0oooo003o000004<000000@3oool008`0oooo
00<000000?ooo`3oool0ZP3oool7000000<0oooo002<0?ooo`030000003oool0oooo0:X0oooo0`00
00070?ooo`00S03oool00`000000oooo0?ooo`2d0?ooo`00S03oool00`000000oooo0?ooo`2d0?oo
o`00S03oool00`000000oooo0?ooo`2d0?ooo`00S03oool00`000000oooo0?ooo`2d0?ooo`00S03o
ool00`000000oooo0?ooo`2Y0?ooo`@000001`3oool008`0oooo00<000000?ooo`3oool0Z03oool0
10000000oooo0?ooo`0000080?ooo`00N03oool5000000L0oooo0P0000000`3oool000000?ooo`03
0?ooo`030000003oool0oooo0:P0oooo00@000000?ooo`3oool00000203oool007T0oooo00<00000
0?ooo`0000001`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0:L0oooo0P00
00000`3oool00000000000080?ooo`00N@3oool00`000000oooo000000070?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0]03oool007T0oooo00<000000?ooo`0000001`3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo0;@0oooo001h0?ooo`@00000203oool2
000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0]03oool008`0oooo00<000000?oo
o`3oool0]03oool007X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2d0?ooo`00
S03oool00`000000oooo0?ooo`2d0?ooo`00S03oool00`000000oooo0?ooo`2d0?ooo`002@00o`07
0?ooo`T00?l01`3oool9003o00L0oooo2@00o`070?ooo`T00?l01`3oool9003o00L0oooo2@00o`07
0?ooo`T00?l01`3oool9003o00<0oooo00@000000?ooo`3oool0oooo2@00o`070?ooo`T00?l0203o
ool9003o00L0oooo2@00o`070?ooo`T00?l01`3oool9003o00L0oooo2@00o`070?ooo`T00?l01`3o
ool9003o00L0oooo2@00o`070?ooo`T00?l02@3oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo00
0`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3o
l03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0
l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0
l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ
:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3o
l01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo00
0`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3o
l03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0
l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0
l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ
:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3o
l01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo00
0`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3o
l03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0
l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0
l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ
:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3o
l01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo00
0`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3o
l03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0
l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0
l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ
:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3o
l01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo00
0`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3o
l03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0
l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0
l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ
:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3o
l01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo00
0`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3o
l03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0
l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0
l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ
:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3o
l01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo00
0`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3o
l03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004H0
l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ:P3`oo00l?o`04<0
l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3ol01V0?3ol00307lZ
:P3`oo00l?o`04<0l?o`203oool004H0l?o`00<0ogl00?3ol03`oo00@`3`oo000`000000l?o`0?3o
l01V0?3ol00307lZ:P3`oo00l?o`04<0l?o`203oool004D0l?o`0`3oO`2/0?l0o`<0ObXZA03`oo08
0?ooo`00A@3`oo030?mo0:`0o`3o0`1o:RY40?3ol0P0oooo00150?3ol0<0ogl0[03o0?l307lZ:T@0
l?o`203oool004D0l?o`0`3oO`140<coc0030000003<ol`0c?o<06D0c?o<0`1o:RY40?3ol0P0oooo
00150?3ol0<0ogl0A03<ol`00`000000c?o<0<coc01U0<coc0<0ObXZA03`oo080?ooo`00A@3`oo03
0?mo04@0c?o<00<000000<coc03<ol`0I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`140<co
c0030000003<ol`0c?o<06D0c?o<0`1o:RY40?3ol0P0oooo00150?3ol0<0ogl0A03<ol`00`000000
c?o<0<coc01U0<coc0<0ObXZA03`oo080?ooo`00A@3`oo030?mo04@0c?o<00<000000<coc03<ol`0
I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`140<coc0030000003<ol`0c?o<06D0c?o<0`1o
:RY40?3ol0P0oooo00150?3ol0<0ogl0A03<ol`00`000000c?o<0<coc01U0<coc0<0ObXZA03`oo08
0?ooo`00A@3`oo030?mo04@0c?o<00<000000<coc03<ol`0I@3<ol`307lZ:T@0l?o`203oool004D0
l?o`0`3oO`140<coc0030000003<ol`0c?o<06D0c?o<0`1o:RY40?3ol0P0oooo00150?3ol0<0ogl0
A03<ol`00`000000c?o<0<coc01U0<coc0<0ObXZA03`oo080?ooo`00A@3`oo030?mo04@0c?o<00<0
00000<coc03<ol`0I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`140<coc0030000003<ol`0
c?o<06D0c?o<0`1o:RY40?3ol0P0oooo00150?3ol0<0ogl0A03<ol`00`000000c?o<0<coc01U0<co
c0<0ObXZA03`oo080?ooo`00A@3`oo030?mo04@0c?o<00<000000<coc03<ol`0I@3<ol`307lZ:T@0
l?o`203oool004D0l?o`0`3oO`140<coc0030000003<ol`0c?o<06D0c?o<0`1o:RY40?3ol0P0oooo
00150?3ol0<0ogl0A03<ol`00`000000c?o<0<coc01U0<coc0<0ObXZA03`oo080?ooo`00A@3`oo03
0?mo04@0c?o<00<000000<coc03<ol`0I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`140<co
c0030000003<ol`0c?o<06D0c?o<0`1o:RY40?3ol0P0oooo00150?3ol0<0ogl0A03<ol`00`000000
c?o<0<coc01U0<coc0<0ObXZA03`oo080?ooo`00A@3`oo030?mo04@0c?o<00<000000<coc03<ol`0
I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`140<coc0030000003<ol`0c?o<06D0c?o<0`1o
:RY40?3ol0P0oooo00150?3ol0<0ogl0A03<ol`00`000000c?o<0<coc01U0<coc0<0ObXZA03`oo08
0?ooo`00A@3`oo030?mo04@0c?o<00<000000<coc03<ol`0I@3<ol`307lZ:T@0l?o`203oool004D0
l?o`0`3oO`140<coc0030000003<ol`0c?o<06D0c?o<0`1o:RY40?3ol0P0oooo00150?3ol0<0ogl0
A03<ol`00`000000c?o<0<coc01U0<coc0<0ObXZA03`oo080?ooo`00A@3`oo030?mo04@0c?o<00<0
00000<coc03<ol`0I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`140<coc0030000003<ol`0
c?o<06D0c?o<0`1o:RY40?3ol0P0oooo00150?3ol0<0ogl0A03<ol`00`000000c?o<0<coc01U0<co
c0<0ObXZA03`oo080?ooo`00A@3`oo030?mo04@0c?o<00<000000<coc03<ol`0I@3<ol`307lZ:T@0
l?o`203oool004D0l?o`0`3oO`140<coc0030000003<ol`0c?o<06D0c?o<0`1o:RY40?3ol0P0oooo
00150?3ol0<0ogl0A03<ol`00`000000c?o<0<coc01U0<coc0<0ObXZA03`oo080?ooo`00A@3`oo03
0?mo04@0c?o<00<000000<coc03<ol`0I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`140<co
c0030000003<ol`0c?o<06D0c?o<0`1o:RY40?3ol0P0oooo00150?3ol0<0ogl0A03<ol`00`000000
c?o<0<coc01U0<coc0<0ObXZA03`oo080?ooo`00A@3`oo030?mo04@0c?o<00<000000<coc03<ol`0
I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`2/0?l000<0ObXZA03`oo080?ooo`00A@3`oo03
0?mo04@0c?o<00<000000<coc03<ol`0I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`140<co
c0030000003<ol`0c?o<06D0c?o<0`1o:RY40?3ol0P0oooo00150?3ol0<0ogl0A03<ol`00`000000
c?o<0<coc01U0<coc0<0ObXZA03`oo080?ooo`00A@3`oo030?mo04@0c?o<00<000000<coc03<ol`0
I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`140<coc0030000003<ol`0c?o<06D0c?o<0`1o
:RY40?3ol0P0oooo00150?3ol0<0ogl0A03<ol`00`000000c?o<0<coc01U0<coc0<0ObXZA03`oo08
0?ooo`00A@3`oo030?mo04@0c?o<00<000000<coc03<ol`0I@3<ol`307lZ:T@0l?o`203oool004D0
l?o`0`3oO`140<coc0030000003<ol`0c?o<06D0c?o<0`1o:RY40?3ol0P0oooo00150?3ol0<0ogl0
A03<ol`00`000000c?o<0<coc01U0<coc0<0ObXZA03`oo080?ooo`00A@3`oo030?mo04@0c?o<00<0
00000<coc03<ol`0I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`140<coc0030000003<ol`0
c?o<06D0c?o<0`1o:RY40?3ol0P0oooo00150?3ol0<0ogl0A03<ol`00`000000c?o<0<coc01U0<co
c0<0ObXZA03`oo080?ooo`00A@3`oo030?mo04@0c?o<00<000000<coc03<ol`0I@3<ol`307lZ:T@0
l?o`203oool004D0l?o`0`3oO`140<coc0030000003<ol`0c?o<06D0c?o<0`1o:RY40?3ol0P0oooo
00150?3ol0<0ogl0A03<ol`00`000000c?o<0<coc01U0<coc0<0ObXZA03`oo080?ooo`00A@3`oo03
0?mo04@0c?o<00<000000<coc03<ol`0I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`140<co
c0030000003<ol`0c?o<06D0c?o<0`1o:RY40?3ol0P0oooo00150?3ol0<0ogl0A03<ol`00`000000
c?o<0<coc01U0<coc0<0ObXZA03`oo080?ooo`00A@3`oo030?mo04@0c?o<00<000000<coc03<ol`0
I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`140<coc0030000003<ol`0c?o<06D0c?o<0`1o
:RY40?3ol0P0oooo00150?3ol0<0ogl0A03<ol`00`000000c?o<0<coc01U0<coc0<0ObXZA03`oo08
0?ooo`00A@3`oo030?mo04@0c?o<00<000000<coc03<ol`0I@3<ol`307lZ:T@0l?o`203oool004D0
l?o`0`3oO`140<coc0030000003<ol`0c?o<06D0c?o<0`1o:RY40?3ol0P0oooo00150?3ol0<0ogl0
A03<ol`00`000000c?o<0<coc01U0<coc0<0ObXZA03`oo080?ooo`00A@3`oo030?mo04@0c?o<00<0
00000<coc03<ol`0I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`140<coc0030000003<ol`0
c?o<06D0c?o<0`1o:RY40?3ol0P0oooo00150?3ol0<0ogl0A03<ol`00`000000c?o<0<coc01U0<co
c0<0ObXZA03`oo080?ooo`00A@3`oo030?mo04@0c?o<00<000000<coc03<ol`0I@3<ol`307lZ:T@0
l?o`203oool004D0l?o`0`3oO`140<coc0030000003<ol`0c?o<06D0c?o<0`1o:RY40?3ol0P0oooo
00150?3ol0<0ogl0A03<ol`00`000000c?o<0<coc01U0<coc0<0ObXZA03`oo080?ooo`00A@3`oo03
0?mo04@0c?o<00<000000<coc03<ol`0I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`140<co
c0030000003<ol`0c?o<06D0c?o<0`1o:RY40?3ol0P0oooo00150?3ol0<0ogl0A03<ol`00`000000
c?o<0<coc01U0<coc0<0ObXZA03`oo080?ooo`00A@3`oo030?mo04@0c?o<00<000000<coc03<ol`0
I@3<ol`307lZ:T@0l?o`203oool004D0l?o`0`3oO`140<coc0030000003<ol`0c?o<06D0c?o<0`1o
:RY40?3ol0P0oooo00150?3ol0<0ogl0[0000?l307lZ:T@0l?o`203oool004D0l?o`0`3oO`2/0000
o`<0ObXZA03`oo080?ooo`00A@3`oo030?mo0:`0003o0`1o:RY40?3ol0P0oooo00160?3ol0030?mo
003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo
00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3o
l0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo00
0`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3o
l03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0
l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo
003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo
00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3o
l0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo00
0`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3o
l03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0
l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo
003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo
00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3o
l0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo00
0`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3o
l03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0
l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo
003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo
00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3o
l0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo00
0`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3o
l03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0
l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo
003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo
00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3o
l0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo00
0`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3o
l03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0
l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo
003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo
00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3o
l0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo00
0`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3o
l03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0
l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo
003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo
00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3o
l0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3ol03`oo00IP3`oo00
0`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0l?o`00<000000?3o
l03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo00160?3ol0030?mo003`oo00l?o`04<0
l?o`00<000000?3ol03`oo00IP3`oo000`1o:RX0l?o`0?3ol0130?3ol0P0oooo003o003o03d00?l0
1`3oool006`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0;@0oooo001[0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool0
1@000000oooo0?ooo`3oool000000;H0oooo001S0?ooo`D000000P3oool00`000000oooo0?ooo`02
0?ooo`80000000<0oooo0000003oool00`3oool010000000oooo0?ooo`3oool4000000030?ooo`00
0000oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0;@0oooo
001T0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo0?ooo`D0000000<0oooo0000003oool0103oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo00000;H0oooo001T0?ooo`030000003oool0000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000]P3o
ool006@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`000000103oool010000000oooo0?ooo`00002f0?ooo`00H`3oool4000000@0oooo00@0
00000?ooo`3oool0oooo0P0000000`3oool000000?ooo`070?ooo`040000003oool0oooo00000080
oooo1@0000020?ooo`050000003oool0oooo0?ooo`000000]P3oool006`0oooo00<000000?ooo`3o
ool03@3oool2000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2d0?ooo`00
I@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0;@0oooo002<0?ooo`030000003o
ool0oooo00D0oooo0P00002]0?ooo`00RP3oool5000000D0oooo0P00002]0?ooo`00RP3oool50000
00@0oooo00@000000?ooo`3oool00000[03oool008X0oooo100000040?ooo`8000000P3oool20000
0:/0oooo002;0?ooo`<00000]@3oool008/0oooo0`00002e0?ooo`00R`3oool300000;D0oooo002;
0?ooo`800000]P3oool008`0oooo00<000000?ooo`3oool0]03oool008`0oooo00<000000?ooo`3o
ool0]03oool00001\
\>"],
    ImageRangeCache->{{{0, 322}, {198.625, 0}} -> {-1, 0, 0, 0}}],
  StyleBox["  \n\t\t\t\t\tFigure 5.4",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The branch ",
  Cell[BoxData[
      \(w = \(log\_\[Alpha]\) \((z)\)\)]],
  " of the logarithm. "
}], "Text"],

Cell[TextData[{
  "\tWe can easily compute the derivative of any branch of the multivalued \
logarithm. For a particular branch ",
  Cell[BoxData[
      \(w = \(log\_\[Alpha]\) \((z)\)\)]],
  " for ",
  Cell[BoxData[
      \(z = r\ \[ExponentialE]\^\[ImaginaryI]\[Theta] \[NotEqual] 0\)]],
  ", and  ",
  Cell[BoxData[
      \(\[Alpha] < \[Theta] \[LessEqual] \[Alpha] + 2  \[Pi]\)]],
  " (note the strict inequality for ",
  Cell[BoxData[
      \(\[Theta]\)]],
  "),  we start with ",
  Cell[BoxData[
      \(z = exp \((w)\)\)]],
  " in Equations ",
  StyleBox["(5-10)",
    FontColor->RGBColor[0, 0, 1]],
  " and differentiate both sides to get  \n\n\t\t\t",
  Cell[BoxData[{
      \(1\  = \ \(\(d\/dz\) \(z\)\(\ \)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \(\(=\)\(\ \)\(\(d\/dz\) 
          exp \((\(log\_\[Alpha]\) \((z)\))\)\)\)\), "\n", 
      \(\ \ \ \(\(=\)\(\ \ \)\(exp \((\(log\_\[Alpha]\) \((z)\))\) \(d\/dz\) \
\(log\_\[Alpha]\) \((z)\)\)\)\), "\n", 
      \(\ \ \ \(\(=\)\(\ \)\(z \( d\/dz\) \(log\_\[Alpha]\) \((z)\)\)\)\)}]],
  "  \n\nSolving for ",
  Cell[BoxData[
      \(\(d\/dz\) \(log\_\[Alpha]\) \((z)\)\)]],
  " gives  \n\n\t\t\t",
  Cell[BoxData[
      \(\(d\/dz\) \(log\_\[Alpha]\) \((z)\)\  = \ 1\/z\)]],
  ",   for    for ",
  Cell[BoxData[
      \(z = \[ExponentialE]\^\[ImaginaryI]\[Theta] \[NotEqual] 0\)]],
  ", and  ",
  Cell[BoxData[
      \(\[Alpha] < \[Theta] \[LessEqual] \[Alpha] + 2  \[Pi]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe Riemann surface for the multivalued function  ",
  Cell[BoxData[
      \(w = log \((z)\)\)]],
  "  is similar to the one we presented for the square root function.  \
However, it requires infinitely many copies of the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane cut along the negative x axis, which we label ",
  Cell[BoxData[
      \(S\_k\)]],
  " for ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"k", " ", "=", " ", 
          StyleBox["...",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(-n\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(-1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  ".  Now, we stack these cut planes directly on each other so that the \
corresponding points have the same position.  We join the sheet ",
  Cell[BoxData[
      RowBox[{\(S\_k\), " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(S\_\(k + 1\)\)}]]],
  " as follows.  For each integer ",
  StyleBox["k",
    FontFamily->"Courier New"],
  ", the edge of the sheet ",
  Cell[BoxData[
      \(S\_k\)]],
  " in the upper half-plane is joined to the edge of the sheet ",
  Cell[BoxData[
      \(S\_\(k + 1\)\)]],
  " in the lower half-plane.  The Riemann surface for the domain of ",
  Cell[BoxData[
      \(log \((z)\)\)]],
  " looks like a spiral staircase that extends upward on the sheets ",
  Cell[BoxData[
      RowBox[{\(S\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  "  and downward on the sheets ",
  Cell[BoxData[
      RowBox[{\(S\_\(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_\(-2\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  ",  as shown in Figure 5-5.  We use polar coordinates for ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " on each sheet.  For ",
  Cell[BoxData[
      \(S\_k\)]],
  ", we use\n\n\t\t\t  ",
  Cell[BoxData[
      \(z = \(r\ \[ExponentialE]\^\[ImaginaryI]\[Theta] = 
          r \((cos\ \[Theta] + \[ImaginaryI]\ sin\ \[Theta])\)\)\)]],
  ",    where  \n\t\t\t  \n\t\t\t  ",
  Cell[BoxData[
      \(r\  = \(\(|\)\(z\)\(|\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(2  \[Pi]\ k - \[Pi] < \[Theta] \[LessEqual] \[Pi] + 2  \[Pi]\ k\)]],
  ".  \n\nAgain, for ",
  Cell[BoxData[
      \(S\_k\)]],
  ", the correct branch of ",
  Cell[BoxData[
      \(log \((z)\)\)]],
  " on each sheet is  \n\n\t\t\t",
  Cell[BoxData[
      \(log \((\ z)\)\  = \ ln\ r\  + \ \[ImaginaryI]\ \ \[Theta]\)]],
  ",    where\n\n\t\t\t  ",
  Cell[BoxData[
      \(r\  = \(\(|\)\(z\)\(|\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(2  \[Pi]\ k - \[Pi] < \[Theta] \[LessEqual] \[Pi] + 2  \[Pi]\ k\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 1.043 -0.416308 1.49011 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 g
.49134 .31897 m
.4745 .3438 L
.34625 .34063 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.49134 .31897 m
.4745 .3438 L
s
.4745 .3438 m
.34625 .34063 L
s
1 g
.59618 .30614 m
.4745 .3438 L
.49134 .31897 L
F
0 g
.4745 .3438 m
.49134 .31897 L
s
.49134 .31897 m
.59618 .30614 L
s
1 g
.59618 .30614 m
.61227 .33027 L
.4745 .3438 L
F
0 g
.59618 .30614 m
.61227 .33027 L
s
.61227 .33027 m
.4745 .3438 L
s
1 g
.69453 .28051 m
.61227 .33027 L
.59618 .30614 L
F
0 g
.61227 .33027 m
.59618 .30614 L
s
.59618 .30614 m
.69453 .28051 L
s
1 g
.69453 .28051 m
.74206 .30052 L
.61227 .33027 L
F
0 g
.69453 .28051 m
.74206 .30052 L
s
.74206 .30052 m
.61227 .33027 L
s
1 g
.39396 .31848 m
.34625 .34063 L
.2443 .32176 L
F
0 g
.39396 .31848 m
.34625 .34063 L
s
.34625 .34063 m
.2443 .32176 L
s
1 g
.49134 .31897 m
.34625 .34063 L
.39396 .31848 L
F
0 g
.34625 .34063 m
.39396 .31848 L
s
.39396 .31848 m
.49134 .31897 L
s
1 g
.77278 .24394 m
.74206 .30052 L
.69453 .28051 L
F
0 g
.74206 .30052 m
.69453 .28051 L
s
.69453 .28051 m
.77278 .24394 L
s
1 g
.77278 .24394 m
.84651 .25665 L
.74206 .30052 L
F
0 g
.77278 .24394 m
.84651 .25665 L
s
.84651 .25665 m
.74206 .30052 L
s
1 g
.50869 .29338 m
.49134 .31897 L
.39396 .31848 L
F
0 g
.50869 .29338 m
.49134 .31897 L
s
.49134 .31897 m
.39396 .31848 L
s
1 g
.57963 .28131 m
.49134 .31897 L
.50869 .29338 L
F
0 g
.49134 .31897 m
.50869 .29338 L
s
.50869 .29338 m
.57963 .28131 L
s
1 g
.57963 .28131 m
.59618 .30614 L
.49134 .31897 L
F
0 g
.57963 .28131 m
.59618 .30614 L
s
.59618 .30614 m
.49134 .31897 L
s
1 g
.64588 .26002 m
.59618 .30614 L
.57963 .28131 L
F
0 g
.59618 .30614 m
.57963 .28131 L
s
.57963 .28131 m
.64588 .26002 L
s
1 g
.64588 .26002 m
.69453 .28051 L
.59618 .30614 L
F
0 g
.64588 .26002 m
.69453 .28051 L
s
.69453 .28051 m
.59618 .30614 L
s
1 g
.39396 .31848 m
.2443 .32176 L
.3173 .30548 L
F
0 g
.2443 .32176 m
.3173 .30548 L
s
.3173 .30548 m
.39396 .31848 L
s
1 g
.44296 .29573 m
.39396 .31848 L
.3173 .30548 L
F
0 g
.44296 .29573 m
.39396 .31848 L
s
.39396 .31848 m
.3173 .30548 L
s
1 g
.50869 .29338 m
.39396 .31848 L
.44296 .29573 L
F
0 g
.39396 .31848 m
.44296 .29573 L
s
.44296 .29573 m
.50869 .29338 L
s
1 g
.3173 .30548 m
.2443 .32176 L
.1836 .28977 L
F
0 g
.3173 .30548 m
.2443 .32176 L
s
.2443 .32176 m
.1836 .28977 L
s
1 g
.69798 .23105 m
.69453 .28051 L
.64588 .26002 L
F
0 g
.69453 .28051 m
.64588 .26002 L
s
.64588 .26002 m
.69798 .23105 L
s
1 g
.69798 .23105 m
.77278 .24394 L
.69453 .28051 L
F
0 g
.69798 .23105 m
.77278 .24394 L
s
.77278 .24394 m
.69453 .28051 L
s
1 g
.52657 .26701 m
.50869 .29338 L
.44296 .29573 L
F
0 g
.52657 .26701 m
.50869 .29338 L
s
.50869 .29338 m
.44296 .29573 L
s
1 g
.56258 .25575 m
.50869 .29338 L
.52657 .26701 L
F
0 g
.50869 .29338 m
.52657 .26701 L
s
.52657 .26701 m
.56258 .25575 L
s
1 g
.56258 .25575 m
.57963 .28131 L
.50869 .29338 L
F
0 g
.56258 .25575 m
.57963 .28131 L
s
.57963 .28131 m
.50869 .29338 L
s
1 g
.59606 .23905 m
.57963 .28131 L
.56258 .25575 L
F
0 g
.57963 .28131 m
.56258 .25575 L
s
.56258 .25575 m
.59606 .23905 L
s
1 g
.59606 .23905 m
.64588 .26002 L
.57963 .28131 L
F
0 g
.59606 .23905 m
.64588 .26002 L
s
.64588 .26002 m
.57963 .28131 L
s
1 g
.81896 .19978 m
.84651 .25665 L
.77278 .24394 L
F
0 g
.84651 .25665 m
.77278 .24394 L
s
.77278 .24394 m
.81896 .19978 L
s
1 g
.81896 .19978 m
.90969 .20259 L
.84651 .25665 L
F
0 g
.81896 .19978 m
.90969 .20259 L
s
.90969 .20259 m
.84651 .25665 L
s
1 g
.3173 .30548 m
.1836 .28977 L
.27273 .28208 L
F
0 g
.1836 .28977 m
.27273 .28208 L
s
.27273 .28208 m
.3173 .30548 L
s
1 g
.39172 .28888 m
.3173 .30548 L
.27273 .28208 L
F
0 g
.39172 .28888 m
.3173 .30548 L
s
.3173 .30548 m
.27273 .28208 L
s
1 g
.44296 .29573 m
.3173 .30548 L
.39172 .28888 L
F
0 g
.3173 .30548 m
.39172 .28888 L
s
.39172 .28888 m
.44296 .29573 L
s
1 g
.49328 .27237 m
.44296 .29573 L
.39172 .28888 L
F
0 g
.49328 .27237 m
.44296 .29573 L
s
.44296 .29573 m
.39172 .28888 L
s
1 g
.52657 .26701 m
.44296 .29573 L
.49328 .27237 L
F
0 g
.44296 .29573 m
.49328 .27237 L
s
.49328 .27237 m
.52657 .26701 L
s
1 g
.62207 .21797 m
.64588 .26002 L
.59606 .23905 L
F
0 g
.64588 .26002 m
.59606 .23905 L
s
.59606 .23905 m
.62207 .21797 L
s
1 g
.62207 .21797 m
.69798 .23105 L
.64588 .26002 L
F
0 g
.62207 .21797 m
.69798 .23105 L
s
.69798 .23105 m
.64588 .26002 L
s
1 g
.72794 .19697 m
.77278 .24394 L
.69798 .23105 L
F
0 g
.77278 .24394 m
.69798 .23105 L
s
.69798 .23105 m
.72794 .19697 L
s
1 g
.72794 .19697 m
.81896 .19978 L
.77278 .24394 L
F
0 g
.72794 .19697 m
.81896 .19978 L
s
.81896 .19978 m
.77278 .24394 L
s
1 g
.39172 .28888 m
.27273 .28208 L
.36267 .27433 L
F
0 g
.27273 .28208 m
.36267 .27433 L
s
.36267 .27433 m
.39172 .28888 L
s
1 g
.4676 .27196 m
.39172 .28888 L
.36267 .27433 L
F
0 g
.4676 .27196 m
.39172 .28888 L
s
.39172 .28888 m
.36267 .27433 L
s
1 g
.49328 .27237 m
.39172 .28888 L
.4676 .27196 L
F
0 g
.39172 .28888 m
.4676 .27196 L
s
.4676 .27196 m
.49328 .27237 L
s
1 g
.27273 .28208 m
.1836 .28977 L
.17547 .24892 L
F
0 g
.27273 .28208 m
.1836 .28977 L
s
.1836 .28977 m
.17547 .24892 L
s
1 g
.54502 .22943 m
.56258 .25575 L
.52657 .26701 L
F
0 g
.56258 .25575 m
.52657 .26701 L
s
1 g
.54502 .22942 m
.54503 .22943 L
.54502 .22943 L
F
0 g
.54502 .22942 m
.54503 .22943 L
s
1 g
.54503 .22943 m
.56258 .25575 L
.54502 .22943 L
F
0 g
.54503 .22943 m
.56258 .25575 L
s
1 g
.54502 .22942 m
.54502 .22943 L
.54501 .23982 L
F
0 g
.54501 .23982 m
.54502 .22942 L
s
1 g
.54502 .22943 m
.52657 .26701 L
.54501 .23982 L
F
0 g
.52657 .26701 m
.54501 .23982 L
s
1 g
.54498 .23984 m
.52657 .26701 L
.49328 .27237 L
F
0 g
.52657 .26701 m
.49328 .27237 L
s
1 g
.54499 .23984 m
.52657 .26701 L
.54498 .23984 L
F
.54501 .23983 m
.52657 .26701 L
.545 .23983 L
F
0 g
.54501 .23983 m
.52657 .26701 L
s
1 g
.545 .23983 m
.54499 .23984 L
.54498 .23984 L
F
.54501 .23982 m
.54501 .23983 L
.545 .23983 L
F
0 g
.54501 .23982 m
.54501 .23983 L
s
1 g
.54501 .23982 m
.49463 .27152 L
.545 .24836 L
F
0 g
.545 .24836 m
.54501 .23982 L
s
1 g
.49463 .27152 m
.49403 .27202 L
.545 .24836 L
F
0 g
.49403 .27202 m
.545 .24836 L
s
1 g
.49463 .27152 m
.49328 .27237 L
.49403 .27202 L
F
0 g
.49328 .27237 m
.49403 .27202 L
s
1 g
.54497 .24836 m
.49328 .27237 L
.4676 .27196 L
F
0 g
.49328 .27237 m
.4676 .27196 L
s
1 g
.545 .24836 m
.54499 .24836 L
.54497 .24836 L
F
0 g
.545 .24836 m
.54499 .24836 L
s
1 g
.54499 .24836 m
.49328 .27237 L
.54497 .24836 L
F
0 g
.54499 .24836 m
.49328 .27237 L
s
1 g
.545 .24836 m
.54497 .24836 L
.54499 .2547 L
F
0 g
.54499 .2547 m
.545 .24836 L
s
1 g
.54497 .24836 m
.47487 .26974 L
.54499 .2547 L
F
.47487 .26974 m
.47195 .27099 L
.54499 .2547 L
F
0 g
.47195 .27099 m
.54499 .2547 L
s
1 g
.47487 .26974 m
.4676 .27196 L
.47195 .27099 L
F
0 g
.4676 .27196 m
.47195 .27099 L
s
1 g
.54499 .2547 m
.4676 .27196 L
.45341 .2665 L
F
0 g
.54499 .2547 m
.4676 .27196 L
s
.4676 .27196 m
.45341 .2665 L
s
1 g
.54499 .2547 m
.4706 .26428 L
.54498 .2586 L
F
0 g
.54498 .2586 m
.54499 .2547 L
s
1 g
.4706 .26428 m
.46337 .26521 L
.468 .26484 L
F
.4706 .26428 m
.468 .26484 L
.54498 .2586 L
F
.46337 .26521 m
.45341 .2665 L
.46148 .2658 L
F
0 g
.45341 .2665 m
.46148 .2658 L
s
1 g
.46337 .26521 m
.46148 .2658 L
.54498 .2586 L
F
0 g
.46148 .2658 m
.54498 .2586 L
s
1 g
.63664 .19415 m
.69798 .23105 L
.62207 .21797 L
F
0 g
.69798 .23105 m
.62207 .21797 L
s
.62207 .21797 m
.63664 .19415 L
s
1 g
.63664 .19415 m
.72794 .19697 L
.69798 .23105 L
F
0 g
.63664 .19415 m
.72794 .19697 L
s
.72794 .19697 m
.69798 .23105 L
s
1 g
.54504 .21756 m
.56258 .25575 L
.54502 .22942 L
F
0 g
.56258 .25575 m
.54502 .22942 L
s
.54502 .22942 m
.54504 .21756 L
s
1 g
.54504 .21756 m
.59606 .23905 L
.56258 .25575 L
F
0 g
.54504 .21756 m
.59606 .23905 L
s
.59606 .23905 m
.56258 .25575 L
s
1 g
.27273 .28208 m
.17547 .24892 L
.26828 .25168 L
F
0 g
.17547 .24892 m
.26828 .25168 L
s
.26828 .25168 m
.27273 .28208 L
s
1 g
.36267 .27433 m
.27273 .28208 L
.26828 .25168 L
F
0 g
.36267 .27433 m
.27273 .28208 L
s
.27273 .28208 m
.26828 .25168 L
s
1 g
.54505 .20469 m
.59606 .23905 L
.54504 .21756 L
F
0 g
.59606 .23905 m
.54504 .21756 L
s
.54504 .21756 m
.54505 .20469 L
s
1 g
.54505 .20469 m
.62207 .21797 L
.59606 .23905 L
F
0 g
.54505 .20469 m
.62207 .21797 L
s
.62207 .21797 m
.59606 .23905 L
s
1 g
.4676 .27196 m
.36267 .27433 L
.45341 .2665 L
F
0 g
.36267 .27433 m
.45341 .2665 L
s
.45341 .2665 m
.4676 .27196 L
s
1 g
.36267 .27433 m
.26828 .25168 L
.3608 .25444 L
F
0 g
.26828 .25168 m
.3608 .25444 L
s
.3608 .25444 m
.36267 .27433 L
s
1 g
.45341 .2665 m
.36267 .27433 L
.3608 .25444 L
F
0 g
.45341 .2665 m
.36267 .27433 L
s
.36267 .27433 m
.3608 .25444 L
s
1 g
.54505 .19131 m
.62207 .21797 L
.54505 .20469 L
F
0 g
.62207 .21797 m
.54505 .20469 L
s
.54505 .20469 m
.54505 .19131 L
s
1 g
.54505 .19131 m
.63664 .19415 L
.62207 .21797 L
F
0 g
.54505 .19131 m
.63664 .19415 L
s
.63664 .19415 m
.62207 .21797 L
s
1 g
.82452 .15273 m
.90969 .20259 L
.81896 .19978 L
F
0 g
.90969 .20259 m
.81896 .19978 L
s
.81896 .19978 m
.82452 .15273 L
s
1 g
.82452 .15273 m
.91939 .14417 L
.90969 .20259 L
F
0 g
.82452 .15273 m
.91939 .14417 L
s
.91939 .14417 m
.90969 .20259 L
s
1 g
.73052 .16121 m
.81896 .19978 L
.72794 .19697 L
F
0 g
.81896 .19978 m
.72794 .19697 L
s
.72794 .19697 m
.73052 .16121 L
s
1 g
.73052 .16121 m
.82452 .15273 L
.81896 .19978 L
F
0 g
.73052 .16121 m
.82452 .15273 L
s
.82452 .15273 m
.81896 .19978 L
s
1 g
.45341 .2665 m
.3608 .25444 L
.45303 .25718 L
F
0 g
.3608 .25444 m
.45303 .25718 L
s
.45303 .25718 m
.45341 .2665 L
s
1 g
.54498 .2586 m
.45341 .2665 L
.45303 .25718 L
F
0 g
.54498 .2586 m
.45341 .2665 L
s
.45341 .2665 m
.45303 .25718 L
s
1 g
.63736 .16961 m
.72794 .19697 L
.63664 .19415 L
F
0 g
.72794 .19697 m
.63664 .19415 L
s
.63664 .19415 m
.63736 .16961 L
s
1 g
.63736 .16961 m
.73052 .16121 L
.72794 .19697 L
F
0 g
.63736 .16961 m
.73052 .16121 L
s
.73052 .16121 m
.72794 .19697 L
s
1 g
.54505 .17794 m
.63664 .19415 L
.54505 .19131 L
F
0 g
.63664 .19415 m
.54505 .19131 L
s
.54505 .19131 m
.54505 .17794 L
s
1 g
.54505 .17794 m
.63736 .16961 L
.63664 .19415 L
F
0 g
.54505 .17794 m
.63736 .16961 L
s
.63736 .16961 m
.63664 .19415 L
s
1 g
.54498 .12282 m
.45318 .11988 L
.46689 .11007 L
F
0 g
.54498 .12282 m
.45318 .11988 L
s
.45318 .11988 m
.46689 .11007 L
s
1 g
.54498 .12282 m
.49227 .11421 L
.54499 .12413 L
F
0 g
.54499 .12413 m
.54498 .12282 L
s
1 g
.49227 .11421 m
.49187 .11415 L
.49232 .11423 L
F
.49227 .11421 m
.49232 .11423 L
.54499 .12413 L
F
.49187 .11415 m
.49704 .1155 L
.54499 .12413 L
F
0 g
.49704 .1155 m
.54499 .12413 L
s
1 g
.49187 .11415 m
.46689 .11007 L
.49704 .1155 L
F
0 g
.46689 .11007 m
.49704 .1155 L
s
1 g
.54499 .12413 m
.46689 .11007 L
.49278 .10494 L
F
0 g
.54499 .12413 m
.46689 .11007 L
s
.46689 .11007 m
.49278 .10494 L
s
1 g
.54499 .12413 m
.49278 .10494 L
.545 .12802 L
F
0 g
.49278 .10494 m
.545 .12802 L
s
.545 .12802 m
.54499 .12413 L
s
1 g
.54499 .12801 m
.49278 .10494 L
.52694 .1058 L
F
0 g
.49278 .10494 m
.52694 .1058 L
s
1 g
.545 .12802 m
.54496 .12801 L
.54499 .12801 L
F
0 g
.545 .12802 m
.54496 .12801 L
s
1 g
.54496 .12801 m
.49278 .10494 L
.54499 .12801 L
F
0 g
.54496 .12801 m
.49278 .10494 L
s
1 g
.545 .12802 m
.52694 .1058 L
.54501 .13435 L
F
0 g
.52694 .1058 m
.54501 .13435 L
s
.54501 .13435 m
.545 .12802 L
s
1 g
.54503 .13433 m
.52694 .1058 L
.56403 .11331 L
F
0 g
.52694 .1058 m
.56403 .11331 L
s
1 g
.54501 .13435 m
.54499 .13431 L
.54503 .13433 L
F
0 g
.54501 .13435 m
.54499 .13431 L
s
1 g
.54499 .13431 m
.52694 .1058 L
.54503 .13433 L
F
0 g
.54499 .13431 m
.52694 .1058 L
s
1 g
.54501 .13435 m
.56403 .11331 L
.54502 .14286 L
F
0 g
.56403 .11331 m
.54502 .14286 L
s
.54502 .14286 m
.54501 .13435 L
s
1 g
.54502 .14286 m
.59814 .12725 L
.54504 .15324 L
F
0 g
.59814 .12725 m
.54504 .15324 L
s
.54504 .15324 m
.54502 .14286 L
s
1 g
.54502 .14286 m
.56403 .11331 L
.59814 .12725 L
F
0 g
.54502 .14286 m
.56403 .11331 L
s
.56403 .11331 m
.59814 .12725 L
s
1 g
.54504 .15324 m
.6239 .1466 L
.54505 .16508 L
F
0 g
.6239 .1466 m
.54505 .16508 L
s
.54505 .16508 m
.54504 .15324 L
s
1 g
.54504 .15324 m
.59814 .12725 L
.6239 .1466 L
F
0 g
.54504 .15324 m
.59814 .12725 L
s
.59814 .12725 m
.6239 .1466 L
s
1 g
.54505 .16508 m
.63736 .16961 L
.54505 .17794 L
F
0 g
.63736 .16961 m
.54505 .17794 L
s
.54505 .17794 m
.54505 .16508 L
s
1 g
.54505 .16508 m
.6239 .1466 L
.63736 .16961 L
F
0 g
.54505 .16508 m
.6239 .1466 L
s
.6239 .1466 m
.63736 .16961 L
s
1 g
.45318 .11988 m
.38762 .0958 L
.46689 .11007 L
F
0 g
.38762 .0958 m
.46689 .11007 L
s
.46689 .11007 m
.45318 .11988 L
s
1 g
.45318 .11988 m
.3611 .11692 L
.38762 .0958 L
F
0 g
.45318 .11988 m
.3611 .11692 L
s
.3611 .11692 m
.38762 .0958 L
s
1 g
.54498 .2586 m
.45303 .25718 L
.54498 .25992 L
F
0 g
.45303 .25718 m
.54498 .25992 L
s
.54498 .25992 m
.54498 .2586 L
s
1 g
.3611 .11692 m
.30715 .08131 L
.38762 .0958 L
F
0 g
.30715 .08131 m
.38762 .0958 L
s
.38762 .0958 m
.3611 .11692 L
s
1 g
.3611 .11692 m
.26873 .11396 L
.30715 .08131 L
F
0 g
.3611 .11692 m
.26873 .11396 L
s
.26873 .11396 m
.30715 .08131 L
s
1 g
.26873 .11396 m
.22545 .0666 L
.30715 .08131 L
F
0 g
.22545 .0666 m
.30715 .08131 L
s
.30715 .08131 m
.26873 .11396 L
s
1 g
.26873 .11396 m
.17607 .11099 L
.22545 .0666 L
F
0 g
.26873 .11396 m
.17607 .11099 L
s
.17607 .11099 m
.22545 .0666 L
s
1 g
.6239 .1466 m
.73052 .16121 L
.63736 .16961 L
F
0 g
.73052 .16121 m
.63736 .16961 L
s
.63736 .16961 m
.6239 .1466 L
s
1 g
.46689 .11007 m
.43926 .08128 L
.49278 .10494 L
F
0 g
.43926 .08128 m
.49278 .10494 L
s
.49278 .10494 m
.46689 .11007 L
s
1 g
.46689 .11007 m
.38762 .0958 L
.43926 .08128 L
F
0 g
.46689 .11007 m
.38762 .0958 L
s
.38762 .0958 m
.43926 .08128 L
s
1 g
.70435 .12774 m
.82452 .15273 L
.73052 .16121 L
F
0 g
.82452 .15273 m
.73052 .16121 L
s
.73052 .16121 m
.70435 .12774 L
s
1 g
.6239 .1466 m
.70435 .12774 L
.73052 .16121 L
F
0 g
.6239 .1466 m
.70435 .12774 L
s
.70435 .12774 m
.73052 .16121 L
s
1 g
.59814 .12725 m
.70435 .12774 L
.6239 .1466 L
F
0 g
.70435 .12774 m
.6239 .1466 L
s
.6239 .1466 m
.59814 .12725 L
s
1 g
.49278 .10494 m
.50831 .07638 L
.52694 .1058 L
F
0 g
.50831 .07638 m
.52694 .1058 L
s
.52694 .1058 m
.49278 .10494 L
s
1 g
.49278 .10494 m
.43926 .08128 L
.50831 .07638 L
F
0 g
.49278 .10494 m
.43926 .08128 L
s
.43926 .08128 m
.50831 .07638 L
s
1 g
.59814 .12725 m
.65275 .10053 L
.70435 .12774 L
F
0 g
.59814 .12725 m
.65275 .10053 L
s
.65275 .10053 m
.70435 .12774 L
s
1 g
.56403 .11331 m
.65275 .10053 L
.59814 .12725 L
F
0 g
.65275 .10053 m
.59814 .12725 L
s
.59814 .12725 m
.56403 .11331 L
s
1 g
.78644 .1085 m
.91939 .14417 L
.82452 .15273 L
F
0 g
.91939 .14417 m
.82452 .15273 L
s
.82452 .15273 m
.78644 .1085 L
s
1 g
.70435 .12774 m
.78644 .1085 L
.82452 .15273 L
F
0 g
.70435 .12774 m
.78644 .1085 L
s
.78644 .1085 m
.82452 .15273 L
s
1 g
.38762 .0958 m
.3844 .05703 L
.43926 .08128 L
F
0 g
.3844 .05703 m
.43926 .08128 L
s
.43926 .08128 m
.38762 .0958 L
s
1 g
.38762 .0958 m
.30715 .08131 L
.3844 .05703 L
F
0 g
.38762 .0958 m
.30715 .08131 L
s
.30715 .08131 m
.3844 .05703 L
s
1 g
.52694 .1058 m
.58364 .0828 L
.56403 .11331 L
F
0 g
.58364 .0828 m
.56403 .11331 L
s
.56403 .11331 m
.52694 .1058 L
s
1 g
.52694 .1058 m
.50831 .07638 L
.58364 .0828 L
F
0 g
.52694 .1058 m
.50831 .07638 L
s
.50831 .07638 m
.58364 .0828 L
s
1 g
.56403 .11331 m
.58364 .0828 L
.65275 .10053 L
F
0 g
.56403 .11331 m
.58364 .0828 L
s
.58364 .0828 m
.65275 .10053 L
s
1 g
.78644 .1085 m
.87022 .08886 L
.91939 .14417 L
F
0 g
.78644 .1085 m
.87022 .08886 L
s
.87022 .08886 m
.91939 .14417 L
s
1 g
.65275 .10053 m
.78644 .1085 L
.70435 .12774 L
F
0 g
.78644 .1085 m
.70435 .12774 L
s
.70435 .12774 m
.65275 .10053 L
s
1 g
.30715 .08131 m
.32814 .03216 L
.3844 .05703 L
F
0 g
.32814 .03216 m
.3844 .05703 L
s
.3844 .05703 m
.30715 .08131 L
s
1 g
.30715 .08131 m
.22545 .0666 L
.32814 .03216 L
F
0 g
.30715 .08131 m
.22545 .0666 L
s
.22545 .0666 m
.32814 .03216 L
s
1 g
.43926 .08128 m
.4891 .04603 L
.50831 .07638 L
F
0 g
.4891 .04603 m
.50831 .07638 L
s
.50831 .07638 m
.43926 .08128 L
s
1 g
.43926 .08128 m
.3844 .05703 L
.4891 .04603 L
F
0 g
.43926 .08128 m
.3844 .05703 L
s
.3844 .05703 m
.4891 .04603 L
s
1 g
.65275 .10053 m
.70893 .07305 L
.78644 .1085 L
F
0 g
.65275 .10053 m
.70893 .07305 L
s
.70893 .07305 m
.78644 .1085 L
s
1 g
.58364 .0828 m
.70893 .07305 L
.65275 .10053 L
F
0 g
.70893 .07305 m
.65275 .10053 L
s
.65275 .10053 m
.58364 .0828 L
s
1 g
.50831 .07638 m
.60389 .05131 L
.58364 .0828 L
F
0 g
.60389 .05131 m
.58364 .0828 L
s
.58364 .0828 m
.50831 .07638 L
s
1 g
.50831 .07638 m
.4891 .04603 L
.60389 .05131 L
F
0 g
.50831 .07638 m
.4891 .04603 L
s
.4891 .04603 m
.60389 .05131 L
s
1 g
.70893 .07305 m
.87022 .08886 L
.78644 .1085 L
F
0 g
.87022 .08886 m
.78644 .1085 L
s
.78644 .1085 m
.70893 .07305 L
s
1 g
.58364 .0828 m
.60389 .05131 L
.70893 .07305 L
F
0 g
.58364 .0828 m
.60389 .05131 L
s
.60389 .05131 m
.70893 .07305 L
s
1 g
.3844 .05703 m
.46927 .01472 L
.4891 .04603 L
F
0 g
.46927 .01472 m
.4891 .04603 L
s
.4891 .04603 m
.3844 .05703 L
s
1 g
.3844 .05703 m
.32814 .03216 L
.46927 .01472 L
F
0 g
.3844 .05703 m
.32814 .03216 L
s
.32814 .03216 m
.46927 .01472 L
s
1 g
.70893 .07305 m
.76674 .04475 L
.87022 .08886 L
F
0 g
.70893 .07305 m
.76674 .04475 L
s
.76674 .04475 m
.87022 .08886 L
s
1 g
.60389 .05131 m
.76674 .04475 L
.70893 .07305 L
F
0 g
.76674 .04475 m
.70893 .07305 L
s
.70893 .07305 m
.60389 .05131 L
s
1 g
.4891 .04603 m
.62481 .01876 L
.60389 .05131 L
F
0 g
.62481 .01876 m
.60389 .05131 L
s
.60389 .05131 m
.4891 .04603 L
s
1 g
.4891 .04603 m
.46927 .01472 L
.62481 .01876 L
F
0 g
.4891 .04603 m
.46927 .01472 L
s
.46927 .01472 m
.62481 .01876 L
s
1 g
.60389 .05131 m
.62481 .01876 L
.76674 .04475 L
F
0 g
.60389 .05131 m
.62481 .01876 L
s
.62481 .01876 m
.76674 .04475 L
s
0 .67 .67 r
.49126 .45042 m
.47439 .47336 L
.34595 .47107 L
F
0 g
.49126 .45042 m
.47439 .47336 L
s
.47439 .47336 m
.34595 .47107 L
s
0 .706 .706 r
.59626 .43778 m
.47439 .47336 L
.49126 .45042 L
F
0 g
.47439 .47336 m
.49126 .45042 L
s
.49126 .45042 m
.59626 .43778 L
s
0 .706 .706 r
.59626 .43778 m
.61237 .46008 L
.47439 .47336 L
F
0 g
.59626 .43778 m
.61237 .46008 L
s
.61237 .46008 m
.47439 .47336 L
s
0 .742 .742 r
.69477 .41318 m
.61237 .46008 L
.59626 .43778 L
F
0 g
.61237 .46008 m
.59626 .43778 L
s
.59626 .43778 m
.69477 .41318 L
s
0 .742 .742 r
.69477 .41318 m
.74237 .43169 L
.61237 .46008 L
F
0 g
.69477 .41318 m
.74237 .43169 L
s
.74237 .43169 m
.61237 .46008 L
s
0 .647 .647 r
.39373 .45062 m
.34595 .47107 L
.24383 .45413 L
F
0 g
.39373 .45062 m
.34595 .47107 L
s
.34595 .47107 m
.24383 .45413 L
s
0 .67 .67 r
.49126 .45042 m
.34595 .47107 L
.39373 .45062 L
F
0 g
.34595 .47107 m
.39373 .45062 L
s
.39373 .45062 m
.49126 .45042 L
s
0 .768 .768 r
.77314 .37838 m
.74237 .43169 L
.69477 .41318 L
F
0 g
.74237 .43169 m
.69477 .41318 L
s
.69477 .41318 m
.77314 .37838 L
s
0 .768 .768 r
.77314 .37838 m
.84698 .39014 L
.74237 .43169 L
F
0 g
.77314 .37838 m
.84698 .39014 L
s
.84698 .39014 m
.74237 .43169 L
s
0 .667 .667 r
.50863 .42678 m
.49126 .45042 L
.39373 .45062 L
F
0 g
.50863 .42678 m
.49126 .45042 L
s
.49126 .45042 m
.39373 .45062 L
s
0 .714 .714 r
.57968 .41483 m
.49126 .45042 L
.50863 .42678 L
F
0 g
.49126 .45042 m
.50863 .42678 L
s
.50863 .42678 m
.57968 .41483 L
s
0 .714 .714 r
.57968 .41483 m
.59626 .43778 L
.49126 .45042 L
F
0 g
.57968 .41483 m
.59626 .43778 L
s
.59626 .43778 m
.49126 .45042 L
s
0 .759 .759 r
.64604 .39424 m
.59626 .43778 L
.57968 .41483 L
F
0 g
.59626 .43778 m
.57968 .41483 L
s
.57968 .41483 m
.64604 .39424 L
s
0 .759 .759 r
.64604 .39424 m
.69477 .41318 L
.59626 .43778 L
F
0 g
.64604 .39424 m
.69477 .41318 L
s
.69477 .41318 m
.59626 .43778 L
s
0 .647 .647 r
.39373 .45062 m
.24383 .45413 L
.31694 .4391 L
F
0 g
.24383 .45413 m
.31694 .4391 L
s
.31694 .4391 m
.39373 .45062 L
s
0 .637 .637 r
.44279 .42961 m
.39373 .45062 L
.31694 .4391 L
F
0 g
.44279 .42961 m
.39373 .45062 L
s
.39373 .45062 m
.31694 .4391 L
s
0 .667 .667 r
.50863 .42678 m
.39373 .45062 L
.44279 .42961 L
F
0 g
.39373 .45062 m
.44279 .42961 L
s
.44279 .42961 m
.50863 .42678 L
s
0 .646 .646 r
.31694 .4391 m
.24383 .45413 L
.18302 .42491 L
F
0 g
.31694 .4391 m
.24383 .45413 L
s
.24383 .45413 m
.18302 .42491 L
s
0 .789 .789 r
.69822 .36645 m
.69477 .41318 L
.64604 .39424 L
F
0 g
.69477 .41318 m
.64604 .39424 L
s
.64604 .39424 m
.69822 .36645 L
s
0 .789 .789 r
.69822 .36645 m
.77314 .37838 L
.69477 .41318 L
F
0 g
.69822 .36645 m
.77314 .37838 L
s
.77314 .37838 m
.69477 .41318 L
s
0 .66 .66 r
.52654 .40242 m
.50863 .42678 L
.44279 .42961 L
F
0 g
.52654 .40242 m
.50863 .42678 L
s
.50863 .42678 m
.44279 .42961 L
s
0 .729 .729 r
.56261 .3912 m
.50863 .42678 L
.52654 .40242 L
F
0 g
.50863 .42678 m
.52654 .40242 L
s
.52654 .40242 m
.56261 .3912 L
s
0 .729 .729 r
.56261 .3912 m
.57968 .41483 L
.50863 .42678 L
F
0 g
.56261 .3912 m
.57968 .41483 L
s
.57968 .41483 m
.50863 .42678 L
s
0 .788 .788 r
.59614 .37484 m
.57968 .41483 L
.56261 .3912 L
F
0 g
.57968 .41483 m
.56261 .3912 L
s
.56261 .3912 m
.59614 .37484 L
s
0 .788 .788 r
.59614 .37484 m
.64604 .39424 L
.57968 .41483 L
F
0 g
.59614 .37484 m
.64604 .39424 L
s
.64604 .39424 m
.57968 .41483 L
s
0 .78 .78 r
.8194 .33647 m
.84698 .39014 L
.77314 .37838 L
F
0 g
.84698 .39014 m
.77314 .37838 L
s
.77314 .37838 m
.8194 .33647 L
s
0 .78 .78 r
.8194 .33647 m
.91028 .33907 L
.84698 .39014 L
F
0 g
.8194 .33647 m
.91028 .33907 L
s
.91028 .33907 m
.84698 .39014 L
s
0 .646 .646 r
.31694 .4391 m
.18302 .42491 L
.27229 .41781 L
F
0 g
.18302 .42491 m
.27229 .41781 L
s
.27229 .41781 m
.31694 .4391 L
s
0 .635 .635 r
.39147 .42378 m
.31694 .4391 L
.27229 .41781 L
F
0 g
.39147 .42378 m
.31694 .4391 L
s
.31694 .4391 m
.27229 .41781 L
s
0 .637 .637 r
.44279 .42961 m
.31694 .4391 L
.39147 .42378 L
F
0 g
.31694 .4391 m
.39147 .42378 L
s
.39147 .42378 m
.44279 .42961 L
s
0 .613 .613 r
.4932 .40803 m
.44279 .42961 L
.39147 .42378 L
F
0 g
.4932 .40803 m
.44279 .42961 L
s
.44279 .42961 m
.39147 .42378 L
s
0 .66 .66 r
.52654 .40242 m
.44279 .42961 L
.4932 .40803 L
F
0 g
.44279 .42961 m
.4932 .40803 L
s
.4932 .40803 m
.52654 .40242 L
s
0 .824 .824 r
.6222 .35434 m
.64604 .39424 L
.59614 .37484 L
F
0 g
.64604 .39424 m
.59614 .37484 L
s
.59614 .37484 m
.6222 .35434 L
s
0 .824 .824 r
.6222 .35434 m
.69822 .36645 L
.64604 .39424 L
F
0 g
.6222 .35434 m
.69822 .36645 L
s
.69822 .36645 m
.64604 .39424 L
s
0 .802 .802 r
.72824 .33387 m
.77314 .37838 L
.69822 .36645 L
F
0 g
.77314 .37838 m
.69822 .36645 L
s
.69822 .36645 m
.72824 .33387 L
s
0 .802 .802 r
.72824 .33387 m
.8194 .33647 L
.77314 .37838 L
F
0 g
.72824 .33387 m
.8194 .33647 L
s
.8194 .33647 m
.77314 .37838 L
s
0 .635 .635 r
.39147 .42378 m
.27229 .41781 L
.36237 .41065 L
F
0 g
.27229 .41781 m
.36237 .41065 L
s
.36237 .41065 m
.39147 .42378 L
s
0 .613 .613 r
.46747 .40816 m
.39147 .42378 L
.36237 .41065 L
F
0 g
.46747 .40816 m
.39147 .42378 L
s
.39147 .42378 m
.36237 .41065 L
s
0 .613 .613 r
.4932 .40803 m
.39147 .42378 L
.46747 .40816 L
F
0 g
.39147 .42378 m
.46747 .40816 L
s
.46747 .40816 m
.4932 .40803 L
s
0 .663 .663 r
.27229 .41781 m
.18302 .42491 L
.17486 .38731 L
F
0 g
.27229 .41781 m
.18302 .42491 L
s
.18302 .42491 m
.17486 .38731 L
s
0 .768 .768 r
.54502 .36687 m
.56261 .3912 L
.52654 .40242 L
F
0 g
.56261 .3912 m
.52654 .40242 L
s
0 .768 .768 r
.54502 .36687 m
.54503 .36687 L
.54502 .36687 L
F
0 g
.54502 .36687 m
.54503 .36687 L
s
0 .768 .768 r
.54503 .36687 m
.56261 .3912 L
.54502 .36687 L
F
0 g
.54503 .36687 m
.56261 .3912 L
s
0 .768 .768 r
.54502 .36687 m
.54502 .36687 L
.54501 .3773 L
F
0 g
.54501 .3773 m
.54502 .36687 L
s
0 .768 .768 r
.54502 .36687 m
.52654 .40242 L
.54501 .3773 L
F
0 g
.52654 .40242 m
.54501 .3773 L
s
0 .635 .635 r
.54498 .37731 m
.52654 .40242 L
.4932 .40803 L
F
0 g
.52654 .40242 m
.4932 .40803 L
s
0 .635 .635 r
.54499 .37731 m
.52654 .40242 L
.54498 .37731 L
F
.54501 .3773 m
.52654 .40242 L
.545 .3773 L
F
0 g
.54501 .3773 m
.52654 .40242 L
s
0 .635 .635 r
.545 .3773 m
.54499 .37731 L
.54498 .37731 L
F
.54501 .3773 m
.54501 .3773 L
.545 .3773 L
F
0 g
.54501 .3773 m
.54501 .3773 L
s
0 .635 .635 r
.54501 .3773 m
.49455 .40723 L
.545 .38586 L
F
0 g
.545 .38586 m
.54501 .3773 L
s
0 .635 .635 r
.49455 .40723 m
.49395 .40771 L
.545 .38586 L
F
0 g
.49395 .40771 m
.545 .38586 L
s
0 .635 .635 r
.49455 .40723 m
.4932 .40803 L
.49395 .40771 L
F
0 g
.4932 .40803 m
.49395 .40771 L
s
0 .528 .528 r
.54497 .38587 m
.4932 .40803 L
.46747 .40816 L
F
0 g
.4932 .40803 m
.46747 .40816 L
s
0 .528 .528 r
.545 .38586 m
.54499 .38586 L
.54497 .38587 L
F
0 g
.545 .38586 m
.54499 .38586 L
s
0 .528 .528 r
.54499 .38586 m
.4932 .40803 L
.54497 .38587 L
F
0 g
.54499 .38586 m
.4932 .40803 L
s
0 .528 .528 r
.545 .38586 m
.54497 .38587 L
.54499 .39222 L
F
0 g
.54499 .39222 m
.545 .38586 L
s
0 .528 .528 r
.54497 .38587 m
.47476 .40606 L
.54499 .39222 L
F
.47476 .40606 m
.47183 .40726 L
.54499 .39222 L
F
0 g
.47183 .40726 m
.54499 .39222 L
s
0 .528 .528 r
.47476 .40606 m
.46747 .40816 L
.47183 .40726 L
F
0 g
.46747 .40816 m
.47183 .40726 L
s
0 .532 .532 r
.54499 .39222 m
.46747 .40816 L
.45326 .40343 L
F
0 g
.54499 .39222 m
.46747 .40816 L
s
.46747 .40816 m
.45326 .40343 L
s
0 .532 .532 r
.54499 .39222 m
.47048 .40133 L
.54498 .39614 L
F
0 g
.54498 .39614 m
.54499 .39222 L
s
0 .532 .532 r
.47048 .40133 m
.46324 .40221 L
.46787 .40187 L
F
.47048 .40133 m
.46787 .40187 L
.54498 .39614 L
F
.46324 .40221 m
.45326 .40343 L
.46135 .40279 L
F
0 g
.45326 .40343 m
.46135 .40279 L
s
0 .532 .532 r
.46324 .40221 m
.46135 .40279 L
.54498 .39614 L
F
0 g
.46135 .40279 m
.54498 .39614 L
s
0 .837 .837 r
.63679 .33125 m
.69822 .36645 L
.6222 .35434 L
F
0 g
.69822 .36645 m
.6222 .35434 L
s
.6222 .35434 m
.63679 .33125 L
s
0 .837 .837 r
.63679 .33125 m
.72824 .33387 L
.69822 .36645 L
F
0 g
.63679 .33125 m
.72824 .33387 L
s
.72824 .33387 m
.69822 .36645 L
s
0 .852 .852 r
.54504 .35497 m
.56261 .3912 L
.54502 .36687 L
F
0 g
.56261 .3912 m
.54502 .36687 L
s
.54502 .36687 m
.54504 .35497 L
s
0 .852 .852 r
.54504 .35497 m
.59614 .37484 L
.56261 .3912 L
F
0 g
.54504 .35497 m
.59614 .37484 L
s
.59614 .37484 m
.56261 .3912 L
s
0 .663 .663 r
.27229 .41781 m
.17486 .38731 L
.26782 .38986 L
F
0 g
.17486 .38731 m
.26782 .38986 L
s
.26782 .38986 m
.27229 .41781 L
s
0 .659 .659 r
.36237 .41065 m
.27229 .41781 L
.26782 .38986 L
F
0 g
.36237 .41065 m
.27229 .41781 L
s
.27229 .41781 m
.26782 .38986 L
s
0 .889 .889 r
.54505 .34206 m
.59614 .37484 L
.54504 .35497 L
F
0 g
.59614 .37484 m
.54504 .35497 L
s
.54504 .35497 m
.54505 .34206 L
s
0 .889 .889 r
.54505 .34206 m
.6222 .35434 L
.59614 .37484 L
F
0 g
.54505 .34206 m
.6222 .35434 L
s
.6222 .35434 m
.59614 .37484 L
s
0 .613 .613 r
.46747 .40816 m
.36237 .41065 L
.45326 .40343 L
F
0 g
.36237 .41065 m
.45326 .40343 L
s
.45326 .40343 m
.46747 .40816 L
s
0 .659 .659 r
.36237 .41065 m
.26782 .38986 L
.3605 .3924 L
F
0 g
.26782 .38986 m
.3605 .3924 L
s
.3605 .3924 m
.36237 .41065 L
s
0 .651 .651 r
.45326 .40343 m
.36237 .41065 L
.3605 .3924 L
F
0 g
.45326 .40343 m
.36237 .41065 L
s
.36237 .41065 m
.3605 .3924 L
s
0 .898 .898 r
.54505 .32863 m
.6222 .35434 L
.54505 .34206 L
F
0 g
.6222 .35434 m
.54505 .34206 L
s
.54505 .34206 m
.54505 .32863 L
s
0 .898 .898 r
.54505 .32863 m
.63679 .33125 L
.6222 .35434 L
F
0 g
.54505 .32863 m
.63679 .33125 L
s
.63679 .33125 m
.6222 .35434 L
s
0 .778 .778 r
.82499 .29185 m
.91028 .33907 L
.8194 .33647 L
F
0 g
.91028 .33907 m
.8194 .33647 L
s
.8194 .33647 m
.82499 .29185 L
s
0 .778 .778 r
.82499 .29185 m
.92002 .28392 L
.91028 .33907 L
F
0 g
.82499 .29185 m
.92002 .28392 L
s
.92002 .28392 m
.91028 .33907 L
s
0 .799 .799 r
.73082 .29971 m
.8194 .33647 L
.72824 .33387 L
F
0 g
.8194 .33647 m
.72824 .33387 L
s
.72824 .33387 m
.73082 .29971 L
s
0 .799 .799 r
.73082 .29971 m
.82499 .29185 L
.8194 .33647 L
F
0 g
.73082 .29971 m
.82499 .29185 L
s
.82499 .29185 m
.8194 .33647 L
s
0 .651 .651 r
.45326 .40343 m
.3605 .3924 L
.45288 .39493 L
F
0 g
.3605 .3924 m
.45288 .39493 L
s
.45288 .39493 m
.45326 .40343 L
s
0 .624 .624 r
.54498 .39614 m
.45326 .40343 L
.45288 .39493 L
F
0 g
.54498 .39614 m
.45326 .40343 L
s
.45326 .40343 m
.45288 .39493 L
s
0 .832 .832 r
.63752 .3075 m
.72824 .33387 L
.63679 .33125 L
F
0 g
.72824 .33387 m
.63679 .33125 L
s
.63679 .33125 m
.63752 .3075 L
s
0 .832 .832 r
.63752 .3075 m
.73082 .29971 L
.72824 .33387 L
F
0 g
.63752 .3075 m
.73082 .29971 L
s
.73082 .29971 m
.72824 .33387 L
s
0 .888 .888 r
.54505 .31521 m
.63679 .33125 L
.54505 .32863 L
F
0 g
.63679 .33125 m
.54505 .32863 L
s
.54505 .32863 m
.54505 .31521 L
s
0 .888 .888 r
.54505 .31521 m
.63752 .3075 L
.63679 .33125 L
F
0 g
.54505 .31521 m
.63752 .3075 L
s
.63752 .3075 m
.63679 .33125 L
s
0 .656 .656 r
.54498 .25992 m
.45303 .25718 L
.46676 .24817 L
F
0 g
.54498 .25992 m
.45303 .25718 L
s
.45303 .25718 m
.46676 .24817 L
s
0 .656 .656 r
.54498 .25992 m
.49218 .25199 L
.54499 .26123 L
F
0 g
.54499 .26123 m
.54498 .25992 L
s
0 .656 .656 r
.49218 .25199 m
.49178 .25193 L
.49223 .25201 L
F
.49218 .25199 m
.49223 .25201 L
.54499 .26123 L
F
.49178 .25193 m
.49696 .25321 L
.54499 .26123 L
F
0 g
.49696 .25321 m
.54499 .26123 L
s
0 .656 .656 r
.49178 .25193 m
.46676 .24817 L
.49696 .25321 L
F
0 g
.46676 .24817 m
.49696 .25321 L
s
0 .56 .56 r
.54499 .26123 m
.46676 .24817 L
.49269 .2437 L
F
0 g
.54499 .26123 m
.46676 .24817 L
s
.46676 .24817 m
.49269 .2437 L
s
0 .56 .56 r
.54499 .26123 m
.49269 .2437 L
.545 .26513 L
F
0 g
.49269 .2437 m
.545 .26513 L
s
.545 .26513 m
.54499 .26123 L
s
0 .531 .531 r
.54499 .26513 m
.49269 .2437 L
.52691 .24498 L
F
0 g
.49269 .2437 m
.52691 .24498 L
s
0 .531 .531 r
.545 .26513 m
.54496 .26512 L
.54499 .26513 L
F
0 g
.545 .26513 m
.54496 .26512 L
s
0 .531 .531 r
.54496 .26512 m
.49269 .2437 L
.54499 .26513 L
F
0 g
.54496 .26512 m
.49269 .2437 L
s
0 .531 .531 r
.545 .26513 m
.52691 .24498 L
.54501 .27148 L
F
0 g
.52691 .24498 m
.54501 .27148 L
s
.54501 .27148 m
.545 .26513 L
s
0 .606 .606 r
.54503 .27146 m
.52691 .24498 L
.56406 .25259 L
F
0 g
.52691 .24498 m
.56406 .25259 L
s
0 .606 .606 r
.54501 .27148 m
.54499 .27145 L
.54503 .27146 L
F
0 g
.54501 .27148 m
.54499 .27145 L
s
0 .606 .606 r
.54499 .27145 m
.52691 .24498 L
.54503 .27146 L
F
0 g
.54499 .27145 m
.52691 .24498 L
s
0 .606 .606 r
.54501 .27148 m
.56406 .25259 L
.54502 .28002 L
F
0 g
.56406 .25259 m
.54502 .28002 L
s
.54502 .28002 m
.54501 .27148 L
s
0 .721 .721 r
.54502 .28002 m
.59823 .26633 L
.54504 .29043 L
F
0 g
.59823 .26633 m
.54504 .29043 L
s
.54504 .29043 m
.54502 .28002 L
s
0 .721 .721 r
.54502 .28002 m
.56406 .25259 L
.59823 .26633 L
F
0 g
.54502 .28002 m
.56406 .25259 L
s
.56406 .25259 m
.59823 .26633 L
s
0 .809 .809 r
.54504 .29043 m
.62403 .28518 L
.54505 .30232 L
F
0 g
.62403 .28518 m
.54505 .30232 L
s
.54505 .30232 m
.54504 .29043 L
s
0 .809 .809 r
.54504 .29043 m
.59823 .26633 L
.62403 .28518 L
F
0 g
.54504 .29043 m
.59823 .26633 L
s
.59823 .26633 m
.62403 .28518 L
s
0 .861 .861 r
.54505 .30232 m
.63752 .3075 L
.54505 .31521 L
F
0 g
.63752 .3075 m
.54505 .31521 L
s
.54505 .31521 m
.54505 .30232 L
s
0 .861 .861 r
.54505 .30232 m
.62403 .28518 L
.63752 .3075 L
F
0 g
.54505 .30232 m
.62403 .28518 L
s
.62403 .28518 m
.63752 .3075 L
s
0 .681 .681 r
.45303 .25718 m
.38735 .23491 L
.46676 .24817 L
F
0 g
.38735 .23491 m
.46676 .24817 L
s
.46676 .24817 m
.45303 .25718 L
s
0 .681 .681 r
.45303 .25718 m
.3608 .25444 L
.38735 .23491 L
F
0 g
.45303 .25718 m
.3608 .25444 L
s
.3608 .25444 m
.38735 .23491 L
s
0 .624 .624 r
.54498 .39614 m
.45288 .39493 L
.54498 .39746 L
F
0 g
.45288 .39493 m
.54498 .39746 L
s
.54498 .39746 m
.54498 .39614 L
s
0 .689 .689 r
.3608 .25444 m
.30675 .22145 L
.38735 .23491 L
F
0 g
.30675 .22145 m
.38735 .23491 L
s
.38735 .23491 m
.3608 .25444 L
s
0 .689 .689 r
.3608 .25444 m
.26828 .25168 L
.30675 .22145 L
F
0 g
.3608 .25444 m
.26828 .25168 L
s
.26828 .25168 m
.30675 .22145 L
s
0 .692 .692 r
.26828 .25168 m
.22491 .20779 L
.30675 .22145 L
F
0 g
.22491 .20779 m
.30675 .22145 L
s
.30675 .22145 m
.26828 .25168 L
s
0 .692 .692 r
.26828 .25168 m
.17547 .24892 L
.22491 .20779 L
F
0 g
.26828 .25168 m
.17547 .24892 L
s
.17547 .24892 m
.22491 .20779 L
s
0 .809 .809 r
.62403 .28518 m
.73082 .29971 L
.63752 .3075 L
F
0 g
.73082 .29971 m
.63752 .3075 L
s
.63752 .3075 m
.62403 .28518 L
s
0 .64 .64 r
.46676 .24817 m
.43908 .22172 L
.49269 .2437 L
F
0 g
.43908 .22172 m
.49269 .2437 L
s
.49269 .2437 m
.46676 .24817 L
s
0 .64 .64 r
.46676 .24817 m
.38735 .23491 L
.43908 .22172 L
F
0 g
.46676 .24817 m
.38735 .23491 L
s
.38735 .23491 m
.43908 .22172 L
s
0 .781 .781 r
.70461 .26769 m
.82499 .29185 L
.73082 .29971 L
F
0 g
.82499 .29185 m
.73082 .29971 L
s
.73082 .29971 m
.70461 .26769 L
s
0 .809 .809 r
.62403 .28518 m
.70461 .26769 L
.73082 .29971 L
F
0 g
.62403 .28518 m
.70461 .26769 L
s
.70461 .26769 m
.73082 .29971 L
s
0 .768 .768 r
.59823 .26633 m
.70461 .26769 L
.62403 .28518 L
F
0 g
.70461 .26769 m
.62403 .28518 L
s
.62403 .28518 m
.59823 .26633 L
s
0 .627 .627 r
.49269 .2437 m
.50825 .21765 L
.52691 .24498 L
F
0 g
.50825 .21765 m
.52691 .24498 L
s
.52691 .24498 m
.49269 .2437 L
s
0 .627 .627 r
.49269 .2437 m
.43908 .22172 L
.50825 .21765 L
F
0 g
.49269 .2437 m
.43908 .22172 L
s
.43908 .22172 m
.50825 .21765 L
s
0 .768 .768 r
.59823 .26633 m
.65293 .24154 L
.70461 .26769 L
F
0 g
.59823 .26633 m
.65293 .24154 L
s
.65293 .24154 m
.70461 .26769 L
s
0 .713 .713 r
.56406 .25259 m
.65293 .24154 L
.59823 .26633 L
F
0 g
.65293 .24154 m
.59823 .26633 L
s
.59823 .26633 m
.56406 .25259 L
s
0 .763 .763 r
.78684 .24985 m
.92002 .28392 L
.82499 .29185 L
F
0 g
.92002 .28392 m
.82499 .29185 L
s
.82499 .29185 m
.78684 .24985 L
s
0 .781 .781 r
.70461 .26769 m
.78684 .24985 L
.82499 .29185 L
F
0 g
.70461 .26769 m
.78684 .24985 L
s
.78684 .24985 m
.82499 .29185 L
s
0 .662 .662 r
.38735 .23491 m
.38412 .1992 L
.43908 .22172 L
F
0 g
.38412 .1992 m
.43908 .22172 L
s
.43908 .22172 m
.38735 .23491 L
s
0 .662 .662 r
.38735 .23491 m
.30675 .22145 L
.38412 .1992 L
F
0 g
.38735 .23491 m
.30675 .22145 L
s
.30675 .22145 m
.38412 .1992 L
s
0 .657 .657 r
.52691 .24498 m
.5837 .22428 L
.56406 .25259 L
F
0 g
.5837 .22428 m
.56406 .25259 L
s
.56406 .25259 m
.52691 .24498 L
s
0 .657 .657 r
.52691 .24498 m
.50825 .21765 L
.5837 .22428 L
F
0 g
.52691 .24498 m
.50825 .21765 L
s
.50825 .21765 m
.5837 .22428 L
s
0 .713 .713 r
.56406 .25259 m
.5837 .22428 L
.65293 .24154 L
F
0 g
.56406 .25259 m
.5837 .22428 L
s
.5837 .22428 m
.65293 .24154 L
s
0 .763 .763 r
.78684 .24985 m
.87077 .23164 L
.92002 .28392 L
F
0 g
.78684 .24985 m
.87077 .23164 L
s
.87077 .23164 m
.92002 .28392 L
s
0 .749 .749 r
.65293 .24154 m
.78684 .24985 L
.70461 .26769 L
F
0 g
.78684 .24985 m
.70461 .26769 L
s
.70461 .26769 m
.65293 .24154 L
s
0 .673 .673 r
.30675 .22145 m
.32777 .1761 L
.38412 .1992 L
F
0 g
.32777 .1761 m
.38412 .1992 L
s
.38412 .1992 m
.30675 .22145 L
s
0 .673 .673 r
.30675 .22145 m
.22491 .20779 L
.32777 .1761 L
F
0 g
.30675 .22145 m
.22491 .20779 L
s
.22491 .20779 m
.32777 .1761 L
s
0 .654 .654 r
.43908 .22172 m
.489 .18947 L
.50825 .21765 L
F
0 g
.489 .18947 m
.50825 .21765 L
s
.50825 .21765 m
.43908 .22172 L
s
0 .654 .654 r
.43908 .22172 m
.38412 .1992 L
.489 .18947 L
F
0 g
.43908 .22172 m
.38412 .1992 L
s
.38412 .1992 m
.489 .18947 L
s
0 .749 .749 r
.65293 .24154 m
.70921 .21603 L
.78684 .24985 L
F
0 g
.65293 .24154 m
.70921 .21603 L
s
.70921 .21603 m
.78684 .24985 L
s
0 .709 .709 r
.5837 .22428 m
.70921 .21603 L
.65293 .24154 L
F
0 g
.70921 .21603 m
.65293 .24154 L
s
.65293 .24154 m
.5837 .22428 L
s
0 .672 .672 r
.50825 .21765 m
.60399 .19504 L
.5837 .22428 L
F
0 g
.60399 .19504 m
.5837 .22428 L
s
.5837 .22428 m
.50825 .21765 L
s
0 .672 .672 r
.50825 .21765 m
.489 .18947 L
.60399 .19504 L
F
0 g
.50825 .21765 m
.489 .18947 L
s
.489 .18947 m
.60399 .19504 L
s
0 .738 .738 r
.70921 .21603 m
.87077 .23164 L
.78684 .24985 L
F
0 g
.87077 .23164 m
.78684 .24985 L
s
.78684 .24985 m
.70921 .21603 L
s
0 .709 .709 r
.5837 .22428 m
.60399 .19504 L
.70921 .21603 L
F
0 g
.5837 .22428 m
.60399 .19504 L
s
.60399 .19504 m
.70921 .21603 L
s
0 .667 .667 r
.38412 .1992 m
.46914 .16039 L
.489 .18947 L
F
0 g
.46914 .16039 m
.489 .18947 L
s
.489 .18947 m
.38412 .1992 L
s
0 .667 .667 r
.38412 .1992 m
.32777 .1761 L
.46914 .16039 L
F
0 g
.38412 .1992 m
.32777 .1761 L
s
.32777 .1761 m
.46914 .16039 L
s
0 .738 .738 r
.70921 .21603 m
.76713 .18978 L
.87077 .23164 L
F
0 g
.70921 .21603 m
.76713 .18978 L
s
.76713 .18978 m
.87077 .23164 L
s
0 .707 .707 r
.60399 .19504 m
.76713 .18978 L
.70921 .21603 L
F
0 g
.76713 .18978 m
.70921 .21603 L
s
.70921 .21603 m
.60399 .19504 L
s
0 .68 .68 r
.489 .18947 m
.62495 .16483 L
.60399 .19504 L
F
0 g
.62495 .16483 m
.60399 .19504 L
s
.60399 .19504 m
.489 .18947 L
s
0 .68 .68 r
.489 .18947 m
.46914 .16039 L
.62495 .16483 L
F
0 g
.489 .18947 m
.46914 .16039 L
s
.46914 .16039 m
.62495 .16483 L
s
0 .707 .707 r
.60399 .19504 m
.62495 .16483 L
.76713 .18978 L
F
0 g
.60399 .19504 m
.62495 .16483 L
s
.62495 .16483 m
.76713 .18978 L
s
1 g
.49117 .58228 m
.47428 .60332 L
.34564 .60192 L
F
0 g
.49117 .58228 m
.47428 .60332 L
s
.47428 .60332 m
.34564 .60192 L
s
1 g
.59634 .56983 m
.47428 .60332 L
.49117 .58228 L
F
0 g
.47428 .60332 m
.49117 .58228 L
s
.49117 .58228 m
.59634 .56983 L
s
1 g
.59634 .56983 m
.61248 .59029 L
.47428 .60332 L
F
0 g
.59634 .56983 m
.61248 .59029 L
s
.61248 .59029 m
.47428 .60332 L
s
1 g
.695 .54628 m
.61248 .59029 L
.59634 .56983 L
F
0 g
.61248 .59029 m
.59634 .56983 L
s
.59634 .56983 m
.695 .54628 L
s
1 g
.695 .54628 m
.74268 .56327 L
.61248 .59029 L
F
0 g
.695 .54628 m
.74268 .56327 L
s
.74268 .56327 m
.61248 .59029 L
s
1 g
.39349 .58317 m
.34564 .60192 L
.24335 .58692 L
F
0 g
.39349 .58317 m
.34564 .60192 L
s
.34564 .60192 m
.24335 .58692 L
s
1 g
.49117 .58228 m
.34564 .60192 L
.39349 .58317 L
F
0 g
.34564 .60192 m
.39349 .58317 L
s
.39349 .58317 m
.49117 .58228 L
s
1 g
.77351 .51325 m
.74268 .56327 L
.695 .54628 L
F
0 g
.74268 .56327 m
.695 .54628 L
s
.695 .54628 m
.77351 .51325 L
s
1 g
.77351 .51325 m
.84746 .52405 L
.74268 .56327 L
F
0 g
.77351 .51325 m
.84746 .52405 L
s
.84746 .52405 m
.74268 .56327 L
s
1 g
.50857 .56061 m
.49117 .58228 L
.39349 .58317 L
F
0 g
.50857 .56061 m
.49117 .58228 L
s
.49117 .58228 m
.39349 .58317 L
s
1 g
.57974 .54877 m
.49117 .58228 L
.50857 .56061 L
F
0 g
.49117 .58228 m
.50857 .56061 L
s
.50857 .56061 m
.57974 .54877 L
s
1 g
.57974 .54877 m
.59634 .56983 L
.49117 .58228 L
F
0 g
.57974 .54877 m
.59634 .56983 L
s
.59634 .56983 m
.49117 .58228 L
s
1 g
.6462 .52888 m
.59634 .56983 L
.57974 .54877 L
F
0 g
.59634 .56983 m
.57974 .54877 L
s
.57974 .54877 m
.6462 .52888 L
s
1 g
.6462 .52888 m
.695 .54628 L
.59634 .56983 L
F
0 g
.6462 .52888 m
.695 .54628 L
s
.695 .54628 m
.59634 .56983 L
s
1 g
.39349 .58317 m
.24335 .58692 L
.31657 .57315 L
F
0 g
.24335 .58692 m
.31657 .57315 L
s
.31657 .57315 m
.39349 .58317 L
s
1 g
.44263 .56392 m
.39349 .58317 L
.31657 .57315 L
F
0 g
.44263 .56392 m
.39349 .58317 L
s
.39349 .58317 m
.31657 .57315 L
s
1 g
.50857 .56061 m
.39349 .58317 L
.44263 .56392 L
F
0 g
.39349 .58317 m
.44263 .56392 L
s
.44263 .56392 m
.50857 .56061 L
s
1 g
.31657 .57315 m
.24335 .58692 L
.18243 .56048 L
F
0 g
.31657 .57315 m
.24335 .58692 L
s
.24335 .58692 m
.18243 .56048 L
s
1 g
.69847 .50228 m
.695 .54628 L
.6462 .52888 L
F
0 g
.695 .54628 m
.6462 .52888 L
s
.6462 .52888 m
.69847 .50228 L
s
1 g
.69847 .50228 m
.77351 .51325 L
.695 .54628 L
F
0 g
.69847 .50228 m
.77351 .51325 L
s
.77351 .51325 m
.695 .54628 L
s
1 g
.52651 .53826 m
.50857 .56061 L
.44263 .56392 L
F
0 g
.52651 .53826 m
.50857 .56061 L
s
.50857 .56061 m
.44263 .56392 L
s
1 g
.56264 .52709 m
.50857 .56061 L
.52651 .53826 L
F
0 g
.50857 .56061 m
.52651 .53826 L
s
.52651 .53826 m
.56264 .52709 L
s
1 g
.56264 .52709 m
.57974 .54877 L
.50857 .56061 L
F
0 g
.56264 .52709 m
.57974 .54877 L
s
.57974 .54877 m
.50857 .56061 L
s
1 g
.59623 .51107 m
.57974 .54877 L
.56264 .52709 L
F
0 g
.57974 .54877 m
.56264 .52709 L
s
.56264 .52709 m
.59623 .51107 L
s
1 g
.59623 .51107 m
.6462 .52888 L
.57974 .54877 L
F
0 g
.59623 .51107 m
.6462 .52888 L
s
.6462 .52888 m
.57974 .54877 L
s
1 g
.81985 .47361 m
.84746 .52405 L
.77351 .51325 L
F
0 g
.84746 .52405 m
.77351 .51325 L
s
.77351 .51325 m
.81985 .47361 L
s
1 g
.81985 .47361 m
.91088 .476 L
.84746 .52405 L
F
0 g
.81985 .47361 m
.91088 .476 L
s
.91088 .476 m
.84746 .52405 L
s
1 g
.31657 .57315 m
.18243 .56048 L
.27185 .55398 L
F
0 g
.18243 .56048 m
.27185 .55398 L
s
.27185 .55398 m
.31657 .57315 L
s
1 g
.39123 .55911 m
.31657 .57315 L
.27185 .55398 L
F
0 g
.39123 .55911 m
.31657 .57315 L
s
.31657 .57315 m
.27185 .55398 L
s
1 g
.44263 .56392 m
.31657 .57315 L
.39123 .55911 L
F
0 g
.31657 .57315 m
.39123 .55911 L
s
.39123 .55911 m
.44263 .56392 L
s
1 g
.49311 .54414 m
.44263 .56392 L
.39123 .55911 L
F
0 g
.49311 .54414 m
.44263 .56392 L
s
.44263 .56392 m
.39123 .55911 L
s
1 g
.52651 .53826 m
.44263 .56392 L
.49311 .54414 L
F
0 g
.44263 .56392 m
.49311 .54414 L
s
.49311 .54414 m
.52651 .53826 L
s
1 g
.62232 .49116 m
.6462 .52888 L
.59623 .51107 L
F
0 g
.6462 .52888 m
.59623 .51107 L
s
.59623 .51107 m
.62232 .49116 L
s
1 g
.62232 .49116 m
.69847 .50228 L
.6462 .52888 L
F
0 g
.62232 .49116 m
.69847 .50228 L
s
.69847 .50228 m
.6462 .52888 L
s
1 g
.72854 .47121 m
.77351 .51325 L
.69847 .50228 L
F
0 g
.77351 .51325 m
.69847 .50228 L
s
.69847 .50228 m
.72854 .47121 L
s
1 g
.72854 .47121 m
.81985 .47361 L
.77351 .51325 L
F
0 g
.72854 .47121 m
.81985 .47361 L
s
.81985 .47361 m
.77351 .51325 L
s
1 g
.39123 .55911 m
.27185 .55398 L
.36208 .54742 L
F
0 g
.27185 .55398 m
.36208 .54742 L
s
.36208 .54742 m
.39123 .55911 L
s
1 g
.46735 .5448 m
.39123 .55911 L
.36208 .54742 L
F
0 g
.46735 .5448 m
.39123 .55911 L
s
.39123 .55911 m
.36208 .54742 L
s
1 g
.49311 .54414 m
.39123 .55911 L
.46735 .5448 L
F
0 g
.39123 .55911 m
.46735 .5448 L
s
.46735 .5448 m
.49311 .54414 L
s
1 g
.27185 .55398 m
.18243 .56048 L
.17425 .52616 L
F
0 g
.27185 .55398 m
.18243 .56048 L
s
.18243 .56048 m
.17425 .52616 L
s
1 g
.54502 .50476 m
.56264 .52709 L
.52651 .53826 L
F
0 g
.56264 .52709 m
.52651 .53826 L
s
1 g
.54502 .50476 m
.54502 .50476 L
.54502 .50476 L
F
0 g
.54502 .50476 m
.54502 .50476 L
s
1 g
.54502 .50476 m
.56264 .52709 L
.54502 .50476 L
F
0 g
.54502 .50476 m
.56264 .52709 L
s
1 g
.54502 .50476 m
.54502 .50476 L
.54501 .51522 L
F
0 g
.54501 .51522 m
.54502 .50476 L
s
1 g
.54502 .50476 m
.52651 .53826 L
.54501 .51522 L
F
0 g
.52651 .53826 m
.54501 .51522 L
s
1 g
.54498 .51524 m
.52651 .53826 L
.49311 .54414 L
F
0 g
.52651 .53826 m
.49311 .54414 L
s
1 g
.54499 .51524 m
.52651 .53826 L
.54498 .51524 L
F
.54501 .51523 m
.52651 .53826 L
.545 .51523 L
F
0 g
.54501 .51523 m
.52651 .53826 L
s
1 g
.545 .51523 m
.54499 .51524 L
.54498 .51524 L
F
.54501 .51522 m
.54501 .51523 L
.545 .51523 L
F
0 g
.54501 .51522 m
.54501 .51523 L
s
1 g
.54501 .51522 m
.49446 .54339 L
.54499 .52381 L
F
0 g
.54499 .52381 m
.54501 .51522 L
s
1 g
.49446 .54339 m
.49386 .54385 L
.54499 .52381 L
F
0 g
.49386 .54385 m
.54499 .52381 L
s
1 g
.49446 .54339 m
.49311 .54414 L
.49386 .54385 L
F
0 g
.49311 .54414 m
.49386 .54385 L
s
1 g
.54497 .52382 m
.49311 .54414 L
.46735 .5448 L
F
0 g
.49311 .54414 m
.46735 .5448 L
s
1 g
.54499 .52381 m
.54499 .52382 L
.54497 .52382 L
F
0 g
.54499 .52381 m
.54499 .52382 L
s
1 g
.54499 .52382 m
.49311 .54414 L
.54497 .52382 L
F
0 g
.54499 .52382 m
.49311 .54414 L
s
1 g
.54499 .52381 m
.54497 .52382 L
.54498 .5302 L
F
0 g
.54498 .5302 m
.54499 .52381 L
s
1 g
.54497 .52382 m
.47464 .54283 L
.54498 .5302 L
F
.47464 .54283 m
.47171 .54398 L
.54498 .5302 L
F
0 g
.47171 .54398 m
.54498 .5302 L
s
1 g
.47464 .54283 m
.46735 .5448 L
.47171 .54398 L
F
0 g
.46735 .5448 m
.47171 .54398 L
s
1 g
.54498 .5302 m
.46735 .5448 L
.45311 .54081 L
F
0 g
.54498 .5302 m
.46735 .5448 L
s
.46735 .5448 m
.45311 .54081 L
s
1 g
.54498 .5302 m
.47035 .53881 L
.54498 .53413 L
F
0 g
.54498 .53413 m
.54498 .5302 L
s
1 g
.47035 .53881 m
.46311 .53965 L
.46775 .53934 L
F
.47035 .53881 m
.46775 .53934 L
.54498 .53413 L
F
.46311 .53965 m
.45311 .54081 L
.46121 .54022 L
F
0 g
.45311 .54081 m
.46121 .54022 L
s
1 g
.46311 .53965 m
.46121 .54022 L
.54498 .53413 L
F
0 g
.46121 .54022 m
.54498 .53413 L
s
1 g
.63694 .46881 m
.69847 .50228 L
.62232 .49116 L
F
0 g
.69847 .50228 m
.62232 .49116 L
s
.62232 .49116 m
.63694 .46881 L
s
1 g
.63694 .46881 m
.72854 .47121 L
.69847 .50228 L
F
0 g
.63694 .46881 m
.72854 .47121 L
s
.72854 .47121 m
.69847 .50228 L
s
1 g
.54504 .49282 m
.56264 .52709 L
.54502 .50476 L
F
0 g
.56264 .52709 m
.54502 .50476 L
s
.54502 .50476 m
.54504 .49282 L
s
1 g
.54504 .49282 m
.59623 .51107 L
.56264 .52709 L
F
0 g
.54504 .49282 m
.59623 .51107 L
s
.59623 .51107 m
.56264 .52709 L
s
1 g
.27185 .55398 m
.17425 .52616 L
.26737 .52849 L
F
0 g
.17425 .52616 m
.26737 .52849 L
s
.26737 .52849 m
.27185 .55398 L
s
1 g
.36208 .54742 m
.27185 .55398 L
.26737 .52849 L
F
0 g
.36208 .54742 m
.27185 .55398 L
s
.27185 .55398 m
.26737 .52849 L
s
1 g
.54505 .47987 m
.59623 .51107 L
.54504 .49282 L
F
0 g
.59623 .51107 m
.54504 .49282 L
s
.54504 .49282 m
.54505 .47987 L
s
1 g
.54505 .47987 m
.62232 .49116 L
.59623 .51107 L
F
0 g
.54505 .47987 m
.62232 .49116 L
s
.62232 .49116 m
.59623 .51107 L
s
1 g
.46735 .5448 m
.36208 .54742 L
.45311 .54081 L
F
0 g
.36208 .54742 m
.45311 .54081 L
s
.45311 .54081 m
.46735 .5448 L
s
1 g
.36208 .54742 m
.26737 .52849 L
.36019 .53082 L
F
0 g
.26737 .52849 m
.36019 .53082 L
s
.36019 .53082 m
.36208 .54742 L
s
1 g
.45311 .54081 m
.36208 .54742 L
.36019 .53082 L
F
0 g
.45311 .54081 m
.36208 .54742 L
s
.36208 .54742 m
.36019 .53082 L
s
1 g
.54505 .4664 m
.62232 .49116 L
.54505 .47987 L
F
0 g
.62232 .49116 m
.54505 .47987 L
s
.54505 .47987 m
.54505 .4664 L
s
1 g
.54505 .4664 m
.63694 .46881 L
.62232 .49116 L
F
0 g
.54505 .4664 m
.63694 .46881 L
s
.63694 .46881 m
.62232 .49116 L
s
1 g
.82545 .43143 m
.91088 .476 L
.81985 .47361 L
F
0 g
.91088 .476 m
.81985 .47361 L
s
.81985 .47361 m
.82545 .43143 L
s
1 g
.82545 .43143 m
.92064 .42413 L
.91088 .476 L
F
0 g
.82545 .43143 m
.92064 .42413 L
s
.92064 .42413 m
.91088 .476 L
s
1 g
.73113 .43867 m
.81985 .47361 L
.72854 .47121 L
F
0 g
.81985 .47361 m
.72854 .47121 L
s
.72854 .47121 m
.73113 .43867 L
s
1 g
.73113 .43867 m
.82545 .43143 L
.81985 .47361 L
F
0 g
.73113 .43867 m
.82545 .43143 L
s
.82545 .43143 m
.81985 .47361 L
s
1 g
.45311 .54081 m
.36019 .53082 L
.45273 .53314 L
F
0 g
.36019 .53082 m
.45273 .53314 L
s
.45273 .53314 m
.45311 .54081 L
s
1 g
.54498 .53413 m
.45311 .54081 L
.45273 .53314 L
F
0 g
.54498 .53413 m
.45311 .54081 L
s
.45311 .54081 m
.45273 .53314 L
s
1 g
.63767 .44583 m
.72854 .47121 L
.63694 .46881 L
F
0 g
.72854 .47121 m
.63694 .46881 L
s
.63694 .46881 m
.63767 .44583 L
s
1 g
.63767 .44583 m
.73113 .43867 L
.72854 .47121 L
F
0 g
.63767 .44583 m
.73113 .43867 L
s
.73113 .43867 m
.72854 .47121 L
s
1 g
.54505 .45294 m
.63694 .46881 L
.54505 .4664 L
F
0 g
.63694 .46881 m
.54505 .4664 L
s
.54505 .4664 m
.54505 .45294 L
s
1 g
.54505 .45294 m
.63767 .44583 L
.63694 .46881 L
F
0 g
.54505 .45294 m
.63767 .44583 L
s
.63767 .44583 m
.63694 .46881 L
s
1 g
.54498 .39746 m
.45288 .39493 L
.46663 .38672 L
F
0 g
.54498 .39746 m
.45288 .39493 L
s
.45288 .39493 m
.46663 .38672 L
s
1 g
.54498 .39746 m
.49209 .39021 L
.54499 .39878 L
F
0 g
.54499 .39878 m
.54498 .39746 L
s
1 g
.49209 .39021 m
.49169 .39016 L
.49214 .39023 L
F
.49209 .39021 m
.49214 .39023 L
.54499 .39878 L
F
.49169 .39016 m
.49688 .39138 L
.54499 .39878 L
F
0 g
.49688 .39138 m
.54499 .39878 L
s
1 g
.49169 .39016 m
.46663 .38672 L
.49688 .39138 L
F
0 g
.46663 .38672 m
.49688 .39138 L
s
1 g
.54499 .39878 m
.46663 .38672 L
.4926 .38291 L
F
0 g
.54499 .39878 m
.46663 .38672 L
s
.46663 .38672 m
.4926 .38291 L
s
1 g
.54499 .39878 m
.4926 .38291 L
.545 .40269 L
F
0 g
.4926 .38291 m
.545 .40269 L
s
.545 .40269 m
.54499 .39878 L
s
1 g
.54499 .40269 m
.4926 .38291 L
.52688 .38461 L
F
0 g
.4926 .38291 m
.52688 .38461 L
s
1 g
.545 .40269 m
.54496 .40268 L
.54499 .40269 L
F
0 g
.545 .40269 m
.54496 .40268 L
s
1 g
.54496 .40268 m
.4926 .38291 L
.54499 .40269 L
F
0 g
.54496 .40268 m
.4926 .38291 L
s
1 g
.545 .40269 m
.52688 .38461 L
.54501 .40906 L
F
0 g
.52688 .38461 m
.54501 .40906 L
s
.54501 .40906 m
.545 .40269 L
s
1 g
.54503 .40904 m
.52688 .38461 L
.56409 .39234 L
F
0 g
.52688 .38461 m
.56409 .39234 L
s
1 g
.54501 .40906 m
.54499 .40903 L
.54503 .40904 L
F
0 g
.54501 .40906 m
.54499 .40903 L
s
1 g
.54499 .40903 m
.52688 .38461 L
.54503 .40904 L
F
0 g
.54499 .40903 m
.52688 .38461 L
s
1 g
.54501 .40906 m
.56409 .39234 L
.54502 .41763 L
F
0 g
.56409 .39234 m
.54502 .41763 L
s
.54502 .41763 m
.54501 .40906 L
s
1 g
.54502 .41763 m
.59832 .40586 L
.54504 .42808 L
F
0 g
.59832 .40586 m
.54504 .42808 L
s
.54504 .42808 m
.54502 .41763 L
s
1 g
.54502 .41763 m
.56409 .39234 L
.59832 .40586 L
F
0 g
.54502 .41763 m
.56409 .39234 L
s
.56409 .39234 m
.59832 .40586 L
s
1 g
.54504 .42808 m
.62416 .42421 L
.54505 .44 L
F
0 g
.62416 .42421 m
.54505 .44 L
s
.54505 .44 m
.54504 .42808 L
s
1 g
.54504 .42808 m
.59832 .40586 L
.62416 .42421 L
F
0 g
.54504 .42808 m
.59832 .40586 L
s
.59832 .40586 m
.62416 .42421 L
s
1 g
.54505 .44 m
.63767 .44583 L
.54505 .45294 L
F
0 g
.63767 .44583 m
.54505 .45294 L
s
.54505 .45294 m
.54505 .44 L
s
1 g
.54505 .44 m
.62416 .42421 L
.63767 .44583 L
F
0 g
.54505 .44 m
.62416 .42421 L
s
.62416 .42421 m
.63767 .44583 L
s
1 g
.45288 .39493 m
.38709 .37449 L
.46663 .38672 L
F
0 g
.38709 .37449 m
.46663 .38672 L
s
.46663 .38672 m
.45288 .39493 L
s
1 g
.45288 .39493 m
.3605 .3924 L
.38709 .37449 L
F
0 g
.45288 .39493 m
.3605 .3924 L
s
.3605 .3924 m
.38709 .37449 L
s
1 g
.54498 .53413 m
.45273 .53314 L
.54498 .53545 L
F
0 g
.45273 .53314 m
.54498 .53545 L
s
.54498 .53545 m
.54498 .53413 L
s
1 g
.3605 .3924 m
.30635 .36206 L
.38709 .37449 L
F
0 g
.30635 .36206 m
.38709 .37449 L
s
.38709 .37449 m
.3605 .3924 L
s
1 g
.3605 .3924 m
.26782 .38986 L
.30635 .36206 L
F
0 g
.3605 .3924 m
.26782 .38986 L
s
.26782 .38986 m
.30635 .36206 L
s
1 g
.26782 .38986 m
.22437 .34945 L
.30635 .36206 L
F
0 g
.22437 .34945 m
.30635 .36206 L
s
.30635 .36206 m
.26782 .38986 L
s
1 g
.26782 .38986 m
.17486 .38731 L
.22437 .34945 L
F
0 g
.26782 .38986 m
.17486 .38731 L
s
.17486 .38731 m
.22437 .34945 L
s
1 g
.62416 .42421 m
.73113 .43867 L
.63767 .44583 L
F
0 g
.73113 .43867 m
.63767 .44583 L
s
.63767 .44583 m
.62416 .42421 L
s
1 g
.46663 .38672 m
.4389 .36263 L
.4926 .38291 L
F
0 g
.4389 .36263 m
.4926 .38291 L
s
.4926 .38291 m
.46663 .38672 L
s
1 g
.46663 .38672 m
.38709 .37449 L
.4389 .36263 L
F
0 g
.46663 .38672 m
.38709 .37449 L
s
.38709 .37449 m
.4389 .36263 L
s
1 g
.70488 .40811 m
.82545 .43143 L
.73113 .43867 L
F
0 g
.82545 .43143 m
.73113 .43867 L
s
.73113 .43867 m
.70488 .40811 L
s
1 g
.62416 .42421 m
.70488 .40811 L
.73113 .43867 L
F
0 g
.62416 .42421 m
.70488 .40811 L
s
.70488 .40811 m
.73113 .43867 L
s
1 g
.59832 .40586 m
.70488 .40811 L
.62416 .42421 L
F
0 g
.70488 .40811 m
.62416 .42421 L
s
.62416 .42421 m
.59832 .40586 L
s
1 g
.4926 .38291 m
.50819 .3594 L
.52688 .38461 L
F
0 g
.50819 .3594 m
.52688 .38461 L
s
.52688 .38461 m
.4926 .38291 L
s
1 g
.4926 .38291 m
.4389 .36263 L
.50819 .3594 L
F
0 g
.4926 .38291 m
.4389 .36263 L
s
.4389 .36263 m
.50819 .3594 L
s
1 g
.59832 .40586 m
.65311 .38301 L
.70488 .40811 L
F
0 g
.59832 .40586 m
.65311 .38301 L
s
.65311 .38301 m
.70488 .40811 L
s
1 g
.56409 .39234 m
.65311 .38301 L
.59832 .40586 L
F
0 g
.65311 .38301 m
.59832 .40586 L
s
.59832 .40586 m
.56409 .39234 L
s
1 g
.78725 .39168 m
.92064 .42413 L
.82545 .43143 L
F
0 g
.92064 .42413 m
.82545 .43143 L
s
.82545 .43143 m
.78725 .39168 L
s
1 g
.70488 .40811 m
.78725 .39168 L
.82545 .43143 L
F
0 g
.70488 .40811 m
.78725 .39168 L
s
.78725 .39168 m
.82545 .43143 L
s
1 g
.38709 .37449 m
.38385 .34185 L
.4389 .36263 L
F
0 g
.38385 .34185 m
.4389 .36263 L
s
.4389 .36263 m
.38709 .37449 L
s
1 g
.38709 .37449 m
.30635 .36206 L
.38385 .34185 L
F
0 g
.38709 .37449 m
.30635 .36206 L
s
.30635 .36206 m
.38385 .34185 L
s
1 g
.52688 .38461 m
.58377 .36623 L
.56409 .39234 L
F
0 g
.58377 .36623 m
.56409 .39234 L
s
.56409 .39234 m
.52688 .38461 L
s
1 g
.52688 .38461 m
.50819 .3594 L
.58377 .36623 L
F
0 g
.52688 .38461 m
.50819 .3594 L
s
.50819 .3594 m
.58377 .36623 L
s
1 g
.56409 .39234 m
.58377 .36623 L
.65311 .38301 L
F
0 g
.56409 .39234 m
.58377 .36623 L
s
.58377 .36623 m
.65311 .38301 L
s
1 g
.78725 .39168 m
.87133 .3749 L
.92064 .42413 L
F
0 g
.78725 .39168 m
.87133 .3749 L
s
.87133 .3749 m
.92064 .42413 L
s
1 g
.65311 .38301 m
.78725 .39168 L
.70488 .40811 L
F
0 g
.78725 .39168 m
.70488 .40811 L
s
.70488 .40811 m
.65311 .38301 L
s
1 g
.30635 .36206 m
.32739 .32053 L
.38385 .34185 L
F
0 g
.32739 .32053 m
.38385 .34185 L
s
.38385 .34185 m
.30635 .36206 L
s
1 g
.30635 .36206 m
.22437 .34945 L
.32739 .32053 L
F
0 g
.30635 .36206 m
.22437 .34945 L
s
.22437 .34945 m
.32739 .32053 L
s
1 g
.4389 .36263 m
.48891 .33341 L
.50819 .3594 L
F
0 g
.48891 .33341 m
.50819 .3594 L
s
.50819 .3594 m
.4389 .36263 L
s
1 g
.4389 .36263 m
.38385 .34185 L
.48891 .33341 L
F
0 g
.4389 .36263 m
.38385 .34185 L
s
.38385 .34185 m
.48891 .33341 L
s
1 g
.65311 .38301 m
.70949 .35951 L
.78725 .39168 L
F
0 g
.65311 .38301 m
.70949 .35951 L
s
.70949 .35951 m
.78725 .39168 L
s
1 g
.58377 .36623 m
.70949 .35951 L
.65311 .38301 L
F
0 g
.70949 .35951 m
.65311 .38301 L
s
.65311 .38301 m
.58377 .36623 L
s
1 g
.50819 .3594 m
.60409 .33926 L
.58377 .36623 L
F
0 g
.60409 .33926 m
.58377 .36623 L
s
.58377 .36623 m
.50819 .3594 L
s
1 g
.50819 .3594 m
.48891 .33341 L
.60409 .33926 L
F
0 g
.50819 .3594 m
.48891 .33341 L
s
.48891 .33341 m
.60409 .33926 L
s
1 g
.70949 .35951 m
.87133 .3749 L
.78725 .39168 L
F
0 g
.87133 .3749 m
.78725 .39168 L
s
.78725 .39168 m
.70949 .35951 L
s
1 g
.58377 .36623 m
.60409 .33926 L
.70949 .35951 L
F
0 g
.58377 .36623 m
.60409 .33926 L
s
.60409 .33926 m
.70949 .35951 L
s
1 g
.38385 .34185 m
.46901 .30657 L
.48891 .33341 L
F
0 g
.46901 .30657 m
.48891 .33341 L
s
.48891 .33341 m
.38385 .34185 L
s
1 g
.38385 .34185 m
.32739 .32053 L
.46901 .30657 L
F
0 g
.38385 .34185 m
.32739 .32053 L
s
.32739 .32053 m
.46901 .30657 L
s
1 g
.70949 .35951 m
.76751 .33531 L
.87133 .3749 L
F
0 g
.70949 .35951 m
.76751 .33531 L
s
.76751 .33531 m
.87133 .3749 L
s
1 g
.60409 .33926 m
.76751 .33531 L
.70949 .35951 L
F
0 g
.76751 .33531 m
.70949 .35951 L
s
.70949 .35951 m
.60409 .33926 L
s
1 g
.48891 .33341 m
.62509 .3114 L
.60409 .33926 L
F
0 g
.62509 .3114 m
.60409 .33926 L
s
.60409 .33926 m
.48891 .33341 L
s
1 g
.48891 .33341 m
.46901 .30657 L
.62509 .3114 L
F
0 g
.48891 .33341 m
.46901 .30657 L
s
.46901 .30657 m
.62509 .3114 L
s
1 g
.60409 .33926 m
.62509 .3114 L
.76751 .33531 L
F
0 g
.60409 .33926 m
.62509 .3114 L
s
.62509 .3114 m
.76751 .33531 L
s
gsave
.93901 .32888 -66.2813 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.563 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.96182 .30748 -65.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93984 .46164 -66.2813 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.563 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.9627 .44008 -65.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93817 .19668 -66.2813 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.563 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .17593 -68.9375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.375 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
74.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00P`3ooolJ000008<0oooo001k
0?ooo`P00000103oool00`000000oooo0?ooo`0C0?oooaT00000JP3oool007<0oooo2000000<0?oo
o`030000003oool0oooo02P0oooo00@000000?ooo`3oool0oooo1P00001T0?ooo`00J`3oool80000
01D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`070?ooo`H00000GP3oool006<0
oooo2000000N0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool03P3oool5000005T0
oooo001M0?ooo`H000009P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01@0oooo
1P00001C0?ooo`00FP3oool3000000<0oooo0P00000X0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool06P3oool6000004d0oooo001G0?ooo`<00000203oool2000002L0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`H00000A`3oool005@0oooo0`00000=0?oo
o`8000009@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02P0oooo100000130?oo
o`00D@3oool300000180oooo0`00000O0?oooaD000004@3oool00`000000oooo0?ooo`0X0?ooo`80
00000P3oool200000440oooo001>0?ooo`<00000603oool2000001<0oooo2P0000050?ooo`030000
003oool0oooo00d0oooo4`00000W0?ooo`8000001P3oool2000003l0oooo001;0?ooo`<000007@3o
ool2000000L0oooo2P00000?0?ooo`030000003oool0oooo01`0oooo00@000000?ooo`3oool0oooo
1@00000P0?ooo`8000002P3oool3000003`0oooo00180?ooo`<000008P3oool7000001X0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`D000006@3oool2000000l0oooo0P00
000j0?ooo`00A@3oool300000280oooo0`0000030?ooo`800000703oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00`0oooo1@00000B0?ooo`8000004`3oool2000003P0oooo00120?oo
o`<000008P3oool3000000P0oooo0P00000K0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool04P3oool5000000/0oooo0P00000G0?ooo`800000=P3oool00400oooo0`00000Q0?ooo`<0
00003@3oool2000001X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`D0
0000103oool2000001/0oooo0`00000c0?ooo`00?`3oool010000000oooo0?ooo`3oool6000001L0
oooo1000000B0?ooo`<000005`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01d0
oooo1000000P0?ooo`800000<@3oool003h0oooo00<000000?ooo`3oool0203oool6000000h0oooo
0`00000I0?ooo`8000004P3oool:00000140oooo00<000000?ooo`3oool07P3oool2000000030?oo
o`00000000000240oooo0P00000_0?ooo`00?03oool200000140oooo1P0000050?ooo`<000007P3o
ool2000000H0oooo2P0000050?ooo`030000003oool0oooo0080oooo2`0000060?ooo`030000003o
ool0oooo01`0oooo0P0000050?ooo`8000008@3oool3000002`0oooo000k0?ooo`030000003oool0
oooo01L0oooo1P00000R0?ooo`H000003`3oool00`000000oooo0?ooo`0=0?ooo`L00000703oool2
000000T0oooo0P00000R0?ooo`800000:P3oool003X0oooo00<000000?ooo`3oool06P3oool01000
0000oooo0?ooo`3oool6000001P0oooo100000030?ooo`8000004@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00@000005P3oool2000000d0oooo0P00000R0?ooo`800000:03oool0
03T0oooo00<000000?ooo`3oool06@3oool2000000X0oooo1P00000>0?ooo`@000002@3oool20000
0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`@00000403oool20000
0140oooo0P00000R0?ooo`8000009P3oool003P0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0@0?ooo`H00000103oool4000000l0oooo0P00000>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool02@3oool4000000X0oooo0P00000E0?ooo`800000703oool400000080
oooo00<000000?ooo`3oool08`3oool003L0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0G0?ooo`D00000503oool2000000d0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0>0?ooo`@00000103oool2000001T0oooo0P00000F0?ooo`@000001`3oool00`000000oooo
0?ooo`0R0?ooo`00=@3oool2000001/0oooo00<000000?ooo`3oool06@3oool010000000oooo0?oo
o`3oool600000100oooo0P00000<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
4P3oool4000001d0oooo0P00000@0?ooo`@00000303oool00`000000oooo0?ooo`0Q0?ooo`00=03o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01P0oooo0P00000:0?ooo`H00000303o
ool2000000X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`80000000<0
oooo0000000000007P3oool2000000X0oooo1000000@0?ooo`030000003oool0oooo0240oooo000c
0?ooo`030000003oool0oooo01T0oooo0P00000J0?ooo`030000003oool0oooo0100oooo1P000006
0?oooa000000203oool00`000000oooo0?ooo`0B0?ooo`8000001@3oool2000001h0oooo0P000004
0?ooo`@000005@3oool00`000000oooo0?ooo`0P0?ooo`00<P3oool>000000h0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`H000001@3oool2000000L0oooo00<000000?oo
o`000000100000030?ooo`030000003oool0oooo0100oooo0P0000090?ooo`8000007@3oool50000
01X0oooo00<000000?ooo`3oool07`3oool00400oooo6P00000>0?ooo`8000006`3oool00`000000
oooo0?ooo`0700000080oooo0`0000040?ooo`030000003oool0oooo00@0oooo1000000@0?ooo`80
00003@3oool2000001L0oooo100000030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool07P3oool005X0oooo6`00000>0?ooo`8000001`3oool:000000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`02000000`0oooo0P00000A0?ooo`800000403oool5000000P0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0M0?ooo`00M@3ooolJ000000<0oooo2000
00060?ooo`030000003oool0oooo0080oooo0`0000070?ooo`8000005@3oool2000000T0oooo1@00
000>0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0703oool008l0oooo30000004
0?ooo`030000003oool0oooo00H0oooo0P0000030?ooo`8000006@3oool2000000<0oooo1000000D
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool009/0oooo00@000000?oo
o`3oool000002`3oool3000001d0oooo0`00000I0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06P3oool009/0oooo00@000000?ooo`3oool000002@3oool200000080oooo00<00000
0?ooo`3oool05P3oool400000080oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01X0oooo002L0?ooo`800000203oool2000000D0oooo00<000000?oo
o`3oool04@3oool4000000H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01T0oooo002L0?ooo`8000001P3oool2000000P0oooo0P00000=0?ooo`@0
00002`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0603oool009`0oooo00<000000?ooo`3oool00`3oool2000000`0oooo00<000000?ooo`3oool0
1P3oool400000100oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01L0oooo002L0?ooo`040000003oool0oooo0?ooo`8000003`3oool010000000oooo
0?ooo`3oool4000001@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0D0?ooo`L0
0000603oool009`0oooo00@000000?ooo`0000000000403oool5000001T0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`050?ooo`h000001P3oool00`000000oooo0?ooo`0F0?ooo`00
W03oool2000000h0oooo100000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
5P3oool;000001@0oooo00<000000?ooo`3oool05P3oool009`0oooo00<000000?ooo`3oool02@3o
ool4000000L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0<0?ooo`T00000103o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00230?ooo`l000002P3oool0
0`000000oooo0?ooo`040?ooo`D00000303oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00<0oooo2@00000=0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3oool0
07/0oooo20000004002ZZP0300000000[Zh00:j^00P00:j^5P00000=0?ooo`030000003oool0oooo
01<0oooo2`00000F0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3oool007<0
oooo2000000<002ZZP0300000000[Zh00:j^01h00:j^3P0000070?ooo`h000001P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool006/0oooo
2000000E002ZZP0300000000[Zh00:j^02L00:j^00@00000002d]000];@00;Bd1`00000D0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0080oooo001S0?ooo`P000007P00ZZX00`0000000:j^002^[P0U002^[P030000
0000];@00;Bd00P00;Bd1P00000?0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo001M0?ooo`H000009P00
ZZX00`0000000:j^002^[P0U002^[P0300000000];@00;Bd00h00;Bd1@00000:0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0:0?ooo`@000001@3o
ool00`000000oooo0?ooo`020?ooo`00FP3oool3000000<00:b/0P00000X002ZZP0300000000[Zh0
0:j^02<00:j^00<00000002d]000];@05000];@6000000<0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool0
05H0oooo10000008002/[08000009`00ZZX00`0000000:j^002^[P0Q002^[P0300000000];@00;Bd
01/00;Bd1P00000H0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo000000040?ooo`00D`3oool3000000h00:b/0P00000U002ZZP0300000000[Zh00:j^0200
0:j^00<00000002d]000];@08P00];@600000180oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`030?ooo`<00000303oool2000000@0oooo001@0?ooo`<000004`00[:`3000001l00:ZZ
5@00000A002^[P0300000000];@00;Bd02P00;Bd1000000=0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3o
ool00P3oool004`0oooo1000000I002/[08000004`00ZZX:000000D00:NW00<00000002/[000[:`0
3@00[:`C000002P00;Bd0P000003002l_08000002`3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool004T0oooo0`00000O002/[08000001`00
ZZX:000000l00:NW00<00000002/[000[:`07000[:`0100000000;Fe002e]@00]KD5000002400;Bd
0P000007002l_0<00000203oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo
0`00000B0?ooo`00AP3oool3000002@00:b/1`00000J002WY`0300000000[:`00:b/01/00:b/00<0
0000002e]@00]KD01P00]KD5000001X00;Bd0P00000<002l_1D000003@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01<0oooo00120?ooo`@000008`00[:`4000000<00:VY0P00000L
002WY`0300000000[:`00:b/01X00:b/00<00000002e]@00]KD03000]KD5000001800;Bd0`00000@
002l_0<000000P3oool00`000000oooo0?ooo`0;0?ooo`h000001@3oool01@000000oooo0?ooo`3o
ool000000140oooo00100?ooo`<000008P00[:`4000000T00:VY0`00000J002WY`0300000000[:`0
0:b/01P00:b/00<00000002e]@00]KD04P00]KD5000000/00;Bd0P00000F002l_08000006P3oool0
0`000000oooo0?ooo`050?ooo`<000004P3oool003l0oooo00@00000002a/@00/K400;6a1P00000I
002/[0<000004000ZJT3000001P00:NW00<00000002/[000[:`05`00[:`00`0000000;Fe002e]@0G
002e]@D000001000];@2000001X00;bl0`00000F0?ooo`030000003oool0oooo01/0oooo000n0?oo
o`0300000000/K400;6a00P00;6a1P00000?002/[0@000005P00ZJT2000001H00:NW00<00000002/
[000[:`05P00[:`00`0000000;Fe002e]@0M002e]@@000007`00_;`200000180oooo0P00000N0?oo
o`00?03oool2000001400;6a1P000005002/[0@000007000ZJT3000000/00:NW3`00000A002/[003
00000000]KD00;Fe01h00;Fe0P000002002o_`8000007`00_;`3000000h0oooo00<000000?ooo`3o
ool07P3oool003/0oooo00<00000002a/@00/K405`00/K46000002800:VY2`00000:002PX0030000
0000Z:P00:RX00800:RX2`000006002/[00300000000]KD00;Fe01`00;Fe0P000006002o_`800000
8000_;`2000000/0oooo00<000000?ooo`3oool07`3oool003X0oooo00<00000002a/@00/K406P00
/K40100000000;2`002`/000/;06000001P00:VY10000003002SX`8000004000X:000`0000000:RX
002XZ00=002XZ0L000007000]KD2000000X00;no0P00000P002l_0<000001`3oool00`000000oooo
0?ooo`0P0?ooo`00>@3oool00`0000000;6a002a/@0I002a/@8000002P00/;06000000h00:VY1000
0009002SX`<000003P00X:000`0000000:RX002XZ00@002XZ00300000000][H00;Jf00@000005P00
]KD2000000h00;no0P00000Q002l_0800000103oool00`000000oooo0?ooo`0Q0?ooo`00>03oool0
0`0000000;6a002a/@0I002a/@0300000000/;000;2`01000;2`1P000004002YZ@@000004000Xj<2
000000d00:2P00<00000002XZ000Z:P03P00Z:P00`0000000;Jf002f]P05002f]P@000004000]KD2
000001800;no0`00000O002l_0D00000903oool003L0oooo00<00000002a/@00/K406@00/K400`00
00000;2`002`/00G002`/0D000005@00Xj<3000000/00:2P00<00000002XZ000Z:P03@00Z:P00`00
00000;Jf002f]P09002f]P@000002P00]KD2000001L00;no0P00000H002l_0D000000`00`l<00`00
0000oooo0?ooo`0S0?ooo`00=@3oool2000001/00;6a00<00000002`/000/;006000/;02000000<0
0:j^1P00000B002SX`8000002@00X:000`0000000:RX002XZ00<002XZ00300000000][H00;Jf00h0
0;Jf10000004002e]@8000006`00_kl2000001800;bl100000090033``030000003oool0oooo0280
oooo000d0?ooo`0300000000/K400;6a01X00;6a00<00000002`/000/;006000/;000`0000000:j^
002^[P09002^[PD000003`00Xj<6000000@00:2P00<00000002XZ000Z:P02P00Z:P00`0000000;Jf
002f]P0C002f]P@000007`00_kl2000000/00;bl1@00000>0033``030000003oool0oooo0240oooo
000c0?ooo`0300000000/K400;6a01T00;6a0P00000I002`/08000004@00[Zh6000000D00:>S1000
0003002?S`80000000<008N70000000000001P000008002XZ00300000000][H00;Jf01<00;Jf0P00
00030034a08000007`00_kl2000000@00;bl1@00000D0033``030000003oool0oooo0200oooo000b
0?ooo`h000003P00/K400`0000000;2`002`/00G002`/08000006@00[Zh6000000P008n?0`000004
0027Q`0300000000Vi/0000000@000000`00Z:P00`0000000;Jf002f]P0A002f]P8000001`00a<@2
000001h00;no1@00000J0033``030000003oool0oooo01l0oooo000b0?ooo`030000003oool0oooo
00/0oooo=@00000>002^[P8000001000YjL8000000<008n?0P0000020027Q`0300000000Vi/009^K
00@009^K1000000A002f]P8000002`00a<@2000001P00;no100000030037a`0300000000`l<00<?3
01X00<?300<000000?ooo`3oool07P3oool00380oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo6P000002002WY`T000001P00Vi/00`000000
0;Rh002h^002000000`00;Jf0`00000?0034a08000004@00_kl5000000P00<O700<000000033``00
`l<06P00`l<00`000000oooo0?ooo`0M0?ooo`00<P3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0:0?ooo``00000
1@00Vi/00`0000000;Rh002h^002002h^0<000001`00][H2000001@00<C40P00000:002o_`D00000
3P00alL00`0000000<?30033``0I0033``030000003oool0oooo01d0oooo000c0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00@0oooo3P0000000`3oool0000000000002000000<009^K00<00000002h^000^;P01P00
^;P2000000<00;Jf0P00000H0034a08000001000_kl4000001@00<O700<000000033``00`l<06@00
`l<00`000000oooo0?ooo`0L0?ooo`00<`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool04@3ooolB000000<0oooo0P0000020?ooo`@000000P3oool0
1000000009^K002KV`00000;002h^0<000007000a<@4000001T00<O700<000000033``00`l<06@00
`l<00`000000oooo0?ooo`0K0?ooo`00<`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0103oool=000000P0oooo1P0000050?ooo`H0000000<0oooo
0000003oool0103oool00`00000009^K00000009002h^08000000P00cll2000001H00<C410000003
003?c`0300000000alL00<O701P00<O700<000000033``00`l<06P00`l<00`000000oooo0?ooo`0J
0?ooo`00<`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo3@00000A0?oo
o`@000001P3oool6000000D0oooo00<000000?ooo`3oool0103oool2000000P00;Rh0P000006003?
c`0300000000a<@00<C400h00<C41@000008003?c`0300000000alL00<O701P00<O700<000000033
``00`l<06P00`l<00`000000oooo0?ooo`0I0?ooo`00<`3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00@0oooo3@0000070?ooo`8000004@3oool4000000X0oooo0P0000090?ooo`03
0000003oool0oooo00@0oooo0P000006002h^08000002@00cll2000000T00<C41@00000=003?c`03
00000000alL00<O701T00<O700<000000033``00`l<06P00`l<00`000000oooo0?ooo`0H0?ooo`00
<`3oool00`000000oooo0?ooo`0D0?ooo`/000005P3oool2000000X0oooo1@00000<0?ooo`800000
2P3oool00`000000oooo0?ooo`050?ooo`0300000000^;P00;Rh00<00;Rh0P00000=003?c`800000
0`00a<@4000001<00<o?00<000000037a`00alL06@00alL00`0000000<?30033``0J0033``030000
003oool0oooo01L0oooo000d0?ooo`030000003oool0oooo00/0oooo200000050?ooo`800000703o
ool2000000@0oooo1000000>0?ooo`<000002`3oool00`000000oooo0?ooo`060?ooo`0400000000
^;P00;Rh002h^08000003`00cll5000001P00<o?00<000000037a`00alL06@00alL00`0000000<?3
0033``0D0033``L00000603oool003@0oooo00<000000?ooo`3oool00P3oool9000000l0oooo0P00
000K0?ooo`H000003`3oool2000000d0oooo00<000000?ooo`3oool0103oool400000003002h^000
0000000000d00<o?10000002003Lg00300000000cll00<o?01T00<o?00<000000037a`00alL06@00
alL00`0000000<?30033``050033``h000001P00alL00`000000oooo0?ooo`0F0?ooo`00=03oool5
000001X0oooo0P00000E0?ooo`@000001P3oool8000000D0oooo0P00000?0?ooo`030000003oool0
000000@000000`3oool2000000X00<o?1@000007003Lg00300000000cll00<o?01P00<o?00<00000
0037a`00alL05000alL=000001@00<O700<000000?ooo`3oool05P3oool003D0oooo0P00000N0?oo
o`8000003`3oool400000180oooo600000080?ooo`0300000000cll00<o?00@00<o?1@00000<003L
g00300000000cll00<o?01T00<o?00<000000037a`00alL01@00alL>000000H00<c<00<000000037
a`00alL05`00alL00`000000oooo0?ooo`0G0?ooo`00=`3oool2000001h0oooo0P0000090?ooo`@0
00005`3oool200000140oooo00<000000?ooo`3oool02@3oool00`0000000<o?003?c`0400000180
0=cL00<00000003?c`00cll05@00cll;000001@00<c<00<000000037a`00alL05`00alL00`000000
oooo0?ooo`080?ooo`<00000303oool003T0oooo0P00000N0?ooo`8000000`3oool4000001T0oooo
0P00000C0?ooo`030000003oool0oooo00T0oooo0`00000F003Lg00300000000cll00<o?00`00<o?
2@000004003De00300000000c<`00<c<01P00<c<00<000000037a`00alL05`00alL00`000000oooo
0?ooo`070?ooo`050000003oool0oooo0?ooo`0000002`3oool003/0oooo0P00000L0?ooo`D00000
6`3oool2000000L0oooo4000000:0?ooo`0300000000g=`00=cL01L00=cL00<00000003?c`00cll0
0P00cll9000000d00=CD00<00000003<c000c<`05`00c<`00`0000000<O70037a`0H0037a`030000
003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`00?@3oool2000001H0oooo
100000050?ooo`H000004`3oool;000000D0oooo00<000000?ooo`3oool0203ooolF000000P00=cL
2`00000F003De00300000000c<`00<c<01L00<c<00<000000037a`00alL06000alL00`000000oooo
0?ooo`070?ooo`050000003oool0oooo0?ooo`0000002`3oool003l0oooo0P00000@0?ooo`@00000
3`3oool5000000D0oooo2P00000?0?ooo`030000003oool0oooo01h0oooo3`00000J003De0030000
0000c<`00<c<01L00<c<00<000000037a`00alL05`00alL00`000000oooo0?ooo`080?ooo`050000
003oool0oooo0?ooo`0000002`3oool00440oooo0P00000:0?ooo`@000004`3oool:000001X0oooo
00<000000?ooo`3oool09`3oool010000000oooo0?ooo`3oool6000001@00=CD00<00000003<c000
c<`06000c<`00`0000000<O70037a`0G0037a`030000003oool0oooo00P0oooo00D000000?ooo`3o
ool0oooo0000000;0?ooo`00@`3oool2000000@0oooo1000000@0?ooo`L000009@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo1P00000>003De00300000000c<`00<c<01P0
0<c<00<000000037a`00alL05`00alL00`000000oooo0?ooo`030?ooo`<000000`3oool3000000`0
oooo00150?ooo`@000004@3oool3000000<0oooo0P00000X0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool03P3oool6000000P00=CD00<00000003<c000c<`06000c<`00`0000000<O7
0037a`0G0037a`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000A0?ooo`00
B@3oool6000000L0oooo100000080?ooo`<000009@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo01D0oooo1P000002003De00300000000c<`00<c<01L00<c<00<000000037a`00alL0
6000alL00`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo001?0?ooo`L000003`3o
ool3000002<0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0L0?ooo`H000005P00
c<`00`0000000<O70037a`0H0037a`030000003oool0oooo00<0oooo0`00000B0?ooo`00D03oool3
000001D0oooo0P00000K0?oooa0000006@3oool00`000000oooo0?ooo`0S0?ooo`T000003@00c<`0
0`0000000<O70037a`0G0037a`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool0
04`0oooo1000000J0?ooo`<000002@3oool?000000P0oooo00<000000?ooo`3oool01@3oool@0000
00T0oooo00<000000?ooo`3oool0:@3ooolM000000d00<O700<000000?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool000000140oooo00190?ooo`<000008@3oool9000001L0oooo00<000000?oo
o`3oool05@3oool;000002P0oooo0`0000030?ooo`8000002@00cLd00`0000000<O70037a`0;0037
a`h000001P3oool300000180oooo00160?ooo`<00000803oool4000000<0oooo0P00000L0?ooo`03
0000003oool0oooo01/0oooo00@000000?ooo`3oool0oooo1P00000O0?ooo`<00000203oool30000
00D00<g=00<000000037a`00alL06000alL00`000000oooo0?ooo`0J0?ooo`00@P3oool4000001l0
oooo100000090?ooo`<000006P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00P0
oooo1P00000G0?ooo`8000003P3oool300000003003=c@0000000<O701P00<O70P00000M0?ooo`00
@03oool4000001h0oooo0`00000@0?ooo`<00000603oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00l0oooo1P00000>0?ooo`<000004`3oool2000001P00<O700<000000?ooo`3oool0
7@3oool003h0oooo0P0000040?ooo`P000004P3oool4000001H0oooo0P00000F0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool05@3oool6000000D0oooo0`00000H0?ooo`<000005000
alL00`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0<0?ooo`P000001P3oool4
000001`0oooo0`00000;0?ooo`l000004P3oool00`000000oooo0?ooo`0L0?ooo`D000007P3oool3
000000l00<O70P00000Q0?ooo`00?03oool00`000000oooo0?ooo`0E0?ooo`L000008P3oool;0000
00X0oooo00<000000?ooo`3oool00P3oool;000000H0oooo00<000000?ooo`3oool07@3oool20000
00<0oooo0P00000O0?ooo`8000003000alL00`000000oooo0?ooo`0Q0?ooo`00>P3oool2000001X0
oooo0P0000030?ooo`H00000603oool4000000<0oooo0P00000@0?ooo`030000003oool0oooo00d0
oooo1`00000M0?ooo`8000001`3oool2000001l0oooo0`0000080037a`030000003oool0oooo0280
oooo000i0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool6000000h0oooo
100000090?ooo`<000003P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@00000
5`3oool2000000/0oooo0P00000P0?ooo`<000001000alL00`000000oooo0?ooo`0S0?ooo`00=`3o
ool2000001/0oooo00<000000?ooo`3oool0403oool6000000@0oooo1000000@0?ooo`8000003@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo1000000@0?ooo`<000003`3o
ool200000240oooo1000000V0?ooo`00=P3oool00`000000oooo0?ooo`0I0?ooo`8000006@3oool6
000001@0oooo0`00000;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool4
000000X0oooo0P00000D0?ooo`<000007`3oool3000002H0oooo000e0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool06@3oool2000000@0oooo1`00000@0?ooo`8000002@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00h0oooo100000040?ooo`8000006@3oool20000
01P0oooo1@0000030?ooo`030000003oool0oooo02<0oooo000c0?ooo`8000006`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo200000080?ooo`P00000103oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo01<0oooo1000000M0?ooo`8000004P3oool4000000T0
oooo00<000000?ooo`3oool08P3oool00380oooo3P00000>0?ooo`8000006P3oool2000001H0oooo
200000050?ooo`80000000<0oooo0000000000001P0000080?ooo`030000003oool0oooo01<0oooo
0P0000030?ooo`8000007@3oool2000000/0oooo1@00000>0?ooo`030000003oool0oooo0240oooo
000b0?ooo`0300000000ZJT00:VY00/00:VY6P00000>0?ooo`8000006P3oool010000000oooo0?oo
o`3oool6000000<0oooo0`0000040?ooo`030000003oool0000000@000000`3oool00`000000oooo
0?ooo`0A0?ooo`8000001`3oool2000001d0oooo0P0000040?ooo`D00000503oool00`000000oooo
0?ooo`0P0?ooo`00<P3oool00`0000000:VY002YZ@0H002YZ@0300000000Z:P00:RX00X00:RX6`00
000>0?ooo`030000003oool0oooo00H0oooo2P0000020?ooo`030000003oool0oooo00@0oooo1000
000A0?ooo`8000002`3oool2000001`0oooo1@00000J0?ooo`030000003oool0oooo01l0oooo000c
0?ooo`0300000000ZJT00:VY01L00:VY00<00000002XZ000Z:P05`00Z:P00`0000000:JV002VYP0;
002VYRD000001P3oool00`000000oooo0?ooo`02000000`0oooo0`00000?0?ooo`800000503oool6
000000<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0N0?ooo`00<`3oool00`00
00000:VY002YZ@0G002YZ@0300000000Z:P00:RX01L00:RX00<00000002VYP00YZH06000YZH00`00
000009nO002OW`04002OW`h0000000@00::R00000000000000001@3oool00`000000oooo0?ooo`02
0?ooo`<000001`3oool2000001@0oooo0P00000<0?ooo`H000002P3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01d0oooo000c0?ooo`0300000000ZJT00:VY01L00:VY00<00000002X
Z000Z:P06000Z:P00`0000000:JV002VYP0A002VYQD000000P00XZ86000000800;Zj00D000000?oo
o`3oool0oooo000000080?ooo`8000000`3oool2000001P0oooo0P0000040?ooo`H000004@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01`0oooo000c0?ooo`0300000000ZJT00:VY
01P00:VY00<00000002XZ000Z:P05`00Z:P00`0000000:JV002VYP04002VYPd000002000W9`?0000
00<00:RX00<00000002j^P00^[X00P00^[X2000000030?ooo`000000oooo00X0oooo0`00000L0?oo
o`@00000603oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo000c0?ooo`03
00000000ZJT00:VY01P00:VY00<00000002XZ000Z:P04@00Z:P=0000014009bL10000007002LW080
00002000Z:P00`0000000;Zj002j^P04002j^P8000002P3oool200000080oooo0P00000F0?ooo`@0
00000`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool06P3oool003<0oooo00<00000002YZ@00ZJT06000ZJT00`0000000:RX002XZ004002XZ0d00000
1`00XZ820000014009bL10000009002LW08000002@00Z:P00`0000000;Zj002j^P05002j^P800000
1`3oool3000000H0oooo00<000000?ooo`3oool03P3oool5000000P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo000d0?ooo`0300000000
ZJT00:VY01400:VY3@00000F002RXP8000002P00W9`5000000/009bL0P00000;002XZ00300000000
^[X00;Zj00D00;Zj00<000000?ooo`3oool0103oool2000000X0oooo0P0000090?ooo`D000003@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0603o
ool003@0oooo00<00000002YZ@00ZJT01000ZJT=000000P00:FU0P00000K002RXP8000001000W9`4
000000h009bL0P00000<002XZ00300000000^[X00;Zj00<00;Zj100000030?ooo`<000003P3oool2
000000<0oooo1000000C0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0G0?ooo`00=03oool7000001L00:FU0P00000J002RXPH000003`00W9`20000
00d00:RX00<00000002j^P00000010000003002f]P040000003oool0000000000140oooo1@00000H
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0503oool7000001P0oooo000e0?oo
o`8000007@00YJD2000001<00::R1@000006002SX`P000001@00W9`2000000H00:RX2`000008002f
]P8000003`3oool400000080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00D0oooo3P0000060?ooo`030000003oool0oooo01H0oooo000g0?ooo`80
00007@00YJD2000000/00::R1P00000C002SX`d000001`00ZZX00`0000000;Jf002f]P09002f]P03
0000003oool0oooo00T0oooo1@0000070?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0503oool=000001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`00
>@3oool2000001d00:FU0P000004002RXPD000006@00Xj<2000001800:ZZ00<00000002f]P00][H0
2@00][H00`000000oooo0?ooo`040?ooo`D00000303oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00D0oooo3P0000060?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`00>`3oool2000001`00:FU1@00000L002SX`8000004`00
ZZX00`0000000;Jf002f]P0:002f]P030000003oool0oooo00@000004P3oool00`000000oooo0?oo
o`0C0?ooo`d00000503oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02@3oool003d0oooo0P00000F002UY@@000001@00YJD6000001<00:>S0`00000D
002ZZP0300000000][H00;Jf00/00;Jf0`00000F0?ooo`030000003oool0oooo00D0oooo3P000006
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00T0oooo000o0?ooo`8000004000YJD4000000l00:FU1@00000<002S
X`8000005P00ZZX00`0000000;Jf002f]P08002f]PD000004`3oool=000001@0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`0000002`3oool00440oooo0P00000:002UY@@000006000YJD6000000@00:>S0P00000H002ZZP03
00000000][H00;Jf00P000001000];@00`000000oooo0?ooo`040?ooo`d000001P3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0:0?ooo`8000002`3oool004<0oooo0P000004002UY@@000008P00YJDQ000000`00;Bd
1`00000C0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00<0oooo0`0000050?ooo`030000003oool0oooo00T0oooo
00150?ooo`D000008`00YJD3000001/00:^[00<00000002d]000];@03P00];@00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000@0?ooo`00BP3o
ool7000001X00:FU0P00000N002[Z`0300000000];@00;Bd00h00;Bd00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo001A0?ooo`P000003`00YJD3
000001l00:^[00<00000002d]000];@03`00];@00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00<0oooo0`00000A0?ooo`00F@3oool7000000D00:FU0`00000Q002[Z`0300000000];@00;Bd
00/00;Bd4P00000=0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3oool00600
oooo5P00000C002[Z`0400000000];@00;Bd002d]0X000001@3oool00`000000oooo0?ooo`0:0?oo
ocD000003@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo0000000@0?ooo`00MP3ooolG000000l0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00`0oooo6P00000=0?ooo`030000003oool0oooo
00@0oooo0`00000A0?ooo`00W03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0;0?ooo`h000006P3oool009`0oooo
1000000D0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0603oool2000001T0oooo
0P00000K0?ooo`00W03oool010000000oooo0?ooo`3oool7000000`0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
6`3oool009`0oooo00<000000?ooo`3oool0203oool8000000@0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0703o
ool009`0oooo00<000000?ooo`3oool0403oool7000001D0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0G0?ooo`8000007`3oool009`0oooo0P00000C0?ooo`030000003oool0oooo
0080oooo1`00000=0?ooo`030000003oool0oooo01H0oooo0P00000I0?ooo`030000003oool0oooo
01l0oooo002L0?ooo`030000003oool00000008000003`3oool00`000000oooo0?ooo`0:0?ooo`P0
0000103oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0803oool009`0oooo00<000000?ooo`3oool00P3oool3000000X0oooo0P00000E0?ooo`L00000
5@3oool00`000000oooo0?ooo`0G0?ooo`8000008`3oool009`0oooo00<000000?ooo`3oool01@3o
ool3000000H0oooo00<000000?ooo`3oool05P3oool2000000@0oooo1`00000<0?ooo`8000006@3o
ool00`000000oooo0?ooo`0S0?ooo`00W03oool2000000T0oooo0`0000020?ooo`030000003oool0
oooo01D0oooo0P00000=0?ooo`L00000103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo02@0oooo002L0?ooo`030000003oool0000000/0oooo0`00000E0?ooo`8000005P3oool60000
01L0oooo0P00000W0?ooo`00W03oool00`000000oooo000000090?ooo`8000000`3oool300000100
oooo0P00000H0?ooo`800000103oool500000140oooo00<000000?ooo`3oool09`3oool009`0oooo
00@000000?ooo`3oool000001@3oool3000000P0oooo0P00000<0?ooo`800000603oool2000000/0
oooo1P00000:0?ooo`030000003oool0oooo02P0oooo002L0?ooo`050000003oool0oooo0?ooo`00
00000P3oool2000000d0oooo0`0000070?ooo`800000603oool2000001<0oooo1@0000030?ooo`80
0000:`3oool00380oooo3@00001L0?ooo`8000000`3oool300000180oooo0`0000020?ooo`800000
603oool2000001X0oooo0`00000]0?ooo`00<P3oool00`000000oooo0?ooo`0:0?oooa/00000@03o
ool3000000030?ooo`00000000000080oooo00<000000?ooo`3oool04`3oool3000001H0oooo0`00
000J0?ooo`<00000;`3oool00380oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;
0?ooocD000001`3oool8000000@0oooo00<000000?ooo`3oool0403oool3000000<0oooo0`00000A
0?ooo`8000006`3oool200000380oooo000c0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo500000060?oo
o`030000003oool0oooo00`0oooo0`0000090?ooo`8000003@3oool2000001X0oooo0`00000d0?oo
o`00<`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool04P3oool?00000080oooo1@0000000`3oool0000000000004000000/0oooo00<000000?ooo`3o
ool01`3oool4000000h0oooo0`0000080?ooo`8000006@3oool3000003L0oooo000c0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`d00000
1`3oool2000000@0oooo2P0000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0`3oool3000001D0oooo0`0000030?ooo`8000006@3oool2000003X0oooo000c0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool04P3oool=000001H0oooo1`0000090?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`00000K0?ooo`<00000603oool3000003`0oooo000c
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool=000000L0oooo0P00000C
0?ooo`H00000103oool2000000X0oooo00<000000?ooo`3oool0303oool5000001X0oooo10000003
0?ooo`8000004`3oool3000003l0oooo000d0?ooo`030000003oool0oooo0140oooo3@00000F0?oo
o`800000303oool5000000L0oooo0`00000;0?ooo`030000003oool0oooo00H0oooo1`0000040?oo
o`030000003oool0oooo01@0oooo100000090?ooo`<000003@3oool300000480oooo000d0?ooo`03
0000003oool0oooo00@0oooo3@0000070?ooo`800000703oool2000000@0oooo1P00000:0?ooo`80
00003@3oool00`000000oooo0?ooo`07000000`0oooo00<000000?ooo`3oool03`3oool400000100
oooo0`0000080?ooo`800000A@3oool003@0oooo1`00000F0?ooo`8000006`3oool:000000T0oooo
0P0000060?ooo``000004`3oool00`000000oooo0?ooo`0;0?ooo`@000005`3oool2000000<0oooo
0`0000170?ooo`00=P3oool2000001/0oooo0P00000C0?ooo`H000002P3ooolA000000L0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`060?ooo`@00000703oool4000004X0oooo000h
0?ooo`8000006`3oool2000000`0oooo1@00000D0?ooo`8000004@3oool00`000000oooo0?ooo`0H
0?ooo`040000003oool0oooo0?ooo`@00000703oool4000004h0oooo000j0?ooo`8000006`3oool2
000000@0oooo1P00000G0?ooo`8000004P3oool00`000000oooo0?ooo`0E0?ooo`P000006`3oool5
00000580oooo000l0?ooo`<000006@3oool6000001T0oooo0`00000D0?ooo`030000003oool0oooo
00/0oooo2P0000060?ooo`030000003oool0oooo01D0oooo1@00001G0?ooo`00?`3oool200000180
oooo1@0000060?ooo`P000003`3oool2000001H0oooo00<000000?ooo`3oool00P3oool:00000100
oooo00<000000?ooo`3oool04@3oool4000005`0oooo00110?ooo`8000002`3oool5000001<0oooo
200000050?ooo`8000002P3ooolC000001/0oooo00<000000?ooo`3oool02`3oool500000600oooo
00130?ooo`800000103oool500000200oooo4@00000<0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool01@3oool5000006D0oooo00150?ooo`D000008`3oool3000001/0oooo00<00000
0?ooo`3oool0803oool010000000oooo0?ooo`3oool4000006X0oooo001:0?ooo`L000006P3oool2
000001d0oooo00<000000?ooo`3oool0703oool9000006h0oooo001A0?ooo`P000003`3oool30000
01h0oooo00<000000?ooo`3oool0403oool=000007L0oooo001I0?ooo`L000001@3oool300000240
oooo00<000000?ooo`3oool00`3oool=000008@0oooo001P0?ooobl00000T@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0, 0, 0, 0}}],
  StyleBox["     ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.468085 0.212766 0.290201 0.0289483 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .2902 m
1 .2902 L
s
.46809 0 m
.46809 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
0 .2902 m
.12121 .2902 L
.29703 .2902 L
.46608 .2902 L
.64609 .2902 L
.81933 .2902 L
s
.81933 .2902 m
1 .2902 L
s
0 1 1 r
.89362 .38114 m
.04255 .38114 L
.04255 .19926 L
.89362 .19926 L
.89362 .38114 L
F
0 g
.04255 .19926 m
.04255 .20664 L
.04255 .21468 L
.04255 .22224 L
.04255 .22951 L
.04255 .23724 L
.04255 .24469 L
.04255 .25261 L
.04255 .26023 L
.04255 .26757 L
.04255 .27537 L
.04255 .28289 L
.04255 .29011 L
.04255 .29781 L
.04255 .30521 L
.04255 .31309 L
.04255 .32067 L
.04255 .32796 L
.04255 .33573 L
.04255 .3432 L
.04255 .35114 L
.04255 .35879 L
.04255 .36616 L
.04255 .37399 L
.04255 .38114 L
s
.14894 .19926 m
.14894 .20664 L
.14894 .21468 L
.14894 .22224 L
.14894 .22951 L
.14894 .23724 L
.14894 .24469 L
.14894 .25261 L
.14894 .26023 L
.14894 .26757 L
.14894 .27537 L
.14894 .28289 L
.14894 .29011 L
.14894 .29781 L
.14894 .30521 L
.14894 .31309 L
.14894 .32067 L
.14894 .32796 L
.14894 .33573 L
.14894 .3432 L
.14894 .35114 L
.14894 .35879 L
.14894 .36616 L
.14894 .37399 L
.14894 .38114 L
s
.25532 .19926 m
.25532 .20664 L
.25532 .21468 L
.25532 .22224 L
.25532 .22951 L
.25532 .23724 L
.25532 .24469 L
.25532 .25261 L
.25532 .26023 L
.25532 .26757 L
.25532 .27537 L
.25532 .28289 L
.25532 .29011 L
.25532 .29781 L
.25532 .30521 L
.25532 .31309 L
.25532 .32067 L
.25532 .32796 L
.25532 .33573 L
.25532 .3432 L
.25532 .35114 L
.25532 .35879 L
.25532 .36616 L
.25532 .37399 L
.25532 .38114 L
s
.3617 .19926 m
.3617 .20664 L
.3617 .21468 L
.3617 .22224 L
.3617 .22951 L
.3617 .23724 L
.3617 .24469 L
.3617 .25261 L
.3617 .26023 L
.3617 .26757 L
.3617 .27537 L
.3617 .28289 L
.3617 .29011 L
.3617 .29781 L
.3617 .30521 L
.3617 .31309 L
.3617 .32067 L
.3617 .32796 L
.3617 .33573 L
.3617 .3432 L
.3617 .35114 L
.3617 .35879 L
.3617 .36616 L
.3617 .37399 L
.3617 .38114 L
s
.46809 .19926 m
.46809 .20664 L
.46809 .21468 L
.46809 .22224 L
.46809 .22951 L
.46809 .23724 L
.46809 .24469 L
.46809 .25261 L
.46809 .26023 L
.46809 .26757 L
.46809 .27537 L
.46809 .28289 L
.46809 .29011 L
.46809 .29781 L
.46809 .30521 L
.46809 .31309 L
.46809 .32067 L
.46809 .32796 L
.46809 .33573 L
.46809 .3432 L
.46809 .35114 L
.46809 .35879 L
.46809 .36616 L
.46809 .37399 L
.46809 .38114 L
s
.57447 .19926 m
.57447 .20664 L
.57447 .21468 L
.57447 .22224 L
.57447 .22951 L
.57447 .23724 L
.57447 .24469 L
.57447 .25261 L
.57447 .26023 L
.57447 .26757 L
.57447 .27537 L
.57447 .28289 L
.57447 .29011 L
.57447 .29781 L
.57447 .30521 L
.57447 .31309 L
.57447 .32067 L
.57447 .32796 L
.57447 .33573 L
.57447 .3432 L
.57447 .35114 L
.57447 .35879 L
.57447 .36616 L
.57447 .37399 L
.57447 .38114 L
s
.68085 .19926 m
.68085 .20664 L
.68085 .21468 L
.68085 .22224 L
.68085 .22951 L
.68085 .23724 L
.68085 .24469 L
.68085 .25261 L
.68085 .26023 L
.68085 .26757 L
.68085 .27537 L
.68085 .28289 L
.68085 .29011 L
.68085 .29781 L
.68085 .30521 L
.68085 .31309 L
.68085 .32067 L
.68085 .32796 L
.68085 .33573 L
.68085 .3432 L
.68085 .35114 L
.68085 .35879 L
.68085 .36616 L
.68085 .37399 L
.68085 .38114 L
s
.78723 .19926 m
.78723 .20664 L
.78723 .21468 L
.78723 .22224 L
.78723 .22951 L
.78723 .23724 L
.78723 .24469 L
.78723 .25261 L
.78723 .26023 L
.78723 .26757 L
.78723 .27537 L
.78723 .28289 L
.78723 .29011 L
.78723 .29781 L
.78723 .30521 L
.78723 .31309 L
.78723 .32067 L
.78723 .32796 L
.78723 .33573 L
.78723 .3432 L
.78723 .35114 L
.78723 .35879 L
.78723 .36616 L
.78723 .37399 L
.78723 .38114 L
s
.89362 .19926 m
.89362 .20664 L
.89362 .21468 L
.89362 .22224 L
.89362 .22951 L
.89362 .23724 L
.89362 .24469 L
.89362 .25261 L
.89362 .26023 L
.89362 .26757 L
.89362 .27537 L
.89362 .28289 L
.89362 .29011 L
.89362 .29781 L
.89362 .30521 L
.89362 .31309 L
.89362 .32067 L
.89362 .32796 L
.89362 .33573 L
.89362 .3432 L
.89362 .35114 L
.89362 .35879 L
.89362 .36616 L
.89362 .37399 L
.89362 .38114 L
s
.04255 .19926 m
.07708 .19926 L
.11473 .19926 L
.15009 .19926 L
.1841 .19926 L
.2203 .19926 L
.25514 .19926 L
.29218 .19926 L
.32786 .19926 L
.36219 .19926 L
.39871 .19926 L
.43387 .19926 L
.46768 .19926 L
.50369 .19926 L
.53833 .19926 L
.57517 .19926 L
.61066 .19926 L
.64479 .19926 L
.68111 .19926 L
.71607 .19926 L
.75323 .19926 L
.78904 .19926 L
.82349 .19926 L
.86013 .19926 L
.89362 .19926 L
s
.04255 .22199 m
.07708 .22199 L
.11473 .22199 L
.15009 .22199 L
.1841 .22199 L
.2203 .22199 L
.25514 .22199 L
.29218 .22199 L
.32786 .22199 L
.36219 .22199 L
.39871 .22199 L
.43387 .22199 L
.46768 .22199 L
.50369 .22199 L
.53833 .22199 L
.57517 .22199 L
.61066 .22199 L
.64479 .22199 L
.68111 .22199 L
.71607 .22199 L
.75323 .22199 L
.78904 .22199 L
.82349 .22199 L
.86013 .22199 L
.89362 .22199 L
s
.04255 .24473 m
.07708 .24473 L
.11473 .24473 L
.15009 .24473 L
.1841 .24473 L
.2203 .24473 L
.25514 .24473 L
.29218 .24473 L
.32786 .24473 L
.36219 .24473 L
.39871 .24473 L
.43387 .24473 L
.46768 .24473 L
.50369 .24473 L
.53833 .24473 L
.57517 .24473 L
.61066 .24473 L
.64479 .24473 L
.68111 .24473 L
.71607 .24473 L
.75323 .24473 L
.78904 .24473 L
.82349 .24473 L
.86013 .24473 L
.89362 .24473 L
s
.04255 .26746 m
.07708 .26746 L
.11473 .26746 L
.15009 .26746 L
.1841 .26746 L
.2203 .26746 L
.25514 .26746 L
.29218 .26746 L
.32786 .26746 L
.36219 .26746 L
.39871 .26746 L
.43387 .26746 L
.46768 .26746 L
.50369 .26746 L
.53833 .26746 L
.57517 .26746 L
.61066 .26746 L
.64479 .26746 L
.68111 .26746 L
.71607 .26746 L
.75323 .26746 L
.78904 .26746 L
.82349 .26746 L
.86013 .26746 L
.89362 .26746 L
s
.04255 .2902 m
.07708 .2902 L
.11473 .2902 L
.15009 .2902 L
.1841 .2902 L
.2203 .2902 L
.25514 .2902 L
.29218 .2902 L
.32786 .2902 L
.36219 .2902 L
.39871 .2902 L
.43387 .2902 L
.46768 .2902 L
.50369 .2902 L
.53833 .2902 L
.57517 .2902 L
.61066 .2902 L
.64479 .2902 L
.68111 .2902 L
.71607 .2902 L
.75323 .2902 L
.78904 .2902 L
.82349 .2902 L
.86013 .2902 L
.89362 .2902 L
s
.04255 .31294 m
.07708 .31294 L
.11473 .31294 L
.15009 .31294 L
.1841 .31294 L
.2203 .31294 L
.25514 .31294 L
.29218 .31294 L
.32786 .31294 L
.36219 .31294 L
.39871 .31294 L
.43387 .31294 L
.46768 .31294 L
.50369 .31294 L
.53833 .31294 L
.57517 .31294 L
.61066 .31294 L
.64479 .31294 L
.68111 .31294 L
.71607 .31294 L
.75323 .31294 L
.78904 .31294 L
.82349 .31294 L
.86013 .31294 L
.89362 .31294 L
s
.04255 .33567 m
.07708 .33567 L
.11473 .33567 L
.15009 .33567 L
.1841 .33567 L
.2203 .33567 L
.25514 .33567 L
.29218 .33567 L
.32786 .33567 L
.36219 .33567 L
.39871 .33567 L
.43387 .33567 L
.46768 .33567 L
.50369 .33567 L
.53833 .33567 L
.57517 .33567 L
.61066 .33567 L
.64479 .33567 L
.68111 .33567 L
.71607 .33567 L
.75323 .33567 L
.78904 .33567 L
.82349 .33567 L
.86013 .33567 L
.89362 .33567 L
s
.04255 .35841 m
.07708 .35841 L
.11473 .35841 L
.15009 .35841 L
.1841 .35841 L
.2203 .35841 L
.25514 .35841 L
.29218 .35841 L
.32786 .35841 L
.36219 .35841 L
.39871 .35841 L
.43387 .35841 L
.46768 .35841 L
.50369 .35841 L
.53833 .35841 L
.57517 .35841 L
.61066 .35841 L
.64479 .35841 L
.68111 .35841 L
.71607 .35841 L
.75323 .35841 L
.78904 .35841 L
.82349 .35841 L
.86013 .35841 L
.89362 .35841 L
s
.04255 .38114 m
.07708 .38114 L
.11473 .38114 L
.15009 .38114 L
.1841 .38114 L
.2203 .38114 L
.25514 .38114 L
.29218 .38114 L
.32786 .38114 L
.36219 .38114 L
.39871 .38114 L
.43387 .38114 L
.46768 .38114 L
.50369 .38114 L
.53833 .38114 L
.57517 .38114 L
.61066 .38114 L
.64479 .38114 L
.68111 .38114 L
.71607 .38114 L
.75323 .38114 L
.78904 .38114 L
.82349 .38114 L
.86013 .38114 L
.89362 .38114 L
s
.04255 .38114 m
.04255 .38852 L
.04255 .39657 L
.04255 .40413 L
.04255 .4114 L
.04255 .41913 L
.04255 .42658 L
.04255 .43449 L
.04255 .44212 L
.04255 .44946 L
.04255 .45726 L
.04255 .46478 L
.04255 .472 L
.04255 .4797 L
.04255 .4871 L
.04255 .49497 L
.04255 .50256 L
.04255 .50985 L
.04255 .51762 L
.04255 .52509 L
.04255 .53303 L
.04255 .54068 L
.04255 .54804 L
.04255 .55587 L
.04255 .56303 L
s
.14894 .38114 m
.14894 .38852 L
.14894 .39657 L
.14894 .40413 L
.14894 .4114 L
.14894 .41913 L
.14894 .42658 L
.14894 .43449 L
.14894 .44212 L
.14894 .44946 L
.14894 .45726 L
.14894 .46478 L
.14894 .472 L
.14894 .4797 L
.14894 .4871 L
.14894 .49497 L
.14894 .50256 L
.14894 .50985 L
.14894 .51762 L
.14894 .52509 L
.14894 .53303 L
.14894 .54068 L
.14894 .54804 L
.14894 .55587 L
.14894 .56303 L
s
.25532 .38114 m
.25532 .38852 L
.25532 .39657 L
.25532 .40413 L
.25532 .4114 L
.25532 .41913 L
.25532 .42658 L
.25532 .43449 L
.25532 .44212 L
.25532 .44946 L
.25532 .45726 L
.25532 .46478 L
.25532 .472 L
.25532 .4797 L
.25532 .4871 L
.25532 .49497 L
.25532 .50256 L
.25532 .50985 L
.25532 .51762 L
.25532 .52509 L
.25532 .53303 L
.25532 .54068 L
.25532 .54804 L
.25532 .55587 L
.25532 .56303 L
s
.3617 .38114 m
.3617 .38852 L
.3617 .39657 L
.3617 .40413 L
.3617 .4114 L
.3617 .41913 L
.3617 .42658 L
.3617 .43449 L
.3617 .44212 L
.3617 .44946 L
.3617 .45726 L
.3617 .46478 L
.3617 .472 L
.3617 .4797 L
.3617 .4871 L
.3617 .49497 L
.3617 .50256 L
.3617 .50985 L
.3617 .51762 L
.3617 .52509 L
.3617 .53303 L
.3617 .54068 L
.3617 .54804 L
.3617 .55587 L
.3617 .56303 L
s
.46809 .38114 m
.46809 .38852 L
.46809 .39657 L
.46809 .40413 L
.46809 .4114 L
.46809 .41913 L
.46809 .42658 L
.46809 .43449 L
.46809 .44212 L
.46809 .44946 L
.46809 .45726 L
.46809 .46478 L
.46809 .472 L
.46809 .4797 L
.46809 .4871 L
.46809 .49497 L
.46809 .50256 L
.46809 .50985 L
.46809 .51762 L
.46809 .52509 L
.46809 .53303 L
.46809 .54068 L
.46809 .54804 L
.46809 .55587 L
.46809 .56303 L
s
.57447 .38114 m
.57447 .38852 L
.57447 .39657 L
.57447 .40413 L
.57447 .4114 L
.57447 .41913 L
.57447 .42658 L
.57447 .43449 L
.57447 .44212 L
.57447 .44946 L
.57447 .45726 L
.57447 .46478 L
.57447 .472 L
.57447 .4797 L
.57447 .4871 L
.57447 .49497 L
.57447 .50256 L
.57447 .50985 L
.57447 .51762 L
.57447 .52509 L
.57447 .53303 L
.57447 .54068 L
.57447 .54804 L
.57447 .55587 L
.57447 .56303 L
s
.68085 .38114 m
.68085 .38852 L
.68085 .39657 L
.68085 .40413 L
.68085 .4114 L
.68085 .41913 L
.68085 .42658 L
.68085 .43449 L
.68085 .44212 L
.68085 .44946 L
.68085 .45726 L
.68085 .46478 L
.68085 .472 L
.68085 .4797 L
.68085 .4871 L
.68085 .49497 L
.68085 .50256 L
.68085 .50985 L
.68085 .51762 L
.68085 .52509 L
.68085 .53303 L
.68085 .54068 L
.68085 .54804 L
.68085 .55587 L
.68085 .56303 L
s
.78723 .38114 m
.78723 .38852 L
.78723 .39657 L
.78723 .40413 L
.78723 .4114 L
.78723 .41913 L
.78723 .42658 L
.78723 .43449 L
.78723 .44212 L
.78723 .44946 L
.78723 .45726 L
.78723 .46478 L
.78723 .472 L
.78723 .4797 L
.78723 .4871 L
.78723 .49497 L
.78723 .50256 L
.78723 .50985 L
.78723 .51762 L
.78723 .52509 L
.78723 .53303 L
.78723 .54068 L
.78723 .54804 L
.78723 .55587 L
.78723 .56303 L
s
.89362 .38114 m
.89362 .38852 L
.89362 .39657 L
.89362 .40413 L
.89362 .4114 L
.89362 .41913 L
.89362 .42658 L
.89362 .43449 L
.89362 .44212 L
.89362 .44946 L
.89362 .45726 L
.89362 .46478 L
.89362 .472 L
.89362 .4797 L
.89362 .4871 L
.89362 .49497 L
.89362 .50256 L
.89362 .50985 L
.89362 .51762 L
.89362 .52509 L
.89362 .53303 L
.89362 .54068 L
.89362 .54804 L
.89362 .55587 L
.89362 .56303 L
s
.04255 .38114 m
.07708 .38114 L
.11473 .38114 L
.15009 .38114 L
.1841 .38114 L
.2203 .38114 L
.25514 .38114 L
.29218 .38114 L
.32786 .38114 L
.36219 .38114 L
.39871 .38114 L
.43387 .38114 L
.46768 .38114 L
.50369 .38114 L
.53833 .38114 L
.57517 .38114 L
.61066 .38114 L
.64479 .38114 L
.68111 .38114 L
.71607 .38114 L
.75323 .38114 L
.78904 .38114 L
.82349 .38114 L
.86013 .38114 L
.89362 .38114 L
s
.04255 .40388 m
.07708 .40388 L
.11473 .40388 L
.15009 .40388 L
.1841 .40388 L
.2203 .40388 L
.25514 .40388 L
.29218 .40388 L
.32786 .40388 L
.36219 .40388 L
.39871 .40388 L
.43387 .40388 L
.46768 .40388 L
.50369 .40388 L
.53833 .40388 L
.57517 .40388 L
.61066 .40388 L
.64479 .40388 L
.68111 .40388 L
.71607 .40388 L
.75323 .40388 L
.78904 .40388 L
.82349 .40388 L
.86013 .40388 L
.89362 .40388 L
s
.04255 .42662 m
.07708 .42662 L
.11473 .42662 L
.15009 .42662 L
.1841 .42662 L
.2203 .42662 L
.25514 .42662 L
.29218 .42662 L
.32786 .42662 L
.36219 .42662 L
.39871 .42662 L
.43387 .42662 L
.46768 .42662 L
.50369 .42662 L
.53833 .42662 L
.57517 .42662 L
.61066 .42662 L
.64479 .42662 L
.68111 .42662 L
.71607 .42662 L
.75323 .42662 L
.78904 .42662 L
.82349 .42662 L
.86013 .42662 L
.89362 .42662 L
s
.04255 .44935 m
.07708 .44935 L
.11473 .44935 L
.15009 .44935 L
.1841 .44935 L
.2203 .44935 L
.25514 .44935 L
.29218 .44935 L
.32786 .44935 L
.36219 .44935 L
.39871 .44935 L
.43387 .44935 L
.46768 .44935 L
.50369 .44935 L
.53833 .44935 L
.57517 .44935 L
.61066 .44935 L
.64479 .44935 L
.68111 .44935 L
.71607 .44935 L
.75323 .44935 L
.78904 .44935 L
.82349 .44935 L
.86013 .44935 L
.89362 .44935 L
s
.04255 .47209 m
.07708 .47209 L
.11473 .47209 L
.15009 .47209 L
.1841 .47209 L
.2203 .47209 L
.25514 .47209 L
.29218 .47209 L
.32786 .47209 L
.36219 .47209 L
.39871 .47209 L
.43387 .47209 L
.46768 .47209 L
.50369 .47209 L
.53833 .47209 L
.57517 .47209 L
.61066 .47209 L
.64479 .47209 L
.68111 .47209 L
.71607 .47209 L
.75323 .47209 L
.78904 .47209 L
.82349 .47209 L
.86013 .47209 L
.89362 .47209 L
s
.04255 .49482 m
.07708 .49482 L
.11473 .49482 L
.15009 .49482 L
.1841 .49482 L
.2203 .49482 L
.25514 .49482 L
.29218 .49482 L
.32786 .49482 L
.36219 .49482 L
.39871 .49482 L
.43387 .49482 L
.46768 .49482 L
.50369 .49482 L
.53833 .49482 L
.57517 .49482 L
.61066 .49482 L
.64479 .49482 L
.68111 .49482 L
.71607 .49482 L
.75323 .49482 L
.78904 .49482 L
.82349 .49482 L
.86013 .49482 L
.89362 .49482 L
s
.04255 .51756 m
.07708 .51756 L
.11473 .51756 L
.15009 .51756 L
.1841 .51756 L
.2203 .51756 L
.25514 .51756 L
.29218 .51756 L
.32786 .51756 L
.36219 .51756 L
.39871 .51756 L
.43387 .51756 L
.46768 .51756 L
.50369 .51756 L
.53833 .51756 L
.57517 .51756 L
.61066 .51756 L
.64479 .51756 L
.68111 .51756 L
.71607 .51756 L
.75323 .51756 L
.78904 .51756 L
.82349 .51756 L
.86013 .51756 L
.89362 .51756 L
s
.04255 .5403 m
.07708 .5403 L
.11473 .5403 L
.15009 .5403 L
.1841 .5403 L
.2203 .5403 L
.25514 .5403 L
.29218 .5403 L
.32786 .5403 L
.36219 .5403 L
.39871 .5403 L
.43387 .5403 L
.46768 .5403 L
.50369 .5403 L
.53833 .5403 L
.57517 .5403 L
.61066 .5403 L
.64479 .5403 L
.68111 .5403 L
.71607 .5403 L
.75323 .5403 L
.78904 .5403 L
.82349 .5403 L
.86013 .5403 L
.89362 .5403 L
s
.04255 .56303 m
.07708 .56303 L
.11473 .56303 L
.15009 .56303 L
.1841 .56303 L
.2203 .56303 L
.25514 .56303 L
.29218 .56303 L
.32786 .56303 L
.36219 .56303 L
.39871 .56303 L
.43387 .56303 L
.46768 .56303 L
.50369 .56303 L
.53833 .56303 L
.57517 .56303 L
.61066 .56303 L
.64479 .56303 L
.68111 .56303 L
.71607 .56303 L
.75323 .56303 L
.78904 .56303 L
.82349 .56303 L
.86013 .56303 L
.89362 .56303 L
s
.04255 .01737 m
.04255 .02475 L
.04255 .03279 L
.04255 .04035 L
.04255 .04762 L
.04255 .05536 L
.04255 .0628 L
.04255 .07072 L
.04255 .07834 L
.04255 .08568 L
.04255 .09349 L
.04255 .101 L
.04255 .10823 L
.04255 .11592 L
.04255 .12333 L
.04255 .1312 L
.04255 .13878 L
.04255 .14608 L
.04255 .15384 L
.04255 .16131 L
.04255 .16925 L
.04255 .17691 L
.04255 .18427 L
.04255 .1921 L
.04255 .19926 L
s
.14894 .01737 m
.14894 .02475 L
.14894 .03279 L
.14894 .04035 L
.14894 .04762 L
.14894 .05536 L
.14894 .0628 L
.14894 .07072 L
.14894 .07834 L
.14894 .08568 L
.14894 .09349 L
.14894 .101 L
.14894 .10823 L
.14894 .11592 L
.14894 .12333 L
.14894 .1312 L
.14894 .13878 L
.14894 .14608 L
.14894 .15384 L
.14894 .16131 L
.14894 .16925 L
.14894 .17691 L
.14894 .18427 L
.14894 .1921 L
.14894 .19926 L
s
.25532 .01737 m
.25532 .02475 L
.25532 .03279 L
.25532 .04035 L
.25532 .04762 L
.25532 .05536 L
.25532 .0628 L
.25532 .07072 L
.25532 .07834 L
.25532 .08568 L
.25532 .09349 L
.25532 .101 L
.25532 .10823 L
.25532 .11592 L
.25532 .12333 L
.25532 .1312 L
.25532 .13878 L
.25532 .14608 L
.25532 .15384 L
.25532 .16131 L
.25532 .16925 L
.25532 .17691 L
.25532 .18427 L
.25532 .1921 L
.25532 .19926 L
s
.3617 .01737 m
.3617 .02475 L
.3617 .03279 L
.3617 .04035 L
.3617 .04762 L
.3617 .05536 L
.3617 .0628 L
.3617 .07072 L
.3617 .07834 L
.3617 .08568 L
.3617 .09349 L
.3617 .101 L
.3617 .10823 L
.3617 .11592 L
.3617 .12333 L
.3617 .1312 L
.3617 .13878 L
.3617 .14608 L
.3617 .15384 L
.3617 .16131 L
.3617 .16925 L
.3617 .17691 L
.3617 .18427 L
.3617 .1921 L
.3617 .19926 L
s
.46809 .01737 m
.46809 .02475 L
.46809 .03279 L
.46809 .04035 L
.46809 .04762 L
.46809 .05536 L
.46809 .0628 L
.46809 .07072 L
.46809 .07834 L
.46809 .08568 L
.46809 .09349 L
.46809 .101 L
.46809 .10823 L
.46809 .11592 L
.46809 .12333 L
.46809 .1312 L
.46809 .13878 L
.46809 .14608 L
.46809 .15384 L
.46809 .16131 L
.46809 .16925 L
.46809 .17691 L
.46809 .18427 L
.46809 .1921 L
.46809 .19926 L
s
.57447 .01737 m
.57447 .02475 L
.57447 .03279 L
.57447 .04035 L
.57447 .04762 L
.57447 .05536 L
.57447 .0628 L
.57447 .07072 L
.57447 .07834 L
.57447 .08568 L
.57447 .09349 L
.57447 .101 L
.57447 .10823 L
.57447 .11592 L
.57447 .12333 L
.57447 .1312 L
.57447 .13878 L
.57447 .14608 L
.57447 .15384 L
.57447 .16131 L
.57447 .16925 L
.57447 .17691 L
.57447 .18427 L
.57447 .1921 L
.57447 .19926 L
s
.68085 .01737 m
.68085 .02475 L
.68085 .03279 L
.68085 .04035 L
.68085 .04762 L
.68085 .05536 L
.68085 .0628 L
.68085 .07072 L
.68085 .07834 L
.68085 .08568 L
.68085 .09349 L
.68085 .101 L
.68085 .10823 L
.68085 .11592 L
.68085 .12333 L
.68085 .1312 L
.68085 .13878 L
.68085 .14608 L
.68085 .15384 L
.68085 .16131 L
.68085 .16925 L
.68085 .17691 L
.68085 .18427 L
.68085 .1921 L
.68085 .19926 L
s
.78723 .01737 m
.78723 .02475 L
.78723 .03279 L
.78723 .04035 L
.78723 .04762 L
.78723 .05536 L
.78723 .0628 L
.78723 .07072 L
.78723 .07834 L
.78723 .08568 L
.78723 .09349 L
.78723 .101 L
.78723 .10823 L
.78723 .11592 L
.78723 .12333 L
.78723 .1312 L
.78723 .13878 L
.78723 .14608 L
.78723 .15384 L
.78723 .16131 L
.78723 .16925 L
.78723 .17691 L
.78723 .18427 L
.78723 .1921 L
.78723 .19926 L
s
.89362 .01737 m
.89362 .02475 L
.89362 .03279 L
.89362 .04035 L
.89362 .04762 L
.89362 .05536 L
.89362 .0628 L
.89362 .07072 L
.89362 .07834 L
.89362 .08568 L
.89362 .09349 L
.89362 .101 L
.89362 .10823 L
.89362 .11592 L
.89362 .12333 L
.89362 .1312 L
.89362 .13878 L
.89362 .14608 L
.89362 .15384 L
.89362 .16131 L
.89362 .16925 L
.89362 .17691 L
.89362 .18427 L
.89362 .1921 L
.89362 .19926 L
s
.04255 .01737 m
.07708 .01737 L
.11473 .01737 L
.15009 .01737 L
.1841 .01737 L
.2203 .01737 L
.25514 .01737 L
.29218 .01737 L
.32786 .01737 L
.36219 .01737 L
.39871 .01737 L
.43387 .01737 L
.46768 .01737 L
.50369 .01737 L
.53833 .01737 L
.57517 .01737 L
.61066 .01737 L
.64479 .01737 L
.68111 .01737 L
.71607 .01737 L
.75323 .01737 L
.78904 .01737 L
.82349 .01737 L
.86013 .01737 L
.89362 .01737 L
s
.04255 .0401 m
.07708 .0401 L
.11473 .0401 L
.15009 .0401 L
.1841 .0401 L
.2203 .0401 L
.25514 .0401 L
.29218 .0401 L
.32786 .0401 L
.36219 .0401 L
.39871 .0401 L
.43387 .0401 L
.46768 .0401 L
.50369 .0401 L
.53833 .0401 L
.57517 .0401 L
.61066 .0401 L
.64479 .0401 L
.68111 .0401 L
.71607 .0401 L
.75323 .0401 L
.78904 .0401 L
.82349 .0401 L
.86013 .0401 L
.89362 .0401 L
s
.04255 .06284 m
.07708 .06284 L
.11473 .06284 L
.15009 .06284 L
.1841 .06284 L
.2203 .06284 L
.25514 .06284 L
.29218 .06284 L
.32786 .06284 L
.36219 .06284 L
.39871 .06284 L
.43387 .06284 L
.46768 .06284 L
.50369 .06284 L
.53833 .06284 L
.57517 .06284 L
.61066 .06284 L
.64479 .06284 L
.68111 .06284 L
.71607 .06284 L
.75323 .06284 L
.78904 .06284 L
.82349 .06284 L
.86013 .06284 L
.89362 .06284 L
s
.04255 .08558 m
.07708 .08558 L
.11473 .08558 L
.15009 .08558 L
.1841 .08558 L
.2203 .08558 L
.25514 .08558 L
.29218 .08558 L
.32786 .08558 L
.36219 .08558 L
.39871 .08558 L
.43387 .08558 L
.46768 .08558 L
.50369 .08558 L
.53833 .08558 L
.57517 .08558 L
.61066 .08558 L
.64479 .08558 L
.68111 .08558 L
.71607 .08558 L
.75323 .08558 L
.78904 .08558 L
.82349 .08558 L
.86013 .08558 L
.89362 .08558 L
s
.04255 .10831 m
.07708 .10831 L
.11473 .10831 L
.15009 .10831 L
.1841 .10831 L
.2203 .10831 L
.25514 .10831 L
.29218 .10831 L
.32786 .10831 L
.36219 .10831 L
.39871 .10831 L
.43387 .10831 L
.46768 .10831 L
.50369 .10831 L
.53833 .10831 L
.57517 .10831 L
.61066 .10831 L
.64479 .10831 L
.68111 .10831 L
.71607 .10831 L
.75323 .10831 L
.78904 .10831 L
.82349 .10831 L
.86013 .10831 L
.89362 .10831 L
s
.04255 .13105 m
.07708 .13105 L
.11473 .13105 L
.15009 .13105 L
.1841 .13105 L
.2203 .13105 L
.25514 .13105 L
.29218 .13105 L
.32786 .13105 L
.36219 .13105 L
.39871 .13105 L
.43387 .13105 L
.46768 .13105 L
.50369 .13105 L
.53833 .13105 L
.57517 .13105 L
.61066 .13105 L
.64479 .13105 L
.68111 .13105 L
.71607 .13105 L
.75323 .13105 L
.78904 .13105 L
.82349 .13105 L
.86013 .13105 L
.89362 .13105 L
s
.04255 .15378 m
.07708 .15378 L
.11473 .15378 L
.15009 .15378 L
.1841 .15378 L
.2203 .15378 L
.25514 .15378 L
.29218 .15378 L
.32786 .15378 L
.36219 .15378 L
.39871 .15378 L
.43387 .15378 L
.46768 .15378 L
.50369 .15378 L
.53833 .15378 L
.57517 .15378 L
.61066 .15378 L
.64479 .15378 L
.68111 .15378 L
.71607 .15378 L
.75323 .15378 L
.78904 .15378 L
.82349 .15378 L
.86013 .15378 L
.89362 .15378 L
s
.04255 .17652 m
.07708 .17652 L
.11473 .17652 L
.15009 .17652 L
.1841 .17652 L
.2203 .17652 L
.25514 .17652 L
.29218 .17652 L
.32786 .17652 L
.36219 .17652 L
.39871 .17652 L
.43387 .17652 L
.46768 .17652 L
.50369 .17652 L
.53833 .17652 L
.57517 .17652 L
.61066 .17652 L
.64479 .17652 L
.68111 .17652 L
.71607 .17652 L
.75323 .17652 L
.78904 .17652 L
.82349 .17652 L
.86013 .17652 L
.89362 .17652 L
s
.04255 .19926 m
.07708 .19926 L
.11473 .19926 L
.15009 .19926 L
.1841 .19926 L
.2203 .19926 L
.25514 .19926 L
.29218 .19926 L
.32786 .19926 L
.36219 .19926 L
.39871 .19926 L
.43387 .19926 L
.46768 .19926 L
.50369 .19926 L
.53833 .19926 L
.57517 .19926 L
.61066 .19926 L
.64479 .19926 L
.68111 .19926 L
.71607 .19926 L
.75323 .19926 L
.78904 .19926 L
.82349 .19926 L
.86013 .19926 L
.89362 .19926 L
s
.89362 .2902 m
1 .2902 L
s
% Start of user PostScript
2. 0 2.5 0 MAarrowhead1
% End of user PostScript
.46809 .59777 m
.46809 .61224 L
s
% Start of user PostScript
0 10.6248 0 11.1248 MAarrowhead1
% End of user PostScript
gsave
.93617 .38114 -66.875 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.500 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
70.750 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .47209 -68.125 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
68.000 14.938 moveto
(p) show
73.250 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .56303 -68.125 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
68.000 14.938 moveto
(p) show
73.250 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .19926 -70.0625 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.500 14.938 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.875 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
77.125 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .10831 -71.3125 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.375 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
74.375 14.938 moveto
(p) show
79.625 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93617 .01737 -71.3125 -11.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.938 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.375 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
74.375 14.938 moveto
(p) show
79.625 14.938 moveto
%%IncludeResource: font Symbol
%%IncludeFont: Symbol
/Symbol findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.98936 .31915 -66 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .60066 -69 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
75.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oQP3oool0
0`000000oooo0?ooo`2G0?ooo`00QP3oool00`000000oooo0?ooo`2G0?ooo`00QP3oool00`000000
oooo0?ooo`210?ooo`<000000`3oool00`000000oooo0?ooo`02000000/0oooo00260?ooo`030000
003oool0oooo08@0oooo00<000000?ooo`3oool00P0000000`3oool000000000000;0?ooo`00QP3o
ool00`000000oooo0?ooo`1l0?ooo`@00000103oool01`000000oooo0?ooo`3oool000000?ooo`00
0000303oool000`0oooom@00000:0?ooo`800000103oool00`000000oooo0000000<0?ooo`00303o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo00000005000000/0oooo000<0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo00000180oooo000<
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`08
0?ooo`<000004P3oool000`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01d0oooo000<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0M0?ooo`00303ooooe000001l0oooo000<0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`00303oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool0
00`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01d0oooo000<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0M0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool07@3oool000`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01d0oooo000<0?ooooD000007`3oool000`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo000<0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`00
303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
7@3oool000`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01d0oooo000<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0M0?ooo`00303ooooe000001l0oooo000<0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`00303oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool000`0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo000<
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`07
0?ooo`@000000P3oool00`000000oooo0?ooo`02000000/0oooo000<0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo0P0000000`3oool000000000000;0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool400000080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0000000<0?ooo`00303ooooe000000/0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0000000<0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool02P3oool00`000000oooo00000005000000/0oooo000<
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo00000180oooo000<0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`8000004`3oool000`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo000<0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`00
303ooooe000001l0oooo000<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0M0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool07@3oool000`0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo000<0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`00303oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool000`0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo000<
0?ooooD000007`3oool000`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01d0oooo000<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0M0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool000`0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo000<0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`00303ooooe0000
01l0oooo000<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0M0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool07@3oool000`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01d0oooo000<0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00800000303oool0
00`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00`0oooo0P0000000`3oool000000000000<0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool01@3oool4000000@0oooo00<000000?ooo`00
00003@3oool000`0oooom@00000?0?ooo`030000003oool0000000d0oooo000<0?ooo`0300000000
ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000
ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000
ool00?oo01/00?oo00<00000003oo`00ool07000ool00`000000oooo0?ooo`0;0?ooo`H00000303o
ool000`0oooo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000ool0
0?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`030000003oool0
oooo01d0oooo000<0?ooo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`00
00000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`00
00000?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`00
0000oooo0?ooo`0M0?ooo`00303oool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`0
0?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo01/0
0?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`0
0?oo00<000000?ooo`3oool07@3oool000`0oooo00<00000003oo`00ool06`00ool00`0000000?oo
003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo
003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo
003oo`0L003oo`030000003oool0oooo01d0oooo000<0?ooooD000007`3oool000`0oooo00<00000
003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000
003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000
003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`030000003oool0oooo01d0oooo000<0?oo
o`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003o
o`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003o
o`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`000000oooo0?ooo`0M0?oo
o`00303oool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00
ool06`00ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00
ool07000ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<000000?ooo`3o
ool07@3oool000`0oooo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`030000
0000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`030000
0000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`030000
003oool0oooo01d0oooo000<0?ooo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000
ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00
ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000
ool00`000000oooo0?ooo`0M0?ooo`00303oool00`0000000?oo003oo`0K003oo`0300000000ool0
0?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000ool0
0?oo01`00?oo00<000000?ooo`3oool07@3oool000`0oooom@00000O0?ooo`00303oool00`000000
0?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`000000
0?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`000000
0?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<000000?ooo`3oool07@3oool000`0oooo
00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo01/00?oo
00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo
00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`030000003oool0oooo01d0oooo
000<0?ooo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003o
o`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003o
o`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`000000oooo0?oo
o`0M0?ooo`00303oool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000
003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000
003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000
0?ooo`3oool07@3oool000`0oooo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003o
o`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003o
o`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003o
o`030000003oool0oooo01d0oooo000<0?ooooD000007`3oool000`0oooo00<00000003oo`00ool0
6`00ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool0
7000ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool0
6`00ool00`0000000?oo003oo`0L003oo`030000003oool0oooo01d0oooo000<0?ooo`0300000000
ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000
ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000
ool00?oo01/00?oo00<00000003oo`00ool07000ool00`000000oooo0?ooo`0M0?ooo`00303oool0
0`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool0
0`0000000?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool0
0`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<000000?ooo`3oool07@3oool0
00`0oooo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo
01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo
01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`030000003oool0oooo
01d0oooo000<0?ooo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`000000
0?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`000000
0?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`000000
oooo0?ooo`0C0?ooo`800000203oool000`0oooo00<00000003oo`00ool06`00ool00`0000000?oo
003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo
003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo
003oo`0L003oo`030000003oool0oooo01<0oooo1P0000040?ooo`00o`00000P00000040oooo000<
0?ooo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K
003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L
003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`000000oooo0?ooo`0C
0?ooo`L000000`3oool000`0oooo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003o
o`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003o
o`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003o
o`030000003oool0oooo01<0oooo0`0000070?ooo`00303oool00`0000000?oo003oo`0K003oo`03
00000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`03
00000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`03
00000000ool00?oo01`00?oo00<000000?ooo`3oool07@3oool000`0oooo00<00000003oo`00ool0
6`00ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool0
7000ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool0
6`00ool00`0000000?oo003oo`0L003oo`030000003oool0oooo01d0oooo000<0?ooo`0300000000
ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000
ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000
ool00?oo01/00?oo00<00000003oo`00ool07000ool00`000000oooo0?ooo`0M0?ooo`00303ooooe
000001T0oooo100000020?ooo`00303oool00`0000000?oo003oo`0K003oo`0300000000ool00?oo
01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo
01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo
01`00?oo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000030?ooo`00303oool00`00
00000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`00
00000?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`00
00000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<000000?ooo`3oool05P3oool01000
0000oooo0?ooo`0000030?ooo`00303oool00`0000000?oo003oo`0K003oo`0300000000ool00?oo
01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo
01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo
01`00?oo00<000000?ooo`3oool05@3oool2000000030?ooo`000000000000<0oooo000<0?ooo`03
00000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`03
00000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`03
00000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`000000oooo0?ooo`0M0?ooo`00
303oool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool0
6`00ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool0
7000ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<000000?ooo`3oool0
7@3oool000`0oooo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000
ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000
ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`030000003o
ool0oooo01d0oooo000<0?ooooD000007`3oool000`0oooo00<00000003oo`00ool06`00ool00`00
00000?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`00
00000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`00
00000?oo003oo`0L003oo`030000003oool0oooo01d0oooo000<0?ooo`0300000000ool00?oo01/0
0?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`0
0?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo01/0
0?oo00<00000003oo`00ool07000ool00`000000oooo0?ooo`0M0?ooo`00303oool00`0000000?oo
003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo
003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo
003oo`0K003oo`0300000000ool00?oo01`00?oo00<000000?ooo`3oool07@3oool000`0oooo00<0
0000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<0
0000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<0
0000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`030000003oool0oooo01d0oooo000<
0?ooo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K
003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L
003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`000000oooo0?ooo`0M
0?ooo`00303ooooe000001l0oooo000<0?ooo`0300000000ool00?oo01/00?oo00<00000003oo`00
ool07000ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00
ool06`00ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00
ool07000ool00`000000oooo0?ooo`0M0?ooo`00303oool00`0000000?oo003oo`0K003oo`030000
0000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`030000
0000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`030000
0000ool00?oo01`00?oo00<000000?ooo`3oool07@3oool000`0oooo00<00000003oo`00ool06`00
ool00`0000000?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000
ool00`0000000?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00
ool00`0000000?oo003oo`0L003oo`030000003oool0oooo01d0oooo000<0?ooo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003oo`0300000000ool0
0?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003oo`0300000000ool0
0?oo01/00?oo00<00000003oo`00ool07000ool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00800000403oool000`0oooo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003o
o`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`0000000?oo003oo`0K003o
o`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`0000000?oo003oo`0L003o
o`030000003oool0oooo00P0oooo0P0000000`3oool000000000000@0?ooo`00303oool00`000000
0?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<00000003oo`00ool06`00ool00`000000
0?oo003oo`0L003oo`0300000000ool00?oo01/00?oo00<00000003oo`00ool07000ool00`000000
0?oo003oo`0K003oo`0300000000ool00?oo01`00?oo00<000000?ooo`3oool02@3oool00`000000
oooo0000000A0?ooo`00303ooooe000000/0oooo00<000000?ooo`0000004@3oool000`0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo1P00
000@0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool07@3oool000`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01d0oooo000<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0M0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool000`0oooom@00000O0?ooo`00303oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool0
00`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01d0oooo000<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0M0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool07@3oool000`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01d0oooo000<0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`00303ooooe000001l0oooo000<0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`00
303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
7@3oool000`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01d0oooo000<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0M0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool07@3oool000`0oooom@00000O0?ooo`00303oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool000`0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo000<
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M
0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0103oool400000080oooo00<000000?ooo`3oool00P00000>0?ooo`00303oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`80000000<0oooo0000000000003P3oool000`0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0000000?0?ooo`00303ooooe000000P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0000000?0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool01`3oool00`000000oooo00000005000000h0oooo000<0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`040?oo
o`040000003oool0oooo000001D0oooo000<0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`050?ooo`8000005P3oool000`0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo000<0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`00303o
oooe000001l0oooo000<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0M0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool07@3oool000`0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo000<0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`00303oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool000`0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo000<0?oo
ooD000007`3oool000`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01d0oooo000<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0M0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool07@3oool000`0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo000<0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`00303ooooe000001l0
oooo000<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0M0?ooo`00303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool07@3oool000`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01d0oooo000<0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`040?ooo`<000000`3oool00`000000oooo0?ooo`020000
00h0oooo000<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080000000<0oooo0000000000003P3oool000`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo
00L000000?ooo`3oool0oooo0000003oool0000000l0oooo000<0?ooooD000001`3oool2000000@0
oooo00<000000?ooo`0000003`3oool008H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo
00000005000000h0oooo00260?ooo`030000003oool0oooo07h0oooo00@000000?ooo`3oool00000
5@3oool008H0oooo00<000000?ooo`3oool0O`3oool3000001D0oooo00260?ooo`030000003oool0
oooo09L0oooo00260?ooo`030000003oool0oooo09L0oooo00240?ooo`D00000U`3oool008@0oooo
1@00002G0?ooo`00Q03oool4000000T0oooo0P00002=0?ooo`00Q@3oool3000000T0oooo0P00002=
0?ooo`00Q@3oool3000000P0oooo00@000000?ooo`3oool00000S03oool008D0oooo0`0000070?oo
o`8000000P3oool2000008/0oooo00250?ooo`800000V@3oool008H0oooo00<000000?ooo`3oool0
U`3oool008H0oooo00<000000?ooo`3oool0U`3oool008H0oooo00<000000?ooo`3oool0U`3oool0
0001\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2, -10, 0, 0}}],
  StyleBox["  \n\t\t\t\tFigure 5.5",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The Riemann surface for the mapping  ",
  Cell[BoxData[
      \(w = log \((z)\)\)]],
  "."
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Logarithms",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/LogarithmFunBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Riemann Surfaces",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/RiemannSurfaceBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{985, 603},
WindowMargins->{{10, Automatic}, {Automatic, 5}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 352912, 12512}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 116, 2, 33, "Text"],
Cell[2221, 66, 428, 12, 52, "Text"],
Cell[2652, 80, 4731, 140, 318, "Text",
  Evaluatable->False],
Cell[7386, 222, 847, 29, 52, "Text",
  Evaluatable->False],
Cell[8236, 253, 1105, 36, 71, "Text",
  Evaluatable->False],
Cell[9344, 291, 1238, 36, 90, "Text",
  Evaluatable->False],
Cell[10585, 329, 64197, 1240, 296, "Text"],
Cell[74785, 1571, 573, 15, 52, "Text",
  Evaluatable->False],
Cell[75361, 1588, 215, 7, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[75601, 1599, 127, 2, 33, "Text"],
Cell[75731, 1603, 167, 5, 33, "Text"],
Cell[75901, 1610, 1018, 21, 250, "Input"],
Cell[76922, 1633, 104, 3, 33, "Text"],
Cell[77029, 1638, 1977, 39, 348, "Input"]
}, Closed]],
Cell[79021, 1680, 9987, 244, 330, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[89033, 1928, 111, 2, 33, "Text"],
Cell[89147, 1932, 122, 5, 33, "Text"],
Cell[89272, 1939, 288, 6, 110, "Input"],
Cell[89563, 1947, 303, 11, 33, "Text",
  Evaluatable->False],
Cell[89869, 1960, 668, 15, 210, "Input"]
}, Closed]],
Cell[90552, 1978, 445, 16, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[91022, 1998, 145, 5, 33, "Text"],
Cell[91170, 2005, 1409, 27, 320, "Input"]
}, Closed]],
Cell[92594, 2035, 1487, 51, 163, "Text"],
Cell[94084, 2088, 780, 25, 109, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[94889, 2117, 111, 2, 33, "Text"],
Cell[95003, 2121, 204, 8, 33, "Text"],
Cell[95210, 2131, 1008, 20, 270, "Input"],
Cell[96221, 2153, 190, 8, 33, "Text"],
Cell[96414, 2163, 994, 20, 270, "Input"]
}, Closed]],
Cell[97423, 2186, 1114, 37, 125, "Text"],
Cell[98540, 2225, 1670, 39, 149, "Text"],
Cell[100213, 2266, 1800, 46, 156, "Text"],
Cell[102016, 2314, 1433, 30, 218, "Text"],
Cell[103452, 2346, 2364, 58, 307, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[105841, 2408, 111, 2, 33, "Text"],
Cell[105955, 2412, 186, 6, 33, "Text"],
Cell[106144, 2420, 1458, 26, 414, "Input"],
Cell[107605, 2448, 338, 8, 52, "Text"]
}, Closed]],
Cell[107958, 2459, 238, 6, 30, "Text"],
Cell[108199, 2467, 420, 13, 52, "Text"],

Cell[CellGroupData[{
Cell[108644, 2484, 111, 2, 33, "Text"],
Cell[108758, 2488, 1012, 23, 71, "Text"]
}, Closed]],
Cell[109785, 2514, 622, 16, 68, "Text"],
Cell[110410, 2532, 835, 30, 156, "Text"],

Cell[CellGroupData[{
Cell[111270, 2566, 111, 2, 33, "Text"],
Cell[111384, 2570, 1602, 43, 221, "Text"]
}, Closed]],
Cell[113001, 2616, 352, 13, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[113378, 2633, 127, 2, 33, "Text"],
Cell[113508, 2637, 290, 9, 33, "Text"],
Cell[113801, 2648, 2239, 48, 530, "Input"],
Cell[116043, 2698, 1294, 29, 251, "Text",
  Evaluatable->False]
}, Closed]],
Cell[117352, 2730, 3824, 111, 182, "Text"],
Cell[121179, 2843, 61270, 1283, 318, "Text"],
Cell[182452, 4128, 1454, 41, 247, "Text"],
Cell[183909, 4171, 7411, 221, 299, "Text"],
Cell[191323, 4394, 159569, 8058, 216, "Text"],
Cell[350895, 12454, 290, 7, 33, "Text"],
Cell[351188, 12463, 288, 7, 33, "Text"],
Cell[351479, 12472, 288, 7, 33, "Text"],
Cell[351770, 12481, 257, 5, 33, "Text"],
Cell[352030, 12488, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

