(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    417575,      12369]*)
(*NotebookOutlinePosition[    418390,      12399]*)
(*  CellTagsIndexPosition[    418312,      12393]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["5.3  Complex Exponents",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tIn Section 1.5we indicated that it is possible to make sense out of \
expressions such as",
  " ",
  Cell[BoxData[
      \(\@\(1 + \[ImaginaryI]\)\)]],
  " or ",
  Cell[BoxData[
      \(\((\(-1\))\)\^\[ImaginaryI]\)]],
  " ",
  "without appealing to a number system beyond the framework of complex \
numbers.  We now show how this is done by taking note of some rudimentary \
properties of the complex exponential and logarithm, and then using our \
imagination."
}], "Text"],

Cell[TextData[{
  "\tWe begin by generalizing Identity ",
  StyleBox["(5-15)",
    FontColor->RGBColor[0, 0, 1]],
  ".  Equations ",
  StyleBox["(5-12)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(5-14)",
    FontColor->RGBColor[0, 0, 1]],
  " show that ",
  Cell[BoxData[
      \(log \((z)\)\)]],
  " can be expressed as the set ",
  Cell[BoxData[
      RowBox[{\(log \((z)\)\), "=", 
        RowBox[{"{", 
          RowBox[{\(Log \((z)\)\), "+", 
            RowBox[{"\[ImaginaryI]", " ", "2", " ", "n", " ", 
              RowBox[{"\[Pi]", ":", " ", 
                RowBox[{"n", " ", 
                  StyleBox["is",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["an",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["integer",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]}]}]}], "}"}]}]]],
  ".  We can easily show (left as an exercise) that, for ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ", ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\(log\_\[Alpha]\) \((z)\)\) = z\)]],
  ", where ",
  Cell[BoxData[
      \(\(log\_\[Alpha]\) \((z)\)\)]],
  " is any branch of the function ",
  Cell[BoxData[
      \(log \((z)\)\)]],
  ".  But this means that for any ",
  Cell[BoxData[
      \(\[Zeta] \[Element] log \((z)\)\)]],
  ", the identity ",
  Cell[BoxData[
      \(\[ExponentialE]\^\[Zeta] = z\)]],
  " holds true.  Because ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(log \((z)\)\)\)]],
  " denotes the set ",
  Cell[BoxData[
      \({\(\[ExponentialE]\^\[Zeta]\) : \ \[Zeta] \[Element] 
            log \((z)\)}\)]],
  ", we see that ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\(log\_\[Alpha]\) \((z)\)\) = z\)]],
  ", for ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tNext, we note that identity ",
  StyleBox["(5-17)",
    FontColor->RGBColor[0, 0, 1]],
  " gives us ",
  Cell[BoxData[
      \(log \((z\^n)\) = n\ log \((z)\)\)]],
  ", where n is any natural number, so that ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(log \((z\^n)\)\) = \(\[ExponentialE]\^\(n\ log \
\((z)\)\) = z\^n\)\)]],
  " for ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ".  With these preliminaries out of the way, we can now come up with a \
definition of a complex number raised to a complex power."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Definition 5.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["c",
    FontFamily->"Courier New"],
  " be a complex number.  We define ",
  Cell[BoxData[
      StyleBox[\(z\^c\),
        FontWeight->"Plain"]],
    FontWeight->"Bold"],
  " as follows  \n\n",
  StyleBox["(5-21)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(z\^c = \ \[ExponentialE]\^\(c\ log \((z)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t The right side of Equation ",
  StyleBox["(5-21)",
    FontColor->RGBColor[0, 0, 1]],
  " is a set.  This definition makes sense because, if both  z  and  c  are \
real numbers with  ",
  Cell[BoxData[
      \(z > 0\)]],
  ", Equation ",
  StyleBox["(5-21)",
    FontColor->RGBColor[0, 0, 1]],
  " gives the familiar (real) definition for  ",
  Cell[BoxData[
      \(z\^c\)]],
  ", as the following example illustrates. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 5.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Equation ",
  StyleBox["(5-21)",
    FontColor->RGBColor[0, 0, 1]],
  " to evaluate ",
  Cell[BoxData[
      \(4\^\(1/2\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  Calculating  ",
  Cell[BoxData[
      \(4\^\(1\/2\)\  = \ exp[1\/2\ log\ 4]\)]],
  "  gives  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(1\/2\ log\ 4\), "  ", "=", "  ", 
        RowBox[{"{", 
          RowBox[{\(ln\ 2\), " ", "+", " ", 
            RowBox[{"\[ImaginaryI]", " ", "n", " ", 
              RowBox[{"\[Pi]", ":", "  ", 
                RowBox[{"n", "  ", 
                  StyleBox["is",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["an",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["integer",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]}]}]}], "}"}]}]]],
  ".  \n\nThus  ",
  Cell[BoxData[
      \(4\^\(1\/2\)\)]],
  "  is the set  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(exp \((ln\ 2\  + \ \[ImaginaryI]\ n\ \[Pi])\)\), ":", "  ", 
          
          RowBox[{"n", "  ", 
            StyleBox["is",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["an",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["integer",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}], "}"}]]],
  ".  The distinct values occur when ",
  Cell[BoxData[
      RowBox[{"n", "=", 
        RowBox[{"0", " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "1"}]}]]],
  ";  we get  ",
  Cell[BoxData[
      \(exp \((ln\ 2)\) = 2\)]],
  "  and  ",
  Cell[BoxData[
      \(exp \((ln\ 2 + \[ImaginaryI]\ \[Pi])\) = \(exp \((ln\ 2)\) 
            exp \((\[ImaginaryI]\ \[Pi])\) = \(-2\)\)\)]],
  ".  In other words, ",
  Cell[BoxData[
      \(4\^\(1\/2\)\  = \ {\(-2\), 2}\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The expression  ",
  Cell[BoxData[
      \(4\^\(1\/2\)\)]],
  "  is different from  ",
  Cell[BoxData[
      \(\@4\)]],
  ",  as the former represents the set  ",
  Cell[BoxData[
      \({\(-2\), 2}\)]],
  "  and the latter gives only one value,  ",
  Cell[BoxData[
      \(\@4 = 2\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter  ",
  Cell[BoxData[
      \(z\_0 = 4\)]],
  "  and find the principal value of  ",
  Cell[BoxData[
      \(4\^\(1/2\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[w];\)\ \), "\n", 
    \(\(Clear[e, pts, W];\)\ \), "\n", 
    \(\(w\_0\  = \ 4\^\(1/2\);\)\ \), "\n", 
    \(\(w\_1\  = \ \[ExponentialE]\^\(\(1\/2\) \((\ Log[4] + \[ImaginaryI]\ 2 \
 n\ \[Pi])\)\);\)\ \), "\n", 
    \(\(w\_2\  = \ \(e\^\(\(1\/2\) 
                Log[4]\)\) \[ExponentialE]\^\(\(1\/2\) \[ImaginaryI]\ 2  n\ \
\[Pi]\);\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_0\) = \!\(4\^\(1/2\)\)\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_0\) = \>\"", w\_0];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \!\(4\^\(1/2\)\) = \>\"", 
        w\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", w\_1];\)\ \), "\n", 
    \(\(w\_1\  = \ ComplexExpand[w\_1]\ ;\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", w\_1];\)\ \), "\n", 
    \(\(w\_1\  = \ Simplify[w\_1, Element[n, Integers]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", w\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", {ReplaceAll[w\_1, n \[Rule] 0], 
          ReplaceAll[w\_1, n \[Rule] 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \!\(4\^\(1/2\)\) = \!\(e\^\(\(1\/2\) Log[4]\
\)\)\!\(\[ExponentialE]\^\(\(1\/2\) \[ImaginaryI]2n\[Pi]\)\)\>\""];\)\ \), "\n\
", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", \(e\^\(\(1\/2\) 
                Log[4]\)\) \[ExponentialE]\^\(\(1\/2\) \[ImaginaryI]\ 2  n\ \
\[Pi]\)];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", \(e\^\(\(1\/2\) Log[4]\)\) 
          ComplexExpand[\[ExponentialE]\^\(\(1\/2\) \[ImaginaryI]\ 2  n\ \
\[Pi]\)]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", \(e\^\(\(1\/2\) Log[4]\)\) 
          Simplify[\[ExponentialE]\^\(\(1\/2\) \[ImaginaryI]\ 2  n\ \[Pi]\), 
            Element[n, Integers]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", 
        Simplify[e\^\(\(1\/2\) Log[4]\)] 
          Simplify[\[ExponentialE]\^\(\(1\/2\) \[ImaginaryI]\ 2  n\ \[Pi]\), 
            Element[n, Integers]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", 
        Simplify[\[ExponentialE]\^\(\(1\/2\) \[ImaginaryI]\ 2  n\ \[Pi]\), 
          Element[n, Integers]], "\< \>", 
        Simplify[\[ExponentialE]\^\(\(1\/2\) Log[4]\)]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", {ReplaceAll[
            w\_2, {e \[Rule] \ \[ExponentialE], n \[Rule] 0}], 
          ReplaceAll[
            w\_2, {e \[Rule] \ \[ExponentialE], 
              n \[Rule] 1}]}];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tBecause ",
  Cell[BoxData[
      \(log \((z)\)\)]],
  " is multivalued, the function ",
  Cell[BoxData[
      \(z\^c\)]],
  " will, in general, be multivalued.  If we want to focus on a single value \
for ",
  Cell[BoxData[
      \(z\^c\)]],
  ", we can do so via the function defined for ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  " by\n\n",
  StyleBox["(5-22)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f \((z)\) = exp \((c\ Log \((z)\))\)\)]],
  "  \n\nwhich is called the principal branch of the multivalued function  ",
  Cell[BoxData[
      \(z\^c\)]],
  ".  Note that the principal branch of  ",
  Cell[BoxData[
      \(z\^c\)]],
  "  is obtained from Equation ",
  StyleBox["(5-21)",
    FontColor->RGBColor[0, 0, 1]],
  " by replacing  ",
  Cell[BoxData[
      \(log \((z)\)\)]],
  "  with the principal branch of the logarithm."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 5.7. ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Find the principal value of  ",
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   ",
  Cell[BoxData[
      \(\@\(1 + \[ImaginaryI]\)\)]],
  ",  and  ",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  Cell[BoxData[
      \(\((\[ImaginaryI])\)\^\[ImaginaryI]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution. From Example 5.3,  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(Log \((1 + \[ImaginaryI])\)\  = \ \(\(ln\ 2\)\/2 + \
\[ImaginaryI]  \[Pi]\/4\  = \ 
              ln\ 2\^\(1\/2\)\  + \ \[ImaginaryI]  \[Pi]\/4\)\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], "\n"}], "\n", 
      RowBox[{\(Log \((\[ImaginaryI])\)\), " ", "=", " ", 
        RowBox[{"\[ImaginaryI]", 
          RowBox[{\(\[Pi]\/2\), 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "  "
}], "Text"],

Cell[TextData[{
  "\nIdentity ",
  StyleBox["(5-22)",
    FontColor->RGBColor[0, 0, 1]],
  " yields the principal values of ",
  Cell[BoxData[
      \(\@\(1 + \[ImaginaryI]\)\)]],
  " and ",
  Cell[BoxData[
      \(\((\[ImaginaryI])\)\^\[ImaginaryI]\)]],
  ":  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\@\(1 + \[ImaginaryI]\)\ \  = \ \ \(\((1 + \
\[ImaginaryI])\)\^\(1\/2\)\ \  = \ \ exp[\(1\/2\) 
              Log \((1 + \[ImaginaryI])\)]\)\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\t\ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(exp[\(1\/2\) \((ln\ 2\^\(1\/2\)\  \
+ \ \[ImaginaryI]  \[Pi]\/4)\)]\ \  = \ \ exp[
            ln\ 2\^\(1\/4\)\  + \ \[ImaginaryI]\ \[Pi]\/8]\)\)\(\
\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(exp[
              ln\ 2\^\(1\/4\)] 
            exp[\[ImaginaryI]\ \[Pi]\/8]\ \  = \ \ \(2\^\(1\/4\)\) \((cos  \
\[Pi]\/8\  + \ \[ImaginaryI]\ sin  \[Pi]\/8)\)\)\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\t\ \ \ \ \ \ \ \ \(\(\[TildeTilde]\)\(\ \ \)\(1.09868411\ \ \
\[InvisibleSpace] + \ 0.45508986\ \ \[ImaginaryI]\)\)\)}]],
  "  \n\tand\n\t\t\t",
  Cell[BoxData[{
      \(\((\[ImaginaryI])\)\^\[ImaginaryI]\ \  = \ \ exp[\[ImaginaryI]\ Log \
\((\[ImaginaryI])\)]\), "\n", 
      \(\t\ \ \(\(=\)\(\ \ \)\(exp[\[ImaginaryI] \((\ \[ImaginaryI]  \
\[Pi]\/2)\)]\)\)\), "\n", 
      \(\t\ \ \(\(=\)\(\ \ \)\(exp[\(-\(\[Pi]\/2\)\)]\)\)\), "\n", 
      \(\t\ \(\(\[TildeTilde]\)\(\ \ \)\(0.20787957635\)\)\)}]],
  "\n\nNote that the result of raising a complex number to a complex power \
may be a real number in a nontrivial way.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.7 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Enter  ",
  Cell[BoxData[
      \(z\_0 = 1 + \[ImaginaryI]\)]],
  "  and find the principal value of  ",
  Cell[BoxData[
      \(\((1 + \[ImaginaryI])\)\^\(1/2\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, w];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[e];\)\ \), "\n", 
    \(\(z\_0\  = \ 1\  + \ \[ImaginaryI];\)\ \), "\n", 
    \(\(w\_0\  = \ ComplexExpand[Log[z\_0]];\)\ \), "\n", 
    \(\(w\_1\  = \ 
        ComplexExpand[\[ExponentialE]\^\(1\/2\ Log[z\_0]\)];\)\ \), "\n", 
    \(\(w\_2\  = \ ComplexExpand[\@z\_0];\)\ \), "\n", 
    \(\(w\_3\  = N[\@z\_0];\)\ \), "\n", 
    \(\(Print["\<Log[\>", z\_0, "\<] = \>", 
        w\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        e\^\(1\/2\ Log[z\_0]\), "\< = e\>", "\<\>"\^\*"\"\<\!\(1\/2\)\>\"", "\
\<\>"\^"\<[\>", "\<\>"\^w\_0, "\<\>"\^"\<]\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print[
        e\^\(1\/2\ Log[z\_0]\), "\< = e\>", "\<\>"\^"\<[\>", "\<\>"\^\(\(1\/2\
\) w\_0\), "\<\>"\^"\<]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        e\^\(1\/2\ Log[z\_0]\), "\< = e\>", "\<\>"\^"\<[\>", \
"\<\>"\^Expand[\(1\/2\) w\_0], "\<\>"\^"\<]\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[
        e\^\(1\/2\ Log[z\_0]\), "\< = e\>", "\<\>"\^"\<[\>", \
"\<\>"\^Re[Expand[\(1\/2\) w\_0]], "\<\>"\^"\<]\>", "\<e\>", "\<\>"\^"\<[\>", \
"\<\>"\^\(\[ImaginaryI]\ Im[Expand[\(1\/2\) w\_0]]\), "\<\>"\^"\<]\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print[e\^\(1\/2\ Log[z\_0]\), "\< = \>", w\_1];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<  \>", \@z\_0, "\< = \>", w\_2];\)\ \), "\n", 
    \(\(Print["\<  \>", \@z\_0, "\< = \>", 
        w\_3];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can try another value, this is just for fun!"
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, w];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[e];\)\ \), "\n", 
    \(\(z\_0\  = \ 1\  + \ \[ImaginaryI]\ \@3;\)\ \), "\n", 
    \(\(w\_0\  = \ ComplexExpand[Log[z\_0]];\)\ \), "\n", 
    \(\(w\_1\  = \ 
        ComplexExpand[\[ExponentialE]\^\(1\/2\ Log[z\_0]\)];\)\ \), "\n", 
    \(\(w\_2\  = \ ComplexExpand[\@z\_0];\)\ \), "\n", 
    \(\(w\_3\  = N[\@z\_0];\)\ \), "\n", 
    \(\(Print["\<Log[\>", z\_0, "\<] = \>", 
        w\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        e\^\(1\/2\ Log[z\_0]\), "\< = e\>", "\<\>"\^\*"\"\<\!\(1\/2\)\>\"", "\
\<\>"\^"\<[\>", "\<\>"\^w\_0, "\<\>"\^"\<]\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print[
        e\^\(1\/2\ Log[z\_0]\), "\< = e\>", "\<\>"\^"\<[\>", "\<\>"\^\(\(1\/2\
\) w\_0\), "\<\>"\^"\<]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        e\^\(1\/2\ Log[z\_0]\), "\< = e\>", "\<\>"\^"\<[\>", \
"\<\>"\^Expand[\(1\/2\) w\_0], "\<\>"\^"\<]\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[
        e\^\(1\/2\ Log[z\_0]\), "\< = e\>", "\<\>"\^"\<[\>", \
"\<\>"\^Re[Expand[\(1\/2\) w\_0]], "\<\>"\^"\<]\>", "\<e\>", "\<\>"\^"\<[\>", \
"\<\>"\^\(\[ImaginaryI]\ Im[Expand[\(1\/2\) w\_0]]\), "\<\>"\^"\<]\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print[e\^\(1\/2\ Log[z\_0]\), "\< = \>", w\_1];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<  \>", \@z\_0, "\< = \>", w\_2];\)\ \), "\n", 
    \(\(Print["\<  \>", \@z\_0, "\< = \>", 
        w\_3];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.7 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Find the principal value of  ",
  Cell[BoxData[
      \(\((\[ImaginaryI])\)\^\[ImaginaryI]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[z, w];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[e];\)\ \), "\n", 
    \(\(z\_0\  = \ \[ImaginaryI];\)\ \), "\n", 
    \(\(w\_0\  = \ ComplexExpand[Log[z\_0]];\)\ \), "\n", 
    \(\(w\_1\  = \ 
        ComplexExpand[\[ExponentialE]\^\(\[ImaginaryI]\ Log[z\_0]\)];\)\ \), \
"\n", 
    \(\(w\_2\  = \ ComplexExpand[\((z\_0)\)\^\[ImaginaryI]];\)\ \), "\n", 
    \(\(w\_3\  = N[\((z\_0)\)\^\[ImaginaryI]];\)\ \), "\n", 
    \(\(Print["\<    Log[\>", z\_0, "\<] = \>", 
        w\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        e\^\(\[ImaginaryI]\ Log[z\_0]\), "\< = e\>", "\<\>"\^"\<\[ImaginaryI]\
\>", "\<\>"\^"\<[\>", "\<\>"\^w\_0, "\<\>"\^"\<]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[
        e\^\(\[ImaginaryI]\ Log[z\_0]\), "\< = e\>", "\<\>"\^"\<[\>", \
"\<\>"\^\(\[ImaginaryI]\ w\_0\), "\<\>"\^"\<]\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[
        e\^\(\[ImaginaryI]\ Log[z\_0]\), "\< = e\>", "\<\>"\^"\<[\>", \
"\<\>"\^Expand[\[ImaginaryI]\ w\_0], "\<\>"\^"\<]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[
        e\^\(\[ImaginaryI]\ Log[z\_0]\), "\< = e\>", "\<\>"\^"\<[\>", \
"\<\>"\^Re[Expand[\[ImaginaryI]\ w\_0]], "\<\>"\^"\<]\>", "\<e\>", \
"\<\>"\^"\<[\>", "\<\>"\^\(\[ImaginaryI]\ Im[Expand[\[ImaginaryI]\ w\_0]]\), \
"\<\>"\^"\<]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[e\^\(\[ImaginaryI]\ Log[z\_0]\), "\< = \>", 
        w\_1];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<    \>", \((z\_0)\)\^\[ImaginaryI], "\< = \>", 
        w\_2];\)\ \), "\n", 
    \(\(Print["\<    \>", \((z\_0)\)\^\[ImaginaryI], "\< = \>", 
        w\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    \>", \((z\_0)\)\^\[ImaginaryI], "\< = \>", 
        Chop[w\_3]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[z_]\  = \ z\^\[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[\[ImaginaryI]] = \>", 
        f[\[ImaginaryI]]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[\[ImaginaryI]] = \>", 
        N[f[\[ImaginaryI]]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[\[ImaginaryI]] = \>", 
        Chop[N[f[\[ImaginaryI]]]]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[x, y, z];\)\ \), "\n", 
    \(\(TagSet[x, Im[x], 0];\)\ \), "\n", 
    \(\(TagSet[y, Im[y], 0];\)\ \), "\n", 
    \(\(TagSet[x, Re[x], x];\)\ \), "\n", 
    \(\(TagSet[y, Re[y], y];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<For other purely imaginary numbers, we have\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<    f[z] = \>", f[z]\ ];\)\), "\n", 
    \(\(Print["\<f[0+\[ImaginaryI] y] = \>", 
        f[0 + \[ImaginaryI]\ y]\ ];\)\), "\n", 
    \(\(w1 = ComplexExpand[f[0 + \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(Print["\<f[0+\[ImaginaryI] y] = \>", w1\ ];\)\), "\n", 
    \(\(w2 = 
        ReplaceAll[w1, Arg[\[ImaginaryI]\ y] \[Rule] \[Pi]\/2];\)\ \), "\n", 
    \(\(Print["\<f[0+\[ImaginaryI] y] = \>", w2\ ];\)\), "\n", 
    \(\(w3 = PowerExpand[w2];\)\), "\n", 
    \(\(Print["\<f[0+\[ImaginaryI] y] = \>", 
        w3\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(g[
          y_] = \[ExponentialE]\^\(\(-\[Pi]\)/2\)\ Cos[
              Log[y]] + \[ImaginaryI]\ \[ExponentialE]\^\(\(-\[Pi]\)/2\)\ Sin[
              Log[y]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[0+\[ImaginaryI]y] = g[y] = \>", 
        g[y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[0+\[ImaginaryI]y] = g[y] = \>", 
        Simplify[g[y]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< f[0+\[ImaginaryI]] = g[1] = \>", 
        g[1]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< f[0+\[ImaginaryI]] = g[1] = \>", 
        g[1.0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< f[0+\[ImaginaryI]] = g[1] = \>", 
        Chop[g[1.0]]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[{Re[g[y]], Im[g[y]]}, {y, 1, 110}, 
        PlotStyle \[Rule] Magenta, 
        Ticks \[Rule] {{{\(1\/2\) \[ExponentialE]\^\(\(-\[Pi]\)/2\), \
\*"\"\<\!\(1\/2\)\!\(\[ExponentialE]\^\(\(-\[Pi]\)/2\)\)\>\""}, {\
\[ExponentialE]\^\(\(-\[Pi]\)/2\), \*"\"\<     \
\!\(\[ExponentialE]\^\(\(-\[Pi]\)/2\)\)\>\""}, {\(\(-1\)\/2\) \[ExponentialE]\
\^\(\(-\[Pi]\)/2\), \*"\"\<\!\(\(-1\)\/2\)\!\(\[ExponentialE]\^\(\(-\[Pi]\)/2\
\)\)\>\""}, {\(-\[ExponentialE]\^\(\(-\[Pi]\)/2\)\), \*"\"\<-\!\(\
\[ExponentialE]\^\(\(-\[Pi]\)/2\)\)\>\""}}, {{\(1\/2\) \[ExponentialE]\^\(\(-\
\[Pi]\)/2\), \*"\"\<\!\(1\/2\)\!\(\[ExponentialE]\^\(\(-\[Pi]\)/2\)\)\>\""}, \
{\[ExponentialE]\^\(\(-\[Pi]\)/2\), \
\*"\"\<\!\(\[ExponentialE]\^\(\(-\[Pi]\)/2\)\)\>\""}, {\(\(-1\)\/2\) \
\[ExponentialE]\^\(\(-\[Pi]\)/2\), \
\*"\"\<\!\(\(-1\)\/2\)\!\(\[ExponentialE]\^\(\(-\[Pi]\)/2\)\)\>\""}, {\(-\
\[ExponentialE]\^\(\(-\[Pi]\)/2\)\), \
\*"\"\<-\!\(\[ExponentialE]\^\(\(-\[Pi]\)/2\)\)\>\""}}}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Points on the imaginary axis  z = 0+\[ImaginaryI]y  are \
mapped onto\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<the parametric curve ( \
\!\(\[ExponentialE]\^\(\(-\[Pi]\)/2\)\) Cos[Log[y]], \
\!\(\[ExponentialE]\^\(\(-\[Pi]\)/2\)\) Sin[Log[y] )\>\""\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<by the transformation  w = f[x+\[ImaginaryI]y] = \>", 
        f[z], "\< = \>", 
        f[x + \[ImaginaryI]\ y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<here we have\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[0+\[ImaginaryI]y] = g[y] = \>", 
        Simplify[g[y]]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<In general, we have\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]\ ];\)\), "\n", 
    \(\(Print["\<f[z] = \>", f[x + \[ImaginaryI]\ y]\ ];\)\), "\n", 
    \(\(w1 = ComplexExpand[f[x + \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", w1\ ];\)\), "\n", 
    \(\(w2 = 
        ReplaceAll[w1, 
          Abs[x + \[ImaginaryI]\ y] \[Rule] "\<|x+\[ImaginaryI] y|\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", w2\ ];\)\), "\[IndentingNewLine]", 
    \(\(w3 = 
        ReplaceAll[w2, 
          Arg[x + \[ImaginaryI]\ y] \[Rule] Arg[z]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", w3\ ];\)\), "\[IndentingNewLine]", 
    \(\(w4 = 
        ReplaceAll[
          w1, {Arg[x + \[ImaginaryI]\ y] \[Rule] Arg[z], 
            Log[Abs[x + \[ImaginaryI]\ y]] \[Rule] "\<ln|z|\>"}];\)\ \), "\n\
", 
    \(\(Print["\<f[z] = \>", w4\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[f, Iden, z];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^\[ImaginaryI];\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {\(-0.8\), 0.6, 0.1}, {0.101, 4.101, 
          0.20}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.8\), 
              0.65}, {0.0, 4.11}}, 
        AspectRatio \[Rule] 
          4.1\/1.45, \[IndentingNewLine]Ticks \[Rule] {{\(-0.8\), 0.6}, 
            Range[0, 4, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<A Rectangle in the z-plane.\>"];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(CartesianMap[
        f, \ {\(-0.8\), 0.6, 0.1}, {0.1, 4.1, 
          0.20}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.2\), 
              0.77}, {\(-0.7\), 0.25}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0.5, 1, 0.25], 
            Range[\(-1\), 1, 0.25]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \ \), "\n", 
    \(\(Print["\<The image in the w-plane under the mapping  w = \>", 
        f[z]];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_] = z\^\[ImaginaryI];\)\), "\[IndentingNewLine]", 
    \(\(Iden[z_]\  = \ z + \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(g[z_] = f[z + \[ImaginaryI]];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Iden, {0, 0.75, 
          0.05}, {0, \ \ 2  \[Pi], \ \(\(\ \)\(\[Pi]\)\)\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {0, 2}}, 
        AspectRatio \[Rule] 1\/1, 
        Ticks \[Rule] {Range[\(-1\), 1, 1\/4], {1\/4, 7\/4, 2}}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<A disk in the z-plane.\>"];\)\ \), "\n", 
    \(\(PolarMap[
        g\ , {0, 0.75, 
          0.05}, {0, \ \ 2  \[Pi], \ \(\(\ \)\(\[Pi]\)\)\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{0, 1\/2}, {\(-0.35\), 0.14}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {{1\/16, 
              1\/2}, {\(-3\)\/8, \(-1\)\/4, \(-1\)\/8, 1\/8, 1\/4}}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\n", 
    \(\(Print["\<The image in the w-plane under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -11.4063 -20.125 ]
[.125 -0.0125 11.4063 0 ]
[.25 -0.0125 -11.4063 -20.125 ]
[.25 -0.0125 11.4063 0 ]
[.375 -0.0125 -11.4063 -20.125 ]
[.375 -0.0125 11.4063 0 ]
[.625 -0.0125 -8.09375 -20.125 ]
[.625 -0.0125 8.09375 0 ]
[.75 -0.0125 -8.09375 -20.125 ]
[.75 -0.0125 8.09375 0 ]
[.875 -0.0125 -8.09375 -20.125 ]
[.875 -0.0125 8.09375 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[.5 .975 -5 0 ]
[.5 .975 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .95 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
gsave
.125 -0.0125 -72.4063 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.063 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.375 17.063 moveto
(\\200\\200) show
75.625 17.063 moveto
(\\200) show
77.688 17.063 moveto
(\\200) show
72.688 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -72.4063 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.063 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.375 17.063 moveto
(\\200\\200) show
75.625 17.063 moveto
(\\200) show
77.688 17.063 moveto
(\\200) show
72.688 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.375 0 m
.375 .00625 L
s
gsave
.375 -0.0125 -72.4063 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.063 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.375 17.063 moveto
(\\200\\200) show
75.625 17.063 moveto
(\\200) show
77.688 17.063 moveto
(\\200) show
72.688 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -69.0938 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -69.0938 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.875 0 m
.875 .00625 L
s
gsave
.875 -0.0125 -69.0938 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .95 L
s
gsave
.5 .975 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .95 L
0 .95 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
0 0 1 r
.525 .5 m
.525 .50019 L
.525 .50037 L
.52499 .50057 L
.52499 .50077 L
.52498 .50111 L
.52496 .50148 L
.52493 .50189 L
.52489 .50232 L
.52481 .50309 L
.5247 .50389 L
.52457 .50463 L
.52419 .5063 L
.52369 .50798 L
.52313 .50948 L
.52153 .5127 L
.51978 .51529 L
.51751 .51784 L
.51505 .51996 L
.51216 .52185 L
.51065 .52262 L
.50896 .52334 L
.50746 .52386 L
.50578 .52432 L
.50498 .5245 L
.50412 .52466 L
.50337 .52477 L
.50254 .52487 L
.50206 .52491 L
.50161 .52495 L
.50119 .52497 L
.50097 .52498 L
.50073 .52499 L
.50052 .52499 L
.50032 .525 L
.5001 .525 L
.5 .525 L
.49988 .525 L
.49968 .525 L
.49946 .52499 L
.49926 .52499 L
.49907 .52498 L
.49869 .52497 L
.49828 .52494 L
.49743 .52487 L
.49665 .52478 L
.49593 .52467 L
.49431 .52434 L
.49259 .52388 L
.49101 .52333 L
Mistroke
.48934 .52261 L
.48644 .52101 L
.48383 .51907 L
.48136 .51666 L
.47919 .51386 L
.47754 .51098 L
.47688 .5095 L
.47628 .50791 L
.47583 .50638 L
.4755 .50496 L
.47523 .50342 L
.47513 .50256 L
.47509 .50217 L
.47506 .50175 L
.47504 .50139 L
.47503 .5012 L
.47502 .501 L
.47501 .50081 L
.47501 .50064 L
.475 .50047 L
.475 .5003 L
.475 .50011 L
.475 .49991 L
.475 .49972 L
.475 .49955 L
.47501 .49934 L
.47502 .49912 L
.47503 .49872 L
.47506 .49833 L
.47509 .49792 L
.47516 .49716 L
.47528 .49627 L
.47541 .49546 L
.4758 .49372 L
.47628 .4921 L
.47752 .48907 L
.47901 .48643 L
.48083 .48395 L
.48318 .4815 L
.48567 .47952 L
.48861 .47774 L
.49164 .47644 L
.49322 .47594 L
.49413 .4757 L
.49499 .47551 L
.49579 .47536 L
.49666 .47522 L
.49745 .47513 L
.49819 .47507 L
.4986 .47504 L
Mistroke
.49899 .47502 L
.49921 .47501 L
.49941 .47501 L
.49952 .475 L
.49964 .475 L
.49976 .475 L
.49986 .475 L
.49998 .475 L
.5001 .475 L
.50021 .475 L
.50032 .475 L
.50051 .47501 L
.50072 .47501 L
.50095 .47502 L
.50116 .47503 L
.50164 .47505 L
.50207 .47509 L
.50246 .47512 L
.50336 .47523 L
.50414 .47535 L
.50497 .4755 L
.50638 .47583 L
.50792 .47629 L
.51088 .47749 L
.51386 .4792 L
.51649 .48121 L
.51894 .48368 L
.5209 .48628 L
.5224 .4889 L
.52312 .49049 L
.52369 .49202 L
.52413 .49345 L
.52449 .49498 L
.52471 .49621 L
.52481 .49692 L
.52488 .49758 L
.52493 .49819 L
.52497 .49875 L
.52498 .49905 L
.52499 .49922 L
.52499 .49939 L
.525 .49956 L
.525 .49971 L
.525 .49986 L
.525 .5 L
Mfstroke
1 0 0 r
.55 .5 m
.55 .50039 L
.54999 .50074 L
.54999 .50115 L
.54998 .50153 L
.54995 .50222 L
.54991 .50296 L
.54986 .50378 L
.54978 .50464 L
.54962 .50619 L
.54939 .50778 L
.54913 .50926 L
.54838 .51261 L
.54739 .51596 L
.54627 .51895 L
.54307 .5254 L
.53956 .53058 L
.53502 .53569 L
.53011 .53992 L
.52431 .54369 L
.52129 .54524 L
.51792 .54668 L
.51492 .54772 L
.51157 .54864 L
.50996 .549 L
.50823 .54932 L
.50673 .54954 L
.50509 .54974 L
.50412 .54983 L
.50323 .5499 L
.50237 .54994 L
.50194 .54996 L
.50146 .54998 L
.50103 .54999 L
.50064 .55 L
.50021 .55 L
.49999 .55 L
.49975 .55 L
.49935 .55 L
.49892 .54999 L
.49852 .54998 L
.49815 .54997 L
.49739 .54993 L
.49655 .54988 L
.49486 .54974 L
.49331 .54955 L
.49186 .54933 L
.48861 .54869 L
.48519 .54775 L
.48203 .54666 L
Mistroke
.47868 .54523 L
.47289 .54201 L
.46767 .53814 L
.46271 .53331 L
.45839 .52772 L
.45508 .52195 L
.45375 .51901 L
.45257 .51581 L
.45165 .51275 L
.45099 .50992 L
.45047 .50683 L
.45026 .50512 L
.45019 .50433 L
.45012 .5035 L
.45008 .50278 L
.45006 .5024 L
.45004 .50199 L
.45003 .50162 L
.45002 .50127 L
.45001 .50094 L
.45 .5006 L
.45 .50022 L
.45 .49982 L
.45 .49944 L
.45001 .49909 L
.45002 .49869 L
.45003 .49825 L
.45007 .49745 L
.45011 .49667 L
.45017 .49583 L
.45032 .49433 L
.45056 .49255 L
.45083 .49093 L
.4516 .48745 L
.45256 .48421 L
.45503 .47814 L
.45801 .47285 L
.46166 .4679 L
.46636 .46301 L
.47134 .45903 L
.47723 .45549 L
.48328 .45288 L
.48645 .45187 L
.48826 .4514 L
.48998 .45101 L
.49158 .45071 L
.49332 .45045 L
.49491 .45026 L
.49638 .45013 L
.4972 .45008 L
Mistroke
.49797 .45004 L
.49841 .45003 L
.49882 .45001 L
.49904 .45001 L
.49928 .45001 L
.49952 .45 L
.49973 .45 L
.49995 .45 L
.50019 .45 L
.50042 .45 L
.50063 .45 L
.50103 .45001 L
.50145 .45002 L
.5019 .45004 L
.50232 .45005 L
.50328 .45011 L
.50414 .45017 L
.50493 .45024 L
.50671 .45045 L
.50828 .45069 L
.50993 .451 L
.51277 .45166 L
.51585 .45258 L
.52176 .45498 L
.52773 .45839 L
.53298 .46241 L
.53787 .46735 L
.54179 .47255 L
.54481 .47781 L
.54624 .48097 L
.54739 .48404 L
.54825 .48689 L
.54898 .48996 L
.54942 .49243 L
.54962 .49384 L
.54977 .49516 L
.54987 .49638 L
.54994 .49749 L
.54996 .49811 L
.54998 .49843 L
.54999 .49878 L
.54999 .49911 L
.55 .49941 L
.55 .49972 L
.55 .5 L
Mfstroke
0 0 1 r
.575 .5 m
.575 .50058 L
.57499 .50111 L
.57498 .50172 L
.57496 .5023 L
.57493 .50333 L
.57487 .50444 L
.57479 .50566 L
.57468 .50696 L
.57442 .50928 L
.57409 .51167 L
.5737 .51389 L
.57258 .51891 L
.57108 .52394 L
.5694 .52843 L
.5646 .5381 L
.55934 .54587 L
.55253 .55353 L
.54516 .55988 L
.53647 .56554 L
.53194 .56786 L
.52688 .57002 L
.52239 .57158 L
.51735 .57297 L
.51495 .5735 L
.51235 .57398 L
.5101 .57432 L
.50763 .57461 L
.50618 .57474 L
.50484 .57484 L
.50356 .57492 L
.50291 .57494 L
.50219 .57497 L
.50155 .57498 L
.50096 .57499 L
.50031 .575 L
.49999 .575 L
.49963 .575 L
.49903 .57499 L
.49838 .57498 L
.49777 .57497 L
.49722 .57495 L
.49608 .5749 L
.49483 .57482 L
.4923 .5746 L
.48996 .57433 L
.48778 .574 L
.48292 .57303 L
.47778 .57163 L
.47304 .56999 L
Mistroke
.46802 .56784 L
.45933 .56302 L
.4515 .55721 L
.44407 .54997 L
.43758 .54158 L
.43261 .53293 L
.43063 .52851 L
.42885 .52372 L
.42748 .51913 L
.42649 .51489 L
.4257 .51025 L
.42539 .50768 L
.42528 .5065 L
.42518 .50525 L
.42512 .50417 L
.42509 .5036 L
.42506 .50299 L
.42504 .50242 L
.42502 .50191 L
.42501 .50142 L
.42501 .5009 L
.425 .50033 L
.425 .49973 L
.425 .49916 L
.42501 .49864 L
.42503 .49803 L
.42505 .49737 L
.4251 .49617 L
.42517 .495 L
.42526 .49375 L
.42548 .49149 L
.42584 .48882 L
.42624 .48639 L
.4274 .48117 L
.42884 .47631 L
.43255 .46721 L
.43702 .45928 L
.44249 .45186 L
.44954 .44451 L
.45701 .43855 L
.46584 .43323 L
.47493 .42932 L
.47967 .42781 L
.48239 .4271 L
.48497 .42652 L
.48737 .42607 L
.48998 .42567 L
.49236 .42539 L
.49457 .4252 L
.4958 .42512 L
Mistroke
.49696 .42506 L
.49762 .42504 L
.49823 .42502 L
.49856 .42501 L
.49893 .42501 L
.49927 .425 L
.49959 .425 L
.49993 .425 L
.50029 .425 L
.50063 .425 L
.50095 .42501 L
.50154 .42502 L
.50217 .42503 L
.50285 .42505 L
.50348 .42508 L
.50492 .42516 L
.50621 .42526 L
.50739 .42537 L
.51007 .42568 L
.51242 .42604 L
.5149 .4265 L
.51915 .42749 L
.52377 .42887 L
.53264 .43247 L
.54159 .43759 L
.54946 .44362 L
.55681 .45103 L
.56269 .45883 L
.56721 .46671 L
.56936 .47146 L
.57108 .47607 L
.57238 .48034 L
.57347 .48494 L
.57413 .48864 L
.57443 .49076 L
.57465 .49274 L
.5748 .49457 L
.57491 .49624 L
.57495 .49716 L
.57496 .49765 L
.57498 .49817 L
.57499 .49867 L
.57499 .49912 L
.575 .49957 L
.575 .5 L
Mfstroke
1 0 0 r
.6 .5 m
.6 .50078 L
.59999 .50148 L
.59997 .5023 L
.59995 .50307 L
.5999 .50443 L
.59982 .50592 L
.59971 .50755 L
.59957 .50928 L
.59923 .51238 L
.59878 .51556 L
.59827 .51853 L
.59677 .52521 L
.59477 .53191 L
.59254 .53791 L
.58614 .5508 L
.57911 .56116 L
.57004 .57138 L
.56021 .57984 L
.54863 .58738 L
.54259 .59048 L
.53584 .59336 L
.52985 .59544 L
.52314 .59729 L
.51993 .59799 L
.51647 .59863 L
.51346 .59909 L
.51018 .59948 L
.50824 .59966 L
.50646 .59979 L
.50474 .59989 L
.50388 .59992 L
.50292 .59996 L
.50207 .59998 L
.50128 .59999 L
.50041 .6 L
.49998 .6 L
.49951 .6 L
.4987 .59999 L
.49784 .59998 L
.49703 .59996 L
.4963 .59993 L
.49478 .59986 L
.4931 .59976 L
.48973 .59947 L
.48661 .5991 L
.48371 .59866 L
.47723 .59737 L
.47037 .59551 L
.46406 .59332 L
Mistroke
.45736 .59045 L
.44577 .58402 L
.43534 .57628 L
.42543 .56662 L
.41677 .55544 L
.41015 .5439 L
.40751 .53801 L
.40513 .53162 L
.40331 .52551 L
.40199 .51985 L
.40094 .51367 L
.40053 .51024 L
.40038 .50867 L
.40024 .50699 L
.40015 .50556 L
.40012 .5048 L
.40008 .50398 L
.40005 .50323 L
.40003 .50255 L
.40002 .50189 L
.40001 .5012 L
.4 .50044 L
.4 .49964 L
.40001 .49888 L
.40002 .49819 L
.40003 .49737 L
.40006 .49649 L
.40013 .4949 L
.40022 .49334 L
.40035 .49167 L
.40065 .48866 L
.40112 .48509 L
.40166 .48186 L
.4032 .4749 L
.40512 .46842 L
.41007 .45628 L
.41603 .4457 L
.42332 .43581 L
.43272 .42602 L
.44267 .41806 L
.45445 .41098 L
.46657 .40575 L
.4729 .40374 L
.47652 .4028 L
.47996 .40203 L
.48315 .40143 L
.48663 .4009 L
.48981 .40052 L
.49276 .40026 L
.4944 .40016 L
Mistroke
.49594 .40008 L
.49683 .40005 L
.49764 .40003 L
.49808 .40002 L
.49857 .40001 L
.49903 .4 L
.49946 .4 L
.4999 .4 L
.50039 .4 L
.50084 .4 L
.50126 .40001 L
.50206 .40002 L
.5029 .40004 L
.5038 .40007 L
.50465 .40011 L
.50656 .40022 L
.50827 .40034 L
.50986 .40049 L
.51343 .40091 L
.51656 .40138 L
.51987 .40199 L
.52554 .40332 L
.53169 .40515 L
.54352 .40996 L
.55546 .41679 L
.56595 .42483 L
.57574 .43471 L
.58359 .44511 L
.58961 .45562 L
.59248 .46195 L
.59477 .46809 L
.5965 .47379 L
.59796 .47992 L
.59885 .48486 L
.59924 .48768 L
.59953 .49032 L
.59974 .49276 L
.59987 .49498 L
.59993 .49621 L
.59995 .49686 L
.59997 .49756 L
.59998 .49822 L
.59999 .49882 L
.6 .49943 L
.6 .5 L
Mfstroke
0 0 1 r
.625 .5 m
.625 .50097 L
.62499 .50185 L
.62497 .50287 L
.62494 .50383 L
.62488 .50554 L
.62478 .5074 L
.62464 .50944 L
.62446 .5116 L
.62404 .51547 L
.62348 .51945 L
.62284 .52316 L
.62096 .53152 L
.61846 .53989 L
.61567 .54739 L
.60767 .5635 L
.59889 .57645 L
.58755 .58922 L
.57527 .5998 L
.56078 .60923 L
.55324 .6131 L
.5448 .6167 L
.53731 .6193 L
.52892 .62161 L
.52491 .62249 L
.52059 .62329 L
.51683 .62386 L
.51272 .62435 L
.51031 .62457 L
.50807 .62474 L
.50593 .62486 L
.50485 .62491 L
.50365 .62495 L
.50258 .62497 L
.5016 .62499 L
.50052 .625 L
.49998 .625 L
.49938 .625 L
.49838 .62499 L
.4973 .62497 L
.49629 .62494 L
.49537 .62491 L
.49347 .62483 L
.49138 .6247 L
.48716 .62434 L
.48327 .62388 L
.47964 .62333 L
.47153 .62172 L
.46296 .61939 L
.45507 .61665 L
Mistroke
.4467 .61307 L
.43222 .60503 L
.41917 .59535 L
.40678 .58328 L
.39597 .5693 L
.38769 .55488 L
.38438 .54751 L
.38142 .53953 L
.37914 .53189 L
.37749 .52481 L
.37617 .51709 L
.37566 .51281 L
.37547 .51084 L
.37531 .50874 L
.37519 .50695 L
.37514 .506 L
.3751 .50498 L
.37507 .50404 L
.37504 .50318 L
.37502 .50236 L
.37501 .5015 L
.375 .50055 L
.375 .49955 L
.37501 .4986 L
.37502 .49773 L
.37504 .49672 L
.37508 .49562 L
.37516 .49362 L
.37528 .49167 L
.37543 .48959 L
.37581 .48582 L
.3764 .48137 L
.37707 .47732 L
.379 .46862 L
.3814 .46052 L
.38758 .44534 L
.39503 .43213 L
.40415 .41976 L
.4159 .40752 L
.42834 .39758 L
.44306 .38872 L
.45821 .38219 L
.46612 .37968 L
.47064 .3785 L
.47495 .37753 L
.47894 .37679 L
.48329 .37612 L
.48727 .37565 L
.49094 .37533 L
.493 .3752 L
Mistroke
.49493 .3751 L
.49603 .37506 L
.49705 .37503 L
.4976 .37502 L
.49821 .37501 L
.49879 .37501 L
.49932 .375 L
.49988 .375 L
.50048 .375 L
.50105 .375 L
.50158 .37501 L
.50257 .37503 L
.50362 .37505 L
.50475 .37509 L
.50581 .37513 L
.5082 .37527 L
.51034 .37543 L
.51232 .37561 L
.51678 .37613 L
.5207 .37673 L
.52484 .37749 L
.53192 .37914 L
.53961 .38144 L
.55439 .38746 L
.56932 .39598 L
.58244 .40604 L
.59468 .41839 L
.60448 .43139 L
.61201 .44452 L
.6156 .45243 L
.61846 .46011 L
.62063 .46724 L
.62245 .4749 L
.62356 .48107 L
.62405 .48459 L
.62441 .4879 L
.62467 .49094 L
.62484 .49373 L
.62491 .49527 L
.62494 .49608 L
.62496 .49695 L
.62498 .49778 L
.62499 .49853 L
.625 .49929 L
.625 .5 L
Mfstroke
1 0 0 r
.65 .5 m
.65 .50116 L
.64998 .50222 L
.64996 .50344 L
.64993 .5046 L
.64985 .50665 L
.64974 .50888 L
.64957 .51133 L
.64935 .51392 L
.64885 .51856 L
.64817 .52334 L
.6474 .52779 L
.64515 .53782 L
.64216 .54787 L
.6388 .55686 L
.6292 .5762 L
.61867 .59174 L
.60506 .60706 L
.59032 .61976 L
.57294 .63107 L
.56388 .63572 L
.55376 .64004 L
.54477 .64316 L
.5347 .64593 L
.52989 .64699 L
.5247 .64795 L
.52019 .64863 L
.51526 .64922 L
.51237 .64949 L
.50968 .64969 L
.50712 .64983 L
.50582 .64989 L
.50438 .64994 L
.5031 .64997 L
.50192 .64999 L
.50062 .65 L
.49997 .65 L
.49926 .65 L
.49805 .64999 L
.49676 .64997 L
.49555 .64993 L
.49445 .6499 L
.49216 .6498 L
.48965 .64964 L
.48459 .64921 L
.47992 .64865 L
.47557 .648 L
.46584 .64606 L
.45556 .64326 L
.44609 .63998 L
Mistroke
.43604 .63568 L
.41866 .62603 L
.403 .61442 L
.38814 .59994 L
.37516 .58316 L
.36523 .56585 L
.36126 .55702 L
.3577 .54744 L
.35496 .53826 L
.35298 .52977 L
.35141 .5205 L
.35079 .51537 L
.35056 .513 L
.35037 .51049 L
.35023 .50834 L
.35017 .5072 L
.35012 .50597 L
.35008 .50485 L
.35005 .50382 L
.35003 .50283 L
.35001 .5018 L
.35 .50066 L
.35 .49946 L
.35001 .49831 L
.35002 .49728 L
.35005 .49606 L
.35009 .49474 L
.3502 .49235 L
.35033 .49001 L
.35052 .4875 L
.35097 .48299 L
.35168 .47764 L
.35249 .47279 L
.3548 .46235 L
.35768 .45262 L
.3651 .43441 L
.37404 .41855 L
.38498 .40371 L
.39908 .38902 L
.41401 .37709 L
.43168 .36646 L
.44985 .35863 L
.45935 .35561 L
.46477 .3542 L
.46995 .35304 L
.47473 .35214 L
.47995 .35135 L
.48472 .35078 L
.48913 .35039 L
.4916 .35024 L
Mistroke
.49391 .35012 L
.49524 .35008 L
.49645 .35004 L
.49712 .35003 L
.49785 .35002 L
.49855 .35001 L
.49919 .35 L
.49986 .35 L
.50058 .35 L
.50126 .35001 L
.50189 .35001 L
.50309 .35003 L
.50435 .35006 L
.5057 .35011 L
.50697 .35016 L
.50984 .35032 L
.51241 .35051 L
.51478 .35073 L
.52014 .35136 L
.52484 .35207 L
.5298 .35299 L
.53831 .35497 L
.54754 .35773 L
.56527 .36495 L
.58318 .37518 L
.59893 .38724 L
.61362 .40206 L
.62538 .41766 L
.63442 .43343 L
.63872 .44292 L
.64216 .45213 L
.64476 .46068 L
.64695 .46989 L
.64827 .47728 L
.64886 .48151 L
.6493 .48548 L
.64961 .48913 L
.64981 .49247 L
.64989 .49432 L
.64993 .4953 L
.64996 .49633 L
.64998 .49733 L
.64999 .49824 L
.65 .49915 L
.65 .5 L
Mfstroke
0 0 1 r
.675 .5 m
.67499 .50136 L
.67498 .50259 L
.67495 .50402 L
.67492 .50536 L
.67483 .50776 L
.67469 .51036 L
.6745 .51322 L
.67424 .51624 L
.67365 .52166 L
.67287 .52723 L
.67197 .53242 L
.66935 .54412 L
.66585 .55585 L
.66194 .56634 L
.65074 .5889 L
.63845 .60704 L
.62257 .62491 L
.60537 .63972 L
.5851 .65292 L
.57453 .65834 L
.56272 .66337 L
.55224 .66702 L
.54049 .67025 L
.53488 .67149 L
.52882 .67261 L
.52356 .67341 L
.51781 .67409 L
.51443 .6744 L
.5113 .67463 L
.5083 .6748 L
.50679 .67487 L
.50512 .67493 L
.50361 .67496 L
.50224 .67499 L
.50073 .675 L
.49997 .675 L
.49913 .675 L
.49773 .67499 L
.49622 .67496 L
.49481 .67492 L
.49352 .67488 L
.49086 .67476 L
.48793 .67458 L
.48203 .67407 L
.47657 .67343 L
.4715 .67266 L
.46015 .6704 L
.44815 .66714 L
.4371 .66331 L
Mistroke
.42538 .65829 L
.4051 .64704 L
.38684 .63349 L
.3695 .61659 L
.35436 .59702 L
.34277 .57683 L
.33813 .56652 L
.33398 .55534 L
.33079 .54464 L
.32848 .53474 L
.32664 .52392 L
.32592 .51793 L
.32566 .51517 L
.32543 .51224 L
.32527 .50973 L
.3252 .5084 L
.32514 .50697 L
.32509 .50566 L
.32506 .50446 L
.32503 .50331 L
.32501 .5021 L
.325 .50077 L
.325 .49936 L
.32501 .49803 L
.32503 .49683 L
.32506 .4954 L
.32511 .49386 L
.32523 .49107 L
.32539 .48834 L
.32561 .48542 L
.32613 .48015 L
.32695 .47392 L
.3279 .46825 L
.3306 .45607 L
.33396 .44473 L
.34261 .42348 L
.35305 .40498 L
.36581 .38767 L
.38226 .37053 L
.39968 .35661 L
.42029 .34421 L
.4415 .33507 L
.45257 .33155 L
.4589 .32989 L
.46494 .32855 L
.47052 .3275 L
.47661 .32657 L
.48217 .32591 L
.48732 .32546 L
.4902 .32527 L
Mistroke
.4929 .32514 L
.49445 .32509 L
.49586 .32505 L
.49664 .32503 L
.4975 .32502 L
.4983 .32501 L
.49905 .325 L
.49983 .325 L
.50068 .325 L
.50148 .32501 L
.50221 .32501 L
.5036 .32504 L
.50507 .32507 L
.50665 .32513 L
.50813 .32519 L
.51148 .32538 L
.51448 .3256 L
.51725 .32585 L
.5235 .32658 L
.52898 .32742 L
.53477 .32849 L
.54469 .3308 L
.55546 .33402 L
.57615 .34244 L
.59705 .35438 L
.61541 .36845 L
.63255 .38574 L
.64628 .40394 L
.65682 .42233 L
.66183 .43341 L
.66585 .44415 L
.66888 .45413 L
.67144 .46487 L
.67298 .4735 L
.67367 .47843 L
.67418 .48306 L
.67454 .48732 L
.67478 .49122 L
.67487 .49337 L
.67491 .49451 L
.67495 .49572 L
.67497 .49689 L
.67499 .49794 L
.675 .499 L
.675 .5 L
Mfstroke
1 0 0 r
.7 .5 m
.69999 .50155 L
.69998 .50296 L
.69995 .50459 L
.69991 .50613 L
.6998 .50887 L
.69965 .51184 L
.69943 .5151 L
.69914 .51856 L
.69846 .52475 L
.69756 .53112 L
.69654 .53705 L
.69354 .55043 L
.68954 .56383 L
.68507 .57582 L
.67227 .6016 L
.65823 .62233 L
.64008 .64275 L
.62043 .65968 L
.59725 .67476 L
.58518 .68095 L
.57168 .68671 L
.5597 .69088 L
.54627 .69457 L
.53986 .69599 L
.53294 .69727 L
.52692 .69818 L
.52035 .69896 L
.51649 .69932 L
.51291 .69958 L
.50949 .69977 L
.50776 .69985 L
.50585 .69991 L
.50413 .69996 L
.50256 .69998 L
.50083 .7 L
.49996 .7 L
.49901 .7 L
.4974 .69998 L
.49569 .69995 L
.49407 .69991 L
.49259 .69986 L
.48955 .69973 L
.48621 .69952 L
.47946 .69894 L
.47323 .6982 L
.46742 .69733 L
.45445 .69474 L
.44074 .69102 L
.42811 .68663 L
Mistroke
.41472 .68091 L
.39155 .66804 L
.37067 .65256 L
.35085 .63325 L
.33355 .61088 L
.3203 .5878 L
.31501 .57602 L
.31026 .56325 L
.30662 .55102 L
.30398 .5397 L
.30188 .52734 L
.30105 .52049 L
.30075 .51734 L
.30049 .51399 L
.30031 .51112 L
.30023 .5096 L
.30016 .50797 L
.3001 .50647 L
.30006 .50509 L
.30004 .50378 L
.30001 .5024 L
.3 .50089 L
.3 .49927 L
.30001 .49775 L
.30003 .49637 L
.30007 .49475 L
.30012 .49299 L
.30026 .4898 L
.30044 .48668 L
.3007 .48334 L
.30129 .47732 L
.30223 .47019 L
.30332 .46372 L
.3064 .4498 L
.31024 .43683 L
.32013 .41255 L
.33205 .3914 L
.34664 .37162 L
.36545 .35203 L
.38535 .33612 L
.4089 .32195 L
.43314 .31151 L
.4458 .30749 L
.45303 .30559 L
.45993 .30406 L
.46631 .30286 L
.47327 .30179 L
.47963 .30104 L
.48551 .30053 L
.4888 .30031 L
Mistroke
.49189 .30016 L
.49365 .3001 L
.49527 .30006 L
.49617 .30004 L
.49714 .30002 L
.49806 .30001 L
.49891 .3 L
.49981 .3 L
.50077 .3 L
.50169 .30001 L
.50252 .30002 L
.50412 .30004 L
.5058 .30008 L
.5076 .30014 L
.50929 .30022 L
.51312 .30043 L
.51655 .30069 L
.51971 .30097 L
.52685 .30181 L
.53312 .30276 L
.53974 .30399 L
.55108 .30663 L
.56338 .31031 L
.58703 .31993 L
.61091 .33357 L
.6319 .34966 L
.65149 .36942 L
.66718 .39022 L
.67922 .41123 L
.68495 .42389 L
.68954 .43618 L
.69301 .44758 L
.69593 .45985 L
.69769 .46971 L
.69848 .47535 L
.69906 .48064 L
.69947 .48551 L
.69975 .48997 L
.69986 .49243 L
.6999 .49373 L
.69994 .49511 L
.69997 .49644 L
.69999 .49765 L
.7 .49886 L
.7 .5 L
Mfstroke
0 0 1 r
.725 .5 m
.72499 .50175 L
.72498 .50333 L
.72494 .50517 L
.72489 .5069 L
.72478 .50998 L
.72461 .51332 L
.72436 .51699 L
.72403 .52088 L
.72327 .52785 L
.72226 .53501 L
.72111 .54168 L
.71773 .55673 L
.71323 .57181 L
.70821 .58529 L
.6938 .6143 L
.67801 .63762 L
.65759 .66059 L
.63548 .67964 L
.60941 .69661 L
.59583 .70357 L
.58064 .71005 L
.56716 .71474 L
.55206 .7189 L
.54484 .72049 L
.53705 .72193 L
.53029 .72295 L
.52289 .72383 L
.51855 .72423 L
.51452 .72453 L
.51067 .72475 L
.50873 .72483 L
.50658 .7249 L
.50465 .72495 L
.50288 .72498 L
.50093 .725 L
.49996 .725 L
.49889 .725 L
.49708 .72498 L
.49515 .72495 L
.49332 .7249 L
.49167 .72485 L
.48824 .72469 L
.48448 .72446 L
.47689 .72381 L
.46988 .72298 L
.46335 .722 L
.44876 .71909 L
.43333 .7149 L
.41913 .70996 L
Mistroke
.40406 .70352 L
.37799 .68905 L
.35451 .67163 L
.33221 .64991 L
.31274 .62474 L
.29784 .59878 L
.29189 .58552 L
.28655 .57115 L
.28244 .55739 L
.27948 .54466 L
.27711 .53076 L
.27618 .52305 L
.27585 .5195 L
.27555 .51574 L
.27535 .51252 L
.27526 .5108 L
.27518 .50896 L
.27512 .50727 L
.27507 .50573 L
.27504 .50425 L
.27502 .5027 L
.275 .501 L
.275 .49918 L
.27501 .49747 L
.27504 .49592 L
.27508 .49409 L
.27514 .49211 L
.27529 .48852 L
.2755 .48501 L
.27578 .48125 L
.27645 .47448 L
.27751 .46646 L
.27873 .45918 L
.2822 .44352 L
.28652 .42894 L
.29765 .40162 L
.31106 .37783 L
.32747 .35557 L
.34863 .33353 L
.37102 .31564 L
.39751 .2997 L
.42478 .28795 L
.43902 .28342 L
.44716 .28129 L
.45492 .27956 L
.4621 .27822 L
.46993 .27702 L
.47708 .27617 L
.4837 .27559 L
.4874 .27535 L
Mistroke
.49087 .27519 L
.49286 .27511 L
.49468 .27506 L
.49569 .27504 L
.49678 .27502 L
.49782 .27501 L
.49878 .275 L
.49978 .275 L
.50087 .275 L
.5019 .27501 L
.50284 .27502 L
.50463 .27505 L
.50652 .27509 L
.50855 .27516 L
.51045 .27524 L
.51476 .27548 L
.51862 .27577 L
.52218 .2761 L
.53021 .27704 L
.53726 .27811 L
.54471 .27949 L
.55746 .28246 L
.57131 .2866 L
.59791 .29742 L
.62478 .31277 L
.64839 .33087 L
.67042 .3531 L
.68807 .37649 L
.70163 .40014 L
.70807 .41438 L
.71324 .4282 L
.71713 .44103 L
.72042 .45483 L
.7224 .46592 L
.72328 .47227 L
.72394 .47822 L
.72441 .4837 L
.72472 .48871 L
.72484 .49148 L
.72489 .49294 L
.72493 .4945 L
.72496 .496 L
.72498 .49736 L
.725 .49872 L
.725 .5 L
Mfstroke
1 0 0 r
.75 .5 m
.74999 .50194 L
.74997 .5037 L
.74993 .50574 L
.74988 .50766 L
.74975 .51108 L
.74956 .5148 L
.74929 .51888 L
.74892 .5232 L
.74808 .53094 L
.74696 .5389 L
.74567 .54631 L
.74192 .56303 L
.73693 .57979 L
.73134 .59477 L
.71534 .627 L
.69779 .65291 L
.6751 .67844 L
.65053 .6996 L
.62156 .71845 L
.60647 .72619 L
.5896 .73339 L
.57462 .7386 L
.55784 .74322 L
.54982 .74498 L
.54117 .74659 L
.53365 .74772 L
.52544 .7487 L
.52061 .74915 L
.51614 .74948 L
.51186 .74972 L
.5097 .74981 L
.50731 .74989 L
.50516 .74995 L
.5032 .74998 L
.50104 .75 L
.49995 .75 L
.49876 .75 L
.49675 .74998 L
.49461 .74994 L
.49258 .74989 L
.49074 .74983 L
.48694 .74966 L
.48276 .7494 L
.47432 .74868 L
.46654 .74775 L
.45928 .74666 L
.44307 .74343 L
.42593 .73877 L
.41014 .73329 L
Mistroke
.3934 .72613 L
.36443 .71005 L
.33834 .6907 L
.31357 .66656 L
.29194 .6386 L
.27538 .60975 L
.26876 .59503 L
.26283 .57906 L
.25827 .56377 L
.25497 .54962 L
.25235 .53417 L
.25132 .52561 L
.25094 .52167 L
.25061 .51748 L
.25039 .51391 L
.25029 .51201 L
.2502 .50996 L
.25013 .50808 L
.25008 .50637 L
.25004 .50472 L
.25002 .503 L
.25 .50111 L
.25 .49909 L
.25002 .49719 L
.25004 .49547 L
.25009 .49343 L
.25015 .49123 L
.25033 .48724 L
.25056 .48335 L
.25087 .47917 L
.25161 .47165 L
.25279 .46274 L
.25415 .45465 L
.258 .43724 L
.2628 .42104 L
.27516 .39069 L
.29007 .36425 L
.3083 .33952 L
.33181 .31504 L
.35669 .29516 L
.38613 .27744 L
.41642 .26438 L
.43225 .25936 L
.44129 .25699 L
.44991 .25507 L
.45788 .25357 L
.46659 .25224 L
.47453 .2513 L
.48189 .25066 L
.486 .25039 L
Mistroke
.48986 .25021 L
.49207 .25013 L
.49409 .25007 L
.49521 .25005 L
.49642 .25003 L
.49758 .25001 L
.49864 .25 L
.49976 .25 L
.50097 .25 L
.50211 .25001 L
.50316 .25002 L
.50515 .25005 L
.50725 .25011 L
.50951 .25018 L
.51161 .25027 L
.5164 .25054 L
.52068 .25086 L
.52464 .25122 L
.53357 .25226 L
.5414 .25345 L
.54967 .25498 L
.56385 .25829 L
.57923 .26289 L
.60879 .27491 L
.63864 .29197 L
.66488 .31207 L
.68936 .33677 L
.70897 .36277 L
.72403 .38904 L
.73119 .40487 L
.73693 .42022 L
.74126 .43447 L
.74491 .44981 L
.74712 .46214 L
.74809 .46919 L
.74883 .4758 L
.74934 .48189 L
.74969 .48746 L
.74982 .49053 L
.74988 .49216 L
.74993 .49389 L
.74996 .49556 L
.74998 .49706 L
.75 .49858 L
.75 .5 L
Mfstroke
0 0 1 r
.775 .5 m
.77499 .50213 L
.77497 .50407 L
.77493 .50631 L
.77487 .50843 L
.77473 .51219 L
.77452 .51628 L
.77421 .52077 L
.77381 .52552 L
.77289 .53403 L
.77165 .54279 L
.77024 .55094 L
.76612 .56934 L
.76062 .58776 L
.75447 .60425 L
.73687 .6397 L
.71756 .6682 L
.69261 .69628 L
.66559 .71956 L
.63372 .7403 L
.61712 .74881 L
.59856 .75673 L
.58208 .76246 L
.56362 .76754 L
.55481 .76948 L
.54529 .77125 L
.53702 .7725 L
.52798 .77357 L
.52267 .77406 L
.51775 .77443 L
.51304 .77469 L
.51067 .77479 L
.50804 .77488 L
.50568 .77494 L
.50352 .77498 L
.50114 .775 L
.49995 .775 L
.49864 .775 L
.49643 .77498 L
.49407 .77494 L
.49184 .77488 L
.48982 .77481 L
.48563 .77462 L
.48103 .77435 L
.47175 .77355 L
.46319 .77253 L
.45521 .77133 L
.43737 .76777 L
.41852 .76265 L
.40116 .75662 L
Mistroke
.38274 .74875 L
.35088 .73106 L
.32217 .70977 L
.29492 .68322 L
.27113 .65246 L
.25292 .62073 L
.24564 .60453 L
.23911 .58697 L
.2341 .57015 L
.23047 .55458 L
.22758 .53759 L
.22645 .52817 L
.22604 .52384 L
.22567 .51923 L
.22543 .5153 L
.22532 .51321 L
.22522 .51095 L
.22514 .50889 L
.22509 .507 L
.22505 .50519 L
.22502 .50329 L
.225 .50122 L
.225 .499 L
.22502 .49691 L
.22505 .49501 L
.22509 .49278 L
.22517 .49036 L
.22536 .48597 L
.22561 .48168 L
.22596 .47709 L
.22677 .46881 L
.22807 .45901 L
.22956 .45011 L
.23381 .43097 L
.23908 .41314 L
.25268 .37976 L
.26907 .35068 L
.28914 .32348 L
.31499 .29654 L
.34236 .27467 L
.37474 .25518 L
.40806 .24082 L
.42547 .23529 L
.43542 .23269 L
.4449 .23058 L
.45367 .22893 L
.46325 .22747 L
.47199 .22643 L
.48008 .22572 L
.4846 .22543 L
Mistroke
.48884 .22523 L
.49128 .22514 L
.4935 .22508 L
.49473 .22505 L
.49607 .22503 L
.49733 .22501 L
.49851 .225 L
.49974 .225 L
.50106 .225 L
.50232 .22501 L
.50347 .22502 L
.50566 .22506 L
.50797 .22512 L
.51046 .2252 L
.51277 .2253 L
.51804 .22559 L
.52275 .22594 L
.5271 .22634 L
.53692 .22749 L
.54554 .2288 L
.55464 .23048 L
.57023 .23412 L
.58715 .23918 L
.61967 .2524 L
.65251 .27116 L
.68136 .29328 L
.7083 .32045 L
.72987 .34905 L
.74643 .37795 L
.75431 .39535 L
.76062 .41224 L
.76539 .42792 L
.7694 .44479 L
.77183 .45835 L
.7729 .46611 L
.77371 .47338 L
.77428 .48008 L
.77465 .4862 L
.7748 .48959 L
.77486 .49138 L
.77492 .49328 L
.77496 .49511 L
.77498 .49677 L
.775 .49843 L
.775 .5 L
Mfstroke
1 0 0 r
.8 .5 m
.79999 .50233 L
.79997 .50444 L
.79992 .50689 L
.79986 .5092 L
.7997 .5133 L
.79947 .51776 L
.79914 .52266 L
.79871 .52784 L
.79769 .53713 L
.79635 .54668 L
.79481 .55558 L
.79031 .57564 L
.78431 .59574 L
.77761 .61373 L
.75841 .6524 L
.73734 .68349 L
.71012 .71413 L
.68064 .73952 L
.64588 .76214 L
.62777 .77143 L
.60752 .78007 L
.58955 .78632 L
.56941 .79186 L
.55979 .79398 L
.54941 .7959 L
.54038 .79727 L
.53053 .79844 L
.52473 .79898 L
.51937 .79937 L
.51423 .79966 L
.51164 .79977 L
.50877 .79987 L
.5062 .79994 L
.50384 .79998 L
.50124 .8 L
.49994 .8 L
.49852 .8 L
.4961 .79997 L
.49353 .79993 L
.4911 .79987 L
.48889 .79979 L
.48433 .79959 L
.47931 .79929 L
.46919 .79841 L
.45984 .7973 L
.45114 .79599 L
.43168 .79212 L
.41111 .78653 L
.39217 .77995 L
Mistroke
.37208 .77136 L
.33732 .75206 L
.30601 .72884 L
.27628 .69987 L
.25032 .66632 L
.23045 .6317 L
.22252 .61403 L
.2154 .59487 L
.20992 .57653 L
.20597 .55955 L
.20282 .54101 L
.20158 .53073 L
.20113 .52601 L
.20073 .52098 L
.20046 .51669 L
.20035 .51441 L
.20024 .51195 L
.20016 .5097 L
.2001 .50764 L
.20005 .50567 L
.20002 .50359 L
.2 .50133 L
.2 .49891 L
.20002 .49663 L
.20005 .49456 L
.2001 .49212 L
.20018 .48948 L
.20039 .48469 L
.20067 .48002 L
.20104 .47501 L
.20194 .46598 L
.20335 .45528 L
.20498 .44558 L
.20961 .42469 L
.21536 .40525 L
.2302 .36883 L
.24808 .3371 L
.26997 .30743 L
.29817 .27805 L
.32802 .25419 L
.36335 .23293 L
.39971 .21726 L
.41869 .21123 L
.42955 .20839 L
.43989 .20608 L
.44946 .20429 L
.4599 .20269 L
.46944 .20156 L
.47827 .20079 L
.4832 .20047 L
Mistroke
.48783 .20025 L
.49048 .20015 L
.49291 .20008 L
.49425 .20006 L
.49571 .20003 L
.49709 .20001 L
.49837 .2 L
.49971 .2 L
.50116 .2 L
.50253 .20001 L
.50379 .20002 L
.50617 .20006 L
.50869 .20013 L
.51141 .20022 L
.51394 .20032 L
.51968 .20065 L
.52482 .20103 L
.52957 .20146 L
.54028 .20272 L
.54968 .20414 L
.55961 .20598 L
.57661 .20995 L
.59507 .21546 L
.63055 .22989 L
.66637 .25036 L
.69785 .27449 L
.72723 .30413 L
.75076 .33532 L
.76883 .36685 L
.77743 .38584 L
.78431 .40426 L
.78951 .42137 L
.79389 .43977 L
.79654 .45457 L
.79771 .46303 L
.79859 .47096 L
.79921 .47827 L
.79962 .48495 L
.79978 .48864 L
.79985 .49059 L
.79991 .49267 L
.79995 .49467 L
.79998 .49647 L
.8 .49829 L
.8 .5 L
Mfstroke
0 0 1 r
.825 .5 m
.82499 .50252 L
.82496 .50481 L
.82491 .50746 L
.82485 .50996 L
.82468 .51441 L
.82443 .51923 L
.82407 .52454 L
.8236 .53016 L
.8225 .54022 L
.82104 .55057 L
.81937 .56021 L
.8145 .58195 L
.808 .60372 L
.80074 .6232 L
.77994 .6651 L
.75712 .69878 L
.72763 .73197 L
.69569 .75948 L
.65803 .78399 L
.63841 .79405 L
.61648 .80341 L
.59701 .81018 L
.57519 .81618 L
.56477 .81848 L
.55352 .82056 L
.54375 .82204 L
.53307 .82331 L
.52679 .82389 L
.52098 .82432 L
.51542 .82463 L
.51261 .82476 L
.5095 .82486 L
.50671 .82493 L
.50416 .82497 L
.50135 .825 L
.49994 .825 L
.49839 .825 L
.49578 .82497 L
.49299 .82492 L
.49036 .82486 L
.48796 .82478 L
.48302 .82456 L
.47758 .82423 L
.46662 .82328 L
.4565 .82208 L
.44706 .82066 L
.42598 .81646 L
.4037 .81041 L
.38319 .80328 L
Mistroke
.36142 .79397 L
.32376 .77307 L
.28984 .74791 L
.25764 .71653 L
.22952 .68018 L
.20799 .64268 L
.19939 .62353 L
.19168 .60278 L
.18575 .5829 L
.18147 .56451 L
.17805 .54442 L
.17671 .5333 L
.17622 .52817 L
.1758 .52273 L
.1755 .51808 L
.17537 .51561 L
.17526 .51295 L
.17517 .51051 L
.17511 .50827 L
.17506 .50614 L
.17502 .50389 L
.175 .50144 L
.175 .49882 L
.17502 .49635 L
.17505 .49411 L
.17511 .49146 L
.1752 .4886 L
.17542 .48342 L
.17572 .47835 L
.17613 .47292 L
.1771 .46314 L
.17863 .45156 L
.18039 .44104 L
.18541 .41842 L
.19164 .39735 L
.20771 .3579 L
.22709 .32353 L
.2508 .29138 L
.28135 .25955 L
.31369 .2337 L
.35196 .21067 L
.39135 .1937 L
.41192 .18716 L
.42368 .18409 L
.43488 .18159 L
.44525 .17964 L
.45656 .17792 L
.46689 .17669 L
.47645 .17585 L
.4818 .17551 L
Mistroke
.48682 .17527 L
.48969 .17516 L
.49232 .17509 L
.49377 .17506 L
.49535 .17503 L
.49685 .17502 L
.49824 .175 L
.49969 .175 L
.50126 .175 L
.50274 .17501 L
.5041 .17503 L
.50669 .17507 L
.50942 .17514 L
.51236 .17523 L
.5151 .17535 L
.52132 .1757 L
.52689 .17611 L
.53203 .17658 L
.54364 .17794 L
.55382 .17949 L
.56457 .18148 L
.583 .18578 L
.603 .19175 L
.64143 .20738 L
.68023 .22955 L
.71434 .2557 L
.74617 .28781 L
.77166 .3216 L
.79124 .35576 L
.80055 .37633 L
.80801 .39629 L
.81364 .41482 L
.81838 .43475 L
.82125 .45078 L
.82252 .45994 L
.82347 .46854 L
.82415 .47646 L
.82459 .48369 L
.82477 .4877 L
.82484 .48981 L
.8249 .49206 L
.82495 .49422 L
.82498 .49618 L
.82499 .49815 L
.825 .5 L
Mfstroke
1 0 0 r
.85 .5 m
.84999 .50271 L
.84996 .50518 L
.84991 .50803 L
.84984 .51073 L
.84966 .51552 L
.84939 .52071 L
.849 .52643 L
.84849 .53248 L
.84731 .54332 L
.84574 .55445 L
.84394 .56484 L
.83869 .58825 L
.8317 .6117 L
.82388 .63268 L
.80147 .6778 L
.7769 .71407 L
.74514 .74981 L
.71075 .77944 L
.67019 .80584 L
.64906 .81667 L
.62544 .82675 L
.60447 .83404 L
.58097 .8405 L
.56975 .84298 L
.55764 .84522 L
.54711 .84681 L
.53561 .84818 L
.52886 .84881 L
.52259 .84927 L
.5166 .84961 L
.51357 .84974 L
.51023 .84985 L
.50723 .84993 L
.50448 .84997 L
.50145 .85 L
.49993 .85 L
.49827 .85 L
.49546 .84997 L
.49245 .84992 L
.48961 .84985 L
.48704 .84976 L
.48171 .84952 L
.47586 .84917 L
.46405 .84815 L
.45315 .84685 L
.44299 .84533 L
.42029 .8408 L
.3963 .83428 L
.3742 .82661 L
Mistroke
.35076 .81659 L
.31021 .79407 L
.27367 .76698 L
.23899 .73319 L
.20871 .69404 L
.18553 .65365 L
.17627 .63304 L
.16796 .61069 L
.16158 .58928 L
.15696 .56947 L
.15329 .54784 L
.15184 .53586 L
.15132 .53034 L
.15086 .52448 L
.15054 .51947 L
.1504 .51681 L
.15028 .51394 L
.15018 .51132 L
.15011 .50891 L
.15006 .50661 L
.15003 .50419 L
.15 .50155 L
.15 .49873 L
.15002 .49607 L
.15006 .49365 L
.15012 .49081 L
.15022 .48773 L
.15046 .48214 L
.15078 .47669 L
.15122 .47084 L
.15226 .46031 L
.15391 .44783 L
.15581 .4365 L
.16121 .41214 L
.16792 .38946 L
.18523 .34697 L
.20609 .30995 L
.23163 .27533 L
.26453 .24105 L
.29936 .21322 L
.34058 .18842 L
.38299 .17014 L
.40514 .1631 L
.4178 .15979 L
.42987 .1571 L
.44104 .155 L
.45322 .15314 L
.46435 .15182 L
.47464 .15092 L
.4804 .15055 L
Mistroke
.4858 .15029 L
.4889 .15018 L
.49173 .1501 L
.49329 .15006 L
.49499 .15004 L
.49661 .15002 L
.4981 .15001 L
.49966 .15 L
.50135 .15 L
.50295 .15001 L
.50442 .15003 L
.5072 .15007 L
.51014 .15015 L
.51331 .15025 L
.51626 .15038 L
.52296 .15075 L
.52896 .1512 L
.5345 .1517 L
.54699 .15317 L
.55796 .15483 L
.56954 .15698 L
.58938 .16161 L
.61092 .16804 L
.6523 .18488 L
.6941 .20875 L
.73083 .2369 L
.7651 .27148 L
.79256 .30788 L
.81364 .34466 L
.82367 .36681 L
.8317 .38831 L
.83776 .40826 L
.84287 .42973 L
.84596 .44699 L
.84733 .45686 L
.84836 .46612 L
.84908 .47464 L
.84956 .48244 L
.84975 .48675 L
.84983 .48902 L
.8499 .49145 L
.84994 .49378 L
.84998 .49589 L
.84999 .49801 L
.85 .5 L
Mfstroke
0 0 1 r
.875 .5 m
.87499 .50291 L
.87496 .50555 L
.8749 .50861 L
.87482 .51149 L
.87463 .51663 L
.87434 .52219 L
.87393 .52832 L
.87338 .5348 L
.87212 .54641 L
.87043 .55834 L
.86851 .56947 L
.86288 .59455 L
.85539 .61968 L
.84701 .64216 L
.82301 .6905 L
.79668 .72936 L
.76265 .76766 L
.7258 .7994 L
.68235 .82768 L
.65971 .83929 L
.6344 .85009 L
.61193 .85791 L
.58676 .86483 L
.57474 .86748 L
.56176 .86988 L
.55048 .87159 L
.53816 .87305 L
.53092 .87372 L
.52421 .87422 L
.51779 .87458 L
.51454 .87472 L
.51096 .87484 L
.50775 .87492 L
.50479 .87497 L
.50156 .875 L
.49993 .875 L
.49814 .875 L
.49513 .87497 L
.49191 .87491 L
.48887 .87483 L
.48611 .87474 L
.48041 .87449 L
.47413 .87411 L
.46148 .87302 L
.4498 .87163 L
.43892 .86999 L
.4146 .86515 L
.38889 .85816 L
.36522 .84994 L
Mistroke
.3401 .8392 L
.29665 .81508 L
.25751 .78605 L
.22035 .74984 L
.18791 .7079 L
.16307 .66463 L
.15315 .64254 L
.14425 .61859 L
.13741 .59566 L
.13246 .57443 L
.12852 .55126 L
.12697 .53842 L
.12641 .53251 L
.12592 .52623 L
.12558 .52086 L
.12543 .51801 L
.1253 .51494 L
.1252 .51212 L
.12512 .50955 L
.12507 .50708 L
.12503 .50449 L
.125 .50166 L
.125 .49864 L
.12502 .49579 L
.12506 .4932 L
.12513 .49015 L
.12523 .48685 L
.12549 .48087 L
.12583 .47502 L
.1263 .46876 L
.12742 .45747 L
.12919 .44411 L
.13122 .43197 L
.13701 .40587 L
.1442 .38156 L
.16275 .33603 L
.1851 .29638 L
.21246 .25928 L
.24771 .22256 L
.28503 .19273 L
.32919 .16616 L
.37463 .14658 L
.39837 .13903 L
.41193 .13549 L
.42486 .1326 L
.43683 .13036 L
.44988 .12836 L
.4618 .12695 L
.47283 .12599 L
.479 .12559 L
Mistroke
.48479 .12531 L
.4881 .12519 L
.49114 .1251 L
.49281 .12507 L
.49464 .12504 L
.49636 .12502 L
.49796 .12501 L
.49964 .125 L
.50145 .125 L
.50316 .12501 L
.50473 .12503 L
.50772 .12508 L
.51087 .12516 L
.51426 .12527 L
.51742 .1254 L
.5246 .12581 L
.53103 .12629 L
.53696 .12683 L
.55035 .1284 L
.5621 .13018 L
.57451 .13248 L
.59577 .13743 L
.61884 .14433 L
.66318 .16237 L
.70796 .18795 L
.74731 .21811 L
.78404 .25516 L
.81345 .29416 L
.83604 .33357 L
.84679 .3573 L
.85539 .38033 L
.86189 .40171 L
.86736 .42471 L
.87067 .44321 L
.87214 .45378 L
.87324 .4637 L
.87401 .47283 L
.87453 .48118 L
.87473 .4858 L
.87482 .48824 L
.87489 .49084 L
.87494 .49333 L
.87497 .49559 L
.87499 .49786 L
.875 .5 L
Mfstroke
1 0 0 r
.5 .5 m
.51521 .5 L
.5318 .5 L
.54738 .5 L
.56237 .5 L
.57832 .5 L
.59367 .5 L
.60999 .5 L
.62571 .5 L
.64084 .5 L
.65693 .5 L
.67243 .5 L
.68732 .5 L
.70319 .5 L
.71845 .5 L
.73469 .5 L
.75032 .5 L
.76536 .5 L
.78136 .5 L
.79677 .5 L
.81314 .5 L
.82892 .5 L
.8441 .5 L
.86024 .5 L
.875 .5 L
s
0 0 1 r
.5 .5 m
.51469 .50394 L
.53072 .50823 L
.54577 .51226 L
.56024 .51614 L
.57565 .52027 L
.59048 .52424 L
.60624 .52847 L
.62143 .53254 L
.63604 .53645 L
.65158 .54062 L
.66655 .54463 L
.68094 .54848 L
.69626 .55259 L
.71101 .55654 L
.72669 .56074 L
.74179 .56479 L
.75632 .56868 L
.77178 .57282 L
.78666 .57681 L
.80247 .58105 L
.81771 .58513 L
.83237 .58906 L
.84797 .59324 L
.86222 .59706 L
s
1 0 0 r
.5 .5 m
.51317 .50761 L
.52754 .5159 L
.54104 .52369 L
.55401 .53118 L
.56783 .53916 L
.58112 .54684 L
.59526 .555 L
.60887 .56286 L
.62197 .57042 L
.63591 .57847 L
.64933 .58621 L
.66223 .59366 L
.67596 .60159 L
.68919 .60923 L
.70324 .61734 L
.71678 .62516 L
.72981 .63268 L
.74367 .64068 L
.75701 .64839 L
.77119 .65657 L
.78485 .66446 L
.798 .67205 L
.81198 .68012 L
.82476 .6875 L
s
0 0 1 r
.5 .5 m
.51076 .51076 L
.52249 .52249 L
.53351 .53351 L
.5441 .5441 L
.55538 .55538 L
.56624 .56624 L
.57778 .57778 L
.58889 .58889 L
.59959 .59959 L
.61097 .61097 L
.62192 .62192 L
.63246 .63246 L
.64367 .64367 L
.65447 .65447 L
.66595 .66595 L
.677 .677 L
.68764 .68764 L
.69895 .69895 L
.70985 .70985 L
.72143 .72143 L
.73258 .73258 L
.74331 .74331 L
.75473 .75473 L
.76517 .76517 L
s
1 0 0 r
.5 .5 m
.50761 .51317 L
.5159 .52754 L
.52369 .54104 L
.53118 .55401 L
.53916 .56783 L
.54684 .58112 L
.555 .59526 L
.56286 .60887 L
.57042 .62197 L
.57847 .63591 L
.58621 .64933 L
.59366 .66223 L
.60159 .67596 L
.60923 .68919 L
.61734 .70324 L
.62516 .71678 L
.63268 .72981 L
.64068 .74367 L
.64839 .75701 L
.65657 .77119 L
.66446 .78485 L
.67205 .798 L
.68012 .81198 L
.6875 .82476 L
s
0 0 1 r
.5 .5 m
.50394 .51469 L
.50823 .53072 L
.51226 .54577 L
.51614 .56024 L
.52027 .57565 L
.52424 .59048 L
.52847 .60624 L
.53254 .62143 L
.53645 .63604 L
.54062 .65158 L
.54463 .66655 L
.54848 .68094 L
.55259 .69626 L
.55654 .71101 L
.56074 .72669 L
.56479 .74179 L
.56868 .75632 L
.57282 .77178 L
.57681 .78666 L
.58105 .80247 L
.58513 .81771 L
.58906 .83237 L
.59324 .84797 L
.59706 .86222 L
s
1 0 0 r
.5 .5 m
.5 .51521 L
.5 .5318 L
.5 .54738 L
.5 .56237 L
.5 .57832 L
.5 .59367 L
.5 .60999 L
.5 .62571 L
.5 .64084 L
.5 .65693 L
.5 .67243 L
.5 .68732 L
.5 .70319 L
.5 .71845 L
.5 .73469 L
.5 .75032 L
.5 .76536 L
.5 .78136 L
.5 .79677 L
.5 .81314 L
.5 .82892 L
.5 .8441 L
.5 .86024 L
.5 .875 L
s
0 0 1 r
.5 .5 m
.49606 .51469 L
.49177 .53072 L
.48774 .54577 L
.48386 .56024 L
.47973 .57565 L
.47576 .59048 L
.47153 .60624 L
.46746 .62143 L
.46355 .63604 L
.45938 .65158 L
.45537 .66655 L
.45152 .68094 L
.44741 .69626 L
.44346 .71101 L
.43926 .72669 L
.43521 .74179 L
.43132 .75632 L
.42718 .77178 L
.42319 .78666 L
.41895 .80247 L
.41487 .81771 L
.41094 .83237 L
.40676 .84797 L
.40294 .86222 L
s
1 0 0 r
.5 .5 m
.49239 .51317 L
.4841 .52754 L
.47631 .54104 L
.46882 .55401 L
.46084 .56783 L
.45316 .58112 L
.445 .59526 L
.43714 .60887 L
.42958 .62197 L
.42153 .63591 L
.41379 .64933 L
.40634 .66223 L
.39841 .67596 L
.39077 .68919 L
.38266 .70324 L
.37484 .71678 L
.36732 .72981 L
.35932 .74367 L
.35161 .75701 L
.34343 .77119 L
.33554 .78485 L
.32795 .798 L
.31988 .81198 L
.3125 .82476 L
s
0 0 1 r
.5 .5 m
.48924 .51076 L
.47751 .52249 L
.46649 .53351 L
.4559 .5441 L
.44462 .55538 L
.43376 .56624 L
.42222 .57778 L
.41111 .58889 L
.40041 .59959 L
.38903 .61097 L
.37808 .62192 L
.36754 .63246 L
.35633 .64367 L
.34553 .65447 L
.33405 .66595 L
.323 .677 L
.31236 .68764 L
.30105 .69895 L
.29015 .70985 L
.27857 .72143 L
.26742 .73258 L
.25669 .74331 L
.24527 .75473 L
.23483 .76517 L
s
1 0 0 r
.5 .5 m
.48683 .50761 L
.47246 .5159 L
.45896 .52369 L
.44599 .53118 L
.43217 .53916 L
.41888 .54684 L
.40474 .555 L
.39113 .56286 L
.37803 .57042 L
.36409 .57847 L
.35067 .58621 L
.33777 .59366 L
.32404 .60159 L
.31081 .60923 L
.29676 .61734 L
.28322 .62516 L
.27019 .63268 L
.25633 .64068 L
.24299 .64839 L
.22881 .65657 L
.21515 .66446 L
.202 .67205 L
.18802 .68012 L
.17524 .6875 L
s
0 0 1 r
.5 .5 m
.48531 .50394 L
.46928 .50823 L
.45423 .51226 L
.43976 .51614 L
.42435 .52027 L
.40952 .52424 L
.39376 .52847 L
.37857 .53254 L
.36396 .53645 L
.34842 .54062 L
.33345 .54463 L
.31906 .54848 L
.30374 .55259 L
.28899 .55654 L
.27331 .56074 L
.25821 .56479 L
.24368 .56868 L
.22822 .57282 L
.21334 .57681 L
.19753 .58105 L
.18229 .58513 L
.16763 .58906 L
.15203 .59324 L
.13778 .59706 L
s
1 0 0 r
.5 .5 m
.48479 .5 L
.4682 .5 L
.45262 .5 L
.43763 .5 L
.42168 .5 L
.40633 .5 L
.39001 .5 L
.37429 .5 L
.35916 .5 L
.34307 .5 L
.32757 .5 L
.31268 .5 L
.29681 .5 L
.28155 .5 L
.26531 .5 L
.24968 .5 L
.23464 .5 L
.21864 .5 L
.20323 .5 L
.18686 .5 L
.17108 .5 L
.1559 .5 L
.13976 .5 L
.125 .5 L
s
0 0 1 r
.5 .5 m
.48531 .49606 L
.46928 .49177 L
.45423 .48774 L
.43976 .48386 L
.42435 .47973 L
.40952 .47576 L
.39376 .47153 L
.37857 .46746 L
.36396 .46355 L
.34842 .45938 L
.33345 .45537 L
.31906 .45152 L
.30374 .44741 L
.28899 .44346 L
.27331 .43926 L
.25821 .43521 L
.24368 .43132 L
.22822 .42718 L
.21334 .42319 L
.19753 .41895 L
.18229 .41487 L
.16763 .41094 L
.15203 .40676 L
.13778 .40294 L
s
1 0 0 r
.5 .5 m
.48683 .49239 L
.47246 .4841 L
.45896 .47631 L
.44599 .46882 L
.43217 .46084 L
.41888 .45316 L
.40474 .445 L
.39113 .43714 L
.37803 .42958 L
.36409 .42153 L
.35067 .41379 L
.33777 .40634 L
.32404 .39841 L
.31081 .39077 L
.29676 .38266 L
.28322 .37484 L
.27019 .36732 L
.25633 .35932 L
.24299 .35161 L
.22881 .34343 L
.21515 .33554 L
.202 .32795 L
.18802 .31988 L
.17524 .3125 L
s
0 0 1 r
.5 .5 m
.48924 .48924 L
.47751 .47751 L
.46649 .46649 L
.4559 .4559 L
.44462 .44462 L
.43376 .43376 L
.42222 .42222 L
.41111 .41111 L
.40041 .40041 L
.38903 .38903 L
.37808 .37808 L
.36754 .36754 L
.35633 .35633 L
.34553 .34553 L
.33405 .33405 L
.323 .323 L
.31236 .31236 L
.30105 .30105 L
.29015 .29015 L
.27857 .27857 L
.26742 .26742 L
.25669 .25669 L
.24527 .24527 L
.23483 .23483 L
s
1 0 0 r
.5 .5 m
.49239 .48683 L
.4841 .47246 L
.47631 .45896 L
.46882 .44599 L
.46084 .43217 L
.45316 .41888 L
.445 .40474 L
.43714 .39113 L
.42958 .37803 L
.42153 .36409 L
.41379 .35067 L
.40634 .33777 L
.39841 .32404 L
.39077 .31081 L
.38266 .29676 L
.37484 .28322 L
.36732 .27019 L
.35932 .25633 L
.35161 .24299 L
.34343 .22881 L
.33554 .21515 L
.32795 .202 L
.31988 .18802 L
.3125 .17524 L
s
0 0 1 r
.5 .5 m
.49606 .48531 L
.49177 .46928 L
.48774 .45423 L
.48386 .43976 L
.47973 .42435 L
.47576 .40952 L
.47153 .39376 L
.46746 .37857 L
.46355 .36396 L
.45938 .34842 L
.45537 .33345 L
.45152 .31906 L
.44741 .30374 L
.44346 .28899 L
.43926 .27331 L
.43521 .25821 L
.43132 .24368 L
.42718 .22822 L
.42319 .21334 L
.41895 .19753 L
.41487 .18229 L
.41094 .16763 L
.40676 .15203 L
.40294 .13778 L
s
1 0 0 r
.5 .5 m
.5 .48479 L
.5 .4682 L
.5 .45262 L
.5 .43763 L
.5 .42168 L
.5 .40633 L
.5 .39001 L
.5 .37429 L
.5 .35916 L
.5 .34307 L
.5 .32757 L
.5 .31268 L
.5 .29681 L
.5 .28155 L
.5 .26531 L
.5 .24968 L
.5 .23464 L
.5 .21864 L
.5 .20323 L
.5 .18686 L
.5 .17108 L
.5 .1559 L
.5 .13976 L
.5 .125 L
s
0 0 1 r
.5 .5 m
.50394 .48531 L
.50823 .46928 L
.51226 .45423 L
.51614 .43976 L
.52027 .42435 L
.52424 .40952 L
.52847 .39376 L
.53254 .37857 L
.53645 .36396 L
.54062 .34842 L
.54463 .33345 L
.54848 .31906 L
.55259 .30374 L
.55654 .28899 L
.56074 .27331 L
.56479 .25821 L
.56868 .24368 L
.57282 .22822 L
.57681 .21334 L
.58105 .19753 L
.58513 .18229 L
.58906 .16763 L
.59324 .15203 L
.59706 .13778 L
s
1 0 0 r
.5 .5 m
.50761 .48683 L
.5159 .47246 L
.52369 .45896 L
.53118 .44599 L
.53916 .43217 L
.54684 .41888 L
.555 .40474 L
.56286 .39113 L
.57042 .37803 L
.57847 .36409 L
.58621 .35067 L
.59366 .33777 L
.60159 .32404 L
.60923 .31081 L
.61734 .29676 L
.62516 .28322 L
.63268 .27019 L
.64068 .25633 L
.64839 .24299 L
.65657 .22881 L
.66446 .21515 L
.67205 .202 L
.68012 .18802 L
.6875 .17524 L
s
0 0 1 r
.5 .5 m
.51076 .48924 L
.52249 .47751 L
.53351 .46649 L
.5441 .4559 L
.55538 .44462 L
.56624 .43376 L
.57778 .42222 L
.58889 .41111 L
.59959 .40041 L
.61097 .38903 L
.62192 .37808 L
.63246 .36754 L
.64367 .35633 L
.65447 .34553 L
.66595 .33405 L
.677 .323 L
.68764 .31236 L
.69895 .30105 L
.70985 .29015 L
.72143 .27857 L
.73258 .26742 L
.74331 .25669 L
.75473 .24527 L
.76517 .23483 L
s
1 0 0 r
.5 .5 m
.51317 .49239 L
.52754 .4841 L
.54104 .47631 L
.55401 .46882 L
.56783 .46084 L
.58112 .45316 L
.59526 .445 L
.60887 .43714 L
.62197 .42958 L
.63591 .42153 L
.64933 .41379 L
.66223 .40634 L
.67596 .39841 L
.68919 .39077 L
.70324 .38266 L
.71678 .37484 L
.72981 .36732 L
.74367 .35932 L
.75701 .35161 L
.77119 .34343 L
.78485 .33554 L
.798 .32795 L
.81198 .31988 L
.82476 .3125 L
s
0 0 1 r
.5 .5 m
.51469 .49606 L
.53072 .49177 L
.54577 .48774 L
.56024 .48386 L
.57565 .47973 L
.59048 .47576 L
.60624 .47153 L
.62143 .46746 L
.63604 .46355 L
.65158 .45938 L
.66655 .45537 L
.68094 .45152 L
.69626 .44741 L
.71101 .44346 L
.72669 .43926 L
.74179 .43521 L
.75632 .43132 L
.77178 .42718 L
.78666 .42319 L
.80247 .41895 L
.81771 .41487 L
.83237 .41094 L
.84797 .40676 L
.86222 .40294 L
s
1 0 0 r
.5 .5 m
.51521 .5 L
.5318 .5 L
.54738 .5 L
.56237 .5 L
.57832 .5 L
.59367 .5 L
.60999 .5 L
.62571 .5 L
.64084 .5 L
.65693 .5 L
.67243 .5 L
.68732 .5 L
.70319 .5 L
.71845 .5 L
.73469 .5 L
.75032 .5 L
.76536 .5 L
.78136 .5 L
.79677 .5 L
.81314 .5 L
.82892 .5 L
.8441 .5 L
.86024 .5 L
.875 .5 L
s
0 g
gsave
.45 .075 -72.0938 -14.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.063 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.063 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
75.188 17.063 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
81.188 17.063 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45 .925 -72.0938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.063 11.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 16.938 moveto
(\\200\\200) show
69.000 16.938 moveto
(\\200) show
71.063 16.938 moveto
(\\200) show
66.063 23.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
75.188 16.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
81.188 16.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{303.063, 287.875},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004_00017b000`400?l00000o`00003oo`3oool`
0?ooo`00o`3oool`0?ooo`00=03oool3000001/0oooo1000000N0?ooo`<00000>P3oool3000001`0
oooo1000000N0?ooo`<00000>P3oool003D0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo03T0oooo000b0?ooo`D00000703oool00`000000oooo0?oo
o`0L0?ooo`D00000>03oool5000001d0oooo00<000000?ooo`3oool0703oool5000003X0oooo000b
0?ooo`040000003oool0oooo000001h0oooo00<000000?ooo`3oool06`3oool010000000oooo0?oo
o`00000i0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool06`3oool010000000
oooo0?ooo`00000k0?ooo`00<`3oool00`000000oooo0000000L0?ooo`040000003oool0oooo0000
01d0oooo00<000000?ooo`000000>P3oool00`000000oooo0000000M0?ooo`040000003oool0oooo
000001d0oooo00<000000?ooo`000000>`3oool003@0oooo0P00000M0?ooo`8000007`3oool20000
03/0oooo0P00000N0?ooo`8000007`3oool2000003/0oooo003o0?oooc00oooo000X0?ooo`@00000
103oool800000140oooo100000030?ooo`P000004@3oool4000000<0oooo2000000e0?ooo`P00000
603oool4000000030?ooo`0000000000008000005`3oool4000000030?ooo`000000000000800000
>@3oool00?l0oooo<03oool00?l0oooo<03oool00180oooo1@00003i0?ooo`D000006P3oool001@0
oooo00<000000?ooo`3oool0703oool2000001d0oooo1@00000K0?ooo`D00000>03oool5000001`0
oooo1@00000L0?ooo`8000007`3oool00`000000oooo0?ooo`0J0?ooo`00503oool00`000000oooo
0?ooo`0K0?ooo`040000003oool0oooo000001h0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06`3oool010000000
oooo0?ooo`00000N0?ooo`030000003oool0oooo01X0oooo000<0?ooo`@00000103oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01X0oooo000D0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool06P3oool001<0oooo0P00000M0?ooo`040000003oool0oooo000001h0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool06`3oool010000000oooo0?ooo`00000M0?ooo`800000703oool003<0oooo
0P00000N0?ooo`8000007P3oool2000003/0oooo0P00000O0?ooo`8000007P3oool2000003`0oooo
003o0?oooc00oooo003o0?oooc00oooo003o0?oooa/0oooo0P0000000`3oool000000000000@0?oo
o`00o`3ooolL0?ooo`030000003oool000000140oooo000A0?ooool000000`0000090?ooo`030000
003oool0oooo0100oooo000A0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`050?ooo`80000000<0oooo000000000000403oool00140oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01X0oooo002A0?oo
o`030000003oool0oooo09/0oooo002A0?ooo`030000003oool0oooo09/0oooo002A0?ooo`030000
003oool0oooo09/0oooo002A0?ooo`030000003oool0oooo09/0oooo002A0?ooo`030000003oool0
oooo09/0oooo002A0?ooo`030000003oool0oooo09/0oooo002A0?ooo`030000003oool0oooo09/0
oooo002A0?ooo`030000003oool0oooo09/0oooo00210?ooo`<000003@3oool00`000000oooo0?oo
o`2K0?ooo`00PP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo09/0oooo001o0?oo
o`D000003@3oool00`000000oooo0?ooo`2K0?ooo`00O`3oool010000000oooo0?ooo`00000>0?oo
o`030000003oool0oooo09/0oooo00200?ooo`030000003oool0000000h0oooo00<000000?ooo`3o
ool0V`3oool00840oooo0P00000>0?ooo`030000003oool0oooo09/0oooo00290?ooo`D000000`3o
ool00`000000oooo0?ooo`2K0?ooo`00O@3oool8000000D0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`2K0?ooo`00RP3oool00`000000oooo000000040?ooo`030000003oool0oooo
09/0oooo002:0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0V`3oool008T0oooo
100000040?ooo`030000003oool0oooo09/0oooo002A0?ooo`030000003oool0oooo09/0oooo001o
0?ooo`D000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo09/0oooo00210?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0V`3oool00840oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`2K0?ooo`00P@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo09/0oooo00210?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0V`3o
ool00800oooo0P00000?0?ooo`030000003oool0oooo09/0oooo002A0?ooo`030000003oool0oooo
09/0oooo002A0?ooo`030000003oool0oooo09/0oooo002A0?ooo`030000003oool0oooo09/0oooo
00290?ooo`P0003o00<0o`000000o`000?l01P000?nE0?ooo`00P`3oool60000o`P0oooo00<0o`00
0?ooo`3oool01P3oool90000oh`0oooo001m0?ooo`H0003o3P3oool00`3o0000oooo0?ooo`0?0?oo
o`@0003oR03oool007P0oooo00<0003o0?ooo`000?l00P000?lD0?ooo`030?l0003oool0oooo01<0
oooo1@000?n30?ooo`00MP3oool40000oaL0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo
0000o`020000oh00oooo001c0?ooo`<0003o0P3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003o
ool0oooo01D0oooo00<0003o0?ooo`3oool00`3oool30000ogd0oooo001`0?ooo`<0003o1P3oool0
0`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool01P3oool2
0000og/0oooo001^0?ooo`80003o2@3oool00`000?l0oooo0?ooo`080?oooa/0o`002P3oool00`00
0?l0oooo0?ooo`080?ooo`80003oN@3oool006`0oooo0P000?l;0?ooo`030000o`3oool0oooo0080
oooo1P3o000=0?ooo`030?l0003oool0oooo00/0oooo1P3o00040?ooo`030000o`3oool0oooo00X0
oooo0P000?mg0?ooo`00J@3oool30000o`d0oooo00<0003o0?ooo`3o00000P3o000C0?ooo`030?l0
003oool0oooo0140oooo0P3o00000`3oool0003o0?ooo`0>0?ooo`80003oM@3oool006L0oooo0P00
0?l?0?ooo`80o`0000<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0C0?ooo`040?l00000
0?l0o`000?l000l0oooo0P000?mc0?ooo`00I@3oool20000o`h0oooo0`3o00020?ooo`030000o`3o
ool0oooo01@0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`050?l000`0oooo0P00
0?ma0?ooo`00H`3oool20000o`d0oooo0`3o00050?ooo`030000o`3oool0oooo01@0oooo00<0o`00
0?ooo`3oool0503oool00`000?l0oooo0?ooo`050?ooo`80o`00303oool20000ofl0oooo001Q0?oo
o`030?l000000?l0oooo00/0oooo0`3o00080?ooo`030000o`3oool0oooo00/0oooo2@000?l00`3o
0000003o0000o`080000o`/0oooo00<0003o0?ooo`3oool0203oool20?l000`0oooo0P000?l00`3o
0000oooo0?ooo`1Z0?ooo`00H03oool20000o`030?l0003oool0oooo00P0oooo0P3o000<0?ooo`03
0000o`3oool0oooo00D0oooo1@000?l90?ooo`030?l0003oool0oooo00P0oooo1@000?l60?ooo`03
0000o`3oool0oooo00X0oooo0P3o000;0?ooo`030?l000000?l0003o06/0oooo001N0?ooo`80003o
0P3oool00`3o0000oooo0?ooo`050?ooo`<0o`003P3oool00`000?l0oooo0000o`050000o`h0oooo
00<0o`000?ooo`3oool03@3oool40000o`80oooo00<0003o0?ooo`3oool0303oool20?l000T0oooo
00<0o`000?ooo`3oool00P000?mY0?ooo`00G@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo0080oooo0P3o000@0?ooo`<0003o503oool00`3o0000oooo0?ooo`0A0?ooo`D0003o3P3o
ool20?l000H0oooo00<0o`000?ooo`3oool00`3oool20000ofL0oooo001K0?ooo`80003o1P3oool0
0`3o0000oooo0?ooo`020?l000l0oooo0`000?l00`3oool0003o0?ooo`0D0?ooo`030?l0003oool0
oooo0180oooo00@0003o0?ooo`3oool0oooo10000?l<0?ooo`80o`000`3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo06@0oooo001J0?ooo`030000o`3oool0oooo00L0oooo0P3o000>
0?ooo`<0003o1@3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo0180oooo00<0003o
0?ooo`3oool01@3oool20000o``0oooo0P3o00000`3oool0o`000?ooo`080?ooo`80003oI03oool0
05P0oooo0P000?l:0?ooo`030?l0003oool0oooo00/0oooo0P000?l80?ooo`030000o`3oool0oooo
0100oooo1P3o000A0?ooo`030000o`3oool0oooo00L0oooo0`000?l;0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool0H@3oool005L0oooo00<0003o0?ooo`3oool0203oool20?l00003
0?ooo`3o0000oooo00P0oooo0`000?l:0?ooo`030000o`3oool0oooo00L0oooo2@3o00020?ooo`03
0?l0003oool0oooo00T0o`002@3oool00`000?l0oooo0?ooo`0:0?ooo`80003o2@3oool30?l000/0
oooo00<0003o0?ooo`3oool0H03oool005H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo00@0oooo0P000?l>0?ooo`040000o`3oool0oooo0?ooo`D0
o`002`3oool00`3o0000oooo0?ooo`090?ooo`H0o`000P3oool00`000?l0oooo0?ooo`0=0?ooo`80
003o1P3oool0103o0000oooo0?ooo`3oool20?l000X0oooo00<0003o0?ooo`3oool0G`3oool005@0
oooo0P000?l90?ooo`80o`001@3oool00`3o0000oooo0?ooo`020?ooo`80003o3`3oool00`3o0000
003o0?l000020?l00100oooo00<0o`000?ooo`3oool03`3oool20?l000030000o`3o0000o`0000l0
oooo0P000?l40?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool20000oel0
oooo001C0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool0103o0000oooo
0000o`000?l?0?ooo`80o`000P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool0103o000=0?ooo`80003o00<0oooo0?l0003oool01P3oool20?l000X0
oooo00<0003o0?ooo`3oool0G03oool00540oooo0P000?l:0?ooo`030?l0003oool0oooo00L0oooo
00<0o`000000o`3oool03@3oool30?l000@0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo00@0oooo0P3o000=0?ooo`030?l0003oool0oooo00P0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`1K0?ooo`00D03oool00`000?l0oooo0?oo
o`080?ooo`80o`002@3oool00`000?l0oooo0?l0000<0?ooo`80o`001`3oool00`000?l0oooo0?oo
o`0@0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool20?l000/0oooo00<0
o`000000o`000?l02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo05X0oooo001?
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool20000o`80oooo00<0o`00
0?ooo`3oool01`3oool30?l000X0oooo00<0003o0?ooo`3oool0203oool70000o`030?l000000?l0
003o00H0003o2P3oool00`000?l0oooo0?ooo`090?ooo`80o`00203oool0103o0000oooo0?ooo`3o
ool20000o`P0oooo0P3o00090?ooo`030000o`3oool0oooo05T0oooo001>0?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool01P3oool20000o`D0oooo00<0o`000?ooo`3oool0103oool2
0?l000d0oooo00@0003o0?ooo`3oool0oooo1`000?l70?ooo`030?l0003oool0oooo00H0oooo1`00
0?l30?ooo`030000o`3oool0oooo00/0oooo0P3o00060?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo05P0oooo001=
0?ooo`030000o`3oool0oooo00L0oooo0P3o00080?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool00P3oool20?l000l0oooo10000?l>0?ooo`030?l0003oool0oooo00d0oooo10000?l?
0?ooo`80o`000`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo0P3o0008
0?ooo`80003oF03oool004`0oooo00<0003o0?ooo`000?l01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00L0oooo00@0o`000?ooo`3o0000o`003`3oool30000oa40oooo00<0o`00
0?ooo`3oool03`3oool010000?l0oooo0000o`000?l?0?ooo`80o`0000<0oooo0?l0003oool01`3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0E`3o
ool004/0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool0203oool20?l000d0oooo10000?l30?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool03`3oool010000?l0oooo0?ooo`3oool30000o`h0oooo0P3o00090?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0000o`1H0?ooo`00B`3o
ool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00002@3oool00`000?l0oooo
0?ooo`070?ooo`80o`0000<0oooo0?l0003oool02P3oool20000o`L0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00@0oooo0P000?l<0?ooo`040?l0
003oool0o`000?l000P0oooo0P000?l90?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`00
0?l0oooo0?ooo`1E0?ooo`00BP3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0o`0000P0
oooo0P000?l80?ooo`80o`00103oool00`3o0000oooo0?ooo`060?ooo`80003o2@3oool00`000?l0
oooo0?ooo`0:0?ooo`X0o`00303oool00`000?l0oooo0?ooo`060?ooo`<0003o203oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0000o`050?ooo`030000o`3oool0oooo05@0oooo00190?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool20000o``0oooo00<0003o0?ooo`3oool00P3oool70?l000@0oooo
00<0o`000?ooo`3oool00`3oool60?l000D0oooo00<0003o0?ooo`3oool02P3oool20000o`H0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1C0?ooo`00B03oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0003o00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`040?l0003oool0oooo0?ooo`80003o3P3oool00`000?l0o`000?l000020?l000/0oooo
00<0o`000?ooo`3oool02@3oool50?l000030000o`3oool0oooo00`0oooo0P000?l30?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0o`0000L0oooo00<0003o0?ooo`3oool0DP3oool004L0oooo00<0003o0?ooo`3oool01P3o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`040?l0003oool0003o0000o`h0oooo0P3o00000`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?l0003o00003P3oool20000o`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?oo
o`3o00001`3oool00`000?l0oooo0?ooo`1A0?ooo`00AP3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`090?ooo`030?l0003oool0oooo
00T0oooo00<0o`000?ooo`3oool02P3oool40?l00080oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0=0?ooo`040000o`3oool0oooo0?ooo`<0o`00303oool00`3o0000003o0000o`09
0?ooo`80o`00203oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`1@0?ooo`00A@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`000?l0203oool20?l000X0oooo0P000?l00`3o0000oooo0?ooo`08
0?ooo`80o`001`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool0103oool20?l000X0oooo00<0o`000?ooo`3oool00P000?l90?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`000?l01`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo0500oooo00150?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo0P000?l30?ooo`030?l0003oool0oooo
00@0oooo0`3o00090?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`060?ooo`80o`001`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool20000o`P0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`1?0?ooo`00A03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`000?l01P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00@0
oooo00@0o`000?ooo`3oool0oooo0P3o000<0?ooo`030000o`3oool0oooo00D0oooo1`000?l00`3o
0000003o0000o`060000o`L0oooo00<0003o0?ooo`3oool0203oool20?l000D0oooo00<0o`000?oo
o`3oool0103oool20000o`P0oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?ooo`000?l8
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0CP3oool004<0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l0103oool0
0`3o0000oooo0?ooo`070?ooo`80003o1`3oool0103o0000oooo0?l0003o000>0?ooo`030000o`3o
ool0003o00D0003o1`3oool00`3o0000oooo0?ooo`060?ooo`D0003o00<0oooo0000o`3oool0303o
ool20?l00080oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0C@3oool00480oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`002@3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00d0oooo0`000?l=0?ooo`030?l0003o
ool0oooo00/0oooo0`000?l>0?ooo`<0o`002P3oool00`000?l0oooo0?ooo`060?ooo`040?l0003o
ool0oooo0000o`H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo04`0oooo00120?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3o0000oooo00P0oooo00<0003o0?ooo`3oool01`3o
ool20?l000030?ooo`3o0000oooo00T0oooo10000?l20?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0000o`030000o`/0oooo0`3o000:0?ooo`80003o1`3o
ool00`3o0000003o0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`1<0?ooo`00@@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000003o0?ooo`060?ooo`80003o203oool2
0?l000<0oooo00<0o`000?ooo`3oool01P3oool20000o`H0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00<0oooo0P000?l90?ooo`030?l0003oool0
oooo0080o`002P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o0000o`0000P0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo04/0oooo00100?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo0080003o103oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool20000o`P0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00H0oooo0P000?l60?ooo`030?l0003oool0oooo
00<0oooo0P3o00090?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l00007
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`1:
0?ooo`00?`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`040000o`3oool0oooo0000o`T0oooo00<0o`00
0?ooo`3oool01@3oool0103o0000oooo0?ooo`3oool20000o`/0oooo00<0003o0?ooo`3oool01@3o
ool;0?l000P0oooo00<0003o0?ooo`3oool0203oool20000o`<0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo0000o`D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
B@3oool003l0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool20000o`T0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000003o0000o`0=0?ooo`030000o`3oool0oooo00D0o`001@3oool00`3o0000oooo0?oo
o`030?ooo`H0o`000P3oool00`000?l0oooo0?ooo`0:0?ooo`80003o00<0o`000?ooo`3oool0203o
ool00`3o0000oooo0?ooo`070?ooo`80003o1`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`190?ooo`00?P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`80003o1`3oool20?l000T0oooo00<0003o0?l0003oool0303oool2
0?l000030000o`3o0000o`0000X0oooo00<0o`000?ooo`3oool02@3oool20?l000030000o`3oool0
oooo00`0oooo00<0o`000000o`3oool02@3oool20?l000L0oooo0P000?l80?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo04P0oooo000n0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00@0003o0?ooo`3oool0003o1@3oool0
0`3o0000oooo0?ooo`070?ooo`80003o0P3oool00`3o0000oooo0?ooo`080?ooo`80o`000P3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o00000`3o0009
0?ooo`030?l0003oool0oooo0080003o2P3oool00`3o0000oooo0?ooo`030?ooo`040000o`3oool0
oooo0000o`L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?l0003oool0B03oool003d0oooo00@0003o0?ooo`3o0000o`00103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00002@3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00D0oooo0P3o00050?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`030?ooo`<0o`001@3oool00`3o0000oooo
0?ooo`030?ooo`80003o2@3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool00P3oool20?l000030000o`3oool0oooo04L0oooo000m0?ooo`050000o`3oool0oooo0?ooo`3o
00000`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0o`0000T0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`030?ooo`80o`001`3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool01P3oool20?l000<0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0003o00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00D0o`000?ooo`3o
ool0oooo0?l000030?ooo`030000o`3oool0oooo04H0oooo000l0?ooo`030000o`3oool0oooo00<0
oooo0`3o00060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`020?l000T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00P0oooo0`3o00090?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool30?l000@0oooo00<0003o0?ooo`3oool0AP3oool003`0oooo00<0003o0?ooo`3oool0
103oool30?l000@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`000?l01P3oool20000o`T0oooo0`3o000;0?ooo`030000
o`3oool0oooo0080oooo1`000?l00`3o0000003o0000o`060000o`<0oooo00<0003o0?ooo`3oool0
2P3oool20?l000X0oooo0P000?l60?ooo`030000o`3o0000oooo00L0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo0P3o00070?ooo`030000
o`3oool0oooo04D0oooo000k0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00P3o
00020?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`080?ooo`<0o`00
2`3oool60000o`L0oooo00<0o`000?ooo`3oool01P3oool50000o`/0oooo00@0o`000?ooo`3o0000
o`002P3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000P0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo0?ooo`80o`000P3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo04D0oooo000k0?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000003o0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`040000o`3oool0oooo
0000o`T0oooo0P3o00020?ooo`030?l0003oool0oooo00L0oooo0P000?l20?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0000o`020000o`L0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`080?ooo`040000o`3oool0oooo0000o`@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3o0000103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo04@0oooo000k
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool20?l000D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo0P000?l9
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool20000o`@0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo0080oooo0P000?l5
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool20000o`H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo0P3o0006
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0A03oool003X0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080o`000P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool20000
o`P0oooo00<0o`000?ooo`3oool01@3oool0103o0000oooo0?ooo`3oool20000o`H0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00D0oooo0P000?l3
0?ooo`030?l0003oool0oooo00@0oooo0P3o00080?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`040?l0003oool0oooo0?ooo`80o`0000<0
oooo0000o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo04<0oooo000j
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`02
0?ooo`<0o`001`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00@0003o
0?ooo`3oool0003o1P3oool00`3o0000oooo0?ooo`060?ooo`040?l0003oool0oooo0000o`T0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo
0P000?l00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`000?l0
203oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo0`3o00030?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`130?ooo`00>@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool20?l000H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`080?ooo`030?l00000
0?l0oooo00T0oooo00<0003o0?ooo`3oool00P3oool;0?l000D0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000003o0?ooo`080?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0000o`070?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool20?l000H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0480oooo
000i0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`040?l0003oool0o`000?l000<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l000090?ooo`80
003o00<0o`000?ooo`3oool02@3oool00`000?l0o`000?l000020?l000D0oooo00<0o`000?ooo`3o
ool00`3oool50?l000030000o`3oool0oooo00P0oooo00@0o`000?ooo`3oool0003o2@3oool0103o
0000oooo0?ooo`000?l50?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
10000?l0oooo0?ooo`3oool20?l00080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0@P3oool003P0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00P3oool20?l000030?ooo`000?l0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0o`0000P0oooo0P000?l30?ooo`030?l0003oool0
oooo00D0oooo0`3o00000`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00@0003o
0?ooo`3o0000o`00203oool01@3o0000oooo0?ooo`3oool0003o00T0oooo00<0o`000000o`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool0
o`001@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`110?ooo`00>03oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`80o`00
103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00@0003o0?ooo`3oool0
oooo0P3o00050?ooo`030?l0003oool0oooo00<0oooo0P000?l70?ooo`030000o`3o0000oooo00L0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o0000oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0@@3oool003P0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0o`00
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0000o`050?ooo`80003o1`3oool00`3o0000oooo0?ooo`020?l000H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo0P3o00030?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o00070?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool20?l000030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0@03oool003L0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`020?l00080oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`050?l0
003oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`080?ooo`80o`00203oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool30?l000T0
oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`020?l000<0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`100?ooo`00=`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080
oooo0`3o00070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool30000o`T0
oooo0`3o000:0?ooo`030000o`3oool0oooo00D0oooo00<0o`000000o`3oool01P3oool00`000?l0
oooo0?ooo`070?ooo`<0o`002@3oool00`000?l0oooo0000o`060?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool20?l000D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`100?ooo`00=P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00@0o`000?ooo`3o0000o`00103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo0P000?l80?ooo`050?l0003oool0oooo0?ooo`3o00002@3oool80000o`030?l000000?l0003o
00D0003o00<0oooo0000o`3oool01`3oool01@3o0000oooo0?ooo`3oool0o`0000T0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo0`3o0007
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0?`3oool003H0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`000?l01P3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo0`000?l70?ooo`030?l0003oool0
oooo00D0oooo10000?l50?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0000o`070?ooo`030?l0003oool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`0o0?ooo`00=P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0000o`070?ooo`030?l0003oool0oooo00D0oooo00D0003o
0?ooo`3oool0oooo0000o`030?ooo`80o`001P3oool00`3o0000oooo0?ooo`020?ooo`80003o0P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0oooo
0P000?l30?ooo`030?l0003oool0oooo00@0oooo0P3o00040?ooo`050000o`3oool0oooo0?ooo`00
0?l01`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0o`0000@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo03l0oooo000e0?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`80o`00
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o0000
203oool00`3o0000oooo0?ooo`020000o`D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o00002@3oool0103o0000oooo
0?ooo`000?l50?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool20?l000H0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo03l0
oooo000e0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`040000o`3oool0oooo0?l000@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0o`000000o`3oool01P3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l0
o`000?ooo`090?ooo`030?l000000?l0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0003o00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo03h0oooo000e0?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo0?ooo`80
o`0000<0oooo0?l0003oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0003o00L0
oooo0P000?l00`3oool0o`000?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`040?l0003oool0003o0000o`P0oooo00<0003o0?l0
003o00001P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080o`000P3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0n0?ooo`00=03oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`80o`001P3oool00`000?l0
oooo0?ooo`060?ooo`040?l0003oool0oooo0000o`D0oooo00D0003o0?ooo`3oool0oooo0?l00007
0?ooo`030000o`3oool0o`0000X0o`0000<0oooo0000o`3oool01P3oool0103o0000oooo0?ooo`3o
ool20000o`D0oooo00D0003o0?ooo`3oool0oooo0?l000060?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3o00001@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0n0?ooo`00=03oool20000o`D0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo0`3o
00040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?oo
o`3oool0003o00D0oooo00<0o`000?ooo`3oool00`3oool20?l000030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool0103o0000003o0?l0003o00040?ooo`030?l0003oool0oooo00@0
oooo0P000?l20?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`80o`001P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool20000ocl0oooo000d0?ooo`030000o`3oool0003o00<0003o
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool00`3o00000`3oool0003o0?ooo`060?ooo`030?l0003oool0oooo00<0oooo
00@0003o0?ooo`3oool0003o1P3oool0103o0000oooo0?ooo`3oool20?l00080oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0o`002@3oool20000
o`H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?l000020?l000030?ooo`3o0000oooo
00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0003o
00<0003o00<0oooo0000o`3oool0?P3oool003<0oooo00<0003o0?ooo`3oool0103oool40000o`<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo0P3o00060?ooo`030?l0003oool0oooo00D0oooo0P000?l80?ooo`030?l0003oool0o`0000@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo0P3o00080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool20?l000D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo0?oo
o`@0003o1@3oool00`000?l0oooo0?ooo`0m0?ooo`00<`3oool00`000?l0oooo0?ooo`040?ooo`04
0?l0003oool0oooo0?ooo`@0003o1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00@0003o0?ooo`3o0000o`00103oool00`3o0000oooo0?ooo`050?ooo`80003o203oool2
0?l000D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00@0o`000?ooo`3oool0o`001P3oool00`000?l0oooo0000o`080?ooo`040?l0003o
ool0oooo0?ooo`80o`0000<0oooo0000o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo10000?l30?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
?@3oool003<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0003o00<0003o00<0oooo0?l0003oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo0080oooo00@0o`000?ooo`3oool0o`001`3oool010000?l0oooo0?ooo`000?l60?ooo`03
0?l0003oool0o`0000H0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo
0?ooo`000?l01`3oool0103o0000oooo0?l0003o00030?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0000o`040000o`H0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0l0?ooo`00<`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool40000o`<0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`030?ooo`80o`001`3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0
oooo0?ooo`80o`000`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080003o00<0
o`000000o`000?l00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00@0
o`000?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`@0003o103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0?03oool00380oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool010000?l60?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo0P3o00050?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3o00001@3oool00`3o0000oooo0?ooo`020?ooo`D0003o00@0
oooo0?l0003oool0oooo1@000?l30?ooo`030?l0003oool0oooo00@0oooo00<0o`000000o`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`80o`001P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`@0003o
0P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0l0?ooo`00<P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`@0003o0P3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080o`000P3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00H0o`000?ooo`000?l0003o0?ooo`000?l40?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P000?l00`3o0000oooo0?ooo`050?ooo`03
0000o`3o0000oooo00H0oooo00@0003o0?ooo`3oool0oooo0P3o00020?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@000?l60?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo03`0oooo000b0?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool0oooo10000?l40?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
0080oooo0P3o00080?ooo`030?l0003oool0003o00H0oooo00<0o`000000o`3oool00`3oool01@00
0?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000003o0?ooo`05
0?ooo`040000o`3oool0oooo0?l000L0oooo0`3o00040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo0`00
0?l40?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0>`3oool00380oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0003o00@0003o1P3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0o`000?ooo`050?ooo`040?l0003oool0oooo0?ooo`80003o0`3oool00`000?l0oooo0?l0
00040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0003o00@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0
00000?l0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`000?l00`000?l00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0>`3oool00380oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo10000?l20?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080o`00103oool00`3o0000oooo0?ooo`030?ooo`<0003o0P3oool00`3o0000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`0000<0
oooo0P000?l00`3oool0003o0?ooo`040?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3o
ool0003o1P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00@0o`000?oo
o`3oool0oooo10000?l40?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0k0?ooo`00<P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?ooo`3oool40000o`H0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00@0o`00
0?ooo`3oool0o`001P3oool20000o`@0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`040?l0
003oool0oooo0000o`@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`04
0?l0003oool0oooo0?l000<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo10000?l20?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo03/0oooo000a0?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`000?l00`000?l00`3oool0003o0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool20?l000L0oooo00<0003o0?ooo`00
0?l0103oool01@3o0000oooo0?ooo`3oool0003o00D0o`0000D0003o0?l0003oool0oooo0?l00005
0?ooo`030000o`3oool0003o00H0oooo0`3o00050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0000o`030000o`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0>`3oool00340oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`<0003o1@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3o00001@3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo103o000010000?l0oooo0?ooo`3o
00020?ooo`030000o`3oool0o`000080o`00103oool010000?l0oooo0?ooo`000?l50?ooo`<0o`00
1P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo10000?l50?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0>`3oool00340oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0003o00<0003o00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080o`000P3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo0080o`000P3oool010000?l0oooo0?ooo`3o00020?ooo`030000
o`3oool0oooo0080o`000`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080o`00
0P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo10000?l20?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0k0?ooo`00<@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103o
ool40000o`<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`80o`001`3o
ool010000?l0o`000?ooo`3o00020?ooo`060000o`3oool0oooo0?l0003oool0003o0P3oool00`3o
0000oooo0?ooo`020?l000030000o`3oool0oooo00@0oooo00<0003o0?l0003oool0103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0003o00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0>`3oool00340
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00@0o`000?ooo`3oool0oooo10000?l50?ooo`030?l0003oool0oooo00@0oooo00<0003o0?l0
003o0000103oool20?l000040000o`3oool0oooo0?l00080oooo00D0003o0?ooo`3o0000oooo0000
o`020?ooo`060?l0003oool0oooo0?ooo`000?l0o`001@3oool20?l000030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool30000o`@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0>`3oool00340oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0000o`030000o`030?ooo`3o0000oooo00D0oooo
00@0003o0?ooo`3oool0o`000`3oool01P3o0000oooo0?ooo`000?l0oooo0?l00080oooo00L0003o
0?ooo`3o0000oooo0000o`3oool0o`0000<0oooo00<0003o0?ooo`3o00000`3oool20?l00080oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0000o`040000o`H0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
>P3oool00340oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`@0003o0`3o
ool00`000?l0oooo0?ooo`020?ooo`80o`0000<0oooo0?l0003oool00P3oool010000?l0oooo0?l0
003oool20000o`050?l000000?l0003o0?ooo`3o00000P3oool010000?l0oooo0?ooo`3oool30?l0
00@0oooo00<0003o0?ooo`3oool00P3oool40000o`D0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0j0?ooo`00<@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00@0o`000?ooo`3oool0oooo10000?l60?ooo`80o`00103oool01P000?l0oooo0?l000000?l0
oooo0?l00080003o00@0o`000000o`3oool0003o103oool20?l000H0oooo10000?l30?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0j0?ooo`00<@3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool20000o`@0oooo00<0o`000?ooo`3oool00P3o00030?ooo`0:0000o`3o0000oooo0000o`3o0000
003o0?ooo`3o0000oooo0000o`<0oooo0P3o00000`3oool0o`000?ooo`040?ooo`80003o1P3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0>P3oool0
0340oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00`000?l00`3oool0o`000?ooo`030?ooo`0>0?l0003oool0003o
0?ooo`000?l0o`000000o`3o0000003o0?l0003oool0003o0?ooo`000?l20?l000@0oooo00<0o`00
0?ooo`000?l00P000?l00`3oool0003o0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0j0?ooo`00<@3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`@0003o0`3oool20?l00080oooo00L0o`000000o`3o0000o`000?ooo`000?l0oooo0080o`00103o
ool40000o`@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0>P3oool00340oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040000o`040?ooo`3o0000o`000?ooo`80003o00D0o`000000o`3oool0o`00
0?ooo`050000o`80oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0j0?ooo`00<@3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo10000?l30?l000030000o`3o
0000003o00@0003o1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo03X0oooo000a
0?oooel0o`0000<0003o0?l0003o0000H03o000l0?ooo`00<@3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`80o`001@3oool50000o`030?l000000?l0o`0000@0003o00<0oooo0000o`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo03X0oooo000a0?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@000?l00`3oool0o`000000o`020?l000050000o`3oool0003o0?l0
003oool010000?l30?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0>P3oool00340
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool30000o`@0oooo0P3o000020000?l0o`000000o`3o0000003o
0?l0003oool0003o0P3o00030?ooo`@0003o1@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0j0?ooo`00<@3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo0P000?l50?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0003o00<0o`000?ooo`3oool00P3oool20?l000080?ooo`000?l0o`000?ooo`000?l0o`00
0000o`3o00020?ooo`030000o`3oool0o`0000D0oooo00<0o`000000o`000?l00P000?l00`3oool0
003o0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`0j0?ooo`00<@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00P3oool40000o`@0oooo0P3o00000`3oool0o`000?l000020?ooo`80003o
00/0o`000000o`000?l0o`000000o`3oool0o`000000o`3oool0003o0?ooo`020?l00080oooo00<0
o`000?ooo`3oool00`3oool40000o`<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo03X0oooo000a0?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000003o0000o`020000o`80oooo00<0003o0?ooo`3oool0103oool2
0?l000<0oooo00@0003o0?ooo`3o0000oooo0P000?l0103o0000003o0000o`3o00030?ooo`030000
o`3oool0oooo0080o`001`3oool00`000?l0oooo0?ooo`040000o`H0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`0j0?ooo`00<@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0003o1P3oool00`000?l0oooo0?ooo`030?ooo`<0o`000P3oool030000?l0oooo0?oo
o`3o0000oooo0000o`3oool0o`000?ooo`000?l0oooo0?l000<0oooo00@0003o0?ooo`3o0000oooo
0P3o00040?ooo`030000o`3oool0oooo00@0oooo00<0o`000000o`000?l00P000?l00`3oool0003o
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo03X0oooo000a0?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo1000
0?l40?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3o00030?ooo`050?l00000
0?l0oooo0?ooo`3o00000P3oool01@000?l0oooo0?l0003oool0003o0080oooo00H0o`000?ooo`3o
ool0oooo0000o`3o00030?ooo`040?l0003oool0oooo0000o`L0oooo00<0o`000?ooo`3oool00P3o
ool40000o`@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool0>`3oool00340oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000000o`000?l00P000?l0
0`3oool0003o0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0003o00001@3oool0
1@000?l0o`000?ooo`3oool0o`000080oooo00D0003o0?ooo`3o0000oooo0000o`020?ooo`060?l0
003oool0oooo0?ooo`3o0000003o103oool20?l000030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`030000o`030?ooo`3o0000oooo00D0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo03/0oooo000a0?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool010000?l0oooo0?ooo`3oool40000
o`H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030?l000000?l0oooo
00@0oooo00<0003o0?ooo`3oool00P3o00020?ooo`040000o`3oool0oooo0?l00080oooo00H0003o
0?ooo`3oool0o`000?ooo`3o00020?ooo`030000o`3oool0oooo0080oooo00<0003o0?l0003o0000
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo10000?l30?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0k0?ooo`00<@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo10000?l30?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0103o0000oooo0?ooo`3oool20?l00080oooo
00D0003o0?ooo`3oool0oooo0000o`030?ooo`<0o`0000D0oooo0000o`3oool0oooo0?l000020?oo
o`030000o`3oool0oooo0080o`00103oool01@000?l0oooo0?ooo`3oool0003o0080oooo0P3o0002
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0103o0000oooo0?ooo`3o
ool40000o`D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0k0?ooo`00<P3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0003o0080003o00<0oooo0000o`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo0`3o00040?ooo`040000o`3oool0
oooo0000o`@0oooo00D0o`000?ooo`3oool0o`000000o`050?l000050000o`3o0000o`000?ooo`3o
00001@3oool00`000?l0oooo0000o`050?ooo`80o`001`3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo1@000?l00`3oool0o`000?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo03/0
oooo000b0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo0080oooo10000?l50?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`80o`001`3oool20000o`@0oooo
00D0o`000?ooo`3oool0oooo0000o`020?ooo`<0o`0000<0oooo0000o`3oool00P3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo0P3o00050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`@0003o0`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`0k0?ooo`00<P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool50000o`80oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo
0?ooo`3o00060?ooo`<0003o0`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0o`000?oo
o`3oool0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`000?l01@3oool0
0`3o0000oooo0?ooo`020?l000<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool010000?l60?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0k0?ooo`00<P3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool010000?l60?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`040000o`3oool0o`000?l000@0oooo00<0o`000?ooo`3oool00P3oool01`000?l0oooo0?ooo`3o
ool0003o0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3o
ool00P3oool0103o0000oooo0?ooo`000?l30?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool20?l000030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo1@000?l20?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0k0?ooo`00<P3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo10000?l30?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo0P3o00060?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool00`000?l0o`000?ooo`030?oo
o`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
003o00@0oooo00D0003o0?ooo`3oool0oooo0?l000070?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00`3oool40000o`@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`0k0?ooo`00<`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`D0003o00<0oooo0?l0003oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
103o0000oooo0?ooo`3oool20?l000030?ooo`000?l0oooo00H0oooo00<0o`000?ooo`000?l01P3o
ool00`3o0000003o0000o`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool01P000?l0oooo0?ooo`3oool0003o0?l000H0oooo00<0003o0?ooo`3o00001`3oool010000?l0
oooo0?l0003o00040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`000?l00`3o
ool0003o0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo03`0oooo000c0?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
003o1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`040?l0003oool0oooo0?l000@0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0o`000?ooo`040?ooo`040?l0003oool0oooo0?ooo`@0003o0`3oool0
0`3o0000oooo0?ooo`020?ooo`@0003o00<0oooo0?l0003oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`040000o`3oool0oooo0?ooo`80o`0000<0oooo0?l0003oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`030?ooo`@0003o0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0l0?ooo`00<`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool30000o`<0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`80o`001P3oool00`000?l0oooo0?ooo`03
0?ooo`040000o`3oool0oooo0?l000@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0000
o`020000o`030?l000000?l0003o0080003o00<0oooo0000o`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0003o00H0oooo00<0003o0?ooo`3oool0103oool20?l000H0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool010000?l0oooo0?ooo`3oool30000o`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo03`0oooo
000c0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`020?ooo`80003o00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo0080oooo0`3o00070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool0103o0000oooo0?ooo`3o00060?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o0000103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo0P000?l40?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0l0?ooo`00<`3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`000?l00P000?l20?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?l0003o00030?ooo`03
0?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0003o1P3oool00`3o0000oooo0?l000050?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`040?l0003oool0o`000?l000D0oooo00@0003o0?ooo`3oool0003o1`3oool0103o0000oooo0?oo
o`3oool20?l00080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0003o00<0oooo0000o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo03d0oooo000d0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3o
ool30000o`H0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
0000oooo00D0oooo00<0o`000?ooo`3oool01@3oool20000o`P0oooo0P3o00050?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`000?l01`3oool00`3o0000oooo0?ooo`030?ooo`80o`001`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo10000?l30?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0?@3oool003@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000003o0000o`020000o`80oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00<0oooo0P3o00000`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo0`000?l70?ooo`030?l0003oool0o`0000@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo0?ooo`<0o`002@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?l0003o0000103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool010000?l60?ooo`030000o`3o
ool0oooo03d0oooo000d0?ooo`030000o`3oool0oooo00@0003o1P3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo
00@0o`000?ooo`3oool0oooo103o00000`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo00@0003o0?l0003o0000o`000`3oool00`3o0000oooo0?ooo`040?ooo`80003o00<0oooo0000
o`000?l0103oool00`3o0000oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000003o0000o`020000o`80oooo00<0003o0?ooo`3oool0?@3oool003@0oooo0`000?l40?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`040?l0003oool0o`000?l000@0oooo00<0003o0?ooo`3oool01P3oool0103o0000oooo0?ooo`00
0?l50?ooo`050000o`3oool0oooo0?ooo`3o00001`3oool00`000?l0o`000?l0000;0?l000030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`040000
o`3oool0oooo0?l000L0oooo00<0003o0?ooo`3oool00`3oool30?l000H0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo0`000?lo0?ooo`00
=@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`030?ooo`80o`001`3oool00`000?l0oooo0?ooo`060?ooo`030?l0
00000?l0oooo00H0oooo00@0003o0?ooo`3oool0o`001`3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0003o
00L0oooo00<0003o0?l0003oool01`3oool00`000?l0oooo0?ooo`050?ooo`80o`001@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0n0?ooo`00=@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?ooo`3oool20?l000030?ooo`3o0000oooo
00L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3o0000oooo
00L0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00@0o`000?ooo`000?l0003o203oool00`3o0000003o0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool00P3o00020?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo03h0oooo000e0?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0o`0000@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0o`0000T0oooo00<0o`000000o`3oool01P3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`070?oo
o`040?l0003oool0oooo0000o`D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0003o00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo03h0oooo000f0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`80o`001P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000070?ooo`030?l0003oool0
oooo0080003o103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool20000o`030?ooo`3o0000oooo00H0oooo00<0o`000?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0003o00P0oooo00<0o`000?ooo`3oool0103oool20?l000D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo03l0oooo000f
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`02
0?ooo`80o`0000<0oooo0000o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0
oooo0000o`D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`D0003o1`3o
ool00`3o0000oooo0?ooo`060?ooo`D0003o0`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00@0003o0?ooo`3oool0003o1`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo0080o`000`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0?`3oool003H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`040?l0003oool0o`000?l000<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`80003o1`3oool20?l000<0oooo00<0o`000?ooo`3oool01`3oool40000o`@0oooo
00<0o`000?ooo`3oool00`3oool40000o`P0oooo00@0o`000?ooo`3oool0oooo0P3o00080?ooo`80
003o1`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo0`3o00070?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0?`3oool003L0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`80003o2@3oool00`3o0000oooo0?l0000:0?ooo`040000
o`3oool0oooo0?ooo`@0003o00<0o`000000o`000?l00`000?l30?ooo`030000o`3oool0oooo00L0
oooo0`3o000:0?ooo`80003o1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0400
oooo000g0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool20?l000030?oo
o`3o0000oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`040000
o`3oool0oooo0000o`T0oooo0P3o00090?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`00
0?l01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3o
0000o`00103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0400oooo000g0?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3o00030?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0003o0?oo
o`3oool01P3oool0103o0000oooo0?l0003o00070?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0o`0000P0oooo0P000?l3
0?ooo`050000o`3oool0oooo0?ooo`3o0000203oool00`000?l0oooo0?ooo`050?ooo`050?l0003o
ool0oooo0?ooo`3o00000P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0400oooo
000h0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo0P3o00060?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0000o`060?ooo`030000o`3oool0oooo00D0oooo00D0
o`000?ooo`3oool0oooo0?l000060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`030?ooo`80o`000`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3o0000203oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00<0oooo0P3o00000`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0440oooo
000h0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo00<0o`000000o`3oool01`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool20000o`@0oooo00<0
o`000?ooo`3oool00`3oool30?l000<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`040000o`3oool0oooo0?ooo`80o`001P3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?l0003o0000103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`110?ooo`00>03o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`020?l00080oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o00002@3oool01@000?l0oooo0?oo
o`3oool0o`0000P0oooo0P3o00000`000?l0o`000?l000070?ooo`030?l0003oool0oooo00H0oooo
00<0o`000000o`3o00000P3o00080?ooo`030?l0003oool0oooo0080003o203oool00`3o0000oooo
0000o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo
0?ooo`3oool20?l00080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0@P3oool003T0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo0`3o00040?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`3o00002@3oool20000o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool0403o00020?ooo`030000o`3oool0oooo00T0oooo00<0o`000000o`3oool0203oool0103o0000
oooo0?ooo`3oool20000o`<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00<0oooo0P3o00060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`120?ooo`00>@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool30?l000H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0oooo0000o`D0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000003o0000o`0:0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`070?ooo`80003o00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`040?ooo`040000o`3oool0oooo0000o`L0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`80o`001@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0@`3oool003X0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool20000o`L0oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020000o`P0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00D0oooo0P000?l30?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool20000o`L0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080o`000P3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0@`3oool003X0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o0000o`0000@0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo0P000?l80?oo
o`80o`001@3oool00`3o0000oooo0?ooo`030?ooo`80003o1@3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool20000o`D0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`070?ooo`80003o1P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool20?l000030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`140?ooo`00>`3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo0P3o00000`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`04
0000o`3oool0oooo0000o`T0oooo00D0o`000?ooo`3oool0oooo0?l000080?ooo`80003o0`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00D0003o0?ooo`3oool0oooo0000
o`070?ooo`030?l0003oool0oooo0080oooo0P3o00090?ooo`040000o`3oool0oooo0000o`@0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?l0003o00001@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo04@0oooo
000l0?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`040?l0
003oool0oooo0?l000X0oooo10000?l:0?ooo`030?l0003oool0oooo00P0oooo1@000?l90?ooo`04
0?l0003oool0oooo0?l000X0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0
o`0000L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0
oooo0?ooo`80o`000P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo04D0oooo000l
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0103o0000oooo0?ooo`00
0?l60?ooo`030000o`3oool0oooo00L0oooo0P3o000>0?ooo`P0003o0`3oool00`3o0000oooo0?oo
o`020?ooo`H0003o00<0oooo0000o`3oool02`3oool30?l000T0oooo0P000?l60?ooo`030000o`3o
ool0o`0000L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3o00001P3oool00`000?l0oooo0?ooo`150?ooo`00?@3oool0
0`000?l0oooo0?ooo`030?ooo`80o`001P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000003o0?ooo`070?ooo`80003o203oool3
0?l000/0oooo00<0003o0?ooo`3oool01P3oool30000o`030?l000000?l0003o0080003o203oool0
0`000?l0oooo0?ooo`080?ooo`<0o`002@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo0P3o00050?ooo`030000o`3oool0oooo04H0oooo000m0?ooo`040000o`3oool0oooo
0?ooo`80o`0000<0oooo0?l0003oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l0o`000?l000090?ooo`030000o`3oool0
oooo00@0oooo00@0o`000?ooo`3oool0oooo0P3o00090?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`80o`000`3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`000?l01@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`020?l000<0oooo00<0003o0?ooo`3oool0AP3oool003h0oooo00<0003o0?l0003o00000`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00002@3oool20000o`@0oooo00<0
o`000?ooo`3oool00`3oool20?l000L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00@0oooo0P3o00050?ooo`030?l0003oool0oooo00<0oooo0P00
0?l90?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`80o`00
00<0003o0?ooo`3oool0A`3oool003h0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?oo
o`000?l50?ooo`030?l0003oool0oooo00P0oooo00@0003o0?ooo`3oool0o`00203oool30?l000<0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080
oooo0P3o00080?ooo`030?l0003oool0oooo0080003o2P3oool00`3o0000oooo0?ooo`030?ooo`04
0000o`3oool0oooo0000o`L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0A`3oool003l0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool20000o`L0oooo00<0o`000?ooo`3oool0203oool00`000?l0o`000?ooo`0;0?ooo`<0
o`0000<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`040000o`3o0000o`000?l0
00/0oooo00<0o`000000o`3oool02@3oool20?l000L0oooo0P000?l70?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
04P0oooo000o0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo0P000?l80?ooo`030?l0003oool0oooo00P0
oooo00<0o`000000o`000?l03@3oool00`000?l0o`000?l000030?l000L0oooo00<0o`000?ooo`3o
ool01P3oool50?l000030000o`3oool0oooo00/0oooo00<0003o0?l0003oool02@3oool00`3o0000
oooo0?ooo`070?ooo`80003o1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`190?ooo`00@03oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`030?ooo`040000o`3oool0oooo0000o`P0oooo00<0o`000?ooo`3oool01P3oool0103o0000
oooo0?ooo`3oool20000o`/0oooo00<0003o0?ooo`3oool00`3oool@0?l000D0oooo00<0003o0?oo
o`3oool02@3oool20000o`80oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`040000o`3oool0oooo0000o`@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0B@3oool00400oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`030000o`3oool0oooo00H0oooo0P3o00060?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo0P3o00090?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`1:0?ooo`00@@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0000o`060?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`80003o1`3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool01@3oool20000o`L0oooo00D0o`00
0?ooo`3oool0oooo0?l000090?ooo`80003o1@3oool010000?l0oooo0?ooo`3o00070?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1:0?ooo`00@P3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo
0?l000090?ooo`80003o1@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool00P3oool30000o`T0oooo00@0o`000?ooo`3oool0o`002@3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3o0000oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo04/0oooo00120?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o0000oooo00P0oooo
0P000?l80?ooo`<0o`00303oool40000o`030?ooo`000?l0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0000o`020000o`d0oooo0P3o00090?ooo`030000o`3oool0oooo00L0oooo
00<0o`000000o`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0C03oool004<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0o`002P3oool00`000?l0oooo
0?ooo`060?ooo`<0o`003`3oool40000o`/0oooo00<0o`000?ooo`3oool02@3oool50000o`l0oooo
0P3o00090?ooo`030000o`3oool0oooo00L0oooo00@0o`000?ooo`3oool0003o1@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0C03oool004@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0oooo0000o`@0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080
o`003@3oool010000?l0oooo0?ooo`3oool80000o`<0oooo00@0o`000?ooo`3oool0oooo20000?l4
0?ooo`030000o`3oool0oooo00/0oooo0P3o00000`3oool0o`000?ooo`070?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00P0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1=0?ooo`00A@3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00L0oooo0P000?l60?ooo`030?l0003oool0oooo00P0oooo0P000?l4
0?ooo`030?l0003oool0oooo00<0oooo0P3o000;0?ooo`030000o`3oool0oooo00T0oooo0`000?l0
103o0000003o0000o`000?l<0?ooo`030000o`3oool0oooo00P0oooo0`3o00040?ooo`030?l0003o
ool0oooo00<0oooo0P000?l80?ooo`80o`001P3oool00`000?l0oooo0000o`080?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0C@3oool004D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`80003o1`3oool00`3o0000oooo0?ooo`090?ooo`050000o`3oool0
oooo0?ooo`3o00001`3oool20?l000T0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00H0oooo0P3o00070?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`1>0?ooo`00AP3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool0003o1`3oool00`3o0000oooo0?oo
o`090?ooo`80003o00<0o`000?ooo`3oool0203oool30?l000D0oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00<0oooo0`3o000:0?ooo`040?l0003o
ool0oooo0000o`T0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0000o`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0C`3oool004L0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3o
ool20?l000/0oooo00<0o`000?ooo`3oool02`3oool50?l000030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool03P3oool00`000?l0o`000?l000020?l000h0oooo00<0o`000000o`3oool0203o
ool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo0?ooo`80003o0`3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo0500oooo00180?ooo`030000o`3oool0oooo00D0oooo00@0
o`000?ooo`3oool0003o1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00@0o`000?ooo`000?l0003o403oool010000?l0o`000?l0003o000<0?ooo`030?l0003oool0oooo
00`0oooo0P3o00000`000?l0oooo0?ooo`0>0?ooo`80003o00<0oooo0?l0003oool01P3oool20?l0
00T0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?l000080?ooo`030000o`3oool0oooo
0540oooo00180?ooo`030000o`3oool0oooo00H0oooo00<0o`000000o`3oool01`3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool20000o`h0
oooo00@0003o0?ooo`3oool0oooo1@3o00070?ooo`030?l0003oool0oooo00H0oooo1P3o00020?oo
o`030000o`3oool0oooo00`0oooo0P000?l30?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool01`3oool20000o`P0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1B0?oo
o`00B@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o0000o`0000P0oooo00<0003o0?ooo`3o
ool01P3oool20?l000D0oooo00<0o`000?ooo`3oool0103oool20000o`/0oooo00<0003o0?ooo`3o
ool01`3oool@0?l000P0oooo00<0003o0?ooo`3oool02P3oool20000o`H0oooo00@0o`000?ooo`3o
ool0oooo0P3o00090?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`000?l01P3oool00`00
0?l0oooo0?ooo`1C0?ooo`00BP3oool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?oo
o`3o0000203oool20000o`P0oooo00D0o`000?ooo`3oool0oooo0?l000090?ooo`80003o2@3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool01`3oool2
0000o`P0oooo00@0o`000?ooo`3oool0o`002P3oool00`000?l0oooo0?ooo`070?ooo`050?l0003o
ool0oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`1C0?ooo`00B`3oool01@000?l0oooo0?oo
o`3oool0003o00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`80o`00
00<0oooo0?l0003oool02P3oool30000o`H0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo00<0oooo10000?l;0?ooo`80o`002P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`1F0?ooo`00
C03oool00`000?l0oooo0000o`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1`3oool20?l000h0oooo10000?l20?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`030000o`h0oooo00<0o`000?ooo`3o0000203oool20000o`T0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0000o`1G0?ooo`00C@3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo0P000?l70?ooo`040?l0003oool0o`000?l00100oooo
0P000?lA0?ooo`030?l0003oool0oooo00l0oooo0`000?l?0?ooo`80o`000P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`1F0?ooo`00CP3oool20000o`P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo0080oooo0P3o000?0?ooo`D0003o3@3oool00`3o0000oooo0?oo
o`090?ooo`P0003o3P3oool20?l000D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0E`3oool00500oooo00<0003o
0?ooo`3oool01P3oool20?l000T0oooo00D0003o0?ooo`3oool0oooo0?l000070?ooo`80o`003@3o
ool00`000?l0oooo0?ooo`020?ooo`d0003o00<0o`000000o`000?l02@000?l70?ooo`030000o`3o
ool0oooo00X0oooo0P3o00070?ooo`040?l0003oool0oooo0?ooo`80003o2P3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo05P0oooo001A0?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01`3oool20000o`030?ooo`3o0000oooo00P0oooo0`3o000:0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`080?ooo`80o`002P3o
ool00`3o0000oooo0000o`0;0?ooo`030?l0003oool0oooo00H0oooo0P000?mK0?ooo`00DP3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0o`000000o`3oool02`3oool3
0?l000H0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo00<0oooo103o000<0?ooo`030?l000000?l0oooo00X0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`1K0?ooo`00D`3oool00`000?l0oooo0?ooo`070?ooo`80o`00203oool0103o
0000oooo0000o`000?l=0?ooo`@0o`000P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3o00000`3o000>0?ooo`80003o00<0oooo0?l0003oool0203oool2
0?l000P0oooo00<0003o0?ooo`3oool0G03oool005@0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo0P000?l?0?ooo`80o`0000<0003o0?oo
o`3oool0403oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o0000oooo00l0oooo0P000?l40?oo
o`030?l0003oool0oooo00@0oooo0P3o00090?ooo`030000o`3oool0oooo05d0oooo001E0?ooo`80
003o2@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo0P000?l>0?ooo`03
0000o`3oool0o`0000<0o`003P3oool00`3o0000oooo0?ooo`0<0?ooo`D0o`0000<0003o0?ooo`3o
ool03@3oool20000o`H0oooo00<0o`000?ooo`3oool00P3oool20?l000T0oooo0P000?mP0?ooo`00
E`3oool00`000?l0oooo0?ooo`070?ooo`80o`000P3oool00`3o0000oooo0?ooo`070?ooo`80003o
303oool00`000?l0oooo0?ooo`030?ooo`P0o`001P3oool00`3o0000oooo0?ooo`050?ooo`L0o`00
1P3oool00`000?l0oooo0?ooo`0:0?ooo`80003o2@3oool0103o0000oooo0?l0003o000:0?ooo`03
0000o`3oool0oooo0600oooo001H0?ooo`030000o`3oool0oooo00P0oooo0P3o000<0?ooo`80003o
2@3oool00`000?l0oooo0?ooo`0<0?ooo`h0o`003@3oool00`000?l0oooo0?ooo`080?ooo`80003o
2`3oool20?l000/0oooo00<0003o0?ooo`3oool0H@3oool005T0oooo00<0003o0?ooo`3oool0203o
ool30?l000`0oooo0P000?l70?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`050?ooo`<0003o303oool00`3o0000oooo0?l000090?ooo`80003oI03o
ool005X0oooo0P000?l70?ooo`040?l0003oool0oooo0?ooo`80o`00303oool30000o`@0oooo00<0
003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00<0oooo0P00
0?l=0?ooo`80o`000P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo06@0oooo001L
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool20?l000d0oooo10000?lE
0?ooo`030?l0003oool0oooo01<0oooo1@000?l=0?ooo`80o`001@3oool00`3o0000oooo0?ooo`03
0?ooo`80003oI`3oool005d0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo00d0oooo1P000?l@0?ooo`030?l0003oool0oooo0100oooo10000?l@0?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00P000?mY0?ooo`00GP3oool20000o`80
oooo00<0o`000?ooo`3oool01`3oool20?l000d0oooo00<0003o0?ooo`3oool00`3oool40000o``0
oooo00<0o`000?ooo`3oool02`3oool50000o`<0oooo00<0003o0?ooo`3oool0303oool20?l000T0
oooo00<0o`000?ooo`000?l0J`3oool00600oooo00<0003o0?l0003oool02`3oool20?l000X0oooo
00<0003o0?ooo`3oool0203oool<0000o`030?l000000?l0003o00/0003o203oool00`000?l0oooo
0?ooo`0:0?ooo`80o`002`3oool00`000?l0o`000?ooo`1[0?ooo`00HP3oool20000o``0oooo0`3o
00070?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?oo
o`060?ooo`<0o`00303oool00`000?l0oooo0?ooo`1/0?ooo`00I03oool20000o`d0oooo0`3o0004
0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`03
0?ooo`<0o`003@3oool20000ofl0oooo001V0?ooo`80003o3P3oool40?l000030000o`3oool0oooo
01@0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?l000030?l000h0oooo0P000?ma0?oo
o`00J03oool20000o`l0oooo00<0003o0?l0003o00000`3o000B0?ooo`030?l0003oool0oooo0140
oooo0`3o00000`000?l0o`000?ooo`0?0?ooo`80003oL`3oool006X0oooo0P000?l=0?ooo`030000
o`3oool0oooo00<0oooo0`3o000?0?ooo`030?l0003oool0oooo00h0oooo0`3o00040?ooo`030000
o`3oool0oooo00`0oooo0P000?me0?ooo`00K03oool20000o`/0oooo00<0003o0?ooo`3oool01P3o
ool80?l000L0oooo00<0o`000?ooo`3oool01@3oool90?l000L0oooo00<0003o0?ooo`3oool02P3o
ool20000ogL0oooo001^0?ooo`<0003o203oool00`000?l0oooo0?ooo`0>0?ooo`l0o`00403oool0
0`000?l0oooo0?ooo`070?ooo`<0003oN@3oool00740oooo0`000?l40?ooo`030000o`3oool0oooo
01H0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`040?ooo`<0003oO03oool007@0
oooo0`000?l00`3oool0003o0?ooo`0G0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3o
ool00`000?mo0?ooo`00M`3oool30000oaL0oooo00<0o`000?ooo`3oool05P3oool30000oh80oooo
001j0?ooo`D0003o4P3oool00`3o0000oooo0?ooo`0@0?ooo`H0003oQ@3oool007l0oooo1`000?l;
0?ooo`030?l0003oool0oooo00T0oooo1`000?n;0?ooo`00QP3oool;0000o`030?l000000?l0003o
00T0003oTP3oool00940oooo00<000000?ooo`3oool0V`3oool00940oooo00<000000?ooo`3oool0
V`3oool00940oooo00<000000?ooo`3oool0V`3oool00940oooo00<000000?ooo`3oool0V`3oool0
0840oooo0`00000=0?ooo`030000003oool0oooo09/0oooo00220?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0V`3oool007l0oooo1@00000=0?ooo`030000003oool0oooo09/0oooo
001o0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0V`3oool00800oooo00<0
00000?ooo`0000003P3oool00`000000oooo0?ooo`2K0?ooo`00P@3oool2000000h0oooo00<00000
0?ooo`3oool0V`3oool008T0oooo1@0000030?ooo`030000003oool0oooo09/0oooo001m0?ooo`P0
00001@3oool00`000000oooo000000040?ooo`030000003oool0oooo09/0oooo002:0?ooo`030000
003oool0000000@0oooo00<000000?ooo`3oool0V`3oool008X0oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`2K0?ooo`00R@3oool4000000@0oooo00<000000?ooo`3oool0V`3oool0
0940oooo00<000000?ooo`3oool0V`3oool00840oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo09/0oooo00210?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0V`3oool00840oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`2K0?ooo`00PP3oool00`000000oooo0?ooo`2Z0?ooo`00O`3oool010000000oooo0?ooo`00002/
0?ooo`00O`3oool400000:`0oooo003o0?oooc00oooo003o0?oooc00oooo003o0?oooc00oooo003o
0?oooc00oooo003o0?oooc00oooo003o0?oooc00oooo002?0?ooo`800000WP3oool00900oooo00<0
00000?ooo`3oool0W03oool00940oooo00<000000?ooo`3oool0V`3oool00900oooo00<000000?oo
o`000000W03oool008l0oooo00@000000?ooo`3oool00000W03oool008h0oooo0`0000000`3oool0
00000000002K0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`0?ooo`00o`3oool`0?oo
o`00\
\>"],
    ImageRangeCache->{{{0, 302.063}, {286.875, 0}} -> {-1, 0, 0, 0}}],
  StyleBox["     ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 1.81818 0.714286 2.04082 [
[.20455 .70179 -11.0938 -20.1875 ]
[.20455 .70179 11.0938 0 ]
[1 .70179 -8.09375 -20.125 ]
[1 .70179 8.09375 0 ]
[1.025 .71429 0 -6.28125 ]
[1.025 .71429 10 6.28125 ]
[.07841 .20408 -10 -6.28125 ]
[.07841 .20408 0 6.28125 ]
[.07841 .45918 -10 -6.28125 ]
[.07841 .45918 0 6.28125 ]
[.07841 .96939 -10 -6.28125 ]
[.07841 .96939 0 6.28125 ]
[.09091 1.025 -5 0 ]
[.09091 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20455 .71429 m
.20455 .72054 L
s
gsave
.20455 .70179 -72.0938 -24.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.1875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
69.063 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200\\200\\200) show
73.250 17.063 moveto
(\\200\\200) show
77.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
1.000 setlinewidth
grestore
1 .71429 m
1 .72054 L
s
gsave
1 .70179 -69.0938 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .71429 m
1 .71429 L
s
gsave
1.025 .71429 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.09091 .20408 m
.09716 .20408 L
s
gsave
.07841 .20408 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.09091 .45918 m
.09716 .45918 L
s
gsave
.07841 .45918 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.09091 .96939 m
.09716 .96939 L
s
gsave
.07841 .96939 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.09091 0 m
.09091 1 L
s
gsave
.09091 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.46887 .71429 m
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
.46887 .71429 L
s
0 0 1 r
.48823 .71484 m
.48822 .71517 L
.48819 .71552 L
.48814 .71615 L
.48805 .7169 L
.48795 .71758 L
.48767 .71903 L
.48732 .72037 L
.48635 .72307 L
.48566 .72451 L
.48494 .72577 L
.48336 .72803 L
.48165 .72989 L
.47985 .73142 L
.47777 .73278 L
.47665 .73335 L
.47539 .73389 L
.47417 .7343 L
.47305 .73459 L
.47247 .73471 L
.47185 .73481 L
.47126 .73489 L
.47071 .73495 L
.47041 .73497 L
.47013 .73498 L
.46997 .73499 L
.46983 .73499 L
.46975 .735 L
.46966 .735 L
.46957 .735 L
.4695 .735 L
.46934 .735 L
.4692 .735 L
.46904 .735 L
.46896 .735 L
.46888 .735 L
.46872 .73499 L
.46855 .73498 L
.46822 .73496 L
.46792 .73494 L
.46759 .73491 L
.467 .73484 L
.46591 .73465 L
.4653 .73451 L
.46466 .73434 L
.46353 .73397 L
.46139 .73303 L
.45951 .7319 L
.45757 .73038 L
.45596 .72877 L
Mistroke
.4545 .72692 L
.45313 .72469 L
.45207 .7224 L
.45122 .71981 L
.45091 .7185 L
.45078 .7178 L
.45066 .71706 L
.45058 .7164 L
.45054 .71605 L
.45051 .71567 L
.45048 .71533 L
.45046 .71501 L
.45045 .71469 L
.45044 .71439 L
.45044 .71424 L
.45043 .71407 L
.45043 .71392 L
.45043 .71378 L
.45043 .71362 L
.45043 .71345 L
.45043 .71336 L
.45044 .71327 L
.45044 .7131 L
.45045 .71292 L
.45045 .71273 L
.45047 .71238 L
.45052 .71173 L
.45058 .71111 L
.45066 .71045 L
.45085 .70928 L
.45113 .70804 L
.4515 .70673 L
.45235 .70442 L
.45366 .70189 L
.45518 .69967 L
.45695 .69771 L
.45879 .69612 L
.46084 .69477 L
.4621 .69413 L
.46328 .69363 L
.46443 .69324 L
.46571 .6929 L
.46638 .69277 L
.46701 .69267 L
.46769 .69259 L
.46806 .69256 L
.46841 .69253 L
.46855 .69253 L
.46871 .69252 L
.46888 .69251 L
Mistroke
.46904 .69251 L
.46913 .69251 L
.46922 .69251 L
.4694 .69251 L
.46956 .69251 L
.46972 .69251 L
.46988 .69251 L
.47003 .69252 L
.4703 .69253 L
.4706 .69255 L
.47093 .69258 L
.47162 .69266 L
.47235 .69278 L
.47365 .69306 L
.47486 .69343 L
.47614 .69393 L
.47837 .69508 L
.48075 .69681 L
.48278 .6988 L
.48452 .70107 L
.48586 .70339 L
.48692 .70591 L
.4874 .70741 L
.48775 .70884 L
.488 .71028 L
.4881 .711 L
.48814 .71142 L
.48818 .7118 L
.4882 .71212 L
.48822 .71248 L
.48823 .71268 L
.48824 .71286 L
.48825 .71304 L
.48825 .71321 L
.48826 .71336 L
.48826 .71351 L
.48826 .71369 L
.48826 .71385 L
.48826 .71401 L
.48825 .7142 L
.48825 .71437 L
.48825 .71452 L
.48823 .71484 L
Mfstroke
1 0 0 r
.50848 .71662 m
.50833 .71803 L
.50814 .71934 L
.5076 .72228 L
.50691 .72506 L
.50599 .72796 L
.50344 .73382 L
.50051 .73863 L
.49726 .7427 L
.49331 .74648 L
.48921 .74945 L
.48703 .75072 L
.48463 .75189 L
.48234 .75281 L
.48022 .7535 L
.47807 .75405 L
.47602 .75444 L
.47486 .7546 L
.47381 .75471 L
.47323 .75476 L
.4726 .7548 L
.47231 .75482 L
.472 .75483 L
.47174 .75484 L
.47146 .75484 L
.47118 .75485 L
.47091 .75485 L
.47067 .75485 L
.47041 .75485 L
.47012 .75485 L
.46982 .75484 L
.46957 .75483 L
.46928 .75482 L
.46878 .75479 L
.46824 .75476 L
.46727 .75467 L
.46615 .75454 L
.46512 .75438 L
.46281 .7539 L
.46059 .75329 L
.45828 .75247 L
.45393 .75042 L
.4501 .74796 L
.44658 .74505 L
.44364 .74199 L
.44074 .73824 L
.43839 .7344 L
.4365 .73046 L
.43489 .72598 L
.43423 .72358 L
Mistroke
.43365 .72091 L
.43344 .71967 L
.43324 .71834 L
.43311 .71717 L
.43299 .71593 L
.43294 .71528 L
.4329 .71457 L
.43289 .71426 L
.43288 .71393 L
.43286 .71361 L
.43286 .71332 L
.43285 .71296 L
.43285 .71276 L
.43284 .71256 L
.43284 .71238 L
.43284 .71222 L
.43284 .71204 L
.43284 .71184 L
.43284 .71167 L
.43285 .71149 L
.43285 .71131 L
.43285 .71113 L
.43286 .71082 L
.43287 .71048 L
.4329 .70982 L
.43294 .70909 L
.43304 .70777 L
.43317 .70649 L
.43333 .70531 L
.43375 .70283 L
.43427 .70051 L
.43503 .69784 L
.4359 .69533 L
.43811 .69041 L
.44066 .68616 L
.44394 .68195 L
.44746 .67844 L
.45147 .67537 L
.45397 .67385 L
.45636 .67263 L
.45869 .67165 L
.46132 .67078 L
.46403 .67011 L
.46554 .66984 L
.46627 .66973 L
.46695 .66965 L
.46762 .66958 L
.46835 .66952 L
.46909 .66948 L
.46949 .66946 L
Mistroke
.46967 .66945 L
.46987 .66945 L
.47023 .66944 L
.47057 .66944 L
.4709 .66943 L
.47121 .66944 L
.47158 .66944 L
.47191 .66945 L
.47229 .66947 L
.47265 .66949 L
.47329 .66953 L
.47396 .66959 L
.47516 .66972 L
.47645 .66992 L
.47786 .67019 L
.48069 .67093 L
.48323 .67181 L
.48613 .6731 L
.48872 .67453 L
.49336 .67785 L
.49787 .68228 L
.50134 .68689 L
.50307 .68977 L
.50445 .69253 L
.50662 .69823 L
.50745 .70132 L
.50782 .70305 L
.5081 .70463 L
.5083 .70605 L
.50847 .7076 L
.50855 .70846 L
.5086 .70924 L
.50864 .70999 L
.50866 .71037 L
.50867 .71079 L
.50868 .71117 L
.50868 .71153 L
.50869 .71186 L
.50869 .71221 L
.50869 .71259 L
.50868 .713 L
.50867 .71339 L
.50866 .71373 L
.50863 .71441 L
.50859 .71515 L
.50849 .71647 L
.50848 .71662 L
Mfstroke
0 0 1 r
.52952 .71976 m
.52879 .72399 L
.52771 .72849 L
.5263 .73303 L
.52474 .7371 L
.52071 .74516 L
.51546 .75277 L
.50958 .75913 L
.5035 .7641 L
.49712 .76802 L
.49102 .77074 L
.48778 .77184 L
.48473 .77265 L
.48137 .77332 L
.47949 .7736 L
.47859 .77371 L
.47777 .77379 L
.477 .77385 L
.47617 .77391 L
.47572 .77394 L
.4753 .77396 L
.47487 .77398 L
.47447 .77399 L
.47413 .774 L
.47377 .774 L
.47336 .77401 L
.47299 .77401 L
.47261 .774 L
.47219 .774 L
.4718 .77399 L
.47144 .77398 L
.47062 .77395 L
.46986 .7739 L
.46903 .77384 L
.46813 .77376 L
.46632 .77355 L
.46467 .7733 L
.46155 .77268 L
.4587 .77192 L
.45246 .76964 L
.44663 .76665 L
.44167 .76335 L
.43655 .75904 L
.43225 .75455 L
.42499 .74419 L
.42216 .73857 L
.41962 .732 L
.41781 .7255 L
.41706 .72173 L
.41679 .72004 L
Mistroke
.41655 .71823 L
.41635 .71638 L
.41621 .7147 L
.41615 .71388 L
.4161 .713 L
.41607 .71216 L
.41604 .71139 L
.41603 .71095 L
.41602 .71048 L
.41602 .71004 L
.41602 .70963 L
.41602 .70916 L
.41602 .70889 L
.41602 .70864 L
.41603 .70818 L
.41603 .7077 L
.41605 .70723 L
.41606 .70673 L
.4161 .70583 L
.41616 .70475 L
.41623 .70376 L
.41639 .702 L
.41661 .70011 L
.41712 .6967 L
.41796 .69265 L
.41893 .68898 L
.42143 .6819 L
.42507 .67445 L
.42949 .66768 L
.43516 .6611 L
.44135 .65569 L
.44787 .65143 L
.45188 .64941 L
.45585 .64781 L
.45954 .64664 L
.46166 .6461 L
.46368 .64568 L
.46565 .64535 L
.4678 .64508 L
.46897 .64497 L
.4696 .64492 L
.4702 .64488 L
.47075 .64486 L
.47126 .64483 L
.47182 .64482 L
.47213 .64481 L
.47242 .64481 L
.47297 .6448 L
.47328 .6448 L
.47357 .6448 L
Mistroke
.47415 .64481 L
.47448 .64482 L
.47478 .64483 L
.47532 .64485 L
.4759 .64488 L
.47697 .64495 L
.47821 .64506 L
.47953 .64522 L
.48191 .64558 L
.48433 .64607 L
.48654 .64662 L
.49148 .64825 L
.49573 .6501 L
.50007 .65247 L
.50778 .65807 L
.51417 .66449 L
.52016 .67275 L
.52447 .68108 L
.52629 .68576 L
.52767 .69019 L
.52885 .69514 L
.52931 .69765 L
.52971 .70044 L
.52997 .70283 L
.53007 .70404 L
.53015 .70535 L
.53021 .70648 L
.53023 .70711 L
.53024 .70768 L
.53025 .70822 L
.53026 .7088 L
.53026 .70934 L
.53026 .70984 L
.53026 .71042 L
.53025 .71105 L
.53023 .71163 L
.53021 .71217 L
.53015 .71347 L
.53007 .71471 L
.52985 .71714 L
.52952 .71976 L
Mfstroke
1 0 0 r
.55126 .72442 m
.54995 .73019 L
.54813 .7363 L
.54343 .7478 L
.54042 .75343 L
.53685 .75906 L
.52968 .76811 L
.52135 .77603 L
.51293 .78205 L
.50425 .78663 L
.49609 .78967 L
.4918 .79082 L
.48779 .79163 L
.4855 .79199 L
.48341 .79224 L
.48225 .79235 L
.481 .79245 L
.47982 .79252 L
.47873 .79257 L
.47817 .79259 L
.47787 .7926 L
.47758 .7926 L
.47708 .79261 L
.47653 .79261 L
.47622 .79261 L
.47593 .79261 L
.47539 .79261 L
.47508 .7926 L
.4748 .7926 L
.47416 .79258 L
.47366 .79256 L
.47318 .79254 L
.4721 .79248 L
.47105 .79241 L
.46992 .79231 L
.46793 .79209 L
.46586 .7918 L
.46219 .79112 L
.45834 .79018 L
.45432 .78894 L
.44735 .78614 L
.43973 .78202 L
.43304 .77735 L
.42176 .76657 L
.41675 .76015 L
.41209 .75278 L
.40833 .74536 L
.40545 .7382 L
.40299 .73013 L
.40191 .72552 L
Mistroke
.4011 .72105 L
.40051 .71675 L
.40026 .71431 L
.40008 .71209 L
.39996 .70999 L
.39992 .7088 L
.3999 .70823 L
.39988 .7077 L
.39987 .70719 L
.39987 .70673 L
.39986 .70622 L
.39986 .70567 L
.39986 .70514 L
.39986 .70456 L
.39987 .70402 L
.39988 .70351 L
.39989 .70296 L
.3999 .70237 L
.39994 .70131 L
.39999 .70018 L
.40007 .69893 L
.40024 .69668 L
.40045 .69458 L
.40109 .68975 L
.40206 .68456 L
.40329 .67952 L
.40495 .67407 L
.40889 .66423 L
.41405 .65474 L
.42096 .64521 L
.42879 .63707 L
.43731 .63041 L
.44266 .62712 L
.44804 .62442 L
.45307 .62238 L
.45603 .62138 L
.45886 .62057 L
.46193 .61983 L
.46479 .61928 L
.46789 .61882 L
.46953 .61863 L
.47128 .61848 L
.47269 .61839 L
.47348 .61835 L
.4742 .61833 L
.47488 .61831 L
.47561 .6183 L
.4763 .6183 L
.47694 .6183 L
.47769 .61831 L
Mistroke
.47839 .61833 L
.47916 .61836 L
.47998 .6184 L
.48167 .61852 L
.48321 .61866 L
.48633 .61905 L
.48965 .61964 L
.49558 .62111 L
.49918 .62228 L
.50253 .62357 L
.50865 .62645 L
.51449 .62989 L
.52037 .63413 L
.52994 .64314 L
.53851 .65442 L
.54481 .66614 L
.54762 .67319 L
.54975 .68003 L
.5512 .68626 L
.55184 .68979 L
.55232 .69307 L
.55268 .69634 L
.55283 .69818 L
.55294 .69986 L
.55301 .70133 L
.55305 .70217 L
.55307 .70295 L
.55309 .70377 L
.5531 .70451 L
.5531 .70537 L
.5531 .70618 L
.55309 .70701 L
.55307 .70792 L
.55306 .70837 L
.55304 .70886 L
.55301 .70975 L
.55292 .71145 L
.55282 .713 L
.55246 .71674 L
.55199 .72023 L
.55126 .72442 L
Mfstroke
0 0 1 r
.57357 .73071 m
.57147 .73806 L
.56872 .74576 L
.56189 .76006 L
.55276 .77376 L
.5431 .78451 L
.53262 .79336 L
.52264 .79973 L
.51212 .8047 L
.50615 .80682 L
.50064 .80836 L
.49808 .80894 L
.49533 .80948 L
.49297 .80987 L
.4904 .81021 L
.48884 .81038 L
.48741 .81051 L
.48593 .81062 L
.48459 .8107 L
.48396 .81073 L
.48327 .81075 L
.48263 .81077 L
.48204 .81078 L
.48141 .81079 L
.48073 .8108 L
.48038 .8108 L
.48001 .8108 L
.47935 .81079 L
.4787 .81078 L
.47834 .81077 L
.478 .81077 L
.47725 .81074 L
.47657 .81071 L
.47534 .81065 L
.47402 .81056 L
.47124 .8103 L
.46835 .80993 L
.46353 .80909 L
.45838 .80788 L
.44915 .80482 L
.43986 .80053 L
.43104 .79518 L
.42335 .7893 L
.41044 .77613 L
.4047 .76844 L
.39933 .75969 L
.39497 .75094 L
.39159 .74251 L
.38862 .73301 L
.38727 .72753 L
Mistroke
.38624 .72232 L
.38547 .71745 L
.38485 .71216 L
.3846 .70909 L
.3845 .70757 L
.38442 .70617 L
.38437 .70491 L
.38432 .70353 L
.3843 .7028 L
.38429 .70213 L
.38428 .70141 L
.38428 .70101 L
.38427 .70064 L
.38427 .69997 L
.38427 .69934 L
.38428 .69864 L
.38429 .6979 L
.3843 .69715 L
.38432 .69637 L
.38437 .69496 L
.38443 .69365 L
.38449 .69242 L
.38469 .68962 L
.38498 .68653 L
.38531 .6837 L
.38629 .67728 L
.38754 .67121 L
.38899 .66557 L
.3934 .65272 L
.3989 .64112 L
.40677 .62867 L
.41613 .61758 L
.42834 .60692 L
.43508 .6024 L
.44298 .5981 L
.45096 .59474 L
.45465 .59349 L
.45873 .59232 L
.46288 .59134 L
.46677 .59063 L
.47053 .59011 L
.47244 .58991 L
.47455 .58974 L
.47576 .58967 L
.4769 .58962 L
.47794 .58958 L
.47906 .58956 L
.47964 .58955 L
.48029 .58955 L
.48096 .58956 L
Mistroke
.48159 .58956 L
.48271 .58959 L
.48335 .58961 L
.48393 .58964 L
.48609 .58976 L
.48731 .58985 L
.48845 .58996 L
.49276 .59049 L
.49512 .59088 L
.49728 .59129 L
.50215 .59244 L
.51088 .59525 L
.51861 .59862 L
.5265 .603 L
.53396 .60812 L
.54145 .61442 L
.55344 .62763 L
.55913 .63583 L
.56446 .64528 L
.56833 .65381 L
.57179 .6635 L
.57311 .66807 L
.57433 .67303 L
.57521 .67734 L
.57599 .68205 L
.57663 .68708 L
.57689 .68981 L
.57707 .69235 L
.57715 .69357 L
.5772 .69473 L
.57724 .69577 L
.57728 .69688 L
.57731 .69808 L
.57732 .69919 L
.57732 .70038 L
.57732 .70105 L
.57732 .70168 L
.5773 .70266 L
.57728 .7037 L
.57725 .70468 L
.57721 .70556 L
.5771 .70772 L
.57697 .70974 L
.57664 .71336 L
.57618 .71722 L
.57499 .72435 L
.57357 .73071 L
Mfstroke
1 0 0 r
.5963 .73874 m
.59322 .74766 L
.58932 .75691 L
.58 .77385 L
.568 .78972 L
.55565 .80189 L
.54253 .81163 L
.53026 .81843 L
.51752 .82352 L
.51036 .82559 L
.50719 .82633 L
.5038 .82701 L
.50051 .82755 L
.49752 .82796 L
.49453 .82827 L
.4917 .82848 L
.49013 .82857 L
.48927 .82861 L
.48846 .82863 L
.4877 .82865 L
.48689 .82867 L
.48615 .82868 L
.48547 .82868 L
.48466 .82868 L
.48391 .82867 L
.48309 .82865 L
.48263 .82864 L
.48221 .82863 L
.48045 .82856 L
.4788 .82846 L
.476 .82824 L
.47294 .82791 L
.46979 .82747 L
.46686 .82697 L
.45634 .82444 L
.45094 .82267 L
.44543 .82053 L
.43603 .81601 L
.41856 .80428 L
.41057 .79713 L
.40278 .78878 L
.3961 .7802 L
.38964 .77025 L
.37987 .75015 L
.3761 .73938 L
.37446 .73367 L
.37293 .72739 L
.37171 .72135 L
.37079 .7157 L
.37006 .7099 L
Mistroke
.36978 .70701 L
.36956 .70427 L
.36946 .70272 L
.36936 .70104 L
.36929 .69963 L
.36924 .69808 L
.36919 .69638 L
.36917 .69545 L
.36916 .69458 L
.36915 .69376 L
.36915 .69301 L
.36915 .69215 L
.36915 .69133 L
.36916 .69062 L
.36917 .68984 L
.36919 .68902 L
.36921 .68826 L
.36926 .68688 L
.36932 .68539 L
.36951 .68197 L
.36976 .6788 L
.37051 .6719 L
.37151 .66537 L
.37297 .65806 L
.37497 .65012 L
.38056 .63389 L
.38807 .61838 L
.39807 .60316 L
.40976 .58985 L
.4243 .57769 L
.43373 .57172 L
.44327 .56694 L
.44829 .56488 L
.45393 .56291 L
.45904 .56144 L
.4646 .56015 L
.4697 .55926 L
.47263 .55886 L
.47542 .55857 L
.47666 .55846 L
.47797 .55836 L
.47911 .55829 L
.48033 .55823 L
.48165 .55818 L
.48288 .55815 L
.48435 .55813 L
.48569 .55814 L
.48707 .55816 L
.48837 .55819 L
.4898 .55825 L
Mistroke
.49133 .55834 L
.49447 .55859 L
.49734 .5589 L
.50287 .55974 L
.50811 .56081 L
.51412 .5624 L
.51963 .56419 L
.53186 .5694 L
.54325 .57594 L
.55334 .58332 L
.57011 .59992 L
.57765 .60985 L
.58459 .62105 L
.59009 .63205 L
.59425 .6424 L
.59781 .65375 L
.59927 .65963 L
.60058 .66604 L
.60154 .67197 L
.60222 .67743 L
.60268 .68263 L
.60284 .68525 L
.60292 .68674 L
.60297 .68812 L
.60302 .68947 L
.60305 .69091 L
.60306 .69174 L
.60307 .69251 L
.60307 .69396 L
.60306 .69548 L
.60304 .69688 L
.603 .69841 L
.60294 .70003 L
.60281 .70268 L
.60264 .70514 L
.60213 .71068 L
.60136 .71659 L
.60046 .72189 L
.59783 .73343 L
.5963 .73874 L
Mfstroke
0 0 1 r
.61928 .74859 m
.60977 .76975 L
.59762 .7891 L
.5837 .80559 L
.56727 .8201 L
.55209 .83006 L
.53567 .83786 L
.52768 .84068 L
.51909 .84306 L
.51518 .84392 L
.51107 .84469 L
.50725 .84527 L
.50377 .84568 L
.50205 .84585 L
.50018 .84601 L
.4984 .84613 L
.49679 .84622 L
.4959 .84626 L
.49493 .84629 L
.4944 .84631 L
.49391 .84632 L
.49295 .84634 L
.49213 .84634 L
.49123 .84635 L
.4903 .84634 L
.48942 .84633 L
.48861 .84632 L
.48772 .8463 L
.48611 .84624 L
.48456 .84616 L
.48313 .84607 L
.47991 .84581 L
.47653 .84544 L
.47015 .84447 L
.46346 .84306 L
.45185 .83965 L
.43988 .83476 L
.42816 .82847 L
.40928 .81458 L
.40069 .80636 L
.39234 .79688 L
.38516 .78726 L
.37821 .77619 L
.36757 .75402 L
.36335 .74218 L
.35969 .72902 L
.35834 .7229 L
.35708 .71615 L
.3561 .70967 L
.35537 .70352 L
Mistroke
.35502 .69974 L
.35477 .69626 L
.35455 .69235 L
.35446 .69018 L
.35443 .6892 L
.3544 .68812 L
.35438 .68723 L
.35437 .68628 L
.35436 .68575 L
.35435 .68527 L
.35435 .68432 L
.35435 .68346 L
.35435 .68251 L
.35435 .68162 L
.35436 .68079 L
.35438 .67983 L
.3544 .67893 L
.35445 .67686 L
.35453 .67484 L
.35464 .67264 L
.35489 .66867 L
.35521 .66493 L
.35622 .65626 L
.35764 .64757 L
.35969 .63803 L
.36218 .62879 L
.36557 .61854 L
.37389 .59947 L
.38538 .58043 L
.39269 .5709 L
.40172 .56102 L
.4114 .55226 L
.42124 .54491 L
.43145 .53867 L
.44318 .533 L
.44934 .5306 L
.45636 .52832 L
.46301 .52659 L
.46924 .52532 L
.47279 .52475 L
.47671 .52425 L
.48068 .52388 L
.48287 .52373 L
.48384 .52367 L
.4849 .52362 L
.48685 .52356 L
.4887 .52352 L
.4905 .52352 L
.49217 .52354 L
.49397 .52359 L
Mistroke
.49596 .52367 L
.49804 .52379 L
.49999 .52394 L
.50389 .52433 L
.50751 .52481 L
.5157 .5263 L
.52287 .52808 L
.53045 .53047 L
.54456 .53637 L
.55682 .54319 L
.56996 .55252 L
.58111 .56243 L
.59285 .57539 L
.60243 .5886 L
.61047 .60237 L
.6166 .61544 L
.62205 .63033 L
.62433 .63817 L
.62635 .64652 L
.62775 .65369 L
.62895 .66157 L
.62937 .66501 L
.62974 .6687 L
.63002 .67215 L
.63022 .67535 L
.63032 .67717 L
.63039 .6791 L
.63043 .6802 L
.63045 .68124 L
.63049 .68318 L
.6305 .68417 L
.6305 .68522 L
.63049 .6871 L
.63048 .68814 L
.63046 .68911 L
.63044 .69017 L
.63041 .69131 L
.63034 .69316 L
.63025 .69516 L
.63002 .69879 L
.62973 .70229 L
.62941 .70551 L
.62866 .71149 L
.62764 .71784 L
.62528 .729 L
.6224 .73942 L
.61928 .74859 L
Mfstroke
1 0 0 r
.64236 .7603 m
.62991 .78427 L
.61462 .80576 L
.59759 .82367 L
.57792 .83905 L
.5601 .84927 L
.5411 .85697 L
.53195 .85961 L
.52718 .86073 L
.52217 .86173 L
.51783 .86243 L
.5131 .86304 L
.51105 .86326 L
.50885 .86345 L
.50677 .8636 L
.5049 .86371 L
.50277 .86381 L
.50161 .86384 L
.50052 .86387 L
.49952 .86388 L
.49859 .86389 L
.49758 .86389 L
.49651 .86389 L
.49544 .86387 L
.49483 .86386 L
.49429 .86385 L
.49223 .86378 L
.49108 .86373 L
.48984 .86366 L
.48759 .86351 L
.48358 .86315 L
.47939 .86264 L
.47202 .86143 L
.46507 .8599 L
.4578 .85789 L
.44527 .85338 L
.43244 .8473 L
.41995 .83979 L
.39997 .82381 L
.38213 .80405 L
.36802 .7828 L
.36192 .77119 L
.35609 .758 L
.35163 .74583 L
.34746 .7318 L
.34424 .71778 L
.34279 .7097 L
.34168 .7021 L
.34081 .69431 L
.34048 .69065 L
Mistroke
.34019 .6867 L
.34006 .68447 L
.33995 .68243 L
.33986 .68034 L
.33979 .6784 L
.33973 .67611 L
.33971 .6749 L
.3397 .67428 L
.33969 .67362 L
.33968 .67249 L
.33968 .67144 L
.33968 .67079 L
.33968 .67018 L
.33968 .66903 L
.33969 .66802 L
.33971 .66694 L
.33973 .66591 L
.33975 .66496 L
.33982 .66275 L
.33991 .6604 L
.34014 .6559 L
.34051 .6509 L
.34146 .64172 L
.34273 .6329 L
.34478 .62203 L
.34734 .61138 L
.35412 .59051 L
.35892 .57913 L
.36509 .56686 L
.37948 .54476 L
.38872 .53369 L
.40017 .52232 L
.41238 .51245 L
.42496 .50425 L
.44089 .49625 L
.44986 .49279 L
.45977 .48975 L
.46861 .4877 L
.47274 .48695 L
.47712 .48629 L
.47947 .486 L
.48206 .48573 L
.48445 .48552 L
.48663 .48536 L
.48923 .48522 L
.49065 .48517 L
.49201 .48513 L
.49442 .48509 L
.49578 .48509 L
.49704 .4851 L
Mistroke
.49943 .48514 L
.50171 .48523 L
.50375 .48534 L
.50599 .48549 L
.51099 .48596 L
.51563 .48657 L
.52406 .48806 L
.53298 .49022 L
.54349 .49355 L
.5532 .49742 L
.57067 .50647 L
.58697 .51768 L
.60267 .53158 L
.6263 .56069 L
.63599 .57718 L
.64448 .59558 L
.65071 .61337 L
.65492 .62972 L
.65666 .63872 L
.65808 .64822 L
.65894 .65629 L
.6593 .66085 L
.65954 .6651 L
.65963 .66731 L
.65971 .66972 L
.65974 .67093 L
.65976 .67222 L
.65978 .67454 L
.65978 .67685 L
.65976 .67903 L
.65972 .68097 L
.65965 .68307 L
.65956 .68536 L
.65943 .68786 L
.65909 .69289 L
.65867 .69749 L
.6582 .70175 L
.65704 .70995 L
.65545 .71868 L
.65175 .73395 L
.64724 .74801 L
.64236 .7603 L
Mfstroke
0 0 1 r
.66535 .7739 m
.64961 .80042 L
.6309 .82373 L
.61058 .84273 L
.5876 .85861 L
.56711 .86882 L
.55576 .87309 L
.54557 .87613 L
.53557 .87844 L
.52649 .87995 L
.52182 .88052 L
.51674 .88098 L
.51421 .88114 L
.51282 .88121 L
.5115 .88127 L
.51029 .88132 L
.50897 .88135 L
.50777 .88138 L
.50666 .88139 L
.50547 .8814 L
.50487 .8814 L
.50421 .88139 L
.50305 .88138 L
.50198 .88136 L
.50071 .88133 L
.49956 .88129 L
.49698 .88117 L
.49478 .88104 L
.4924 .88086 L
.48812 .88044 L
.48404 .87992 L
.47978 .87927 L
.47228 .87782 L
.45673 .87355 L
.44308 .86832 L
.42909 .86137 L
.41722 .85407 L
.39473 .836 L
.37657 .81613 L
.36058 .79282 L
.34808 .76845 L
.34271 .75525 L
.33761 .74029 L
.33375 .72643 L
.33019 .71036 L
.32755 .69413 L
.32644 .68478 L
.32564 .67569 L
.32535 .67111 L
.32521 .66865 L
Mistroke
.3251 .666 L
.325 .66343 L
.32494 .66108 L
.32491 .65993 L
.32489 .65869 L
.32488 .6575 L
.32486 .65641 L
.32486 .65534 L
.32485 .65419 L
.32486 .6531 L
.32486 .6521 L
.32487 .65093 L
.32489 .64964 L
.32491 .64842 L
.32493 .64729 L
.32499 .64501 L
.32508 .64246 L
.32534 .63723 L
.3257 .63184 L
.3262 .62603 L
.32747 .61528 L
.32943 .60313 L
.33243 .58915 L
.33627 .57524 L
.34077 .56208 L
.34749 .54612 L
.35532 .53101 L
.3756 .50196 L
.38946 .4873 L
.40666 .47301 L
.42403 .46196 L
.43441 .4567 L
.44474 .45236 L
.45471 .44895 L
.46594 .44597 L
.47099 .44491 L
.47643 .44396 L
.48114 .4433 L
.48633 .44273 L
.48926 .44249 L
.492 .44231 L
.4949 .44218 L
.498 .44209 L
.50091 .44207 L
.50366 .44209 L
.50613 .44216 L
.50882 .44227 L
.51176 .44245 L
.515 .4427 L
.52155 .44342 L
Mistroke
.52762 .44433 L
.53328 .44539 L
.54432 .44806 L
.5543 .45117 L
.57608 .46041 L
.5974 .47311 L
.61558 .48735 L
.63348 .50528 L
.64994 .52648 L
.66311 .54838 L
.67438 .57313 L
.67854 .5847 L
.68224 .59699 L
.6851 .60851 L
.6872 .61898 L
.68891 .62999 L
.69007 .64033 L
.69053 .64595 L
.69083 .65112 L
.69095 .6538 L
.69104 .65675 L
.69108 .65823 L
.69111 .65982 L
.69113 .66268 L
.69113 .66518 L
.6911 .66749 L
.69105 .67001 L
.69096 .6727 L
.69085 .6755 L
.69071 .67814 L
.69038 .68304 L
.68955 .69174 L
.68834 .70098 L
.6867 .71066 L
.68485 .71949 L
.67964 .73869 L
.67337 .75618 L
.66552 .77357 L
.66535 .7739 L
Mfstroke
1 0 0 r
.68808 .78938 m
.66871 .81814 L
.64636 .84291 L
.62262 .86265 L
.59628 .87869 L
.57315 .8886 L
.56046 .89257 L
.54914 .89528 L
.54374 .89631 L
.53808 .8972 L
.53324 .89781 L
.5281 .89832 L
.52525 .89853 L
.52266 .89869 L
.52142 .89875 L
.52007 .8988 L
.51881 .89885 L
.51763 .89888 L
.51691 .89889 L
.51613 .89891 L
.51479 .89892 L
.51402 .89892 L
.51322 .89892 L
.51253 .89892 L
.51178 .89892 L
.51044 .8989 L
.50969 .89888 L
.50901 .89886 L
.50644 .89878 L
.50413 .89867 L
.50161 .89851 L
.49657 .89808 L
.49197 .89757 L
.48772 .89698 L
.47839 .8953 L
.4687 .89298 L
.45167 .88743 L
.43512 .88009 L
.40869 .86376 L
.38502 .84311 L
.36608 .82091 L
.34949 .7953 L
.33646 .76878 L
.32629 .74128 L
.32194 .7264 L
.31778 .7091 L
.31445 .69153 L
.31195 .67384 L
.31089 .66354 L
.31045 .65829 L
Mistroke
.3101 .65329 L
.30982 .64828 L
.30963 .64364 L
.30954 .64093 L
.30947 .63835 L
.30944 .63701 L
.30942 .63559 L
.30941 .63485 L
.3094 .63402 L
.30939 .63257 L
.30938 .63102 L
.30938 .62959 L
.30939 .62883 L
.30939 .62799 L
.3094 .62712 L
.30941 .62629 L
.30943 .62477 L
.30945 .62337 L
.30953 .62017 L
.30962 .61744 L
.30975 .61441 L
.31009 .60818 L
.31062 .60111 L
.31139 .5933 L
.31341 .57849 L
.31647 .56236 L
.32128 .54368 L
.32763 .5249 L
.33543 .50678 L
.3574 .47034 L
.37464 .45008 L
.39418 .43249 L
.40521 .42446 L
.41812 .41651 L
.43024 .4103 L
.4438 .40464 L
.4565 .40047 L
.46343 .39863 L
.47103 .39694 L
.47806 .39569 L
.48459 .39479 L
.49088 .39415 L
.49407 .39391 L
.49756 .39372 L
.50154 .39358 L
.50522 .39352 L
.50715 .39353 L
.50928 .39355 L
.51149 .39361 L
.51357 .39369 L
Mistroke
.5174 .39389 L
.5209 .39414 L
.52493 .39452 L
.52876 .39497 L
.54231 .39719 L
.54992 .39889 L
.55693 .40075 L
.58643 .41183 L
.60211 .42003 L
.61569 .42858 L
.64023 .44804 L
.66017 .4686 L
.67893 .49342 L
.6951 .52141 L
.70633 .54713 L
.71129 .56146 L
.71523 .57506 L
.71825 .58769 L
.72084 .60134 L
.72261 .61365 L
.72323 .61915 L
.72376 .62491 L
.72422 .63133 L
.72438 .63417 L
.72452 .63718 L
.72464 .64042 L
.72471 .64342 L
.72474 .64525 L
.72476 .64698 L
.72477 .65019 L
.72474 .65301 L
.72469 .65598 L
.72462 .65851 L
.72452 .66128 L
.7242 .66739 L
.72379 .67305 L
.72318 .67961 L
.72248 .68575 L
.72083 .69705 L
.7186 .70887 L
.7157 .72134 L
.70407 .75664 L
.69607 .77445 L
.68808 .78938 L
Mfstroke
0 0 1 r
.71039 .80671 m
.6871 .83734 L
.66092 .86319 L
.63368 .88332 L
.61805 .89237 L
.60396 .89916 L
.59152 .90416 L
.57824 .90852 L
.5645 .91202 L
.55792 .91333 L
.55183 .91435 L
.54582 .91516 L
.54038 .91574 L
.53753 .91598 L
.53443 .91619 L
.53274 .91628 L
.53119 .91636 L
.52959 .91642 L
.52813 .91647 L
.5266 .9165 L
.52579 .91652 L
.52495 .91653 L
.52353 .91654 L
.52273 .91654 L
.52198 .91654 L
.52059 .91653 L
.51933 .91651 L
.51787 .91648 L
.5165 .91644 L
.51348 .91632 L
.51072 .91617 L
.5077 .91596 L
.50453 .91568 L
.49456 .91447 L
.48909 .91357 L
.48417 .91263 L
.46637 .90806 L
.44925 .90188 L
.43201 .89371 L
.40246 .87443 L
.37874 .85288 L
.35789 .82774 L
.34137 .80179 L
.32817 .77532 L
.31652 .74519 L
.3072 .71346 L
.29983 .67899 L
.2967 .65902 L
.29521 .64699 L
.29404 .63512 L
Mistroke
.29351 .62854 L
.2931 .62237 L
.29274 .61527 L
.29258 .61126 L
.29247 .6074 L
.29239 .60391 L
.29237 .60213 L
.29235 .60111 L
.29234 .60016 L
.29233 .59843 L
.29233 .59685 L
.29233 .59501 L
.29235 .59325 L
.29237 .59132 L
.29238 .59034 L
.2924 .58925 L
.29249 .58548 L
.29256 .58333 L
.29264 .58098 L
.29284 .57667 L
.29337 .56825 L
.29408 .56009 L
.29512 .55077 L
.2966 .54035 L
.29865 .52886 L
.30112 .51751 L
.30746 .49499 L
.31631 .47167 L
.32932 .44591 L
.34397 .42367 L
.3643 .39996 L
.39069 .37724 L
.419 .35994 L
.43615 .35225 L
.44557 .34881 L
.45582 .34565 L
.46493 .34334 L
.47516 .34128 L
.47968 .34054 L
.48459 .33986 L
.48918 .33933 L
.49353 .33893 L
.49828 .3386 L
.50262 .33839 L
.50729 .33827 L
.50994 .33826 L
.51238 .33827 L
.51645 .33835 L
.52093 .33854 L
.52562 .33884 L
Mistroke
.53 .33922 L
.54005 .34043 L
.5492 .34197 L
.55968 .34424 L
.56953 .34688 L
.58866 .35344 L
.60584 .36104 L
.64211 .38306 L
.6728 .40946 L
.69749 .43784 L
.71602 .46538 L
.73219 .49651 L
.74434 .52783 L
.74965 .54566 L
.75362 .56224 L
.75684 .57959 L
.75893 .59522 L
.75976 .60377 L
.76011 .60825 L
.76041 .61297 L
.76062 .61707 L
.76071 .61924 L
.76079 .62157 L
.7609 .62564 L
.76095 .62944 L
.76096 .6333 L
.76093 .63678 L
.76085 .64077 L
.76073 .64452 L
.76059 .64798 L
.76043 .65114 L
.75995 .65823 L
.75933 .66529 L
.75848 .67294 L
.75628 .68805 L
.75354 .70232 L
.75001 .71709 L
.74223 .74227 L
.72718 .77757 L
.71039 .80671 L
Mfstroke
1 0 0 r
.73211 .82582 m
.70467 .85793 L
.67452 .88447 L
.64373 .90462 L
.62628 .91346 L
.61066 .91994 L
.59696 .9246 L
.5824 .92852 L
.57457 .9302 L
.56744 .93148 L
.56077 .93246 L
.5537 .93328 L
.55028 .93359 L
.54705 .93383 L
.54393 .93402 L
.54105 .93415 L
.53966 .9342 L
.53836 .93424 L
.53686 .93427 L
.53551 .93429 L
.53401 .93431 L
.53264 .93431 L
.53114 .93431 L
.52956 .93429 L
.52796 .93426 L
.52651 .93422 L
.52484 .93417 L
.52326 .9341 L
.52048 .93396 L
.51749 .93377 L
.5108 .93318 L
.50473 .93246 L
.49378 .9307 L
.48388 .92859 L
.46262 .92233 L
.44354 .91452 L
.42748 .90619 L
.39737 .88548 L
.37329 .86293 L
.35207 .83702 L
.33518 .81067 L
.32026 .78125 L
.30814 .75119 L
.298 .7199 L
.28834 .68243 L
.28385 .66125 L
.27985 .63916 L
.27633 .61514 L
.27459 .60005 L
.27327 .58501 L
Mistroke
.27273 .5768 L
.27248 .57212 L
.27229 .56761 L
.27215 .56328 L
.27208 .5608 L
.27203 .55848 L
.272 .5565 L
.27198 .55431 L
.27197 .55199 L
.27197 .5498 L
.27198 .54714 L
.272 .54563 L
.27202 .54421 L
.27207 .54159 L
.27214 .53877 L
.27232 .53379 L
.2726 .52815 L
.273 .52197 L
.27357 .5151 L
.27503 .5021 L
.27702 .48892 L
.27951 .47604 L
.28344 .45994 L
.28806 .44464 L
.30142 .41162 L
.31138 .39291 L
.32272 .37523 L
.34891 .34376 L
.36476 .32906 L
.38414 .31432 L
.40219 .30321 L
.4229 .29307 L
.44354 .2854 L
.46309 .28014 L
.47378 .27804 L
.48572 .27631 L
.49176 .27568 L
.49494 .27542 L
.4983 .27518 L
.50449 .27488 L
.51018 .27475 L
.51545 .27475 L
.52108 .27489 L
.5264 .27514 L
.53123 .27547 L
.5369 .27599 L
.54304 .2767 L
.55413 .27841 L
.56592 .2808 L
.57873 .28409 L
Mistroke
.60399 .29276 L
.6264 .30302 L
.64637 .31439 L
.68558 .34387 L
.71741 .37677 L
.74127 .40911 L
.76227 .44628 L
.77165 .46718 L
.77914 .48698 L
.78983 .52389 L
.79405 .54436 L
.79689 .56293 L
.798 .57254 L
.79893 .58298 L
.79929 .58819 L
.79959 .59374 L
.79971 .59642 L
.7998 .59895 L
.79993 .60367 L
.8 .60782 L
.80002 .61227 L
.8 .61645 L
.79994 .62025 L
.79983 .62445 L
.79965 .62901 L
.79942 .63373 L
.79915 .63809 L
.79843 .64704 L
.79762 .65505 L
.79523 .67258 L
.79261 .68714 L
.78921 .7024 L
.78175 .72865 L
.77227 .75442 L
.7603 .78036 L
.7325 .8253 L
.73211 .82582 L
Mfstroke
0 0 1 r
.75311 .84663 m
.72131 .8798 L
.68711 .90664 L
.65275 .92646 L
.63372 .93482 L
.61639 .94095 L
.59971 .94556 L
.59169 .94735 L
.58439 .94873 L
.57103 .95068 L
.56414 .95138 L
.56044 .95168 L
.55696 .9519 L
.55361 .95207 L
.55185 .95214 L
.54998 .9522 L
.54827 .95224 L
.54672 .95227 L
.54517 .95228 L
.54371 .95229 L
.54201 .95228 L
.54022 .95227 L
.5387 .95224 L
.53704 .9522 L
.53526 .95214 L
.53336 .95207 L
.52996 .9519 L
.52684 .95169 L
.52348 .95143 L
.51745 .95083 L
.50645 .94931 L
.49503 .94716 L
.48295 .94422 L
.4601 .93668 L
.44089 .92819 L
.42204 .91771 L
.38997 .89409 L
.36464 .86886 L
.34451 .84313 L
.32674 .8146 L
.3124 .78606 L
.29931 .7542 L
.288 .72115 L
.27756 .6856 L
.26601 .64039 L
.25984 .61293 L
.25389 .58228 L
.25106 .56473 L
.24859 .54609 L
.24741 .53482 L
Mistroke
.24687 .52856 L
.24636 .52163 L
.24598 .51498 L
.2457 .50873 L
.2456 .50563 L
.24552 .50223 L
.24546 .49896 L
.24543 .49591 L
.24543 .49215 L
.24546 .48852 L
.24552 .48521 L
.24562 .48155 L
.24577 .4775 L
.24598 .47312 L
.24651 .46503 L
.24718 .45733 L
.248 .44988 L
.25062 .4321 L
.25493 .41149 L
.2605 .39159 L
.26872 .36881 L
.28013 .3442 L
.30765 .30142 L
.32754 .27873 L
.34831 .2597 L
.36992 .24372 L
.39542 .22886 L
.42115 .21751 L
.44595 .20958 L
.46051 .20617 L
.47396 .2038 L
.48144 .2028 L
.4854 .20236 L
.48961 .20196 L
.49735 .2014 L
.50452 .20108 L
.51104 .20096 L
.51807 .20101 L
.5247 .20123 L
.53078 .20158 L
.53749 .20212 L
.54481 .2029 L
.55948 .20507 L
.5755 .20838 L
.58985 .21217 L
.62105 .22324 L
.64848 .23639 L
.67288 .25106 L
.71688 .2859 L
.75585 .32865 L
Mistroke
.78281 .36818 L
.80606 .41338 L
.81593 .43798 L
.8237 .46132 L
.82948 .48241 L
.83436 .50463 L
.83658 .51711 L
.83826 .52832 L
.83965 .53961 L
.84067 .54988 L
.84154 .56178 L
.84187 .56797 L
.842 .57111 L
.84212 .57446 L
.84226 .58007 L
.84232 .58526 L
.84233 .58842 L
.84232 .5914 L
.84224 .59694 L
.84212 .60171 L
.84194 .60681 L
.84171 .61159 L
.84146 .61594 L
.84071 .62592 L
.8397 .63626 L
.83718 .65524 L
.83359 .67524 L
.8253 .70884 L
.81571 .73773 L
.80244 .76909 L
.78842 .79584 L
.75943 .83882 L
.75311 .84663 L
Mfstroke
1 0 0 r
.77324 .86905 m
.73695 .90284 L
.69864 .92956 L
.66076 .94873 L
.63998 .95654 L
.62117 .96208 L
.61247 .96417 L
.60318 .96607 L
.59512 .96744 L
.58672 .9686 L
.57929 .9694 L
.5754 .96973 L
.57125 .97003 L
.56748 .97023 L
.56406 .97037 L
.56243 .97043 L
.56065 .97047 L
.55899 .9705 L
.55744 .97052 L
.55549 .97053 L
.55451 .97053 L
.55344 .97052 L
.55155 .9705 L
.54979 .97047 L
.54873 .97044 L
.54773 .97042 L
.54586 .97036 L
.54169 .97017 L
.5381 .96995 L
.5348 .96971 L
.52746 .96901 L
.51507 .96733 L
.50242 .96496 L
.49057 .96211 L
.47834 .95851 L
.45763 .95081 L
.4369 .9409 L
.41717 .92917 L
.38641 .90556 L
.35958 .87822 L
.33842 .85064 L
.31987 .82042 L
.30488 .79045 L
.29229 .76051 L
.27995 .72663 L
.26804 .69053 L
.25522 .64983 L
.23788 .59321 L
.2279 .55795 L
.2222 .53524 L
Mistroke
.21616 .5066 L
.21312 .48826 L
.2108 .46979 L
.20991 .46016 L
.20951 .4549 L
.20916 .44919 L
.20892 .44406 L
.20881 .44129 L
.20872 .43828 L
.20862 .4329 L
.2086 .42776 L
.20861 .42477 L
.20866 .42156 L
.20881 .41568 L
.20894 .41236 L
.2091 .4092 L
.20956 .40188 L
.2101 .39535 L
.21072 .38924 L
.21258 .37505 L
.21471 .36266 L
.21769 .3487 L
.22607 .31944 L
.2392 .2867 L
.25592 .25565 L
.27473 .22848 L
.29909 .20076 L
.33011 .17364 L
.36719 .14972 L
.40156 .13386 L
.42188 .12688 L
.44124 .12174 L
.45092 .11969 L
.46126 .11787 L
.47023 .11659 L
.47993 .11552 L
.48534 .11507 L
.4903 .11473 L
.50004 .11432 L
.5052 .11422 L
.51084 .11422 L
.51672 .11433 L
.52219 .11453 L
.53212 .11515 L
.54145 .11602 L
.54978 .11703 L
.55876 .11838 L
.57866 .12231 L
.59666 .127 L
.62711 .13746 L
Mistroke
.65895 .15201 L
.71708 .18944 L
.74498 .2134 L
.76892 .23792 L
.8072 .28719 L
.8391 .34293 L
.85317 .37493 L
.86385 .40457 L
.87215 .43304 L
.87903 .46339 L
.8815 .47712 L
.88367 .49147 L
.88519 .50373 L
.88647 .51671 L
.88698 .52314 L
.88738 .52919 L
.8877 .53504 L
.88794 .54041 L
.88811 .54547 L
.88823 .5508 L
.8883 .55613 L
.88831 .56196 L
.88825 .56819 L
.88812 .57386 L
.88791 .58004 L
.88761 .58648 L
.88693 .5972 L
.88594 .60873 L
.88466 .62041 L
.88299 .6328 L
.87927 .65462 L
.87016 .69305 L
.85658 .734 L
.84186 .76806 L
.81087 .82188 L
.77324 .86905 L
Mfstroke
0 0 1 r
.79239 .89296 m
.75151 .92693 L
.7091 .95314 L
.66774 .97133 L
.64526 .97845 L
.62504 .98328 L
.61571 .98502 L
.60577 .98653 L
.59658 .98761 L
.59226 .98802 L
.58824 .98834 L
.58438 .98859 L
.58087 .98878 L
.57701 .98893 L
.57489 .98899 L
.57289 .98903 L
.57098 .98906 L
.56895 .98908 L
.56704 .98908 L
.56532 .98907 L
.56331 .98904 L
.56217 .98902 L
.56113 .989 L
.55723 .98888 L
.5552 .98879 L
.5533 .9887 L
.54975 .98849 L
.54191 .98786 L
.53527 .98715 L
.52819 .98622 L
.5127 .9835 L
.49903 .98032 L
.47504 .97285 L
.45097 .96277 L
.41065 .9391 L
.37902 .91316 L
.3517 .88373 L
.33029 .85444 L
.31319 .82576 L
.29777 .79467 L
.28468 .76386 L
.27158 .72935 L
.25841 .69287 L
.2433 .65206 L
.22055 .59559 L
.20416 .55669 L
.1842 .50601 L
.17303 .47204 L
.1676 .45204 L
.16293 .43112 L
Mistroke
.16044 .4173 L
.1585 .40391 L
.15762 .39641 L
.1568 .38803 L
.15642 .38329 L
.15612 .37886 L
.15588 .37458 L
.15568 .36992 L
.15547 .36216 L
.15542 .35474 L
.15557 .34569 L
.15591 .33722 L
.15649 .32818 L
.15741 .31813 L
.15857 .30841 L
.15992 .29925 L
.16379 .27896 L
.16858 .25985 L
.17518 .23889 L
.18422 .21576 L
.20402 .17693 L
.23099 .13784 L
.26802 .09836 L
.29109 .07921 L
.31434 .06309 L
.33715 .04989 L
.36281 .03771 L
.3869 .02857 L
.40928 .02189 L
.43304 .01658 L
.44618 .0144 L
.45866 .0128 L
.47015 .01174 L
.48078 .01109 L
.4924 .01075 L
.50471 .01081 L
.51692 .01129 L
.52376 .01175 L
.53 .01227 L
.54144 .01352 L
.55338 .01521 L
.57831 .02002 L
.60485 .02711 L
.65137 .04459 L
.69727 .06872 L
.73663 .09565 L
.769 .1229 L
.82544 .18487 L
.86584 .24608 L
.89851 .31468 L
Mistroke
.91081 .34909 L
.92144 .38646 L
.9288 .42046 L
.9316 .43692 L
.93375 .45201 L
.93544 .46658 L
.93664 .47962 L
.93761 .4939 L
.93799 .50165 L
.93826 .50889 L
.93843 .51608 L
.93848 .52013 L
.93851 .52389 L
.93849 .53144 L
.93844 .53564 L
.93836 .53945 L
.93817 .54621 L
.93787 .55349 L
.93751 .5603 L
.9371 .56654 L
.93597 .58024 L
.93437 .59505 L
.9301 .62399 L
.92529 .64834 L
.91928 .6728 L
.90649 .71359 L
.8903 .75339 L
.87043 .79225 L
.83389 .84697 L
.79239 .89296 L
Mfstroke
1 0 0 r
.46887 .71429 m
.46922 .71429 L
.46954 .71429 L
.46991 .71429 L
.47026 .71429 L
.47088 .71429 L
.47155 .7143 L
.4723 .7143 L
.47309 .71431 L
.47451 .71433 L
.47599 .71436 L
.47737 .71439 L
.48054 .71449 L
.48381 .71462 L
.48681 .71476 L
.49366 .7152 L
.49969 .7157 L
.50637 .71638 L
.5197 .71813 L
.53283 .72038 L
.54706 .72341 L
.56102 .72698 L
.57463 .73105 L
.58928 .73609 L
.60351 .74165 L
.61727 .74766 L
.63196 .7548 L
.6461 .76238 L
.66108 .77123 L
.67542 .78051 L
.6891 .79013 L
.70347 .8011 L
.7171 .81237 L
.72998 .82384 L
.74342 .83672 L
.75604 .84974 L
.76911 .86423 L
.78131 .8788 L
.79239 .89296 L
s
0 0 1 r
.46887 .71429 m
.48004 .7179 L
.49233 .72247 L
.50393 .72737 L
.51513 .73265 L
.52703 .73888 L
.53846 .74548 L
.55051 .75315 L
.56201 .76115 L
.57293 .76941 L
.58436 .77879 L
.59516 .78839 L
.60532 .79813 L
.61586 .80902 L
.62573 .81998 L
.63589 .83214 L
.64533 .84432 L
.65408 .85643 L
.66302 .86972 L
.67124 .88288 L
.67956 .89723 L
.68715 .91139 L
.69406 .92528 L
.70097 .94032 L
.7069 .95429 L
s
1 0 0 r
.46887 .71429 m
.47876 .72101 L
.48936 .72893 L
.49912 .73692 L
.50828 .74508 L
.51777 .75427 L
.52664 .76357 L
.53574 .77392 L
.54418 .78431 L
.55197 .79468 L
.5599 .80608 L
.56717 .81738 L
.57381 .82852 L
.58051 .84065 L
.58658 .85257 L
.59263 .86547 L
.59806 .87808 L
.60292 .89038 L
.60769 .9036 L
.6119 .91645 L
.61597 .93021 L
.6195 .94354 L
.62254 .95642 L
.6254 .97016 L
.62767 .98274 L
s
0 0 1 r
.46887 .71429 m
.47683 .7236 L
.48509 .73417 L
.49244 .74445 L
.49913 .75462 L
.50584 .76572 L
.5119 .77664 L
.5179 .78847 L
.52326 .80004 L
.52803 .81132 L
.53269 .82344 L
.53677 .8352 L
.54034 .84658 L
.54376 .85874 L
.54669 .87048 L
.54942 .88297 L
.5517 .89499 L
.55356 .90653 L
.5552 .91878 L
.55645 .93051 L
.55698 .93648 L
.55746 .94291 L
.55781 .94858 L
.55812 .95478 L
.55833 .96066 L
.55842 .96386 L
.55848 .96684 L
.55851 .9683 L
.55853 .9699 L
.55854 .9714 L
.55855 .97211 L
.55855 .97279 L
.55855 .97339 L
.55856 .97403 L
.55856 .97438 L
.55856 .97475 L
.55856 .97506 L
.55856 .97541 L
.55856 .97577 L
.55856 .9761 L
.55856 .97649 L
.55856 .97685 L
.55856 .97718 L
.55855 .97749 L
.55855 .97819 L
.55855 .97885 L
.55854 .97946 L
.55853 .98083 L
.5585 .98331 L
.55844 .98619 L
Mistroke
.55838 .98892 L
Mfstroke
1 0 0 r
.46887 .71429 m
.47438 .72553 L
.47987 .73792 L
.48452 .74963 L
.48857 .76095 L
.49242 .77301 L
.4957 .78463 L
.49875 .79694 L
.50128 .80876 L
.50335 .82007 L
.50517 .83203 L
.50657 .84344 L
.50761 .85432 L
.50806 .86033 L
.5084 .86579 L
.50867 .8714 L
.50886 .87671 L
.50893 .87939 L
.50896 .88086 L
.50899 .88224 L
.50901 .88353 L
.50903 .88492 L
.50903 .88553 L
.50904 .88618 L
.50904 .88674 L
.50904 .88734 L
.50905 .88771 L
.50905 .88805 L
.50905 .88837 L
.50905 .88871 L
.50905 .88902 L
.50905 .8893 L
.50905 .88962 L
.50905 .88996 L
.50905 .8903 L
.50905 .89049 L
.50905 .89067 L
.50905 .89103 L
.50905 .89142 L
.50904 .89212 L
.50904 .89276 L
.50903 .894 L
.50901 .89535 L
.50897 .89778 L
.50892 .90036 L
.50884 .9032 L
.50862 .90889 L
.50836 .91411 L
.50802 .91968 L
.50714 .93055 L
Mistroke
.50607 .94086 L
.50484 .95063 L
.50332 .96086 L
.50166 .97054 L
.49974 .9805 L
Mfstroke
0 0 1 r
.46887 .71429 m
.47161 .72668 L
.47409 .74001 L
.47597 .75235 L
.47738 .76403 L
.47802 .77046 L
.4785 .77627 L
.47891 .78231 L
.47921 .78783 L
.47944 .79344 L
.47953 .79637 L
.47961 .79947 L
.47963 .80086 L
.47965 .80218 L
.47966 .8029 L
.47967 .8037 L
.47968 .80442 L
.47968 .80508 L
.47969 .80576 L
.47969 .80639 L
.47969 .80674 L
.47969 .80706 L
.47969 .80741 L
.47969 .80779 L
.47969 .80808 L
.47969 .8084 L
.47969 .80871 L
.47969 .80898 L
.47969 .8093 L
.47969 .80965 L
.47968 .81029 L
.47968 .81095 L
.47967 .81166 L
.47966 .81295 L
.47964 .81447 L
.47961 .81586 L
.47955 .81873 L
.47946 .82173 L
.47925 .82718 L
.47899 .83221 L
.47826 .84273 L
.47722 .85368 L
.47598 .864 L
.47459 .87371 L
.4729 .88382 L
.47109 .89334 L
.46919 .9023 L
.46701 .91162 L
.46475 .92039 L
.46221 .9295 L
Mistroke
.45963 .93807 L
.45703 .94612 L
.45414 .9545 L
.45126 .96237 L
.45109 .96282 L
Mfstroke
1 0 0 r
.46887 .71429 m
.46887 .71468 L
.46887 .71504 L
.46887 .71545 L
.46887 .71584 L
.46887 .71653 L
.46886 .71727 L
.46886 .7181 L
.46885 .71897 L
.46883 .72052 L
.46881 .72212 L
.46878 .72362 L
.4687 .727 L
.4686 .73042 L
.46848 .73353 L
.46815 .74043 L
.46779 .74634 L
.46732 .75269 L
.46618 .76484 L
.46483 .77619 L
.46314 .78787 L
.4613 .79877 L
.45934 .80895 L
.45708 .81944 L
.45473 .82924 L
.45234 .83839 L
.44965 .84784 L
.44695 .85667 L
.44396 .86577 L
.44097 .87427 L
.438 .88221 L
.43476 .89042 L
.43156 .89808 L
.42842 .90524 L
.42501 .91265 L
.42167 .91957 L
.41807 .92672 L
.41455 .93341 L
.41122 .9395 L
s
0 0 1 r
.46887 .71429 m
.46583 .72649 L
.46239 .73923 L
.45905 .75068 L
.45575 .76125 L
.45215 .77205 L
.44862 .78204 L
.4448 .79224 L
.44106 .80167 L
.43742 .81041 L
.4335 .81936 L
.42969 .82766 L
.42601 .83535 L
.42206 .84325 L
.41824 .85058 L
.41416 .8581 L
.41023 .86509 L
.40643 .87158 L
.40238 .87825 L
.39849 .88445 L
.39435 .89081 L
.39036 .89673 L
.38653 .90224 L
.38246 .9079 L
.37875 .91291 L
s
1 0 0 r
.46887 .71429 m
.46318 .7252 L
.45712 .73654 L
.45154 .74667 L
.44627 .75598 L
.44076 .76546 L
.43556 .77418 L
.43012 .78303 L
.42497 .79119 L
.42009 .79872 L
.41498 .80639 L
.41013 .81347 L
.40553 .82002 L
.4007 .82671 L
.39612 .8329 L
.39132 .83922 L
.38675 .84507 L
.38242 .85048 L
.37786 .85603 L
.37353 .86117 L
.36899 .86642 L
.36467 .87129 L
.36056 .87581 L
.35625 .88044 L
.35235 .88453 L
s
0 0 1 r
.46887 .71429 m
.46091 .72322 L
.45259 .73253 L
.4451 .74089 L
.43816 .7486 L
.43105 .75645 L
.42443 .76369 L
.41764 .77105 L
.41132 .77784 L
.40542 .7841 L
.39933 .79049 L
.39364 .79638 L
.38831 .80183 L
.38279 .8074 L
.37761 .81254 L
.37225 .81779 L
.36721 .82264 L
.36247 .82713 L
.35754 .83172 L
.35291 .83597 L
.34809 .84031 L
.34354 .84433 L
.33926 .84805 L
.33479 .85186 L
.33079 .85521 L
s
1 0 0 r
.46887 .71429 m
.45915 .72067 L
.44905 .72745 L
.44002 .73364 L
.43171 .73943 L
.42326 .74542 L
.41547 .75099 L
.40754 .75673 L
.40022 .76207 L
.39345 .76704 L
.38653 .77214 L
.38011 .77689 L
.37415 .78129 L
.36804 .78581 L
.36235 .79001 L
.3565 .79431 L
.35105 .79831 L
.34597 .80201 L
.34073 .80581 L
.33584 .80933 L
.33079 .81293 L
.32606 .81627 L
.32163 .81937 L
.31705 .82255 L
.31297 .82534 L
s
0 0 1 r
.46887 .71429 m
.458 .71769 L
.44667 .72154 L
.43651 .72523 L
.42716 .72884 L
.41764 .73271 L
.40888 .73645 L
.39998 .74042 L
.39178 .74421 L
.38423 .74783 L
.37654 .75162 L
.36944 .75522 L
.36288 .75861 L
.35618 .76216 L
.34999 .76549 L
.34366 .76895 L
.3378 .77219 L
.33236 .77523 L
.32679 .77837 L
.32162 .78131 L
.31631 .78434 L
.31138 .78717 L
.30679 .78981 L
.30207 .79252 L
.29788 .79493 L
s
1 0 0 r
.46887 .71429 m
.46852 .71429 L
.4682 .71429 L
.46784 .71429 L
.46749 .71429 L
.46688 .71429 L
.46621 .7143 L
.46548 .7143 L
.4647 .71431 L
.46332 .71433 L
.46189 .71436 L
.46056 .71439 L
.45755 .71448 L
.4545 .71459 L
.45174 .71472 L
.44561 .71509 L
.43475 .71602 L
.42468 .71719 L
.41435 .7187 L
.4048 .72039 L
.39504 .72239 L
.38603 .72449 L
.37771 .72665 L
.36923 .72905 L
.3614 .73145 L
.35419 .73383 L
.34682 .7364 L
.34003 .73891 L
.33311 .74159 L
.32674 .74417 L
.32085 .74665 L
.31484 .74927 L
.30929 .75176 L
.30416 .75412 L
.29891 .7566 L
.29404 .75894 L
.28907 .76138 L
.28459 .76362 L
s
0 0 1 r
.46887 .71429 m
.45783 .71121 L
.44597 .70845 L
.43504 .70639 L
.42473 .70487 L
.41908 .70421 L
.41401 .70373 L
.40881 .70333 L
.40395 .70306 L
.4015 .70296 L
.39891 .70287 L
.39672 .70282 L
.39547 .7028 L
.39432 .70278 L
.39368 .70278 L
.39309 .70278 L
.39275 .70277 L
.39245 .70277 L
.39228 .70277 L
.39209 .70277 L
.39192 .70277 L
.39176 .70277 L
.39147 .70277 L
.3912 .70277 L
.3909 .70277 L
.39059 .70277 L
.39025 .70278 L
.38994 .70278 L
.38935 .70278 L
.38823 .7028 L
.3872 .70281 L
.38487 .70286 L
.38258 .70293 L
.38044 .70302 L
.37562 .70327 L
.37098 .7036 L
.3668 .70397 L
.35809 .70496 L
.35002 .70614 L
.34176 .70761 L
.33414 .70921 L
.32637 .71107 L
.31921 .713 L
.31261 .71496 L
.3059 .71712 L
.29972 .71927 L
.29403 .72138 L
.28824 .72365 L
.28291 .72585 L
.27749 .7282 L
Mistroke
.27251 .73045 L
.27206 .73065 L
Mfstroke
1 0 0 r
.46887 .71429 m
.45885 .7081 L
.44782 .70198 L
.4374 .69683 L
.42735 .69243 L
.41667 .68834 L
.40644 .68497 L
.39566 .68199 L
.3854 .6797 L
.3757 .678 L
.37085 .67732 L
.36557 .67672 L
.36062 .67627 L
.35605 .67597 L
.35357 .67585 L
.35124 .67576 L
.35023 .67573 L
.34916 .6757 L
.34854 .67569 L
.34799 .67568 L
.34743 .67567 L
.3469 .67567 L
.34636 .67566 L
.34608 .67566 L
.34577 .67566 L
.34562 .67566 L
.34545 .67566 L
.34515 .67566 L
.34486 .67566 L
.34458 .67566 L
.34433 .67566 L
.34409 .67566 L
.34383 .67566 L
.34355 .67566 L
.34298 .67567 L
.34246 .67567 L
.34136 .67569 L
.34015 .67571 L
.3389 .67574 L
.33773 .67578 L
.33537 .67588 L
.33317 .67599 L
.32909 .67627 L
.32477 .67665 L
.32086 .67708 L
.31275 .67822 L
.30526 .67957 L
.29761 .68126 L
.29058 .68308 L
.28346 .68521 L
Mistroke
.27693 .6874 L
.27095 .68961 L
.26491 .69205 L
.25939 .69447 L
.25904 .69462 L
Mfstroke
0 0 1 r
.46887 .71429 m
.46057 .70536 L
.45113 .69611 L
.44194 .68793 L
.43281 .68055 L
.42281 .67326 L
.41296 .66681 L
.40228 .66061 L
.39182 .6553 L
.38166 .65081 L
.37078 .64673 L
.36029 .64347 L
.35025 .64097 L
.3447 .63985 L
.33965 .63898 L
.33441 .63824 L
.32959 .6377 L
.32473 .6373 L
.32218 .63714 L
.32077 .63708 L
.31948 .63702 L
.31825 .63698 L
.3169 .63695 L
.3162 .63693 L
.31555 .63692 L
.31486 .63691 L
.31448 .63691 L
.31431 .63691 L
.31413 .63691 L
.31382 .63691 L
.31365 .63691 L
.31349 .6369 L
.3132 .6369 L
.3129 .63691 L
.31274 .63691 L
.31256 .63691 L
.31237 .63691 L
.3122 .63691 L
.31189 .63691 L
.31156 .63691 L
.31091 .63692 L
.3103 .63693 L
.30916 .63696 L
.30802 .63699 L
.30679 .63703 L
.3043 .63715 L
.30201 .63729 L
.29989 .63745 L
.29512 .63791 L
.29085 .63844 L
Mistroke
.28195 .63994 L
.27376 .64178 L
.26546 .64412 L
.2579 .64669 L
.25032 .64969 L
.24356 .65276 L
Mfstroke
1 0 0 r
.46887 .71429 m
.46288 .70319 L
.45579 .69129 L
.4486 .68036 L
.44118 .67011 L
.43275 .65955 L
.42412 .64977 L
.4144 .63985 L
.4045 .63082 L
.39452 .62269 L
.38343 .6147 L
.37232 .60771 L
.36129 .60171 L
.34923 .59616 L
.33737 .59168 L
.32456 .5879 L
.31812 .58641 L
.31213 .58526 L
.30634 .58438 L
.30018 .58368 L
.29697 .58341 L
.29529 .5833 L
.29352 .5832 L
.29196 .58313 L
.29114 .5831 L
.29026 .58307 L
.28945 .58305 L
.28872 .58304 L
.28836 .58303 L
.28798 .58303 L
.28764 .58302 L
.28728 .58302 L
.2869 .58302 L
.28656 .58301 L
.28619 .58301 L
.28579 .58301 L
.28544 .58302 L
.28506 .58302 L
.28471 .58302 L
.28439 .58302 L
.2836 .58304 L
.28276 .58305 L
.28122 .5831 L
.2796 .58316 L
.27789 .58324 L
.27485 .58345 L
.27202 .5837 L
.269 .58402 L
.26361 .58477 L
.2575 .58588 L
Mistroke
.25182 .58717 L
.24139 .59022 L
.23093 .59424 L
.22181 .59861 L
Mfstroke
0 0 1 r
.46887 .71429 m
.46565 .70175 L
.46156 .68793 L
.45712 .67485 L
.45229 .6622 L
.44648 .64868 L
.44022 .63567 L
.43278 .62189 L
.42483 .60873 L
.41639 .59622 L
.40654 .58317 L
.39615 .57094 L
.3853 .5596 L
.3728 .54808 L
.35981 .53767 L
.34498 .52749 L
.3297 .51874 L
.31411 .51147 L
.30506 .50798 L
.29664 .5052 L
.28757 .5027 L
.27906 .50082 L
.27018 .49932 L
.26546 .49872 L
.26284 .49845 L
.26044 .49823 L
.2583 .49807 L
.25597 .49793 L
.25469 .49786 L
.2535 .49781 L
.25229 .49777 L
.25115 .49774 L
.25019 .49772 L
.24964 .49771 L
.24915 .49771 L
.24863 .4977 L
.24806 .4977 L
.24747 .4977 L
.24693 .4977 L
.24634 .4977 L
.24579 .49771 L
.24529 .49771 L
.24475 .49772 L
.24354 .49774 L
.24242 .49778 L
.24019 .49786 L
.23779 .49799 L
.23346 .49832 L
.22831 .49888 L
.22361 .49955 L
Mistroke
.21458 .50126 L
.20485 .50379 L
.19577 .50684 L
.18634 .51077 L
.18599 .51093 L
Mfstroke
1 0 0 r
.46887 .71429 m
.46887 .71389 L
.46887 .71353 L
.46887 .71312 L
.46887 .71273 L
.46887 .71203 L
.46886 .71128 L
.46886 .71044 L
.46885 .70955 L
.46883 .70796 L
.4688 .7063 L
.46878 .70474 L
.46869 .70118 L
.46858 .69751 L
.46845 .69413 L
.46806 .68642 L
.46761 .67961 L
.467 .67207 L
.4654 .6569 L
.46332 .64183 L
.46047 .62532 L
.45703 .6089 L
.453 .59263 L
.44786 .57482 L
.44199 .55715 L
.43539 .53971 L
.4272 .52065 L
.41807 .50185 L
.40684 .48142 L
.39434 .46134 L
.38056 .44174 L
.36373 .42067 L
.34513 .40034 L
.32469 .38093 L
.29977 .3607 L
.27223 .34205 L
.23847 .32371 L
.21966 .31541 L
.20085 .30839 L
.16025 .29724 L
s
0 0 1 r
.46887 .71429 m
.47178 .70154 L
.47479 .68699 L
.47744 .67266 L
.4798 .65823 L
.4821 .64211 L
.48407 .6258 L
.48587 .60755 L
.48729 .58898 L
.48782 .58014 L
.48831 .57013 L
.4887 .55999 L
.48887 .55432 L
.48899 .54892 L
.48905 .54625 L
.48909 .54332 L
.48913 .54072 L
.48916 .53793 L
.48917 .53649 L
.48918 .53514 L
.48919 .53382 L
.4892 .5326 L
.4892 .53143 L
.4892 .53084 L
.4892 .53019 L
.4892 .52954 L
.4892 .52884 L
.4892 .52818 L
.4892 .52758 L
.4892 .52691 L
.4892 .52628 L
.4892 .52559 L
.4892 .52484 L
.48919 .52332 L
.48918 .52192 L
.48916 .51934 L
.48914 .5166 L
.48905 .51077 L
.48892 .50428 L
.48876 .49804 L
.48857 .49227 L
.48804 .479 L
.4874 .46644 L
.48652 .45235 L
.4842 .42307 L
.48114 .39271 L
.47733 .36124 L
.47225 .32491 L
.46623 .28677 L
.45849 .24222 L
Mistroke
.44962 .1947 L
.43971 .14389 L
.42766 .08322 L
.41537 .02036 L
Mfstroke
1 0 0 r
.46887 .71429 m
.47469 .70283 L
.48119 .68969 L
.48746 .67667 L
.49367 .6635 L
.50047 .64871 L
.50724 .63367 L
.51471 .61676 L
.5222 .59949 L
.52973 .58189 L
.53813 .56202 L
.54667 .54168 L
.55535 .52092 L
.56521 .49739 L
.57538 .47327 L
.58709 .4459 L
.59938 .41773 L
.61233 .38886 L
.62756 .35608 L
.64388 .32244 L
.66335 .28437 L
.68458 .24536 L
.70768 .2057 L
.73562 .16132 L
.76464 .11894 L
s
0 0 1 r
.46887 .71429 m
.47718 .70496 L
.48668 .69432 L
.49606 .68387 L
.50554 .67337 L
.51616 .66172 L
.52697 .65 L
.53914 .63702 L
.5516 .62397 L
.56434 .61093 L
.57878 .59652 L
.59364 .58214 L
.60889 .56786 L
.62628 .55221 L
.64422 .53675 L
.66472 .51996 L
.68596 .50352 L
.70788 .48756 L
.73293 .47055 L
.75882 .45428 L
.78835 .43729 L
.81884 .42144 L
.85013 .40686 L
.88554 .39234 L
.91984 .38019 L
s
1 0 0 r
.46887 .71429 m
.47908 .70776 L
.49079 .7005 L
.50238 .69356 L
.5141 .6868 L
.52725 .67953 L
.54058 .67251 L
.55554 .66505 L
.57074 .65793 L
.58615 .65118 L
.60342 .64419 L
.62092 .63769 L
.6386 .63174 L
.65836 .62581 L
.67829 .62057 L
.70048 .61562 L
.72282 .61155 L
.7452 .60838 L
.75707 .60707 L
.76996 .60592 L
.77637 .60546 L
.78337 .60504 L
.78948 .60475 L
.79274 .60461 L
.79624 .60449 L
.79972 .60439 L
.8029 .60432 L
.80444 .60429 L
.80612 .60427 L
.80769 .60425 L
.80917 .60423 L
.81082 .60422 L
.8117 .60421 L
.81215 .60421 L
.81265 .60421 L
.81314 .60421 L
.81359 .60421 L
.81407 .60421 L
.81458 .60421 L
.81506 .60421 L
.81551 .60421 L
.81636 .60421 L
.81717 .60422 L
.81803 .60422 L
.81957 .60423 L
.82123 .60425 L
.82306 .60427 L
.82653 .60434 L
.82984 .60442 L
.83607 .60462 L
Mistroke
.84283 .60491 L
.85025 .60532 L
.86381 .60632 L
.87843 .60774 L
.90795 .61174 L
.93144 .61598 L
Mfstroke
0 0 1 r
.46887 .71429 m
.48022 .71102 L
.49316 .70767 L
.50586 .70476 L
.51858 .70222 L
.53267 .69985 L
.54679 .69794 L
.55419 .69712 L
.56237 .69636 L
.56972 .69581 L
.57395 .69555 L
.57795 .69534 L
.58208 .69517 L
.58589 .69504 L
.58785 .69498 L
.59 .69494 L
.59228 .6949 L
.59341 .69488 L
.59445 .69487 L
.5955 .69486 L
.59604 .69486 L
.59664 .69485 L
.59716 .69485 L
.59764 .69485 L
.59815 .69485 L
.59844 .69485 L
.59871 .69485 L
.5992 .69485 L
.59966 .69485 L
.60016 .69485 L
.6007 .69485 L
.6016 .69486 L
.60259 .69487 L
.60373 .69488 L
.60477 .69489 L
.60712 .69493 L
.60921 .69497 L
.61141 .69503 L
.61547 .69517 L
.61983 .69536 L
.62778 .69581 L
.63714 .69653 L
.6461 .69741 L
.6635 .69964 L
.68243 .70285 L
.701 .70681 L
.71915 .71145 L
.73872 .71734 L
.75776 .72395 L
.77815 .73203 L
Mistroke
.79787 .74084 L
.81686 .75029 L
.83702 .7614 L
.85634 .77311 L
.87443 .78508 L
Mfstroke
1 0 0 r
.46887 .71429 m
.46922 .71429 L
.46954 .71429 L
.46991 .71429 L
.47026 .71429 L
.47088 .71429 L
.47155 .7143 L
.4723 .7143 L
.47309 .71431 L
.47451 .71433 L
.47599 .71436 L
.47737 .71439 L
.48054 .71449 L
.48381 .71462 L
.48681 .71476 L
.49366 .7152 L
.49969 .7157 L
.50637 .71638 L
.5197 .71813 L
.53283 .72038 L
.54706 .72341 L
.56102 .72698 L
.57463 .73105 L
.58928 .73609 L
.60351 .74165 L
.61727 .74766 L
.63196 .7548 L
.6461 .76238 L
.66108 .77123 L
.67542 .78051 L
.6891 .79013 L
.70347 .8011 L
.7171 .81237 L
.72998 .82384 L
.74342 .83672 L
.75604 .84974 L
.76911 .86423 L
.78131 .8788 L
.79239 .89296 L
s
0 g
gsave
.05455 .96939 -70.4063 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.5 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.375 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
68.688 11.563 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
64.750 17.375 moveto
(\\200\\200\\200\\200) show
73.250 17.375 moveto
(\\200) show
73.688 17.375 moveto
(\\200) show
67.375 23.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
77.813 17.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05455 .45918 -72.4063 -14.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.5 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.375 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.063 11.563 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 11.563 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
64.750 17.375 moveto
(\\200\\200\\200\\200) show
73.250 17.375 moveto
(\\200\\200) show
77.688 17.375 moveto
(\\200) show
69.375 23.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
81.813 17.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05455 .20408 -72.4063 -14.2188 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.375 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.063 11.563 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 11.563 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
64.750 17.375 moveto
(\\200\\200\\200\\200) show
73.250 17.375 moveto
(\\200\\200) show
77.688 17.375 moveto
(\\200) show
69.375 23.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
81.813 17.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{287.875, 287.875},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004O00017b000`400?l00000o`00003o6@3oool0
0`000000oooo0?ooo`3o0?ooo`@0oooo000I0?ooo`030000003oool0oooo0?l0oooo103oool001T0
oooo00<000000?ooo`3oool0o`3oool40?ooo`006@3oool00`000000oooo0?ooo`1K0?oooad0003o
R`3oool001T0oooo00<000000?ooo`3oool0EP3oool50000oad0oooo1@000?n60?ooo`006@3oool0
0`000000oooo0?ooo`1A0?ooo`D0003o9`3oool50000oh40oooo000I0?ooo`030000003oool0oooo
04h0oooo0`000?l30?ooo`030000o`3oool0oooo02/0oooo10000?mm0?ooo`006@3oool00`000000
oooo0?ooo`1<0?ooo`80003o1P3oool00`000?l0oooo0?ooo`0_0?ooo`<0003oNP3oool001T0oooo
00<000000?ooo`3oool0BP3oool20000o`T0oooo00<0003o0?ooo`3oool0<@3oool20000ogP0oooo
000I0?ooo`030000003oool0oooo04P0oooo0P000?l;0?ooo`030000o`3oool0oooo03<0oooo0P00
0?mf0?ooo`006@3oool00`000000oooo0?ooo`150?ooo`<0003o3@3oool00`000?l0oooo0?ooo`0e
0?ooo`<0003oL`3oool001T0oooo00<000000?ooo`3oool0@`3oool20000oa00oooo00<0003o0?oo
o`3oool0>03oool20000og40oooo000I0?ooo`030000003oool0oooo0440oooo0P000?lB0?ooo`03
0000o`3oool0oooo03X0oooo0P000?m_0?ooo`006@3oool00`000000oooo0?ooo`0o0?ooo`80003o
503oool00`000?l0oooo0?ooo`0l0?ooo`80003oK@3oool001T0oooo00<000000?ooo`3oool0?@3o
ool20000oaL0oooo00<0003o0?ooo`3oool0?@3oool20000of/0oooo000I0?ooo`030000003oool0
oooo03`0oooo00<0003o0?ooo`3oool05`3oool00`000?l0oooo0?ooo`0o0?ooo`80003oJ@3oool0
01T0oooo00<000000?ooo`3oool0>P3oool20000oaX0oooo00<0003o0?ooo`3oool0@@3oool20000
ofL0oooo000I0?ooo`030000003oool0oooo03T0oooo00<0003o0?ooo`3oool06P3oool00`000?l0
oooo0?ooo`130?ooo`80003oI@3oool001T0oooo00<000000?ooo`3oool0=`3oool20000oad0oooo
00<0003o0?ooo`3oool0A@3oool20000of<0oooo000I0?ooo`030000003oool0oooo03H0oooo00<0
003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`170?ooo`80003oH@3oool001T0oooo00<00000
0?ooo`3oool0=03oool20000ob40oooo00<0003o0?ooo`3oool0B03oool00`000?l0oooo0?ooo`1N
0?ooo`006@3oool00`000000oooo0?ooo`0c0?ooo`030000o`3oool0oooo0240oooo00<0003o0?oo
o`3oool0B@3oool20000oeh0oooo000I0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3o
ool08P3oool00`000?l0oooo0?ooo`1;0?ooo`80003oG03oool001T0oooo00<000000?ooo`3oool0
<@3oool00`000?l0oooo0?ooo`0S0?ooo`030000o`3oool0oooo04d0oooo00<0003o0?ooo`3oool0
F@3oool001T0oooo00<000000?ooo`3oool0;`3oool20000obH0oooo00<0003o0?ooo`3oool0CP3o
ool20000oeT0oooo000I0?ooo`030000003oool0oooo02h0oooo00<0003o0?ooo`3oool09`3oool0
0`000?l0oooo0?ooo`1?0?ooo`030000o`3oool0oooo05H0oooo000I0?ooo`030000003oool0oooo
02d0oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`1@0?ooo`030000o`3oool0oooo
05D0oooo000I0?ooo`030000003oool0oooo02`0oooo00<0003o0?ooo`3oool0:@3oool00`000?l0
oooo0?ooo`1A0?ooo`030000o`3oool0oooo05@0oooo000I0?ooo`030000003oool0oooo02/0oooo
00<0003o0?ooo`3oool0:P3oool00`000?l0oooo0?ooo`1B0?ooo`030000o`3oool0oooo05<0oooo
000I0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0:`3oool00`000?l0oooo0?oo
o`1C0?ooo`80003oD`3oool001T0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0/
0?ooo`030000o`3oool0oooo00`0oooo3P3o000k0?ooo`030000o`3oool0oooo0500oooo000I0?oo
o`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0;P3oool00`000?l0oooo0?ooo`030?oo
o`P0o`003P3oool80?l003@0oooo00<0o`000?ooo`3oool0C`3oool001T0oooo00<000000?ooo`3o
ool0:03oool00`000?l0oooo0?ooo`0^0?ooo`030000o`3o0000o`0000<0o`007P3oool40?l002l0
oooo00<0o`000?ooo`000?l0D03oool001T0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo
0?ooo`0^0?ooo`030?l000000?l0oooo02H0oooo0P3o000]0?ooo`040?l0003oool0oooo0000odl0
oooo000I0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0:`3oool40?l000030?oo
o`000?l0oooo02P0oooo103o000X0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
C03oool001T0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`0X0?ooo`@0o`001@3o
ool00`000?l0oooo0?ooo`0[0?ooo`@0o`00903oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo04/0oooo000I0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool09`3oool2
0?l000X0oooo00<0003o0?ooo`3oool0;P3oool30?l00200oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`1:0?ooo`006@3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo
02H0oooo0P3o000<0?ooo`030000o`3oool0oooo0340oooo0P3o000M0?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool0B@3oool001T0oooo00<000000?ooo`3oool08P3oool00`000?l0
oooo0?ooo`0U0?ooo`80o`003P3oool00`000?l0oooo0?ooo`0c0?ooo`80o`006`3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo04P0oooo000I0?ooo`030000003oool0oooo0240oooo
00<0003o0?ooo`3oool0903oool20?l00100oooo00<0003o0?ooo`3oool0=@3oool20?l001P0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`170?ooo`006@3oool00`000000oooo0?oo
o`0Q0?ooo`030000o`3oool0oooo02<0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0g0?ooo`80o`005P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo04H0oooo000I
0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool08P3oool20?l001@0oooo00<0003o
0?ooo`3oool0>03oool20?l001<0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`16
0?ooo`006@3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0240oooo0P3o000F0?oo
o`030000o`3oool0oooo03X0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo04D0oooo000I0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3o
ool08@3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo03/0oooo0P3o000?0?ooo`03
0?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0A03oool001T0oooo00<000000?ooo`3oool0
7@3oool00`000?l0oooo0?ooo`0P0?ooo`80o`006@3oool00`000?l0oooo0?ooo`0m0?ooo`80o`00
303oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04<0oooo000I0?ooo`030000003o
ool0oooo01d0oooo00<0003o0?ooo`3oool07P3oool20?l001/0oooo00<0003o0?ooo`3oool0?`3o
ool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0@P3o
ool000l0oooo0`0000070?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool07P3oool0
0`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo03l0oooo0P3o00080?ooo`030?l0003oool0
oooo01@0oooo00<0003o0?ooo`3oool0@@3oool00100oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool07@3oool00`00
0?l0oooo0?ooo`110?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool05P3oool00`00
0?l0oooo0?ooo`100?ooo`003@3oool5000000L0oooo00<000000?ooo`3oool06P3oool00`000?l0
oooo0?ooo`0N0?ooo`030?l0003oool0oooo01h0oooo00<0003o0?ooo`3oool0@P3oool20?l000@0
oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0o0?ooo`003@3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo01X0oooo00<0003o0?ooo`3oool07@3oool00`3o0000
oooo0?ooo`0O0?ooo`030000o`3oool0oooo04@0oooo0P3o00000`3oool0o`000?ooo`0J0?ooo`03
0000o`3oool0oooo03h0oooo000>0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0
6@3oool00`000?l0oooo0?ooo`0L0?ooo`80o`008`3oool00`000?l0oooo0?ooo`150?ooo`030?l0
003oool0oooo01/0oooo00<0003o0?ooo`3oool0?@3oool000l0oooo0P0000080?ooo`030000003o
ool0oooo01T0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3o
ool0oooo04D0oooo0P3o000L0?ooo`030000o`3oool0oooo03d0oooo000I0?ooo`030000003oool0
oooo01P0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0
oooo04@0oooo00@0o`000?ooo`3oool0o`00703oool00`000?l0oooo0?ooo`0l0?ooo`00203oool<
000000030?ooo`00000000000080oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`0J
0?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0303oool60000oc40oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo03/0oooo000I0?oo
o`<000005`3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo02H0oooo00<0003o0?oo
o`3oool00`3oool90000o`H0oooo1`000?lZ0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool06@3oool00`000?l0oooo0?ooo`0k0?ooo`006@3oool00`000000oooo0?ooo`0G0?ooo`03
0000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool09`3oool00`000?l0oooo0000o`030000oaH0
oooo20000?lQ0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool06@3oool00`000?l0
oooo0?ooo`0j0?ooo`006@3oool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01T0oooo
00<0o`000?ooo`3oool09P3oool40000ob80oooo10000?lL0?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0i0?ooo`006@3oool00`000000oooo0?oo
o`0F0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool08`3oool40000o`<0oooo00<0
003o0?ooo`3oool0903oool20000oaX0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?oo
o`0H0?ooo`030000o`3oool0oooo03T0oooo000A0?ooo`D000000`3oool00`000000oooo0?ooo`0F
0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool08@3oool20000o`L0oooo00<0003o
0?ooo`3oool09P3oool30000oaH0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo03P0oooo000:0?ooo`@00000103oool00`000000oooo000000040?oo
o`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0P0?oo
o`80003o2@3oool00`000?l0oooo0?ooo`0Y0?ooo`80003o503oool00`3o0000oooo0?ooo`0;0?oo
o`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0=`3oool00180oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3o
ool07`3oool20000o`/0oooo00<0003o0?ooo`3oool0:`3oool20000oa40oooo00<0o`000?ooo`3o
ool03@3oool20?l001T0oooo00<0003o0?ooo`3oool0=P3oool00180oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool0
7P3oool20000o`d0oooo00<0003o0?ooo`3oool0;@3oool20000o`h0oooo00<0o`000?ooo`3oool0
403oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo03H0oooo000A0?ooo`@00000103o
ool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool07@3o
ool20000oa00oooo00<0003o0?ooo`3oool0;P3oool20000o``0oooo00<0o`000?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo03D0oooo000I0?ooo`030000003oool0
oooo01@0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0K0?ooo`80003o4P3oool0
0`000?l0oooo0?ooo`0`0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool04`3oool0
0`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo03@0oooo000C0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo
01X0oooo0P000?lD0?ooo`030000o`3oool0oooo0340oooo0P000?l80?ooo`030?l0003oool0oooo
01@0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0d0?ooo`006@3oool00`000000
oooo0?ooo`0D0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool06P3oool00`000?l0
oooo0?ooo`0D0?ooo`030000o`3oool0oooo03<0oooo0P000?l50?ooo`030?l0003oool0oooo01H0
oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0c0?ooo`006@3oool00`000000oooo
0?ooo`0C0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool06@3oool20000oaL0oooo
00<0003o0?ooo`3oool0=@3oool20000o`80oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo
0?ooo`0E0?ooo`030000o`3oool0oooo03<0oooo000I0?ooo`030000003oool0oooo01<0oooo00<0
003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo01P0oooo00<0
003o0?ooo`3oool0=P3oool00`000?l0oooo0?l0000J0?ooo`030?l0003oool0oooo01D0oooo00<0
003o0?ooo`3oool0<P3oool001T0oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0D
0?ooo`030?l0003oool0oooo01L0oooo0P000?lK0?ooo`030000o`3oool0oooo03L0oooo00<0o`00
0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0380oooo000I0?oo
o`030000003oool0oooo0180oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0G0?oo
o`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool0=`3oool00`3o0000003o0000o`0K0?oo
o`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0<@3oool001T0oooo00<000000?ooo`3o
ool04P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3o
ool0703oool00`000?l0oooo0?ooo`0f0?ooo`050?l0003oool0oooo0?ooo`000?l06P3oool00`3o
0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0340oooo000I0?ooo`030000003oool0oooo0180
oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01h0
oooo00<0003o0?ooo`3oool0=@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo01P0
oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0`0?ooo`006@3oool00`000000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0503oool20000ob40oooo
00<0003o0?ooo`3oool0=03oool00`3o0000oooo0?ooo`040?ooo`80003o6@3oool00`3o0000oooo
0?ooo`0C0?ooo`030000o`3oool0oooo0300oooo000I0?ooo`030000003oool0oooo0140oooo00<0
003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0240oooo00<0
003o0?ooo`3oool0103oool=0?l002<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0G0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0<03oool001T0oooo00<00000
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo01<0oooo00<0003o
0?ooo`3oool08P3oool00`000?l0oooo0?l000040?l000d0oooo1P3o000L0?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0
oooo02l0oooo000I0?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0240oooo0`3o00000`000?l0oooo0?ooo`0F0?oo
o`<0o`006@3oool00`3o0000oooo0?ooo`090?ooo`80003o5`3oool00`3o0000oooo0?ooo`0B0?oo
o`030000o`3oool0oooo02l0oooo000I0?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo01d0oooo1@3o00030?ooo`03
0000o`3oool0oooo01T0oooo103o000D0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool05@3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo02h0oooo000I0?ooo`030000
003oool0oooo0100oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo01`0oooo0P3o00080?ooo`030000o`3oool0oooo01d0oooo0`3o000@0?ooo`030?l0
003oool0oooo00h0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo02h0oooo000I0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo01X0oooo0P3o000:0?ooo`030000o`3o
ool0oooo0200oooo0P3o000>0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0503o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo02h0oooo000I0?ooo`030000003oool0
oooo0100oooo0P3o000B0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool06@3oool2
0?l000`0oooo00<0003o0?ooo`3oool08P3oool20?l000/0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0;@3oool0
01T0oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?l000030?l000d0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0H0?ooo`80o`003P3oool00`000?l0oooo0?ooo`0T0?oo
o`80o`002@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0]0?ooo`006@3oool00`000000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo00@0oooo103o00090?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool05`3oool20?l00100oooo00<0003o0?ooo`3oool09P3oool20?l000H0oooo00<0o`000?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool0;03oool001T0oooo00<000000?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`<0o`00
1@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0W0?ooo`80o`00103oool00`3o0000oooo0?ooo`0D0?ooo`030000
o`3oool0oooo01<0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0/0?ooo`006@3o
ool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00/0oooo0P3o00030?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool05@3oool20?l001@0oooo00<0003o0?ooo`3oool0:@3o
ool20?l000030?ooo`3o0000oooo01L0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo02/0oooo000I0?ooo`030000003oool0oooo00l0oooo00<0003o
0?ooo`3oool03@3oool30?l001<0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0D
0?ooo`030000o`3oool0oooo02/0oooo0P3o000I0?ooo`030000o`3oool0oooo0180oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0[0?ooo`006@3oool00`000000oooo0?ooo`0?0?oo
o`030000o`3oool0oooo00l0oooo0`3o000@0?ooo`030000o`3oool0oooo01<0oooo0P3o000G0?oo
o`030000o`3oool0oooo02/0oooo00<0o`000?ooo`3o0000603oool00`000?l0oooo0?ooo`0C0?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0:`3oool001T0oooo00<000000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0080o`003@3oool00`000?l0
oooo0?ooo`0C0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool0:`3oool00`3o0000
oooo0?ooo`020?l001L0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo02X0oooo000I0?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`030?ooo`80o`002`3oool00`000?l0oooo0?ooo`0A0?ooo`80o`00
6P3oool00`000?l0oooo0?ooo`0[0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
5@3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
:P3oool001T0oooo00<000000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00D0oooo0P3o00080?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool06P3o
ool00`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool05@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0:@3o
ool001T0oooo00<000000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00L0oooo0P3o00060?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool06`3oool0
0`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool05@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0:@3oool0
01T0oooo00<000000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00T0oooo0P3o00030?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool07@3oool01000
0?l0oooo0?ooo`3oool<0000oa/0oooo00<0o`000?ooo`3oool01`3oool20?l001D0oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo02P0oooo000I0?oo
o`030000003oool0oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0<0?oo
o`040?l0003oool0oooo0000oa40oooo00<0o`000?ooo`3oool07@3oool50000o``0oooo1P000?lE
0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0:03oool001T0oooo00<000000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo0P3o000A0?oo
o`030?l0003oool0oooo01T0oooo1@000?l00`3oool0003o0?ooo`0D0?ooo`D0003o3`3oool00`3o
0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0403oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo02L0oooo000I0?ooo`030000003oool0oooo00h0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0o`0000l0
oooo00<0o`000?ooo`3oool0603oool20000o`H0oooo00<0003o0?ooo`3oool0603oool20000o`d0
oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0W0?ooo`006@3oool00`000000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool010000?l0oooo
0?ooo`3o000=0?ooo`030?l0003oool0oooo01H0oooo0`000?l90?ooo`030000o`3oool0oooo01T0
oooo0`000?l90?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0@0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool09`3oool001T0oooo
00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool00P3oool20?l000X0oooo00<0o`000?ooo`3oool05@3oool20000o``0oooo
00<0003o0?ooo`3oool0703oool20000o`L0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo
0?ooo`0B0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`0W0?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool0503oool20000o`h0oooo00<0003o0?ooo`3oool07P3oool20000o`D0oooo00<0
o`000?ooo`3oool0403oool20?l001<0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo02H0oooo000I0?ooo`030000003oool0oooo00h0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0B0?ooo`80003o403oool00`000?l0oooo0?ooo`0P
0?ooo`80003o0P3oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo02H0oooo000I0?oo
o`030000003oool0oooo00h0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0B0?oo
o`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool08P3oool20000o`030?l0003oool0oooo
01@0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
00l0oooo00<0003o0?ooo`3oool09P3oool001T0oooo00<000000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool20?l00080
oooo00<0o`000?ooo`3oool04@3oool20000oa<0oooo00<0003o0?ooo`3oool08`3oool00`3o0000
003o0?ooo`0F0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0>0?ooo`030000o`3oool0oooo02H0oooo000I0?ooo`030000003oool0oooo00l0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo
0P3o000B0?ooo`80003o5@3oool00`000?l0oooo0?ooo`0S0?ooo`040?l0003oool0003o0000oaH0
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool09P3oool001T0oooo00<000000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0303oool20?l00140oooo
00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0080oooo
0P000?lE0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0>0?ooo`80003o9`3oool001T0oooo00<000000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?l0
000?0?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo00/0oooo0P000?l00`3oool0003o0?ooo`0V0?ooo`006@3oool0
0`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0<0?ooo`050?l0003oool0oooo0?ooo`3o00003@3oool00`000?l0oooo0?oo
o`0H0?ooo`030000o`3oool0oooo0200oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0B0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`090?ooo`80003o0`3oool00`000?l0oooo0?ooo`0U0?ooo`006@3oool00`000000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0203oool20000oa/0oooo00<0003o
0?ooo`3oool0803oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo0180oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00L0oooo0P000?l5
0?ooo`030000o`3oool0oooo02D0oooo000I0?ooo`030000003oool0oooo00l0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo01/0oooo00<0003o0?l0
003o00002`3o000D0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool00`3oool30000
o`L0oooo00<0003o0?ooo`3oool09@3oool001T0oooo00<000000?ooo`3oool03`3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool05`3oool50?l00003
0000o`3oool0oooo00/0oooo1@3o000?0?ooo`030?l0003oool0oooo00X0oooo0P000?lB0?ooo`03
0?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03@3oool0103o0000oooo0?ooo`3oool20000
o`/0oooo00<0003o0?ooo`3oool0903oool001T0oooo00<000000?ooo`3oool03`3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool05@3oool30?l000D0
oooo00<0003o0?ooo`3oool0403oool30?l000/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03P3oool30000o`d0
oooo00<0003o0?ooo`3oool0903oool001T0oooo00<000000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`090?ooo`040?l0003oool0oooo0000oaD0oooo0`3o00080?ooo`030000o`3oool0oooo01<0
oooo0P3o00090?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0?0?ooo`030000o`3oool0oooo00/0oooo0P000?l00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo02@0oooo000I0?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
2P3oool00`3o0000003o0?ooo`0B0?ooo`<0o`002`3oool00`000?l0oooo0?ooo`0E0?ooo`<0o`00
1@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`080?ooo`<0003o0P3oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo02@0oooo000I0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0o`000?ooo`0@0?ooo`80o`003P3oool00`000?l0oooo0?ooo`0H0?ooo`80o`000`3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`050?ooo`80003o1@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo02<0oooo000I0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?l0000?0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool06P3oool3
0?l001@0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo0080oooo0`000?l80?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool08`3oool0
01T0oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0;0?ooo`050000o`3oool0oooo
0?ooo`3o0000303oool20?l00140oooo00<0003o0?ooo`3oool0703oool20?l001@0oooo00<0003o
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0>0?ooo`040000o`3oool0003o0000o`/0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0S0?ooo`006@3oool00`000000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`07
0?ooo`80o`004`3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo0080o`004`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo0P000?l=0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool08`3oool000h0oooo0P0000090?ooo`030000003oool0oooo
0100oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo0P3o000E0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool00P3oool20?l0
0180oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0<0?ooo`80003o3P3oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo02<0oooo000=0?ooo`040000003oool0oooo0000
00P0oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo
01X0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00l0oooo00<0o`000?ooo`3oool02@3oool20000o`030?ooo`000?l0oooo00h0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0R0?ooo`003@3oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo0100oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?oo
o`050?l0003oool0oooo0?ooo`3o0000603oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00L0oooo0P000?l40?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0R0?ooo`003P3oool2000000T0oooo00<000000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o00006@3oool00`00
0?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool08P3oool000d0
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0F0?ooo`d0003o4@3oool00`3o
0000oooo0?ooo`090?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`030?ooo`80003o1`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool08P3oool000h0oooo0P0000090?ooo`030000003oool0oooo0140
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0o`0001<0
oooo10000?l30?ooo`030000o`3oool0oooo00L0oooo10000?l=0?ooo`030?l0003oool0oooo00X0
oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0080
003o2P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool08P3oool001T0oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00X0oooo00@0o`000?ooo`3oool0o`004@3oool20000o`L0oooo00<0003o0?ooo`3o
ool02`3oool50000o`P0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000000o`000?l0303oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool08@3oool000P0oooo300000000`3oool00000
000000020?ooo`030000003oool0oooo0180oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02`3oool30000o`T0oooo
00<0003o0?ooo`3oool0403oool20000o`D0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00/0oooo0P000?l00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0Q0?ooo`006@3o
ool00`000000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo0`000?l<0?ooo`030000o`3o
ool0oooo0180oooo0P000?l30?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`080?ooo`80003o0P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0Q0?ooo`006@3oool3
00000180oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool20000o`l0oooo00<0003o0?ooo`3oool0503oool2
0000o`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool08@3oool001T0oooo00<000000?oo
o`3oool04`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00l0oooo00<0003o0?oo
o`3oool05P3oool00`3o0000003o0?ooo`0A0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo0240oooo000I0?ooo`03
0000003oool0oooo01<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool00P000?lB0?ooo`030000o`3oool0oooo01D0
oooo00<0o`000?ooo`3oool00P000?lA0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool00P3oool20000o`L0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool08@3oool00140oooo1@0000030?ooo`030000
003oool0oooo01<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00X0oooo00<0o`000?ooo`000?l0503oool00`000?l0oooo0?ooo`0E0?ooo`030?l0
003oool0oooo0080oooo0P000?l@0?ooo`030?l0003oool0oooo00`0oooo00D0003o0?ooo`3oool0
oooo0000o`090?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo0240oooo000:0?ooo`@00000103oool00`000000oooo
000000040?ooo`030000003oool0oooo01<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo
0?ooo`0E0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0=0?ooo`<0003o2`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0Q0?ooo`004P3oool00`000000oooo0000
00040?ooo`030000003oool0oooo01@0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00X0oooo0P000?l00`3oool0o`000?ooo`0C0?ooo`030000o`3o
ool0oooo01@0oooo00<0o`000?ooo`3oool01P3oool20000o`h0oooo00<0o`000?ooo`3oool02`3o
ool20000o`d0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool08@3oool00180oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`3o0000503oool00`000?l0o`000?l0
00020?l00180oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00P0oooo0P000?l20?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool08@3o
ool00140oooo100000040?ooo`030000003oool0oooo01@0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0<0?ooo`H0o`0000@0003o0?ooo`3oool0oooo1P3o000;0?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0Q0?ooo`006@3oool0
0`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool3
0?l000H0oooo00<0003o0?ooo`3oool01`3oool30?l000P0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00@0oooo0P000?l60?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0803oool001<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool40?l0
00T0oooo00<0003o0?ooo`3oool02P3oool30?l000@0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo0200oooo000I0?ooo`030000003oool0oooo01D0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000003o0000o`0<0000o`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00d0
oooo0`3o00000`3oool0o`000?ooo`0>0?ooo`030000o`3oool0oooo00`0oooo00@0o`000?ooo`00
0?l0003o2P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo0200oooo000I0?ooo`03
0000003oool0oooo01H0oooo00<0003o0?ooo`3oool00P3oool50000o`H0oooo00<0003o0?ooo`3o
ool01@3oool50000o`<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool00P3o000>0?ooo`030000o`3oool0oooo0100
oooo0P3o000@0?ooo`030000o`3oool0oooo00/0oooo00<0o`000000o`3oool02`3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo0200oooo000I0?ooo`030000003oool0oooo01H0oooo
00<0003o0?ooo`3oool00P000?l40?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`020?ooo`80003o00<0oooo0000o`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o0000403oool00`000?l0oooo
0?ooo`0@0?ooo`040?l0003oool0o`000?l000l0oooo00<0003o0?ooo`3oool02P3oool00`000?l0
o`000?ooo`0<0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0803oool001T0oooo
00<000000?ooo`3oool05P3oool30000o`H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo0`000?l60?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool02P3oool20?l00140oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0203oool010000?l0oooo
0?ooo`3o000<0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0803oool001T0oooo
00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0003o
0`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo0P3o00000`3oool0o`00
0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool00`3oool20?l000h0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0P0?ooo`006@3oool00`000000oooo0?oo
o`0G0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool30000o`P0oooo00<0
003o0?ooo`3oool0203oool20?l000@0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo0200oooo000I0?ooo`030000003oool0oooo01L0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l000000?l0oooo00H0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0P0?ooo`006@3oool00`000000oooo0?ooo`0H0?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020000
o`@0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo
00P0oooo3P000?l90?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`020000o`P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo0200oooo000I0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3o
ool0oooo0000o`080?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool30000
o`H0oooo00<0003o0?ooo`3oool01@3oool20000o`H0oooo00<0o`000?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0;0?ooo`80003o2`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool0803oool001T0oooo00<000000?ooo`3oool0603oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0000o`080?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool010000?l90?ooo`03
0000o`3oool0oooo00L0oooo0`000?l30?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3o
ool02@3oool30000o`/0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo0200oooo000I0?ooo`030000003oool0oooo01T0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo0P000?l70?ooo`030?l0
003oool0oooo00X0oooo00<0o`000000o`3oool0303oool00`000?l0oooo0?ooo`0:0?ooo`<0003o
00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo0000o``0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo0200
oooo000I0?ooo`030000003oool0oooo01T0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`000?l01@3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3o0000oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000003o
0000o`0=0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0P0?ooo`006@3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo0?ooo`80003o
0P3oool00`3o0000oooo0?ooo`090?ooo`80003o00<0oooo0?l0003oool03@3oool00`000?l0oooo
0?ooo`0<0?ooo`040?l0003oool0oooo0000o`d0oooo00<0o`000?ooo`3oool00`3oool20000o`D0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool0803oool001T0oooo00<000000?ooo`3oool06P3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`80003o2P3oool20000o`@0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`040?l0003oool0oooo0?ooo`80003o303oool01@3o0000oooo0?ooo`3oool0003o
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool0803oool001T0oooo00<000000?ooo`3oool06P3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l000000?l0oooo00L0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0003o00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0803oool001T0oooo
00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`040?l0003oool0oooo0000o`H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`090?ooo`030?l000000?l0oooo00X0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool0803oool001T0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00@0oooo1P3o000010000?l0o`000?l0003o00090?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`000?l0o`000?ooo`0:0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo0200oooo000I0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`030?ooo`040000o`3oool0oooo0000o`X0oooo00<0o`000?ooo`3o
ool0103o00060?ooo`040000o`3oool0oooo0?ooo`<0o`001P3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o00002`3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0P0?oo
o`006@3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool01@3oool20000o`/0oooo0`3o00090?ooo`030000o`3oool0oooo00D0oooo0`3o00030?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0o`00
00X0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool0803oool001T0oooo00<000000?ooo`3oool0703oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo0P000?l:0?ooo`030?l0003oool0o`0000X0
oooo00<0003o0?ooo`3oool0203oool30?l000`0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0803oool001T0oooo
00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo
00@0003o0?ooo`3oool0003o1`3oool20?l000<0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`0:0?ooo`80o`00303oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0Q0?ooo`006@3oool00`000000oooo
0?ooo`0M0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo
0?ooo`000?l50?ooo`80o`001@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00T0
oooo00@0o`000?ooo`3oool0o`00303oool010000?l0oooo0000o`000?l80?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool08@3oool001T0oooo00<000000?ooo`3oool07P3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0o`0000L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`09
0?ooo`040?l0003oool0oooo0?ooo`80o`002`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool08@3oool001T0oooo00<000000?ooo`3oool07P3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?l0003o00003@3o0005
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3o0000o`0000T0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0000o`0:
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool08@3oool001T0oooo00<000000?oo
o`3oool07`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0o`00103oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo1P3o00000`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000003o0?ooo`090?oo
o`030?l0003oool0oooo0080oooo1@000?l:0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool01@000?l0oooo0?ooo`3oool0003o00T0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0Q0?ooo`006@3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo
0080oooo0`3o00020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo0`3o00030?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0000o`0:0?ooo`030?l000000?l0003o
00<0003o0`3oool60000o`D0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo0240oooo000I0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3o
00000P3o00040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0oooo0P3o00000`3o
ool0o`000?ooo`040?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`08
0?ooo`030000o`3o0000oooo00L0oooo00<0003o0?ooo`3oool00`3oool20000o`80oooo00<0o`00
0?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0240oooo000I0?ooo`030000003oool0
oooo0200oooo0P3o00030?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`80o`00103oool00`000?l0oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`000?l0
1P3oool20000o`030?ooo`3o0000oooo00L0oooo00<0003o0?ooo`3oool01@3oool20000o`030?l0
003oool0oooo00T0oooo00<0o`000?ooo`000?l01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool08@3oool001T0oooo00<000000?ooo`3oool08@3o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`04
0?l0003oool0o`000?l00080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`040000o`3oool0oooo0?ooo`80003o103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00L0oooo00<0o`000000o`3oool02P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01@3oool>0?l000030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0Q0?ooo`006@3oool00`000000oooo0?ooo`0Q0?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool20?l000D0oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0000
o`000?l60?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`020000o`P0oooo00<0003o0?l0003oool02@3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool0103o0000oooo0?ooo`3oool>0?l000<0
oooo00<0o`000?ooo`3oool0203oool>0?l000/0oooo00<0003o0?ooo`3oool08@3oool001T0oooo
00<000000?ooo`3oool08P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3o
ool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`05
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0003o00000`3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool010000?l0oooo0?ooo`3o
00090?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`H0o`001P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?l000060?l000<0oooo00<0003o0?ooo`3oool08P3o
ool001T0oooo00<000000?ooo`3oool08P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0
003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`050?ooo`030?l0003oool0oooo0080oooo00L0003o0?ooo`3oool0oooo0?l0003oool0
o`0000L0oooo00<0003o0?ooo`000?l01`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3o0000103o00020?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool01P3oool40?l002@0oooo000I0?ooo`030000003oool0oooo0280oooo00D0003o0?oo
o`3oool0oooo0?l000030?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo0P3o00060?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool00`3o0000
oooo0?l000040?l000030000o`3o0000o`0000H0oooo00<0o`000?ooo`3oool01@3oool010000?l0
oooo0?ooo`000?l50?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`060?ooo`<0o`001`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool08P3oool001T0oooo00<000000?ooo`3oool08`3oool010000?l0
oooo0?ooo`3o00040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3o0000103oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo0`3o00050?ooo`030000o`3oool0oooo0080o`000`3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0003o00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo0080oooo103o00000`3oool0003o0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0R0?ooo`006@3oool0
0`000000oooo0?ooo`0S0?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?oo
o`3oool0o`0000<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080
o`000P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0o`000080o`000P3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo103o00090?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`@0o`001@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`0R0?ooo`006@3oool00`000000oooo0?ooo`0T0?ooo`040000o`3oool0oooo0?l000<0
oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l40?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000003o0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`80o`00203oool00`000?l0oooo0000o`08
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool30?l000P0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool08P3oool001T0oooo00<000000?ooo`3oool05`3oool5000000040?ooo`0000000000
000000@0oooo00@0003o0?ooo`3oool0o`000`3oool00`000?l0oooo0?ooo`020?ooo`040?l0003o
ool0oooo0000o`@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?oo
o`000?l01@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o0000oooo00D0oooo00<0o`000000
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00@0o`000?oo
o`3o0000o`001@3oool010000?l0oooo0?ooo`000?l90?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103o00020?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool03P3o
ool400000140oooo000I0?ooo`030000003oool0oooo01T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0003o00<0
oooo00<0o`000?ooo`000?l030000?l00`3oool0o`000?ooo`030?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?l000040?ooo`040?l0003oool0oooo0000
o`D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool0103oool40?l000L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>
0?ooo`030000003oool0oooo0180oooo000I0?ooo`030000003oool0oooo01T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@0003o0?ooo`3oool0o`000`3o
ool00`000?l0oooo0000o`030000o`030?ooo`000?l0oooo00<0oooo00D0o`000?ooo`3oool0oooo
0000o`020?ooo`D0003o00<0oooo0000o`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`060000
o`3oool0oooo0?ooo`3o0000oooo0P3o00030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`000?l01P3oool00`000?l0oooo0?ooo`060?ooo`040?l0003oool0oooo0?ooo`80o`000P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool03`3oool0
0`000000oooo0?ooo`0A0?ooo`006@3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo
0?ooo`<000001@3oool010000?l0oooo0?ooo`3o00030?ooo`80003o0P3oool01@3o0000oooo0?oo
o`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`040?l0003oool0oooo0?oo
o`<0003o0`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030?l000000?l0003o00<0003o103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0103o
0000oooo0?l0003o00040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo000I0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0003o
00@0003o0`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000
o`030?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool30000o`D0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0003o0080003o00<0o`000?ooo`3oool0
0P3oool30000o`80oooo00<0o`000?ooo`3oool01@3oool00`000?l0o`000?ooo`060?ooo`030000
o`3oool0oooo00D0oooo0P3o00060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`0?0?ooo`040000003oool0oooo00000140oooo000I0?ooo`030000
003oool0oooo01P0oooo0P0000040?ooo`<000001@3oool20000o`030?ooo`3o0000oooo0080oooo
00@0003o0?ooo`3oool0o`000`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?oo
o`3oool0oooo0?l000030?ooo`030000o`3oool0oooo0080oooo00H0o`000000o`000?l0003o0?oo
o`000?l50?ooo`030?l0003oool0o`0000D0oooo0P000?l30?ooo`050?l0003oool0oooo0?ooo`00
0?l00`3oool00`000?l0o`000000o`060?ooo`030000o`3oool0o`0000P0oooo00<0003o0?ooo`3o
ool00P3oool20?l000030?ooo`3o0000oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo0100oooo0P00000B0?ooo`006@3oool00`000000oooo
0?ooo`0V0?ooo`040000o`3oool0oooo0?l000<0oooo00D0003o0?ooo`3oool0oooo0?l000020?oo
o`050000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0
003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`3oool20000o`D0oooo00<0o`000?ooo`3oool0
0P3o00020?ooo`<0003o0`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`00
0?l0103oool01@000?l0oooo0?ooo`3oool0o`0000L0oooo00<0003o0?ooo`3oool00P3o00030?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo02@0oooo000I0?ooo`030000003oool0oooo01@0oooo200000000`3oool0
000000000004000000@0oooo00@0003o0?ooo`3oool0o`000P3oool01@000?l0oooo0?ooo`3oool0
o`000080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o0000
0`3oool00`000?l0oooo0?ooo`020?ooo`060?l0003oool0oooo0?ooo`000?l0oooo0P000?l20?oo
o`030?l0003oool0oooo00<0oooo00D0o`000000o`3oool0oooo0000o`030?ooo`050?l0003oool0
oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`<0o`001@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0=0?ooo`P00000
3`3oool001T0oooo00<000000?ooo`3oool09`3oool010000?l0oooo0?ooo`3o00020?ooo`050000
o`3oool0oooo0?ooo`3o00000P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?oo
o`3oool0oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o0000103oool010000?l0oooo0?oo
o`3oool20000o`H0oooo00<0003o0?l0003oool00P3oool010000?l0oooo0?ooo`3o00030?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool20000o`H0oooo00<0o`000?ooo`3oool00P3oool20?l0
00030?ooo`000?l0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool09@3oool001T0oooo00<000000?ooo`3o
ool09`3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00@0003o0?ooo`3oool0o`000P3oool0
1@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`030?l000000?l0oooo00<0
oooo00<0003o0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00@0003o0?oo
o`3oool0o`001@3oool20000o`L0oooo00@0o`000?ooo`3o0000o`000`3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo02D0oooo000I0?ooo`030000003oool0oooo02P0oooo00@0003o
0?ooo`3oool0o`000P3oool010000?l0oooo0?ooo`3o00030?ooo`040000o`3oool0oooo0?l000<0
oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080003o00<0oooo0000o`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00D0o`0000@0003o0?l0003oool0o`00103oool00`000?l0oooo
0000o`070?ooo`80o`001@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo02D0oooo
000I0?ooo`030000003oool0oooo02P0oooo00@0003o0?ooo`3oool0o`000P3oool01@000?l0oooo
0?ooo`3oool0o`000080oooo00@0003o0?ooo`3oool0o`000`3oool00`000?l0oooo0?ooo`050?l0
00050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo0P000?l40?ooo`040?l0003oool0o`000000o`80oooo00D0o`000?ooo`3oool0003o
0?ooo`020?l000<0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`@0o`001P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo02D0oooo000I0?ooo`030000003oool0oooo01X0oooo
1@00000:0?ooo`060000o`3oool0oooo0?l0003oool0003o0`3oool0103o0000oooo0?ooo`000?l;
0?l000<0oooo1`3o00000`3oool0003o0?ooo`030?ooo`030?l0003oool0oooo0080oooo0`000?l3
0?ooo`80o`0000D0oooo0000o`3oool0oooo0?l000020?ooo`070000o`3oool0o`000?ooo`3o0000
oooo0000o`040?ooo`040000o`3oool0o`000?l000<0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo0100oooo1@00000@0?ooo`006@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00X0oooo00@0003o0?ooo`3oool0o`000P3oool00`00
0?l0oooo0?ooo`040?l00080oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0
oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`060?l000D0oooo00@0003o0?ooo`3oool0003o
0P3oool20?l000070?ooo`000?l0oooo0?ooo`3o0000oooo0000o`020?ooo`050?l0003oool0oooo
0?l000000?l0103oool20?l000H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo0P000?l60?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?ooo`006@3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00X0oooo00P0003o0?ooo`3oool0oooo0?l0003oool0003o0?ooo`80o`00
0P3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00D0003o0?ooo`3oool0oooo0?l000030?oo
o`050000o`3oool0oooo0?ooo`3o00000`3oool010000?l0oooo0?ooo`3oool30?l00080oooo00<0
003o0?ooo`3oool00P3oool03@000?l0o`000?ooo`3oool0o`000?ooo`000?l0oooo0?l0003oool0
003o0?ooo`3o00000`3oool010000?l0o`000?ooo`3oool20?l00080oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
4`3oool00`000000oooo0?ooo`0@0?ooo`006@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00/0oooo00<0003o0?ooo`3oool0103o00020?ooo`040?l0003oool0oooo0000o`80oooo
00@0o`000?ooo`3oool0003o0`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0o`000?oo
o`3oool0oooo0000o`030?ooo`030?l0003oool0oooo00<0o`00103oool03P3o0000003o0?ooo`3o
ool0o`000?ooo`000?l0oooo0?l0003oool0003o0?ooo`3o0000oooo0P000?l0103oool0o`000?l0
003o00040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3oool0403oool001T0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0;0?ooo`@0o`000P3oool010000?l0oooo0?oo
o`3o00020?ooo`040000o`3oool0oooo0?l00080oooo00D0003o0?ooo`3oool0oooo0?l000030?oo
o`050000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?l0003o00000P3o00020?ooo`80003o00D0oooo0?l000000?l0003o0?l000020000o`030?l0
003oool0003o00<0oooo0P3o00050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo01@0oooo00<000000?ooo`3oool0
403oool001T0oooo00<000000?ooo`3oool06`3oool2000000d0oooo00L0o`000?ooo`3oool0oooo
0?l0003oool0003o0080oooo00@0o`000?ooo`3oool0003o0P3oool0103o0000oooo0?ooo`000?l3
0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo
00D0o`000?ooo`3oool0oooo0000o`040?ooo`<0o`000P3oool20000o`070?l000000?l0o`000000
o`3oool0o`000000o`020?ooo`80o`0000<0oooo0?l0003oool0103oool010000?l0oooo0?ooo`3o
oolN0000o`030?ooo`3o0000oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool04`3oool200000180oooo000I
0?ooo`030000003oool0oooo02/0oooo00H0003o0?ooo`3oool0o`000?ooo`000?l20?ooo`040?l0
003oool0oooo0000o`80oooo00@0o`000?ooo`3oool0003o0`3oool01@3o0000oooo0?ooo`3oool0
003o00<0oooo00T0o`000?ooo`3oool0oooo0000o`3oool0003o0?ooo`3o00000`3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080o`000P000?l01@3o0000003o0?l000000?l0o`00
0080003o00<0oooo0?l0003oool00`3oool00`3o0000oooo0?ooo`020?ooo`@0003o0`3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`D0003o103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0X0?ooo`006@3oool00`000000
oooo0?ooo`0[0?ooo`060000o`3oool0oooo0?l0003oool0003o0`3oool00`3o0000oooo0000o`03
0?ooo`040?l0003oool0oooo0000o`80oooo00@0o`000?ooo`3oool0oooo50000?l00`3oool0o`00
0?ooo`030?ooo`80o`000P000?l0103o0000003o0000o`3oool20?l000<0oooo1`000?l00`3oool0
003o0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3oool0oooo1@000?l70?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0X0?oo
o`006@3oool00`000000oooo0?ooo`0[0?ooo`040000o`3oool0oooo0?l00080oooo00@0003o0?oo
o`3oool0o`000P3oool010000?l0oooo0?ooo`3o00020?ooo`P0003o0`3oool01@3o0000oooo0?oo
o`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`L0003o00<0oooo0?l00000
0?l00P000?l00`3oool0o`000?ooo`040000o`80oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool60000o`80
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo0200
oooo100000040?ooo`006@3oool00`000000oooo0?ooo`0[0?ooo`070000o`3oool0oooo0?ooo`3o
0000oooo0000o`020?ooo`040?l0003oool0oooo0000o`80oooo10000?l30?ooo`040?l0003oool0
oooo0000o`<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool0103o0000oooo0?ooo`3oool60000o`030?l000000?l0003o00<0003o103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo10000?l70?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0803oool010000000oooo0?ooo`0000050?ooo`0000<0oooo0000
00000000A@0000001P000?l000000000003o000000000000o`<0000000<0o`00000000000?l00P00
0?l0103o00000000000000000?l3000000040?l00000000000000000o`<0000000D0o`0000000000
000000000000o`03000000050?l0000000000000000000000?l00`0000090?l000030000o`3o0000
o`0000X0o`001@0000000`000?l0000000000003000000030?l000000000000000<0000000<0003o
000000000000100000000`3o0000000000000004000000030000o`000000000000@0000000<0o`00
0000000000001@0000000`000?l0000000000005000000030?l00000000000000080003o1@000000
0`000?l0000000000006000000030?l000000000000000L0000000<0003o00000000000020000000
0`3o0000000000000008000000030000o`000000000001L000002@3oool010000000oooo0?ooo`00
00050?ooo`006@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00d0oooo00@0003o
0?ooo`3oool0o`000P3oool00`000?l0oooo0?ooo`030000o`<0oooo00<0o`000?ooo`000?l00`3o
ool0103o0000oooo0?ooo`000?l30?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool80?l00003
0?ooo`3o0000oooo0080oooo10000?l40?l000<0003o1@3oool80?l000@0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool00P3oool40000o`030?ooo`000?l0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool05P3oool00`000000
oooo0?ooo`060?ooo`80000000<0oooo0000000000001@3oool001T0oooo00<000000?ooo`3oool0
;03oool01P000?l0oooo0?ooo`3oool0o`000?ooo`<0003o00<0o`000?ooo`000?l00`3oool0103o
0000oooo0?ooo`000?l20?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool01P3o0000oooo0?oo
o`3oool0003o0?ooo`<0o`000`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
003o0P3o00000`000?l0o`000?l000020000o`030?l0003oool0003o00<0003o0P3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00@0o`001P3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool40000o`H0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0:P3oool001T0oooo00<000000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`030000o`80oooo
00@0o`000?ooo`3oool0003o0P3oool0103o0000oooo0?ooo`000?l30?ooo`040?l0003oool0oooo
0000o`<0oooo1@3o00020?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0oooo0`00
0?l01@3oool0o`000000o`000?l0oooo0080o`0000<0003o0?l000000?l00P3o00030?ooo`80003o
1@3oool00`000?l0oooo0?ooo`030?ooo`D0o`0000<0oooo0000o`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00@0003o0?ooo`3oool0oooo0P000?l30?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo02X0oooo000I0?ooo`030000003oool0oooo02d0oooo0`000?l0103o0000oooo
0?ooo`000?l20?ooo`030?l0003oool0003o0080oooo00@0o`000?ooo`3oool0003o0`3oool0103o
0000oooo0?ooo`000?l40?l00080oooo00<0003o0?ooo`3oool00P3oool01P3o0000oooo0?ooo`3o
ool0003o0?ooo`80003o00@0oooo0?l0003oool0o`000P3oool01P000?l0o`000000o`3o0000003o
0?l00080003o00<0oooo0?l0003oool00P3oool00`3o0000003o0000o`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool30?l000D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo0P000?l00`3oool0o`000?ooo`08
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0[
0?ooo`006@3oool00`000000oooo0?ooo`0]0?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0000
o`020?ooo`030?l0003oool0003o0080oooo00@0o`000?ooo`3oool0003o0`3oool0103o0000oooo
0?l0003o00030?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`030000
o`<0oooo0P3o00020?ooo`050000o`3oool0o`000000o`3o00000P000?l01@3o0000oooo0000o`3o
ool0o`000080oooo00<0o`000?ooo`3oool00P000?l00`3oool0003o0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00@0003o0?ooo`3o0000o`000`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool20000o`P0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo02/0oooo000I0?ooo`030000003o
ool0oooo02h0oooo00H0003o0?ooo`3oool0o`000?ooo`000?l20?ooo`030?l0003oool0003o00<0
oooo00@0o`000?ooo`3oool0003o103o00020?ooo`040000o`3oool0oooo0?l000<0oooo00D0003o
0?ooo`3oool0oooo0?l000020000o`80oooo00<0003o0?ooo`3oool00`3o00002P3oool0003o0?oo
o`3o0000oooo0000o`3o0000oooo0000o`3o00020?ooo`040000o`3oool0o`000?l000D0oooo0P00
0?l40?ooo`030?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool0oooo0`3o00060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool0103o0000oooo0000o`000?l60?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0[0?ooo`00
6@3oool00`000000oooo0?ooo`0^0?ooo`040000o`3oool0oooo0?l00080oooo00<0003o0?ooo`3o
00000P3oool01@000?l0oooo0?ooo`3o0000oooo0080o`000`3oool0103o0000oooo0?ooo`000?l2
0?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`000?l0003o103oool00`000?l0oooo0?l0
00030?ooo`030000o`3oool0o`000080oooo00D0003o0?l0003oool0003o0?l000020?ooo`030000
o`3oool0o`000080o`000`3oool00`000?l0oooo0?ooo`020000o`80oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`<0o`00103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00L0oooo00@0o`000?ooo`3oool0oooo0`000?l30?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0/0?ooo`006@3oool00`000000oooo
0?ooo`0_0?ooo`060000o`3oool0oooo0?l0003oool0003o0P3oool0103o0000oooo0000o`3oool3
0?l000030?ooo`000?l0oooo0080oooo00@0o`000?ooo`3oool0003o0`3oool0103o0000oooo0?oo
o`3oool20000o`80oooo00@0o`000?ooo`3oool0oooo0P3o00030?ooo`0<0000o`3o0000oooo0?l0
003oool0003o0?ooo`3o0000oooo0000o`3oool0o`000P3oool01@000?l0oooo0?ooo`3oool0o`00
0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0o`000?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00P3o00020?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`<0003o2P3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo02`0oooo000I0?ooo`030000003oool0oooo02l0oooo00@0003o0?ooo`3o
ool0o`000P3oool010000?l0oooo0?l0003oool20?l00080oooo00@0o`000?ooo`3oool0003o0P3o
ool01@3o0000oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`000?l00P000?l30?ooo`060?l0
003oool0oooo0?l0003oool0003o0P3oool00`000?l0oooo0?ooo`020?l0000;0?ooo`000?l0oooo
0?l0003oool0003o0?ooo`3o0000oooo0?l000000?l0103oool00`3o0000003o0?ooo`050?ooo`80
003o103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo0P3o00000`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool20000o`P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0]0?ooo`006@3oool00`000000oooo
0?ooo`0`0?ooo`030000o`3oool0o`000080oooo00H0003o0?l0003o0000o`000?ooo`000?l20?oo
o`040?l0003oool0oooo0000o`<0oooo00@0o`000?ooo`3oool0003o0P3oool20000o`80oooo00<0
003o0?ooo`3oool00P3oool20?l000<0oooo0P000?l30?ooo`040?l0003oool0o`000000o`80o`00
00<0oooo0000o`3o00000P3o00020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0`3oool0103o0000oooo0?ooo`000?l30?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0o`000?l000050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`020000o`H0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`0]0?ooo`006@3oool00`000000oooo0?ooo`0`0?ooo`080000o`3oool0oooo0?l0003o
ool0o`000?ooo`3o00020?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool010000?l0oooo0?oo
o`3o00020?ooo`<0003o00<0oooo0?l0003oool00P3oool00`000?l0oooo0?ooo`020?l000@0oooo
00D0003o0?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0o`000080o`0000@0003o0?ooo`3o
ool0o`000P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`3o00000`3oool00`3o0000oooo0?oo
o`020?ooo`<0003o1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0080o`000P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00P3o
ool20000o`<0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0]0?ooo`006@3oool0
0`000000oooo0?ooo`0a0?ooo`080000o`3o0000o`000?l0003oool0003o0?ooo`3o00020?ooo`04
0000o`3oool0oooo0?l00080oooo00D0003o0?ooo`3oool0o`000?ooo`030000o`80oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0o`000?ooo`3oool0o`000080oooo00D0003o0?ooo`000?l0003o
0?l000030?ooo`040000o`3oool0oooo0?l00080oooo00@0003o0?ooo`3oool0o`000P3oool00`00
0?l0oooo0000o`030?ooo`040?l0003oool0oooo0?l000H0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo0`3o00070?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool0103oool20000o`030?ooo`3o0000oooo00T0oooo00<0003o
0?ooo`3oool0;P3oool001T0oooo00<000000?ooo`3oool0<@3oool00`3o0000oooo0?l000020?oo
o`030000o`3oool0o`000080oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`@0003o0P3oool0
1@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000003o0?oo
o`030?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool0103o0000oooo0?ooo`000?l20?ooo`03
0?l0003oool0oooo0080003o1@3oool20?l000H0oooo00<0003o0?ooo`000?l0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo0`3o00050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo02h0
oooo000I0?ooo`030000003oool0oooo0340oooo00P0003o0?ooo`3oool0o`000?ooo`000?l0oooo
0?l000<0oooo00D0003o0?ooo`3oool0o`000?ooo`020000o`80oooo00D0o`000?ooo`3oool0oooo
0000o`020?ooo`060?l0003oool0o`000?l0003oool0003o0`3oool00`000?l0o`000?ooo`020?oo
o`050?l0003oool0003o0?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l30?ooo`040?l00000
0?l0003o0000o`H0oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?ooo`000?l30?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?l000<0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l000000?l0003o00P0
oooo00<0003o0?ooo`3oool0;`3oool001T0oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo
0?l000020?ooo`030000o`3oool0o`000080oooo00<0003o0?ooo`3oool00P000?l00`3oool0003o
0?ooo`020?ooo`040?l0003oool0oooo0000o`80oooo0P3o00040?ooo`060000o`3oool0oooo0000
o`3oool0o`000P3oool00`3o0000oooo0?ooo`040000o`060?l0003oool0oooo0?ooo`000?l0oooo
0P000?l01@3o0000oooo0?ooo`3oool0003o00<0oooo0`3o00050?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3o00001`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo0P3o00000`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00D0o`000?ooo`3o
ool0oooo0000o`070?ooo`030000o`3oool0oooo02l0oooo000I0?ooo`030000003oool0oooo0380
oooo00<0003o0?ooo`3o00000P3oool00`000?l0oooo0?l000030?ooo`80003o00D0oooo0?l0003o
ool0oooo0000o`020?ooo`060?l0003oool0oooo0?ooo`000?l0o`000P3oool00`3o0000oooo0?oo
o`020?ooo`80003o0`3oool20?l000@0oooo00@0003o0?ooo`3oool0o`001@000?l20?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3o00000`3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00<0oooo0P000?l60?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0300oooo000I0?ooo`030000003o
ool0oooo0380oooo00H0003o0?ooo`3oool0o`000?ooo`000?l20?ooo`040?l0003oool0003o0000
o`80oooo00@0o`000?ooo`3oool0003o0`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0
o`000?ooo`3oool0oooo0P000?l30?ooo`80o`000`3oool01@000?l0oooo0?ooo`3oool0o`0000<0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3o0000oooo00@0oooo00@0o`000?oo
o`3oool0003o1P3oool00`3o0000oooo0000o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool010000?l0oooo0?l0003o00040?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool0103oool20000o`<0oooo00<0003o0?ooo`3oool0<03oool001T0oooo00<00000
0?ooo`3oool0<`3oool00`000?l0oooo0?l000020?ooo`040000o`3oool0o`000000o`80oooo00@0
003o0?ooo`3oool0o`000P3oool01@000?l0oooo0?ooo`3o0000oooo0080o`0000<0003o0?ooo`3o
ool00P3oool01@3o0000003o0000o`3oool0003o00<0oooo00H0o`000?ooo`3o0000o`000?ooo`00
0?l30?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`000?l01P3oool01@3o0000oooo0?ooo`3oool0003o00<0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`050000o`3oool0oooo0?oo
o`3o00000`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo0`000?lc0?oo
o`006@3oool00`000000oooo0?ooo`0c0?ooo`050000o`3oool0oooo0?l0003oool00`000?l30?oo
o`040000o`3oool0oooo0?l00080oooo00<0003o0?ooo`3oool00P3o00030?ooo`050000o`3oool0
oooo0?ooo`000?l0103oool00`000?l0oooo0?l000040?ooo`030?l000000?l0oooo0080oooo00D0
o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo0080o`0000<0oooo0000o`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0
003o1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo0`3o00080?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0<@3oool001T0oooo00<000000?ooo`3oool0
=03oool00`000?l0oooo0?l000020000o`80oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`07
0?l0003oool0oooo0000o`3o0000oooo0?l000040?ooo`050000o`3oool0oooo0000o`3o0000103o
ool00`000?l0o`000?ooo`030?ooo`030000o`3oool0o`0000<0o`000`3oool00`000?l0oooo0?l0
00040?l000<0oooo00<0003o0?ooo`3oool00P3oool20000o`030?ooo`3o0000o`0000@0oooo00<0
o`000?ooo`3oool0103oool20000o`H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`0b0?ooo`006@3oool00`000000oooo0?ooo`0d0?ooo`<0003o0P3oool00`000?l0oooo0?l00003
0?ooo`050000o`3oool0oooo0?l0003oool00P3o00030?ooo`070?l0003oool0oooo0?ooo`000?l0
oooo0000o`020?ooo`050?l0003oool0oooo0?ooo`3o00000P000?l30?ooo`040000o`3oool0oooo
0?ooo`D0o`0000<0003o0?l0003o00000P3oool00`3o0000oooo0?ooo`030?ooo`040000o`3oool0
oooo0000o`D0oooo00@0o`000?ooo`3oool0o`001`3oool30000o`@0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0o`0000H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`0b0?ooo`006@3oool00`000000oooo0?ooo`0e0?ooo`050000o`3o
ool0o`000?ooo`000?l00P3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00@0o`000?ooo`3o
ool0003o0`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3o00000`3oool0
0`000?l0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0003o00L0oooo0P3o00070?ooo`050000o`3oool0
oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool00P3o00030?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0<`3o
ool001T0oooo00<000000?ooo`3oool0=@3oool00`000?l0oooo0?l000020?ooo`030000o`3oool0
o`0000<0oooo00@0003o0?l0003o0000o`000`3oool010000?l0oooo0?ooo`3o00020?ooo`030000
o`3oool0003o00@0oooo00<0o`000?ooo`3oool00`3oool20000o`@0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo0P000?l70?ooo`80o`00
1`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0o`0000P0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo0000o`L0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool0<`3oool001T0oooo00<000000?ooo`3oool0=P3oool01@000?l0oooo0?l0003oool0003o0080
oooo00D0o`000?ooo`3oool0o`000000o`020?ooo`040?l0003oool0oooo0000o`<0oooo00<0o`00
0000o`3oool00P3oool010000?l0oooo0?ooo`3oool20?l000D0oooo0`000?l20?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020000o`030?ooo`00
0?l0oooo00D0oooo00@0o`000?ooo`3oool0o`001@3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030?l0
00000?l0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0=03oool001T0oooo00<000000?ooo`3oool0=P3o
ool00`000?l0oooo0?l000020?ooo`070000o`3oool0o`000?ooo`3o0000oooo0000o`030?ooo`04
0?l0003oool0oooo0000o`80oooo00<0003o0?l0003oool00`3oool00`000?l0oooo0?l000020?oo
o`050?l0003oool0oooo0?ooo`000?l00`3oool20000o`060?l000000?l0003o0000o`3oool0003o
0P3oool30000o`030?l000000?l0003o00@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l01`3oool00`3o0000oooo0000o`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool20?l000H0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0=@3oool001T0oooo00<000000?ooo`3oool0=`3oool01P000?l0oooo0?l0003oool0003o0?oo
o`80o`000`3oool01@000?l0oooo0?ooo`3oool0o`000080oooo0P000?l20?ooo`070?l0003oool0
oooo0?ooo`000?l0oooo0?l000030?ooo`80o`0000<0oooo0000o`3oool0103oool0103o0000oooo
0?ooo`3oool40000o`<0oooo00<0o`000?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0o`00
00D0oooo00@0o`000?ooo`3oool0003o1`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0oooo0?l000D0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool0=P3oool001T0oooo00<000000?ooo`3oool0=`3oool00`000?l0oooo0?l0
00020?ooo`040?l0003oool0oooo0?l000<0oooo00D0003o0?ooo`3oool0o`000?ooo`030000o`<0
oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`030000o`3o0000oooo00<0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00@0003o0?oo
o`3o0000o`001`3oool00`3o0000003o0?ooo`070?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0o`0000T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo03H0oooo000I0?ooo`030000003oool0oooo03P0oooo00P0
003o0?ooo`3o0000o`000?ooo`000?l0oooo0?l000@0oooo00@0003o0?ooo`3oool0003o0`3oool0
20000?l0oooo0?ooo`3oool0o`000?ooo`3o0000oooo0P000?l40?ooo`040000o`3oool0o`000?l0
0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00@0oooo00<0o`000000o`3oool0203oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00<0oooo00@0003o0?ooo`3oool0003o203oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00<0oooo00@0o`000?ooo`3oool0o`002@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0=`3oool001T0oooo00<000000?ooo`3oool0>03oool0
1P000?l0oooo0?l0003o0000oooo0000o`80oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`03
0000o`3o0000oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`80003o00<0oooo0000
o`3oool00`3oool40?l000@0oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`3oool3
0?l000030?ooo`000?l0oooo00L0oooo00<0003o0?ooo`3o00001P3oool00`3o0000oooo0?ooo`05
0?ooo`80003o203oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo0P3o0009
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0h
0?ooo`006@3oool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0o`000080oooo00@0003o0?oo
o`3oool0o`000`3oool20000o`80oooo00@0o`000?ooo`3oool0003o0`3oool20?l000D0oooo0P00
0?l50?ooo`030?l0003oool0oooo00@0o`0000<0003o0?l0003o00001`3o00040?ooo`030000o`3o
ool0oooo00@0oooo0P000?l20?ooo`030?l0003oool0oooo0080oooo0P3o00080?ooo`80003o1`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0>03o
ool001T0oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo0?l000020?ooo`050000o`3oool0
oooo0?l0003oool00`000?l20?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0?l000020?ooo`80
o`000`3oool30000o`@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0oooo0P000?l40?ooo`050?l0003oool0oooo
0?ooo`3o00002@3oool010000?l0oooo0?ooo`000?l50?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?l000060?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0i0?ooo`006@3oool00`000000oooo0?ooo`0j
0?ooo`030000o`3oool0o`0000<0oooo00@0003o0?ooo`3o0000003o0P3oool01@000?l0oooo0?oo
o`3oool0o`0000<0oooo00<0003o0?l0003oool00`3oool0103o0000oooo0?ooo`000?l20?ooo`<0
003o00<0oooo0?l0003oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0
oooo00@0003o0?ooo`000?l0003o1`3oool30?l000P0oooo0P000?l30?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`050?l0003oool0oooo
0?ooo`3o00001@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0>P3oool001T0oooo00<000000?ooo`3oool0>`3oool00`000?l0oooo0?l000020?oo
o`040000o`3oool0003o0?l000<0oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`030?l00000
0?l0oooo00@0oooo00<0o`000000o`3oool01@3oool00`000?l0o`000000o`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool20000o`T0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo0?l000T0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l02P3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo03/0oooo000I0?ooo`030000003oool0oooo03/0oooo
00@0003o0?ooo`3oool0o`000P3oool20000o`030?ooo`3o0000oooo0080oooo00@0003o0?ooo`3o
ool0oooo0P3o00020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?l0003oool01@3oool0103o
0000oooo0000o`000?l30?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@000?l0
0`3oool0003o0?ooo`070?ooo`030?l0003oool0o`0000L0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?l000090?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0000o`0:0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0>`3oool0
01T0oooo00<000000?ooo`3oool0?03oool00`000?l0oooo0?l000020?ooo`80003o0P3oool01@3o
0000oooo0?ooo`3oool0003o0080oooo0P3o00030?ooo`80003o0P3oool00`000?l0oooo0?ooo`02
0?l000<0oooo00<0o`000?ooo`3oool00P3oool:0000o`030?l000000?l0003o00H0oooo00<0003o
0?ooo`3oool0103oool20?l000<0oooo00<0o`000?ooo`3oool00P3oool20000o`P0oooo00<0o`00
0000o`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo03`0oooo000I0?oo
o`030000003oool0oooo03`0oooo00L0003o0?ooo`3oool0o`000000o`3oool0003o00<0oooo00H0
o`000?ooo`3oool0003o0?ooo`3o00020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`00
0?l0103oool20?l000030?ooo`3o0000oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo0P3o00050?ooo`050?l0003oool0oooo0?oo
o`000?l02@3oool0103o0000oooo0?ooo`000?l70?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?l000080?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0?@3oool001T0oooo00<000000?ooo`3oool0?@3oool30000o`040?l0003oool0oooo
0000o`80oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool01@3oool20?l000H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`060?ooo`040000o`3oool0o`000?l000P0oooo00<0o`000000o`000?l02@3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`070?ooo`050000o`3oool0oooo0?ooo`3o00001P3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo03h0oooo000I0?ooo`030000003oool0oooo03h0oooo00<0003o0?ooo`3o0000
0`3oool010000?l0oooo0?ooo`3o00020?ooo`030?l000000?l0oooo00<0oooo00@0o`000?ooo`3o
ool0oooo0`000?l50?ooo`040?l0003oool0o`000?l000@0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030?l000000?l0o`0000X0oooo00<0o`000?ooo`3oool01`3oool2
0?l000H0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0?`3oool001T0oooo00<000000?ooo`3oool0?P3oool010000?l0oooo0?ooo`3o
00030?ooo`030000o`3oool0oooo0080o`000P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0003o00<0oooo0P000?l30?ooo`040?l0003oool0oooo0?ooo`@0o`0000<0003o0?l0003oool0
1P3oool00`3o0000oooo0?l000050?l000030?ooo`000?l0oooo00P0oooo0P000?l00`3oool0o`00
0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`000?l0203oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`03
0000o`3oool0oooo03l0oooo000I0?ooo`030000003oool0oooo03l0oooo00@0003o0?ooo`3oool0
o`000P3oool00`000?l0oooo0?ooo`020?l000<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
003o0?ooo`040?ooo`80003o00<0oooo0?l0003oool01P3oool00`000?l0oooo0?l000080?l000L0
oooo00<0003o0?ooo`3oool01@3oool20000o`<0oooo00<0o`000?ooo`3oool00`3oool20?l000X0
oooo0P000?l80?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?l0000:0?ooo`030000o`3oool0oooo0400oooo000I0?ooo`030000003oool0oooo0400oooo
00@0003o0?ooo`3oool0o`000P3oool01@000?l0o`000?ooo`3oool0o`0000<0oooo00D0003o0?oo
o`3oool0oooo0000o`020?l000H0oooo00<0003o0?l0003oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool20000o`D0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`090?ooo`<0003o1`3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`11
0?ooo`006@3oool00`000000oooo0?ooo`110?ooo`030000o`3oool0o`000080oooo00<0o`000000
o`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool00P3o0004
0?ooo`030?l0003oool0003o0080003o103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`000?l00P000?l80?ooo`040?l0003oool0oooo0?l000/0oooo00@0
003o0?ooo`3oool0003o1@3oool20?l000X0oooo00<0003o0?ooo`3oool0203oool20?l000T0oooo
00<0003o0?ooo`3oool0@P3oool001T0oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo0?oo
o`020?l00080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`80003o1@3oool20?l00080oooo
00<0o`000?ooo`3oool00P3oool20000o`80oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`<0003o2`3oool30?l000X0oooo0P000?l40?ooo`050000o`3oool0oooo0?ooo`3o
00002`3oool00`000?l0oooo0?ooo`080?ooo`040?l0003oool0oooo0?l000L0oooo00<0003o0?oo
o`3oool0@`3oool001T0oooo00<000000?ooo`3oool0@P3oool010000?l0oooo0?l0003o00030?oo
o`050000o`3oool0oooo0?ooo`3o00000P3oool30000o`H0oooo0P3o00070?ooo`X0003o00<0oooo
0?l000000?l01`000?l20?ooo`030000o`3oool0oooo00P0oooo0`3o00090?ooo`80003o1P3oool0
10000?l0oooo0?ooo`3o000;0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo04@0oooo000I0?ooo`030000003oool0
oooo04<0oooo00@0o`000?ooo`3oool0o`000`3oool01P000?l0oooo0?ooo`3oool0o`000000o`<0
oooo00<0003o0?ooo`3oool0103oool30?l000H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
o`000?ooo`090?ooo`030000o`3oool0oooo00D0oooo0`3o00020?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0o`000?ooo`0:0?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo04@0
oooo000I0?ooo`030000003oool0oooo04@0oooo00@0003o0?ooo`3oool0o`000`3oool01@000?l0
oooo0?ooo`000?l0o`0000@0oooo0P000?l30?ooo`040?l0003oool0oooo0?ooo`80o`00103oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool3
0?l000H0oooo00<0o`000?ooo`3oool00`3oool20000o`X0oooo00<0o`000000o`3oool0203oool2
0000o`T0oooo0P3o00070?ooo`050?l0003oool0oooo0?ooo`000?l0A`3oool001T0oooo00<00000
0?ooo`3oool0A@3oool010000?l0oooo0?ooo`3o00030?ooo`040000o`3oool0003o0?ooo`80o`00
103oool20000o`030?ooo`3o0000oooo00@0oooo0P3o00020?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?l000020?l000T0oooo00@0o`000?ooo`3oool0
oooo0P000?l:0?ooo`80o`0000<0oooo0000o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`000?l0B03oool001T0oooo00<000000?ooo`3oool0
AP3oool010000?l0oooo0?ooo`3o00030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000003o0?ooo`060?ooo`80o`0000<0003o0?l0003o00001`3oool00`3o0000
oooo0?ooo`060?ooo`80o`0000<0003o0?l0003oool02`3oool0103o0000oooo0000o`000?l;0?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0A`3oool001T0oooo00<000000?ooo`3o
ool0AP3oool01@000?l0oooo0?ooo`3oool0o`000080oooo0`000?l30?ooo`80o`000`3oool0103o
0000oooo0000o`000?l60?ooo`040000o`3oool0oooo0?oooa00o`000P3oool00`000?l0oooo0?oo
o`0;0?ooo`030000o`3o0000oooo00/0oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?oo
o`3oool20000o`X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`180?ooo`006@3o
ool00`000000oooo0?ooo`170?ooo`060000o`3oool0oooo0?ooo`3o0000003o0`3oool00`000?l0
oooo0?ooo`020?ooo`<0o`00103oool30000o`<0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo0P000?l00`3oool0o`000?ooo`090?ooo`80
o`001`3oool010000?l0oooo0?ooo`000?l;0?ooo`030?l0003oool0oooo00T0oooo0P000?m;0?oo
o`006@3oool00`000000oooo0?ooo`180?ooo`050000o`3oool0oooo0000o`3o0000103oool20000
o`@0oooo00<0o`000?ooo`3oool01@3oool20000o`030?ooo`000?l0oooo00T0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`80003o0`3oool00`3o0000oooo0?ooo`060?oo
o`80o`002P3oool20000o`X0oooo0P3o000;0?ooo`030000o`3oool0oooo04/0oooo000I0?ooo`03
0000003oool0oooo04T0oooo00D0003o0?ooo`000?l0oooo0?l000050?ooo`040000o`3oool0oooo
0?ooo`<0o`001`3oool30000o`T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`03
0?ooo`<0003o1P3oool00`3o0000oooo0?ooo`030?ooo`80o`002`3oool20000o`X0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`1<0?ooo`006@3oool00`000000oooo0?ooo`1:0?oo
o`040000o`3oool0oooo0?ooo`80o`00103oool20000o`040?ooo`3o0000oooo0?ooo`<0o`001@3o
ool00`000?l0oooo0000o`060000o`80oooo00<0o`000?ooo`3oool0203oool70000o`T0oooo00@0
o`000?ooo`3oool0oooo0P3o000;0?ooo`80003o0P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool0C@3oool001T0oooo00<000000?ooo`3oool0B`3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool30?l000030?ooo`000?l0oooo00P0oooo0P000?l00`3o0000003o0000o`080000o`030?ooo`00
0?l0oooo00h0oooo0`3o000<0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool20?l000`0oooo00<0003o0?ooo`3oool0CP3oool001T0oooo00<000000?ooo`3oool0C03oool2
0000o`<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000003o0000o`070?ooo`030?l000000?l0
o`0000X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`<0o`00303oool2
0000o`H0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`80003oD@3oool0
01T0oooo00<000000?ooo`3oool0CP3oool010000?l0oooo0?ooo`3oool20?l000030?ooo`3o0000
oooo0080oooo0P000?l50?ooo`030000o`3oool0oooo0080o`00203oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00P0oooo0`3o00020?ooo`030?l0003oool0oooo00P0oooo0P000?l9
0?ooo`040000o`3oool0o`000?l000`0oooo00<0003o0?ooo`3oool0D@3oool001T0oooo00<00000
0?ooo`3oool0C`3oool00`000?l0oooo0?ooo`020?ooo`80o`001@3oool20000o`<0oooo00<0003o
0?ooo`3oool00P3oool30?l000D0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`04
0?ooo`<0o`001P3oool00`3o0000oooo0?ooo`050?ooo`80003o2`3oool00`000?l0o`000?ooo`0<
0?ooo`030000o`3oool0oooo0580oooo000I0?ooo`030000003oool0oooo0500oooo0P000?l20?oo
o`<0o`001P3oool20000o`030?ooo`000?l0oooo00H0oooo1P3o000:0?ooo`80o`0000<0003o0?l0
003o0000103o00090?ooo`030?l0003oool0oooo00<0oooo0P000?l<0?ooo`030?l000000?l0oooo
00/0oooo0P000?mE0?ooo`006@3oool00`000000oooo0?ooo`1B0?ooo`030000o`3o0000oooo0080
oooo0P3o00060?ooo`<0003o2P3oool00`3o0000oooo0?l000090?l00080oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`030000o``0oooo0P3o00020?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool0E@3oool000h0oooo0P0000090?ooo`030000003oool0oooo05<0oooo
00<0o`000?ooo`3oool00`3oool20?l000D0oooo00<0003o0?ooo`000?l00P000?l70?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool20000o`030?l000000?l0oooo00d0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`80003oF03oool000d0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`1D0?ooo`80003o1@3oool20?l00080oooo
00<0003o0?ooo`3oool00`3oool30000o`@0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0:0?ooo`80003o0P3oool00`3o0000oooo0?ooo`0;0?ooo`80o`001@3oool00`000?l0oooo
0?ooo`040?ooo`80003oFP3oool000d0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`1F0?ooo`80003o1@3oool20?l000030000o`3oool0oooo00H0oooo0`000?l00`3oool0o`00
0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo10000?l40?ooo`030?l0003oool0oooo00T0oooo
0P3o00080?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0FP3oool000h0oooo0P00
00090?ooo`030000003oool0oooo05P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0o`000?l0
000:0?ooo`030000o`3o0000003o01D0003o203oool00`3o0000oooo0?ooo`070?ooo`80o`002P3o
ool00`000?l0oooo0?ooo`020000oed0oooo000=0?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool0F@3oool20000o`<0oooo00<0003o0?ooo`3oool00`3o00080?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`040?ooo`<0o`003@3o
ool20000oel0oooo000>0?ooo`8000002@3oool00`000000oooo0?ooo`1K0?ooo`80003o00<0oooo
0000o`3oool0103oool30?l000@0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00@0o`003P3oool20000of40oooo000I0?ooo`030000003oool0oooo
05d0oooo0P000?l80?ooo`<0o`0000<0oooo0?l0003oool03@3oool00`000?l0oooo0?ooo`0>0?oo
o`<0o`00403oool20000of<0oooo000:0?ooo`/00000103oool00`000000oooo0?ooo`1O0?ooo`80
003o2@3oool30?l000d0oooo00<0003o0?ooo`3oool02@3oool50?l000030?ooo`3o0000oooo00d0
oooo0`000?mU0?ooo`006@3oool300000640oooo0P000?l80?ooo`030?l0003oool0o`0000`0o`00
00<0003o0?l0003o00002@3o00060?ooo`030?l0003oool0oooo00X0oooo0P000?mX0?ooo`006@3o
ool00`000000oooo0?ooo`1S0?ooo`<0003o1@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?ooo`3oool01P3oool40000ofX0oooo000I0?ooo`030000003oool0
oooo06H0oooo0`000?l20?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03`3oool0
103o0000oooo0?ooo`3oool50000ofh0oooo000I0?ooo`030000003oool0oooo06T0oooo0P000?l0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo0100oooo00<0o`000000o`000?l0L`3oool0
00l0oooo1@0000050?ooo`030000003oool0oooo06`0oooo10000?l:0?ooo`030000o`3oool0oooo
00`0oooo10000?l00`3o0000oooo0?ooo`1c0?ooo`00403oool00`000000oooo000000060?ooo`03
0000003oool0oooo0700oooo6@000?mj0?ooo`00403oool00`000000oooo000000060?ooo`030000
003oool0oooo0?l0oooo103oool00100oooo00<000000?ooo`0000001P3oool00`000000oooo0?oo
o`3o0?ooo`@0oooo000?0?ooo`@000001P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo003o0?oo
ob00oooo000A0?ooo`030000003oool0oooo0?l0oooo303oool00?l0oooo803oool00?l0oooo803o
ool00?l0oooo803oool00?l0oooo803oool00?l0oooo803oool00?l0oooo803oool00?l0oooo803o
ool00?l0oooo803oool00?l0oooo803oool001P0oooo0P00003o0?ooo`H0oooo000H0?ooo`800000
o`3oool60?ooo`005`3oool010000000oooo0?ooo`00003o0?ooo`D0oooo000F0?ooo`8000000P3o
ool200000?l0oooo103oool00?l0oooo803oool00?l0oooo803oool00?l0oooo803oool00?l0oooo
803oool00001\
\>"],
    ImageRangeCache->{{{0, 286.875}, {286.875, 0}} -> {0, 0, 0, 0}}],
  StyleBox["     \n\t\t\t\t\t\tFigure 5.C",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The mapping  ",
  Cell[BoxData[
      \(w\  = \((z)\)\^\[ImaginaryI]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Complex Exponents",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tLet us now consider the various possibilities that may arise in the \
definition of  ",
  Cell[BoxData[
      \(z\^c\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Case (i).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose ",
  Cell[BoxData[
      \(c = k\)]],
  " where ",
  StyleBox["k",
    FontFamily->"Courier New"],
  " an integer.  Then, if  ",
  Cell[BoxData[
      \(z = 
        r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\) \[NotEqual] 0\)]],
  ",  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(k\ log \((z)\)\), "=", 
        RowBox[{"{", 
          
          RowBox[{\(k\ ln \((r)\) + \[ImaginaryI]\ k \((\[Theta] + 
                    2  n\ \[Pi])\)\), ":", "  ", 
            RowBox[{"n", "  ", 
              StyleBox["is",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["an",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["integer",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}], "}"}]}]]],
  ".    "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Recalling that the complex exponential function has period ",
  Cell[BoxData[
      \(2  \[Pi]\ \[ImaginaryI]\)]],
  ", we have  \n\n\t\t\t",
  Cell[BoxData[
      StyleBox[\(z\^k\  = \ \(r\^k\) \((cos\ k\ \[Theta]\  + \ \[ImaginaryI]\ \
sin\ k\ \[Theta])\)\),
        FontWeight->"Plain"]],
    FontWeight->"Bold"],
  ".\n\n",
  "which is the single-valued ",
  StyleBox["k",
    FontFamily->"Courier New"],
  "th power of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " that we discussed in Section 1.5.  ",
  "This is easily verified by the computation \n\n\t\t\t",
  Cell[BoxData[{
      \(z\^k\  = \ \(exp[k\ log\ z]\ \  = \ \ exp[
            k\ log \((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\))\)]\)\
\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \(\(=\)\(exp[
          k\ ln\ r\  + \ \[ImaginaryI]\ k \((\[Theta] + 
                  2\ n\ \[Pi])\)]\)\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \(\(=\)\(exp[
          ln\ r\^k\  + \ \[ImaginaryI]\ k\ \[Theta] + \[ImaginaryI]\ 2\ k\ n\ \
\[Pi]]\)\)\n\), "\n", 
      \(\ \ \ \ \ \ \(\(=\)\(exp[ln\ r\^k] exp[\[ImaginaryI]\ k\ \[Theta]] 
          exp[\[ImaginaryI]\ 2\ k\ n\ \[Pi]]\)\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \(\(=\)\(\(r\^k\) 
          exp \((\[ImaginaryI]\ k\ \[Theta])\)\)\)\ \[IndentingNewLine]\), 
    "\n", 
      \(\ \ \ \ \ \ \(\(=\)\(\ \)\(\(r\^k\) \((cos\ k\ \[Theta]\  + \ \
\[ImaginaryI]\ sin\ k\ \[Theta])\)\)\)\)}]],
  "  ",
  "\n\nwhich is the single-valued kth power of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " that we discussed in Section 1.5."
}], "Text"],

Cell[TextData[{
  StyleBox["Case (ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(c = 1\/k\)]],
  "  where k is an integer and  ",
  Cell[BoxData[
      \(z = 
        r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\) \[NotEqual] 0\)]],
  ",  then\n\n",
  StyleBox["(5-23)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      RowBox[{\(1\/k\ log \((z)\)\), " ", "=", " ", 
        RowBox[{"{", 
          
          RowBox[{\(1\/k\ ln \((r)\) + \(\[ImaginaryI]\ \((\[Theta]\  + \ 2\ \
\[Pi]\ n)\)\)\/k\), ":", "  ", 
            RowBox[{"n", "   ", 
              StyleBox["is",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["an",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["integer",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}], "}"}]}]]],
  ".  \n\nHence Equation ",
  StyleBox["(5-21)",
    FontColor->RGBColor[0, 0, 1]],
  " becomes  \n\n\t\t\t",
  Cell[BoxData[
      \(z\^\(1\/k\)\  = \ \(r\^\(1\/k\)\) \((cos\ \(\[Theta] + 2  n\ \
\[Pi]\)\/k\  + \ \[ImaginaryI]\ sin\ \(\[Theta] + 2  n\ \[Pi]\)\/k)\)\)]],
  "  for  ",
  Cell[BoxData[
      RowBox[{\(n = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(k - 1\)}]]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "When we again use the periodicity of the complex exponential function, \
Equation ",
  StyleBox["(5-23)",
    FontColor->RGBColor[0, 0, 1]],
  " gives k distance values corresponding to  ",
  Cell[BoxData[
      RowBox[{\(n = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(k - 1\)}]]],
  ".  Therefore, as Example 5.6 illustrated, the fractional power ",
  Cell[BoxData[
      \(z\^\(1\/k\)\)]],
  " is the multivalued ",
  Cell[BoxData[
      \(k\^th\)]],
  " root function.  Equation ",
  StyleBox["(5-23)",
    FontColor->RGBColor[0, 0, 1]],
  " ",
  "is easily verified by the computation  \n\n\t\t\t",
  Cell[BoxData[{
      \(z\^\(1\/k\)\  = \ \(exp[1\/k\ log \((z)\)]\  = \ 
          exp[1\/k\ log \((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\))\)]\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \(\(=\)\(\ \)\(exp[
          1\/k\ \((ln\ r\  + \ \ \[ImaginaryI]\ \((\[Theta] + 
                      2\ n\ \[Pi]\ )\))\)]\)\)\n\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \(\(=\)\(\ \)\(exp[
          ln\ r\^\(1\/k\)\  + \ \[ImaginaryI]\ \((\(\[Theta] + \(\(2\)\(\ \
\)\(n\)\(\ \)\(\[Pi]\)\(\ \)\)\)\/k)\)]\)\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \(\(=\)\(\ \)\(exp[ln\ \(\(r\^\(1\/k\)\)\^\ \)] 
          exp[\[ImaginaryI]\ \((\(\[Theta] + 2  n\ \[Pi]\)\/k)\)]\)\)\n\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \(\(=\)\(\ \)\(\(r\^\(1\/k\)\) \((cos\ \(\[Theta] + 2  \
n\ \[Pi]\)\/k\  + \ \[ImaginaryI]\ sin\ \(\[Theta] + 2  n\ \[Pi]\)\/k)\)\(\ \ \
\)\)\)\)}]],
  "   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Case (iii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If ",
  StyleBox["j",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["k",
    FontFamily->"Courier New"],
  " are positive integers that have no common factors and  ",
  Cell[BoxData[
      \(c = j\/k\)]],
  ",  then Equation ",
  StyleBox["(5-21)",
    FontColor->RGBColor[0, 0, 1]],
  " becomes  \n\n\t\t\t",
  Cell[BoxData[
      \(z\^\(j\/k\)\  = \ \(r\^\(j\/k\)\) \((cos\ \(\((\[Theta]\  + \ 2  n\ \
\[Pi]\ )\) j\)\/k\  + \ \[ImaginaryI]\ sin\ \(\((\[Theta]\  + \ 2  n\ \[Pi]\ \
)\) j\)\/k)\)\)]],
  "  for  ",
  Cell[BoxData[
      RowBox[{\(n = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(k - 1\)}]]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This is easy to establish.  If  ",
  Cell[BoxData[
      \(z = r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)]],
  "  then  \n\n\t\t\t",
  Cell[BoxData[{
      \(z\^\(j\/k\)\  = \ \(exp[j\/k\ log \((z)\)]\  = \ 
          exp[j\/k\ log \((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\))\)]\)\n\), "\n", 
      \(\ \ \ \ \ \ \ \(\(=\)\(\ \)\(exp[
          j\/k\ \((ln\ r\  + \ \ \[ImaginaryI]\ \((\[Theta] + 
                      2\ n\ \[Pi]\ )\))\)]\)\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \(\(=\)\(\ \)\(exp[
          ln\ r\^\(j\/k\)\  + \ \[ImaginaryI]\ \(\((\[Theta] + 2\ n\ \[Pi]\ )\
\) j\)\/k]\)\)\n\), "\n", 
      \(\ \ \ \ \ \ \ \(\(=\)\(\ \)\(exp[ln\ \(\(r\^\(j\/k\)\)\^\ \)] 
          exp[\[ImaginaryI]\ \(\((\[Theta] + 2\ n\ \[Pi]\ )\) j\)\/k]\)\)\
\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \(\(=\)\(\ \)\(\(r\^\(j\/k\)\) \((cos\ \(\((\[Theta] + \
2\ n\ \[Pi]\ )\) j\)\/k\  + \ \[ImaginaryI]\ sin\ \(\((\[Theta] + 2\ n\ \[Pi]\
\ )\) j\)\/k)\)\(\ \ \)\)\)\)}]],
  "  \n"
}], "Text"],

Cell[TextData[{
  StyleBox["Case (iv).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose ",
  StyleBox["c",
    FontFamily->"Courier New"],
  " is not a rational number, then there are infinitely many values for  ",
  Cell[BoxData[
      StyleBox[\(z\^c\),
        FontWeight->"Plain"]],
    FontWeight->"Bold"],
  ",  provided  ",
  Cell[BoxData[
      \(z = 
        r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\) \[NotEqual] 0\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 5.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The values of of  ",
  Cell[BoxData[
      \(2\^\(1\/9 + \[ImaginaryI]\/50\)\)]],
  "  are  \n\n\t\t\t",
  Cell[BoxData[{
      \(2\^\(1\/9 + \[ImaginaryI]\/50\)\ \  = \ \ exp[\((1\/9 + \[ImaginaryI]\
\/50)\) \((ln\ 2\  + \ \[ImaginaryI]\ 2  n\ \[Pi])\)]\), "\n", 
      \(\t\ \ \ \ \ \(\(=\)\(\ \)\(exp[\(ln\ 2\)\/9 - \(n\ \[Pi]\)\/25\  + \ \
\[ImaginaryI] \((\(ln\ 2\)\/50 + \(2\ n\ \[Pi]\)\/9)\)]\)\)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(exp[\(ln\ 2\)\/9] 
          exp[\(-\(\(n\ \[Pi]\)\/25\)\)] 
          exp[\[ImaginaryI] \((\(ln\ 2\)\/50 + \(2\ n\ \[Pi]\)\/9)\)]\)\)\), 
    "\n", 
      \(\t\ \ \ \ \ \(\(=\)\(\ \)\(\(2\^\(1\/9\)\) \
\(\[ExponentialE]\^\(-\(\(n\ \[Pi]\)\/25\)\)\)\ [
            cos \((\(ln\ 2\)\/50 + \(2\ n\ \[Pi]\)\/9)\) + \[ImaginaryI]\ sin \
\((\(ln\ 2\)\/50 + \(2\ n\ \[Pi]\)\/9)\)]\)\)\)}]],
  "  \n\nwhere ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is an integer.  The principal value of  ",
  Cell[BoxData[
      \(2\^\(1\/9 + \[ImaginaryI]\/50\)\)]],
  "  is  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(2\^\(1\/9 + \[ImaginaryI]\/50\)\ \  = \ \ \(2\^\(1\/9\)\) \(\
\[ExponentialE]\^\(-\(\(n\ \[Pi]\)\/25\)\)\)\ [
            cos \((\(ln\ 2\)\/50)\) + \[ImaginaryI]\ sin \((\(ln\ 2\)\/50)\)]\
\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\[TildeTilde]\)\(\ \ \
\)\(1.07995595696\  + 0.01497232767\ \[ImaginaryI]\)\)\)}]],
  "  \n\nFigure 5.6 shows the terms for this multivalued expression \
corresponding to  ",
  Cell[BoxData[
      RowBox[{\(n = \(-9\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(-8\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(-1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "8", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "9"}]]],
  ".  They exhibit a spiral pattern that is often present in complex powers."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Enter  ",
  Cell[BoxData[
      \(w\_0 = 2\^\(1/9\  + \ \[ImaginaryI]/50\)\)]],
  "  and find the principal value.  "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[w];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[e, pts, W];\)\ \), "\n", 
    \(\(W\  = \ 
        e\^\(\((1\/9 + \[ImaginaryI]\/50)\) Log[2]\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(w\_0\  = \ 
        2\^\(1/9\  + \ \[ImaginaryI]/50\);\)\ \), "\[IndentingNewLine]", 
    \(\(w\_1\  = \ \[ExponentialE]\^\(\((1\/9\  + \(\(\ \)\(\[ImaginaryI]\)\)\
\/50)\)\ Log[2]\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_0\) = \>\"", W];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_0\) = \>\"", 
        ComplexExpand[w\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_0\) = \>\"", \ 
        N[w\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", 
        w\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", 
        N[w\_1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \!\(w\_0\) = \!\(w\_1\) ? \>\"", 
        w\_0 \[Equal] w\_1];\)\ \), "\n", 
    \(\)}], "Input"],

Cell[TextData[{
  "\n",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Enter  ",
  Cell[BoxData[
      \(w\_0 = 2\^\(1/9\  + \ \[ImaginaryI]/50\)\)]],
  "  and find some of its values.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[w];\)\ \), "\[IndentingNewLine]", 
    \(\(w\_0 = \[ExponentialE]\^\(\((1\/9\  + \(\(\ \
\)\(\[ImaginaryI]\)\)\/50)\)\ \((Log[2] + 2  \[Pi]\ \[ImaginaryI]\ n)\)\);\)\ \
\), "\[IndentingNewLine]", 
    \(\(table = 
        Table[ComplexExpand[w\_0], {n, \(-5\), 5, 
            1}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Prepend[Append[
            table, "\<...\>"], "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(2\^\(1/9 + \[ImaginaryI]/50\)\) = \>\"", 
        w\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<        = \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<        = \>", 
        TableForm[table]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Remove[w];\)\ \), "\[IndentingNewLine]", 
    \(\(w\_0 = \[ExponentialE]\^\(\((1\/9\  + \(\(\ \
\)\(\[ImaginaryI]\)\)\/50)\)\ \((Log[2] + 2  \[Pi]\ \[ImaginaryI]\ n)\)\);\)\ \
\), "\[IndentingNewLine]", 
    \(\(table = 
        Table[N[w\_0], {n, \(-5\), 5, 1}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Prepend[Append[
            table, "\<...\>"], "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(2\^\(1/9 + \[ImaginaryI]/50\)\) = \>\"", 
        w\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<        = \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<        = \>", 
        TableForm[table]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some of the values of  ",
  Cell[BoxData[
      \(2\^\(1/9\  + \ \[ImaginaryI]/50\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(w = 0; \ Remove[w];\ \), "\[IndentingNewLine]", 
    \(\(w = \[ExponentialE]\^\(\((1\/9\  + \(\(\ \)\(\[ImaginaryI]\)\)\/50)\)\
\ \((Log[2] + 2  \[Pi]\ \[ImaginaryI]\ n)\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Table[ComplexExpand[w], {n, \(-9\), 18, 
            1}];\)\ \), "\[IndentingNewLine]", 
    \(\(table = 
        Prepend[Append[
            table, "\<...\>"], "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(pts = Table[{Re[w], Im[w]}, {n, \(-9\), 18, 1}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ListPlot[pts, PlotRange \[Rule] {{\(-2\), 3.35}, {\(-1.5\), 2.6}}, 
        Ticks \[Rule] {Range[\(-2\), 3, 1], Range[\(-2\), 3, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, AspectRatio \[Rule] 4.1\/5.35, 
        Prolog \[Rule] {PointSize[0.02], Red}];\)\ \), "\n", 
    \(\(Print[\*"\"\<Some of the values of \!\(2\^\(1/9\\\  + \\\ \
\[ImaginaryI]/50\)\)\>\""];\)\ \), "\n", 
    \(\(Print[NumberForm[N[table], 3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .76636 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.373832 0.186916 0.280374 0.186916 [
[0 .26787 -6 -9 ]
[0 .26787 6 0 ]
[.18692 .26787 -6 -9 ]
[.18692 .26787 6 0 ]
[.56075 .26787 -3 -9 ]
[.56075 .26787 3 0 ]
[.74766 .26787 -3 -9 ]
[.74766 .26787 3 0 ]
[.93458 .26787 -3 -9 ]
[.93458 .26787 3 0 ]
[1.025 .28037 0 -6.28125 ]
[1.025 .28037 10 6.28125 ]
[.36133 .09346 -12 -4.5 ]
[.36133 .09346 0 4.5 ]
[.36133 .46729 -6 -4.5 ]
[.36133 .46729 0 4.5 ]
[.36133 .65421 -6 -4.5 ]
[.36133 .65421 0 4.5 ]
[.37383 .79136 -5 0 ]
[.37383 .79136 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .76636 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .28037 m
0 .28662 L
s
[(-2)] 0 .26787 0 1 Mshowa
.18692 .28037 m
.18692 .28662 L
s
[(-1)] .18692 .26787 0 1 Mshowa
.56075 .28037 m
.56075 .28662 L
s
[(1)] .56075 .26787 0 1 Mshowa
.74766 .28037 m
.74766 .28662 L
s
[(2)] .74766 .26787 0 1 Mshowa
.93458 .28037 m
.93458 .28662 L
s
[(3)] .93458 .26787 0 1 Mshowa
0 .28037 m
1 .28037 L
s
gsave
1.025 .28037 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.37383 .09346 m
.38008 .09346 L
s
[(-1)] .36133 .09346 1 0 Mshowa
.37383 .46729 m
.38008 .46729 L
s
[(1)] .36133 .46729 1 0 Mshowa
.37383 .65421 m
.38008 .65421 L
s
[(2)] .36133 .65421 1 0 Mshowa
.37383 0 m
.37383 .76636 L
s
gsave
.37383 .79136 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .76636 L
0 .76636 L
closepath
clip
newpath
1 0 0 r
.02 w
.99933 .28905 Mdot
0 0 1 r
.79149 .64082 Mdot
1 0 0 r
.45167 .76065 Mdot
0 0 1 r
.15416 .64896 Mdot
1 0 0 r
.01648 .40486 Mdot
0 0 1 r
.06184 .1619 Mdot
1 0 0 r
.23022 .02347 Mdot
0 0 1 r
.42244 .0254 Mdot
1 0 0 r
.55121 .13568 Mdot
0 0 1 r
.57569 .28317 Mdot
1 0 0 r
.50862 .3967 Mdot
0 0 1 r
.39895 .43537 Mdot
1 0 0 r
.30294 .39932 Mdot
0 0 1 r
.25851 .32055 Mdot
1 0 0 r
.27315 .24214 Mdot
0 0 1 r
.32749 .19747 Mdot
1 0 0 r
.38952 .19809 Mdot
0 0 1 r
.43108 .23368 Mdot
1 0 0 r
.43898 .28128 Mdot
0 0 1 r
.41733 .31791 Mdot
1 0 0 r
.38194 .33039 Mdot
0 0 1 r
.35095 .31876 Mdot
1 0 0 r
.33661 .29334 Mdot
0 0 1 r
.34134 .26803 Mdot
1 0 0 r
.35887 .25362 Mdot
0 0 1 r
.37889 .25382 Mdot
1 0 0 r
.39231 .2653 Mdot
0 0 1 r
.39486 .28067 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 220.688},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000g2000`400?l00000o`00003oJ@3oool0
0`000000oooo0?ooo`2d0?ooo`00J@3oool00`000000oooo0?ooo`2d0?ooo`00J@3oool00`000000
oooo0?ooo`2d0?ooo`00J@3oool00`000000oooo0?ooo`2d0?ooo`00@P3oool30?l002@0oooo00<0
00000?ooo`3oool0]03oool00440oooo1@3o000S0?ooo`030000003oool0oooo00P0oooo0`000?nY
0?ooo`00@@3oool50?l002<0oooo00<000000?ooo`3oool01`3oool50000ojP0oooo00110?ooo`D0
o`008`3oool00`000000oooo0?ooo`070?ooo`D0003oZ03oool00480oooo0`3o000T0?ooo`030000
003oool0oooo00L0oooo1@000?nX0?ooo`00J@3oool00`000000oooo0?ooo`080?ooo`<0003oZ@3o
ool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0
oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<0
00000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?oo
o`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0
]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool0
06T0oooo00<000000?ooo`3oool0]03oool00600oooo1@0000040?ooo`030000003oool0oooo0;@0
oooo001R0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0]03oool00680oooo00<0
00000?ooo`3oool0103oool200000;D0oooo001J0?ooo`@00000103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0;@0oooo001R0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0]03oool00640oooo0P0000060?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000
003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0
oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0
oooo001Y0?ooo`030000003oool0oooo02X0oooo0`3o00270?ooo`00J@3oool00`000000oooo0?oo
o`0Y0?ooo`D0o`00QP3oool006T0oooo00<000000?ooo`3oool0:@3oool50?l008H0oooo001Y0?oo
o`030000003oool0oooo02T0oooo1@3o00260?ooo`00J@3oool00`000000oooo0?ooo`0Z0?ooo`<0
o`00Q`3oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03o
ool001H0oooo0`000?m@0?ooo`030000003oool0oooo0;@0oooo000E0?ooo`D0003oC`3oool00`00
0000oooo0?ooo`2d0?ooo`005@3oool50000odl0oooo00<000000?ooo`3oool0]03oool001D0oooo
1@000?m?0?ooo`030000003oool0oooo0;@0oooo000F0?ooo`<0003oD03oool00`000000oooo0?oo
o`2d0?ooo`00J@3oool00`000000oooo0?ooo`2d0?ooo`00J@3oool00`000000oooo0?ooo`2d0?oo
o`00J@3oool00`000000oooo0?ooo`2d0?ooo`00J@3oool00`000000oooo0?ooo`2d0?ooo`00J@3o
ool00`000000oooo0?ooo`2d0?ooo`00G03oool30000o`X0oooo00<000000?ooo`3oool00`3o002a
0?ooo`00F`3oool50000o`T0oooo00<000000?ooo`3o0000103o002`0?ooo`00F`3oool50000o`T0
oooo00<000000?ooo`3o0000103o002`0?ooo`00F`3oool50000o`T0oooo00<000000?ooo`3o0000
103o002`0?ooo`00G03oool30000o`X0oooo00<000000?ooo`3oool00`3o002a0?ooo`00J@3oool0
0`000000oooo0?ooo`2d0?ooo`00J@3oool00`000000oooo0?ooo`2d0?ooo`00J@3oool00`000000
oooo0?ooo`2d0?ooo`00J@3oool00`000000oooo0?ooo`2d0?ooo`00J@3oool00`000000oooo0?oo
o`0;0?ooo`<0003oYP3oool006T0oooo00<000000?ooo`3oool02P3oool50000ojD0oooo001=0?oo
o`<0o`006@3oool00`000000oooo0?ooo`0:0?ooo`D0003oY@3oool000P0oooo1000000]0?ooo`D0
00003P3oool50?l001P0oooo00<000000?ooo`3oool02P3oool50000oad0oooo1@00000/0?ooo`@0
0000;@3oool2000002@0oooo00080?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
3P3oool50?l001P0oooo00<000000?ooo`3oool02`3oool30000ob00oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0]0?ooo`040000003oool0oooo000002<0oooo00090?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool03P3oool50?l001<0oooo0`3o00020?ooo`<0003o
;P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
8P3oool00080oooo100000040?ooo`030000003oool0oooo02H0oooo100000040?ooo`030000003o
ool0oooo00l0oooo0`3o000C0?ooo`D0o`001@000?l]0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0Q0?ooo`00203oool010000000oooo0?ooo`00
000_0?ooo`030000003oool0oooo02D0oooo1@3o00050000obd0oooo00<000000?ooo`3oool0;03o
ool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000002<0oooo00090?ooo`800000
;`3oool2000002L0oooo1@3o00040000o`<0o`00:P3oool2000002l0oooo0P00000^0?ooo`800000
903oool005l0oooo0`000?l20?ooo`<0o`000P3oool20000o`D0o`00/03oool005h0oooo1@000?l6
0?ooo`030000003oool0o`0000@0o`00/03oool005h0oooo1@000?l60?ooo`030000003oool0o`00
00@0o`00/03oool005h0oooo1@000?l60?ooo`040000003oool0oooo0?l000<0003o2@3oool30?l0
0:@0oooo001O0?ooo`<0003o1`3oool00`000000oooo0?ooo`050000o`L0oooo1@3o000O0?ooo`<0
003oMP3oool2000000030?ooo`000000000000H0oooo00070?ooofD000001@000?l7000000D0o`00
7P0000050000ofh00000203oool00`000000oooo000000070?ooo`001`3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool01@000?l70?ooo`D0o`007@3o
ool00`000000003o0000o`030000ob/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0=0?ooo`<0o`002@3oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo02<0oooo0`3o00080?ooo`040000003oool0oooo0?ooo`<0003o2@3o
ool30?l001h0oooo00<000000000o`000?l00`000?l[0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0303oool50?l000H0oooo0P0000000`3oool00000000000060?ooo`00G@3oool5
0?l000L0oooo00<000000?ooo`3oool0<03oool30000of/0oooo1@3o000A0?ooo`00G@3oool50?l0
00L0oooo00<000000?ooo`3oool0WP3oool50?l00140oooo001M0?ooo`D0o`001`3oool00`000000
oooo0?ooo`2O0?ooo`<0o`004P3oool005h0oooo0`3o00080?ooo`030000003oool0oooo0;@0oooo
001Y0?ooo`030000003oool0oooo0;@0oooo001R0?ooo`<0003o103oool00`000000oooo0?ooo`07
0?ooo`<0003oZP3oool004T0oooo0`000?lE0?ooo`D0003o0`3oool00`000000oooo0?ooo`060?oo
o`D0003oZ@3oool004P0oooo1@000?lD0?ooo`D0003o0`3oool00`000000oooo0?ooo`060?ooo`D0
003oZ@3oool004P0oooo1@000?lD0?ooo`D0003o0`3oool010000000o`000?l0003o00050?ooo`D0
003oZ@3oool004P0oooo1@000?lE0?ooo`<0003o103oool50?l000D0oooo0`000?nZ0?ooo`00B@3o
ool30000oad0oooo1@3o002b0?ooo`00J@3oool50?l00;80oooo001Y0?ooo`040000003o0000o`00
0?l00;<0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0
oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y
0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`03
0000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003o
ool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo
0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo
001E0?ooo`<0o`004@3oool00`000000oooo0?ooo`0O0?ooo`<0o`00TP3oool005@0oooo1@3o000@
0?ooo`030000003oool0oooo01h0oooo1@3o002A0?ooo`002P3oool30?l004L0oooo1@3o000@0?oo
o`030000003oool0oooo01h0oooo1@3o002A0?ooo`002@3oool50?l004H0oooo1@3o000@0?ooo`03
0000003oool0oooo01h0oooo1@3o002A0?ooo`002@3oool50?l004L0oooo0`3o000A0?ooo`030000
003oool0oooo01l0oooo0`3o002B0?ooo`002@3oool50?l005/0oooo00<000000?ooo`3oool0]03o
ool000X0oooo0`3o001L0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo
0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo
001Y0?ooo`030000003oool0oooo0080oooo0`000?n_0?ooo`00J@3oool010000000oooo0?ooo`3o
ool50000ojh0oooo001Y0?ooo`040000003oool0oooo0?ooo`D0003o[P3oool006T0oooo00@00000
0?ooo`3oool0oooo1@000?n^0?ooo`00J@3oool00`000000oooo0?ooo`020?ooo`<0003o[`3oool0
06T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo
00<000000?ooo`3oool0]03oool00600oooo1@0000040?ooo`030000003oool0oooo0;@0oooo001R
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0]03oool00680oooo00<000000?oo
o`3oool0103oool200000;D0oooo001R0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0]03oool00680oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2d0?ooo`00H@3o
ool2000000H0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool0
06T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo
00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<00000
0?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3o
ool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03o
ool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0
oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<0
00000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?oo
o`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0
]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool0
06T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo
00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<00000
0?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3o
ool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03o
ool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0
oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<0
00000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?oo
o`3oool0]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0
]03oool006T0oooo00<000000?ooo`3oool0]03oool006T0oooo00<000000?ooo`3oool0J@3oool3
0000odP0oooo001Y0?ooo`030000003oool0oooo06P0oooo1@000?m70?ooo`00;P3oool30000ocP0
oooo00<000000?ooo`3oool0J03oool50000odL0oooo000]0?ooo`D0003o;P3oool4000000D0oooo
00<000000?ooo`3oool0J03oool50000odL0oooo000]0?ooo`D0003o;P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo06T0oooo0`000?m80?ooo`00;@3oool50000obl0oooo00<00000
0?ooo`3oool01@3oool200000;D0oooo000^0?ooo`<0003o<@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0;@0oooo001P0?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0]03oool00640oooo0P0000060?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000
003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0
oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0
oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y
0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`03
0000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003o
ool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo
0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo
001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?oo
o`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000
003oool0oooo0;@0oooo001Y0?ooo`030000003oool0oooo0;@0oooo001Y0?ooo`030000003oool0
oooo0100oooo0`3o002Q0?ooo`00J@3oool00`000000oooo0?ooo`0?0?ooo`D0o`00X03oool006T0
oooo00<000000?ooo`3oool03`3oool50?l00:00oooo001Y0?ooo`030000003oool0oooo00l0oooo
1@3o002P0?ooo`00O03oool30?l00:40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo001W0?ooo`800000]`3oool006P0oooo00<000000?ooo`3oool0]@3oool006T0oooo00<00000
0?ooo`3oool0]03oool006P0oooo00<000000?ooo`000000]@3oool006L0oooo00@000000?ooo`3o
ool00000]@3oool006H0oooo0`0000000`3oool000000000002d0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 287}, {219.688, 0}} -> {-2, -1, 0, 0}}],
  StyleBox["\n\tFigure 5.6",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Some of the \"spiral pattern\" of values for  ",
  Cell[BoxData[
      \(2\^\(1/9\  + \ \[ImaginaryI]/50\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["The Rules for exponents.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  \n\n\tSome of the rules for exponents carry over from the real case.  In \
the exercises we ask you to show that if ",
  StyleBox["c",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["d",
    FontFamily->"Courier New"],
  " are complex numbers and  ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ",  then  \n \t\t\t\n",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[\((5 - 24)\),
              FontFamily->"Times New Roman",
              FontColor->RGBColor[0, 0, 0.996109]], 
            "                       ", \(z\^\(-c\)\)}], "=", \(1\/z\^c\)}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{
            StyleBox[\((5 - 25)\),
              FontFamily->"Times New Roman",
              FontColor->RGBColor[0, 0, 0.996109]], 
            "                       ", \(z\^c\), \(z\^d\)}], 
          "=", \(z\^\(c + d\)\)}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{
            StyleBox[\((5 - 26)\),
              FontFamily->"Times New Roman",
              FontColor->RGBColor[0, 0, 0.996109]], 
            "                       ", \(z\^c\/z\^d\)}], 
          "=", \(z\^\(c - d\)\)}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{
            StyleBox[\((5 - 27)\),
              FontFamily->"Times New Roman",
              FontColor->RGBColor[0, 0, 0.996109]], 
            "                       ", \(\((z\^c)\)\^n\)}], 
          "=", \(z\^\(c\ n\)\)}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  "    \n\nwhere ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is an integer.  \n\n\n\tThe following example shows that Identity ",
  StyleBox["(5-21)",
    FontColor->RGBColor[0, 0, 1]],
  " does not hold if n is replaced with an arbitrary complex value."
}], "Text"],

Cell[TextData[{
  "\n",
  StyleBox["Example 5.9.  (a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  Cell[BoxData[
      RowBox[{\(\((\[ImaginaryI]\^2)\)\^\[ImaginaryI]\), "  ", "=", "  ", 
        RowBox[{\(exp[\[ImaginaryI]\ log \((\(-1\))\)]\), "  ", "=", "  ", 
          RowBox[{"{", 
            
            RowBox[{\(\[ExponentialE]\^\(\(-\((1 + 2  n)\)\) \[Pi]\)\), ":", 
              "  ", 
              RowBox[{
                StyleBox["n",
                  FontFamily->"Courier New"], 
                StyleBox["  ",
                  FontFamily->"Courier New"], 
                StyleBox["is",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["an",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["integer",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}], "}"}]}]}]]],
  ",  \n\nand  ",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  Cell[BoxData[
      \(\[ImaginaryI]\^\(2  \[ImaginaryI]\)\)]],
  Cell[BoxData[
      RowBox[{"=", "  ", 
        RowBox[{\(exp[2  \[ImaginaryI]\ log\ \[ImaginaryI]]\), "  ", "=", 
          "  ", 
          RowBox[{"{", 
            
            RowBox[{\(\[ExponentialE]\^\(\(-\((1 + 4  n)\)\) \[Pi]\)\), ":", 
              "  ", 
              RowBox[{
                StyleBox["n",
                  FontFamily->"Courier New"], 
                StyleBox["  ",
                  FontFamily->"Courier New"], 
                StyleBox["is",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["an",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["integer",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}], "}"}]}]}]]],
  ".  \n\nSince these sets of solutions are not equal, Identity ",
  StyleBox["(5-21)",
    FontColor->RGBColor[0, 0, 1]],
  "  does not always hold."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter  ",
  Cell[BoxData[
      RowBox[{\(w\_1\), "=", 
        RowBox[{
          
          RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ Log[\[ImaginaryI]\^2]\)\
\), "   ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], "   ", \(w\_2\)}], 
          "=", \(\[ExponentialE]\^\(2  \[ImaginaryI]\ \
Log[\[ImaginaryI]]\)\)}]}]]],
  "  and find the principal values."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[t, w];\)\ \), "\n", 
    \(\(w\_1\  = \ \[ExponentialE]\^\(\[ImaginaryI]\ Log[\[ImaginaryI]\^2]\);\
\)\ \), "\n", 
    \(\(w\_2\  = \ \[ExponentialE]\^\(2  \[ImaginaryI]\ Log[\[ImaginaryI]]\);\
\)\ \), "\n", 
    \(\(w\_3\  = 
        N[\[ExponentialE]\^\(\[ImaginaryI]\ Log[\[ImaginaryI]\^2]\)];\)\ \), \
"\n", 
    \(\(w\_4\  = \ 
        N[\[ExponentialE]\^\(2  \[ImaginaryI]\ Log[\[ImaginaryI]]\)];\)\ \), \
"\n", 
    \(\(Print[\((\[ImaginaryI]\^2)\)\^\[ImaginaryI], "\< = \>", 
        w\_1];\)\ \), "\n", 
    \(\(Print["\<  \>", \[ImaginaryI]\^\(2  \[ImaginaryI]\), "\< = \>", 
        w\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\((\[ImaginaryI]\^2)\)\^\[ImaginaryI], "\< = \>", 
        w\_3];\)\ \), "\n", 
    \(\(Print["\<  \>", \[ImaginaryI]\^\(2  \[ImaginaryI]\), "\< = \>", 
        w\_4];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Are the principal values the same ? \>", \ \ w\_1 == 
          w\_2];\)\)}], "Input"],

Cell["Second, find the other values in the solution sets.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(t\_1\  = \ 
        Table[\[ExponentialE]\^\(\[ImaginaryI]\ \((Log[\[ImaginaryI]\^2] + 2  \
\[Pi]\ \[ImaginaryI]\ n)\)\), {n, \(-4\), 4, 1}];\)\ \), "\n", 
    \(\(t\_2\  = \ 
        Table[\[ExponentialE]\^\(2  \[ImaginaryI] \((\ Log[\[ImaginaryI]]\ \  \
+ 2  \[Pi]\ \[ImaginaryI]\ n)\)\), {n, \(-4\), 4, 
            1}];\)\ \), "\[IndentingNewLine]", 
    \(\(set\_1\  = \ 
        Append[Prepend[
            t\_1, "\<...\>"], "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(set\_2\  = \ 
        Append[Prepend[t\_2, "\<...\>"], "\<...\>"];\)\ \), "\n", 
    \(\(Print[\((\[ImaginaryI]\^2)\)\^\[ImaginaryI], "\< = \>", 
        set\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<  \>", \[ImaginaryI]\^\(2  \[ImaginaryI]\), "\< = \>", 
        set\_2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Caveat.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  The two solution sets are different.  Therefore, in general ,  ",
  Cell[BoxData[
      \(\((z\^a)\)\^b \[NotEqual] z\^\(a\ b\)\)]],
  ".  \n\nThe following computation is also interesting."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(w\_1 = \ \[ExponentialE]\^\(\[ImaginaryI]\ \((Log[\[ImaginaryI]\^2] + \
2  \[Pi]\ \[ImaginaryI]\ n)\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", 
        w\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(w\_1 = \ 
        Simplify[\[ExponentialE]\^\(\[ImaginaryI]\ \((Log[\[ImaginaryI]\^2] + \
2  \[Pi]\ \[ImaginaryI]\ n)\)\), 
          Element[n, Integers]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", 
        w\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(w\_2 = \ \[ExponentialE]\^\(2  \[ImaginaryI] \((\ Log[\[ImaginaryI]]\ \
\  + 2  \[Pi]\ \[ImaginaryI]\ n)\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", 
        w\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(w\_2 = \ 
        Simplify[\[ExponentialE]\^\(2  \[ImaginaryI] \((\ Log[\[ImaginaryI]]\ \
\  + 2  \[Pi]\ \[ImaginaryI]\ n)\)\), 
          Element[n, Integers]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", 
        w\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \!\(w\_1\) = \!\(w\_2\) ? \>\""];\)\ \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(eqn = w\_1\  == \ w\_2;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Does \>", eqn, "\< ? \>", 
        w\_1\  === \ w\_2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Since ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is an arbitrary integer, the last equation does not hold true, hence ",
  Cell[BoxData[
      \(w\_1\  \[NotEqual] \ w\_2\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "    We can compute the derivative of the principal branch of ",
  Cell[BoxData[
      \(z\^c\)]],
  ", which is the function  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\  = \ exp[c\ Log\ z]\)]],
  ".   By the chain rule,  \n\n",
  StyleBox["(5-28)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f' \((z)\) = exp[c\ Log\ z]\)]],
  ".  \n\n    If we restrict ",
  Cell[BoxData[
      \(z\^c\)]],
  " to the principal branch,  ",
  Cell[BoxData[
      \(z\^c\  = \ exp[c\ Log\ z]\)]],
  ", then Equation ",
  StyleBox["(5-28)",
    FontColor->RGBColor[0, 0, 1]],
  " can be written in the familiar form that you learned in calculus.  That \
is, for ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  " and ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " not a negative real number, \n\n\t\t\t",
  Cell[BoxData[
      \(\(d\/dz\) z\^c = \(\(z\^c\) c\/z = c\ z\^\(c - 1\)\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[z_]\  = \ Exp[c\ Log[z]];\)\ \), "\n", 
    \(\(g[z_]\  = \ c\ Log[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = \>", f[z]\ ];\)\), "\n", 
    \(\(Print["\< f[z] = \>", \ Exp["\<c Log[z]\>"]\ ];\)\), "\n", 
    \(\(Print["\<\>"];\)\), "\n", 
    \(\(Print["\<f'[z] = \>", Exp["\<c Log[z]\>"], \(g'\)[z]\ ];\)\), "\n", 
    \(\(Print["\<f'[z] = \>", Exp[c\ Log[z]], \(g'\)[z]\ ];\)\), "\n", 
    \(\(Print["\<f'[z] = \>", Exp[c\ Log[z]] \(g'\)[z]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "    We can use Identity ",
  StyleBox["(5-21)",
    FontColor->RGBColor[0, 0, 1]],
  " to define the exponential function with base ",
  StyleBox["b",
    FontFamily->"Courier New"],
  ", where ",
  Cell[BoxData[
      \(b \[NotEqual] 0\)]],
  " is a complex number: \n\n\t\t",
  Cell[BoxData[
      \(b\^z\ \  = \ \ exp[z\ log \((b)\)]\)]],
  ".  \n\n    If we specify a branch of the logarithm, then ",
  Cell[BoxData[
      \(b\^z\)]],
  " will be single-valued and we can use the rules of differentiation to show \
that the resulting branch of ",
  Cell[BoxData[
      \(b\^z\)]],
  " is an analytic function.  The derivative of ",
  Cell[BoxData[
      \(b\^z\)]],
  " is then given by the familiar rule  \n\n",
  StyleBox["(5-29)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\(d\/dz\) b\^z\  = \ \(b\^z\) \(log\_\[Alpha]\) \((b)\)\)]],
  "\n\nwhere ",
  Cell[BoxData[
      \(\(log\_\[Alpha]\) \((z)\)\)]],
  " is any branch of the logarithm whose branch cut does not include the \
point ",
  Cell[BoxData[
      \(z = b\)]],
  "."
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Exponential Function",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ExponentialFunBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Logarithms",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/LogarithmFunBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 418191, 12385}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 112, 2, 33, "Text"],
Cell[2217, 66, 496, 14, 52, "Text"],
Cell[2716, 82, 3326, 95, 71, "Text",
  Evaluatable->False],
Cell[6045, 179, 597, 18, 52, "Text",
  Evaluatable->False],
Cell[6645, 199, 533, 21, 71, "Text",
  Evaluatable->False],
Cell[7181, 222, 503, 17, 52, "Text",
  Evaluatable->False],
Cell[7687, 241, 304, 13, 33, "Text",
  Evaluatable->False],
Cell[7994, 256, 4694, 126, 146, "Text",
  Evaluatable->False],
Cell[12691, 384, 455, 19, 37, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[13171, 407, 111, 2, 33, "Text"],
Cell[13285, 411, 167, 8, 33, "Text"],
Cell[13455, 421, 2565, 48, 554, "Input"]
}, Closed]],
Cell[16035, 472, 956, 35, 125, "Text",
  Evaluatable->False],
Cell[16994, 509, 508, 21, 33, "Text",
  Evaluatable->False],
Cell[17505, 532, 1878, 51, 121, "Text"],
Cell[19386, 585, 1633, 38, 379, "Text"],

Cell[CellGroupData[{
Cell[21044, 627, 115, 2, 33, "Text"],
Cell[21162, 631, 283, 11, 33, "Text"],
Cell[21448, 644, 1587, 33, 430, "Input"],
Cell[23038, 679, 183, 6, 71, "Text"],
Cell[23224, 687, 1592, 33, 432, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[24853, 725, 115, 2, 30, "Text"],
Cell[24971, 729, 260, 10, 33, "Text",
  Evaluatable->False],
Cell[25234, 741, 1879, 39, 412, "Input"],
Cell[27116, 782, 481, 9, 131, "Input"],
Cell[27600, 793, 1738, 35, 482, "Input"],
Cell[29341, 830, 1769, 30, 220, "Input"],
Cell[31113, 862, 1009, 22, 270, "Input"],
Cell[32125, 886, 803, 15, 206, "Input"],
Cell[32931, 903, 551, 11, 90, "Input"],
Cell[33485, 916, 1403, 27, 358, "Input"]
}, Closed]],
Cell[34903, 946, 326711, 9897, 323, "Text"],
Cell[361617, 10845, 305, 11, 71, "Text",
  Evaluatable->False],
Cell[361925, 10858, 2269, 65, 71, "Text",
  Evaluatable->False],
Cell[364197, 10925, 1618, 41, 375, "Text"],
Cell[365818, 10968, 3699, 107, 160, "Text",
  Evaluatable->False],
Cell[369520, 11077, 2634, 70, 291, "Text",
  Evaluatable->False],
Cell[372157, 11149, 1826, 59, 82, "Text",
  Evaluatable->False],
Cell[373986, 11210, 1046, 22, 294, "Text"],
Cell[375035, 11234, 525, 19, 33, "Text",
  Evaluatable->False],
Cell[375563, 11255, 4547, 123, 328, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[380135, 11382, 111, 2, 33, "Text"],
Cell[380249, 11386, 226, 8, 33, "Text"],
Cell[380478, 11396, 1133, 23, 326, "Input"],
Cell[381614, 11421, 281, 11, 52, "Text",
  Evaluatable->False],
Cell[381898, 11434, 748, 16, 180, "Input"],
Cell[382649, 11452, 723, 15, 180, "Input"],
Cell[383375, 11469, 198, 8, 33, "Text"],
Cell[383576, 11479, 1081, 19, 254, "Input"]
}, Closed]],
Cell[384672, 11501, 15109, 360, 256, "Text"],
Cell[399784, 11863, 4101, 118, 327, "Text"],
Cell[403888, 11983, 4838, 126, 128, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[408751, 12113, 111, 2, 33, "Text"],
Cell[408865, 12117, 477, 15, 33, "Text",
  Evaluatable->False],
Cell[409345, 12134, 1067, 23, 270, "Input"],
Cell[410415, 12159, 115, 2, 33, "Text",
  Evaluatable->False],
Cell[410533, 12163, 877, 18, 181, "Input"],
Cell[411413, 12183, 352, 10, 71, "Text",
  Evaluatable->False],
Cell[411768, 12195, 1463, 28, 319, "Input"],
Cell[413234, 12225, 226, 8, 33, "Text"]
}, Closed]],
Cell[413475, 12236, 948, 33, 204, "Text"],

Cell[CellGroupData[{
Cell[414448, 12273, 101, 2, 33, "Text"],
Cell[414552, 12277, 504, 8, 170, "Input"]
}, Closed]],
Cell[415071, 12288, 1096, 37, 204, "Text"],
Cell[416170, 12327, 290, 7, 33, "Text"],
Cell[416463, 12336, 292, 7, 33, "Text"],
Cell[416758, 12345, 288, 7, 33, "Text"],
Cell[417049, 12354, 257, 5, 33, "Text"],
Cell[417309, 12361, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

