(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    452063,      11365]*)
(*NotebookOutlinePosition[    452877,      11395]*)
(*  CellTagsIndexPosition[    452799,      11389]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["5.4  Trigonometric and Hyperbolic Functions",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tBased on the success we had in using power series to define the complex \
exponential, we have reason to believe this approach will be fruitful for \
other elementary functions as well. The power series expansions for the \
real-valued sine and cosine functions are \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(sin \((x)\)\), " ", "=", " ", 
        StyleBox[\(\[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\ x\^\(2  n \
+ 1\)\)\/\(\((2  n + 1)\)!\)\),
          FontSize->12]}]]],
  ",    and  \n\t\t   \n\t\t\t",
  Cell[BoxData[
      \(cos \((x)\) = \[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\ x\^\(2\
\ n\)\)\/\(\((2\ n)\)!\)\)]],
  "\n\nThus, it is natural to make the following definitions."
}], "Text"],

Cell[TextData[{
  " ",
  StyleBox["Definition 5.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   The series for  ",
  StyleBox[ButtonBox["Sine",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Sine.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " and ",
  StyleBox[ButtonBox["Cosine",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Cosine.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " are ",
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 1]],
  "\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(sin \((z)\)\), " ", "=", " ", 
        StyleBox[\(\[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\ z\^\(2  n \
+ 1\)\)\/\(\((2  n\  + \ 1)\)!\)\),
          FontSize->12]}]]],
  ",    and  \n\t\t   \n\t\t\t",
  Cell[BoxData[
      \(cos \((z)\) = \[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\ z\^\(2\
\ n\)\)\/\(\((2\ n)\)!\)\)]],
  "\n\n\tClearly, these definitions agree with their real counterparts when z \
is real.  Additionally, it is easy to show that ",
  Cell[BoxData[
      RowBox[{"cos", \((z)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "sin", \((z)\)}]]],
  " are entire functions.  (We leave the proof as an exercise.)"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Exploration (i).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Investigate the series ",
  Cell[BoxData[
      RowBox[{\(sin \((z)\)\), " ", "=", " ", 
        StyleBox[\(\[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\ z\^\(2  n \
+ 1\)\)\/\(\((2  n + 1)\)!\)\),
          FontSize->12]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Consider  sin(z) and use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find a Taylor polynomial expanded about z = 0, the remainder is \
expressed in the Big \"O\" notation."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[b, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[k, n, sin, S, S13];\)\ \), "\n", 
    \(\(sin[z_]\  = \ Series[Sin[z], \ {z, 0, 11}];\)\ \), "\n", 
    \(\(Print["\<Sin[z] = \>", sin[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Sin[z] = \>", 
        Normal[sin[z]], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Use the general term in the series for  sin(z)  and sum the infinite \
series.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(b\_n_\  = \ \((\(-1\))\)\^n\/\(\((2  n + 1)\)!\);\)\ \), "\n", 
    \(\(S13\  = \ \[Sum]\+\(n = 0\)\%6\(\((\(-1\))\)\^n\ z\^\(2  n + \
1\)\)\/\(\((2  n + 1)\)!\);\)\ \), "\n", 
    \(\(S\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\ z\^\(2  n + \
1\)\)\/\(\((2  n + 1)\)!\);\)\ \), "\n", 
    \(\(Print[\*"\"\<    \!\(b\_n\) = \>\"", b\_n];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_13\)[z] = \!\(\[Sum]\+\(n = \
0\)\%6\)\!\(\(\(\((\(-1\))\)\^n\) z\^\(2  n + 1\)\)\/\(\((2  n + \
1)\)!\)\)\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_13\)[z] = \>\"", S13];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_\[Infinity]\)[z] = \>\"", 
        S13, "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(S\_\[Infinity]\)[z] =  \!\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\)\!\(\(\(\((\(-1\))\)\^n\) z\^\(2  n + 1\)\)\/\(\((2  n + 1)\)!\)\
\)\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(S\_\[Infinity]\)[z] = \>\"", S];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(S\_\[Infinity]\)[z] = \>\"", 
        PowerExpand[S]];\)\ \)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some partial sums for sin(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, m, n, s, z];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = Sin[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(For\ [m = 1, 
        m \[LessEqual] 
          3, \(m++\), \[IndentingNewLine]s[
            z_] = \[Sum]\+\(n = 0\)\%m\(\((\(-1\))\)\^n\ z\^\(2  n + \
1\)\)\/\(\((2  n + 1)\)!\); \ \[IndentingNewLine]CartesianMap[
          s, {\(-\[Pi]\)\/2, \[Pi]\/2, \[Pi]\/16}, {\(-1\), 1, 0.25}, 
          PlotRange \[Rule] {{\(-1.7\), 1.7}, {\(-1.2\), 1.2}}, 
          AspectRatio \[Rule] 1.2\/1.7, 
          Ticks \[Rule] {Range[\(-2\), 2, 1], Range[\(-2\), 2, 1]}, 
          AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {DarkGreen, 
              Green}]; \ \ \[IndentingNewLine]Print["\<w = s[z,\>", 
          2  m + 1, "\<] = \>", s[z]];\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        f, {\(-\[Pi]\)\/2, \[Pi]\/2, \[Pi]\/16}, {\(-1\), 1, 0.25}, 
        PlotRange \[Rule] {{\(-1.7\), 1.7}, {\(-1.2\), 1.2}}, 
        AspectRatio \[Rule] 1.2\/1.7, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Magenta, Red}];\)\ \), "\n", 
    \(\(Print["\<  The mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Exploration (ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Investigate the series ",
  Cell[BoxData[
      \(cos \((z)\) = \[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\ z\^\(2\
\ n\)\)\/\(\((2\ n)\)!\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Consider  cos(z) and use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find a Taylor polynomial expanded about z = 0, the remainder is \
expressed in the Big \"O\" notation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[a, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[cos, k, n, S, S12];\)\ \), "\n", 
    \(\(cos[z_]\  = \ Series[Cos[z], \ {z, 0, 12}];\)\ \), "\n", 
    \(\(Print["\<Cos[z] = \>", cos[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Cos[z] = \>", 
        Normal[cos[z]], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Use the general term in the series for  cos(z)  and sum the infinite \
series.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(a\_n_\  = \ \((\(-1\))\)\^n\/\(\((2  n)\)!\);\)\ \), "\n", 
    \(\(S12 = \[Sum]\+\(n = 0\)\%6\ \(\((\(-1\))\)\^n\ z\^\(2\ n\)\)\/\(\((2\ \
n)\)!\);\)\ \), "\n", 
    \(\(S = \[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\ z\^\(2\ \
n\)\)\/\(\((2\ n)\)!\);\)\ \), "\n", 
    \(\(Print[\*"\"\<    \!\(a\_n\) = \>\"", a\_n];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_12\)[z] = \!\(\[Sum]\+\(n = 0\)\%6\) \
\!\(\(\(\((\(-1\))\)\^n\) z\^\(2  n\)\)\/\(\((2  n)\)!\)\)\>\""];\)\ \), "\n\
", 
    \(\(Print[\*"\"\<\!\(S\_12\)[z] = \>\"", S12];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_\[Infinity]\)[z] = \>\"", 
        S12, "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(S\_\[Infinity]\)[z] = \!\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\)\!\(\(\(\((\(-1\))\)\^n\) z\^\(2  n\)\)\/\(\((2  \
n)\)!\)\)\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(S\_\[Infinity]\)[z] = \>\"", S];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(S\_\[Infinity]\)[z] = \>\"", 
        PowerExpand[S]];\)\ \)}], "Input"],

Cell[TextData[{
  "\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some partial sums for cos(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, m, n, s, z];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = Cos[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(For\ [m = 2, 
        m \[LessEqual] 
          5, \(m++\), \[IndentingNewLine]s[
            z_] = \[Sum]\+\(n = 0\)\%m\ \(\((\(-1\))\)\^n\ z\^\(2\ \
n\)\)\/\(\((2\ n)\)!\); \ \[IndentingNewLine]CartesianMap[
          s, {0, \[Pi], \[Pi]\/16}, {\(-1\), 1, 0.25}, 
          PlotRange \[Rule] {{\(-1.7\), 1.7}, {\(-1.2\), 1.2}}, 
          AspectRatio \[Rule] 1.2\/1.7, 
          Ticks \[Rule] {Range[\(-2\), 2, 1], Range[\(-2\), 2, 1]}, 
          AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Blue, 
              Cyan}]; \ \ \[IndentingNewLine]Print["\<w = s[z,\>", 
          2  m, "\<] = \>", s[z]];\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[f, {0, \[Pi], \[Pi]\/16}, {\(-1\), 1, 0.25}, 
        PlotRange \[Rule] {{\(-1.7\), 1.7}, {\(-1.2\), 1.2}}, 
        AspectRatio \[Rule] 1.2\/1.7, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Magenta, Red}];\)\ \), "\n", 
    \(\(Print["\<  The mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell["\<\
\tWith these definitions in place, it is now easy to create the other complex \
trigonometric functions, provided the denominators in the following \
expressions do not equal zero.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Definition 5.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   ",
  Cell[BoxData[
      \(tan\ z\  = \ \(sin\ z\)\/\(cos\ z\)\)]],
  ",  ",
  Cell[BoxData[
      \(cot\ z\  = \ \(cos\ z\)\/\(sin\ z\)\)]],
  ",  ",
  Cell[BoxData[
      \(sec\ z\  = \ 1\/\(cos\ z\)\)]],
  ",  and  ",
  Cell[BoxData[
      \(csc\ z\  = \ 1\/\(sin\ z\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for Definition 5.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Tan[z] \[Equal] Sin[z]\/Cos[z]\)], "Input"],

Cell[BoxData[
    \(Cot[z] \[Equal] Cos[z]\/Sin[z]\)], "Input"],

Cell[BoxData[
    \(Sec[z] \[Equal] 1\/Cos[z]\)], "Input"],

Cell[BoxData[
    \(Csc[z] \[Equal] 1\/Sin[z]\)], "Input"]
}, Closed]],

Cell["\<\
\tSince the series for the complex sine and cosine agree with the real sine \
and cosine when z is real, the remaining complex trigonometric functions \
likewise agree with their real counterparts. What additional properties are \
common? For starters, we have  \
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 5.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  Cell[BoxData[
      \(sin \((z)\)\)]],
  " and ",
  Cell[BoxData[
      \(cos \((z)\)\)]],
  " are entire functions, with  ",
  Cell[BoxData[
      \(\(d\/dz\) sin \((z)\)\  = \ cos \((z)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\(d\/dz\) cos \((z)\)\  = \ \(-\ sin\) \((z)\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof of Theorem 5.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tThe ratio test shows that the radius of convergence for both functions \
is infinity, so they are entire by 4.17, part (i). Part (iii) of that theorem \
gives  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(\(d\/dz\) sin \((z)\)\), " ", "=", " ", 
          RowBox[{\(d\/dz\), 
            
            StyleBox[\(\[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\ \
z\^\(2  n + 1\)\)\/\(\((2  n + 1)\)!\)\),
              FontSize->12]}]}], " ", "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"                       ", 
        RowBox[{"=", " ", 
          
          StyleBox[\(\[Sum]\+\(n = 0\)\%\[Infinity]\((\(d\/dz\) \(\(\(\((\(-1\
\))\)\^n\)\(\ \)\)\/\(\((2  n + 1)\)!\)\) z\^\(2  n + 1\))\)\),
            FontSize->12]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"                       ", 
        RowBox[{"=", " ", 
          
          StyleBox[\(\[Sum]\+\(n = 0\)\%\[Infinity]\((\(\(\(\((\(-1\))\)\^n\) \
\((2  n + 1)\)\)\/\(\((2  n + 1)\)!\)\) z\^\(2  n\))\)\),
            FontSize->12]}], " ", "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"                       ", 
        RowBox[{"=", " ", 
          
          StyleBox[\(\[Sum]\+\(n = \
0\)\%\[Infinity]\((\(\((\(-1\))\)\^n\/\(\((2  n)\)!\)\) z\^\(2  n\))\)\),
            FontSize->12]}], 
        StyleBox[" ",
          FontSize->12], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"                       ", 
        RowBox[{
          StyleBox["=",
            FontSize->12], 
          StyleBox[" ",
            FontSize->12], \(cos \((z)\)\)}]}]}]],
  "  "
}], "Text"],

Cell[TextData[{
  "We leave the proof that ",
  Cell[BoxData[
      \(\(d\/dz\) cos \((z)\)\  = \ \(-\ sin\) \((z)\)\)]],
  " as an exercise. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for Theorem 5.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\[PartialD]\_z\ Sin[z] \[Equal] Cos[z]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_z\ Cos[z] \[Equal] \(-Sin[z]\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  "\tWe now list several additional properties, providing proofs for some and \
leaving others as exercises.  For all complex numbers ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ", \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(sin \((\(-z\))\)\  = \ \(-\ sin\) \((z)\)\), 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{" ", \(cos \((\(-z\))\)\  = \ cos \((z)\)\), 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{
              StyleBox["(",
                FontSize->16], \(cos\ z\), 
              StyleBox[")",
                FontSize->16]}], "2"], " ", "+", 
          SuperscriptBox[
            RowBox[{
              StyleBox["(",
                FontSize->16], \(sin\ z\), 
              StyleBox[")",
                FontSize->16]}], "2"]}], " ", "=", " ", "1"}]}]],
  "  "
}], "Text"],

Cell[TextData[{
  "\tThe verification that  ",
  Cell[BoxData[
      \(sin \((\(-z\))\) = \(-sin\) \((z)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(cos \((\(-z\))\) = cos \((z)\)\)]],
  "  comes from substituting ",
  StyleBox["-z",
    FontFamily->"Courier New"],
  " for ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " in Definition 5.5.  We leave verification of the identity ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{
              StyleBox["(",
                FontSize->16], \(cos\ z\), 
              StyleBox[")",
                FontSize->16]}], "2"], "+", 
          SuperscriptBox[
            RowBox[{
              StyleBox["(",
                FontSize->16], \(sin\ z\), 
              StyleBox[")",
                FontSize->16]}], "2"]}], "=", "1"}]]],
  "  as an exercise (with hints)."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for identities.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Sin[\(-z\)] \[Equal] \(-Sin[z]\)\)], "Input"],

Cell[BoxData[
    \(Cos[\(-z\)] \[Equal] Cos[z]\)], "Input"],

Cell[BoxData[{
    \(eqn = Cos[z]\^2 + Sin[z]\^2 \[Equal] 1\), "\[IndentingNewLine]", 
    \(Simplify[eqn]\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["A series exploration (i)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" The derivative of  sin(z)  is  cos(z).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["A series exploration (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Construct the Maclaurin series for cos(z) and sin(z) using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s \"Series\" procedure."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[cos, sin];\)\ \), "\n", 
    \(\(cos[z_]\  = \ 
        Series[Cos[z], \ {z, 0, 14}];\)\ \), "\[IndentingNewLine]", 
    \(\(sin[z_]\  = \ Series[Sin[z], \ {z, 0, 15}];\)\ \), "\n", 
    \(\(Print["\<Sin[z] = \>", sin[z]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(d\/dz\)Sin[z] = \>\"", \(sin'\)[z]];\)\ \), "\n", 
    \(\(Print["\<   Cos[z] = \>", cos[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Does  \!\(d\/dz\)Sin[z] = Cos[z] ?  \>\"", \(sin'\)[
            z]\  \[Equal] \ cos[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["A series exploration (ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["The derivative of  cos(z)  is  -sin(z).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["A series exploration (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Construct the Maclaurin series for cos(z) and sin(z) using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s \"Series\" procedure."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[cos, sin];\)\ \), "\n", 
    \(\(cos[z_]\  = \ 
        Series[Cos[z], \ {z, 0, 16}];\)\ \), "\[IndentingNewLine]", 
    \(\(sin[z_]\  = \ 
        Series[Sin[z], \ {z, 0, 15}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Cos[z] = \>", cos[z]];\)\ \), "\n", 
    \(\(Print["\<Sin[z] = \>", sin[z]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(d\/dz\)Cos[z] = \>\"", \(cos'\)[z]];\)\ \), "\n", 
    \(\(Print["\<  - Sin[z] = \>", \(-sin[
            z]\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Does  \!\(d\/dz\)Cos[z] = - Sin[z] ?  \>\"", \(cos'\)[
            z]\  \[Equal] \ \(-\ sin[z]\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tFor all complex numbers ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " for which the expressions are defined,  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(\(d\/dz\) tan\ z\ \  = \ \((sec\ z)\)\^2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(d\/dz\ cot\ z\ \  = \ \(-\ \((csc\ z)\)\^2\)\
\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(d\/dz\ sec\ z\ \  = \ sec\ z\ \ tan\ z\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{\(d\/dz\ csc\ z\), "  ", "=", " ", 
          RowBox[{\(-\ cot\), " ", "z", "  ", "Csc", " ", 
            RowBox[{"z", 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe proof that ",
  Cell[BoxData[
      \(\(d\/dz\) tan\ z\  = \((sec\ z)\)\^2\)]],
  " uses the identity ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{
              StyleBox["(",
                FontSize->16], \(cos\ z\), 
              StyleBox[")",
                FontSize->16]}], "2"], "+", 
          SuperscriptBox[
            RowBox[{
              StyleBox["(",
                FontSize->16], \(sin\ z\), 
              StyleBox[")",
                FontSize->16]}], "2"]}], "=", "1"}]]],
  ":  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(\(d\/dz\) 
            tan\ z\  = \(\(d\/\(\(\ \)\(dz\)\)\) \(sin\ z\)\/\(cos\ z\)\  = \ \
\(cos\ z \( d\/dz\) sin\ z\  - \ sin\ z \( d\/dz\) cos\ z\)\/\((cos\ \
z)\)\^2\)\), "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"                  ", 
        RowBox[{"=", " ", 
          RowBox[{
            FractionBox[
              RowBox[{
                SuperscriptBox[
                  RowBox[{
                    StyleBox["(",
                      FontSize->16], \(cos\ z\), 
                    StyleBox[")",
                      FontSize->16]}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{
                    StyleBox["(",
                      FontSize->16], \(sin\ z\), 
                    StyleBox[")",
                      FontSize->16]}], "2"]}], \(\((cos\ z)\)\^2\)], " ", "=",
             " ", \(1\/\((cos\ z)\)\^2\)}]}], " ", "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"                  ", \(\(=\)\(\ \)\(\((sec\ z)\)\^2\)\)}]}]]
}], "Text"],

Cell["\<\
We leave the proofs of the other derivative formulas as exercises.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for the identities.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\[PartialD]\_z\ Tan[z] \[Equal] Sec[z]\^2\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_z\ Cot[z] \[Equal] \(-Csc[z]\^2\)\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_z\ Sec[z] \[Equal] Sec[z]\ Tan[z]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_z\ Csc[z] \[Equal] \(-Cot[z]\)\ Csc[z]\)], "Input"]
}, Closed]],

Cell[TextData[{
  "\tTo establish additional properties, it will be useful to express ",
  Cell[BoxData[
      RowBox[{"cos", " ", "z", "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "sin", " ", "z"}]]],
  " in the Cartesian form ",
  Cell[BoxData[
      \(u + \[ImaginaryI]\ v\)]],
  ".  (Additionally, the applications in Chapters 9 and 10 will use these \
formulas.)  We begin by observing that the argument given to prove part (iii) \
in Theorem 5.1 easily generalizes to the complex case with the aid of \
Definition 5.5.  That is,  \n\n",
  StyleBox["(5-30)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\[ImaginaryI]\ z\)\  = \ 
        cos\ z\  + \ \[ImaginaryI]\ sin\ z\)]],
  ",\n\nfor all z, whether z is real or complex.  Hence,  \n\n",
  StyleBox["(5-31)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ z\)\  = \ \(cos \((\(-z\))\)\  \
+ \ \[ImaginaryI]\ sin \((\(-z\))\)\  = \ 
          cos\ z\  - \ \[ImaginaryI]\ sin\ z\)\)]],
  "  "
}], "Text"],

Cell[TextData[{
  "\tAdding the above two expressions and solving for ",
  Cell[BoxData[
      \(cos\ z\)]],
  " gives\n\n",
  StyleBox["(5-32)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(cos\ z\  = \ \(\[ExponentialE]\^\(\[ImaginaryI]\ z\)\ \  + \ \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ z\)\)\/2\)]],
  " ,\n\nand subtracting ",
  StyleBox["(5-32)",
    FontColor->RGBColor[0, 0, 1]],
  " from ",
  StyleBox["(5-31) ",
    FontColor->RGBColor[0, 0, 1]],
  "and solving for ",
  Cell[BoxData[
      \(sin\ z\)]],
  " gives\n\n",
  StyleBox["(5-33)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(sin\ z\  = \ \(\[ExponentialE]\^\(\[ImaginaryI]\ z\)\ \  - \ \ \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ z\)\)\/\(2  \[ImaginaryI]\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .64706 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.294118 0.323529 0.294118 [
[.038 .31103 -17.4375 -20.875 ]
[.038 .31103 17.4375 0 ]
[.962 .31103 -12.8125 -20.875 ]
[.962 .31103 12.8125 0 ]
[1.025 .32353 0 -6.5 ]
[1.025 .32353 9 6.5 ]
[.4875 .02941 -16.375 -6.5 ]
[.4875 .02941 0 6.5 ]
[.4875 .61765 -9.5 -6.5 ]
[.4875 .61765 0 6.5 ]
[.5 .67206 -4.34375 0 ]
[.5 .67206 4.34375 13 ]
[ 0 0 0 0 ]
[ 1 .64706 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.038 .32353 m
.038 .32978 L
s
gsave
.038 .31103 -78.4375 -24.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.688 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.563 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.438 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.438 16.688 moveto
(\\200\\200\\200\\200) show
69.938 16.688 moveto
(\\200\\200\\200\\200) show
75.438 16.688 moveto
(\\200) show
77.063 16.688 moveto
(\\200) show
68.813 23.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.875 16.688 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.962 .32353 m
.962 .32978 L
s
gsave
.962 .31103 -73.8125 -24.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.688 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.750 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
75.438 16.688 moveto
(\\200\\200\\200\\200) show
80.938 16.688 moveto
(\\200) show
81.563 16.688 moveto
(\\200) show
76.563 23.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.625 16.688 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .32353 m
1 .32353 L
s
gsave
1.025 .32353 -61 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .02941 m
.50625 .02941 L
s
gsave
.4875 .02941 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .61765 m
.50625 .61765 L
s
gsave
.4875 .61765 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .64706 L
s
gsave
.5 .67206 -65.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
67.688 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .64706 L
0 .64706 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.038 .02941 m
.038 .05327 L
.038 .0793 L
.038 .10374 L
.038 .12725 L
.038 .15227 L
.038 .17635 L
.038 .20195 L
.038 .22661 L
.038 .25034 L
.038 .27558 L
.038 .29988 L
.038 .32325 L
.038 .34814 L
.038 .37208 L
.038 .39755 L
.038 .42207 L
.038 .44566 L
.038 .47077 L
.038 .49493 L
.038 .52062 L
.038 .54536 L
.038 .56917 L
.038 .5945 L
.038 .61765 L
s
1 0 0 r
.09575 .02941 m
.09575 .05327 L
.09575 .0793 L
.09575 .10374 L
.09575 .12725 L
.09575 .15227 L
.09575 .17635 L
.09575 .20195 L
.09575 .22661 L
.09575 .25034 L
.09575 .27558 L
.09575 .29988 L
.09575 .32325 L
.09575 .34814 L
.09575 .37208 L
.09575 .39755 L
.09575 .42207 L
.09575 .44566 L
.09575 .47077 L
.09575 .49493 L
.09575 .52062 L
.09575 .54536 L
.09575 .56917 L
.09575 .5945 L
.09575 .61765 L
s
0 0 1 r
.1535 .02941 m
.1535 .05327 L
.1535 .0793 L
.1535 .10374 L
.1535 .12725 L
.1535 .15227 L
.1535 .17635 L
.1535 .20195 L
.1535 .22661 L
.1535 .25034 L
.1535 .27558 L
.1535 .29988 L
.1535 .32325 L
.1535 .34814 L
.1535 .37208 L
.1535 .39755 L
.1535 .42207 L
.1535 .44566 L
.1535 .47077 L
.1535 .49493 L
.1535 .52062 L
.1535 .54536 L
.1535 .56917 L
.1535 .5945 L
.1535 .61765 L
s
1 0 0 r
.21125 .02941 m
.21125 .05327 L
.21125 .0793 L
.21125 .10374 L
.21125 .12725 L
.21125 .15227 L
.21125 .17635 L
.21125 .20195 L
.21125 .22661 L
.21125 .25034 L
.21125 .27558 L
.21125 .29988 L
.21125 .32325 L
.21125 .34814 L
.21125 .37208 L
.21125 .39755 L
.21125 .42207 L
.21125 .44566 L
.21125 .47077 L
.21125 .49493 L
.21125 .52062 L
.21125 .54536 L
.21125 .56917 L
.21125 .5945 L
.21125 .61765 L
s
0 0 1 r
.269 .02941 m
.269 .05327 L
.269 .0793 L
.269 .10374 L
.269 .12725 L
.269 .15227 L
.269 .17635 L
.269 .20195 L
.269 .22661 L
.269 .25034 L
.269 .27558 L
.269 .29988 L
.269 .32325 L
.269 .34814 L
.269 .37208 L
.269 .39755 L
.269 .42207 L
.269 .44566 L
.269 .47077 L
.269 .49493 L
.269 .52062 L
.269 .54536 L
.269 .56917 L
.269 .5945 L
.269 .61765 L
s
1 0 0 r
.32675 .02941 m
.32675 .05327 L
.32675 .0793 L
.32675 .10374 L
.32675 .12725 L
.32675 .15227 L
.32675 .17635 L
.32675 .20195 L
.32675 .22661 L
.32675 .25034 L
.32675 .27558 L
.32675 .29988 L
.32675 .32325 L
.32675 .34814 L
.32675 .37208 L
.32675 .39755 L
.32675 .42207 L
.32675 .44566 L
.32675 .47077 L
.32675 .49493 L
.32675 .52062 L
.32675 .54536 L
.32675 .56917 L
.32675 .5945 L
.32675 .61765 L
s
0 0 1 r
.3845 .02941 m
.3845 .05327 L
.3845 .0793 L
.3845 .10374 L
.3845 .12725 L
.3845 .15227 L
.3845 .17635 L
.3845 .20195 L
.3845 .22661 L
.3845 .25034 L
.3845 .27558 L
.3845 .29988 L
.3845 .32325 L
.3845 .34814 L
.3845 .37208 L
.3845 .39755 L
.3845 .42207 L
.3845 .44566 L
.3845 .47077 L
.3845 .49493 L
.3845 .52062 L
.3845 .54536 L
.3845 .56917 L
.3845 .5945 L
.3845 .61765 L
s
1 0 0 r
.44225 .02941 m
.44225 .05327 L
.44225 .0793 L
.44225 .10374 L
.44225 .12725 L
.44225 .15227 L
.44225 .17635 L
.44225 .20195 L
.44225 .22661 L
.44225 .25034 L
.44225 .27558 L
.44225 .29988 L
.44225 .32325 L
.44225 .34814 L
.44225 .37208 L
.44225 .39755 L
.44225 .42207 L
.44225 .44566 L
.44225 .47077 L
.44225 .49493 L
.44225 .52062 L
.44225 .54536 L
.44225 .56917 L
.44225 .5945 L
.44225 .61765 L
s
0 0 1 r
.5 .02941 m
.5 .05327 L
.5 .0793 L
.5 .10374 L
.5 .12725 L
.5 .15227 L
.5 .17635 L
.5 .20195 L
.5 .22661 L
.5 .25034 L
.5 .27558 L
.5 .29988 L
.5 .32325 L
.5 .34814 L
.5 .37208 L
.5 .39755 L
.5 .42207 L
.5 .44566 L
.5 .47077 L
.5 .49493 L
.5 .52062 L
.5 .54536 L
.5 .56917 L
.5 .5945 L
.5 .61765 L
s
1 0 0 r
.55775 .02941 m
.55775 .05327 L
.55775 .0793 L
.55775 .10374 L
.55775 .12725 L
.55775 .15227 L
.55775 .17635 L
.55775 .20195 L
.55775 .22661 L
.55775 .25034 L
.55775 .27558 L
.55775 .29988 L
.55775 .32325 L
.55775 .34814 L
.55775 .37208 L
.55775 .39755 L
.55775 .42207 L
.55775 .44566 L
.55775 .47077 L
.55775 .49493 L
.55775 .52062 L
.55775 .54536 L
.55775 .56917 L
.55775 .5945 L
.55775 .61765 L
s
0 0 1 r
.6155 .02941 m
.6155 .05327 L
.6155 .0793 L
.6155 .10374 L
.6155 .12725 L
.6155 .15227 L
.6155 .17635 L
.6155 .20195 L
.6155 .22661 L
.6155 .25034 L
.6155 .27558 L
.6155 .29988 L
.6155 .32325 L
.6155 .34814 L
.6155 .37208 L
.6155 .39755 L
.6155 .42207 L
.6155 .44566 L
.6155 .47077 L
.6155 .49493 L
.6155 .52062 L
.6155 .54536 L
.6155 .56917 L
.6155 .5945 L
.6155 .61765 L
s
1 0 0 r
.67325 .02941 m
.67325 .05327 L
.67325 .0793 L
.67325 .10374 L
.67325 .12725 L
.67325 .15227 L
.67325 .17635 L
.67325 .20195 L
.67325 .22661 L
.67325 .25034 L
.67325 .27558 L
.67325 .29988 L
.67325 .32325 L
.67325 .34814 L
.67325 .37208 L
.67325 .39755 L
.67325 .42207 L
.67325 .44566 L
.67325 .47077 L
.67325 .49493 L
.67325 .52062 L
.67325 .54536 L
.67325 .56917 L
.67325 .5945 L
.67325 .61765 L
s
0 0 1 r
.731 .02941 m
.731 .05327 L
.731 .0793 L
.731 .10374 L
.731 .12725 L
.731 .15227 L
.731 .17635 L
.731 .20195 L
.731 .22661 L
.731 .25034 L
.731 .27558 L
.731 .29988 L
.731 .32325 L
.731 .34814 L
.731 .37208 L
.731 .39755 L
.731 .42207 L
.731 .44566 L
.731 .47077 L
.731 .49493 L
.731 .52062 L
.731 .54536 L
.731 .56917 L
.731 .5945 L
.731 .61765 L
s
1 0 0 r
.78875 .02941 m
.78875 .05327 L
.78875 .0793 L
.78875 .10374 L
.78875 .12725 L
.78875 .15227 L
.78875 .17635 L
.78875 .20195 L
.78875 .22661 L
.78875 .25034 L
.78875 .27558 L
.78875 .29988 L
.78875 .32325 L
.78875 .34814 L
.78875 .37208 L
.78875 .39755 L
.78875 .42207 L
.78875 .44566 L
.78875 .47077 L
.78875 .49493 L
.78875 .52062 L
.78875 .54536 L
.78875 .56917 L
.78875 .5945 L
.78875 .61765 L
s
0 0 1 r
.8465 .02941 m
.8465 .05327 L
.8465 .0793 L
.8465 .10374 L
.8465 .12725 L
.8465 .15227 L
.8465 .17635 L
.8465 .20195 L
.8465 .22661 L
.8465 .25034 L
.8465 .27558 L
.8465 .29988 L
.8465 .32325 L
.8465 .34814 L
.8465 .37208 L
.8465 .39755 L
.8465 .42207 L
.8465 .44566 L
.8465 .47077 L
.8465 .49493 L
.8465 .52062 L
.8465 .54536 L
.8465 .56917 L
.8465 .5945 L
.8465 .61765 L
s
1 0 0 r
.90425 .02941 m
.90425 .05327 L
.90425 .0793 L
.90425 .10374 L
.90425 .12725 L
.90425 .15227 L
.90425 .17635 L
.90425 .20195 L
.90425 .22661 L
.90425 .25034 L
.90425 .27558 L
.90425 .29988 L
.90425 .32325 L
.90425 .34814 L
.90425 .37208 L
.90425 .39755 L
.90425 .42207 L
.90425 .44566 L
.90425 .47077 L
.90425 .49493 L
.90425 .52062 L
.90425 .54536 L
.90425 .56917 L
.90425 .5945 L
.90425 .61765 L
s
0 0 1 r
.962 .02941 m
.962 .05327 L
.962 .0793 L
.962 .10374 L
.962 .12725 L
.962 .15227 L
.962 .17635 L
.962 .20195 L
.962 .22661 L
.962 .25034 L
.962 .27558 L
.962 .29988 L
.962 .32325 L
.962 .34814 L
.962 .37208 L
.962 .39755 L
.962 .42207 L
.962 .44566 L
.962 .47077 L
.962 .49493 L
.962 .52062 L
.962 .54536 L
.962 .56917 L
.962 .5945 L
.962 .61765 L
s
.038 .02941 m
.07548 .02941 L
.11636 .02941 L
.15476 .02941 L
.19168 .02941 L
.23098 .02941 L
.26881 .02941 L
.30902 .02941 L
.34776 .02941 L
.38503 .02941 L
.42468 .02941 L
.46286 .02941 L
.49956 .02941 L
.53865 .02941 L
.57627 .02941 L
.61626 .02941 L
.65479 .02941 L
.69184 .02941 L
.73128 .02941 L
.76924 .02941 L
.80958 .02941 L
.84846 .02941 L
.88586 .02941 L
.92564 .02941 L
.962 .02941 L
s
1 0 0 r
.038 .10294 m
.07548 .10294 L
.11636 .10294 L
.15476 .10294 L
.19168 .10294 L
.23098 .10294 L
.26881 .10294 L
.30902 .10294 L
.34776 .10294 L
.38503 .10294 L
.42468 .10294 L
.46286 .10294 L
.49956 .10294 L
.53865 .10294 L
.57627 .10294 L
.61626 .10294 L
.65479 .10294 L
.69184 .10294 L
.73128 .10294 L
.76924 .10294 L
.80958 .10294 L
.84846 .10294 L
.88586 .10294 L
.92564 .10294 L
.962 .10294 L
s
0 0 1 r
.038 .17647 m
.07548 .17647 L
.11636 .17647 L
.15476 .17647 L
.19168 .17647 L
.23098 .17647 L
.26881 .17647 L
.30902 .17647 L
.34776 .17647 L
.38503 .17647 L
.42468 .17647 L
.46286 .17647 L
.49956 .17647 L
.53865 .17647 L
.57627 .17647 L
.61626 .17647 L
.65479 .17647 L
.69184 .17647 L
.73128 .17647 L
.76924 .17647 L
.80958 .17647 L
.84846 .17647 L
.88586 .17647 L
.92564 .17647 L
.962 .17647 L
s
1 0 0 r
.038 .25 m
.07548 .25 L
.11636 .25 L
.15476 .25 L
.19168 .25 L
.23098 .25 L
.26881 .25 L
.30902 .25 L
.34776 .25 L
.38503 .25 L
.42468 .25 L
.46286 .25 L
.49956 .25 L
.53865 .25 L
.57627 .25 L
.61626 .25 L
.65479 .25 L
.69184 .25 L
.73128 .25 L
.76924 .25 L
.80958 .25 L
.84846 .25 L
.88586 .25 L
.92564 .25 L
.962 .25 L
s
0 0 1 r
.038 .32353 m
.07548 .32353 L
.11636 .32353 L
.15476 .32353 L
.19168 .32353 L
.23098 .32353 L
.26881 .32353 L
.30902 .32353 L
.34776 .32353 L
.38503 .32353 L
.42468 .32353 L
.46286 .32353 L
.49956 .32353 L
.53865 .32353 L
.57627 .32353 L
.61626 .32353 L
.65479 .32353 L
.69184 .32353 L
.73128 .32353 L
.76924 .32353 L
.80958 .32353 L
.84846 .32353 L
.88586 .32353 L
.92564 .32353 L
.962 .32353 L
s
1 0 0 r
.038 .39706 m
.07548 .39706 L
.11636 .39706 L
.15476 .39706 L
.19168 .39706 L
.23098 .39706 L
.26881 .39706 L
.30902 .39706 L
.34776 .39706 L
.38503 .39706 L
.42468 .39706 L
.46286 .39706 L
.49956 .39706 L
.53865 .39706 L
.57627 .39706 L
.61626 .39706 L
.65479 .39706 L
.69184 .39706 L
.73128 .39706 L
.76924 .39706 L
.80958 .39706 L
.84846 .39706 L
.88586 .39706 L
.92564 .39706 L
.962 .39706 L
s
0 0 1 r
.038 .47059 m
.07548 .47059 L
.11636 .47059 L
.15476 .47059 L
.19168 .47059 L
.23098 .47059 L
.26881 .47059 L
.30902 .47059 L
.34776 .47059 L
.38503 .47059 L
.42468 .47059 L
.46286 .47059 L
.49956 .47059 L
.53865 .47059 L
.57627 .47059 L
.61626 .47059 L
.65479 .47059 L
.69184 .47059 L
.73128 .47059 L
.76924 .47059 L
.80958 .47059 L
.84846 .47059 L
.88586 .47059 L
.92564 .47059 L
.962 .47059 L
s
1 0 0 r
.038 .54412 m
.07548 .54412 L
.11636 .54412 L
.15476 .54412 L
.19168 .54412 L
.23098 .54412 L
.26881 .54412 L
.30902 .54412 L
.34776 .54412 L
.38503 .54412 L
.42468 .54412 L
.46286 .54412 L
.49956 .54412 L
.53865 .54412 L
.57627 .54412 L
.61626 .54412 L
.65479 .54412 L
.69184 .54412 L
.73128 .54412 L
.76924 .54412 L
.80958 .54412 L
.84846 .54412 L
.88586 .54412 L
.92564 .54412 L
.962 .54412 L
s
0 0 1 r
.038 .61765 m
.07548 .61765 L
.11636 .61765 L
.15476 .61765 L
.19168 .61765 L
.23098 .61765 L
.26881 .61765 L
.30902 .61765 L
.34776 .61765 L
.38503 .61765 L
.42468 .61765 L
.46286 .61765 L
.49956 .61765 L
.53865 .61765 L
.57627 .61765 L
.61626 .61765 L
.65479 .61765 L
.69184 .61765 L
.73128 .61765 L
.76924 .61765 L
.80958 .61765 L
.84846 .61765 L
.88586 .61765 L
.92564 .61765 L
.962 .61765 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 186.313},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000^R000`400?l00000o`00003oR`3oool0
0`000000oooo0?ooo`2B0?ooo`00R`3oool00`000000oooo0?ooo`2B0?ooo`00R`3oool00`000000
oooo0?ooo`2B0?ooo`00R`3oool00`000000oooo0?ooo`2B0?ooo`00R`3oool00`000000oooo0?oo
o`2B0?ooo`00P`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0980oooo00230?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0TP3oool007/0oooo100000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0TP3oool001D0ooookP000?lM0?ooo`005@3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`0000001`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3o
ool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`030?ooo`8000001`3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool0
01D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?oo
o`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K
0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooonh0
o`007@3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0
oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`00
5@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooonh0003o7@3oool001D0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
6`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo
000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool06`3oool000/0oooo1@0000050?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`0000001000000G0?ooo`00303oool00`000000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00@0003o0?ooo`3oool000006P3oool000d0oooo00<000000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`050000o`3oool0oooo0?ooo`0000006@3oool000h0
oooo00<000000?ooo`3oool0103oooo^0?l000@0oooo00<000000?ooo`3oool05P3oool000l0oooo
00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00<0oooo
00<000000?ooo`3oool05@3oool000/0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`0000000`3oool00`000000oooo0?ooo`0E0?ooo`00303o
ool3000000H0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`03000001P0oooo000E
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`001`3oool>000000030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0000000000001P00000E0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3o
ool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000?0?ooo`030000003oool0oooo0080
000000<0oooo0000o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool010000?l0oooo0?ooo`0000020?ooo`8000005P3oool00100
oooo00<000000?ooo`0000000P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`070000o`3oool0oooo0?oo
o`000000oooo0000000G0?ooo`002@3oool4000000<0oooo00<000000?ooo`0000000P3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`070000o`3oool0oooo0?ooo`000000oooo0000000G0?ooo`003`3oool0
1`000000oooo0000003oool000000?ooo`000?l03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool020000?l0oooo0?ooo`000000oooo0000
003oool000005P3oool00100oooo1@0000000`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`040000o`3oool0oooo
0?ooo`D000005@3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?oo
o`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00l0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo0100
oooo00<000000?ooo`000000203oool000/0oooo2P00003^0000o`T000002P3oool00`000000oooo
0?ooo`070?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo0100oooo00<0
00000?ooo`000000203oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0?
0?ooo`050000003oool0oooo0?ooo`0000001`3oool001D0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?oo
o`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K
0?ooo`005@3oooo^0?l001d0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0
oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`00
5@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooonh0003o7@3oool001D0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
6`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo
000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0
oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0ooookP3o
000M0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3o
ool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01/0oooo000E
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool001D0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
6`3oool001D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0K0?ooo`005@3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool06`3oool0
01D0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
01/0oooo000E0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0K0?ooo`005@3oooo^0000oad0oooo00210?ooo`030000003oool0000000L0oooo00<0
00000?ooo`3oool0TP3oool00880oooo0P0000070?ooo`030000003oool0oooo0980oooo00230?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0TP3oool008/0oooo00<000000?ooo`3o
ool0TP3oool008/0oooo00<000000?ooo`3oool0TP3oool008/0oooo00<000000?ooo`3oool0TP3o
ool008/0oooo00<000000?ooo`3oool0TP3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool008X0oooo00<000000?ooo`3oool0T`3oool008/0oooo00<000000?ooo`3oool0TP3oool0
08/0oooo00<000000?ooo`3oool0TP3oool008X0oooo00<000000?ooo`000000T`3oool008X0oooo
00<000000?ooo`000000T`3oool008X0oooo00<000000?ooo`000000T`3oool008T0oooo00D00000
0?ooo`3oool0oooo0000002B0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 287}, {185.313, 0}} -> {-1, -1, 0, 0}}],
  StyleBox["     ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.3125 0.375 0.3125 [
[.1875 .3625 -8.1875 -13 ]
[.1875 .3625 8.1875 0 ]
[.8125 .3625 -4.75 -13 ]
[.8125 .3625 4.75 0 ]
[1.025 .375 0 -6.5 ]
[1.025 .375 9.5 6.5 ]
[.4875 .0625 -16.375 -6.5 ]
[.4875 .0625 0 6.5 ]
[.4875 .6875 -9.5 -6.5 ]
[.4875 .6875 0 6.5 ]
[.5 .775 -4.4375 0 ]
[.5 .775 4.4375 13 ]
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1875 .375 m
.1875 .38125 L
s
gsave
.1875 .3625 -69.1875 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.8125 .375 m
.8125 .38125 L
s
gsave
.8125 .3625 -65.75 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .375 m
1 .375 L
s
gsave
1.025 .375 -61 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .0625 m
.50625 .0625 L
s
gsave
.4875 .0625 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .6875 m
.50625 .6875 L
s
gsave
.4875 .6875 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .75 L
s
gsave
.5 .775 -65.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
67.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.01779 .375 m
.04603 .375 L
.07343 .375 L
.09611 .375 L
.11529 .375 L
.13301 .375 L
.14755 .375 L
.16042 .375 L
.17038 .375 L
.17777 .375 L
.18334 .375 L
.18649 .375 L
.1875 .375 L
.18641 .375 L
.18323 .375 L
.17755 .375 L
.1698 .375 L
.16017 .375 L
.14752 .375 L
.13291 .375 L
.11467 .375 L
.09432 .375 L
.07202 .375 L
.04523 .375 L
.01779 .375 L
s
1 0 0 r
.02705 .30335 m
.05475 .31076 L
.08162 .31835 L
.10387 .32508 L
.12268 .33123 L
.14006 .33746 L
.15432 .3432 L
.16694 .34907 L
.17671 .35454 L
.18397 .35967 L
.18685 .36223 L
.18942 .36502 L
.19128 .36764 L
.19193 .36882 L
.19251 .37009 L
.19277 .37078 L
.19298 .37143 L
.19316 .37209 L
.19328 .37269 L
.19338 .37328 L
.19342 .37355 L
.19345 .37384 L
.19347 .37414 L
.19348 .37428 L
.19349 .37443 L
.1935 .37458 L
.1935 .37473 L
.1935 .37482 L
.1935 .3749 L
.1935 .37506 L
.1935 .37521 L
.1935 .37537 L
.19349 .37551 L
.19349 .37565 L
.19347 .37597 L
.19344 .3763 L
.1934 .37662 L
.19335 .37693 L
.19322 .37761 L
.19292 .37875 L
.19249 .37998 L
.19188 .38129 L
.19106 .38272 L
.18913 .38533 L
.1867 .38792 L
.18352 .39069 L
.17623 .39575 L
.16622 .40129 L
.15432 .4068 L
.13915 .41288 L
Mistroke
.12197 .41902 L
.10296 .4252 L
.07991 .43215 L
.05482 .43922 L
.02705 .44665 L
Mfstroke
0 0 1 r
.05449 .23446 m
.08059 .24899 L
.1059 .26388 L
.12685 .27708 L
.14457 .28913 L
.16094 .30136 L
.17438 .31263 L
.18627 .32415 L
.19547 .33488 L
.2023 .34493 L
.20502 .34994 L
.20744 .35542 L
.20919 .36057 L
.20981 .36287 L
.21035 .36538 L
.2106 .36673 L
.21079 .36799 L
.21096 .36929 L
.21108 .37047 L
.21117 .37163 L
.21121 .37216 L
.21124 .37272 L
.21126 .37332 L
.21127 .37359 L
.21127 .37388 L
.21128 .37418 L
.21128 .37447 L
.21129 .37465 L
.21129 .37481 L
.21129 .37512 L
.21129 .37541 L
.21128 .37572 L
.21128 .37601 L
.21127 .37628 L
.21125 .37689 L
.21122 .37755 L
.21119 .37818 L
.21114 .37878 L
.21102 .38012 L
.21074 .38236 L
.21033 .38476 L
.20975 .38734 L
.20898 .39015 L
.20717 .39527 L
.20487 .40035 L
.20188 .40578 L
.19502 .41571 L
.18559 .42657 L
.17438 .43737 L
.16009 .44931 L
Mistroke
.1439 .46134 L
.126 .47348 L
.10429 .48709 L
.08065 .50098 L
.05449 .51554 L
Mfstroke
1 0 0 r
.09905 .17097 m
.12254 .19205 L
.14532 .21368 L
.16418 .23284 L
.18012 .25034 L
.19486 .26809 L
.20695 .28445 L
.21765 .30117 L
.22593 .31675 L
.23208 .33135 L
.23452 .33862 L
.2367 .34657 L
.23828 .35405 L
.23883 .35739 L
.23933 .36103 L
.23955 .363 L
.23972 .36482 L
.23987 .36671 L
.23998 .36842 L
.24006 .37011 L
.24009 .37088 L
.24012 .37169 L
.24014 .37256 L
.24015 .37295 L
.24015 .37337 L
.24016 .37381 L
.24016 .37423 L
.24016 .37448 L
.24017 .37473 L
.24017 .37518 L
.24016 .37559 L
.24016 .37604 L
.24016 .37646 L
.24015 .37685 L
.24013 .37775 L
.24011 .3787 L
.24007 .37962 L
.24004 .38048 L
.23993 .38244 L
.23967 .38569 L
.2393 .38917 L
.23879 .39292 L
.23809 .39699 L
.23646 .40442 L
.23439 .4118 L
.2317 .41968 L
.22552 .4341 L
.21704 .44987 L
.20695 .46555 L
.19409 .48288 L
Mistroke
.17952 .50035 L
.16341 .51797 L
.14387 .53774 L
.1226 .55789 L
.09905 .57903 L
Mfstroke
0 0 1 r
.15902 .11531 m
.17899 .14215 L
.19837 .16968 L
.21441 .19407 L
.22797 .21634 L
.2405 .23893 L
.25078 .25975 L
.25988 .28103 L
.26692 .30086 L
.27215 .31944 L
.27423 .3287 L
.27609 .33881 L
.27743 .34834 L
.2779 .35259 L
.27831 .35722 L
.2785 .35972 L
.27865 .36204 L
.27878 .36445 L
.27887 .36663 L
.27894 .36877 L
.27897 .36975 L
.27899 .37079 L
.27901 .3719 L
.27901 .37239 L
.27902 .37292 L
.27902 .37349 L
.27903 .37402 L
.27903 .37434 L
.27903 .37465 L
.27903 .37523 L
.27903 .37576 L
.27903 .37632 L
.27902 .37686 L
.27902 .37736 L
.279 .3785 L
.27898 .37971 L
.27895 .38088 L
.27892 .38198 L
.27883 .38447 L
.27861 .38861 L
.27829 .39303 L
.27786 .39781 L
.27726 .40299 L
.27588 .41245 L
.27412 .42184 L
.27183 .43187 L
.26658 .45022 L
.25936 .47029 L
.25078 .49025 L
.23984 .51231 L
Mistroke
.22746 .53454 L
.21375 .55696 L
.19713 .58212 L
.17905 .60777 L
.15902 .63469 L
Mfstroke
1 0 0 r
.2321 .06964 m
.24779 .1012 L
.26301 .13357 L
.27561 .16225 L
.28627 .18843 L
.29611 .215 L
.30419 .23948 L
.31134 .26451 L
.31687 .28782 L
.32098 .30967 L
.32261 .32056 L
.32407 .33245 L
.32513 .34365 L
.32549 .34865 L
.32582 .35409 L
.32597 .35703 L
.32609 .35977 L
.32619 .36259 L
.32626 .36516 L
.32632 .36768 L
.32634 .36883 L
.32635 .37005 L
.32637 .37136 L
.32637 .37194 L
.32638 .37256 L
.32638 .37322 L
.32638 .37385 L
.32638 .37423 L
.32638 .37459 L
.32638 .37527 L
.32638 .37589 L
.32638 .37656 L
.32638 .37719 L
.32637 .37777 L
.32636 .37912 L
.32634 .38053 L
.32632 .38192 L
.3263 .38321 L
.32622 .38613 L
.32606 .391 L
.32581 .3962 L
.32546 .40182 L
.325 .40792 L
.32391 .41903 L
.32253 .43007 L
.32073 .44187 L
.3166 .46345 L
.31093 .48705 L
.30419 .51052 L
.2956 .53646 L
Mistroke
.28586 .56259 L
.2751 .58897 L
.26204 .61855 L
.24783 .64871 L
.2321 .68036 L
Mfstroke
0 0 1 r
.31547 .0357 m
.32627 .07077 L
.33676 .10674 L
.34544 .1386 L
.35278 .1677 L
.35956 .19722 L
.36512 .22442 L
.37005 .25223 L
.37386 .27813 L
.37669 .30241 L
.37781 .31451 L
.37882 .32772 L
.37954 .34016 L
.3798 .34572 L
.38002 .35176 L
.38013 .35504 L
.38021 .35807 L
.38028 .36121 L
.38033 .36406 L
.38036 .36686 L
.38038 .36815 L
.38039 .3695 L
.3804 .37095 L
.3804 .37159 L
.38041 .37228 L
.38041 .37303 L
.38041 .37372 L
.38041 .37414 L
.38041 .37454 L
.38041 .3753 L
.38041 .37599 L
.38041 .37673 L
.38041 .37743 L
.3804 .37808 L
.3804 .37957 L
.38038 .38115 L
.38037 .38269 L
.38035 .38412 L
.3803 .38737 L
.38018 .39278 L
.38001 .39856 L
.37978 .4048 L
.37946 .41157 L
.37871 .42393 L
.37775 .43619 L
.37651 .4493 L
.37367 .47328 L
.36977 .4995 L
.36512 .52558 L
.3592 .5544 L
Mistroke
.3525 .58344 L
.34508 .61275 L
.33609 .64562 L
.3263 .67913 L
.31547 .7143 L
Mfstroke
1 0 0 r
.40592 .01481 m
.41143 .05203 L
.41678 .09022 L
.4212 .12404 L
.42495 .15493 L
.4284 .18627 L
.43124 .21515 L
.43375 .24466 L
.43569 .27217 L
.43714 .29794 L
.43771 .31078 L
.43822 .32481 L
.43859 .33802 L
.43872 .34391 L
.43884 .35033 L
.43889 .35381 L
.43893 .35703 L
.43896 .36037 L
.43899 .36339 L
.43901 .36636 L
.43902 .36772 L
.43902 .36916 L
.43903 .3707 L
.43903 .37138 L
.43903 .37212 L
.43903 .37291 L
.43903 .37364 L
.43903 .37409 L
.43903 .37452 L
.43903 .37531 L
.43903 .37605 L
.43903 .37684 L
.43903 .37758 L
.43903 .37827 L
.43903 .37986 L
.43902 .38153 L
.43901 .38316 L
.439 .38468 L
.43898 .38813 L
.43892 .39387 L
.43883 .40001 L
.43871 .40663 L
.43855 .41383 L
.43817 .42694 L
.43768 .43996 L
.43705 .45388 L
.4356 .47933 L
.43361 .50717 L
.43124 .53485 L
.42822 .56545 L
Mistroke
.42481 .59628 L
.42102 .62739 L
.41644 .66229 L
.41145 .69787 L
.40592 .73519 L
Mfstroke
0 0 1 r
.5 .00775 m
.5 .04571 L
.5 .08464 L
.5 .11913 L
.5 .15062 L
.5 .18257 L
.5 .21201 L
.5 .24211 L
.5 .27015 L
.5 .29643 L
.5 .32383 L
.5 .34985 L
.5 .37471 L
.5 .40117 L
.5 .42682 L
.5 .45447 L
.5 .48167 L
.5 .50853 L
.5 .53805 L
.5 .5676 L
.5 .60043 L
.5 .63369 L
.5 .66742 L
.5 .7054 L
.5 .74225 L
s
1 0 0 r
.59408 .01481 m
.58857 .05203 L
.58322 .09022 L
.5788 .12404 L
.57505 .15493 L
.5716 .18627 L
.56876 .21515 L
.56625 .24466 L
.56431 .27217 L
.56286 .29794 L
.56229 .31078 L
.56178 .32481 L
.56141 .33802 L
.56128 .34391 L
.56116 .35033 L
.56111 .35381 L
.56107 .35703 L
.56104 .36037 L
.56101 .36339 L
.56099 .36636 L
.56098 .36772 L
.56098 .36916 L
.56097 .3707 L
.56097 .37138 L
.56097 .37212 L
.56097 .37291 L
.56097 .37364 L
.56097 .37409 L
.56097 .37452 L
.56097 .37531 L
.56097 .37605 L
.56097 .37684 L
.56097 .37758 L
.56097 .37827 L
.56097 .37986 L
.56098 .38153 L
.56099 .38316 L
.561 .38468 L
.56102 .38813 L
.56108 .39387 L
.56117 .40001 L
.56129 .40663 L
.56145 .41383 L
.56183 .42694 L
.56232 .43996 L
.56295 .45388 L
.5644 .47933 L
.56639 .50717 L
.56876 .53485 L
.57178 .56545 L
Mistroke
.57519 .59628 L
.57898 .62739 L
.58356 .66229 L
.58855 .69787 L
.59408 .73519 L
Mfstroke
0 0 1 r
.68453 .0357 m
.67373 .07077 L
.66324 .10674 L
.65456 .1386 L
.64722 .1677 L
.64044 .19722 L
.63488 .22442 L
.62995 .25223 L
.62614 .27813 L
.62331 .30241 L
.62219 .31451 L
.62118 .32772 L
.62046 .34016 L
.6202 .34572 L
.61998 .35176 L
.61987 .35504 L
.61979 .35807 L
.61972 .36121 L
.61967 .36406 L
.61964 .36686 L
.61962 .36815 L
.61961 .3695 L
.6196 .37095 L
.6196 .37159 L
.61959 .37228 L
.61959 .37303 L
.61959 .37372 L
.61959 .37414 L
.61959 .37454 L
.61959 .3753 L
.61959 .37599 L
.61959 .37673 L
.61959 .37743 L
.6196 .37808 L
.6196 .37957 L
.61962 .38115 L
.61963 .38269 L
.61965 .38412 L
.6197 .38737 L
.61982 .39278 L
.61999 .39856 L
.62022 .4048 L
.62054 .41157 L
.62129 .42393 L
.62225 .43619 L
.62349 .4493 L
.62633 .47328 L
.63023 .4995 L
.63488 .52558 L
.6408 .5544 L
Mistroke
.6475 .58344 L
.65492 .61275 L
.66391 .64562 L
.6737 .67913 L
.68453 .7143 L
Mfstroke
1 0 0 r
.7679 .06964 m
.75221 .1012 L
.73699 .13357 L
.72439 .16225 L
.71373 .18843 L
.70389 .215 L
.69581 .23948 L
.68866 .26451 L
.68313 .28782 L
.67902 .30967 L
.67739 .32056 L
.67593 .33245 L
.67487 .34365 L
.67451 .34865 L
.67418 .35409 L
.67403 .35703 L
.67391 .35977 L
.67381 .36259 L
.67374 .36516 L
.67368 .36768 L
.67366 .36883 L
.67365 .37005 L
.67363 .37136 L
.67363 .37194 L
.67362 .37256 L
.67362 .37322 L
.67362 .37385 L
.67362 .37423 L
.67362 .37459 L
.67362 .37527 L
.67362 .37589 L
.67362 .37656 L
.67362 .37719 L
.67363 .37777 L
.67364 .37912 L
.67366 .38053 L
.67368 .38192 L
.6737 .38321 L
.67378 .38613 L
.67394 .391 L
.67419 .3962 L
.67454 .40182 L
.675 .40792 L
.67609 .41903 L
.67747 .43007 L
.67927 .44187 L
.6834 .46345 L
.68907 .48705 L
.69581 .51052 L
.7044 .53646 L
Mistroke
.71414 .56259 L
.7249 .58897 L
.73796 .61855 L
.75217 .64871 L
.7679 .68036 L
Mfstroke
0 0 1 r
.84098 .11531 m
.82101 .14215 L
.80163 .16968 L
.78559 .19407 L
.77203 .21634 L
.7595 .23893 L
.74922 .25975 L
.74012 .28103 L
.73308 .30086 L
.72785 .31944 L
.72577 .3287 L
.72391 .33881 L
.72257 .34834 L
.7221 .35259 L
.72169 .35722 L
.7215 .35972 L
.72135 .36204 L
.72122 .36445 L
.72113 .36663 L
.72106 .36877 L
.72103 .36975 L
.72101 .37079 L
.72099 .3719 L
.72099 .37239 L
.72098 .37292 L
.72098 .37349 L
.72097 .37402 L
.72097 .37434 L
.72097 .37465 L
.72097 .37523 L
.72097 .37576 L
.72097 .37632 L
.72098 .37686 L
.72098 .37736 L
.721 .3785 L
.72102 .37971 L
.72105 .38088 L
.72108 .38198 L
.72117 .38447 L
.72139 .38861 L
.72171 .39303 L
.72214 .39781 L
.72274 .40299 L
.72412 .41245 L
.72588 .42184 L
.72817 .43187 L
.73342 .45022 L
.74064 .47029 L
.74922 .49025 L
.76016 .51231 L
Mistroke
.77254 .53454 L
.78625 .55696 L
.80287 .58212 L
.82095 .60777 L
.84098 .63469 L
Mfstroke
1 0 0 r
.90095 .17097 m
.87746 .19205 L
.85468 .21368 L
.83582 .23284 L
.81988 .25034 L
.80514 .26809 L
.79305 .28445 L
.78235 .30117 L
.77407 .31675 L
.76792 .33135 L
.76548 .33862 L
.7633 .34657 L
.76172 .35405 L
.76117 .35739 L
.76067 .36103 L
.76045 .363 L
.76028 .36482 L
.76013 .36671 L
.76002 .36842 L
.75994 .37011 L
.75991 .37088 L
.75988 .37169 L
.75986 .37256 L
.75985 .37295 L
.75985 .37337 L
.75984 .37381 L
.75984 .37423 L
.75984 .37448 L
.75983 .37473 L
.75983 .37518 L
.75984 .37559 L
.75984 .37604 L
.75984 .37646 L
.75985 .37685 L
.75987 .37775 L
.75989 .3787 L
.75993 .37962 L
.75996 .38048 L
.76007 .38244 L
.76033 .38569 L
.7607 .38917 L
.76121 .39292 L
.76191 .39699 L
.76354 .40442 L
.76561 .4118 L
.7683 .41968 L
.77448 .4341 L
.78296 .44987 L
.79305 .46555 L
.80591 .48288 L
Mistroke
.82048 .50035 L
.83659 .51797 L
.85613 .53774 L
.8774 .55789 L
.90095 .57903 L
Mfstroke
0 0 1 r
.94551 .23446 m
.91941 .24899 L
.8941 .26388 L
.87315 .27708 L
.85543 .28913 L
.83906 .30136 L
.82562 .31263 L
.81373 .32415 L
.80453 .33488 L
.7977 .34493 L
.79498 .34994 L
.79256 .35542 L
.79081 .36057 L
.79019 .36287 L
.78965 .36538 L
.7894 .36673 L
.78921 .36799 L
.78904 .36929 L
.78892 .37047 L
.78883 .37163 L
.78879 .37216 L
.78876 .37272 L
.78874 .37332 L
.78873 .37359 L
.78873 .37388 L
.78872 .37418 L
.78872 .37447 L
.78871 .37465 L
.78871 .37481 L
.78871 .37512 L
.78871 .37541 L
.78872 .37572 L
.78872 .37601 L
.78873 .37628 L
.78875 .37689 L
.78878 .37755 L
.78881 .37818 L
.78886 .37878 L
.78898 .38012 L
.78926 .38236 L
.78967 .38476 L
.79025 .38734 L
.79102 .39015 L
.79283 .39527 L
.79513 .40035 L
.79812 .40578 L
.80498 .41571 L
.81441 .42657 L
.82562 .43737 L
.83991 .44931 L
Mistroke
.8561 .46134 L
.874 .47348 L
.89571 .48709 L
.91935 .50098 L
.94551 .51554 L
Mfstroke
1 0 0 r
.97295 .30335 m
.94525 .31076 L
.91838 .31835 L
.89613 .32508 L
.87732 .33123 L
.85994 .33746 L
.84568 .3432 L
.83306 .34907 L
.82329 .35454 L
.81603 .35967 L
.81315 .36223 L
.81058 .36502 L
.80872 .36764 L
.80807 .36882 L
.80749 .37009 L
.80723 .37078 L
.80702 .37143 L
.80684 .37209 L
.80672 .37269 L
.80662 .37328 L
.80658 .37355 L
.80655 .37384 L
.80653 .37414 L
.80652 .37428 L
.80651 .37443 L
.8065 .37458 L
.8065 .37473 L
.8065 .37482 L
.8065 .3749 L
.8065 .37506 L
.8065 .37521 L
.8065 .37537 L
.80651 .37551 L
.80651 .37565 L
.80653 .37597 L
.80656 .3763 L
.8066 .37662 L
.80665 .37693 L
.80678 .37761 L
.80708 .37875 L
.80751 .37998 L
.80812 .38129 L
.80894 .38272 L
.81087 .38533 L
.8133 .38792 L
.81648 .39069 L
.82377 .39575 L
.83378 .40129 L
.84568 .4068 L
.86085 .41288 L
Mistroke
.87803 .41902 L
.89704 .4252 L
.92009 .43215 L
.94518 .43922 L
.97295 .44665 L
Mfstroke
0 0 1 r
.98221 .375 m
.95397 .375 L
.92657 .375 L
.90389 .375 L
.88471 .375 L
.86699 .375 L
.85245 .375 L
.83958 .375 L
.82962 .375 L
.82223 .375 L
.81666 .375 L
.81351 .375 L
.8125 .375 L
.81359 .375 L
.81677 .375 L
.82245 .375 L
.8302 .375 L
.83983 .375 L
.85248 .375 L
.86709 .375 L
.88533 .375 L
.90568 .375 L
.92798 .375 L
.95477 .375 L
.98221 .375 L
s
.01779 .375 m
.01779 .37358 L
.0178 .37228 L
.01782 .37078 L
.01784 .36937 L
.01791 .36686 L
.018 .36413 L
.01813 .36112 L
.01831 .35794 L
.01872 .35223 L
.01926 .34634 L
.01988 .34083 L
.0217 .32832 L
.02413 .31562 L
.02687 .30405 L
.0348 .27831 L
.04366 .25632 L
.05537 .23286 L
.08431 .18887 L
.11923 .14967 L
.16326 .11213 L
.21168 .08063 L
.26303 .05515 L
.29058 .04419 L
.32182 .03374 L
.35274 .02529 L
.38153 .019 L
.41184 .01394 L
.42869 .01179 L
.44473 .01017 L
.46001 .00901 L
.46774 .00857 L
.47629 .00819 L
.48355 .00796 L
.48764 .00787 L
.48958 .00784 L
.49139 .00781 L
.49312 .00779 L
.49469 .00777 L
.49644 .00776 L
.4983 .00775 L
.5001 .00775 L
.50205 .00775 L
.50388 .00776 L
.50558 .00777 L
.50757 .00779 L
.50946 .00782 L
.51301 .00788 L
.51683 .00797 L
.52099 .0081 L
Mistroke
.52847 .00839 L
.53539 .00874 L
.55123 .00983 L
.56803 .01142 L
.58422 .01339 L
.60161 .016 L
.63275 .02194 L
.66299 .02936 L
.69412 .03882 L
.74782 .05996 L
.80068 .08789 L
.84652 .1196 L
.88896 .15792 L
.923 .19867 L
.94885 .24076 L
.9594 .26338 L
.96845 .28789 L
.97177 .29898 L
.97484 .31101 L
.97706 .32146 L
.97904 .33294 L
.98044 .34353 L
.98138 .35341 L
.98175 .35888 L
.98199 .36385 L
.98209 .3666 L
.98213 .36805 L
.98216 .36959 L
.98218 .37093 L
.9822 .37241 L
.98221 .37375 L
.98221 .375 L
Mfstroke
1 0 0 r
.09541 .375 m
.09541 .374 L
.09542 .3731 L
.09544 .37205 L
.09546 .37106 L
.09551 .3693 L
.09559 .36739 L
.0957 .36529 L
.09585 .36306 L
.09619 .35907 L
.09665 .35495 L
.09717 .35109 L
.09869 .34234 L
.10074 .33345 L
.10303 .32536 L
.10969 .30734 L
.11712 .29196 L
.12694 .27554 L
.15122 .24476 L
.18052 .21733 L
.21746 .19106 L
.25809 .16902 L
.30117 .1512 L
.32429 .14352 L
.35051 .13621 L
.37645 .1303 L
.4006 .1259 L
.42603 .12236 L
.44017 .12085 L
.45363 .11972 L
.46645 .11891 L
.47294 .1186 L
.48011 .11834 L
.4862 .11818 L
.48963 .11811 L
.49126 .11809 L
.49278 .11807 L
.49423 .11805 L
.49555 .11804 L
.49701 .11803 L
.49858 .11803 L
.50008 .11803 L
.50172 .11803 L
.50326 .11803 L
.50468 .11804 L
.50635 .11806 L
.50794 .11808 L
.51092 .11812 L
.51412 .11818 L
.51761 .11827 L
Mistroke
.52389 .11847 L
.5297 .11872 L
.54298 .11948 L
.55708 .1206 L
.57067 .12198 L
.58525 .1238 L
.61138 .12795 L
.63675 .13315 L
.66287 .13977 L
.70792 .15456 L
.75228 .1741 L
.79074 .19629 L
.82634 .22311 L
.8549 .25162 L
.87659 .28107 L
.88545 .29689 L
.89304 .31404 L
.89583 .32181 L
.8984 .33023 L
.90027 .33754 L
.90193 .34557 L
.9031 .35298 L
.90389 .35989 L
.9042 .36372 L
.9044 .3672 L
.90448 .36913 L
.90452 .37014 L
.90454 .37121 L
.90456 .37215 L
.90458 .37318 L
.90459 .37412 L
.90459 .375 L
Mfstroke
0 0 1 r
.14762 .375 m
.14762 .37437 L
.14763 .37379 L
.14764 .37313 L
.14766 .3725 L
.1477 .37139 L
.14777 .37018 L
.14787 .36885 L
.148 .36744 L
.14829 .3649 L
.14869 .36229 L
.14915 .35985 L
.15047 .3543 L
.15225 .34867 L
.15425 .34354 L
.16005 .33212 L
.16652 .32238 L
.17508 .31197 L
.19623 .29247 L
.22174 .27509 L
.25392 .25844 L
.28931 .24447 L
.32683 .23318 L
.34696 .22832 L
.36979 .22368 L
.39239 .21994 L
.41343 .21715 L
.43558 .2149 L
.44789 .21395 L
.45961 .21323 L
.47078 .21272 L
.47643 .21252 L
.48267 .21235 L
.48798 .21225 L
.49097 .21221 L
.49239 .2122 L
.49371 .21218 L
.49497 .21217 L
.49612 .21217 L
.4974 .21216 L
.49876 .21216 L
.50007 .21216 L
.50149 .21216 L
.50284 .21216 L
.50408 .21217 L
.50553 .21218 L
.50692 .21219 L
.50951 .21222 L
.5123 .21226 L
.51534 .21231 L
Mistroke
.5208 .21244 L
.52586 .2126 L
.53744 .21308 L
.54971 .21379 L
.56155 .21466 L
.57425 .21581 L
.59701 .21845 L
.6191 .22174 L
.64186 .22594 L
.6811 .23531 L
.71972 .24769 L
.75322 .26175 L
.78423 .27875 L
.80911 .29682 L
.828 .31548 L
.83571 .3255 L
.84233 .33637 L
.84475 .34129 L
.84699 .34663 L
.84862 .35126 L
.85006 .35635 L
.85109 .36105 L
.85177 .36542 L
.85204 .36785 L
.85222 .37006 L
.85229 .37128 L
.85232 .37192 L
.85234 .3726 L
.85236 .3732 L
.85237 .37385 L
.85238 .37444 L
.85238 .375 L
Mfstroke
1 0 0 r
.17768 .375 m
.17769 .37469 L
.17769 .37442 L
.1777 .37409 L
.17772 .37379 L
.17776 .37325 L
.17782 .37266 L
.17791 .37202 L
.17803 .37133 L
.1783 .37011 L
.17867 .36884 L
.17908 .36766 L
.1803 .36497 L
.18193 .36224 L
.18375 .35975 L
.18906 .35422 L
.19498 .34949 L
.2028 .34445 L
.22215 .33499 L
.24549 .32656 L
.27492 .3185 L
.30728 .31172 L
.34161 .30625 L
.36002 .30389 L
.3809 .30165 L
.40157 .29983 L
.42082 .29848 L
.44107 .29739 L
.45233 .29693 L
.46306 .29658 L
.47327 .29633 L
.47844 .29624 L
.48415 .29615 L
.48901 .2961 L
.49174 .29608 L
.49304 .29608 L
.49425 .29607 L
.4954 .29607 L
.49645 .29606 L
.49762 .29606 L
.49887 .29606 L
.50007 .29606 L
.50137 .29606 L
.5026 .29606 L
.50373 .29606 L
.50506 .29607 L
.50633 .29607 L
.5087 .29609 L
.51125 .29611 L
.51403 .29613 L
Mistroke
.51903 .2962 L
.52366 .29627 L
.53424 .29651 L
.54547 .29685 L
.5563 .29727 L
.56792 .29783 L
.58873 .29911 L
.60894 .3007 L
.62975 .30274 L
.66564 .30728 L
.70098 .31328 L
.73162 .3201 L
.75998 .32834 L
.78274 .3371 L
.80001 .34615 L
.80707 .35101 L
.81312 .35627 L
.81534 .35866 L
.81739 .36125 L
.81887 .36349 L
.8202 .36596 L
.82113 .36824 L
.82176 .37036 L
.82201 .37153 L
.82217 .3726 L
.82223 .3732 L
.82226 .37351 L
.82228 .37384 L
.8223 .37413 L
.82231 .37444 L
.82231 .37473 L
.82232 .375 L
Mfstroke
0 0 1 r
.1875 .375 m
.19003 .375 L
.19853 .375 L
.2118 .375 L
.2292 .375 L
.25239 .375 L
.27889 .375 L
.31105 .375 L
.34537 .375 L
.38093 .375 L
.42084 .375 L
.46064 .375 L
.49954 .375 L
.54095 .375 L
.58013 .375 L
.62034 .375 L
.65698 .375 L
.68968 .375 L
.72118 .375 L
.74776 .375 L
.77147 .375 L
.7895 .375 L
.80209 .375 L
.81012 .375 L
.8125 .375 L
s
1 0 0 r
.17768 .375 m
.17769 .37531 L
.17769 .37558 L
.1777 .37591 L
.17772 .37621 L
.17776 .37675 L
.17782 .37734 L
.17791 .37798 L
.17803 .37867 L
.1783 .37989 L
.17867 .38116 L
.17908 .38234 L
.1803 .38503 L
.18193 .38776 L
.18375 .39025 L
.18906 .39578 L
.19498 .40051 L
.2028 .40555 L
.22215 .41501 L
.24549 .42344 L
.27492 .4315 L
.30728 .43828 L
.34161 .44375 L
.36002 .44611 L
.3809 .44835 L
.40157 .45017 L
.42082 .45152 L
.44107 .45261 L
.45233 .45307 L
.46306 .45342 L
.47327 .45367 L
.47844 .45376 L
.48415 .45385 L
.48901 .4539 L
.49174 .45392 L
.49304 .45392 L
.49425 .45393 L
.4954 .45393 L
.49645 .45394 L
.49762 .45394 L
.49887 .45394 L
.50007 .45394 L
.50137 .45394 L
.5026 .45394 L
.50373 .45394 L
.50506 .45393 L
.50633 .45393 L
.5087 .45391 L
.51125 .45389 L
.51403 .45387 L
Mistroke
.51903 .4538 L
.52366 .45373 L
.53424 .45349 L
.54547 .45315 L
.5563 .45273 L
.56792 .45217 L
.58873 .45089 L
.60894 .4493 L
.62975 .44726 L
.66564 .44272 L
.70098 .43672 L
.73162 .4299 L
.75998 .42166 L
.78274 .4129 L
.80001 .40385 L
.80707 .39899 L
.81312 .39373 L
.81534 .39134 L
.81739 .38875 L
.81887 .38651 L
.8202 .38404 L
.82113 .38176 L
.82176 .37964 L
.82201 .37847 L
.82217 .3774 L
.82223 .3768 L
.82226 .37649 L
.82228 .37616 L
.8223 .37587 L
.82231 .37556 L
.82231 .37527 L
.82232 .375 L
Mfstroke
0 0 1 r
.14762 .375 m
.14762 .37563 L
.14763 .37621 L
.14764 .37687 L
.14766 .3775 L
.1477 .37861 L
.14777 .37982 L
.14787 .38115 L
.148 .38256 L
.14829 .3851 L
.14869 .38771 L
.14915 .39015 L
.15047 .3957 L
.15225 .40133 L
.15425 .40646 L
.16005 .41788 L
.16652 .42762 L
.17508 .43803 L
.19623 .45753 L
.22174 .47491 L
.25392 .49156 L
.28931 .50553 L
.32683 .51682 L
.34696 .52168 L
.36979 .52632 L
.39239 .53006 L
.41343 .53285 L
.43558 .5351 L
.44789 .53605 L
.45961 .53677 L
.47078 .53728 L
.47643 .53748 L
.48267 .53765 L
.48798 .53775 L
.49097 .53779 L
.49239 .5378 L
.49371 .53782 L
.49497 .53783 L
.49612 .53783 L
.4974 .53784 L
.49876 .53784 L
.50007 .53784 L
.50149 .53784 L
.50284 .53784 L
.50408 .53783 L
.50553 .53782 L
.50692 .53781 L
.50951 .53778 L
.5123 .53774 L
.51534 .53769 L
Mistroke
.5208 .53756 L
.52586 .5374 L
.53744 .53692 L
.54971 .53621 L
.56155 .53534 L
.57425 .53419 L
.59701 .53155 L
.6191 .52826 L
.64186 .52406 L
.6811 .51469 L
.71972 .50231 L
.75322 .48825 L
.78423 .47125 L
.80911 .45318 L
.828 .43452 L
.83571 .4245 L
.84233 .41363 L
.84475 .40871 L
.84699 .40337 L
.84862 .39874 L
.85006 .39365 L
.85109 .38895 L
.85177 .38458 L
.85204 .38215 L
.85222 .37994 L
.85229 .37872 L
.85232 .37808 L
.85234 .3774 L
.85236 .3768 L
.85237 .37615 L
.85238 .37556 L
.85238 .375 L
Mfstroke
1 0 0 r
.09541 .375 m
.09541 .376 L
.09542 .3769 L
.09544 .37795 L
.09546 .37894 L
.09551 .3807 L
.09559 .38261 L
.0957 .38471 L
.09585 .38694 L
.09619 .39093 L
.09665 .39505 L
.09717 .39891 L
.09869 .40766 L
.10074 .41655 L
.10303 .42464 L
.10969 .44266 L
.11712 .45804 L
.12694 .47446 L
.15122 .50524 L
.18052 .53267 L
.21746 .55894 L
.25809 .58098 L
.30117 .5988 L
.32429 .60648 L
.35051 .61379 L
.37645 .6197 L
.4006 .6241 L
.42603 .62764 L
.44017 .62915 L
.45363 .63028 L
.46645 .63109 L
.47294 .6314 L
.48011 .63166 L
.4862 .63182 L
.48963 .63189 L
.49126 .63191 L
.49278 .63193 L
.49423 .63195 L
.49555 .63196 L
.49701 .63197 L
.49858 .63197 L
.50008 .63197 L
.50172 .63197 L
.50326 .63197 L
.50468 .63196 L
.50635 .63194 L
.50794 .63192 L
.51092 .63188 L
.51412 .63182 L
.51761 .63173 L
Mistroke
.52389 .63153 L
.5297 .63128 L
.54298 .63052 L
.55708 .6294 L
.57067 .62802 L
.58525 .6262 L
.61138 .62205 L
.63675 .61685 L
.66287 .61023 L
.70792 .59544 L
.75228 .5759 L
.79074 .55371 L
.82634 .52689 L
.8549 .49838 L
.87659 .46893 L
.88545 .45311 L
.89304 .43596 L
.89583 .42819 L
.8984 .41977 L
.90027 .41246 L
.90193 .40443 L
.9031 .39702 L
.90389 .39011 L
.9042 .38628 L
.9044 .3828 L
.90448 .38087 L
.90452 .37986 L
.90454 .37879 L
.90456 .37785 L
.90458 .37682 L
.90459 .37588 L
.90459 .375 L
Mfstroke
0 0 1 r
.01779 .375 m
.01779 .37642 L
.0178 .37772 L
.01782 .37922 L
.01784 .38063 L
.01791 .38314 L
.018 .38587 L
.01813 .38888 L
.01831 .39206 L
.01872 .39777 L
.01926 .40366 L
.01988 .40917 L
.0217 .42168 L
.02413 .43438 L
.02687 .44595 L
.0348 .47169 L
.04366 .49368 L
.05537 .51714 L
.08431 .56113 L
.11923 .60033 L
.16326 .63787 L
.21168 .66937 L
.26303 .69485 L
.29058 .70581 L
.32182 .71626 L
.35274 .72471 L
.38153 .731 L
.41184 .73606 L
.42869 .73821 L
.44473 .73983 L
.46001 .74099 L
.46774 .74143 L
.47629 .74181 L
.48355 .74204 L
.48764 .74213 L
.48958 .74216 L
.49139 .74219 L
.49312 .74221 L
.49469 .74223 L
.49644 .74224 L
.4983 .74225 L
.5001 .74225 L
.50205 .74225 L
.50388 .74224 L
.50558 .74223 L
.50757 .74221 L
.50946 .74218 L
.51301 .74212 L
.51683 .74203 L
.52099 .7419 L
Mistroke
.52847 .74161 L
.53539 .74126 L
.55123 .74017 L
.56803 .73858 L
.58422 .73661 L
.60161 .734 L
.63275 .72806 L
.66299 .72064 L
.69412 .71118 L
.74782 .69004 L
.80068 .66211 L
.84652 .6304 L
.88896 .59208 L
.923 .55133 L
.94885 .50924 L
.9594 .48662 L
.96845 .46211 L
.97177 .45102 L
.97484 .43899 L
.97706 .42854 L
.97904 .41706 L
.98044 .40647 L
.98138 .39659 L
.98175 .39112 L
.98199 .38615 L
.98209 .3834 L
.98213 .38195 L
.98216 .38041 L
.98218 .37907 L
.9822 .37759 L
.98221 .37625 L
.98221 .375 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 186.313},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000^R000`400?l00000o`00003oQ`3oool0
0`000000oooo0?ooo`2F0?ooo`00Q`3oool00`000000oooo0?ooo`2F0?ooo`00NP3ooolK0000oh/0
oooo001a0?ooo`T0003o3@3oool00`000?l0oooo0?ooo`0;0?ooo`L0003o00<0o`000?ooo`3oool0
P@3oool006`0oooo1@000?l20?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04P3o
ool60000ogh0oooo001Y0?ooo`<0003o1`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0180oooo00<0o`000?ooo`3oool00`3oool50000ogT0oooo001V0?ooo`<0003o2P3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0203oool40000
ogD0oooo001R0?ooo`@0003o3@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0180
oooo00<0o`000?ooo`3oool0303oool30000og80oooo001N0?ooo`@0003o4P3oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool40000ofh0oooo
001K0?ooo`@0003o5@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04`3oool40000of/0oooo001H0?ooo`<0003o103oool00`000?l0oooo0?ooo`0B
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo0080oooo0P000?mY0?ooo`00E@3oool30000o`L0oooo00<0003o0?oo
o`3oool04P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`040?ooo`80003oI`3oool005<0oooo0P000?l:0?ooo`03
0000o`3oool0oooo0180oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`070?ooo`<0
003oI03oool00540oooo0P000?l=0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
2@3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0:0?ooo`80003oHP3oool004l0oooo0P000?l?0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool0100000050?ooo`030000003oool0oooo00@0oooo00<0
003o0000000000004@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00`0oooo0P00
0?mP0?ooo`00C@3oool20000oa80oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`09
0?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo00l0oooo0P000?mN0?ooo`00B`3oool20000oa@0oooo00<0003o0?oo
o`3oool0403oool00`3o0000oooo0?ooo`070?ooo`030000003oool0000000H0oooo00<0003o0?oo
o`3oool0403oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo0P000?mL0?oo
o`00B@3oool20000o`030?ooo`3o0000oooo01<0oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`070?ooo`8000001P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04P3oool00`3o0000003o0000o`1J0?ooo`00A`3oool20000o`@0oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00P0oooo
00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool04P3oool0103o0000oooo0?ooo`3oool20000oeP0oooo00150?ooo`80003o
1P3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
4P3oool00`3o0000oooo0?ooo`030?ooo`80003oEP3oool004@0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo05<0oooo00130?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool01`3oool20000oe<0oooo00110?ooo`80003o303oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0500oooo00100?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool02`3oool20000oe00oooo000n0?ooo`80003o403oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo
0?ooo`0>0?ooo`80003oCP3oool003d0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo04/0oooo000l0?ooo`030000o`3oool0oooo0180oooo00<0o`00
0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00X0oooo2@3o000=
0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0B
0?ooo`80003oB`3oool003X0oooo0P000?l00`3oool0003o0?ooo`0B0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool03P3oool>0?l000@0oooo00<0003o0?ooo`3oool00P3oool>0?l0
0140oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0A0?ooo`040000o`3oool0oooo
0000odX0oooo000i0?ooo`050000o`3oool0oooo0?ooo`000?l0503oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo00P0oooo1P3o00000`3oool0o`000?ooo`0?0?ooo`030000o`3oool0
oooo00l0oooo103o000>0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool04P3oool0
1@000?l0oooo0?ooo`3oool0003o04T0oooo000h0?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00<0oooo1@3o0007
0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03`3oool0103o0000oooo0?ooo`3o
ool60?l000P0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0AP3oool003L0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00l0oooo1@3o000<0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`070?ooo`H0o`0000<0oooo
0000o`3oool0403oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool0A@3oool003D0oooo0P000?l80?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool0303oool30?l000030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00d0oooo1@3o000=0?ooo`030?l0003oool0oooo
0180oooo00<0003o0?ooo`3oool01P3oool20000odD0oooo000d0?ooo`030000o`3oool0oooo00T0
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`080?ooo`<0o`000`3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0?0?ooo`040000o`3oool0oooo0?ooo`80o`002`3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0@P3oool003<0oooo00<0003o0?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00H0oooo0P3o00070?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0103oool30?l000L0oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo0440oooo000b0?ooo`030000
o`3oool0oooo00`0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`020?ooo`<0o`00
2@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00L0oooo0P3o00050?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`100?ooo`00<@3o
ool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool00P3o
000<0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool30?l000030?ooo`3o
0000oooo0180oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0o0?ooo`00<03oool0
0`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo0100oooo0P3o000?0?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool03@3oool20?l00180oooo00<0003o0?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0n0?ooo`00;`3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo
00h0oooo0`3o000@0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool40?l0
00l0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0m0?ooo`00;P3oool00`3o0000
003o0?ooo`0C0?ooo`030000o`3oool0oooo00/0oooo0P3o00030?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080
oooo0P3o000<0?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0?03oool002h0oooo
00<0003o0?l0003oool0503oool00`000?l0oooo0?ooo`080?ooo`80o`001@3oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`040?ooo`80o`002@3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0003o03d0oooo
000]0?ooo`040000o`3oool0oooo0?l001D0oooo00<0003o0?ooo`3oool01@3oool20?l000L0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool01P3oool20?l000H0oooo00<0003o0?ooo`3oool04`3oool0103o0000oooo
0?ooo`000?lm0?ooo`00;03oool00`000?l0oooo0?ooo`020?ooo`80o`004`3oool00`000?l0oooo
0?ooo`030?ooo`80o`002P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool04@3oool20?l000@0oooo00<0003o0?ooo`3oool0>P3oool002/0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0080o`00303o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0:0?ooo`80o`000P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0>@3oool002X0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3o0000oooo00d0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303oool2
0?l001<0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0h0?ooo`00:P3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00l0oooo0P3o00000`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o00004@3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo03L0oooo000Y0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool03@3oool0103o0000oooo0?ooo`000?l?0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00@0003o0?oo
o`3oool0o`003`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo03L0oooo000Y0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool20?l000@0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo0080oooo0P3o000<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0=P3oool002P0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool01@3oool?0000o`P0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0=P3oool002L0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`050?ooo`80o`00203oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool01`3oool=0000o`L0oooo00<0003o0?ooo`3oool0
1@3oool<0000o`/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo03D0oooo000W0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`020?ooo`D0003o1@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00d0oooo00@0o`000?ooo`3oool0oooo2`000?l?0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0203oool20?l000D0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0e0?ooo`009P3oool00`000?l0oooo0?ooo`0B0?ooo`050?l0003oool0oooo0?ooo`3o0000
303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo1@000?l:0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0;0?ooo`@0003o
2`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00X0oooo00D0o`000?ooo`3oool0
oooo0?l0000D0?ooo`030000o`3oool0oooo03@0oooo000V0?ooo`030000o`3oool0oooo01<0oooo
00<0o`000?ooo`3o00003P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00H0oooo
1P000?l>0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0;0?ooo`040000o`3oool0oooo0?ooo`<0003o203oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3o00005@3oool00`000?l0oooo0?ooo`0d0?ooo`00
903oool20000oaL0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0<0?ooo`040?l0
003oool0oooo0?ooo`@0003o1P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00@0
oooo0`000?l40?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0E0?ooo`80003o=03oool002@0oooo0`000?lE0?ooo`030?l0003oool0o`0000l0oooo
00<0003o0?ooo`3oool02`3oool0103o0000oooo0000o`000?l:0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool0203oool30000o`030?ooo`3o0000oooo00`0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?l0000E0?ooo`80003o=@3oool002@0oooo00@0003o0?ooo`3oool0
003o4`3oool0103o0000oooo0?ooo`3o000?0?ooo`030000o`3oool0oooo00X0oooo0`000?l<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool40000o`/0oooo00<0003o0?oo
o`3oool0303oool01@3o0000oooo0?ooo`3oool0o`0001<0oooo00@0003o0?ooo`3oool0003o=03o
ool002<0oooo00<0003o0?ooo`3oool00P3oool20000oa00oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00H0oooo0`000?l20?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`040?l0003oool0
oooo0?ooo`@0003o1P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool03P3oool20000o`@0oooo00<0003o0?ooo`3oool0<@3oool002<0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`040?ooo`80003o1@3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`05
0?ooo`80003o103oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0340oooo000R0?oo
o`030000o`3oool0oooo00H0oooo0P000?l;0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`030000o`L0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool01`3oool40000
o`h0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`090?ooo`80003o203oool00`00
0?l0oooo0?ooo`0`0?ooo`008P3oool00`000?l0oooo0?ooo`080?ooo`80003o203oool00`3o0000
oooo0?ooo`080?ooo`030?l0003oool0oooo00/0oooo0`000?l;0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0
oooo0P000?l<0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool20000o`X0
oooo00<0003o0?ooo`3oool0<03oool00240oooo00<0003o0?ooo`3oool02`3oool20000o`H0oooo
00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`<0003o3@3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0;0?ooo`040000o`3oool0003o0000o`T0oooo00<0o`000?ooo`3oool02@3oool00`3o0000
oooo0?ooo`040?ooo`80003o3@3oool00`000?l0oooo0?ooo`0_0?ooo`008@3oool00`000?l0oooo
0?ooo`0=0?ooo`80003o0`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00D0oooo
0P000?l30?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`020?ooo`80003o1P3oool00`3o0000oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?ooo`80
003o3`3oool00`000?l0oooo0?ooo`0_0?ooo`00803oool00`000?l0oooo0?ooo`0@0?ooo`80003o
00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`80003o1@3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0103oool20000o`<0oooo
00<0o`000?ooo`3oool03@3oool00`3o0000003o0000o`0B0?ooo`030000o`3oool0oooo02h0oooo
000P0?ooo`030000o`3oool0oooo0140oooo00<0o`000000o`3oool03P3oool00`3o0000oooo0?oo
o`020000o`P0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00L0oooo00@0003o0?ooo`3oool0o`003`3oool00`3o0000oooo0?ooo`0B0?ooo`030000
o`3oool0oooo02h0oooo000P0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool00P00
0?l>0?ooo`030?l000000?l0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?l0003oool03@3oool20000o`030?ooo`3o
0000oooo01<0oooo00<0003o0?ooo`3oool0;@3oool001l0oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00X0oooo0P000?l00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`09
0?ooo`030?l000000?l0003o00/0oooo0P000?l40?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool0;@3oool001l0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00P0oooo00@0003o0?ooo`3oool0o`002`3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool01@3o0000oooo0?ooo`3o
ool0003o00T0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo02d0oooo000O0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool01@3oool2
0000o`L0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooob00o`002P3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo02d0oooo000N0?ooo`030000o`3oool0oooo
0100oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00P0oooo3`3o000=0?ooo`030000o`3oool0oooo00/0oooo00@0o`000?ooo`3oool0oooo3@3o0009
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo02d0oooo000N0?ooo`030000o`3o0000o`000100oooo00<0o`000?oo
o`3oool02@3oool01@000?l0oooo0?ooo`3oool0003o00L0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`090?ooo`/0o`0000<0oooo0000o`3oool0303oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`04
0?l000D0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00H0oooo00D0003o0?ooo`3oool0oooo0000o`0;0?ooo`030?l0003oool0oooo00d0oooo0P3o
00000`000?l0o`000?ooo`0]0?ooo`007P3oool00`000?l0oooo0?ooo`050?l000/0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0000o`090?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01@3oool50?l000/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`04
0?ooo`H0o`002P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`000?l0303oool00`3o0000oooo0?ooo`080?ooo`D0o`000`3oool00`000?l0oooo0?ooo`0/
0?ooo`007P3oool00`000?l0oooo0?ooo`050?ooo`<0o`001`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`040?l0
00@0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00T0oooo2@3o00020?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00@0oooo0`3o00080?ooo`030000o`3oool0oooo
02`0oooo000N0?ooo`030000o`3oool0oooo00P0oooo103o00030?ooo`030?l0003oool0oooo00/0
oooo00@0003o0?ooo`000?l0003o2@3oool00`3o0000oooo0?ooo`060?ooo`@0o`00203oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`060?ooo`D0o`001`3oool00`3o0000oooo0?ooo`070?ooo`80003o00<0oooo0000
o`3oool0303oool0103o0000oooo0?ooo`3oool30?l000`0oooo00<0003o0?ooo`3oool0:`3oool0
01d0oooo00<0003o0?ooo`3oool03@3oool40?l000`0oooo00<0003o0?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0000000@0oooo00<0o`000?ooo`3oool00`3oool30?l000030?ooo`000?l0
oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`030?l000@0oooo00<0o`00
0?ooo`3oool01P3oool01@000?l0oooo0?ooo`3oool0003o00d0oooo103o000?0?ooo`030000o`3o
ool0oooo02/0oooo000M0?ooo`030000o`3oool0oooo00l0oooo00@0o`000?ooo`3o0000o`002@3o
ool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo000000D0oooo00<0o`000?ooo`3o0000
0P3o00040?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`030?ooo`@0o`00203oool00`000?l000000?ooo`030?ooo`030000o`3oool0oooo00P0oooo
0`3o000B0?ooo`030000o`3oool0oooo02/0oooo000M0?ooo`030000o`3oool0oooo00l0oooo00@0
o`000?ooo`3oool0oooo0`3o00060?ooo`030000o`0000000000008000000P3oool010000?l0oooo
0?ooo`0000050?ooo`80o`001`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool01P3oool20?l000L0oooo00<0003o0000003oool0103oool00`000?l0
oooo0?ooo`040?ooo`<0o`000`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo02/0
oooo000M0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool01@3oool30?l000<0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo000000020?ooo`@0o`002@3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`020?l000@0oooo00<0003o0?ooo`0000001P3oool00`000?l0oooo0?ooo`030?l000H0oooo
00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0[0?ooo`007@3oool00`000?l0oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00P0oooo0P3o00000`000?l0oooo0?ooo`060?ooo`030000o`3o
ool000000080o`000`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo0P3o
00001@3oool0003o0000003oool0000000H0oooo00<0003o0?l0003o00002@3oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo02/0oooo000M0?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0o`000?ooo`070?ooo`80o`001P3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00@0oooo0P3o00000`3oool00000000000050?ooo`030?l0003o
ool0003o00/0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0[0?ooo`00703oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool00P3o0005
0?ooo`030?l0003oool0003o00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`04
0?ooo`050000o`3oool0o`000?l0000000000`3oool20?l00080oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo02/0oooo000L0?ooo`030000o`3oool0
oooo00l0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`80o`0000<0oooo
0?l0003o00000P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool0103oool01P000?l0oooo0?ooo`3oool0o`000?ooo`80o`00103oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0:P3oool001`0oooo00<0
003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`80o`001`3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01@3oool20?l000D0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0Z0?ooo`00703oool00`000?l0oooo0?ooo`0?
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0103oool30?l000@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00P3oool20?l000L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo00X0oooo0`00000M0?ooo`00703oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0103oool0103o0000oooo0?ooo`3o0003
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`090?ooo`040000003o
ool0oooo000001d0oooo000L0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080o`000P3oool20000o`D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`3o0000
0P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`090?ooo`040000003oool0oooo000001d0oooo000H0?ooo`@00000
4P000?l00`3o0000003o0000o`0?0000o`030?l000000?l0003o08`0003o00<0o`000000o`000?l0
3`000?l00`3o0000003o0000o`0@0000o`@000001`3oool010000000oooo0?ooo`00000M0?ooo`00
703oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
103oool0103o0000oooo0000003o00030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`080000o`3oool0oooo0?ooo`3o000000000?ooo`3o
00060?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`090?ooo`040000003oool0oooo000001d0oooo000L0?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`040?ooo`<0o`00103oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`020?ooo`<0o`001P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00l0oooo00<0
003o0?ooo`3oool0:P3oool001`0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo02X0oooo000L0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`80o`0000<0oooo0?l0003oool00P3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool01P00
0?l0oooo0?ooo`3oool0o`000?ooo`80o`00103oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3oool0:P3oool001`0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo0080o`00103oool20?l000030?ooo`000?l0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0
oooo0?l000@0oooo0P3o00020?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0Z0?ooo`007@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3o0000203oool20?l000H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`80o`001`3oool00`3o0000oooo0000o`0;0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool0:`3oool001d0oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`090?ooo`030?l000000?l0oooo00P0oooo00@0003o0?ooo`3o0000o`000`3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo0P3o00000`000?l0oooo0?ooo`07
0?ooo`030000o`3o0000oooo00T0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0[
0?ooo`007@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0oooo103o00000`3o
ool0003o0?ooo`070?ooo`030000o`3oool0oooo0080oooo103o00090?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0o`00
0080o`000`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0o`0000<0o`001P3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo02/0oooo000M0?ooo`030000o`3oool0oooo00l0
oooo00@0o`000?ooo`3oool0oooo0`3o00060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool20?l000L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00L0oooo0P3o00060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool30?l000<0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0[0?oo
o`007@3oool00`000?l0oooo0?ooo`0?0?ooo`040?l0003oool0o`000?l000T0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0o`00103oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool40?l0
00P0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`070?ooo`80o`0000<0oooo0?l0
003oool0403oool00`000?l0oooo0?ooo`0[0?ooo`007@3oool00`000?l0oooo0?ooo`0=0?ooo`@0
o`00303oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool00`3oool30?l000030?ooo`000?l0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`030?l000<0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00X0oooo103o000?0?ooo`030000o`3oool0oooo02/0oooo000N0?ooo`030000
o`3oool0oooo00P0oooo103o00020?ooo`030?l0003oool0oooo00`0oooo00@0003o0?ooo`000?l0
003o203oool00`3o0000oooo0?ooo`070?ooo`<0o`002@3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`D0
o`001`3oool00`3o0000oooo0?ooo`070?ooo`80003o00<0oooo0000o`3oool0303oool0103o0000
oooo0?ooo`3oool40?l000/0oooo00<0003o0?ooo`3oool0:`3oool001h0oooo00<0003o0?ooo`3o
ool01@3oool30?l000L0oooo00<0o`000?ooo`3oool02`3oool20000o`X0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?l000030?l000D0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00T0oooo00@0o`000?ooo`3oool0oooo1@3o00020?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00D0oooo0P3o00080?ooo`030000o`3oool0oooo02`0oooo000N0?ooo`04
0000o`3oool0oooo0?ooo`@0o`002P3oool00`3o0000oooo0?ooo`0;0?ooo`80003o2P3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo1P3o000;0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool02@3oool40?l000L0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0003o00`0oooo00<0o`000?ooo`3oool0203oool50?l0
00<0oooo00<0003o0?ooo`3oool0;03oool001h0oooo00@0003o0?l0003o0000o`003`3oool00`3o
0000oooo0?ooo`090?ooo`040000o`3oool0oooo0000o`P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`090?ooo`/0o`0000<0oooo0000o`3oool0303oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`03
0?ooo`L0o`002`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00D0003o
0?ooo`3oool0oooo0000o`0;0?ooo`030?l0003oool0oooo00d0oooo0P3o00000`000?l0o`000?oo
o`0]0?ooo`007P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool00P3oool20000o`H0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00P0oooo2@3o00050?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?ooo`l0o`001P3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0]
0?ooo`007`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00D0oooo9P3o00090?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0;@3oool001l0oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`040?ooo`80003o2@3oool010000?l0oooo0?ooo`3o000;0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?oo
o`050?l0003oool0oooo0?ooo`000?l02@3oool20000o`D0oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0]0?ooo`007`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool02P3oool20000o`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000000
o`000?l0303oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool0;@3oool00200oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`020000o`h0
oooo00<0o`000000o`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool0203oool00`000?l0o`000?ooo`0=0?ooo`80003o00<0oooo0?l0003o
ool04`3oool00`000?l0oooo0?ooo`0]0?ooo`00803oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
00000?l0oooo00h0oooo00<0o`000?ooo`3oool00P000?l80?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0o`000100oooo
00<0o`000000o`3oool04P3oool00`000?l0oooo0?ooo`0^0?ooo`00803oool00`000?l0oooo0?oo
o`0?0?ooo`80003o00<0oooo0?l0003oool03@3oool00`3o0000oooo0?ooo`030?ooo`80003o1@3o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01@3o
ool20000o`<0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0000o`0B0?ooo`030000o`3o
ool0oooo02h0oooo000Q0?ooo`030000o`3oool0oooo00`0oooo0P000?l40?ooo`030?l0003oool0
oooo00/0oooo00<0o`000?ooo`3oool01@3oool20000o`<0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo0080oooo0P000?l50?ooo`030?l0003oool0
oooo00`0oooo00@0o`000?ooo`3oool0oooo0P000?l?0?ooo`030000o`3oool0oooo02l0oooo000Q
0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00P0oooo0`000?l<0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool00P000?l80?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo02l0oooo000R0?ooo`030000o`3oool0oooo
00T0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo
00/0oooo0P000?l;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo0P000?l;0?ooo`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`3oool01P3oool20000o`/0oooo00<0003o0?ooo`3oool0<03oool00280
oooo00<0003o0?ooo`3oool01`3oool20000o`X0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`0<0?ooo`040000o`3oool0003o0000o`T0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0203oool30000
o`d0oooo0P3o00080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`00
0?l0oooo0?ooo`0`0?ooo`008`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo0080
oooo0P000?l60?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00D0oooo0`000?l30?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0:0?ooo`80003o1`3oool00`000?l0
oooo0?ooo`0a0?ooo`008`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00@0oooo
0P000?l40?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`040?l0003oool0oooo0?ooo`<0003o1P3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo0340oooo000T0?ooo`040000o`3oool0oooo0?ooo`80003o403oool01@3o0000
oooo0?ooo`3oool0o`0000l0oooo00<0003o0?ooo`3oool01`3oool30000o`030?ooo`3o0000oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`040?l0003oool0003o
0000o`X0oooo00<0003o0?ooo`3oool0303oool01@3o0000oooo0?ooo`3oool0o`000140oooo0P00
0?l30?ooo`030000o`3oool0oooo0380oooo000T0?ooo`040000o`3oool0003o0000oa<0oooo00@0
o`000?ooo`3oool0o`003`3oool00`000?l0oooo0?ooo`0:0?ooo`@0003o2`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo0`000?l<0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3o0000503oool30000ocD0oooo000T0?ooo`80003o5P3oool20?l000l0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`040000o`L0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`060?ooo`@0003o00<0oooo0?l0003oool03@3oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo01D0oooo0P000?ld0?ooo`009P3oool00`000?l0oooo0?ooo`0C
0?ooo`80o`003`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00D0oooo1@000?l0
0`3oool0003o0?ooo`0=0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo0080oooo10000?l60?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?l0000E0?ooo`030000o`3oool0
oooo03@0oooo000V0?ooo`030000o`3oool0oooo0180oooo00@0o`000?ooo`3oool0o`003@3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo1P000?l:0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0;0?ooo`D0003o2P3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00X0oooo00D0o`000?ooo`3oool0oooo0?l0
000D0?ooo`030000o`3oool0oooo03@0oooo000W0?ooo`030000o`3oool0oooo0100oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`020?ooo`@0003o1P3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00d0oooo00@0o`000?ooo`3oool0oooo2`000?l?0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool0=@3oool002L0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo2`000?l:0?ooo`030000o`3oool0
oooo00P0oooo2@000?l;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`060?ooo`80o`001`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo03D0oooo000X0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool01P3oool20?l0
00L0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool00P3ooolE0000o`D0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`080?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0=P3oool002T0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`090?ooo`80o`001@3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0=P3oool002T0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`80o`000P3oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool00P3o000>0?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool0=`3oool002X0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0?0?ooo`80o`0000<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0o`000140oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0g0?ooo`00:P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo0140oooo00<0003o
0?l0003oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`80o`004`3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo03P0oooo000[0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`020?l000`0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool02`3oool0103o
0000oooo0?ooo`000?lC0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0>@3oool0
02`0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo
0080oooo0P3o00090?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00T0oooo0P3o00030?ooo`030000o`3oool0oooo
0180oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0j0?ooo`00;@3oool00`000?l0
oooo0?ooo`020?l001@0oooo00<0003o0?ooo`3oool01@3oool20?l000L0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool01P3oool20?l000H0oooo00<0003o0?ooo`3oool04P3oool20?l00080oooo00<0003o0?ooo`3o
ool0>`3oool002h0oooo00<0003o0?l0003oool0503oool00`000?l0oooo0?ooo`080?ooo`80o`00
103oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
4`3oool00`3o0000oooo0000o`0m0?ooo`00;P3oool00`3o0000003o0?ooo`0D0?ooo`030000o`3o
ool0oooo00X0oooo0P3o00020?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00<0oooo0P3o000:0?ooo`030000o`3o
ool0oooo01@0oooo00<0003o0?ooo`3oool0?03oool002l0oooo00<0003o0?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`0=0?ooo`80o`004@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool00P3o000=0?ooo`030000o`3oool0oooo0180oooo00<0003o
0?ooo`3oool0?@3oool00300oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?oo
o`<0o`003`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo0`3o000@0?oo
o`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0?P3oool00340oooo00<0003o0?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0080o`00303oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00`0oooo0P3o000C0?ooo`030000o`3oool0oooo00h0
oooo00<0003o0?ooo`3oool0?`3oool00380oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0003oool0oooo00<0oooo0`3o00090?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo
00<0003o0?ooo`3oool02@3oool30?l00080oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0=0?ooo`030000o`3oool0oooo0400oooo000c0?ooo`030000o`3oool0oooo00/0oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`060?ooo`80o`001`3oool00`000?l0oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00H0oooo0`3o00050?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`110?ooo`00=03oool00`000?l0oooo0?ooo`09
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0203oool30?l000<0oooo00<0003o
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool03`3oool010000?l0oooo0?ooo`3oool40?l000T0oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0480oooo000e0?ooo`80003o203oool0
0`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00/0oooo0`3o00000`000?l0oooo0?ooo`0?
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0?
0?ooo`@0o`003@3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00H0oooo0P000?m5
0?ooo`00=`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool03`3oool40?l000d0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo00P0oooo1P3o00000`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`150?ooo`00>03oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`020?ooo`H0o`001`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool00P3oool60?l000H0oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0B0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0AP3oool003T0oooo
00D0003o0?ooo`3oool0oooo0000o`0D0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3o
ool0203oool50?l00080oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0?0?ooo`D0
o`003@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0180oooo00D0003o0?ooo`3o
ool0oooo0000o`190?ooo`00>P3oool20000o`030?ooo`000?l0oooo01<0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0=0?ooo`/0o`00203oool00`000?l0oooo0?ooo`060?ooo`X0
o`004@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0180oooo00@0003o0?ooo`3o
ool0003oBP3oool003`0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool01P3ooolA0?l000T0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0180oooo0P000?m;0?ooo`00
?@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
403oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
B`3oool003h0oooo0P000?l@0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0403o
ool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo0P000?m>0?ooo`00@03oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00/0oooo0P000?m@0?ooo`00@@3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool03`3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0D03oool00480
oooo0P000?l:0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0403oool00`3o0000
oooo0?ooo`0?0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0403oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo00L0oooo0P000?mC0?ooo`00A03oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0D`3oool004D0oooo0P00
0?l60?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0?0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0B0?ooo`030?l0003oool0oooo00<0oooo0P000?mF0?ooo`00A`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0B
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0EP3oool004P0oooo0P000?l20?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0?0?oo
o`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0B0?oo
o`040?l0003oool0003o0000oeT0oooo001:0?ooo`80003o00<0o`000?ooo`3oool04P3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04P3oool20000
oe/0oooo001<0?ooo`80003o4`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00T0
oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`1K0?ooo`00CP3oool20000oa00oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo
00<0003o0000000000004@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00h0oooo
0P000?mN0?ooo`00D03oool20000o`h0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`090?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo00`0oooo0P000?mP0?ooo`00DP3oool30000o`X0oooo00<0003o
0?ooo`3oool04P3oool00`3o0000oooo0?ooo`070?ooo`030000003oool0000000H0oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00T0oooo0`000?mR
0?ooo`00E@3oool30000o`L0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`080?oo
o`8000001P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool01@3oool30000ofD0oooo001H0?ooo`<0003o103oool00`000?l0oooo0?ooo`0B0?ooo`03
0?l0003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0180oooo00<0003o0?ooo`3oool00P3oool30000ofP0oooo001K0?ooo`@0003o
5@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4`3oool40000of/0oooo001N0?ooo`@0003o4P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool0403oool40000ofh0oooo001R0?ooo`@0003o3@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0303oool3
0000og80oooo001V0?ooo`<0003o2P3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0180oooo00<0o`000?ooo`3oool0203oool40000ogD0oooo001Y0?ooo`<0003o1`3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool00`3oool50000ogT0
oooo001/0?ooo`D0003o0P3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0180oooo
00<0o`000000o`000?l00`000?mn0?ooo`00L@3oool90000o`d0oooo00<0003o0?ooo`3oool0303o
ool70000oh<0oooo001j0?oooa`0003oRP3oool008L0oooo00<000000?ooo`3oool0UP3oool008L0
oooo00<000000?ooo`3oool0UP3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool008L0oooo00<000000?ooo`3oool0UP3oool008H0oooo00<000000?ooo`000000
U`3oool008H0oooo00<000000?ooo`000000U`3oool008H0oooo00<000000?ooo`000000U`3oool0
08D0oooo00D000000?ooo`3oool0oooo0000002F0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 287}, {185.313, 0}} -> {-1, -1, 0, 0}}],
  StyleBox["  \n\t\t\t\tFigure 5.A",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The mapping  ",
  Cell[BoxData[
      \(w\  = \(u + \[ImaginaryI]\ v = sin\ z\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "These equations in turn are used to obtain the following important \
identities \n\n",
  StyleBox["(5-34)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(sin\ z\  = \ \(sin \((x + \[ImaginaryI]\ y)\)\  = \ 
          sin\ x\ cosh\ y\  + \ \[ImaginaryI]\ cos\ x\ sinh\ y\)\)]],
  ", \n\n",
  StyleBox["(5-35)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(cos\ z\  = \ \(cos \((x + \[ImaginaryI]\ y)\)\  = \ 
          cos\ x\ cosh\ y\  - \ \[ImaginaryI]\ sin\ x\ sinh\ y\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tSubtracting Equation ",
  StyleBox["(5-31) ",
    FontColor->RGBColor[0, 0, 1]],
  "from Equation ",
  StyleBox["(5-30)",
    FontColor->RGBColor[0, 0, 1]],
  " and solving for ",
  Cell[BoxData[
      \(sin\ z\)]],
  " gives \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(sin\ z\ \  = \ \(\(1\/\(2  \[ImaginaryI]\)\) \((\ \
\[ExponentialE]\^\(\[ImaginaryI]\ z\)\  - \ \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ z\)\ )\)\  = \ \ \(1\/\(2  \[ImaginaryI]\)\) \((\
\[ExponentialE]\^\(\[ImaginaryI]\ \((x + \[ImaginaryI]\ y)\)\)\  - \ \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \((x + \[ImaginaryI]\ y)\)\))\)\)\), 
        "\n"}], "\[IndentingNewLine]", 
      RowBox[{
        "             ", \(\(=\)\(\ \ \)\(\(1\/\(2  \[ImaginaryI]\)\) \((\
\[ExponentialE]\^\(\(-y\) + \[ImaginaryI]\ x\)\  - \ \[ExponentialE]\^\(y - \
\[ImaginaryI]\ x\))\)\)\), "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"             ", 
        RowBox[{"=", "  ", 
          RowBox[{\(1\/\(2  \[ImaginaryI]\)\), 
            RowBox[{
              StyleBox["(",
                
                FontSize->
                  16], \(\[ExponentialE]\^\(-y\)\ \((cos\ x + \[ImaginaryI]\ \
sin\ x)\) - \[ExponentialE]\^y\ \((cos\ x - \[ImaginaryI]\ sin\ x)\)\), 
              StyleBox[")",
                FontSize->16]}]}]}], "\[IndentingNewLine]"}], "\n", 
      RowBox[{
        "             ", \(\(=\)\(\ \ \)\(sin\ x \( \[ExponentialE]\^y + \
\[ExponentialE]\^\(-y\)\)\/2\  + \ \[ImaginaryI]\ cos\ x \( \
\[ExponentialE]\^y - \[ExponentialE]\^\(-y\)\)\/2\)\), "\n"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        "             ", \(\(=\)\(\ \ \)\(sin\ x\ cosh\ y\ \  + \ \
\[ImaginaryI]\ \ cos\ x\ sinh\ y\)\)}]}]],
  "   \n\nwhere  ",
  Cell[BoxData[
      \(cosh\ y\  = \(\[ExponentialE]\^y + \[ExponentialE]\^\(-y\)\)\/2\)]],
  "  and  ",
  Cell[BoxData[
      \(sinh\ y\  = \(\[ExponentialE]\^y - \[ExponentialE]\^\(-y\)\)\/2\)]],
  ",  respectively, are the hyperbolic cosine and hyperbolic sine functions \
that you studied in calculus."
}], "Text"],

Cell[TextData[{
  "\tSimilarly\t\t",
  Cell[BoxData[{
      RowBox[{\(cos\ z\ \  = \ \ \(\(1\/2\) \((\[ExponentialE]\^\(\
\[ImaginaryI]\ z\)\  + \ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ z\)\ )\)\  = \
\ \ \(1\/2\) \((\[ExponentialE]\^\(\[ImaginaryI]\ \((x + \[ImaginaryI]\ \
y)\)\)\  + \ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \((x + \[ImaginaryI]\ \
y)\)\))\)\)\), "\n"}], "\[IndentingNewLine]", 
      RowBox[{
        "            ", \(\(=\)\(\ \ \)\(\(1\/2\) \
\((\[ExponentialE]\^\(\(-y\) + \[ImaginaryI]\ x\)\  + \ \[ExponentialE]\^\(y \
- \[ImaginaryI]\ x\))\)\)\), "\[IndentingNewLine]"}], "\n", 
      RowBox[{"            ", 
        RowBox[{"=", " ", 
          RowBox[{\(1\/2\), 
            RowBox[{
              StyleBox["(",
                
                FontSize->
                  16], \(\[ExponentialE]\^\(-y\)\ \((cos\ x + \[ImaginaryI]\ \
sin\ x)\) + \[ExponentialE]\^y\ \((cos\ x - \[ImaginaryI]\ sin\ x)\)\), 
              StyleBox[")",
                FontSize->16]}]}]}], "\n"}], "\[IndentingNewLine]", 
      RowBox[{
        "            ", \(\(=\)\(\ \ \)\(cos\ x \( \[ExponentialE]\^y + \
\[ExponentialE]\^\(-y\)\)\/2\  - \ \[ImaginaryI]\ \ sin\ x \( \[ExponentialE]\
\^y - \[ExponentialE]\^\(-y\)\)\/2\)\), "\n"}], "\[IndentingNewLine]", 
      RowBox[{
        "            ", \(\(=\)\(\ \ \)\(cos\ x\ Cosh\ y\ \  - \ \
\[ImaginaryI]\ \ sin\ x\ sinh\ y\)\)}]}]],
  "    "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for the real and imaginary parts of Sin \
and Cos.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\ \[ExponentialE]\^\(\[ImaginaryI]\ z\) \[Equal] 
          Cos[z] + \[ImaginaryI]\ Sin[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(ComplexExpand[\ \[ExponentialE]\^\(\[ImaginaryI]\ z\) \[Equal] 
        Cos[z] + \[ImaginaryI]\ Sin[z]\ ]\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\ \*"\"\<\!\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\\\ z\)\) \
\[Equal] Cos[-z] + \[ImaginaryI] Sin[-z]\>\""\ ];\)\ \), \
"\[IndentingNewLine]", 
    \(ComplexExpand[\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ z\) \[Equal] 
        Cos[\(-z\)] + \[ImaginaryI]\ Sin[\(-z\)]\ ]\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ z\) \[Equal] 
          Cos[z] - \[ImaginaryI]\ Sin[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(ComplexExpand[\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ z\) \[Equal] 
        Cos[z] - \[ImaginaryI]\ Sin[z]\ ]\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\ 
        Sin[z] \[Equal] \(\[ExponentialE]\^\(\[ImaginaryI]\ z\) - \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ z\)\)\/\(2  \[ImaginaryI]\)];\)\ \), "\
\[IndentingNewLine]", 
    \(ComplexExpand[\ 
      Sin[z] \[Equal] \(\[ExponentialE]\^\(\[ImaginaryI]\ z\) - \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ z\)\)\/\(2  \[ImaginaryI]\)]\)}], \
"Input"],

Cell[BoxData[{
    \(\(Print[\ 
        Cos[z] \[Equal] \(\[ExponentialE]\^\(\[ImaginaryI]\ z\) + \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ z\)\)\/2];\)\ \), \
"\[IndentingNewLine]", 
    \(ComplexExpand[\ \ Cos[
          z] \[Equal] \(\[ExponentialE]\^\(\[ImaginaryI]\ z\) + \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ z\)\)\/2]\)}], "Input"],

Cell[BoxData[{
    \(\(Print[
        Sin[x + \[ImaginaryI]\ y] == 
          ComplexExpand[\ 
            Sin[x + \[ImaginaryI]\ y]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        ComplexExpand[
          Sin[x + \[ImaginaryI]\ y] == \ 
            Sin[x + \[ImaginaryI]\ y]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Print[
        Cos[x + \[ImaginaryI]\ y] == 
          ComplexExpand[\ 
            Cos[x + \[ImaginaryI]\ y]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        ComplexExpand[
          Cos[x + \[ImaginaryI]\ y] == \ 
            Cos[x + \[ImaginaryI]\ y]]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tEquipped with Identities ",
  StyleBox["(5-32)",
    FontColor->RGBColor[0, 0, 1]],
  " - ",
  StyleBox["(5-35)",
    FontColor->RGBColor[0, 0, 1]],
  ", we can now establish many other properties of the trigonometric \
functions.  We begin with some periodic results.  For all complex numbers ",
  Cell[BoxData[
      \(z = x + \[ImaginaryI]\ y\)]],
  ",  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(sin \((z + 2  \[Pi])\)\  = \ sin\ z\), " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(cos \((z + 2  \[Pi])\)\  = \ cos\ z\), " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        "   ", \(sin \((z + \[Pi])\)\  = \ \(-\ sin\)\ z\), " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        "   ", \(cos \((z + \[Pi])\)\  = \ \(-\ cos\)\ z\), " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "   ", \(tan \((z + \[Pi])\)\  = \ tan\ z\), 
        " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "   ", 
        RowBox[{\(cot \((z + \[Pi])\)\), " ", "=", " ", 
          RowBox[{"cot", " ", 
            RowBox[{"z", 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]]],
  "     "
}], "Text"],

Cell[TextData[{
  "Clearly, ",
  Cell[BoxData[
      \(\(\(\ \)\(sin\ \((z + 2  \[Pi])\)\  = \ 
        sin \((\((x + 2  \[Pi])\) + \[ImaginaryI]\ y)\)\)\)\)]],
  ".  By Identity ",
  StyleBox["(5-34)",
    FontColor->RGBColor[0, 0, 1]],
  " this expression is  \n\n\t\t\t",
  Cell[BoxData[{
      \(sin\ \((z + 
              2  \[Pi])\)\  = \ \ sin\ \((x + 
                2  \[Pi])\)\ cosh\ y\  + \ \[ImaginaryI]\ cos\ \((x + 
                2  \[Pi])\)\ sinh\ y\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(sin\ x\ cosh\ y\ \  + \ \ \[ImaginaryI]\ cos\ x\ sinh\ y\)\)\ \ \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(sin\ z\)\)\)}]],
  "   \n\nAgain, the proofs for the other periodic results are left as \
exercises."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for trigonometric identities.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\< Sin[z+2\[Pi]] = \>", 
        Sin[z + 2  \[Pi]]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Sin[z+2n\[Pi]] = \>", 
        Simplify[Sin[z + 2  n\ \[Pi]], 
          Element[n, Integers]]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\< Cos[z+2\[Pi]] = \>", 
        Cos[z + 2  \[Pi]]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Cos[z+2n\[Pi]] = \>", 
        Simplify[Cos[z + 2  n\ \[Pi]], 
          Element[n, Integers]]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<      Sin[z+\[Pi]] = \>", 
        Sin[z + \[Pi]]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Sin[z+(2n+1)\[Pi]] = \>", 
        Simplify[Sin[z + \((2  n + 1)\)\ \[Pi]], 
          Element[n, Integers]]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<      Cos[z+\[Pi]] = \>", 
        Cos[z + \[Pi]]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Cos[z+(2n+1)\[Pi]] = \>", 
        Simplify[Cos[z + \((2  n + 1)\)\ \[Pi]], 
          Element[n, Integers]]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<      Tan[z+\[Pi]] = \>", 
        Tan[z + \[Pi]]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Tan[z+(2n+1)\[Pi]] = \>", 
        Simplify[Tan[z + \((2  n + 1)\)\ \[Pi]], 
          Element[n, Integers]]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<      Cot[z+\[Pi]] = \>", 
        Cot[z + \[Pi]]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Cot[z+(2n+1)\[Pi]] = \>", 
        Simplify[Cot[z + \((2  n + 1)\)\ \[Pi]], 
          Element[n, Integers]]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tIf  ",
  Cell[BoxData[
      RowBox[{"z", 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", 
        RowBox[{\(z\_1\), "  ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", \(z\_2\)}]}]]],
  "  are any complex numbers, then \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(sin \((z\_1 + z\_2)\)\  = \ 
          sin \((z\_1)\) cos \((z\_2)\)\ \  + \ \ cos\ z\_1\ sin\ z\_2\), " ",
         
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        "\n", \(cos \((z\_1 + z\_2)\)\  = \ 
          cos \((z\_1)\) cos \((z\_2)\)\ \  - \ \ sin\ z\_1\ sin\ z\_2\), " ",
         
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\n", "\[IndentingNewLine]", 
        "       ", \(sin \((2  z)\)\  = \ 2\ sin\ z\ cos\ z\), " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\n", "\[IndentingNewLine]", 
        "       ", \(cos \((2\ z)\)\  = \ \((cos\ z)\)\^2\ \  - \ \ \((sin\ \
z)\)\^2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", "\n", "  ", 
        RowBox[{\(sin \((\[Pi]\/2 + z)\)\), " ", "=", "  ", 
          RowBox[{\(sin \((\[Pi]\/2 - z)\)\), " ", "=", "  ", 
            RowBox[{"cos", " ", 
              RowBox[{"z", 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[".",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}]}]}]}]]],
  "  \n"
}], "Text"],

Cell[TextData[{
  "\tWe demonstrate that ",
  Cell[BoxData[
      \(cos \((z\_1 + z\_2)\) = 
        cos \((z\_1)\) cos \((z\_2)\) - sin\ z\_1\ sin\ z\_2\)]],
  " by making use of Identities ",
  StyleBox["(5-32)",
    FontColor->RGBColor[0, 0, 1]],
  " - ",
  StyleBox["(5-35)",
    FontColor->RGBColor[0, 0, 1]],
  ":  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \ \ \ \ \)\(cos\ z\_1\ cos\ z\_2\  = \ 
        1\/4\ \((\ \[ExponentialE]\^\(\[ImaginaryI] \((z\_1 + z\_2)\)\) + \ \
\[ExponentialE]\^\(\[ImaginaryI]\ \((z\_1 - z\_2)\)\) + \ \[ExponentialE]\^\(\
\[ImaginaryI]\ \((z\_2 - z\_1)\)\) + \[ExponentialE]\^\(\(-\[ImaginaryI]\) \
\((z\_1 + z\_2)\)\))\)\)\)\)]],
  ",   and  \n\n\t\t\t",
  Cell[BoxData[
      \(\(-\ \ sin\)\ z\_1\ sin\ z\_2\  = \ 
        1\/4\ \((\[ExponentialE]\^\(\[ImaginaryI] \((z\_1 + z\_2)\)\) - \ \ \
\[ExponentialE]\^\(\[ImaginaryI]\ \((z\_1 - z\_2)\)\) - \ \[ExponentialE]\^\(\
\[ImaginaryI]\ \((z\_2 - z\_1)\)\) + \[ExponentialE]\^\(\(-\[ImaginaryI]\) \
\((z\_1 + z\_2)\)\))\)\)]],
  " \n\nAdding these expressions gives\n\n\t\t\t",
  Cell[BoxData[
      \(cos\ z\_1\ cos\ z\_2\  - \ 
          sin\ z\_1\ sin\ z\_2 = \(\(1\/2\) \((\[ExponentialE]\^\(\
\[ImaginaryI] \((z\_1 + z\_2)\)\) + \[ExponentialE]\^\(\(-\[ImaginaryI]\) \
\((z\_1 + z\_2)\)\))\)\  = \ cos \((z\_1 + z\_2)\)\)\)]],
  "\n\nwhich is what we wanted."
}], "Text"],

Cell[TextData[{
  StyleBox["Demonstration.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Establish the identity  ",
  Cell[BoxData[
      \(cos \((z\_1 + z\_2)\)\  = \ 
        cos \((z\_1)\) cos \((z\_2)\)\ \  - \ \ sin \((z\_1)\) 
            sin \((z\_2)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration Method (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s \"ComplexExpand\" procedure and the identities ",
  Cell[BoxData[
      RowBox[{\(Cos[z]\), " ", "=", 
        RowBox[{
          
          RowBox[{\(\(\[ExponentialE]\^\(\[ImaginaryI]\ z\) + \ \
\[ExponentialE]\^\(\(-\ \[ImaginaryI]\)\ z\)\)\/2\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], "  ", \(Sin[z]\)}], " ", 
          "=", \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \ z\) - \ \
\[ExponentialE]\^\(\(-\ \[ImaginaryI]\)\ z\)\)\/\(2  \[ImaginaryI]\)\)}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[w, x, y, z];\)\ \), "\n", 
    \(\(z\_1\  = \ x\_1\  + \ \[ImaginaryI]\ y\_1;\)\ \), "\n", 
    \(\(z\_2\  = \ x\_2\  + \ \[ImaginaryI]\ y\_2;\)\ \), "\n", 
    \(\(w\_1\  = \ Cos[z\_1\  + \ z\_2];\)\ \), "\n", 
    \(\(w\_2\  = \ 
        Cos[z\_1] Cos[z\_2]\  - \ Sin[z\_1] Sin[z\_2];\)\ \), "\n", 
    \(\(w\_3\  = \ 
        ReplaceAll[w\_1, 
          Cos[z_]\  \[Rule] \(\[ExponentialE]\^\(\[ImaginaryI]\ z\) + \ \
\[ExponentialE]\^\(\(-\ \[ImaginaryI]\)\ z\)\)\/2];\)\ \), "\n", 
    \(\(w\_4\  = \ 
        ReplaceAll[
          w\_2, {Cos[
                z_]\  \[Rule] \(\[ExponentialE]\^\(\[ImaginaryI]\ z\) + \ \
\[ExponentialE]\^\(\(-\ \[ImaginaryI]\)\ \ z\)\)\/2, \n\ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ Sin[
                z_]\  \[Rule] \(\[ExponentialE]\^\(\[ImaginaryI]\ \ z\) - \ \
\[ExponentialE]\^\(\(-\ \[ImaginaryI]\)\ z\)\)\/\(2  \[ImaginaryI]\)}];\)\ \
\), "\n", 
    \(\(w\_5\  = \ ComplexExpand[w\_3];\)\ \), "\n", 
    \(\(w\_6\  = \ ComplexExpand[w\_4];\)\ \), "\n", 
    \(\(w\_7\  = \ Apart[w\_5];\)\ \), "\n", 
    \(\(w\_8\  = \ Apart[w\_6];\)\ \), "\n", 
    \(\(w\_9\  = \ Expand[w\_7, Trig \[Rule] True];\)\ \), "\n", 
    \(\(w\_0\  = \ Expand[w\_8, Trig \[Rule] True];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", w\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", w\_2];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", w\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", w\_4];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", w\_5];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", w\_6];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", w\_7];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", w\_8];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", w\_9];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", 
        w\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(w\_1\) = \!\(w\_2\) ?  \>\"", 
        Expand[w\_9, Trig \[Rule] True]\  \[Equal] \ \ Expand[w\_0, 
            Trig \[Rule] True]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nTherefore,  ",
  Cell[BoxData[
      \(cos \((z\_1 + z\_2)\) = 
        cos \((z\_1)\) cos \((z\_2)\)\  - \ 
          sin \((z\_1)\) sin \((z\_2)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration Method (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s \"ComplexExpand\" procedure."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[v, w, x, y, z];\)\ \), "\n", 
    \(\(v\_1\  = \ 
        ComplexExpand[
          Cos[x\_1 + \[ImaginaryI]\ y\_1\  + \ 
              x\_2 + \[ImaginaryI]\ y\_2]];\)\ \), "\n", 
    \(\(v\_2\  = \ 
        ComplexExpand[Cos[\((x\_1 + \[ImaginaryI]\ y\_1)\)]];\)\ \), "\n", 
    \(\(v\_3\  = \ 
        ComplexExpand[Cos[\((x\_2 + \[ImaginaryI]\ y\_2)\)]];\)\ \), "\n", 
    \(\(v\_4\  = \ 
        ComplexExpand[Sin[\((x\_1 + \[ImaginaryI]\ y\_1)\)]];\)\ \), "\n", 
    \(\(v\_5\  = \ 
        ComplexExpand[Sin[\((x\_2 + \[ImaginaryI]\ y\_2)\)]];\)\ \), "\n", 
    \(\(v\_6\  = \ v\_2\ v\_3\  - \ v\_4\ v\_5;\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_1\) = Cos[\!\(z\_1\)+\!\(z\_2\)]\>\""];\)\ \), "\n\
", 
    \(\(Print[\*"\"\<\!\(w\_2\) = Cos[\!\(z\_1\)]Cos[\!\(z\_2\)]-Sin[\!\(z\_1\
\)]Sin[\!\(z\_2\)]\>\""];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", v\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", v\_6];\)\ \), "\n", 
    \(\(v\_7\  = \ Expand[v\_6, Trig \[Rule] True];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", v\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", v\_7];\)\ \), "\n", 
    \(\(v\_1\  = \ Expand[v\_1, Trig \[Rule] True];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \>\"", v\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \>\"", 
        v\_7];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(w\_1\) = \!\(w\_2\) ?  \>\"", 
        v\_1\  \[Equal] \ v\_7];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Therefore,  ",
  Cell[BoxData[
      \(cos \((z\_1 + z\_2)\) = 
        cos \((z\_1)\) cos \((z\_2)\)\  - \ 
          sin \((z\_1)\) sin \((z\_2)\)\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\tA solution to the equation  ",
  Cell[BoxData[
      \(f \((z)\) = 0\)]],
  "  is called a zero of the given function ",
  StyleBox["f",
    FontFamily->"Courier New"],
  ".  As we now show, the zeros of the sine and cosine function are exactly \
where you might expect them to be.  We have  ",
  Cell[BoxData[
      \(sin\ z = 0\)]],
  "  iff  ",
  Cell[BoxData[
      \(z = n\ \[Pi]\)]],
  ",  where ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is any integer, and  ",
  Cell[BoxData[
      \(cos\ z = 0\)]],
  "  iff  ",
  Cell[BoxData[
      \(z = \((n + 1\/2)\)\ \[Pi]\)]],
  ",  where ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is any integer.\n\n\tWe show the result for ",
  Cell[BoxData[
      \(cos\ z\)]],
  " and leave the result for ",
  Cell[BoxData[
      \(sin\ z\)]],
  " as an exercise.  When we use Identity ",
  StyleBox["(5-35)",
    FontColor->RGBColor[0, 0, 1]],
  ",  ",
  Cell[BoxData[
      \(cos\ z = 0\)]],
  "  iff  \n\n\t\t\t",
  Cell[BoxData[
      \(0\  = \ cos\ x\ cosh\ y\  - \ \[ImaginaryI]\ sin\ x\ sinh\ y\)]],
  ".  \n\nEquating the real and imaginary parts of this equation gives \n\n\t\
\t\t",
  Cell[BoxData[
      \(0 = cos\ x\ cosh\ y\)]],
  "   and   ",
  Cell[BoxData[
      \(0 = sin\ x\ sinh\ y\)]],
  ".  \n\nThe real-valued function ",
  StyleBox["cosh y",
    FontFamily->"Courier New"],
  " is never zero, so the equation  ",
  Cell[BoxData[
      \(0 = cos\ x\ cosh\ y\)]],
  "  implies that  ",
  Cell[BoxData[
      \(0 = cos\ x\)]],
  ",  from which we obtain ",
  Cell[BoxData[
      \(x = \((n + 1\/2)\)\ \[Pi]\)]],
  " for any integer ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " .  Using the values for  ",
  Cell[BoxData[
      \(z\  = \ \(x + \[ImaginaryI]\ y\  = \ \(x = \((n + 
                    1\/2)\)\ \[Pi] + \[ImaginaryI]\ y\)\)\)]],
  "  in the equation  ",
  Cell[BoxData[
      \(0 = sin\ x\ sinh\ y\)]],
  "  yields  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{"0", "=", 
        RowBox[{
          RowBox[{"sin", 
            RowBox[{
              StyleBox["(",
                FontSize->16], \(\((n + 1\/2)\)\ \[Pi]\), ")"}], " ", "sinh", 
            " ", "y"}], " ", "=", " ", \(\(\((\(-1\))\)\^n\) sinh\ y\)}]}]]],
  ".  \n\nwhich implies that  ",
  Cell[BoxData[
      \(y = 0\)]],
  ",  so the only zeros for ",
  Cell[BoxData[
      \(cos\ z\)]],
  " are the values ",
  Cell[BoxData[
      \(z = \((n + 1\/2)\) \[Pi]\)]],
  "  for  ",
  StyleBox["n",
    FontFamily->"Courier New"],
  "  an integer. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s \"Solve\" procedure to find some of the solutions to  cos(z) = 0.  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[cosZ, eq1, eq2];\)\ \), "\n", 
    \(\(cosZ\  = \ 
        ComplexExpand[
          Cos[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\[IndentingNewLine]", 
    \(\(eq1\  = \ ComplexExpand[Re[cosZ]]\  \[Equal] \ 0;\)\ \), "\n", 
    \(\(eq2\  = \ 
        ComplexExpand[Im[cosZ]]\  \[Equal] \ 
          0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[Cos[x\  + \ \[ImaginaryI]\ y]\  \[Equal] \ 0];\)\ \), "\n", 
    \(\(Print[cosZ\  \[Equal] \ 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[eq1\ ];\)\ \), "\n", 
    \(\(Print[eq2];\)\ \), "\n", 
    \(\(Print[Solve[{eq1, eq2}, {x, y}]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " It is assumed that both  x  and  y  are real numbers. Hence, the only two \
valid solution in the above list are  ",
  Cell[BoxData[
      \({y \[Rule] 0, x \[Rule] \(-\(\[Pi]\/2\)\)}, {y \[Rule] 0, 
        x \[Rule] \[Pi]\/2}\)]],
  ".  \nThis is another way to solve the equation  cos(z) = 0."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[solset];\)\ \), "\n", 
    \(\(solset = Solve[Cos[z] \[Equal] 0, z];\)\ \), "\n", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(Print["\<The solutions are to cos(z) = 0 are:\>"];\)\ \), "\n", 
    \(\(Print["\<2 n \[Pi] + \>", \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(Print["\<2 n \[Pi] \>", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["We can also list some of the solutions.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[n];\)\ \), "\[IndentingNewLine]", 
    \(\(For[n = 0, 
        n \[LessEqual] 
          5, \(n++\), \[IndentingNewLine]Print[\*"\"\<Cos[\!\(\[Pi]\/2\)+ \
\>\"", n, "\< \[Pi]] = \>", 
          Cos[\[Pi]\/2 + n\ \[Pi]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Or by showing that the system of equations is satisfied.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<Cos[\!\(\[Pi]\/2\)]Cosh[0] = \>\"", 
        Cos[\[Pi]\/2] 
          Cosh[0], \n\*"\"\<,   -Sin[\!\(\[Pi]\/2\)]Sinh[0] = \>\"", \(-Sin[\
\[Pi]\/2]\) Sinh[0]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Cos[\!\(\[Pi]\/2\)+\[Pi]]Cosh[0] = \>\"", 
        Cos[\[Pi]\/2 + \[Pi]] 
          Cosh[0], \n\*"\"\<,   -Sin[\!\(\[Pi]\/2\)+\[Pi]]Sinh[0] = \>\"", \
\(-Sin[\[Pi]\/2 + \[Pi]]\) Sinh[0]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Cos[\!\(\[Pi]\/2\)+2\[Pi]]Cosh[0] = \>\"", 
        Cos[\[Pi]\/2 + 2  \[Pi]] 
          Cosh[0], \n\*"\"\<,   -Sin[\!\(\[Pi]\/2\)+2\[Pi]]Sinh[0] = \>\"", \
\(-Sin[\[Pi]\/2 + 2  \[Pi]]\) Sinh[0]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Cos[\!\(\[Pi]\/2\)+3\[Pi]]Cosh[0] = \>\"", 
        Cos[\[Pi]\/2 + 3  \[Pi]] 
          Cosh[0], \n\*"\"\<,   -Sin[\!\(\[Pi]\/2\)+3\[Pi]]Sinh[0] = \>\"", \
\(-Sin[\[Pi]\/2 + 3  \[Pi]]\) Sinh[0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Finally, we could just let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " do it. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[n];\)\), "\[IndentingNewLine]", 
    \(Print[\*"\"\<Cos[(n+\!\(1\/2\))\[Pi] = \>\"", 
      Cos[\((n + 1\/2)\) \[Pi]]]\), "\[IndentingNewLine]", 
    \(Print[\*"\"\<Cos[(n+\!\(1\/2\))\[Pi] = \>\"", 
      Simplify[Cos[\((n + 1\/2)\) \[Pi]], Element[n, Integers]]]\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tWhat does the mapping ",
  Cell[BoxData[
      \(w = sin\ z\)]],
  " look like?  We can get a graph of the mapping  ",
  Cell[BoxData[
      \(w = \(sin\ z = \(sin \((x + \[ImaginaryI]\ y)\) = 
            sin\ x\ cosh\ y + \[ImaginaryI]\ cos\ x\ sinh\ y\)\)\)]],
  "  by using parametric methods.  Let's consider the vertical line segments \
in the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane obtained by successfully setting  ",
  Cell[BoxData[
      \(x = \(-\(\[Pi]\/2\)\) + \(k\ \[Pi]\)\/12\)]],
  "  for ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "12"}]]],
  ", and for each ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " value and letting ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " vary continuously, ",
  Cell[BoxData[
      \(3 \[LessEqual] y \[LessEqual] 3\)]],
  ".  In the exercises we ask you to show that the images of these vertical \
segments are hyperbolas in the uv plane, as Figure 5.7 illustrates.  In \
Chapter 9, we give a more detailed analysis of the mapping  ",
  Cell[BoxData[
      \(w\  = \ sin\ z\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.285714 0.309017 0.103006 [
[.0512 .29652 -17.4375 -20.875 ]
[.0512 .29652 17.4375 0 ]
[.9488 .29652 -12.8125 -20.875 ]
[.9488 .29652 12.8125 0 ]
[1.025 .30902 0 -6.5 ]
[1.025 .30902 9 6.5 ]
[.4875 0 -16.375 -6.5 ]
[.4875 0 0 6.5 ]
[.4875 .10301 -16.375 -6.5 ]
[.4875 .10301 0 6.5 ]
[.4875 .20601 -16.375 -6.5 ]
[.4875 .20601 0 6.5 ]
[.4875 .41202 -9.5 -6.5 ]
[.4875 .41202 0 6.5 ]
[.4875 .51503 -9.5 -6.5 ]
[.4875 .51503 0 6.5 ]
[.4875 .61803 -9.5 -6.5 ]
[.4875 .61803 0 6.5 ]
[.5 .64303 -4.34375 0 ]
[.5 .64303 4.34375 13 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0512 .30902 m
.0512 .31527 L
s
gsave
.0512 .29652 -78.4375 -24.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.688 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.563 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.438 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.438 16.688 moveto
(\\200\\200\\200\\200) show
69.938 16.688 moveto
(\\200\\200\\200\\200) show
75.438 16.688 moveto
(\\200) show
77.063 16.688 moveto
(\\200) show
68.813 23.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.875 16.688 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.9488 .30902 m
.9488 .31527 L
s
gsave
.9488 .29652 -73.8125 -24.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.688 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.750 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
75.438 16.688 moveto
(\\200\\200\\200\\200) show
80.938 16.688 moveto
(\\200) show
81.563 16.688 moveto
(\\200) show
76.563 23.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.625 16.688 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
gsave
.4875 0 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
gsave
.4875 .10301 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .20601 m
.50625 .20601 L
s
gsave
.4875 .20601 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .41202 m
.50625 .41202 L
s
gsave
.4875 .41202 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .51503 m
.50625 .51503 L
s
gsave
.4875 .51503 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -65.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
67.688 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.01429 .30902 m
.05369 .30902 L
.09667 .30902 L
.13703 .30902 L
.17585 .30902 L
.21717 .30902 L
.25694 .30902 L
.29922 .30902 L
.33995 .30902 L
.37913 .30902 L
.42081 .30902 L
.46095 .30902 L
.49954 .30902 L
.54064 .30902 L
.58018 .30902 L
.62223 .30902 L
.66273 .30902 L
.70169 .30902 L
.74315 .30902 L
.78306 .30902 L
.82548 .30902 L
.86634 .30902 L
.90567 .30902 L
.94749 .30902 L
.98571 .30902 L
s
.5 .165 .165 r
.0512 0 m
.0512 .61803 L
s
1 0 1 r
.126 0 m
.126 .61803 L
s
0 0 1 r
.2008 0 m
.2008 .61803 L
s
0 1 1 r
.2756 0 m
.2756 .61803 L
s
0 1 0 r
.3504 0 m
.3504 .61803 L
s
1 0 0 r
.4252 0 m
.4252 .61803 L
s
.5 .165 .165 r
.5 0 m
.5 .61803 L
s
1 0 0 r
.5748 0 m
.5748 .61803 L
s
0 1 0 r
.6496 0 m
.6496 .61803 L
s
0 1 1 r
.7244 0 m
.7244 .61803 L
s
0 0 1 r
.7992 0 m
.7992 .61803 L
s
1 0 1 r
.874 0 m
.874 .61803 L
s
.5 .165 .165 r
.9488 0 m
.9488 .61803 L
s
.009 w
.5 0 m
.5 .61803 L
s
.012 w
.0512 0 m
.0512 .61803 L
s
.9488 0 m
.9488 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00P03oool3000009d0oooo001o
0?ooo`050000003oool0oooo0?ooo`000000W03oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0
oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0
oooo0100oooo00<0o`000000000000000P0000060?ooo`030000003oool0oooo00<0oooo0P1o:RX0
0`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03`3oool0
0`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool2
07lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo
00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo
00H0oooo0P0000060?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo
00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo
00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0
oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000
oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100
oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0
oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo
0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo
0?ooo`0@0?ooo`030?l0003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000050?ooo`80
ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`00
6`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003o
o`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`050?ooo`<00000
1P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003o
o`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ
9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3o
ool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3o
ool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3o
ool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3o
ool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool0
0`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool2
07lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0
oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool0
01/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00
ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ
:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo
00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0
oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0
oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40
oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0
oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo
0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo
0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo
00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo
00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o
:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?oo
o`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0
o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0
003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA
0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?
0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`00
0?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o
0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?oo
o`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?oo
o`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?oo
o`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?oo
o`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`03
0?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03
003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3o
ool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3o
ool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0
o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o
003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0
403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3o
ool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003o
ool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403o
ool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3o
ool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0
oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0
oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool0
0`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo
0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo
0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00
o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o
0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100
oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100
oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00
oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0
oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo
00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo
00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo
0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo
0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0
003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0
o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?oo
o`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?oo
o`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o
0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`00
0?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?
0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?
0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?oo
o`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?oo
o`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?oo
o`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?oo
o`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3o
ool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3o
ool0103oool5000000D0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3o
ool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3o
ool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000
o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0
403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3o
ool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003o
ool0oooo0100oooo00<0o`000000000000000P0000040?ooo`030000003oool0oooo00D0oooo0P1o
:RX00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03`3o
ool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3o
ool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0
oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0
oooo00L0oooo00<000000?ooo`3oool0103oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool0
0`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo
0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo
0100oooo00<0o`000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`80ObXZ4@3oool00`3o
0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40
oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0
oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000001@3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?oo
o`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?oo
o`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3o
ool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3o
ool01@3oool3000000H0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3o
ool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3o
ool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000
o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0
003oool0oooo00h0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool0
3`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool0
3`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo00h0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03`3o
ool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3o
ool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0
oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0
oooo00h0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03`3oool0
0`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool2
07lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo
00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo
00h0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03`3oool00`00
ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool207lZ
:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0
oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0
oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03`3oool00`00ool0
oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0
oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo
00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo
0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo
0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo
000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<0
0?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo0P1o
:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?oo
o`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K
0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo
0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo0P1o:RXA
0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?
0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K0?oo
o`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?oo
o`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo0P1o:RXA0?oo
o`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?oo
o`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K0?ooo`80
ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3o
ool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo0P1o:RXA0?ooo`03
0?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ
4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool0
3`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo0P1o:RXA0?ooo`030?l0
003oool0oooo0100oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3o
ool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3o
ool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo0P1o:RXA0?ooo`030?l0003o
ool0oooo0100oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool0
0`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool0
0`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo0P1o:RXA0?ooo`030?l0003oool0
oooo0100oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0
oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o
0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00
o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo0P1o:RXA0?ooo`030?l0003oool0oooo
0100oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00l0oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0
oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00
oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100
oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0
oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo
0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo
0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo
00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo
00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?oo
o`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?oo
o`0@0?ooo`030?l0003oool0oooo00h0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<0
0?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0
o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@
0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@
0?ooo`030?l0003oool0oooo00h0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l0
0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o
0?ooo`3oool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?oo
o`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?oo
o`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool0103oool207lZ:Q40oooo00<0o`000?oo
o`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?oo
o`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`03
0?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03
003o003oool0oooo0100oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`80
ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`00
6`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003o
o`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000000000000002000000D0oooo
00<000000?ooo`3oool0103oool207lZ:P030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0
403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3o
ool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003o
ool0oooo0100oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`80ObXZ4@3o
ool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool2
07lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0
oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`050?ooo`030000003oool0
000000H0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03`3oool0
0`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool2
07lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo
00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo
00H0oooo0P0000060?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo
00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo
00l0oooo0P1o:RXW0?ooo`004P3oool5000000@0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100
oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100
oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`80ObXZ4@3oool00`3o0000
oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RX20?ooo`D00000803oool001<0oooo
00<000000?ooo`3oool01@3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo
0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo
0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo
00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo
0P1o:RX30?ooo`030000003oool0oooo0240oooo000D0?ooo`030000003oool0oooo00@0oooo0P1o
:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?oo
o`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0
o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0
003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ103oool00`000000oooo0?oo
o`0P0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@
0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@
0?ooo`030?l0003oool0oooo00h0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l0
0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o
0?ooo`3oool03`3oool207lZ:PD0oooo00<000000?ooo`3oool07`3oool001H0oooo00<000000?oo
o`3oool00P3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?oo
o`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?oo
o`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?oo
o`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RX60?oo
o`030000003oool0oooo01h0oooo000B0?ooo`050000003oool0oooo0?ooo`000000103oool207lZ
:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo
00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o
0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RX20?ooo`050000003oool0oooo
0?ooo`000000803oool001<0oooo0`0000050?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?oo
o`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?oo
o`030?l0003oool0oooo00h0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l00?oo
o`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?oo
o`3oool03`3oool207lZ:P<0oooo0`00000Q0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03
003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0
403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0
403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o
003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
o`3oool0oooo00l0oooo0P1o:RXW0?ooo`003P3oool=00000080ObXZ4@3oool00`3o0?l0oooo0?oo
o`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?oo
o`0@0?ooo`030?l0003oool0oooo00h0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<0
0?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0
o`3o0?ooo`3oool03`3oool207lZ:PT000007P3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0
oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0
oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool0
0`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo
0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo
0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00
o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o
0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100
oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100
oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00
oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0
oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo
00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo
00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo
0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo
0?ooo`0?0?ooo`80ObXZ9`3oool001H0oooo00<000000?ooo`3oool00P00000207lZ:Q40oooo00<0
o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0
0?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?oo
o`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RX20?ooo`030000003oool0oooo00800000803o
ool001L0oooo00@000000?ooo`000000oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0
003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0
o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?oo
o`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?oo
o`0?0?ooo`80ObXZ0`3oool00`000000oooo0000000Q0?ooo`00403oool4000000<0oooo00@00000
0?ooo`000000oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3o
ool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3o
ool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3o
ool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ0`3o
ool00`000000oooo0000000Q0?ooo`005P3oool01@000000oooo0000003oool000000080ObXZ4@3o
ool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3o
ool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo0P1o:RXA0?ooo`030?l0003o
ool0oooo0100oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool207lZ:P80oooo00D000000?ooo`000000oooo
0000000P0?ooo`005`3oool400000080ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo00h0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03`3o
ool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3o
ool207lZ:P<0oooo1@00000O0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0
oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0
oooo00l0oooo0P1o:RXC0?ooo`050000003oool0oooo0?ooo`0000003`3oool001/0oooo0P1o:RXA
0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?
0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`00
0?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o
0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ503oool00`000000oooo0000000@
0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?oo
o`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?oo
o`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?oo
o`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXE0?oo
o`030000003oool0oooo00l0oooo000?0?ooo``000000P1o:RXA000000030?l0o`00000000000100
000000<0003o0000000000003`0000000`00ool000000000000?00000003003o0000000000000100
000000<0o`000000000000003P00000207lZ:Q40000000<0o`00000000000000400000000`00o`00
00000000000?00000003003oo`000000000000l0000000<0003o0000000000003`0000000`3o0?l0
00000000000?00000080ObXZ300000080?ooo`030000003oool000000100oooo000K0?ooo`80ObXZ
4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool0
3`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo0P1o:RXA0?ooo`030?l0
003oool0oooo0100oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool207lZ:Q<0oooo00D000000?ooo`3oool0
oooo0000000?0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo
0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo
0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo
00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo
0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?oo
o`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?oo
o`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<0
0?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o
:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?
0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>
0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW
0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?oo
o`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?oo
o`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?oo
o`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?oo
o`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03
003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80
ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`00
6`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003o
o`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ
4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3o
ool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3o
ool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3o
ool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool2
07lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0
oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool0
0`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ
:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo
00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o
0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40
oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0
oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000
oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo
00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo
00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo
0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0
o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0
0?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?oo
o`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o
0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l0
0?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@
0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?
0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?oo
o`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?oo
o`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?oo
o`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03
003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0
403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0
403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o
003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403o
ool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003o
ool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3o
ool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0
oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0
oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o
0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo
00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo
00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0
oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000
oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0
oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0
oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo
0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo
0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo
00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo
0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?oo
o`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?oo
o`070?ooo`030000003oool0oooo00@0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<0
0?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0
o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@
0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@
0?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool0103oool207lZ:Q40oooo00<0o`00
0?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o
0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?oo
o`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?oo
o`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`040?oo
o`80ObXZ00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo
00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo
00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0
oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000
oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100
oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0
oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo
0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo
0?ooo`0@0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`0000001P3oool207lZ:Q40oooo
00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo
00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o
:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?oo
o`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool01P3oool2000000H0oooo0P1o
:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?oo
o`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K
0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo
0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00L0oooo00<00000
0?ooo`3oool0103oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?
0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?
0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?oo
o`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?oo
o`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?oo
o`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?oo
o`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3o
ool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3o
ool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03
003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80
ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool0
3`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool0
3P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003o
o`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ
9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3o
ool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3o
ool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3o
ool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3o
ool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool0
0`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool2
07lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0
oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool0
01/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00
ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ
:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo
00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0
oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0
oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40
oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0
oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo
0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo
0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo
00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo
00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o
:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?oo
o`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0
o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0
003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA
0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?
0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`00
0?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o
0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?oo
o`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?oo
o`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?oo
o`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?oo
o`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`03
0?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03
003o003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3o
ool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3o
ool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0
o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o
003oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0
403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3o
ool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003o
ool0oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403o
ool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3o
ool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0
oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0
oooo0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool0
0`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo
0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo
0100oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00
o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o
0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100
oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100
oooo00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00
oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0
oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo
00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo
00<0o`000?ooo`3oool03P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo
0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo
0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0
003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003oool0oooo0100oooo00<0
o`000?ooo`3oool0103oool5000000D0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<0
0?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0
o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@
0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@
0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool207lZ:Q40oooo00<0o`00
0?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o
0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?oo
o`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?oo
o`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`80ObXZ00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo
00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo
00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0
oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000
oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100
oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0
oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo
0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo
0?ooo`0@0?ooo`030?l0003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool207lZ:Q40oooo
00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo
00<0003o0?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o
:RXA0?ooo`030?l0o`3oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?oo
o`0?0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool0000000D0oooo0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool0
3`3oool00`00ool0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool0
3`3oool207lZ:RL0oooo000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo00D0oooo0`0000060?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003o
ool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3o
ool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0
oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0
oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o
0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo
00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo
00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0
oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000
oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0
oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0
oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo
0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo
0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo
00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo
0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?oo
o`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?oo
o`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<0
0?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o
:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?
0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>
0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW
0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?oo
o`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?oo
o`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?oo
o`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?oo
o`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03
003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80
ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`00
6`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003o
o`3oool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ
4@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3o
ool207lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3o
ool0oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3o
ool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool2
07lZ:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0
oooo00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool0
0`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ
:Q40oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo
00l0oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o
0000oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40
oooo00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0
oooo00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000
oooo0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo
00<0o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo
00<00?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo
0?ooo`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0
o`3o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0
0?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?oo
o`0@0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o
0?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l0
0?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@
0?ooo`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?
0?ooo`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?oo
o`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?oo
o`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?oo
o`03003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0@0?ooo`03
003o003oool0oooo00l0oooo00<00?oo0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0o`3oool0oooo00l0oooo0P1o:RXW0?ooo`006`3oool207lZ:Q40oooo00<0o`3o0?ooo`3oool0
403oool00`000?l0oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0
403oool00`3o0000oooo0?ooo`050?ooo`<000001P3oool207lZ:Q40oooo00<0o`000?ooo`3oool0
403oool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RXA0?ooo`030?l0o`3o
ool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`00ool0oooo0?ooo`0?0?ooo`03003o003o
ool0oooo0100oooo00<0o`000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000D0oooo
0P1o:RXA0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool03`3oool00`00ool0oooo
0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`3o0?ooo`3oool03`3oool207lZ:RL0oooo
000K0?ooo`80ObXZ4@3oool00`3o0?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<0
0?oo0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool207lZ:P030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0403o
ool00`00o`00oooo0?ooo`0?0?ooo`03003oo`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3o
ool00`3o0?l0oooo0?ooo`0?0?ooo`80ObXZ9`3oool001/0oooo0P1o:RYT0?ooo`8000001P3oool2
07lZ:V`0oooo0P1o:RXW0?ooo`00P`3oool00`000000oooo0?ooo`2J0?ooo`00O`3oool01@000000
oooo0?ooo`3oool0000009`0oooo00200?ooo`<00000W@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool008T0oooo00<000000?ooo`3oool0U03oool008X0oooo
00<000000?ooo`3oool0T`3oool008X0oooo00<000000?ooo`3oool0T`3oool008T0oooo00<00000
0?ooo`000000U03oool008T0oooo00<000000?ooo`000000U03oool008T0oooo00<000000?ooo`00
0000U03oool008P0oooo00D000000?ooo`3oool0oooo0000002C0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1, -3, 0, 0}}],
  StyleBox["     ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.309017 0.0309017 [
[0 .29652 -10.9375 -13 ]
[0 .29652 10.9375 0 ]
[.25 .29652 -8.1875 -13 ]
[.25 .29652 8.1875 0 ]
[.75 .29652 -4.75 -13 ]
[.75 .29652 4.75 0 ]
[1 .29652 -7.5 -13 ]
[1 .29652 7.5 0 ]
[1.025 .30902 0 -6.5 ]
[1.025 .30902 9.5 6.5 ]
[.4875 0 -21.875 -6.5 ]
[.4875 0 0 6.5 ]
[.4875 .15451 -16.375 -6.5 ]
[.4875 .15451 0 6.5 ]
[.4875 .46353 -9.5 -6.5 ]
[.4875 .46353 0 6.5 ]
[.4875 .61803 -15 -6.5 ]
[.4875 .61803 0 6.5 ]
[.5 .64303 -4.4375 0 ]
[.5 .64303 4.4375 13 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
gsave
0 .29652 -71.9375 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.25 .30902 m
.25 .31527 L
s
gsave
.25 .29652 -69.1875 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.75 .30902 m
.75 .31527 L
s
gsave
.75 .29652 -65.75 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
1 .30902 m
1 .31527 L
s
gsave
1 .29652 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
gsave
.4875 0 -82.875 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -76 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -65.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
67.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
0 .22661 m
.019 .22977 L
.14982 .25158 L
.24966 .26834 L
.31801 .27996 L
.3692 .28889 L
.40331 .29515 L
.42573 .29967 L
.434 .30157 L
.44107 .30342 L
.44604 .30503 L
.44918 .3064 L
.45033 .3071 L
.45074 .30741 L
.4511 .30774 L
.45126 .30793 L
.45138 .30809 L
.45149 .30826 L
.45157 .30842 L
.45164 .3086 L
.45166 .3087 L
.45168 .30874 L
.45169 .3088 L
.4517 .30888 L
.4517 .30897 L
.4517 .30902 L
.4517 .30906 L
.4517 .30915 L
.45169 .30923 L
.45167 .30931 L
.45165 .30939 L
.45163 .30946 L
.45156 .30963 L
.45147 .3098 L
.45124 .31013 L
.45088 .3105 L
.45001 .31115 L
.44891 .31178 L
.44527 .31328 L
.44056 .31475 L
.42533 .31845 L
.40267 .32301 L
.36724 .3295 L
.31822 .33804 L
.25222 .34926 L
.15392 .36577 L
.0216 .38784 L
s
.0216 .38784 m
0 .39143 L
s
0 0 1 r
0 .13129 m
.06875 .15591 L
.18604 .19806 L
.27555 .23043 L
.33683 .25288 L
.38273 .27013 L
.41331 .28222 L
.43342 .29097 L
.44082 .29463 L
.44716 .29821 L
.45162 .30132 L
.45444 .30396 L
.45547 .3053 L
.45583 .30591 L
.45615 .30656 L
.4563 .30691 L
.45641 .30724 L
.45651 .30756 L
.45658 .30786 L
.45664 .30821 L
.45666 .3084 L
.45667 .30849 L
.45668 .30859 L
.45669 .30876 L
.4567 .30892 L
.4567 .30901 L
.4567 .30911 L
.45669 .30928 L
.45668 .30942 L
.45667 .30958 L
.45665 .30973 L
.45663 .30987 L
.45657 .31019 L
.45649 .31053 L
.45628 .31117 L
.45596 .31188 L
.45518 .31315 L
.45419 .31435 L
.45093 .31725 L
.44671 .3201 L
.43305 .32724 L
.41273 .33605 L
.38097 .34858 L
.33702 .36508 L
.27785 .38677 L
.18971 .41865 L
.07108 .46128 L
s
.07108 .46128 m
0 .48674 L
s
0 1 1 r
0 .00078 m
.00964 .00675 L
.14789 .0925 L
.24365 .1521 L
.31674 .19788 L
.36678 .22963 L
.40425 .25402 L
.42922 .27112 L
.44563 .28349 L
.45168 .28866 L
.45686 .29374 L
.4605 .29813 L
.4628 .30187 L
.46364 .30377 L
.46394 .30463 L
.4642 .30554 L
.46432 .30604 L
.46441 .3065 L
.46449 .30696 L
.46455 .30738 L
.4646 .30788 L
.46462 .30814 L
.46462 .30827 L
.46463 .30841 L
.46464 .30865 L
.46464 .30888 L
.46464 .30901 L
.46464 .30914 L
.46464 .30938 L
.46463 .30959 L
.46462 .30982 L
.46461 .31003 L
.46459 .31023 L
.46454 .31068 L
.46448 .31116 L
.4643 .31207 L
.46404 .31306 L
.4634 .31486 L
.4626 .31656 L
.45993 .32067 L
.45649 .32469 L
.44533 .33478 L
.42875 .34725 L
.40281 .36497 L
.36693 .3883 L
.31861 .41897 L
.24665 .46406 L
.14979 .52435 L
.00528 .61399 L
s
.00528 .61399 m
0 .61726 L
s
0 1 0 r
.21022 0 m
.25102 .04384 L
.31873 .11683 L
.37041 .17291 L
.4058 .21179 L
.43229 .24166 L
.44995 .2626 L
.46156 .27776 L
.46584 .28409 L
.46949 .2903 L
.47207 .29569 L
.4737 .30026 L
.47429 .30259 L
.4745 .30364 L
.47469 .30476 L
.47477 .30537 L
.47483 .30593 L
.47489 .3065 L
.47493 .30702 L
.47497 .30762 L
.47498 .30794 L
.47499 .3081 L
.47499 .30828 L
.475 .30857 L
.475 .30885 L
.475 .30901 L
.475 .30917 L
.475 .30947 L
.47499 .30972 L
.47498 .31 L
.47497 .31026 L
.47496 .3105 L
.47493 .31106 L
.47488 .31164 L
.47476 .31275 L
.47458 .31397 L
.47412 .31617 L
.47355 .31826 L
.47167 .32328 L
.46923 .32821 L
.46135 .34058 L
.44962 .35584 L
.43128 .37754 L
.4059 .40612 L
.37174 .44368 L
.32086 .49891 L
.25236 .57275 L
s
.25236 .57275 m
.21021 .61803 L
s
1 0 0 r
.36539 0 m
.37112 .01325 L
.40617 .09466 L
.43292 .1572 L
.45124 .20058 L
.46495 .23389 L
.47409 .25725 L
.4801 .27415 L
.48231 .28121 L
.48421 .28814 L
.48554 .29415 L
.48638 .29925 L
.48669 .30185 L
.4868 .30302 L
.4869 .30426 L
.48694 .30495 L
.48697 .30557 L
.487 .30621 L
.48702 .30679 L
.48704 .30746 L
.48705 .30782 L
.48705 .308 L
.48705 .30819 L
.48706 .30852 L
.48706 .30883 L
.48706 .30901 L
.48706 .30919 L
.48706 .30952 L
.48705 .30981 L
.48705 .31011 L
.48705 .3104 L
.48704 .31067 L
.48702 .31129 L
.487 .31194 L
.48693 .31318 L
.48684 .31454 L
.4866 .317 L
.48631 .31932 L
.48533 .32493 L
.48407 .33043 L
.47999 .34422 L
.47392 .36124 L
.46443 .38544 L
.45129 .41732 L
.43361 .45922 L
.40727 .52081 L
.37181 .60317 L
s
.37181 .60317 m
.36539 .61803 L
s
.5 .165 .165 r
.5 0 m
.5 .00281 L
.5 .0871 L
.5 .15185 L
.5 .19675 L
.5 .23124 L
.5 .25542 L
.5 .27292 L
.5 .28741 L
.5 .29891 L
.5 .3089 L
.5 .31955 L
.5 .33094 L
.5 .34565 L
.5 .36399 L
.5 .38742 L
.5 .42137 L
.5 .46649 L
.5 .5334 L
s
.5 .5334 m
.5 .61803 L
s
1 0 0 r
.63461 0 m
.62888 .01325 L
.59383 .09466 L
.56708 .1572 L
.54876 .20058 L
.53505 .23389 L
.52591 .25725 L
.5199 .27415 L
.51769 .28121 L
.51579 .28814 L
.51446 .29415 L
.51362 .29925 L
.51331 .30185 L
.5132 .30302 L
.5131 .30426 L
.51306 .30495 L
.51303 .30557 L
.513 .30621 L
.51298 .30679 L
.51296 .30746 L
.51295 .30782 L
.51295 .308 L
.51295 .30819 L
.51294 .30852 L
.51294 .30883 L
.51294 .30901 L
.51294 .30919 L
.51294 .30952 L
.51295 .30981 L
.51295 .31011 L
.51295 .3104 L
.51296 .31067 L
.51298 .31129 L
.513 .31194 L
.51307 .31318 L
.51316 .31454 L
.5134 .317 L
.51369 .31932 L
.51467 .32493 L
.51593 .33043 L
.52001 .34422 L
.52608 .36124 L
.53557 .38544 L
.54871 .41732 L
.56639 .45922 L
.59273 .52081 L
.62819 .60317 L
s
.62819 .60317 m
.63461 .61803 L
s
0 1 0 r
.78978 0 m
.74898 .04384 L
.68127 .11683 L
.62959 .17291 L
.5942 .21179 L
.56771 .24166 L
.55005 .2626 L
.53844 .27776 L
.53416 .28409 L
.53051 .2903 L
.52793 .29569 L
.5263 .30026 L
.52571 .30259 L
.5255 .30364 L
.52531 .30476 L
.52523 .30537 L
.52517 .30593 L
.52511 .3065 L
.52507 .30702 L
.52503 .30762 L
.52502 .30794 L
.52501 .3081 L
.52501 .30828 L
.525 .30857 L
.525 .30885 L
.525 .30901 L
.525 .30917 L
.525 .30947 L
.52501 .30972 L
.52502 .31 L
.52503 .31026 L
.52504 .3105 L
.52507 .31106 L
.52512 .31164 L
.52524 .31275 L
.52542 .31397 L
.52588 .31617 L
.52645 .31826 L
.52833 .32328 L
.53077 .32821 L
.53865 .34058 L
.55038 .35584 L
.56872 .37754 L
.5941 .40612 L
.62826 .44368 L
.67914 .49891 L
.74764 .57275 L
s
.74764 .57275 m
.78979 .61803 L
s
0 1 1 r
1 .00078 m
.99036 .00675 L
.85211 .0925 L
.75635 .1521 L
.68326 .19788 L
.63322 .22963 L
.59575 .25402 L
.57078 .27112 L
.55437 .28349 L
.54832 .28866 L
.54314 .29374 L
.5395 .29813 L
.5372 .30187 L
.53636 .30377 L
.53606 .30463 L
.5358 .30554 L
.53568 .30604 L
.53559 .3065 L
.53551 .30696 L
.53545 .30738 L
.5354 .30788 L
.53538 .30814 L
.53538 .30827 L
.53537 .30841 L
.53536 .30865 L
.53536 .30888 L
.53536 .30901 L
.53536 .30914 L
.53536 .30938 L
.53537 .30959 L
.53538 .30982 L
.53539 .31003 L
.53541 .31023 L
.53546 .31068 L
.53552 .31116 L
.5357 .31207 L
.53596 .31306 L
.5366 .31486 L
.5374 .31656 L
.54007 .32067 L
.54351 .32469 L
.55467 .33478 L
.57125 .34725 L
.59719 .36497 L
.63307 .3883 L
.68139 .41897 L
.75335 .46406 L
.85021 .52435 L
.99472 .61399 L
s
.99472 .61399 m
1 .61726 L
s
0 0 1 r
1 .13129 m
.93125 .15591 L
.81396 .19806 L
.72445 .23043 L
.66317 .25288 L
.61727 .27013 L
.58669 .28222 L
.56658 .29097 L
.55918 .29463 L
.55284 .29821 L
.54838 .30132 L
.54556 .30396 L
.54453 .3053 L
.54417 .30591 L
.54385 .30656 L
.5437 .30691 L
.54359 .30724 L
.54349 .30756 L
.54342 .30786 L
.54336 .30821 L
.54334 .3084 L
.54333 .30849 L
.54332 .30859 L
.54331 .30876 L
.5433 .30892 L
.5433 .30901 L
.5433 .30911 L
.54331 .30928 L
.54332 .30942 L
.54333 .30958 L
.54335 .30973 L
.54337 .30987 L
.54343 .31019 L
.54351 .31053 L
.54372 .31117 L
.54404 .31188 L
.54482 .31315 L
.54581 .31435 L
.54907 .31725 L
.55329 .3201 L
.56695 .32724 L
.58727 .33605 L
.61903 .34858 L
.66298 .36508 L
.72215 .38677 L
.81029 .41865 L
.92892 .46128 L
s
.92892 .46128 m
1 .48674 L
s
1 0 1 r
1 .22661 m
.981 .22977 L
.85018 .25158 L
.75034 .26834 L
.68199 .27996 L
.6308 .28889 L
.59669 .29515 L
.57427 .29967 L
.566 .30157 L
.55893 .30342 L
.55396 .30503 L
.55082 .3064 L
.54967 .3071 L
.54926 .30741 L
.5489 .30774 L
.54874 .30793 L
.54862 .30809 L
.54851 .30826 L
.54843 .30842 L
.54836 .3086 L
.54834 .3087 L
.54832 .30874 L
.54831 .3088 L
.5483 .30888 L
.5483 .30897 L
.5483 .30902 L
.5483 .30906 L
.5483 .30915 L
.54831 .30923 L
.54833 .30931 L
.54835 .30939 L
.54837 .30946 L
.54844 .30963 L
.54853 .3098 L
.54876 .31013 L
.54912 .3105 L
.54999 .31115 L
.55109 .31178 L
.55473 .31328 L
.55944 .31475 L
.57467 .31845 L
.59733 .32301 L
.63276 .3295 L
.68178 .33804 L
.74778 .34926 L
.84608 .36577 L
.9784 .38784 L
s
.9784 .38784 m
1 .39143 L
s
0 g
0 .30902 m
.00592 .30902 L
.05537 .30902 L
.10292 .30902 L
.15353 .30902 L
.20226 .30902 L
.25404 .30902 L
.30393 .30902 L
.35193 .30902 L
.403 .30902 L
.45216 .30902 L
.49944 .30902 L
.54978 .30902 L
.59822 .30902 L
.64973 .30902 L
.69935 .30902 L
.74707 .30902 L
.79786 .30902 L
.84675 .30902 L
.89871 .30902 L
.94877 .30902 L
.99694 .30902 L
s
.99694 .30902 m
1 .30902 L
s
.5 .165 .165 r
.009 w
.5 0 m
.5 .61803 L
s
0 .30902 m
.4475 .30902 L
s
.5525 .30902 m
1 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{287.5, 177.625},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004O0000/B000`400?l00000o`00003oo`3ooolP
0?ooo`00o`3ooolP0?ooo`00o`3ooolP0?ooo`00o`3ooolP0?ooo`00O`3oool010000000oooo0?oo
o`3oool3000009T0oooo001o0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
UP3oool004H0oooo00<00?l00?ooo`3oool08`3oool00`3o0000oooo0?ooo`070?ooo`@000001@3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo0P1o:RX2000001h0oooo
00<0o`000?ooo`3oool08`3oool00`00o`00oooo0?ooo`190?ooo`004P3oool2003ooc<0oooo00<0
0?l00?ooo`3oool08P3oool00`3o0000oooo0?ooo`0@0?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00P3oool207lZ:R00oooo00<0o`000?ooo`3oool08P3oool00`00o`00oooo
0?ooo`0a0?ooo`800?oo5`3oool001@0oooo0P00oolb0?ooo`03003o003oool0oooo0240oooo00<0
o`000?ooo`3oool03P3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
103oool207lZ:Ql0oooo00<0o`000?ooo`3oool08P3oool00`00o`00oooo0?ooo`0`0?ooo`800?oo
6@3oool001H0oooo0P00oola0?ooo`03003o003oool0oooo0240oooo00<0o`000?ooo`3oool03P3o
ool200000080oooo00D000000?ooo`3oool0oooo000000040?ooo`80ObXZ7`3oool00`3o0000oooo
0?ooo`0Q0?ooo`03003o003oool0oooo02l0oooo0P00oolK0?ooo`00603oool00`00ool0oooo0?oo
o`0_0?ooo`03003o003oool0oooo0200oooo00<0o`000?ooo`3oool03`3oool010000000oooo0?oo
o`3oool3000000D0oooo0P1o:RXO0?ooo`030?l0003oool0oooo0200oooo00<00?l00?ooo`3oool0
;P3oool2003ooad0oooo000I0?ooo`800?oo<03oool00`00o`00oooo0?ooo`0O0?ooo`030?l0003o
ool0oooo01/0oooo0P1o:RXO0?ooo`030?l0003oool0oooo01l0oooo00<00?l00?ooo`3oool0;P3o
ool00`00ool0oooo0?ooo`0M0?ooo`006`3oool2003oobh0oooo00<00?l00?ooo`3oool0803oool0
0`3o0000oooo0?ooo`0J0?ooo`80ObXZ7P3oool00`3o0000oooo0?ooo`0P0?ooo`03003o003oool0
oooo02`0oooo0P00oolP0?ooo`007@3oool00`00ool0oooo0?ooo`0/0?ooo`03003o003oool0oooo
01l0oooo00<0o`000?ooo`3oool06P3oool207lZ:Qh0oooo00<0o`000?ooo`3oool07`3oool00`00
o`00oooo0?ooo`0/0?ooo`03003oo`3oool0oooo0200oooo000N0?ooo`800?oo;@3oool00`00o`00
oooo0?ooo`0O0?ooo`030?l0003oool0oooo01T0oooo0P1o:RXM0?ooo`030?l0003oool0oooo01l0
oooo00<00?l00?ooo`3oool0:`3oool2003oob<0oooo000P0?ooo`03003oo`3oool0oooo02/0oooo
00<00?l00?ooo`3oool07P3oool00`3o0000oooo0?ooo`0I0?ooo`80ObXZ7@3oool00`3o0000oooo
0?ooo`0N0?ooo`03003o003oool0oooo02X0oooo0P00oolU0?ooo`008@3oool2003oob`0oooo00<0
0?l00?ooo`3oool07@3oool00`3o0000oooo0?ooo`0I0?ooo`80ObXZ703oool00`3o0000oooo0?oo
o`0N0?ooo`03003o003oool0oooo02X0oooo00<00?oo0?ooo`3oool09@3oool002<0oooo00<00?oo
0?ooo`3oool0:P3oool00`00o`00oooo0?ooo`0M0?ooo`030?l0003oool0oooo01P0oooo0P1o:RXL
0?ooo`030?l0003oool0oooo01d0oooo00<00?l00?ooo`3oool0:@3oool2003oobP0oooo000T0?oo
o`800?oo:`3oool00`00o`00oooo0?ooo`0L0?ooo`030?l0003oool0oooo01P0oooo0P1o:RXK0?oo
o`030?l0003oool0oooo01d0oooo00<00?l00?ooo`3oool0:@3oool00`00ool0oooo0?ooo`0X0?oo
o`009P3oool2003oobX0oooo00<00?l00?ooo`3oool0703oool00`3o0000oooo0?ooo`0G0?ooo`80
ObXZ6`3oool00`3o0000oooo0?ooo`0L0?ooo`03003o003oool0oooo02P0oooo0P00ool[0?ooo`00
:03oool00`00ool0oooo0?ooo`0X0?ooo`03003o003oool0oooo01/0oooo00<0o`000?ooo`3oool0
5`3oool207lZ:QX0oooo00<0o`000?ooo`3oool0703oool00`00o`00oooo0?ooo`0W0?ooo`800?oo
;@3oool002T0oooo0P00oolY0?ooo`03003o003oool0oooo01X0oooo00<0o`000?ooo`3oool05`3o
ool207lZ:QX0oooo00<0o`000?ooo`3oool06`3oool00`00o`00oooo0?ooo`0W0?ooo`03003oo`3o
ool0oooo02d0oooo000[0?ooo`03003oo`3oool0oooo02H0oooo00<00?l00?ooo`3oool06`3oool0
0`3o0000oooo0?ooo`0F0?ooo`80ObXZ6P3oool00`3o0000oooo0?ooo`0K0?ooo`03003o003oool0
oooo02D0oooo0P00ool`0?ooo`00;03oool2003oobL0oooo00<00?l00?ooo`3oool06P3oool00`3o
0000oooo0?ooo`0F0?ooo`80ObXZ6@3oool00`3o0000oooo0?ooo`0K0?ooo`03003o003oool0oooo
02@0oooo0P00oolb0?ooo`00;P3oool00`00ool0oooo0?ooo`0U0?ooo`03003o003oool0oooo01X0
oooo00<0o`000?ooo`3oool05@3oool207lZ:QT0oooo00<0o`000?ooo`3oool06P3oool00`00o`00
oooo0?ooo`0T0?ooo`03003oo`3oool0oooo0380oooo000_0?ooo`800?oo9P3oool00`00o`00oooo
0?ooo`0I0?ooo`030?l0003oool0oooo01D0oooo0P1o:RXH0?ooo`030?l0003oool0oooo01X0oooo
00<00?l00?ooo`3oool08`3oool2003oocD0oooo000a0?ooo`800?oo9@3oool00`00o`00oooo0?oo
o`0H0?ooo`030?l0003oool0oooo01D0oooo0P1o:RXH0?ooo`030?l0003oool0oooo01T0oooo00<0
0?l00?ooo`3oool08`3oool00`00ool0oooo0?ooo`0e0?ooo`00<`3oool00`00ool0oooo0?ooo`0S
0?ooo`03003o003oool0oooo01P0oooo00<0o`000?ooo`3oool0503oool207lZ:QL0oooo00<0o`00
0?ooo`3oool06@3oool00`00o`00oooo0?ooo`0R0?ooo`800?oo>03oool003@0oooo0P00oolT0?oo
o`03003o003oool0oooo01L0oooo00<0o`000?ooo`3oool0503oool207lZ:QL0oooo00<0o`000?oo
o`3oool0603oool00`00o`00oooo0?ooo`0Q0?ooo`800?oo>P3oool003H0oooo00<00?oo0?ooo`3o
ool08P3oool00`00o`00oooo0?ooo`0G0?ooo`030?l0003oool0oooo01<0oooo0P1o:RXF0?ooo`03
0?l0003oool0oooo01P0oooo00<00?l00?ooo`3oool08@3oool00`00ool0oooo0?ooo`0j0?ooo`00
=`3oool2003oob<0oooo00<00?l00?ooo`3oool05P3oool00`3o0000oooo0?ooo`0C0?ooo`80ObXZ
5P3oool00`3o0000oooo0?ooo`0G0?ooo`03003o003oool0oooo0200oooo0P00oolm0?ooo`00>@3o
ool00`00ool0oooo0?ooo`0P0?ooo`03003o003oool0oooo01H0oooo00<0o`000?ooo`3oool04`3o
ool207lZ:QH0oooo00<0o`000?ooo`3oool05`3oool00`00o`00oooo0?ooo`0O0?ooo`03003oo`3o
ool0oooo03d0oooo000j0?ooo`800?oo8@3oool00`00o`00oooo0?ooo`0F0?ooo`030?l0003oool0
oooo0180oooo0P1o:RXE0?ooo`030?l0003oool0oooo01L0oooo00<00?l00?ooo`3oool07P3oool2
003ood00oooo000l0?ooo`800?oo803oool00`00o`00oooo0?ooo`0E0?ooo`030?l0003oool0oooo
0180oooo0P1o:RXE0?ooo`030?l0003oool0oooo01H0oooo00<00?l00?ooo`3oool07P3oool00`00
ool0oooo0?ooo`100?ooo`00?P3oool00`00ool0oooo0?ooo`0N0?ooo`03003o003oool0oooo01D0
oooo00<0o`000?ooo`3oool04@3oool207lZ:Q@0oooo00<0o`000?ooo`3oool05P3oool00`00o`00
oooo0?ooo`0M0?ooo`800?oo@`3oool003l0oooo0P00oolO0?ooo`03003o003oool0oooo01@0oooo
00<0o`000?ooo`3oool04@3oool207lZ:Q@0oooo00<0o`000?ooo`3oool05@3oool00`00o`00oooo
0?ooo`0M0?ooo`03003oo`3oool0oooo04<0oooo00110?ooo`03003oo`3oool0oooo01d0oooo00<0
0?l00?ooo`3oool0503oool00`3o0000oooo0?ooo`0@0?ooo`80ObXZ503oool00`3o0000oooo0?oo
o`0D0?ooo`03003o003oool0oooo01`0oooo0P00oom60?ooo`00@P3oool2003ooah0oooo00<00?l0
0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0@0?ooo`80ObXZ4`3oool00`3o0000oooo0?ooo`0D
0?ooo`03003o003oool0oooo01/0oooo0P00oom80?ooo`004P3oool20000oc00oooo0P00oolM0?oo
o`03003o003oool0oooo01<0oooo00<0o`000?ooo`3oool03`3oool207lZ:Q<0oooo00<0o`000?oo
o`3oool04`3oool00`00o`00oooo0?ooo`0K0?ooo`03003oo`3oool0oooo02l0oooo0P000?lG0?oo
o`00503oool30000obl0oooo00<00?oo0?ooo`3oool06`3oool00`00o`00oooo0?ooo`0B0?ooo`03
0?l0003oool0oooo00l0oooo0P1o:RXB0?ooo`030?l0003oool0oooo01<0oooo00<00?l00?ooo`3o
ool06P3oool2003oobl0oooo0`000?lI0?ooo`005`3oool30000obd0oooo0P00oolL0?ooo`03003o
003oool0oooo0180oooo00<0o`000?ooo`3oool03P3oool207lZ:Q80oooo00<0o`000?ooo`3oool0
4P3oool00`00o`00oooo0?ooo`0J0?ooo`03003oo`3oool0oooo02`0oooo0`000?lL0?ooo`006P3o
ool20000obd0oooo00<00?oo0?ooo`3oool06P3oool00`00o`00oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo00h0oooo0P1o:RXB0?ooo`030?l0003oool0oooo0140oooo00<00?l00?ooo`3oool06@3o
ool2003oobd0oooo0P000?lO0?ooo`00703oool30000ob/0oooo0P00oolJ0?ooo`03003o003oool0
oooo0180oooo00<0o`000?ooo`3oool01@3oool3000000D0oooo0P1o:RXA0?ooo`030?l0003oool0
oooo0140oooo00<00?l00?ooo`3oool06@3oool00`00ool0oooo0?ooo`0Z0?ooo`<0003o8@3oool0
01l0oooo0`000?lZ0?ooo`800?oo6@3oool00`00o`00oooo0?ooo`0A0?ooo`030?l0003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`80ObXZ4@3oool00`3o0000oooo0?ooo`0A
0?ooo`03003o003oool0oooo01L0oooo0P00oolZ0?ooo`<0003o903oool00280oooo0`000?lY0?oo
o`03003oo`3oool0oooo01L0oooo00<00?l00?ooo`3oool04@3oool0103o00000000000000000006
0?ooo`030000003oool0oooo0080oooo0P1o:RX2000000h0oooo00<0o`000?ooo`3oool04@3oool0
0`00o`00oooo0?ooo`0G0?ooo`03003oo`3oool0oooo02L0oooo0`000?lW0?ooo`009@3oool20000
obP0oooo0P00oolH0?ooo`03003o003oool0oooo0100oooo00<0o`000?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo0P1o:RX@0?ooo`030?l0003oool0oooo0100oooo00<00?l0
0?ooo`3oool05P3oool2003oobP0oooo0P000?lZ0?ooo`009`3oool30000obL0oooo0P00oolG0?oo
o`03003o003oool0oooo00l0oooo00<0o`000?ooo`3oool00`3oool4000000D0oooo0P1o:RX?0?oo
o`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool05@3oool2003oobL0oooo0`000?l/0?oo
o`00:P3oool30000obH0oooo00<00?oo0?ooo`3oool05@3oool00`00o`00oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool207lZ:Pl0oooo00<0o`000?ooo`3o
ool03`3oool00`00o`00oooo0?ooo`0E0?ooo`03003oo`3oool0oooo02@0oooo0`000?l_0?ooo`00
;@3oool20000obD0oooo0P00oolF0?ooo`03003o003oool0oooo00h0oooo00<0o`000?ooo`3oool0
0`3oool4000000@0oooo0P1o:RX>0?ooo`030?l0003oool0oooo00l0oooo00<00?l00?ooo`3oool0
503oool2003oobD0oooo0P000?lb0?ooo`00;`3oool30000ob@0oooo00<00?oo0?ooo`3oool0503o
ool00`00o`00oooo0?ooo`0>0?ooo`030?l0003oool0oooo00X0oooo0P1o:RX>0?ooo`030?l0003o
ool0oooo00h0oooo00<00?l00?ooo`3oool0503oool00`00ool0oooo0?ooo`0R0?ooo`<0003o=03o
ool00380oooo0`000?lR0?ooo`800?oo5@3oool00`00o`00oooo0?ooo`0=0?ooo`030?l0003oool0
oooo00X0oooo0P1o:RX=0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool04`3oool2
003oob80oooo0`000?lg0?ooo`00=@3oool20000ob80oooo0P00oolD0?ooo`03003o003oool0oooo
00d0oooo00<0o`000?ooo`3oool02@3oool207lZ:Pd0oooo00<0o`000?ooo`3oool03@3oool00`00
o`00oooo0?ooo`0B0?ooo`800?oo8P3oool20000ocX0oooo000g0?ooo`<0003o8@3oool00`00ool0
oooo0?ooo`0B0?ooo`03003o003oool0oooo00`0oooo00<0o`000?ooo`3oool02@3oool207lZ:P`0
oooo00<0o`000?ooo`3oool03@3oool00`00o`00oooo0?ooo`0B0?ooo`03003oo`3oool0oooo01l0
oooo0`000?ll0?ooo`00>P3oool30000oal0oooo0P00oolC0?ooo`03003o003oool0oooo00`0oooo
00<0o`000?ooo`3oool0203oool207lZ:P`0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo
0?ooo`0A0?ooo`800?oo7`3oool30000ocl0oooo000m0?ooo`80003o7`3oool2003ooa40oooo00<0
0?l00?ooo`3oool0303oool00`3o0000oooo0?ooo`080?ooo`80ObXZ2`3oool00`3o0000oooo0?oo
o`0<0?ooo`03003o003oool0oooo0100oooo0P00oolO0?ooo`80003o@P3oool003l0oooo0`000?lN
0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0303oool00`3o0000oooo0?ooo`07
0?ooo`80ObXZ2`3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo0100oooo00<00?oo
0?ooo`3oool0703oool30000od@0oooo00120?ooo`<0003o703oool2003ooa00oooo00<00?l00?oo
o`3oool02`3oool00`3o0000oooo0?ooo`070?ooo`80ObXZ2`3oool00`3o0000oooo0?ooo`0:0?oo
o`03003o003oool0oooo00l0oooo0P00oolL0?ooo`<0003oA`3oool004D0oooo0P000?lL0?ooo`80
0?oo3`3oool00`00o`00oooo0?ooo`0;0?ooo`030?l0003oool0oooo00H0oooo0P1o:RX:0?ooo`03
0?l0003oool0oooo00X0oooo00<00?l00?ooo`3oool03P3oool2003ooa`0oooo0P000?m:0?ooo`00
A`3oool30000oa/0oooo00<00?oo0?ooo`3oool03@3oool00`00o`00oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00H0oooo0P1o:RX:0?ooo`030?l0003oool0oooo00T0oooo00<00?l00?ooo`3oool0
3P3oool00`00ool0oooo0?ooo`0I0?ooo`<0003oC03oool004X0oooo0`000?lI0?ooo`800?oo3P3o
ool00`00o`00oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo0P1o:RX:0?ooo`030?l0003o
ool0oooo00P0oooo00<00?l00?ooo`3oool03@3oool2003ooaT0oooo0`000?m?0?ooo`00C@3oool3
0000oaP0oooo0P00ool=0?ooo`03003o003oool0oooo00T0oooo00<0o`000?ooo`3oool01@3oool2
07lZ:PT0oooo00<0o`000?ooo`3oool0203oool00`00o`00oooo0?ooo`0<0?ooo`800?oo603oool3
0000oe80oooo001@0?ooo`80003o603oool2003oo``0oooo00<00?l00?ooo`3oool0203oool00`3o
0000oooo0?ooo`050?ooo`80ObXZ2@3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo
00/0oooo0P00oolH0?ooo`80003oE@3oool00180oooo0`3o0?lm0?ooo`<0003o5`3oool00`00ool0
oooo0?ooo`0:0?ooo`03003o003oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool207lZ:PT0
oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`0:0?ooo`03003oo`3oool0oooo01D0
oooo0`000?lm0?ooo`<0o`3o5`3oool001D0oooo1P3o0?lj0?ooo`<0003o5@3oool2003oo`/0oooo
00<00?l00?ooo`3oool01`3oool00`3o0000oooo0?ooo`040?ooo`80ObXZ203oool00`3o0000oooo
0?ooo`070?ooo`03003o003oool0oooo00T0oooo0P00oolE0?ooo`<0003o>P3oool60?l0oaX0oooo
000K0?ooo`H0o`3o=`3oool30000oa@0oooo00<00?oo0?ooo`3oool02@3oool00`00o`00oooo0?oo
o`060?ooo`030?l0003oool0oooo00@0oooo0P1o:RX80?ooo`030?l0003oool0oooo00H0oooo00<0
0?l00?ooo`3oool02@3oool00`00ool0oooo0?ooo`0B0?ooo`<0003o=`3oool60?l0ob00oooo000Q
0?ooo`H0o`3o=03oool30000oa80oooo0P00ool:0?ooo`03003o003oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool207lZ:PP0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`08
0?ooo`800?oo4P3oool30000oc@0oooo1P3o0?lV0?ooo`009`3oool70?l0oc00oooo0`000?lA0?oo
o`03003oo`3oool0oooo00P0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?oo
o`80ObXZ1`3oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo00P0oooo00<00?oo0?oo
o`3oool03`3oool30000oc00oooo1`3o0?l/0?ooo`00;P3oool60?l0obd0oooo0`000?l?0?ooo`80
0?oo203oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo0P1o:RX70?ooo`03
0?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool01P3oool2003oo`l0oooo0`000?l]0?ooo`H0
o`3o<`3oool003@0oooo1P3o0?lZ0?ooo`<0003o3P3oool00`00ool0oooo0?ooo`060?ooo`03003o
003oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool207lZ:PH0oooo00<0o`000?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`060?ooo`03003oo`3oool0oooo00`0oooo0`000?lZ0?ooo`H0o`3o
>@3oool003X0oooo1P3o0?lW0?ooo`<0003o303oool00`00ool0oooo0?ooo`060?ooo`03003o003o
ool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool207lZ:PH0oooo00<0o`000?ooo`3oool0103o
ool00`00o`00oooo0?ooo`060?ooo`03003oo`3oool0oooo00X0oooo0`000?lW0?ooo`H0o`3o?`3o
ool001<0oooo00@000000?ooo`3oool0oooo0`00000V0?ooo`H0o`3o2`3oool3000001H0oooo0P00
0?l;0?ooo`03003oo`3oool0oooo00D0oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?oo
o`020?ooo`80ObXZ1@3oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo00D0oooo00<0
0?oo0?ooo`3oool02@3oool20000oaP0oooo0`0000090?ooo`H0o`3o:P3oool010000000oooo0?oo
o`3oool3000001@0oooo000C0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
:@3oool60?l0o`@0oooo00D000000?ooo`3oool0oooo0000000G0?ooo`<0003o2@3oool2003oo`H0
oooo00<00?l00?ooo`3oool0103oool0103o0000oooo0?ooo`3oool207lZ:PD0oooo00<0o`000?oo
o`3oool0103oool00`00o`00oooo0?ooo`040?ooo`800?oo2@3oool30000oaT0oooo00D000000?oo
o`3oool0oooo000000020?ooo`H0o`3o<03oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo0140oooo000:0?ooo`@000001@3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo02d0oooo0P0000060?l0o`80oooo00<000000?ooo`3oool0603oool30000o`P0oooo00<0
0?oo0?ooo`3oool0103oool00`00o`00oooo0?ooo`030?ooo`040?l0003oool0oooo0?ooo`80ObXZ
103oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo00@0oooo00<00?oo0?ooo`3oool0
1P3oool30000oad0oooo1P3o0?lf0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool04@3oool001<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0o`3o00D0o`3o6P3oool20000o`L0oooo00<00?oo0?ooo`3oool0103oool00`00o`00
oooo0?ooo`030?ooo`030?l0003oool0oooo0080ObXZ103oool00`3o0000oooo0?ooo`030?ooo`03
003o003oool0oooo00@0oooo00<00?oo0?ooo`3oool01@3oool20000oaX0oooo1P3o0?l30?ooo`03
0000003oool0oooo03H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0A0?oo
o`004@3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000=@3oool40000
00@0oooo1P3o0?lF0?ooo`80003o1P3oool00`00ool0oooo0?ooo`040?ooo`03003o003oool0oooo
0080oooo00<0o`000?ooo`3oool00P1o:RX40?ooo`030?l0003oool0oooo0080oooo00<00?l00?oo
o`3oool0103oool00`00ool0oooo0?ooo`040?ooo`80003o5P3oool60?l0o`D0oooo1000000g0?oo
o`030000003oool000000080oooo00D000000?ooo`3oool0oooo0000000C0?ooo`004P3oool20000
0080oooo00D000000?ooo`3oool0oooo0000000f0?ooo`030000003oool0oooo00X0oooo1@3o0?lC
0?ooo`<0003o103oool2003oo`@0oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
07lZ:P@0oooo00D0o`000?ooo`3oool0oooo003o00050?ooo`800?oo103oool30000oa80oooo1P3o
0?l<0?ooo`030000003oool0oooo03P0oooo0P0000020?ooo`050000003oool0oooo0?ooo`000000
4`3oool001<0oooo00@000000?ooo`3oool0oooo0`00000g0?ooo`@000003P3oool60?l0oa00oooo
0P000?l40?ooo`03003oo`3oool0oooo0080oooo00D00?l00?ooo`3oool0oooo0?l000020?ooo`80
ObXZ0`3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo0080oooo00<00?oo0?ooo`3o
ool00P3oool20000o`l0oooo1P3o0?lB0?ooo`@00000>03oool010000000oooo0?ooo`3oool30000
01@0oooo001Y0?ooo`P0o`3o2P3oool20000o`<0oooo0P00ool30?ooo`06003o003oool0oooo0?oo
o`3o0000oooo0P1o:RX30?ooo`050?l0003oool0oooo0?ooo`00o`000`3oool2003oo`<0oooo0P00
0?l:0?ooo`L0o`3oK`3oool00740oooo1P3o0?l60?ooo`80003o0`3oool01000ool0oooo0?ooo`00
o`030?ooo`040?l0003oool0ObXZ07lZ:P<0oooo00@0o`000?ooo`3oool00?l00`3oool01000ool0
oooo0?ooo`3oool20000o`H0oooo1P3o0?mf0?ooo`00M`3oool20?l0o`H0oooo0P000?l20?ooo`04
003oo`3oool0oooo003o0080oooo00@0o`000?ooo`1o:RX0ObXZ0`3oool0103o0000oooo0?ooo`00
o`020?ooo`03003oo`3oool0oooo0080003o1P3oool20?l0og`0oooo001i0?ooo`@0o`3o103oool0
0`000?l0oooo003oo`020?ooo`05003o003oool0oooo0?l0003oool00P1o:RX30?ooo`040?l0003o
ool0oooo003o0080oooo00<00?oo0?ooo`000?l0103oool40?l0og00oooo0`00000;0?ooo`00O@3o
ool40?l0o`80003o00@0oooo003oo`3oool00?l00P3oool20?l00080ObXZ0`3oool0203o0000oooo
0?ooo`00o`00oooo003oo`3oool0003o1@3o0?mc0?ooo`040000003oool0oooo000000/0oooo000A
0?ooog00ObXZ2P00000207lZ:P/00000L01o:RX80?ooo`040000003oool0oooo000000/0oooo000A
0?ooog00ObXZ0P000?l2003oo`060?ooo`00o`00oooo0?ooo`3o0000oooo0P1o:RX30?ooo`080?l0
003oool0oooo003o003oool00?oo0?ooo`000?m`07lZ:PP0oooo00@000000?ooo`3oool000002`3o
ool007P0oooo1@3o0?l30?ooo`040000o`3oool0oooo003oo`80oooo00D00?l00?ooo`3oool0o`00
0?ooo`0207lZ:P<0oooo00@0o`000?ooo`3oool00?l00P3oool00`00ool0oooo0000o`040?ooo`D0
o`3oKP3oool010000000oooo0?ooo`00000;0?ooo`00L`3oool50?l0o`H0oooo0P000?l30?ooo`03
003oo`3oool00?l000<0oooo00@0o`000?ooo`1o:RX0ObXZ0`3oool0103o0000oooo0?ooo`00o`02
0?ooo`03003oo`3oool0oooo0080003o1`3oool50?l0ogP0oooo001_0?ooo`@0o`3o203oool30000
o`@0oooo00@00?oo0?ooo`3oool00?l00`3oool0103o0000oooo07lZ:P1o:RX30?ooo`040?l0003o
ool0oooo003o00<0oooo00@00?oo0?ooo`3oool0oooo10000?l80?ooo`@0o`3oM03oool006X0oooo
1@3o0?l:0?ooo`80003o1@3oool2003oo`<0oooo00H00?l00?ooo`3oool0oooo0?l0003oool207lZ
:P<0oooo00D0o`000?ooo`3oool0oooo003o00030?ooo`800?oo1@3oool20000o`X0oooo1@3o0?m_
0?ooo`00I03oool60?l0o`d0oooo0P000?l60?ooo`03003oo`3oool0oooo0080oooo00<00?l00?oo
o`3oool00P3oool0103o0000oooo07lZ:P1o:RX30?ooo`030?l0003oool0oooo0080oooo00<00?l0
0?ooo`3oool00P3oool00`00ool0oooo0?ooo`040?ooo`80003o3@3oool60?l0ofT0oooo001N0?oo
o`H0o`3o4@3oool20000o`L0oooo00<00?oo0?ooo`3oool00`3oool01@00o`00oooo0?ooo`3oool0
o`000080oooo0P1o:RX40?ooo`050?l0003oool0oooo0?ooo`00o`001@3oool00`00ool0oooo0?oo
o`050?ooo`80003o4@3oool60?l0of<0oooo001I0?ooo`D0o`3o5@3oool20000o`L0oooo0P00ool5
0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool00P1o:RX40?ooo`030?l0003oool0
oooo0080oooo00<00?l00?ooo`3oool00`3oool2003oo`L0oooo0P000?lE0?ooo`D0o`3oGP3oool0
05<0oooo1P3o0?lH0?ooo`80003o203oool00`00ool0oooo0?ooo`040?ooo`03003o003oool0oooo
00<0oooo00<0o`000?ooo`3oool00P1o:RX40?ooo`030?l0003oool0oooo00<0oooo00<00?l00?oo
o`3oool0103oool00`00ool0oooo0?ooo`060?ooo`80003o603oool60?l0oeP0oooo001>0?ooo`D0
o`3o6`3oool30000o`T0oooo00<00?oo0?ooo`3oool0103oool00`00o`00oooo0?ooo`030?ooo`04
0?l0003oool0oooo0?ooo`80ObXZ1@3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo
00@0oooo00<00?oo0?ooo`3oool01`3oool30000oa/0oooo1@3o0?mC0?ooo`00B03oool60?l0oah0
oooo0P000?l;0?ooo`03003oo`3oool0oooo00@0oooo00<00?l00?ooo`3oool0103oool0103o0000
oooo0?ooo`3oool207lZ:PD0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`040?oo
o`03003oo`3oool0oooo00T0oooo0P000?lN0?ooo`H0o`3oC@3oool00480oooo1P3o0?lQ0?ooo`<0
003o2`3oool2003oo`H0oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`80
ObXZ1P3oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo00@0oooo0P00ool;0?ooo`<0
003o8@3oool60?l0odL0oooo000l0?ooo`H0o`3o9@3oool20000o`d0oooo00<00?oo0?ooo`3oool0
1P3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo0P1o:RX60?ooo`030?l0
003oool0oooo00@0oooo00<00?l00?ooo`3oool01P3oool00`00ool0oooo0?ooo`0;0?ooo`80003o
9@3oool60?l0od40oooo000e0?ooo`L0o`3o:03oool30000o`h0oooo00<00?oo0?ooo`3oool01P3o
ool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo0P1o:RX60?ooo`030?l0003o
ool0oooo00D0oooo00<00?l00?ooo`3oool01P3oool00`00ool0oooo0?ooo`0<0?ooo`<0003o:03o
ool70?l0ocX0oooo000_0?ooo`H0o`3o;03oool30000o`l0oooo0P00ool80?ooo`03003o003oool0
oooo00D0oooo00<0o`000?ooo`3oool00`3oool207lZ:PL0oooo00<0o`000?ooo`3oool01@3oool0
0`00o`00oooo0?ooo`060?ooo`800?oo3`3oool30000ob`0oooo1P3o0?ld0?ooo`00:@3oool60?l0
obl0oooo0`000?l@0?ooo`800?oo2P3oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo
00<0oooo0P1o:RX70?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool0203oool2003o
oa00oooo0`000?l_0?ooo`H0o`3o;P3oool00280oooo1`3o0?lb0?ooo`<0003o4@3oool2003oo`/0
oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`80ObXZ1`3oool00`3o0000
oooo0?ooo`060?ooo`03003o003oool0oooo00T0oooo0P00oolA0?ooo`<0003o<P3oool70?l0obL0
oooo000L0?ooo`H0o`3o=P3oool30000oa80oooo0P00ool<0?ooo`03003o003oool0oooo00H0oooo
00<0o`000?ooo`3oool0103oool207lZ:PP0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo
0?ooo`0:0?ooo`800?oo4P3oool30000ocH0oooo1P3o0?lQ0?ooo`005P3oool60?l0ocT0oooo0`00
0?lD0?ooo`03003oo`3oool0oooo00/0oooo00<00?l00?ooo`3oool01`3oool00`3o0000oooo0?oo
o`040?ooo`80ObXZ203oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo00/0oooo00<0
0?oo0?ooo`3oool04P3oool30000ocT0oooo1P3o0?lK0?ooo`004P3oool40?l0ocd0oooo0P000?lE
0?ooo`800?oo3@3oool00`00o`00oooo0?ooo`080?ooo`030?l0003oool0oooo00@0oooo0P1o:RX8
0?ooo`030?l0003oool0oooo00P0oooo00<00?l00?ooo`3oool02`3oool2003ooaD0oooo0P000?lm
0?ooo`@0o`3o5`3oool00500oooo0`000?lF0?ooo`03003oo`3oool0oooo00`0oooo00<00?l00?oo
o`3oool0203oool00`3o0000oooo0?ooo`050?ooo`80ObXZ2@3oool00`3o0000oooo0?ooo`070?oo
o`03003o003oool0oooo00d0oooo00<00?oo0?ooo`3oool0503oool30000oeD0oooo001=0?ooo`<0
003o5`3oool2003oo`h0oooo00<00?l00?ooo`3oool02@3oool00`3o0000oooo0?ooo`050?ooo`80
ObXZ2@3oool00`3o0000oooo0?ooo`080?ooo`03003o003oool0oooo00d0oooo0P00oolG0?ooo`<0
003oDP3oool004/0oooo0P000?lI0?ooo`03003oo`3oool0oooo00d0oooo00<00?l00?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`060?ooo`80ObXZ2P3oool00`3o0000oooo0?ooo`080?ooo`03003o
003oool0oooo00h0oooo00<00?oo0?ooo`3oool05`3oool20000oe00oooo00180?ooo`<0003o6@3o
ool2003oo`l0oooo00<00?l00?ooo`3oool02P3oool00`3o0000oooo0?ooo`060?ooo`80ObXZ2P3o
ool00`3o0000oooo0?ooo`090?ooo`03003o003oool0oooo00h0oooo0P00oolI0?ooo`<0003oC@3o
ool004D0oooo0`000?lK0?ooo`03003oo`3oool0oooo00h0oooo00<00?l00?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`070?ooo`80ObXZ2`3oool00`3o0000oooo0?ooo`090?ooo`03003o003oool0
oooo00l0oooo00<00?oo0?ooo`3oool06@3oool30000odX0oooo00130?ooo`80003o703oool2003o
oa00oooo00<00?l00?ooo`3oool02`3oool00`3o0000oooo0?ooo`070?ooo`80ObXZ2`3oool00`3o
0000oooo0?ooo`0:0?ooo`03003o003oool0oooo00l0oooo0P00oolL0?ooo`80003oB03oool00400
oooo0`000?lM0?ooo`03003oo`3oool0oooo00l0oooo00<00?l00?ooo`3oool0303oool00`3o0000
oooo0?ooo`070?ooo`80ObXZ2`3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo0100
oooo00<00?oo0?ooo`3oool06`3oool30000odD0oooo000m0?ooo`<0003o7P3oool2003ooa40oooo
00<00?l00?ooo`3oool0303oool00`3o0000oooo0?ooo`080?ooo`80ObXZ303oool00`3o0000oooo
0?ooo`0;0?ooo`03003o003oool0oooo0100oooo0P00oolN0?ooo`<0003o@P3oool003X0oooo0`00
0?lP0?ooo`03003oo`3oool0oooo0140oooo00<00?l00?ooo`3oool0303oool00`3o0000oooo0?oo
o`080?ooo`80ObXZ303oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo0140oooo00<0
0?oo0?ooo`3oool07P3oool30000ocl0oooo000g0?ooo`<0003o8@3oool2003ooa<0oooo00<00?l0
0?ooo`3oool0303oool00`3o0000oooo0?ooo`090?ooo`80ObXZ3@3oool00`3o0000oooo0?ooo`0<
0?ooo`03003o003oool0oooo0140oooo0P00oolQ0?ooo`<0003o?03oool003@0oooo0`000?lS0?oo
o`03003oo`3oool0oooo0180oooo00<00?l00?ooo`3oool03@3oool00`3o0000oooo0?ooo`090?oo
o`80ObXZ3@3oool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo0180oooo00<00?oo0?oo
o`3oool08@3oool30000ocT0oooo000b0?ooo`80003o903oool2003ooa@0oooo00<00?l00?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0:0?ooo`80ObXZ3P3oool00`3o0000oooo0?ooo`0=0?ooo`03
003o003oool0oooo0180oooo0P00oolT0?ooo`80003o=`3oool002l0oooo0`000?lT0?ooo`800?oo
5@3oool00`00o`00oooo0?ooo`0>0?ooo`030?l0003oool0oooo00X0oooo0P1o:RX>0?ooo`030?l0
003oool0oooo00h0oooo00<00?l00?ooo`3oool04`3oool2003oob@0oooo0`000?ld0?ooo`00;03o
ool30000obH0oooo00<00?oo0?ooo`3oool0503oool00`00o`00oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00/0oooo0P1o:RX?0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool0503o
ool00`00ool0oooo0?ooo`0T0?ooo`<0003o<@3oool002T0oooo0`000?lW0?ooo`800?oo5P3oool0
0`00o`00oooo0?ooo`0?0?ooo`030?l0003oool0oooo00<0oooo0`0000050?ooo`80ObXZ3`3oool0
0`3o0000oooo0?ooo`0?0?ooo`03003o003oool0oooo01@0oooo0P00oolW0?ooo`<0003o;P3oool0
02H0oooo0`000?lY0?ooo`03003oo`3oool0oooo01D0oooo00<00?l00?ooo`3oool03`3oool00`3o
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool207lZ:Q00oooo00<0o`00
0?ooo`3oool03`3oool00`00o`00oooo0?ooo`0E0?ooo`03003oo`3oool0oooo02L0oooo0`000?l[
0?ooo`008`3oool30000obX0oooo0P00oolG0?ooo`03003o003oool0oooo0100oooo00<0o`000?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`80ObXZ403oool00`3o0000oooo0?ooo`0@0?oo
o`03003o003oool0oooo01D0oooo0P00oolZ0?ooo`<0003o:03oool00200oooo0`000?l/0?ooo`03
003oo`3oool0oooo01H0oooo00<00?l00?ooo`3oool04@3oool00`3o0000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`000000103oool207lZ:P8000003P3oool00`3o0000oooo0?ooo`0A0?oo
o`03003o003oool0oooo01H0oooo00<00?oo0?ooo`3oool0:P3oool30000obD0oooo000M0?ooo`<0
003o;@3oool2003ooaP0oooo00<00?l00?ooo`3oool04@3oool00`3o0000oooo0?ooo`040?ooo`@0
00001@3oool207lZ:Q40oooo00<0o`000?ooo`3oool04@3oool00`00o`00oooo0?ooo`0F0?ooo`80
0?oo;@3oool30000ob80oooo000J0?ooo`<0003o;P3oool2003ooaX0oooo00<00?l00?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0P1o:RXA0?ooo`030?l0
003oool0oooo0140oooo00<00?l00?ooo`3oool0603oool2003oobh0oooo0`000?lO0?ooo`005`3o
ool30000oc00oooo00<00?oo0?ooo`3oool06@3oool00`00o`00oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo00H0oooo100000040?ooo`80ObXZ4P3oool00`3o0000oooo0?ooo`0A0?ooo`03003o003o
ool0oooo01T0oooo00<00?oo0?ooo`3oool0;P3oool30000oa`0oooo000D0?ooo`<0003o<@3oool2
003ooa/0oooo00<00?l00?ooo`3oool04P3oool00`3o0000oooo0?ooo`0>0?ooo`80ObXZ4P3oool0
0`3o0000oooo0?ooo`0B0?ooo`03003o003oool0oooo01T0oooo0P00oola0?ooo`<0003o6@3oool0
0180oooo0P000?lb0?ooo`800?oo703oool00`00o`00oooo0?ooo`0C0?ooo`030?l0003oool0oooo
00h0oooo0P1o:RXB0?ooo`030?l0003oool0oooo01<0oooo00<00?l00?ooo`3oool06P3oool2003o
oc80oooo0P000?lG0?ooo`00A03oool2003ooad0oooo00<00?l00?ooo`3oool04`3oool00`3o0000
oooo0?ooo`0?0?ooo`80ObXZ4`3oool00`3o0000oooo0?ooo`0C0?ooo`03003o003oool0oooo01/0
oooo0P00oom90?ooo`00@`3oool00`00ool0oooo0?ooo`0L0?ooo`03003o003oool0oooo01@0oooo
00<0o`000?ooo`3oool03`3oool207lZ:Q<0oooo00<0o`000?ooo`3oool0503oool00`00o`00oooo
0?ooo`0L0?ooo`03003oo`3oool0oooo04H0oooo00110?ooo`800?oo7P3oool00`00o`00oooo0?oo
o`0D0?ooo`030?l0003oool0oooo0100oooo0P1o:RXD0?ooo`030?l0003oool0oooo01@0oooo00<0
0?l00?ooo`3oool0703oool2003oodH0oooo000o0?ooo`800?oo7`3oool00`00o`00oooo0?ooo`0E
0?ooo`030?l0003oool0oooo0100oooo0P1o:RXD0?ooo`030?l0003oool0oooo01D0oooo00<00?l0
0?ooo`3oool07@3oool2003ood@0oooo000n0?ooo`03003oo`3oool0oooo01h0oooo00<00?l00?oo
o`3oool05P3oool00`3o0000oooo0?ooo`0@0?ooo`80ObXZ503oool00`3o0000oooo0?ooo`0F0?oo
o`03003o003oool0oooo01h0oooo00<00?oo0?ooo`3oool0@@3oool003`0oooo0P00oolP0?ooo`03
003o003oool0oooo01H0oooo00<0o`000?ooo`3oool04@3oool207lZ:QD0oooo00<0o`000?ooo`3o
ool05P3oool00`00o`00oooo0?ooo`0N0?ooo`800?oo@@3oool003X0oooo0P00oolQ0?ooo`03003o
003oool0oooo01L0oooo00<0o`000?ooo`3oool04@3oool207lZ:QD0oooo00<0o`000?ooo`3oool0
5`3oool00`00o`00oooo0?ooo`0O0?ooo`800?oo?`3oool003P0oooo0P00oolR0?ooo`03003o003o
ool0oooo01L0oooo00<0o`000?ooo`3oool04P3oool207lZ:QH0oooo00<0o`000?ooo`3oool05`3o
ool00`00o`00oooo0?ooo`0P0?ooo`800?oo?@3oool003L0oooo00<00?oo0?ooo`3oool08@3oool0
0`00o`00oooo0?ooo`0H0?ooo`030?l0003oool0oooo0180oooo0P1o:RXF0?ooo`030?l0003oool0
oooo01P0oooo00<00?l00?ooo`3oool08@3oool00`00ool0oooo0?ooo`0j0?ooo`00=@3oool2003o
ob<0oooo00<00?l00?ooo`3oool06@3oool00`3o0000oooo0?ooo`0B0?ooo`80ObXZ5P3oool00`3o
0000oooo0?ooo`0I0?ooo`03003o003oool0oooo0240oooo0P00oolj0?ooo`00=03oool00`00ool0
oooo0?ooo`0R0?ooo`03003o003oool0oooo01T0oooo00<0o`000?ooo`3oool04`3oool207lZ:QL0
oooo00<0o`000?ooo`3oool06@3oool00`00o`00oooo0?ooo`0R0?ooo`03003oo`3oool0oooo03L0
oooo000b0?ooo`800?oo903oool00`00o`00oooo0?ooo`0J0?ooo`030?l0003oool0oooo01<0oooo
0P1o:RXG0?ooo`030?l0003oool0oooo01T0oooo00<00?l00?ooo`3oool08`3oool2003oocL0oooo
000`0?ooo`800?oo9P3oool00`00o`00oooo0?ooo`0I0?ooo`030?l0003oool0oooo01@0oooo0P1o
:RXH0?ooo`030?l0003oool0oooo01T0oooo00<00?l00?ooo`3oool0903oool2003oocD0oooo000_
0?ooo`03003oo`3oool0oooo02D0oooo00<00?l00?ooo`3oool06P3oool00`3o0000oooo0?ooo`0D
0?ooo`80ObXZ603oool00`3o0000oooo0?ooo`0J0?ooo`03003o003oool0oooo02D0oooo00<00?oo
0?ooo`3oool0<P3oool002d0oooo0P00oolW0?ooo`03003o003oool0oooo01X0oooo00<0o`000?oo
o`3oool05@3oool207lZ:QT0oooo00<0o`000?ooo`3oool06P3oool00`00o`00oooo0?ooo`0U0?oo
o`800?oo<P3oool002`0oooo00<00?oo0?ooo`3oool09P3oool00`00o`00oooo0?ooo`0K0?ooo`03
0?l0003oool0oooo01D0oooo0P1o:RXI0?ooo`030?l0003oool0oooo01/0oooo00<00?l00?ooo`3o
ool09P3oool00`00ool0oooo0?ooo`0_0?ooo`00:P3oool2003oobP0oooo00<00?l00?ooo`3oool0
6`3oool00`3o0000oooo0?ooo`0F0?ooo`80ObXZ6P3oool00`3o0000oooo0?ooo`0K0?ooo`03003o
003oool0oooo02H0oooo0P00ool_0?ooo`00:03oool2003oobT0oooo00<00?l00?ooo`3oool0703o
ool00`3o0000oooo0?ooo`0F0?ooo`80ObXZ6P3oool00`3o0000oooo0?ooo`0L0?ooo`03003o003o
ool0oooo02L0oooo0P00ool]0?ooo`009`3oool00`00ool0oooo0?ooo`0X0?ooo`03003o003oool0
oooo01`0oooo00<0o`000?ooo`3oool05`3oool207lZ:QX0oooo00<0o`000?ooo`3oool07@3oool0
0`00o`00oooo0?ooo`0X0?ooo`03003oo`3oool0oooo02X0oooo000U0?ooo`800?oo:P3oool00`00
o`00oooo0?ooo`0M0?ooo`030?l0003oool0oooo01L0oooo0P1o:RXK0?ooo`030?l0003oool0oooo
01d0oooo00<00?l00?ooo`3oool0:03oool2003oobX0oooo000T0?ooo`03003oo`3oool0oooo02T0
oooo00<00?l00?ooo`3oool07P3oool00`3o0000oooo0?ooo`0G0?ooo`80ObXZ6`3oool00`3o0000
oooo0?ooo`0N0?ooo`03003o003oool0oooo02T0oooo00<00?oo0?ooo`3oool09`3oool00280oooo
0P00ool[0?ooo`03003o003oool0oooo01h0oooo00<0o`000?ooo`3oool0603oool207lZ:Q`0oooo
00<0o`000?ooo`3oool07P3oool00`00o`00oooo0?ooo`0Y0?ooo`800?oo9`3oool00200oooo0P00
ool/0?ooo`03003o003oool0oooo01l0oooo00<0o`000?ooo`3oool0603oool207lZ:Q`0oooo00<0
o`000?ooo`3oool07`3oool00`00o`00oooo0?ooo`0Z0?ooo`800?oo9@3oool001l0oooo00<00?oo
0?ooo`3oool0:`3oool00`00o`00oooo0?ooo`0O0?ooo`030?l0003oool0oooo01T0oooo0P1o:RXM
0?ooo`030?l0003oool0oooo01l0oooo00<00?l00?ooo`3oool0:`3oool00`00ool0oooo0?ooo`0R
0?ooo`007@3oool2003oobd0oooo00<00?l00?ooo`3oool0803oool00`3o0000oooo0?ooo`0I0?oo
o`80ObXZ7@3oool00`3o0000oooo0?ooo`0P0?ooo`03003o003oool0oooo02/0oooo0P00oolR0?oo
o`00703oool00`00ool0oooo0?ooo`0/0?ooo`03003o003oool0oooo0200oooo00<0o`000?ooo`3o
ool06P3oool207lZ:Qh0oooo00<0o`000?ooo`3oool0803oool00`00o`00oooo0?ooo`0/0?ooo`03
003oo`3oool0oooo01l0oooo000J0?ooo`800?oo;`3oool00`00o`00oooo0?ooo`0P0?ooo`030?l0
003oool0oooo01X0oooo0P1o:RXN0?ooo`030?l0003oool0oooo0200oooo00<00?l00?ooo`3oool0
;@3oool2003ooal0oooo000H0?ooo`800?oo<03oool00`00o`00oooo0?ooo`0P0?ooo`030?l0003o
ool0oooo01/0oooo0P1o:RXO0?ooo`030?l0003oool0oooo0200oooo00<00?l00?ooo`3oool0;P3o
ool2003ooad0oooo000G0?ooo`03003oo`3oool0oooo02l0oooo00<00?l00?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`0K0?ooo`80ObXZ7`3oool00`3o0000oooo0?ooo`0Q0?ooo`03003o003oool0
oooo02l0oooo00<00?oo0?ooo`3oool06P3oool001D0oooo0P00oola0?ooo`03003o003oool0oooo
0280oooo00<0o`000?ooo`3oool03`3oool010000000oooo0?ooo`3oool3000000D0oooo0P1o:RXO
0?ooo`030?l0003oool0oooo0280oooo00<00?l00?ooo`3oool0;`3oool2003ooaX0oooo000D0?oo
o`03003oo`3oool0oooo0300oooo00<00?l00?ooo`3oool08P3oool00`3o0000oooo0?ooo`0@0?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool207lZ:R00oooo00<0o`00
0?ooo`3oool08P3oool00`00o`00oooo0?ooo`0`0?ooo`03003oo`3oool0oooo01L0oooo000B0?oo
o`800?oo<P3oool00`00o`00oooo0?ooo`0S0?ooo`030?l0003oool0oooo0100oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`020?ooo`80ObXZ0P00000N0?ooo`030?l0003oool0
oooo02<0oooo00<00?l00?ooo`3oool0<03oool2003ooaL0oooo001o0?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00P3oool207lZ:Y80oooo001m0?ooo`030000003oool00000
0080oooo00D000000?ooo`3oool0oooo0000002H0?ooo`00OP3oool200000080oooo00D000000?oo
o`3oool0oooo0000002H0?ooo`00O`3oool010000000oooo0?ooo`3oool3000009T0oooo003o0?oo
ob00oooo003o0?ooob00oooo003o0?ooob00oooo003o0?ooob00oooo003o0?ooob00oooo003o0?oo
ob00oooo002<0?ooo`030000003oool0oooo0900oooo002;0?ooo`030000003oool000000940oooo
002;0?ooo`030000003oool000000940oooo002;0?ooo`030000003oool000000940oooo002:0?oo
o`050000003oool0oooo0?ooo`000000T03oool00?l0oooo803oool00?l0oooo803oool00?l0oooo
803oool00?l0oooo803oool00001\
\>"],
    ImageRangeCache->{{{0, 286.5}, {176.625, 0}} -> {-11, -10, 0, 0}}],
  StyleBox["  \n\t\t\tFigure 5.7",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Vertical segments mapped onto hyperbolas by  ",
  Cell[BoxData[
      \(w\  = sin\ z\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the formula f[z] = Sin[z] and graph the transformation.\
\>", "Text"],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, wplane];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ Sin[z];\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {\(-\[Pi]\)\/2, \[Pi]\/2, \[Pi]\/16}, {\(-1\), 1, 0.25}, 
        PlotRange \[Rule] {{\(-1.7\), 1.7}, {\(-1.1\), 1.1}}, 
        AspectRatio \[Rule] 1.1\/1.7, 
        Ticks \[Rule] {{{\(-\(\[Pi]\/2\)\), \*"\"\<\!\(\(-\[Pi]\)\/2\)     \>\
\""}, {\[Pi]\/2, \*"\"\<    \!\(\[Pi]\/2\)\>\""}}, Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Blue, Red}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The lines forming the rectangle \!\(\(-\[Pi]\)\/2\) \
\[LessEqual] x \[LessEqual] \!\(\[Pi]\/2\), -1 \[LessEqual] y \[LessEqual] 1.\
\>\""];\)\ \), "\n", 
    \(\(CartesianMap[
        f, {\(-\[Pi]\)\/2, \[Pi]\/2, \[Pi]\/16}, {\(-1\), 1, 0.25}, 
        PlotRange \[Rule] {{\(-1.6\), 1.6}, {\(-1.2\), 1.2}}, 
        AspectRatio \[Rule] 1.2\/1.6, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Red}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image hyperbolas and ellipses,\>"];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, wplane];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ Sin[z];\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {\(-\[Pi]\)\/2, \[Pi]\/2, \[Pi]\/12}, {\(-3\), 3, 0.5}, 
        PlotRange \[Rule] {{\(-1.7\), 1.7}, {\(-3\), 3}}, 
        AspectRatio \[Rule] 1.1\/1.7, 
        Ticks \[Rule] {{{\(-\(\[Pi]\/2\)\), \*"\"\<\!\(\(-\[Pi]\)\/2\)     \>\
\""}, {\[Pi]\/2, \*"\"\<    \!\(\[Pi]\/2\)\>\""}}, Range[\(-3\), 3, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The lines forming the rectangle \!\(\(-\[Pi]\)\/2\) \
\[LessEqual] x \[LessEqual] \!\(\[Pi]\/2\), -1 \[LessEqual] y \[LessEqual] 1.\
\>\""];\)\ \), "\n", 
    \(\(CartesianMap[
        f, {\(-\[Pi]\)\/2, \[Pi]\/2, \[Pi]\/12}, {\(-3\), 3, 0.25}, 
        PlotRange \[Rule] {{\(-10.6\), 10.6}, {\(-10.2\), 10.2}}, 
        AspectRatio \[Rule] 1.2\/1.6, 
        Ticks \[Rule] {Range[\(-10\), 10, 5], Range[\(-10\), 10, 5]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image hyperbolas and ellipses,\>"];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tFigure 5.7 suggests one big difference between the real and complex sine \
functions. The real sine has the property that  ",
  Cell[BoxData[
      \(\(\(|\)\(sin\ x\)\(|\)\(\(\[LessEqual]\)\(1\)\)\)\)]],
  "  for all real ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ".  In Figure 5.7, however, the modulus of the complex sine appears to be \
unbounded, which is indeed the case.  Using Identity ",
  StyleBox["(5-34)",
    FontColor->RGBColor[0, 0, 1]],
  " gives  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(|\)\(sin\ z\)\( | \^2\)\)\ \  = \ \(\(\(|\)\(sin \((x + \
\[ImaginaryI]\ y)\)\)\( | \^2\)\)\ \[IndentingNewLine]\[IndentingNewLine]\ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  = \ \(\(\(|\)\(sin\ x\ cosh\ y\  + \ \
\[ImaginaryI]\ cos\ x\ sinh\ y\)\( | \^2\)\)\[IndentingNewLine]\
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  = \ 
            sin\^2\ x\ cosh\^2\ y\  + \ 
              cos\^2\ x\ sinh\^2\ y\)\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(sin\^2\ x\ \
\((cosh\^2\ y - 
                sinh\^2\ y)\)\  + \ \(\(sinh\^2\)\(\ \)\(y\)\(\ \ \)\((cos\^2\
\ x\  + sin\^2\ x)\)\(\ \)\)\)\)\)}]],
  "   \n\nThe identities  ",
  Cell[BoxData[
      \(cosh\^2\ y - sinh\^2\ y\  = \ 1\)]],
  "  and  ",
  Cell[BoxData[
      \(cos\^2\ x\  + sin\^2\ x\  = \ 1\)]],
  "  then yield  \n\n",
  StyleBox["(5-36)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(sin\ z\)\( | \^2\)\)\ \  = \ \ sin\^2\ x\  + \ 
          sinh\^2\ y\)]],
  ".  \n\nA similar derivation produces  \n\n",
  StyleBox["(5-37)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(cos\ z\)\( | \^2\)\)\ \  = \ \ cos\^2\ x\  + \ 
          sinh\^2\ y\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tIf we set ",
  Cell[BoxData[
      \(z = x\_0 + \(\(\[ImaginaryI]\)\(\ \)\(y\)\(\ \)\)\)]],
  " in Identity ",
  StyleBox["(5-36)",
    FontColor->RGBColor[0, 0, 1]],
  " and let  ",
  Cell[BoxData[
      \(y \[Rule] \[Infinity]\)]],
  ",  we get  \n\n\t\t\t",
  Cell[BoxData[
      \(lim\+\(y \[Rule] \[Infinity]\)\ \(\(|\)\(sin\ \((x\_0 + \[ImaginaryI]\
\ y)\)\)\( | \^2\)\)\ \  = \ \ \(sin\^2\ x\_0\ \  + \ \ lim\+\(y \[Rule] \
\[Infinity]\)\ sinh\^2\ y\ \  = \ \ \[Infinity]\)\)]],
  "\n\nAs advertised, we have shown that ",
  Cell[BoxData[
      \(sin\ z\)]],
  " is not a bounded function; it is also evident from Identity ",
  StyleBox["(5-37)",
    FontColor->RGBColor[0, 0, 1]],
  " that ",
  Cell[BoxData[
      \(cos\ z\)]],
  " is unbounded."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Remove[w];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[aw];\)\ \), "\n", 
    \(\(w\ \  = \ ComplexExpand[Sin[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(aw\  = \ 
        ComplexExpand[
          Abs[w], \n\ \ \ \ \ \ \ TargetFunctions \[Rule] {Im, 
              Re}];\)\ \), "\[IndentingNewLine]", 
    \(\(aw1 = 
        ReplaceAll[
          aw\^2, {Cos[x]\^2 \[Rule] 1 - Sin[x]\^2, 
            Cosh[y]\^2 \[Rule] 
              1 + Sinh[y]\^2}];\)\ \), "\[IndentingNewLine]", 
    \(\(aw2 = Simplify[aw1];\)\ \), "\n", 
    \(\(Print["\<   Sin[x+\[ImaginaryI]y] = \>", 
        w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<|Sin[x+\[ImaginaryI]y]|\>"\^2, "\< = \>", 
        aw\^2];\)\ \), "\n", 
    \(\(Print["\<|Sin[x+\[ImaginaryI]y]|\>"\^2, "\< = \>", 
        aw1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<|Sin[x+\[ImaginaryI]y]|\>"\^2, "\< = \>", 
        aw2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[w];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[aw];\)\ \), "\n", 
    \(\(w\ \  = \ ComplexExpand[Cos[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(aw\  = \ 
        ComplexExpand[
          Abs[w], \n\ \ \ \ \ \ \ TargetFunctions \[Rule] {Im, 
              Re}];\)\ \), "\[IndentingNewLine]", 
    \(\(aw1 = 
        ReplaceAll[
          aw\^2, {Sin[x]\^2 \[Rule] 1 - Cos[x]\^2, 
            Cosh[y]\^2 \[Rule] 
              1 + Sinh[y]\^2}];\)\ \), "\[IndentingNewLine]", 
    \(\(aw2 = Simplify[aw1];\)\ \), "\n", 
    \(\(Print["\<   Cos[x+\[ImaginaryI]y] = \>", 
        w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<|Cos[x+\[ImaginaryI]y]|\>"\^2, "\< = \>", 
        aw\^2];\)\ \), "\n", 
    \(\(Print["\<|Cos[x+\[ImaginaryI]y]|\>"\^2, "\< = \>", 
        aw1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<|Cos[x+\[ImaginaryI]y]|\>"\^2, "\< = \>", 
        aw2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tThe periodic character of the trigonometric functions makes apparent that \
any point in their ranges is actually the image of infinitely many points.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 5.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find all the values of  z  for which  ",
  Cell[BoxData[
      \(cos\ z = cosh\ 2\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  Starting with Identity ",
  StyleBox["(5-35)",
    FontColor->RGBColor[0, 0, 1]],
  ", we write \n\n\t\t\t",
  Cell[BoxData[
      \(cos\ z\ \  = \ \ \(cos\ x\ cosh\ y\  - \ \[ImaginaryI]\ sin\ x\ sinh\ \
y\ \  = \ \ cosh\ 2\)\)]],
  ".  \n\nIf we equate real and imaginary parts, then we get \n\n\t\t\t",
  Cell[BoxData[
      \(cos\ x\ cosh\ y\  = \ cosh\ 2\)]],
  "   and   ",
  Cell[BoxData[
      \(sin\ x\ sinh\ y\  = \ 0\)]],
  ".  \n\nThe equation  ",
  Cell[BoxData[
      \(sin\ x\ sinh\ y = 0\)]],
  "  implies either that  ",
  Cell[BoxData[
      \(x = n\ \[Pi]\)]],
  ", where ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is an integer, or that ",
  Cell[BoxData[
      \(y = 0\)]],
  ".  Using ",
  Cell[BoxData[
      \(y = 0\)]],
  " in the equation ",
  Cell[BoxData[
      \(cos\ x\ cosh\ y = cosh\ 2\)]],
  "  leads to the impossible situation  ",
  Cell[BoxData[
      \(cos\ x = \(\(cosh\ 2\)\/\(cosh\ 0\) = cosh\ 2 > 1\)\)]],
  ".  Therefore  ",
  Cell[BoxData[
      \(x = n\ \[Pi]\)]],
  ", where ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is an integer.  Since  ",
  Cell[BoxData[
      \(cosh\ y \[GreaterEqual] 1\)]],
  "  for all values of ",
  StyleBox["y",
    FontFamily->"Courier New"],
  ", the term ",
  Cell[BoxData[
      \(cos\ x\)]],
  " in the equation  ",
  Cell[BoxData[
      \(cos\ x\ cosh\ y = cosh\ 2\)]],
  "  must also be positive.  For this reason we eliminate the odd values of \
",
  StyleBox["n",
    FontFamily->"Courier New"],
  " and get  ",
  Cell[BoxData[
      \(x = 2  k\ \[Pi]\)]],
  ", where ",
  StyleBox["k",
    FontFamily->"Courier New"],
  " is an integer."
}], "Text"],

Cell[TextData[{
  "\tFinally, we solve the equation  ",
  Cell[BoxData[
      \(cos\ \((2  k\ \[Pi])\)\ cosh\ y = \(cosh\ y = cosh\ 2\)\)]],
  "  and use the fact that ",
  Cell[BoxData[
      \(cosh\ y\)]],
  " is an even function to conclude that  ",
  Cell[BoxData[
      \(y = \(\[PlusMinus]2\)\)]],
  ".  Therefore the solutions to the equation  ",
  Cell[BoxData[
      \(cos\ z = cosh\ 2\)]],
  "  are  ",
  Cell[BoxData[
      \(z = 2\ \[Pi]\ k \[PlusMinus] 2  \[ImaginaryI]\)]],
  ",  where k is an integer."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 5.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s \"Solve\" procedure to find some of the solutions to  cos z = cosh 2.  \
"
}], "Text"],

Cell[BoxData[{
    \(\(Remove[x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[cosZ, eq1, eq2];\)\ \), "\n", 
    \(\(cosZ\  = \ 
        ComplexExpand[
          Cos[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\[IndentingNewLine]", 
    \(\(eq1\  = \ ComplexExpand[Re[cosZ]]\  \[Equal] \ Cosh[2];\)\ \), "\n", 
    \(\(eq2\  = \ 
        ComplexExpand[Im[cosZ]]\  \[Equal] \ 
          0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        Cos[x\  + \ \[ImaginaryI]\ y]\  \[Equal] \ \ Cosh[2]];\)\ \), "\n", 
    \(\(Print[cosZ\  \[Equal] \ 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[eq1\ ];\)\ \), "\n", 
    \(\(Print[eq2];\)\ \), "\n", 
    \(\(Print[Solve[{eq1, eq2}, {x, y}]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["This is another way to solve the equation  cos(z) = cosh(2).", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[solset];\)\ \), "\n", 
    \(\(solset = Solve[Cos[z] \[Equal] Cosh[2], z];\)\ \), "\n", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(Print["\<The solutions are to cos(z) = cosh(2) are:\>"];\)\ \), "\n", \

    \(\(Print["\<2 k \[Pi] + \>", \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(Print["\<2 k \[Pi] \>", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["We can also list some of the solutions.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[k];\)\ \), "\[IndentingNewLine]", 
    \(\(For[k = 0, 
        k \[LessEqual] 5, \(k++\), \[IndentingNewLine]Print["\<Cos[\>", 
          2  k, "\< \[Pi] + 2\[ImaginaryI]] = \>", 
          Cos[2  k\ \[Pi] + 
              2  \[ImaginaryI]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(For[k = 0, 
        k \[LessEqual] 5, \(k++\), \[IndentingNewLine]Print["\<Cos[\>", 
          2  k, "\< \[Pi] - 2\[ImaginaryI]] = \>", 
          Cos[2  k\ \[Pi] - 
              2  \[ImaginaryI]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tThe hyperbolic functions also have practical use in putting the tangent \
function into the Cartesian form ",
  Cell[BoxData[
      \(u + \[ImaginaryI]\ v\)]],
  ".  \nUsing Definition 5.6, and Equations ",
  StyleBox["(5-34)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(5-35)",
    FontColor->RGBColor[0, 0, 1]],
  ", we have  \n\n",
  StyleBox["(5-38)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(tan\ z = \(tan \((x + \[ImaginaryI]\ y)\) = \ \(\(sin \((x + \
\[ImaginaryI]\ y)\)\)\/\(cos \((x + \[ImaginaryI]\ y)\)\) = \ \(sin\ x\ cosh\ \
y\ \  + \ \ \[ImaginaryI]\ cos\ x\ sinh\ y\)\/\(cos\ x\ cosh\ y\  - \ \
\[ImaginaryI]\ sin\ x\ sinh\ y\)\)\)\)]],
  ".  \n\nIf we multiply each term on the right by the conjugate of the \
denominator, the simplified result is  \n\n\t\t\t",
  Cell[BoxData[
      \(tan\ z\ \  = \ \ \(cos\ x\ \ sin\ x\ \  + \ \[ImaginaryI]\ cosh\ y\ \
sinh\ y\)\/\(\(cos\^2\) x\ \(cosh\^2\) y\  + \ \(sin\^2\) x\ \(sinh\^2\) \
y\)\)]],
  "\n\nWe leave it as an exercise to show that the identities  ",
  Cell[BoxData[
      \(\(cosh\^2\) y - \(sinh\^2\) y = 1\)]],
  "  and  ",
  Cell[BoxData[
      \(sinh\ 2\ y = 2  cosh\ y\ sinh\ y\)]],
  "  can be used in simplifying Equation ",
  StyleBox["(5-38)",
    FontColor->RGBColor[0, 0, 1]],
  " to get  \n\n",
  StyleBox["(5-39)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(tan\ z\ \  = \ \ \(sin \((2\ x)\)\)\/\(cos \((2\ x)\) + cosh \((2\ y)\
\)\)\  + \ \[ImaginaryI] \(\(\ \)\(sinh \((2\ y)\)\)\)\/\(cos \((2\ x)\) + \
cosh \((2\ y)\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(x = 0; y = 0; w = 0;\), "\[IndentingNewLine]", 
    \(\(Remove[w, x, y];\)\ \), "\n", 
    \(\(Clear[cos, sin];\)\), "\[IndentingNewLine]", 
    \(\(w\_1\  = \ 
        ComplexExpand[Sin[x + \[ImaginaryI]\ y]]\/ComplexExpand[Cos[x + \
\[ImaginaryI]\ y]];\)\), "\n", 
    \(\(Print["\<Tan[x+\[ImaginaryI]y] = \>", w\_1];\)\ \), "\n", 
    \(\(d01 = Cos[x]\ cosh[y] + \[ImaginaryI]\ Sin[x]\ sinh[y];\)\), "\n", 
    \(\(d02 = cos[x]\ Cosh[y] + \[ImaginaryI]\ sin[x]\ Sinh[y];\)\), "\n", 
    \(\(n1 = Numerator[w\_1] d01;\)\), "\n", 
    \(\(d1 = Denominator[w\_1] d02;\)\), "\n", 
    \(\(w\_2\  = n1\/d1;\)\), "\n", 
    \(\(Print["\<Tan[x+\[ImaginaryI]y] = \>", w\_2];\)\ \), "\n", 
    \(\(d = ComplexExpand[Conjugate[Denominator[w\_1]]];\)\), "\n", 
    \(\(n2 = ComplexExpand[Numerator[w\_1] d];\)\), "\n", 
    \(\(d2 = ComplexExpand[Denominator[w\_1] d];\)\), "\n", 
    \(\(w\_3\  = n2\/d2;\)\), "\n", 
    \(\(Print["\<Tan[x+\[ImaginaryI]y] = \>", w\_3];\)\ \), "\n", 
    \(\(n3 = Simplify[n2];\)\), "\n", 
    \(\(d3 = d2;\)\), "\n", 
    \(\(w\_4\  = n3\/d3;\)\), "\n", 
    \(\(Print["\<Tan[x+\[ImaginaryI]y] = \>", w\_4];\)\ \), "\n", 
    \(\(n4 = Simplify[n3];\)\), "\n", 
    \(\(d4 = Simplify[d3];\)\), "\n", 
    \(\(w\_5\  = n4\/d4;\)\), "\n", 
    \(\(Print["\<Tan[x+\[ImaginaryI]y] = \>", w\_5];\)\ \), "\n", 
    \(\(w\_5\  = ExpandNumerator[w\_5];\)\), "\n", 
    \(\(Print["\<Tan[x+\[ImaginaryI]y] = \>", w\_5];\)\ \), "\n", 
    \(\(w\_6\  = \ 
        ReplaceAll[w\_5, 2\ Cos[x]\ Sin[x] \[Rule] Sin[2  x]];\)\), "\n", 
    \(\(Print["\<Tan[x+\[ImaginaryI]y] = \>", w\_6];\)\ \), "\n", 
    \(\(w\_7\  = \ 
        ReplaceAll[w\_6, 
          2\ \[ImaginaryI]\ Cosh[y]\ Sinh[y] \[Rule] \[ImaginaryI]\ Sinh[
                2  y]];\)\), "\n", 
    \(\(Print["\<Tan[x+\[ImaginaryI]y] = \>", w\_7];\)\ \)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tAs with ",
  Cell[BoxData[
      \(sin\ z\)]],
  ", we obtain a graph of the mapping ",
  Cell[BoxData[
      \(w\  = tan\ z\)]],
  " parametrically.  Consider the vertical line segments in the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane obtained by successively setting  ",
  Cell[BoxData[
      \(x = \(-\(\[Pi]\/4\)\) + \(k\ \[Pi]\)\/16\)]],
  "  for  ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "8"}]]],
  ",  and for each ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " value letting y vary continuously, ",
  Cell[BoxData[
      \(3 \[LessEqual] y \[LessEqual] 3\)]],
  ".  In the exercises we ask you to show that the images of these vertical \
segments are circular arcs in the ",
  StyleBox["uv",
    FontFamily->"Courier New"],
  " plane, as Figure 5.8 shows.  In Chapter 9, we give a more detailed \
investigation of the mapping  ",
  Cell[BoxData[
      \(w\  = tan\ z\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 220 220 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.574713 0.5 0.166667 [
[.04862 .4875 -17.4375 -20.875 ]
[.04862 .4875 17.4375 0 ]
[.95138 .4875 -12.8125 -20.875 ]
[.95138 .4875 12.8125 0 ]
[1.025 .5 0 -6.5 ]
[1.025 .5 9 6.5 ]
[.4875 0 -16.375 -6.5 ]
[.4875 0 0 6.5 ]
[.4875 .16667 -16.375 -6.5 ]
[.4875 .16667 0 6.5 ]
[.4875 .33333 -16.375 -6.5 ]
[.4875 .33333 0 6.5 ]
[.4875 .66667 -9.5 -6.5 ]
[.4875 .66667 0 6.5 ]
[.4875 .83333 -9.5 -6.5 ]
[.4875 .83333 0 6.5 ]
[.4875 1 -9.5 -6.5 ]
[.4875 1 0 6.5 ]
[.5 1.025 -4.34375 0 ]
[.5 1.025 4.34375 13 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04862 .5 m
.04862 .50625 L
s
gsave
.04862 .4875 -78.4375 -24.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.688 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.563 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.438 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.438 16.688 moveto
(\\200\\200\\200\\200) show
69.938 16.688 moveto
(\\200\\200\\200\\200) show
75.438 16.688 moveto
(\\200) show
77.063 16.688 moveto
(\\200) show
68.813 23.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.875 16.688 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.95138 .5 m
.95138 .50625 L
s
gsave
.95138 .4875 -73.8125 -24.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.688 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.750 9.438 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
75.438 16.688 moveto
(\\200\\200\\200\\200) show
80.938 16.688 moveto
(\\200) show
81.563 16.688 moveto
(\\200) show
76.563 23.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
84.625 16.688 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
gsave
.4875 0 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
gsave
.4875 .16667 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .33333 m
.50625 .33333 L
s
gsave
.4875 .33333 -77.375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .66667 m
.50625 .66667 L
s
gsave
.4875 .66667 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .83333 m
.50625 .83333 L
s
gsave
.4875 .83333 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 0 m
.5 1 L
s
gsave
.5 1.025 -65.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
67.688 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
0 .5 m
.02472 .5 L
.07049 .5 L
.11348 .5 L
.15481 .5 L
.19881 .5 L
.24117 .5 L
.28619 .5 L
.32956 .5 L
.37128 .5 L
.41567 .5 L
.45842 .5 L
.49951 .5 L
.54327 .5 L
.58539 .5 L
.63017 .5 L
.6733 .5 L
.71478 .5 L
.75893 .5 L
.80144 .5 L
.8466 .5 L
.89012 .5 L
.932 .5 L
.97653 .5 L
s
.97653 .5 m
1 .5 L
s
1 0 1 r
.015 w
.04862 0 m
.04862 1 L
s
0 0 1 r
.16147 0 m
.16147 1 L
s
0 1 0 r
.27431 0 m
.27431 1 L
s
1 0 0 r
.38716 0 m
.38716 1 L
s
0 1 1 r
.5 0 m
.5 1 L
s
1 0 0 r
.61284 0 m
.61284 1 L
s
0 1 0 r
.72569 0 m
.72569 1 L
s
0 0 1 r
.83853 0 m
.83853 1 L
s
1 0 1 r
.95138 0 m
.95138 1 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{220, 220},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003L0000g2000`400?l00000o`00003og03oool0
0=`0oooo003L0?ooo`00g03oool00=`0oooo001Q0?ooo`<00000N03oool00600oooo00D000000?oo
o`3oool0oooo0000001g0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l0
00D0oooo100000060?ooo`030000003oool0oooo0080oooo0P00ool00`000000oooo0?ooo`0A0?oo
o`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80
003o503oool2003o01@0oooo0P3o000=0?ooo`8000001@3oool2003ooa@0oooo0P3o000D0?ooo`80
0?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0
503oool20?l000l0oooo00<000000?ooo`3oool00P3oool2003ooa@0oooo0P3o000D0?ooo`800?l0
503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503o
ool20?l000/0oooo00D000000?ooo`3oool0oooo000000040?ooo`800?oo503oool20?l001@0oooo
0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00
o`0D0?ooo`80o`00303oool3000000D0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P00
0?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D
0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?oo
o`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?oo
o`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`80
0?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80
o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo
503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503o
ool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503o
ool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool2
0?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool0
0140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l0
01@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0
oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0
oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo
0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o
0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00
o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D
0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI
0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?oo
o`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80
003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80
003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00
503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3o
ool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503o
ool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2
003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool2
0?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003o
oa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0
oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0
oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo
0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo
000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o
000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD
0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD
0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?oo
o`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80
o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`80
0?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0
503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o
6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503o
ool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool2
0000oa@0oooo0P00o`0D0?ooo`80o`002`3oool5000000@0oooo0P00oolD0?ooo`80o`00503oool2
003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o
01@0oooo0P3o000<0?ooo`030000003oool0oooo00D0oooo0P00oolD0?ooo`80o`00503oool2003o
01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0
oooo0P3o00050?ooo`@00000103oool00`000000oooo0?ooo`040?ooo`800?oo00<000000?ooo`3o
ool04@3oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o
503oool20000oa@0oooo0P00o`0D0?ooo`80o`003P3oool00`000000oooo0?ooo`030?ooo`800?oo
503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503o
ool20000oa@0oooo0P00o`0D0?ooo`80o`003`3oool00`000000oooo0?ooo`020?ooo`800?oo503o
ool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool2
0000oa@0oooo0P00o`0D0?ooo`80o`002`3oool01@000000oooo0?ooo`3oool0000000@0oooo0P00
oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD
0?ooo`80003o503oool2003o01@0oooo0P3o000<0?ooo`<000001@3oool2003ooa@0oooo0P3o000D
0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?oo
o`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?oo
o`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`80
0?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o
503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0
503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503o
ool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3o
ool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool2
0?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000
oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000
oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0
oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo
0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo
0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00
o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o
0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD
0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?oo
o`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?oo
o`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80
o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`00
4@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00
503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503o
ool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503o
ool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2
003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0
oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o
01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0
oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0
oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo
0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P00
0?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P00
0?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D
0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?oo
o`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?oo
o`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`80
0?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80
o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo
503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503o
ool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503o
ool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool2
0?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool0
0140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l0
01@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0
oooo0P00o`0D0?ooo`80o`003P3oool00`000000oooo0?ooo`030?ooo`800?oo503oool20?l001@0
oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo
0P00o`0D0?ooo`80o`003P3oool00`000000oooo0?ooo`030?ooo`800?oo503oool20?l001@0oooo
0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00
o`0D0?ooo`80o`001@3oool4000000D0oooo00<000000?ooo`3oool00`3oool2003oo`030000003o
ool0oooo0140oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool2
0?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l000h0oooo00<000000?ooo`3oool00`3oool2
003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0
oa@0oooo0P000?lD0?ooo`800?l0503oool20?l000`0oooo00<000000?ooo`0000001@3oool2003o
oa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0
oooo0P000?lD0?ooo`800?l0503oool20?l000d0oooo0P0000050?ooo`800?oo503oool20?l001@0
oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo
0P00o`0D0?ooo`80o`003P3oool00`000000oooo0?ooo`030?ooo`800?oo503oool20?l001@0oooo
0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00
o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o
0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD
0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?oo
o`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?oo
o`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80
o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`00
4@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00
503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503o
ool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503o
ool20?l0oaT0oooo000=0?ooo`040000003oool0oooo0?ooo`80o`3o503oool20000oa@0oooo0P00
o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o
0?l60?ooo`030000003oool0oooo0100oooo000=0?ooo`040000003oool0oooo0?ooo`80o`3o503o
ool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503o
ool20000oa@0oooo0P3o0?l60?ooo`030000003oool0oooo0100oooo00090?ooo`H000000P3oool2
0?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2
003o01@0oooo0P000?lD0?ooo`80o`3o0P3oool600000140oooo00090?ooo`050000003oool0oooo
0?ooo`0000000`3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD
0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o0P3oool01@000000oooo0?ooo`3o
ool000000180oooo000:0?ooo`040000003oool0oooo000000<0oooo0P3o0?lD0?ooo`80003o503o
ool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503o
ool20?l0o`<0oooo00@000000?ooo`3oool000004P3oool000/0oooo00<000000?ooo`0000000`3o
ool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503o
ool2003o01@0oooo0P000?lD0?ooo`80o`3o103oool00`000000oooo0000000B0?ooo`00303oool2
000000<0oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool2
0?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0o`D0oooo0P00000B0?ooo`004@3oool20?l0
oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o
01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0
oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0
oooo00040?ooo`d000000P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo
503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0o`030?ooo`000000000000H00000
403oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503o
ool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool2
0000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool2
0000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l0
01@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140
oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0
oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000<0?ooo`030000003oool0oooo00800000
0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo
0P00o`0D0?ooo`80003o503oool20?l0o`80oooo00<000000?ooo`3oool00P00000B0?ooo`003@3o
ool010000000oooo0000003oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo
0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o0`3oool00`000000oooo
0000000C0?ooo`001P3oool4000000<0oooo00@000000?ooo`000000oooo0P3o0?lD0?ooo`80003o
503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o
503oool20?l0o`<0oooo00<000000?ooo`0000004`3oool000`0oooo00D000000?ooo`000000oooo
000000020?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00
503oool2003o01@0oooo0P000?lD0?ooo`80o`3o0P3oool01@000000oooo0000003oool000000180
oooo000=0?ooo`@000000P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo
503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0o`<0oooo1@00000A0?ooo`004@3o
ool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503o
ool2003o01@0oooo0P000?lD0?ooo`80o`3o3`3oool01@000000oooo0?ooo`3oool0000000D0oooo
000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o
000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?l@0?ooo`030000003oool0000000H0oooo0009
0?ooo`P000000P3o0?lD00000080003o50000002003o01@000000P3o000D000000800?oo50000002
0?l001@000000P00o`0D00000080003o500000020?l0o`T00000203oool00`000000oooo0?ooo`05
0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?oo
o`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o403oool00`000000oooo000000060?oo
o`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80
o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o3`3oool01@000000oooo0?ooo`3oool00000
00D0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0
oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo
0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo
0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o
000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A
0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D
0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?oo
o`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?oo
o`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`80
0?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o
503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0
503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503o
ool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3o
ool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool2
0?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000
oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000
oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0
oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo
0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo
0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00
o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o
0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD
0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?oo
o`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?oo
o`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80
o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`00
4@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00
503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503o
ool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503o
ool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2
003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0
oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o
01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0
oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0
oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo
0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P00
0?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P00
0?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D
0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?oo
o`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?oo
o`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`80
0?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80
o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo
503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503o
ool20000oa@0oooo0P00o`0D0?ooo`80o`003P3oool00`000000oooo0?ooo`030?ooo`800?oo503o
ool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool2
0000oa@0oooo0P00o`0D0?ooo`80o`003P3oool00`000000oooo0?ooo`030?ooo`800?oo503oool2
0?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000
oa@0oooo0P00o`0D0?ooo`80o`003P3oool00`000000oooo0?ooo`030?ooo`800?oo503oool20?l0
01@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0
oooo0P00o`0D0?ooo`80o`003P3oool00`000000oooo0?ooo`030?ooo`800?oo00<000000?ooo`3o
ool04@3oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o
503oool20000oa@0oooo0P00o`0D0?ooo`80o`00303oool00`000000oooo000000050?ooo`800?oo
503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503o
ool20000oa@0oooo0P00o`0D0?ooo`80o`003@3oool2000000D0oooo0P00oolD0?ooo`80o`00503o
ool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2
003o01@0oooo0P3o000>0?ooo`030000003oool0oooo00<0oooo0P00oolD0?ooo`80o`00503oool2
003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o
01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0
oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0
oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo
0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo
0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o
000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A
0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D
0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?oo
o`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?oo
o`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`80
0?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o
503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0
503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503o
ool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3o
ool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool2
0?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000
oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000
oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0
oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo
0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo
0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00
o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o
0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD
0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?oo
o`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?oo
o`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80
o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`00
4@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00
503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503o
ool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503o
ool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2
003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0
oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o
01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0
oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0
oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo
0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P00
0?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P00
0?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D
0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?oo
o`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?oo
o`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`80
0?l0503oool20?l000/0oooo1@0000040?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80
003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00
303oool00`000000oooo0?ooo`050?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o
503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`003@3o
ool00`000000oooo0?ooo`040?ooo`800?oo00<000000?ooo`3oool04@3oool20?l001@0oooo0P00
o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D
0?ooo`80o`003P3oool00`000000oooo0?ooo`030?ooo`800?oo503oool20?l001@0oooo0P00o`0D
0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?oo
o`80o`003`3oool00`000000oooo0?ooo`020?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?oo
o`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80
o`002`3oool01@000000oooo0?ooo`3oool0000000@0oooo0P00oolD0?ooo`80o`00503oool2003o
01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0
oooo0P3o000<0?ooo`<000001@3oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0
oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo
0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o
0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00
o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D
0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI
0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?oo
o`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80
003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80
003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00
503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3o
ool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503o
ool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2
003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool2
0?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003o
oa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0
oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0
oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo
0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo
000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o
000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD
0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD
0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?oo
o`800?oo503oool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80
o`3o503oool20000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`80
0?l0503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0
503oool20?l001@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o
6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503o
ool20?l001@0oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool2
0000oa@0oooo0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool2
0000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l0
01@0oooo0P00oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140
oooo0P3o0?lD0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0
oooo0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo
0P00o`0D0?ooo`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo
0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00
oolD0?ooo`80o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD
0?ooo`80003o503oool2003o01@0oooo0P3o000D0?ooo`800?oo503oool20?l001@0oooo0P00o`0D
0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D0?oo
o`80o`00503oool2003ooa@0oooo0P3o000D0?ooo`800?l0503oool20000oa@0oooo0P3o0?lI0?oo
o`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503oool20?l001@0oooo0P00oolD0?ooo`80
o`00503oool2003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o
503oool2003o01@0oooo0P3o000<0?ooo`<000001@3oool2003ooa@0oooo0P3o000D0?ooo`800?l0
503oool20000oa@0oooo0P3o0?lI0?ooo`004@3oool20?l0oa@0oooo0P000?lD0?ooo`800?l0503o
ool20?l000/0oooo00D000000?ooo`3oool0oooo000000040?ooo`800?oo503oool20?l001@0oooo
0P00o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00
o`0D0?ooo`80o`003`3oool00`000000oooo0?ooo`020?ooo`800?oo503oool20?l001@0oooo0P00
o`0D0?ooo`80003o503oool20?l0oaT0oooo000A0?ooo`80o`3o503oool20000oa@0oooo0P00o`0D
0?ooo`80o`003@3oool2000000D0oooo0P00ool00`000000oooo0?ooo`0A0?ooo`80o`00503oool2
003o01@0oooo0P000?lD0?ooo`80o`3o6@3oool00140oooo0P3o0?lD0?ooo`80003o503oool2003o
01@0oooo0P3o000?0?ooo`030000003oool0oooo0080oooo0P00oolD0?ooo`80o`00503oool2003o
01@0oooo0P000?lD0?ooo`80o`3o6@3oool00600oooo00D000000?ooo`3oool0oooo0000001g0?oo
o`00H@3oool3000007P0oooo003L0?ooo`00g03oool00=`0oooo001Y0?ooo`030000003oool0oooo
0700oooo001Z0?ooo`030000003oool0oooo06l0oooo001Z0?ooo`030000003oool0oooo06l0oooo
001Y0?ooo`030000003oool000000700oooo001Y0?ooo`030000003oool000000700oooo001Y0?oo
o`030000003oool000000700oooo001X0?ooo`050000003oool0oooo0?ooo`000000K`3oool00=`0
oooo003L0?ooo`00g03oool00=`0oooo0000\
\>"],
    ImageRangeCache->{{{0, 219}, {219, 0}} -> {0, -3, 0, 0}}],
  StyleBox["     ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 220 220 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[1.025 .5 0 -6.5 ]
[1.025 .5 9.5 6.5 ]
[.5 1.025 -4.4375 0 ]
[.5 1.025 4.4375 13 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 1 L
s
gsave
.5 1.025 -65.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
67.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 1 r
.015 w
.49764 .02382 m
.49701 .02382 L
.49616 .02383 L
.49505 .02384 L
.49347 .02385 L
.49164 .02388 L
.48912 .02393 L
.48577 .02402 L
.48166 .02416 L
.47642 .02439 L
.47026 .02474 L
.46237 .0253 L
.45126 .02631 L
.43786 .02788 L
.4194 .03068 L
.39534 .03545 L
.36627 .04297 L
.33057 .05497 L
.29043 .0724 L
.23766 .10259 L
.18398 .14378 L
.12661 .20447 L
.09603 .24788 L
.07078 .29377 L
.06027 .31725 L
.05022 .34363 L
.04266 .36734 L
.03577 .39395 L
.03229 .41052 L
.02959 .42605 L
.02751 .44075 L
.02659 .44861 L
.02574 .45711 L
.02511 .46478 L
.02464 .47182 L
.02429 .47856 L
.02403 .48567 L
.02386 .4932 L
.02381 .50021 L
.02388 .50791 L
.02397 .51221 L
.02408 .51612 L
.02438 .52326 L
.02475 .52994 L
.02595 .54508 L
.02757 .55975 L
.02981 .57538 L
.03513 .60321 L
.04134 .62801 L
.06121 .68499 L
Mistroke
.08521 .7339 L
.11125 .77501 L
.14104 .8129 L
.19598 .86651 L
.25627 .90909 L
.30553 .93467 L
.34641 .95074 L
.3771 .96006 L
.40247 .9661 L
.42452 .97017 L
.44085 .9725 L
.45449 .97401 L
.46516 .97491 L
.47295 .97542 L
.4785 .97571 L
.48331 .9759 L
.487 .97601 L
.49002 .97609 L
.49219 .97613 L
.49399 .97615 L
.49534 .97617 L
.49642 .97618 L
.49764 .97618 L
Mfstroke
0 0 1 r
.49782 .02472 m
.49646 .02529 L
.494 .02634 L
.49015 .02801 L
.48418 .03068 L
.47389 .03548 L
.458 .04346 L
.43122 .05853 L
.39172 .08489 L
.33828 .13012 L
.30602 .16443 L
.26851 .2139 L
.25157 .24109 L
.23417 .27366 L
.2192 .30728 L
.20696 .341 L
.19583 .38063 L
.19113 .40245 L
.18712 .42625 L
.18565 .4373 L
.18432 .44934 L
.18331 .46078 L
.18293 .46624 L
.18262 .47134 L
.18236 .47635 L
.18217 .48093 L
.18201 .48601 L
.18189 .49147 L
.18183 .4967 L
.18183 .5024 L
.18188 .50778 L
.18198 .51276 L
.18213 .51786 L
.18234 .52323 L
.18286 .53281 L
.18362 .54308 L
.18468 .55427 L
.18718 .57417 L
.19017 .59242 L
.19925 .63291 L
.21198 .67372 L
.22659 .71012 L
.24434 .74605 L
.27919 .80148 L
.3478 .87889 L
.39991 .92102 L
.43519 .94383 L
.45997 .95756 L
.47509 .96509 L
.48505 .96972 L
Mistroke
.49089 .97232 L
.49436 .97381 L
.49661 .97477 L
.49782 .97528 L
Mfstroke
0 1 0 r
.49834 .02548 m
.4973 .02653 L
.49543 .02843 L
.49252 .03141 L
.48803 .03609 L
.4804 .04425 L
.46882 .05718 L
.4499 .07984 L
.42325 .11559 L
.38942 .16953 L
.37012 .20642 L
.34866 .25562 L
.32989 .31076 L
.32254 .33797 L
.31557 .36925 L
.31234 .3868 L
.30972 .40343 L
.30741 .42093 L
.30571 .43702 L
.3044 .453 L
.30392 .46037 L
.30351 .46817 L
.30316 .47655 L
.30304 .48027 L
.30294 .48427 L
.30285 .48857 L
.3028 .49258 L
.30277 .49504 L
.30276 .49736 L
.30276 .50172 L
.30278 .50572 L
.30283 .51003 L
.3029 .5141 L
.30299 .51784 L
.30328 .52649 L
.3037 .53557 L
.30422 .54442 L
.30481 .55262 L
.30652 .5711 L
.31041 .60126 L
.31591 .63247 L
.32318 .66461 L
.33235 .69745 L
.3513 .75105 L
.39205 .8351 L
.42612 .8885 L
.45083 .92132 L
.46903 .94306 L
.48049 .95585 L
.4882 .96409 L
Mistroke
.49278 .96886 L
.49551 .97166 L
.4973 .97348 L
.49834 .97452 L
Mfstroke
1 0 0 r
.4991 .02599 m
.49854 .02735 L
.49753 .02981 L
.49597 .03366 L
.49357 .03964 L
.48952 .04993 L
.48346 .06589 L
.47373 .09297 L
.46042 .13369 L
.44413 .19149 L
.43513 .22907 L
.42537 .27732 L
.41702 .32944 L
.41381 .35459 L
.41078 .38313 L
.40939 .399 L
.40826 .41397 L
.40727 .42965 L
.40654 .44402 L
.40598 .45826 L
.40578 .46481 L
.4056 .47175 L
.40545 .47919 L
.4054 .48249 L
.40536 .48604 L
.40532 .48985 L
.4053 .49342 L
.40529 .49559 L
.40528 .49766 L
.40528 .50152 L
.40529 .50507 L
.40531 .5089 L
.40534 .51252 L
.40538 .51583 L
.4055 .52351 L
.40568 .53158 L
.40591 .53945 L
.40616 .54675 L
.40689 .56323 L
.40856 .59025 L
.41093 .61843 L
.41409 .64779 L
.41811 .67821 L
.42655 .72911 L
.44537 .81332 L
.46183 .87087 L
.47421 .90839 L
.48357 .9344 L
.48957 .9502 L
.49366 .96059 L
Mistroke
.49611 .96669 L
.49758 .9703 L
.49854 .97266 L
.4991 .97401 L
Mfstroke
0 1 1 r
.5 .02616 m
.5 .02764 L
.5 .0303 L
.5 .03444 L
.5 .04087 L
.5 .0519 L
.5 .06887 L
.5 .09739 L
.5 .13964 L
.5 .19853 L
.5 .28405 L
.5 .38733 L
.5 .49865 L
.5 .61707 L
.5 .71827 L
.5 .80386 L
.5 .86369 L
.5 .90337 L
.5 .93118 L
.5 .94818 L
.5 .9594 L
.5 .96599 L
.5 .96989 L
.5 .97242 L
.5 .97384 L
s
1 0 0 r
.5009 .02599 m
.50146 .02735 L
.50247 .02981 L
.50403 .03366 L
.50643 .03964 L
.51048 .04993 L
.51654 .06589 L
.52627 .09297 L
.53958 .13369 L
.55587 .19149 L
.56487 .22907 L
.57463 .27732 L
.58298 .32944 L
.58619 .35459 L
.58922 .38313 L
.59061 .399 L
.59174 .41397 L
.59273 .42965 L
.59346 .44402 L
.59402 .45826 L
.59422 .46481 L
.5944 .47175 L
.59455 .47919 L
.5946 .48249 L
.59464 .48604 L
.59468 .48985 L
.5947 .49342 L
.59471 .49559 L
.59472 .49766 L
.59472 .50152 L
.59471 .50507 L
.59469 .5089 L
.59466 .51252 L
.59462 .51583 L
.5945 .52351 L
.59432 .53158 L
.59409 .53945 L
.59384 .54675 L
.59311 .56323 L
.59144 .59025 L
.58907 .61843 L
.58591 .64779 L
.58189 .67821 L
.57345 .72911 L
.55463 .81332 L
.53817 .87087 L
.52579 .90839 L
.51643 .9344 L
.51043 .9502 L
.50634 .96059 L
Mistroke
.50389 .96669 L
.50242 .9703 L
.50146 .97266 L
.5009 .97401 L
Mfstroke
0 1 0 r
.50166 .02548 m
.5027 .02653 L
.50457 .02843 L
.50748 .03141 L
.51197 .03609 L
.5196 .04425 L
.53118 .05718 L
.5501 .07984 L
.57675 .11559 L
.61058 .16953 L
.62988 .20642 L
.65134 .25562 L
.67011 .31076 L
.67746 .33797 L
.68443 .36925 L
.68766 .3868 L
.69028 .40343 L
.69259 .42093 L
.69429 .43702 L
.6956 .453 L
.69608 .46037 L
.69649 .46817 L
.69684 .47655 L
.69696 .48027 L
.69706 .48427 L
.69715 .48857 L
.6972 .49258 L
.69723 .49504 L
.69724 .49736 L
.69724 .50172 L
.69722 .50572 L
.69717 .51003 L
.6971 .5141 L
.69701 .51784 L
.69672 .52649 L
.6963 .53557 L
.69578 .54442 L
.69519 .55262 L
.69348 .5711 L
.68959 .60126 L
.68409 .63247 L
.67682 .66461 L
.66765 .69745 L
.6487 .75105 L
.60795 .8351 L
.57388 .8885 L
.54917 .92132 L
.53097 .94306 L
.51951 .95585 L
.5118 .96409 L
Mistroke
.50722 .96886 L
.50449 .97166 L
.5027 .97348 L
.50166 .97452 L
Mfstroke
0 0 1 r
.50218 .02472 m
.50354 .02529 L
.506 .02634 L
.50985 .02801 L
.51582 .03068 L
.52611 .03548 L
.542 .04346 L
.56878 .05853 L
.60828 .08489 L
.66172 .13012 L
.69398 .16443 L
.73149 .2139 L
.74843 .24109 L
.76583 .27366 L
.7808 .30728 L
.79304 .341 L
.80417 .38063 L
.80887 .40245 L
.81288 .42625 L
.81435 .4373 L
.81568 .44934 L
.81669 .46078 L
.81707 .46624 L
.81738 .47134 L
.81764 .47635 L
.81783 .48093 L
.81799 .48601 L
.81811 .49147 L
.81817 .4967 L
.81817 .5024 L
.81812 .50778 L
.81802 .51276 L
.81787 .51786 L
.81766 .52323 L
.81714 .53281 L
.81638 .54308 L
.81532 .55427 L
.81282 .57417 L
.80983 .59242 L
.80075 .63291 L
.78802 .67372 L
.77341 .71012 L
.75566 .74605 L
.72081 .80148 L
.6522 .87889 L
.60009 .92102 L
.56481 .94383 L
.54003 .95756 L
.52491 .96509 L
.51495 .96972 L
Mistroke
.50911 .97232 L
.50564 .97381 L
.50339 .97477 L
.50218 .97528 L
Mfstroke
1 0 1 r
.50236 .02382 m
.50299 .02382 L
.50384 .02383 L
.50495 .02384 L
.50653 .02385 L
.50836 .02388 L
.51088 .02393 L
.51423 .02402 L
.51834 .02416 L
.52358 .02439 L
.52974 .02474 L
.53763 .0253 L
.54874 .02631 L
.56214 .02788 L
.5806 .03068 L
.60466 .03545 L
.63373 .04297 L
.66943 .05497 L
.70957 .0724 L
.76234 .10259 L
.81602 .14378 L
.87339 .20447 L
.90397 .24788 L
.92922 .29377 L
.93973 .31725 L
.94978 .34363 L
.95734 .36734 L
.96423 .39395 L
.96771 .41052 L
.97041 .42605 L
.97249 .44075 L
.97341 .44861 L
.97426 .45711 L
.97489 .46478 L
.97536 .47182 L
.97571 .47856 L
.97597 .48567 L
.97614 .4932 L
.97619 .50021 L
.97612 .50791 L
.97603 .51221 L
.97592 .51612 L
.97562 .52326 L
.97525 .52994 L
.97405 .54508 L
.97243 .55975 L
.97019 .57538 L
.96487 .60321 L
.95866 .62801 L
.93879 .68499 L
Mistroke
.91479 .7339 L
.88875 .77501 L
.85896 .8129 L
.80402 .86651 L
.74373 .90909 L
.69447 .93467 L
.65359 .95074 L
.6229 .96006 L
.59753 .9661 L
.57548 .97017 L
.55915 .9725 L
.54551 .97401 L
.53484 .97491 L
.52705 .97542 L
.5215 .97571 L
.51669 .9759 L
.513 .97601 L
.50998 .97609 L
.50781 .97613 L
.50601 .97615 L
.50466 .97617 L
.50358 .97618 L
.50236 .97618 L
Mfstroke
0 g
gsave
1.00952 .44286 -65.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
-0.01905 .44286 -68.9375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.375 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
74.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45714 1.00952 -65.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
68.500 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45238 -0.02381 -68.9375 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.375 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
74.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{220, 220},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003L0000g2000`400?l00000o`00003oIP3oool0
0`000000oooo0?ooo`1c0?ooo`00IP3oool00`000000oooo0?ooo`1c0?ooo`00IP3oool00`000000
oooo0?ooo`1c0?ooo`00IP3oool00`000000oooo0?ooo`1c0?ooo`00G`3oool50?l0o`030000o`3o
0?l0o`3o00H0o`3oK`3oool005L0oooo303o0?l00`000?l0o`000?l0o`0>0?l0ofP0oooo001D0?oo
o`d0o`3o0P000?l00`00o`00o`000?l0o`0C0?l0of<0oooo001>0?oooa00o`3o10000?l00`00o`00
o`000?l000070000oa80o`3oGP3oool004X0oooo3P3o0?l40?ooo`D0003o0P00o`020?l00003003o
o`00o`000?l000P0003o103oool?0?l0oeT0oooo00170?ooo`d0o`3o1P3oool60000o`<00?l00P3o
00000`00ool0o`00003o0002003o00P0003o1`3oool<0?l0oeL0oooo00150?ooo`T0o`3o2`3oool6
0000o`@00?l00P3o00001000ool0o`000?l0003o0003003o00P0003o2P3oool:0?l0oe@0oooo0013
0?ooo`P0o`3o303oool60000o`030?ooo`00o`000?l000800?l000<0oooo0?l0003o00000P00ool3
0?l000@00?l000<0oooo0000o`000?l01@000?l<0?ooo`P0o`3oDP3oool00400oooo203o0?l>0?oo
o`D0003o0`3oool3003o00040?ooo`3o0000o`000?l000800?oo0`3o0000103oool00?l0003o0000
o`030?ooo`H0003o3@3oool90?l0odl0oooo000m0?ooo`T0o`3o3`3oool50000o`<0oooo1000o`04
0?l000800?oo103o0004003o00@0oooo1@000?l?0?ooo`T0o`3oC03oool003/0oooo2@3o0?l?0?oo
o`D0003o103oool4003o00050?ooo`3o0000o`000?l0003oool00`00ool30?l000030?ooo`00o`00
0?l000800?l01@3oool50000o`l0oooo2@3o0?m:0?ooo`00>@3oool80?l0oa40oooo1@000?l50?oo
o`<00?l000<0oooo0?l0003o00000P3o0000103oool00?oo003oo`00ool40?l000030?ooo`00o`00
0?l000800?l01@3oool50000oa40oooo1`3o0?m90?ooo`00=`3oool70?l0oa<0oooo1@000?l50?oo
o`@00?l000@0oooo0?l0003o0000o`000P3oool3003oo`040?ooo`3o0000o`000?l00080oooo0`00
o`060?ooo`D0003o4`3oool60?l0odL0oooo000f0?ooo`H0o`3o4`3oool50000o`L0oooo0`00o`02
0?ooo`<0o`000P3oool3003oo`040?ooo`3o0000o`000?l000<0oooo0`00o`070?ooo`@0003o503o
ool60?l0odD0oooo000d0?ooo`H0o`3o503oool50000o`L0oooo0`00o`020?ooo`@0o`000P3oool3
003oo`030?ooo`3o0000o`000080o`000P3oool4003o00L0oooo1@000?lC0?ooo`H0o`3oA03oool0
0380oooo1P3o0?lE0?ooo`D0003o1`3oool4003o0080oooo0`3o00030?ooo`<00?oo0P3oool30?l0
00<0oooo1000o`070?ooo`D0003o503oool60?l0od80oooo000`0?ooo`L0o`3o5@3oool40000o`P0
oooo1000o`030?ooo`<0o`000`3oool3003oo`80oooo103o00030?ooo`<00?l02@3oool40000oaD0
oooo1P3o0?m00?ooo`00;`3oool60?l0oaH0oooo10000?l80?ooo`@00?l00`3oool40?l000<0oooo
0`00ool30?ooo`<0o`000`3oool4003o00T0oooo10000?lE0?ooo`H0o`3o?`3oool002h0oooo1@3o
0?lF0?ooo`D0003o203oool4003o00@0oooo0`3o00040?ooo`<00?oo0`3oool30?l000@0oooo1000
o`090?ooo`@0003o5P3oool50?l0och0oooo000/0?ooo`D0o`3o5`3oool50000o`P0oooo1000o`05
0?ooo`<0o`00103oool3003oo`<0oooo103o00040?ooo`@00?l02@3oool40000oaL0oooo1@3o0?ll
0?ooo`00:`3oool50?l0oaL0oooo10000?l:0?ooo`<00?l01P3oool30?l000@0oooo0`00ool40?oo
o`<0o`001@3oool3003o00X0oooo10000?lG0?ooo`D0o`3o>`3oool002T0oooo1P3o0?lG0?ooo`@0
003o2P3oool4003o00D0oooo103o00040?ooo`<00?oo103oool30?l000D0oooo1000o`0:0?ooo`@0
003o5`3oool60?l0ocT0oooo000X0?ooo`D0o`3o5`3oool50000o`/0oooo0`00o`060?ooo`<0o`00
1@3oool3003oo`@0oooo103o00050?ooo`@00?l02P3oool40000oaP0oooo1@3o0?lh0?ooo`009`3o
ool50?l0oaP0oooo10000?l;0?ooo`@00?l01P3oool30?l000D0oooo0`00ool50?ooo`<0o`001P3o
ool3003o00/0oooo10000?lH0?ooo`D0o`3o=`3oool002D0oooo1@3o0?lI0?ooo`<0003o3@3oool3
003o00L0oooo0`3o00050?ooo`<00?oo1@3oool30?l000H0oooo1000o`0;0?ooo`@0003o6@3oool4
0?l0ocH0oooo000U0?ooo`@0o`3o6@3oool40000o``0oooo1000o`060?ooo`@0o`001@3oool3003o
o`D0oooo103o00060?ooo`<00?l0303oool40000oaT0oooo103o0?le0?ooo`00903oool40?l0oaT0
oooo10000?l<0?ooo`@00?l01`3oool30?l000H0oooo0`00ool60?ooo`<0o`001P3oool4003o00`0
oooo10000?lI0?ooo`@0o`3o=03oool002<0oooo103o0?lI0?ooo`@0003o3@3oool3003o00P0oooo
0`3o00060?ooo`<00?oo1P3oool30?l000L0oooo1000o`0<0?ooo`@0003o6@3oool40?l0oc<0oooo
000R0?ooo`@0o`3o6@3oool40000o`d0oooo1000o`080?ooo`<0o`001P3oool3003oo`H0oooo0`3o
00080?ooo`<00?l03@3oool40000oaT0oooo103o0?lb0?ooo`008@3oool40?l0oaT0oooo10000?l>
0?ooo`<00?l0203oool40?l000H0oooo0`00ool60?ooo`@0o`001`3oool4003o00d0oooo10000?lI
0?ooo`@0o`3o<@3oool00200oooo103o0?lJ0?ooo`<0003o3P3oool4003o00P0oooo0`3o00070?oo
o`<00?oo1`3oool30?l000P0oooo1000o`0=0?ooo`@0003o6@3oool40?l0oc00oooo000P0?ooo`<0
o`3o6P3oool30000o`l0oooo0`00o`090?ooo`<0o`001`3oool3003oo`L0oooo0`3o00090?ooo`<0
0?l03P3oool40000oaT0oooo103o0?l_0?ooo`007`3oool30?l0oaX0oooo10000?l>0?ooo`@00?l0
2@3oool30?l000L0oooo0`00ool70?ooo`<0o`002@3oool4003o00h0oooo10000?lI0?ooo`@0o`3o
;P3oool001h0oooo103o0?lI0?ooo`@0003o3`3oool3003o00T0oooo103o00070?ooo`<00?oo1`3o
ool40?l000T0oooo0`00o`0?0?ooo`@0003o6@3oool40?l0obd0oooo000M0?ooo`@0o`3o6@3oool4
0000o`l0oooo1000o`090?ooo`<0o`00203oool3003oo`P0oooo0`3o00090?ooo`@00?l03`3oool3
0000oaX0oooo103o0?l/0?ooo`00703oool40?l0oaT0oooo10000?l?0?ooo`@00?l02P3oool30?l0
00P0oooo0`00ool80?ooo`<0o`002P3oool4003o00l0oooo0`000?lJ0?ooo`@0o`3o:`3oool001/0
oooo103o0?lI0?ooo`@0003o403oool3003o00/0oooo0`3o00080?ooo`<00?oo203oool30?l000/0
oooo0`00o`0?0?ooo`@0003o6P3oool40?l0obX0oooo000J0?ooo`@0o`3o6@3oool40000oa00oooo
1000o`0:0?ooo`@0o`00203oool3003oo`P0oooo103o000:0?ooo`@00?l03`3oool40000oaX0oooo
0`3o0?lZ0?ooo`006P3oool30?l0oaT0oooo10000?lA0?ooo`<00?l02`3oool30?l000T0oooo0`00
ool90?ooo`<0o`002`3oool3003o0100oooo0`000?lK0?ooo`<0o`3o:@3oool001T0oooo0`3o0?lJ
0?ooo`<0003o4@3oool4003o00/0oooo0`3o00090?ooo`<00?oo2@3oool30?l000/0oooo1000o`0@
0?ooo`<0003o6P3oool40?l0obP0oooo000H0?ooo`@0o`3o6@3oool40000oa40oooo0`00o`0<0?oo
o`<0o`002@3oool3003oo`T0oooo0`3o000<0?ooo`<00?l0403oool40000oaX0oooo103o0?lW0?oo
o`005`3oool40?l0oaX0oooo0`000?lA0?ooo`@00?l02`3oool40?l000T0oooo0`00ool90?ooo`@0
o`002`3oool3003o0140oooo10000?lJ0?ooo`<0o`3o9`3oool001L0oooo0`3o0?lJ0?ooo`@0003o
4@3oool3003o00`0oooo0`3o000:0?ooo`<00?oo2P3oool30?l000/0oooo1000o`0A0?ooo`<0003o
6`3oool30?l0obH0oooo000F0?ooo`<0o`3o6`3oool30000oa40oooo1000o`0<0?ooo`<0o`002P3o
ool3003oo`X0oooo0`3o000<0?ooo`<00?l04@3oool40000oaX0oooo103o0?lU0?ooo`005@3oool4
0?l0oaX0oooo10000?lA0?ooo`<00?l03@3oool30?l000X0oooo0`00ool:0?ooo`<0o`00303oool4
003o0140oooo10000?lJ0?ooo`@0o`3o903oool001@0oooo103o0?lK0?ooo`<0003o4@3oool4003o
00`0oooo103o000:0?ooo`<00?oo2P3oool40?l000`0oooo0`00o`0B0?ooo`<0003o6`3oool30?l0
ob@0oooo000D0?ooo`<0o`3o6`3oool40000oa40oooo0`00o`0=0?ooo`<0o`002`3oool3003oo`/0
oooo0`3o000<0?ooo`<00?l04P3oool40000oa/0oooo0`3o0?lS0?ooo`004`3oool40?l0oaX0oooo
10000?lA0?ooo`@00?l03@3oool30?l000/0oooo0`00ool;0?ooo`<0o`00303oool4003o0180oooo
0`000?lK0?ooo`@0o`3o8P3oool00180oooo103o0?lK0?ooo`<0003o4P3oool3003o00h0oooo0`3o
000;0?ooo`<00?oo2`3oool30?l000d0oooo0`00o`0B0?ooo`@0003o6`3oool30?l0ob80oooo000B
0?ooo`<0o`3o6`3oool40000oa80oooo0`00o`0>0?ooo`<0o`002`3oool3003oo`/0oooo0`3o000=
0?ooo`@00?l04P3oool30000oa/0oooo103o0?lQ0?ooo`004@3oool40?l0oaX0oooo10000?lB0?oo
o`@00?l03@3oool40?l000/0oooo0`00ool;0?ooo`@0o`003@3oool3003o0180oooo10000?lK0?oo
o`<0o`3o8@3oool00140oooo0`3o0?lK0?ooo`<0003o4`3oool3003o00h0oooo0`3o000<0?ooo`<0
0?oo303oool30?l000d0oooo0`00o`0C0?ooo`<0003o6`3oool40?l0ob00oooo000@0?ooo`@0o`3o
6P3oool40000oa<0oooo0`00o`0>0?ooo`<0o`00303oool3003oo``0oooo0`3o000=0?ooo`@00?l0
4P3oool40000oa/0oooo0`3o0?lP0?ooo`003`3oool40?l0oa/0oooo0`000?lC0?ooo`@00?l03P3o
ool30?l000`0oooo0`00ool<0?ooo`<0o`003P3oool3003o01<0oooo0`000?lK0?ooo`@0o`3o7`3o
ool000l0oooo0`3o0?lK0?ooo`@0003o4`3oool3003o00l0oooo0`3o000<0?ooo`<00?oo303oool3
0?l000h0oooo0`00o`0C0?ooo`<0003o703oool30?l0oal0oooo000>0?ooo`@0o`3o6`3oool30000
oa@0oooo0`00o`0>0?ooo`<0o`003@3oool3003oo``0oooo0`3o000>0?ooo`@00?l04P3oool40000
oa/0oooo103o0?lN0?ooo`003P3oool30?l0oa`0oooo0`000?lD0?ooo`<00?l03P3oool30?l000d0
oooo0`00ool<0?ooo`<0o`003`3oool3003o01<0oooo0`000?lL0?ooo`<0o`3o7P3oool000d0oooo
103o0?lK0?ooo`@0003o4`3oool4003o00h0oooo0`3o000=0?ooo`<00?oo303oool30?l000l0oooo
0`00o`0C0?ooo`@0003o6`3oool40?l0oad0oooo000=0?ooo`<0o`3o703oool30000oa@0oooo0`00
o`0?0?ooo`<0o`003@3oool3003oo`d0oooo0`3o000>0?ooo`@00?l04`3oool30000oa`0oooo0`3o
0?lM0?ooo`00303oool40?l0oa`0oooo0`000?lD0?ooo`<00?l03`3oool30?l000d0oooo0`00ool=
0?ooo`<0o`003`3oool3003o01<0oooo10000?lK0?ooo`@0o`3o703oool000`0oooo0`3o0?lL0?oo
o`@0003o4`3oool4003o00l0oooo0`3o000=0?ooo`<00?oo3@3oool30?l000l0oooo0`00o`0D0?oo
o`<0003o703oool30?l0oa`0oooo000;0?ooo`@0o`3o703oool30000oa@0oooo0`00o`0?0?ooo`<0
o`003P3oool3003oo`d0oooo0`3o000?0?ooo`<00?l0503oool30000oa`0oooo0`3o0?lL0?ooo`00
2`3oool30?l0oad0oooo0`000?lD0?ooo`<00?l03`3oool30?l000h0oooo0`00ool=0?ooo`<0o`00
403oool3003o01<0oooo10000?lK0?ooo`@0o`3o6`3oool000/0oooo0`3o0?lL0?ooo`@0003o4`3o
ool4003o00l0oooo0`3o000>0?ooo`<00?oo3@3oool30?l00100oooo0`00o`0D0?ooo`<0003o703o
ool30?l0oa/0oooo000:0?ooo`@0o`3o703oool30000oa@0oooo0`00o`0@0?ooo`<0o`003P3oool3
003oo`d0oooo0`3o000@0?ooo`<00?l0503oool40000oa/0oooo0`3o0?lK0?ooo`002P3oool30?l0
oad0oooo0`000?lD0?ooo`<00?l0403oool30?l000h0oooo0`00ool=0?ooo`<0o`00403oool3003o
01D0oooo0`000?lK0?ooo`@0o`3o6P3oool000X0oooo0`3o0?lM0?ooo`<0003o503oool3003o00l0
oooo0`3o000?0?ooo`<00?oo3P3oool30?l000l0oooo1000o`0D0?ooo`<0003o703oool30?l0oaX0
oooo000:0?ooo`<0o`3o703oool40000oa@0oooo0`00o`0?0?ooo`<0o`003`3oool3003oo`h0oooo
0`3o000@0?ooo`<00?l0503oool40000oa/0oooo103o0?lI0?ooo`002@3oool40?l0oa`0oooo0`00
0?lD0?ooo`<00?l0403oool30?l000l0oooo0`00ool>0?ooo`<0o`00403oool3003o01D0oooo0`00
0?lL0?ooo`<0o`3o6@3oool000T0oooo0`3o0?lM0?ooo`<0003o503oool3003o0100oooo0`3o000?
0?ooo`<00?oo3P3oool30?l00100oooo1000o`0D0?ooo`<0003o703oool40?l0oaP0oooo00090?oo
o`<0o`3o7@3oool30000oa@0oooo0`00o`0@0?ooo`<0o`003`3oool3003oo`h0oooo0`3o000A0?oo
o`<00?l0503oool30000oad0oooo0`3o0?lH0?ooo`00203oool40?l0oa`0oooo10000?lD0?ooo`<0
0?l0403oool30?l000l0oooo0`00ool?0?ooo`<0o`00403oool3003o01@0oooo10000?lL0?ooo`<0
o`3o603oool000P0oooo0`3o0?lM0?ooo`<0003o503oool4003o0100oooo0`3o000?0?ooo`<00?oo
3`3oool30?l00100oooo0`00o`0E0?ooo`<0003o703oool30?l0oaP0oooo00080?ooo`<0o`3o7@3o
ool30000oa@0oooo0`00o`0A0?ooo`<0o`003`3oool3003oo`l0oooo0`3o000@0?ooo`<00?l05@3o
ool30000oa`0oooo0`3o0?lH0?ooo`001`3oool40?l0oad0oooo0`000?lD0?ooo`<00?l04@3oool3
0?l000l0oooo0`00ool?0?ooo`<0o`00403oool3003o01D0oooo0`000?lM0?ooo`<0o`3o5`3oool0
00L0oooo0`3o0?lM0?ooo`@0003o503oool3003o0140oooo0`3o000?0?ooo`<00?oo3`3oool30?l0
0100oooo0`00o`0E0?ooo`@0003o703oool30?l0oaL0oooo00070?ooo`<0o`3o7@3oool30000oa@0
oooo1000o`0A0?ooo`<0o`003`3oool3003oo`l0oooo0`3o000@0?ooo`@00?l05@3oool30000oa`0
oooo0`3o0?lG0?ooo`001`3oool30?l0oad0oooo0`000?lD0?ooo`<00?l04P3oool30?l000l0oooo
0`00ool?0?ooo`<0o`004@3oool3003o01D0oooo0`000?lL0?ooo`<0o`3o5`3oool000L0oooo0`3o
0?lM0?ooo`<0003o503oool3003o0140oooo103o000?0?ooo`<00?oo3`3oool30?l00140oooo0`00
o`0E0?ooo`<0003o703oool40?l0oaH0oooo00070?ooo`<0o`3o7@3oool30000oa@0oooo0`00o`0A
0?ooo`<0o`00403oool3003oo`l0oooo0`3o000A0?ooo`<00?l05@3oool30000oad0oooo0`3o0?lF
0?ooo`001P3oool40?l0oa`0oooo0`000?lE0?ooo`<00?l04@3oool30?l00100oooo0`00ool?0?oo
o`<0o`004@3oool3003o01H0oooo0`000?lL0?ooo`<0o`3o5P3oool000H0oooo0`3o0?lM0?ooo`<0
003o5@3oool3003o0140oooo0`3o000@0?ooo`<00?oo3`3oool30?l00140oooo0`00o`0F0?ooo`<0
003o703oool30?l0oaH0oooo00060?ooo`<0o`3o7@3oool30000oaD0oooo0`00o`0A0?ooo`<0o`00
403oool3003oo`l0oooo0`3o000A0?ooo`<00?l05P3oool30000oa`0oooo0`3o0?lF0?ooo`0000<0
oooo0000003oool00`3oool30?l0oad0oooo0`000?lE0?ooo`<00?l04@3oool30?l00100oooo0`00
ool?0?ooo`<0o`004@3oool4003o01D0oooo0`000?lL0?ooo`<0o`3o1P3oool00`000000oooo0?oo
o`0=0?ooo`0000<0oooo0000003oool00`3oool30?l0oad0oooo0`000?lE0?ooo`<00?l04@3oool3
0?l00100oooo0`00ool?0?ooo`<0o`004P3oool3003o01D0oooo0`000?lL0?ooo`@0o`3o1@3oool0
0`000000oooo0?ooo`0=0?ooo`0000<0oooo0000003oool00`3oool30?l0oa`0oooo10000?lE0?oo
o`<00?l04@3oool30?l00100oooo0`00ool?0?ooo`@0o`004@3oool3003o01D0oooo0`000?lM0?oo
o`<0o`3o1@3oool00`000000oooo0?ooo`0=0?ooo`0000<0oooo0000003oool00`3oool30?l0oa`0
oooo0`000?lE0?ooo`@00?l04@3oool30?l00100oooo0`00ool@0?ooo`<0o`004@3oool3003o01D0
oooo0`000?lM0?ooo`<0o`3o1@3oool00`000000oooo0?ooo`0=0?ooo`0000<0oooo0000003oool0
0P3oool40?l0oa`0oooo0`000?lE0?ooo`<00?l04P3oool30?l00100oooo0`00ool@0?ooo`<0o`00
4@3oool3003o01D0oooo0`000?lM0?ooo`<0o`3o0`3oool00`000000oooo0000000?0?ooo`000P00
00030?ooo`<0o`3o7@3oool30000oaD0oooo0`00o`0B0?ooo`<0o`00403oool3003ooa00oooo0`3o
000A0?ooo`<00?l05@3oool30000oad0oooo0`3o0?l40?ooo`8000003`3oool000030?ooo`000000
oooo0080oooo0`3o0?lM0?ooo`<0003o5@3oool3003o0180oooo0`3o000@0?ooo`<00?oo403oool3
0?l00140oooo0`00o`0E0?ooo`<0003o7@3oool30?l0o`D0oooo00<000000?ooo`3oool03@3oool0
00D0oooo0`3o0?lM0?ooo`<0003o5@3oool3003o0180oooo0`3o000@0?ooo`<00?oo403oool30?l0
0140oooo0`00o`0E0?ooo`<0003o7@3oool30?l0oaD0oooo00050?ooo`<0o`3o7@3oool30000oaD0
oooo0`00o`0B0?ooo`<0o`00403oool3003ooa00oooo0`3o000A0?ooo`<00?l05@3oool40000oa`0
oooo0`3o0?lE0?ooo`001@3oool30?l0oad0oooo0`000?lE0?ooo`<00?l04P3oool30?l00100oooo
0`00ool@0?ooo`<0o`004@3oool3003o01H0oooo0`000?lL0?ooo`<0o`3o5@3oool000D0oooo0`3o
0?lM0?ooo`<0003o5@3oool3003o0180oooo0`3o000@0?ooo`<00?oo403oool30?l00140oooo0`00
o`0F0?ooo`<0003o703oool30?l0oaD0oooo00050?ooo`<0o`3o7@3oool30000oaD0oooo0`00o`0B
0?ooo`<0o`00403oool3003ooa00oooo0`3o000A0?ooo`<00?l05P3oool30000oa`0oooo0`3o0?lE
0?ooo`001@3oool30?l0oad0oooo0`000?lE0?ooo`<00?l04P3oool30?l00100oooo0`00ool@0?oo
o`<0o`004@3oool3003o01H0oooo0`000?lL0?ooo`<0o`3o303oool3000000H0oooo00050?ooo`<0
o`3o7@3oool30000oaD0oooo0`00o`0B0?ooo`<0o`00403oool3003ooa00oooo0`3o000A0?ooo`<0
0?l05P3oool30000oa`0oooo0`3o0?l;0?ooo`040000003oool0oooo000000H0oooo00000`3oool0
000000000002000000<0o`3o7@0000030000oaD000000`00o`0B000000<0o`0040000003003ooa00
00000`3o000A000000<00?l05P0000030000oa`000000`3o0?l4000000L0oooo00@000000?ooo`3o
ool000001P3oool000D0oooo0`3o0?lM0?ooo`<0003o5@3oool3003o0180oooo0`3o000@0?ooo`<0
0?oo403oool30?l00140oooo0`00o`0F0?ooo`<0003o703oool30?l0o`/0oooo00@000000?ooo`3o
ool000001P3oool000D0oooo0`3o0?lM0?ooo`<0003o5@3oool3003o0180oooo0`3o000@0?ooo`<0
0?oo403oool30?l00140oooo0`00o`0F0?ooo`<0003o703oool30?l0o`/0oooo00@000000?ooo`3o
ool000001P3oool000D0oooo0`3o0?lM0?ooo`<0003o5@3oool3003o0180oooo0`3o000@0?ooo`<0
0?oo403oool30?l00140oooo0`00o`0F0?ooo`<0003o703oool30?l0oaD0oooo00050?ooo`<0o`3o
7@3oool30000oaD0oooo0`00o`0B0?ooo`<0o`00403oool3003ooa00oooo0`3o000A0?ooo`<00?l0
5P3oool30000oa`0oooo0`3o0?lE0?ooo`001@3oool30?l0oad0oooo0`000?lE0?ooo`<00?l04P3o
ool30?l00100oooo0`00ool@0?ooo`<0o`004@3oool3003o01H0oooo0`000?lL0?ooo`<0o`3o5@3o
ool000D0oooo0`3o0?lM0?ooo`<0003o5@3oool3003o0180oooo0`3o000@0?ooo`<00?oo403oool3
0?l00140oooo0`00o`0E0?ooo`@0003o703oool30?l0oaD0oooo00050?ooo`<0o`3o7@3oool30000
oaD0oooo0`00o`0B0?ooo`<0o`00403oool3003ooa00oooo0`3o000A0?ooo`<00?l05@3oool30000
oad0oooo0`3o0?lE0?ooo`001@3oool30?l0oad0oooo0`000?lE0?ooo`<00?l04P3oool30?l00100
oooo0`00ool@0?ooo`<0o`004@3oool3003o01D0oooo0`000?lM0?ooo`<0o`3o5@3oool000D0oooo
0`3o0?lM0?ooo`<0003o5@3oool3003o0180oooo0`3o000@0?ooo`<00?oo403oool30?l00140oooo
0`00o`0E0?ooo`<0003o7@3oool30?l0oaD0oooo00050?ooo`<0o`3o7@3oool30000oaD0oooo1000
o`0A0?ooo`<0o`00403oool3003ooa00oooo0`3o000A0?ooo`<00?l05@3oool30000oad0oooo0`3o
0?lE0?ooo`001@3oool40?l0oa`0oooo0`000?lF0?ooo`<00?l04@3oool30?l00100oooo0`00ool?
0?ooo`@0o`004@3oool3003o01D0oooo0`000?lM0?ooo`<0o`3o5@3oool000H0oooo0`3o0?lL0?oo
o`<0003o5P3oool3003o0140oooo0`3o000@0?ooo`<00?oo3`3oool30?l00180oooo0`00o`0E0?oo
o`<0003o7@3oool30?l0oaD0oooo00060?ooo`<0o`3o703oool40000oaD0oooo0`00o`0A0?ooo`<0
o`00403oool3003oo`l0oooo0`3o000B0?ooo`<00?l05@3oool30000oa`0oooo103o0?lE0?ooo`00
1P3oool30?l0oad0oooo0`000?lE0?ooo`<00?l04@3oool30?l00100oooo0`00ool?0?ooo`<0o`00
4P3oool3003o01D0oooo0`000?lL0?ooo`<0o`3o5P3oool000H0oooo0`3o0?lM0?ooo`<0003o5@3o
ool3003o0140oooo0`3o000@0?ooo`<00?oo3`3oool30?l00180oooo0`00o`0E0?ooo`<0003o703o
ool30?l0oaH0oooo00060?ooo`<0o`3o7@3oool30000oaD0oooo0`00o`0A0?ooo`<0o`00403oool3
003oo`l0oooo0`3o000B0?ooo`<00?l05@3oool30000oa`0oooo0`3o0?lF0?ooo`001P3oool30?l0
oad0oooo0`000?lE0?ooo`<00?l04@3oool30?l00100oooo0`00ool?0?ooo`<0o`004@3oool3003o
01D0oooo10000?lL0?ooo`<0o`3o5P3oool000H0oooo0`3o0?lM0?ooo`<0003o5P3oool3003o0100
oooo0`3o000@0?ooo`<00?oo3`3oool30?l00140oooo0`00o`0E0?ooo`<0003o703oool30?l0oaL0
oooo00070?ooo`<0o`3o703oool30000oaH0oooo0`00o`0@0?ooo`<0o`00403oool3003oo`l0oooo
0`3o000A0?ooo`<00?l05@3oool30000oa`0oooo0`3o0?lG0?ooo`001`3oool30?l0oa`0oooo0`00
0?lF0?ooo`<00?l0403oool30?l00100oooo0`00ool?0?ooo`<0o`004@3oool3003o01D0oooo0`00
0?lL0?ooo`<0o`3o5`3oool000L0oooo0`3o0?lL0?ooo`@0003o5@3oool3003o0100oooo0`3o000@
0?ooo`<00?oo3`3oool30?l00140oooo0`00o`0D0?ooo`@0003o703oool30?l0oaL0oooo00070?oo
o`@0o`3o703oool30000oaD0oooo0`00o`0A0?ooo`<0o`003`3oool3003oo`l0oooo0`3o000A0?oo
o`<00?l0503oool30000oad0oooo0`3o0?lG0?ooo`00203oool30?l0oa`0oooo0`000?lE0?ooo`<0
0?l04@3oool30?l000l0oooo0`00ool?0?ooo`<0o`004@3oool3003o01@0oooo0`000?lM0?ooo`<0
o`3o5`3oool000P0oooo0`3o0?lL0?ooo`<0003o5P3oool3003o0100oooo0`3o000?0?ooo`<00?oo
3`3oool30?l00100oooo0`00o`0E0?ooo`<0003o703oool30?l0oaP0oooo00080?ooo`@0o`3o6`3o
ool40000oaD0oooo0`00o`0@0?ooo`<0o`003`3oool3003oo`l0oooo0`3o000@0?ooo`<00?l0503o
ool40000oa`0oooo0`3o0?lH0?ooo`002@3oool30?l0oa`0oooo0`000?lE0?ooo`<00?l0403oool3
0?l000l0oooo0`00ool?0?ooo`<0o`00403oool3003o01@0oooo0`000?lM0?ooo`<0o`3o603oool0
00T0oooo103o0?lK0?ooo`<0003o5@3oool3003o0100oooo0`3o000?0?ooo`<00?oo3P3oool30?l0
0140oooo0`00o`0D0?ooo`<0003o703oool40?l0oaP0oooo000:0?ooo`<0o`3o6`3oool40000oa@0
oooo0`00o`0@0?ooo`<0o`003`3oool3003oo`h0oooo0`3o000@0?ooo`@00?l0503oool30000oa`0
oooo0`3o0?lI0?ooo`002P3oool30?l0oa`0oooo0`000?lD0?ooo`<00?l0403oool30?l000l0oooo
0`00ool>0?ooo`<0o`00403oool3003o01@0oooo10000?lL0?ooo`<0o`3o6@3oool000X0oooo103o
0?lK0?ooo`<0003o503oool3003o0100oooo0`3o000?0?ooo`<00?oo3P3oool30?l00100oooo0`00
o`0D0?ooo`<0003o703oool40?l0oaT0oooo000;0?ooo`<0o`3o6`3oool40000oa@0oooo0`00o`0?
0?ooo`<0o`003`3oool3003oo`h0oooo0`3o000?0?ooo`@00?l0503oool30000oa`0oooo0`3o0?lJ
0?ooo`002`3oool30?l0oa`0oooo0`000?lD0?ooo`<00?l03`3oool30?l000l0oooo0`00ool>0?oo
o`<0o`003`3oool3003o01D0oooo0`000?lL0?ooo`<0o`3o6P3oool000/0oooo103o0?lK0?ooo`<0
003o503oool3003o00l0oooo0`3o000?0?ooo`<00?oo3@3oool30?l00100oooo0`00o`0D0?ooo`@0
003o6`3oool40?l0oaX0oooo000<0?ooo`<0o`3o6`3oool40000oa<0oooo0`00o`0@0?ooo`<0o`00
3P3oool3003oo`d0oooo0`3o000@0?ooo`<00?l0503oool30000oa`0oooo0`3o0?lK0?ooo`00303o
ool30?l0oa`0oooo0`000?lC0?ooo`@00?l03`3oool30?l000h0oooo0`00ool=0?ooo`<0o`003`3o
ool4003o01@0oooo0`000?lL0?ooo`<0o`3o6`3oool000`0oooo103o0?lK0?ooo`@0003o4`3oool3
003o00l0oooo0`3o000>0?ooo`<00?oo3@3oool30?l000l0oooo0`00o`0D0?ooo`@0003o6`3oool4
0?l0oa/0oooo000=0?ooo`<0o`3o703oool30000oa<0oooo0`00o`0?0?ooo`<0o`003P3oool3003o
o`d0oooo0`3o000?0?ooo`<00?l0503oool30000oa`0oooo0`3o0?lL0?ooo`003@3oool40?l0oa/0
oooo0`000?lC0?ooo`@00?l03P3oool30?l000h0oooo0`00ool=0?ooo`<0o`003P3oool4003o01<0
oooo10000?lK0?ooo`@0o`3o703oool000h0oooo0`3o0?lK0?ooo`@0003o4`3oool3003o00l0oooo
0`3o000=0?ooo`<00?oo3@3oool30?l000h0oooo0`00o`0D0?ooo`<0003o703oool30?l0oad0oooo
000>0?ooo`<0o`3o703oool30000oa<0oooo0`00o`0?0?ooo`<0o`003@3oool3003oo`d0oooo0`3o
000>0?ooo`<00?l0503oool30000oa/0oooo103o0?lM0?ooo`003P3oool40?l0oa/0oooo10000?lB
0?ooo`@00?l03P3oool30?l000d0oooo0`00ool<0?ooo`<0o`003`3oool3003o01<0oooo10000?lK
0?ooo`<0o`3o7P3oool000l0oooo0`3o0?lL0?ooo`<0003o4`3oool3003o00h0oooo0`3o000=0?oo
o`<00?oo303oool30?l000h0oooo1000o`0C0?ooo`<0003o6`3oool40?l0oah0oooo000?0?ooo`@0
o`3o6`3oool40000oa80oooo0`00o`0>0?ooo`<0o`003@3oool3003oo``0oooo0`3o000>0?ooo`<0
0?l04`3oool40000oa/0oooo0`3o0?lO0?ooo`00403oool30?l0oa`0oooo0`000?lB0?ooo`@00?l0
3P3oool30?l000`0oooo0`00ool<0?ooo`<0o`003P3oool3003o01<0oooo0`000?lK0?ooo`@0o`3o
7`3oool00100oooo0`3o0?lL0?ooo`<0003o4`3oool3003o00h0oooo0`3o000<0?ooo`<00?oo303o
ool30?l000d0oooo1000o`0B0?ooo`@0003o6`3oool30?l0ob00oooo000@0?ooo`@0o`3o6`3oool4
0000oa80oooo1000o`0=0?ooo`<0o`00303oool3003oo``0oooo0`3o000=0?ooo`<00?l04P3oool4
0000oa/0oooo103o0?lP0?ooo`004@3oool30?l0oa`0oooo0`000?lC0?ooo`<00?l03@3oool30?l0
00`0oooo0`00ool<0?ooo`<0o`003@3oool3003o0180oooo0`000?lL0?ooo`<0o`3o8@3oool00140
oooo103o0?lK0?ooo`@0003o4P3oool3003o00d0oooo103o000;0?ooo`<00?oo2`3oool40?l000`0
oooo1000o`0A0?ooo`@0003o6`3oool40?l0ob40oooo000B0?ooo`@0o`3o6`3oool30000oa80oooo
1000o`0=0?ooo`<0o`002`3oool3003oo`/0oooo0`3o000=0?ooo`<00?l04P3oool30000oa/0oooo
103o0?lR0?ooo`004`3oool30?l0oa/0oooo10000?lB0?ooo`<00?l03@3oool30?l000/0oooo0`00
ool;0?ooo`<0o`003@3oool3003o0140oooo10000?lK0?ooo`<0o`3o8`3oool001@0oooo0`3o0?lK
0?ooo`<0003o4P3oool4003o00`0oooo0`3o000;0?ooo`<00?oo2`3oool30?l000`0oooo1000o`0A
0?ooo`<0003o6`3oool40?l0ob<0oooo000D0?ooo`@0o`3o6P3oool40000oa80oooo0`00o`0<0?oo
o`@0o`002P3oool3003oo`X0oooo103o000<0?ooo`<00?l04@3oool40000oa/0oooo0`3o0?lT0?oo
o`005@3oool40?l0oaX0oooo10000?lA0?ooo`@00?l0303oool30?l000X0oooo0`00ool:0?ooo`<0
o`00303oool4003o0100oooo10000?lK0?ooo`@0o`3o903oool001H0oooo0`3o0?lK0?ooo`<0003o
4P3oool3003o00`0oooo0`3o000:0?ooo`<00?oo2P3oool30?l000`0oooo0`00o`0A0?ooo`<0003o
6`3oool40?l0obD0oooo000G0?ooo`<0o`3o6P3oool40000oa40oooo1000o`0;0?ooo`<0o`002P3o
ool3003oo`X0oooo0`3o000;0?ooo`@00?l0403oool40000oa/0oooo0`3o0?lV0?ooo`005`3oool4
0?l0oaX0oooo0`000?lB0?ooo`<00?l02`3oool30?l000X0oooo0`00ool:0?ooo`<0o`002`3oool3
003o0140oooo0`000?lK0?ooo`<0o`3o9`3oool001P0oooo103o0?lI0?ooo`@0003o4@3oool4003o
00X0oooo103o00090?ooo`<00?oo2@3oool40?l000X0oooo1000o`0@0?ooo`@0003o6P3oool40?l0
obL0oooo000I0?ooo`<0o`3o6P3oool40000oa40oooo0`00o`0;0?ooo`<0o`002@3oool3003oo`T0
oooo0`3o000:0?ooo`@00?l0403oool40000oaX0oooo103o0?lX0?ooo`006P3oool30?l0oaX0oooo
0`000?lA0?ooo`<00?l02`3oool30?l000T0oooo0`00ool90?ooo`<0o`002P3oool3003o0140oooo
0`000?lK0?ooo`<0o`3o:@3oool001X0oooo103o0?lI0?ooo`@0003o403oool4003o00X0oooo0`3o
00090?ooo`<00?oo2@3oool30?l000T0oooo1000o`0@0?ooo`@0003o6P3oool30?l0obX0oooo000K
0?ooo`@0o`3o6@3oool30000oa40oooo0`00o`0:0?ooo`@0o`00203oool3003oo`P0oooo103o0009
0?ooo`<00?l04@3oool30000oaX0oooo103o0?lZ0?ooo`00703oool30?l0oaT0oooo10000?l@0?oo
o`@00?l02P3oool30?l000P0oooo0`00ool80?ooo`<0o`002@3oool4003o0100oooo0`000?lJ0?oo
o`@0o`3o:`3oool001d0oooo0`3o0?lI0?ooo`@0003o403oool3003o00X0oooo0`3o00080?ooo`<0
0?oo203oool30?l000T0oooo0`00o`0@0?ooo`@0003o6@3oool40?l0ob`0oooo000M0?ooo`@0o`3o
6@3oool40000o`l0oooo1000o`090?ooo`<0o`00203oool3003oo`L0oooo103o00080?ooo`@00?l0
3`3oool40000oaT0oooo103o0?l]0?ooo`007P3oool40?l0oaT0oooo10000?l?0?ooo`<00?l02@3o
ool40?l000L0oooo0`00ool70?ooo`<0o`002@3oool3003o00l0oooo10000?lI0?ooo`@0o`3o;P3o
ool001l0oooo103o0?lI0?ooo`@0003o3P3oool4003o00T0oooo0`3o00070?ooo`<00?oo1`3oool3
0?l000P0oooo1000o`0>0?ooo`@0003o6@3oool40?l0obl0oooo000P0?ooo`@0o`3o6@3oool40000
o`h0oooo0`00o`090?ooo`<0o`001`3oool3003oo`H0oooo103o00080?ooo`<00?l03P3oool40000
oaT0oooo103o0?l`0?ooo`008@3oool40?l0oaT0oooo10000?l=0?ooo`@00?l0203oool30?l000L0
oooo0`00ool60?ooo`<0o`00203oool4003o00d0oooo10000?lI0?ooo`@0o`3o<@3oool00280oooo
103o0?lI0?ooo`@0003o3@3oool4003o00L0oooo103o00060?ooo`<00?oo1P3oool30?l000P0oooo
0`00o`0=0?ooo`@0003o6@3oool40?l0oc80oooo000S0?ooo`@0o`3o6@3oool40000o`d0oooo0`00
o`080?ooo`<0o`001P3oool3003oo`D0oooo103o00070?ooo`@00?l0303oool40000oaT0oooo103o
0?lc0?ooo`00903oool40?l0oaT0oooo10000?l<0?ooo`@00?l01`3oool30?l000H0oooo0`00ool5
0?ooo`<0o`00203oool3003o00`0oooo10000?lI0?ooo`@0o`3o=03oool002D0oooo103o0?lI0?oo
o`@0003o303oool3003o00L0oooo0`3o00060?ooo`<00?oo1@3oool30?l000L0oooo1000o`0;0?oo
o`@0003o6@3oool40?l0ocD0oooo000V0?ooo`D0o`3o603oool40000o`/0oooo1000o`060?ooo`@0
o`001@3oool3003oo`@0oooo103o00060?ooo`@00?l02`3oool40000oaT0oooo103o0?lf0?ooo`00
9`3oool50?l0oaP0oooo10000?l;0?ooo`@00?l01P3oool30?l000D0oooo0`00ool40?ooo`<0o`00
1`3oool3003o00/0oooo10000?lI0?ooo`@0o`3o=`3oool002P0oooo1P3o0?lG0?ooo`<0003o303o
ool3003o00H0oooo0`3o00050?ooo`<00?oo103oool30?l000H0oooo1000o`0:0?ooo`@0003o603o
ool50?l0ocP0oooo000Z0?ooo`D0o`3o5`3oool40000o`X0oooo1000o`050?ooo`@0o`00103oool3
003oo`@0oooo0`3o00060?ooo`<00?l02P3oool40000oaP0oooo1@3o0?li0?ooo`00:`3oool60?l0
oaD0oooo1@000?l:0?ooo`@00?l01@3oool30?l000@0oooo0`00ool30?ooo`@0o`001@3oool4003o
00T0oooo10000?lG0?ooo`H0o`3o>P3oool002d0oooo1@3o0?lF0?ooo`@0003o2P3oool3003o00D0
oooo0`3o00040?ooo`<00?oo0`3oool30?l000H0oooo0`00o`090?ooo`@0003o5`3oool50?l0oc`0
oooo000^0?ooo`H0o`3o5@3oool40000o`T0oooo1000o`040?ooo`@0o`000`3oool3003oo`<0oooo
0`3o00050?ooo`@00?l0203oool40000oaH0oooo1P3o0?lm0?ooo`00<03oool50?l0oaD0oooo1@00
0?l80?ooo`@00?l0103oool30?l000<0oooo0`00ool20?ooo`@0o`00103oool4003o00P0oooo1000
0?lF0?ooo`D0o`3o?`3oool00340oooo1P3o0?lD0?ooo`D0003o203oool3003o00@0oooo103o0002
0?ooo`<00?oo0P3oool30?l000@0oooo1000o`080?ooo`@0003o5@3oool60?l0od00oooo000c0?oo
o`H0o`3o503oool40000o`L0oooo1000o`040?ooo`<0o`000P3oool3003oo`80oooo0`3o00040?oo
o`<00?l0203oool40000oa@0oooo1P3o0?m20?ooo`00=03oool70?l0oa<0oooo10000?l70?ooo`@0
0?l00`3oool30?l00080oooo0`00ool00`3oool0o`000?l000020?l000<0oooo1000o`070?ooo`@0
003o4`3oool70?l0od<0oooo000f0?ooo`L0o`3o4P3oool50000o`H0oooo1000o`020?ooo`<0o`00
0P3oool3003oo`040?ooo`3o0000o`000?l000<0oooo1000o`060?ooo`D0003o4P3oool70?l0odD0
oooo000h0?ooo`L0o`3o4@3oool60000o`D0oooo0`00o`030?ooo`<0o`0000D0oooo003oo`00ool0
0?oo0?ooo`030?l00080oooo1000o`050?ooo`H0003o4@3oool70?l0odL0oooo000j0?ooo`L0o`3o
403oool60000o`@0oooo1000o`020?ooo`<0o`0000@0oooo003oo`00ool00?oo103o00000`3oool0
0?l0003o0002003o00D0oooo1@000?lA0?ooo`L0o`3oB@3oool003`0oooo1`3o0?l@0?ooo`H0003o
0`3oool4003o00050?ooo`3o0000o`000?l0003oool00`00ool30?l000030?ooo`00o`000?l00080
0?l0103oool60000oa00oooo1`3o0?m;0?ooo`00?P3oool70?l0oa00oooo1P000?l20?ooo`@00?l0
103o0002003oo`@0o`001000o`030?ooo`H0003o403oool70?l0odd0oooo00100?ooo`L0o`3o3`3o
ool60000o`80oooo1000o`030?l000800?oo0`3o0000103oool00?l0003o0000o`020?ooo`L0003o
3`3oool70?l0odl0oooo00120?ooo`P0o`3o3P3oool60000o`030?ooo`00o`000?l000800?l00P3o
0002003oo`<0o`001000o`000`3oool0003o0000o`040000o`d0oooo2@3o0?mA0?ooo`00A03oool;
0?l0o`/0oooo1P000?l3003o0080o`0000<00?oo0?l0003o00001000o`070000o`X0oooo303o0?mC
0?ooo`00AP3oool<0?l0o`T0oooo1P000?l2003o0080o`0000@00?oo0?l00000o`000?l020000?l9
0?ooo`d0o`3oE@3oool004X0oooo3`3o0?l40?ooo`@0003o00D00?l00?l0003o0000o`00003oo`02
003o00P0003o0`3oool?0?l0oeX0oooo001>0?oooa40o`3o0`000?l00`00o`00o`000?l000070000
oa80o`3oGP3oool00540oooo4@3o0?l00`000?l00?l00?l0000F0?l0of40oooo001H0?ooo`/0o`3o
00<0003o0?l0003o0?l03P3o0?mX0?ooo`00G`3oool50?l0o`030000o`3o0?l0o`3o00H0o`3oK`3o
ool006H0oooo00<000000?ooo`3oool0L`3oool006H0oooo00<000000?ooo`3oool0L`3oool005d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1c0?ooo`00G@3oool00`000000oooo
0?ooo`1l0?ooo`00G@3oool00`000000oooo0?ooo`1l0?ooo`00G@3oool00`000000oooo0?ooo`1l
0?ooo`00F`3oool00`000000oooo0000001n0?ooo`00G03oool2000007h0oooo001M0?ooo`030000
003oool0oooo07`0oooo003L0?ooo`00g03oool00=`0oooo001U0?ooo`030000003oool0oooo07@0
oooo001T0?ooo`030000003oool0000007D0oooo001T0?ooo`030000003oool0000007D0oooo001T
0?ooo`030000003oool0000007D0oooo001S0?ooo`050000003oool0oooo0?ooo`000000M03oool0
0=`0oooo003L0?ooo`00g03oool00=`0oooo0000\
\>"],
    ImageRangeCache->{{{0, 219}, {219, 0}} -> {-1, -1, 0, 0}}],
  StyleBox["  \n\tFigure 5.8",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Vertical segments mapped onto circular arcs by  ",
  Cell[BoxData[
      \(w\  = tan\ z\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the formula f[z] = Tan[z] and graph the transformation.\
\>", "Text"],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, Iden];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(f[z_]\  = \ Tan[z];\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, \ {\(-\[Pi]\)\/4, \[Pi]\/4, \[Pi]\/16}, {\(-3\), 3, 0.25}, 
        PlotRange \[Rule] {{\(-1\), 1}, {\(-3.2\), 3.2}}, 
        AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-\[Pi]\)\/4, \[Pi]\/4, \[Pi]\/4], 
            Range[\(-3\), 3, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The lines forming the rectangle \!\(\(-\[Pi]\)\/4\) \
\[LessEqual] x \[LessEqual] \!\(\[Pi]\/4\), -3 \[LessEqual] y \[LessEqual] 3.\
\>\""];\)\ \), "\n", 
    \(\(CartesianMap[
        f, {\(-\[Pi]\)\/4, \[Pi]\/4, \[Pi]\/16}, {\(-3\), 3, 0.25}, 
        PlotRange \[Rule] {{\(-1.1\), 1.1}, {\(-1.1\), 1.1}}, 
        AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Cyan}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image disk  |w| < 1,\>"];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tHow should we define the complex hyperbolic functions?  We begin with\
\>", "Text"],

Cell[TextData[{
  " ",
  StyleBox["Definition 5.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   The hyperbolic cosine and hyperbolic sine functions are  \n\n\t\t",
  Cell[BoxData[{
      \(cosh\ z\  = \ \(1\/2\) \((\[ExponentialE]\^z + \
\[ExponentialE]\^\(-z\))\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(sinh\ z\  = \ \(1\/2\) \((\[ExponentialE]\^z - \
\[ExponentialE]\^\(-z\))\)\)}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWith these definitions in place, we can now easily create the other complex \
hyperbolic trigonometric functions, provided the denominators in the \
following expressions are not zero.\
\>", "Text"],

Cell[TextData[{
  " ",
  StyleBox["Definition 5.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   Identities for the hyperbolic trigonometric functions are  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(tanh\ z\  = \ \(sinh\ z\)\/\(cosh\ z\)\), " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        "\[IndentingNewLine]", \(coth\ z\  = \ \(cosh\ z\)\/\(sinh\ z\)\), 
        " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(sech\ z\  = \ 1\/\(cosh\ z\)\), " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{\(csch\ z\), " ", "=", " ", 
          RowBox[{\(1\/\(sinh\ z\)\), " ", 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]]],
  "    "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tAs the series for the complex hyperbolic sine and cosine agree with the \
real hyperbolic sine and cosine when z is real, the remaining complex \
hyperbolic trigonometric functions likewise agree with their real \
counterparts. Many other properties are also shared. We state several results \
without proof, as they follow from the definitions we gave using standard \
operations, such as the quotient rule for derivatives. We ask you to \
establish some of these identities in the exercises.\
\>", "Text"],

Cell[TextData[{
  "\tThe derivatives of the hyperbolic functions follow the same rules as in \
calculus:  \n\n\t\t\t",
  Cell[BoxData[GridBox[{
          {
            RowBox[{\(\(d\/dz\) cosh\ z\  = \ sinh\ z\), " ", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "                "}], 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            RowBox[{\(\(d\/dz\) Sinh\ z\  = \ cosh\ z\), " ", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "                "}]},
          {
            RowBox[{"\[IndentingNewLine]", 
              RowBox[{\(\(d\/dz\) Tanh\ z\  = \ \(sech\^2\) z\), " ", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "              "}]}], 
            RowBox[{"\[IndentingNewLine]", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}], 
            RowBox[{"\[IndentingNewLine]", 
              RowBox[{\(\(d\/dz\) coth\ z\  = \ \(-\ csch\^2\) z\), " ", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "          "}]}]},
          {
            RowBox[{"\[IndentingNewLine]", 
              
              RowBox[{\(\(d\/dz\) sech\ z\  = \ \(-\ sech\)\ z\ Tanh\ z\), 
                " ", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}], 
            RowBox[{"\[IndentingNewLine]", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}], 
            RowBox[{"\[IndentingNewLine]", 
              RowBox[{\(\(d\/dz\) csch\ z\), " ", "=", " ", 
                RowBox[{\(-\ csch\), " ", "z", " ", "coth", " ", 
                  RowBox[{"z", 
                    StyleBox[" ",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox[".",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}]}]}]}]}]}
          }]]],
  "  "
}], "Text"],

Cell[TextData[{
  "\tThe hyperbolic cosine and hyperbolic sine can be expressed as  \n\n\t\t\t\
",
  Cell[BoxData[{
      \(cosh\ z\ \  = \ \(cosh \((x + \[ImaginaryI]\ y)\)\  = \ 
          cos\ y\ \ cosh\ x\ \  + \ \[ImaginaryI]\ sinh\ x\ sin\ y\)\n\), 
    "\[IndentingNewLine]", 
      \(sinh\ z\  = \ \(sinh \((x + \[ImaginaryI]\ y)\)\ \  = \ 
          sinh\ x\ cos\ y\ \  + \ \[ImaginaryI]\ cosh\ x\ \ sin\ y\)\)}]]
}], "Text"],

Cell[TextData[{
  "\tSome of the important identities involving the hyperbolic functions are  \
\n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(\(cosh\^2\) z\  - \ \(sinh\^2\) z\  = \ 1\), " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\n", \(sinh \((z\_1 + 
                z\_2)\)\ \  = \ \ sinh\ z\_1\ cosh\ z\_2\ \  + \ 
            cosh\ z\_1\ sinh\ z\_2\), " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\n", \(cosh \((z\_1 + 
                z\_2)\)\ \  = \ \ cosh\ z\_1\ cosh\ z\_2\ \  + \ 
            sinh\ z\_1\ sinh\ z\_2\), " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\n", \(cosh \((z + 2  \[Pi]\ \[ImaginaryI])\)\  = \ cosh\ z\), " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\n", \(sinh \((z + 2  \[Pi]\ \[ImaginaryI])\)\  = \ sinh\ z\), " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\n", \(cosh \((\(-z\))\)\  = \ \ cosh\ z\), " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", "\n", 
        RowBox[{\(sinh \((\(-z\))\)\), " ", "=", " ", 
          RowBox[{\(-\ sinh\), " ", 
            RowBox[{"z", " ", 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]]],
  "    "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Exponential Function",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ExponentialFunBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Logarithms",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/LogarithmFunBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Conformal Mapping",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ConformalMappingBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Smith Chart",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/SmithChartBib.html"], None},
  
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{982, 573},
WindowMargins->{{1, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 452678, 11381}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 133, 2, 33, "Text"],
Cell[2238, 66, 736, 15, 180, "Text"],
Cell[2977, 83, 1557, 45, 180, "Text",
  Evaluatable->False],
Cell[4537, 130, 408, 13, 40, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4970, 147, 154, 4, 33, "Text",
  Evaluatable->False],
Cell[5127, 153, 221, 6, 33, "Text"],
Cell[5351, 161, 401, 8, 130, "Input"],
Cell[5755, 171, 150, 5, 33, "Text",
  Evaluatable->False],
Cell[5908, 178, 1144, 20, 389, "Input"],
Cell[7055, 200, 132, 5, 33, "Text"],
Cell[7190, 207, 1446, 27, 337, "Input"]
}, Closed]],
Cell[8651, 237, 330, 11, 37, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[9006, 252, 155, 4, 33, "Text",
  Evaluatable->False],
Cell[9164, 258, 269, 8, 33, "Text",
  Evaluatable->False],
Cell[9436, 268, 401, 8, 130, "Input"],
Cell[9840, 278, 150, 5, 33, "Text",
  Evaluatable->False],
Cell[9993, 285, 1102, 20, 389, "Input"],
Cell[11098, 307, 134, 5, 52, "Text"],
Cell[11235, 314, 1391, 26, 337, "Input"]
}, Closed]],
Cell[12641, 343, 252, 6, 30, "Text",
  Evaluatable->False],
Cell[12896, 351, 407, 17, 36, "Text"],

Cell[CellGroupData[{
Cell[13328, 372, 169, 4, 33, "Text",
  Evaluatable->False],
Cell[13500, 378, 63, 1, 44, "Input"],
Cell[13566, 381, 63, 1, 44, "Input"],
Cell[13632, 384, 58, 1, 44, "Input"],
Cell[13693, 387, 58, 1, 44, "Input"]
}, Closed]],
Cell[13766, 391, 286, 5, 49, "Text"],
Cell[14055, 398, 415, 17, 36, "Text"],

Cell[CellGroupData[{
Cell[14495, 419, 111, 2, 33, "Text"],
Cell[14609, 423, 1664, 41, 257, "Text"],
Cell[16276, 466, 155, 5, 36, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[16468, 476, 166, 4, 30, "Text",
  Evaluatable->False],
Cell[16637, 482, 71, 1, 30, "Input"],
Cell[16711, 485, 76, 1, 30, "Input"]
}, Closed]],
Cell[16802, 489, 932, 26, 142, "Text"],
Cell[17737, 517, 878, 30, 52, "Text"],

Cell[CellGroupData[{
Cell[18640, 551, 165, 4, 33, "Text",
  Evaluatable->False],
Cell[18808, 557, 65, 1, 30, "Input"],
Cell[18876, 560, 60, 1, 30, "Input"],
Cell[18939, 563, 120, 2, 50, "Input"]
}, Closed]],
Cell[19074, 568, 285, 9, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[19384, 581, 163, 4, 33, "Text",
  Evaluatable->False],
Cell[19550, 587, 173, 5, 33, "Text"],
Cell[19726, 594, 728, 14, 258, "Input"]
}, Closed]],
Cell[20469, 611, 361, 12, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20855, 627, 164, 4, 33, "Text",
  Evaluatable->False],
Cell[21022, 633, 173, 5, 33, "Text"],
Cell[21198, 640, 837, 17, 278, "Input"]
}, Closed]],
Cell[22050, 660, 2401, 63, 200, "Text"],

Cell[CellGroupData[{
Cell[24476, 727, 144, 4, 33, "Text",
  Evaluatable->False],
Cell[24623, 733, 1655, 46, 177, "Text"],
Cell[26281, 781, 90, 2, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[26408, 788, 169, 4, 30, "Text",
  Evaluatable->False],
Cell[26580, 794, 74, 1, 30, "Input"],
Cell[26657, 797, 79, 1, 30, "Input"],
Cell[26739, 800, 79, 1, 30, "Input"],
Cell[26821, 803, 84, 1, 30, "Input"]
}, Closed]],
Cell[26920, 807, 1306, 34, 163, "Text"],
Cell[28229, 843, 808, 28, 157, "Text"],
Cell[29040, 873, 172400, 4377, 225, "Text"],
Cell[201443, 5252, 567, 17, 109, "Text"],

Cell[CellGroupData[{
Cell[202035, 5273, 96, 2, 33, "Text"],
Cell[202134, 5277, 2071, 49, 283, "Text"],
Cell[204208, 5328, 1419, 31, 204, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[205664, 5364, 200, 5, 30, "Text",
  Evaluatable->False],
Cell[205867, 5371, 280, 4, 54, "Input"],
Cell[206150, 5377, 314, 5, 54, "Input"],
Cell[206467, 5384, 290, 4, 54, "Input"],
Cell[206760, 5390, 374, 8, 85, "Input"],
Cell[207137, 5400, 340, 7, 85, "Input"],
Cell[207480, 5409, 309, 8, 50, "Input"],
Cell[207792, 5419, 309, 8, 50, "Input"]
}, Closed]],
Cell[208116, 5430, 3096, 82, 275, "Text"],
Cell[211215, 5514, 903, 22, 183, "Text"],

Cell[CellGroupData[{
Cell[212143, 5540, 179, 4, 33, "Text",
  Evaluatable->False],
Cell[212325, 5546, 277, 6, 70, "Input"],
Cell[212605, 5554, 277, 6, 70, "Input"],
Cell[212885, 5562, 292, 6, 70, "Input"],
Cell[213180, 5570, 292, 6, 70, "Input"],
Cell[213475, 5578, 292, 6, 70, "Input"],
Cell[213770, 5586, 292, 6, 70, "Input"]
}, Closed]],
Cell[214077, 5595, 3003, 79, 223, "Text"],
Cell[217083, 5676, 1367, 32, 232, "Text"],
Cell[218453, 5710, 352, 12, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[218830, 5726, 113, 2, 33, "Text"],
Cell[218946, 5730, 603, 16, 38, "Text"],
Cell[219552, 5748, 2312, 45, 686, "Input"],
Cell[221867, 5795, 242, 9, 52, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[222146, 5809, 114, 2, 30, "Text"],
Cell[222263, 5813, 125, 5, 33, "Text"],
Cell[222391, 5820, 1705, 35, 470, "Input"],
Cell[224099, 5857, 192, 7, 33, "Text"]
}, Closed]],
Cell[224306, 5867, 2549, 92, 349, "Text"],

Cell[CellGroupData[{
Cell[226880, 5963, 102, 2, 33, "Text"],
Cell[226985, 5967, 171, 5, 33, "Text"],
Cell[227159, 5974, 781, 17, 250, "Input"],
Cell[227943, 5993, 457, 12, 55, "Text",
  Evaluatable->False],
Cell[228403, 6007, 577, 12, 170, "Input"],
Cell[228983, 6021, 103, 2, 33, "Text",
  Evaluatable->False],
Cell[229089, 6025, 302, 7, 103, "Input"],
Cell[229394, 6034, 120, 2, 33, "Text",
  Evaluatable->False],
Cell[229517, 6038, 1046, 20, 341, "Input"],
Cell[230566, 6060, 173, 7, 33, "Text",
  Evaluatable->False],
Cell[230742, 6069, 306, 5, 97, "Input"]
}, Closed]],
Cell[231063, 6077, 2183, 65, 90, "Text"],
Cell[233249, 6144, 107383, 2390, 216, "Text"],

Cell[CellGroupData[{
Cell[340657, 8538, 102, 2, 33, "Text"],
Cell[340762, 8542, 85, 2, 33, "Text"],
Cell[340850, 8546, 1559, 29, 342, "Input"],
Cell[342412, 8577, 1564, 29, 342, "Input"]
}, Closed]],
Cell[343991, 8609, 1795, 46, 351, "Text"],
Cell[345789, 8657, 788, 25, 109, "Text"],

Cell[CellGroupData[{
Cell[346602, 8686, 102, 2, 33, "Text"],
Cell[346707, 8690, 1087, 25, 294, "Input"],
Cell[347797, 8717, 1087, 25, 294, "Input"]
}, Closed]],
Cell[348899, 8745, 176, 3, 30, "Text"],
Cell[349078, 8750, 260, 10, 33, "Text",
  Evaluatable->False],
Cell[349341, 8762, 1687, 64, 226, "Text"],
Cell[351031, 8828, 529, 17, 52, "Text"],

Cell[CellGroupData[{
Cell[351585, 8849, 112, 2, 33, "Text"],
Cell[351700, 8853, 177, 6, 33, "Text"],
Cell[351880, 8861, 778, 17, 250, "Input"],
Cell[352661, 8880, 124, 2, 33, "Text",
  Evaluatable->False],
Cell[352788, 8884, 591, 13, 170, "Input"],
Cell[353382, 8899, 103, 2, 33, "Text",
  Evaluatable->False],
Cell[353488, 8903, 618, 13, 150, "Input"]
}, Closed]],
Cell[354121, 8919, 1621, 43, 254, "Text"],

Cell[CellGroupData[{
Cell[355767, 8966, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[355920, 8972, 1885, 37, 683, "Input"]
}, Closed]],
Cell[357820, 9012, 2024, 63, 71, "Text"],
Cell[359847, 9077, 77678, 1904, 258, "Text"],

Cell[CellGroupData[{
Cell[437550, 10985, 102, 2, 33, "Text"],
Cell[437655, 10989, 85, 2, 33, "Text"],
Cell[437743, 10993, 1474, 28, 336, "Input"]
}, Closed]],
Cell[439232, 11024, 95, 2, 30, "Text"],
Cell[439330, 11028, 489, 14, 117, "Text",
  Evaluatable->False],
Cell[439822, 11044, 210, 4, 33, "Text"],
Cell[440035, 11050, 1773, 49, 184, "Text",
  Evaluatable->False],
Cell[441811, 11101, 519, 8, 71, "Text"],
Cell[442333, 11111, 4404, 105, 161, "Text"],
Cell[446740, 11218, 434, 9, 107, "Text"],
Cell[447177, 11229, 2904, 74, 297, "Text"],
Cell[450084, 11305, 290, 7, 33, "Text"],
Cell[450377, 11314, 292, 7, 33, "Text"],
Cell[450672, 11323, 288, 7, 33, "Text"],
Cell[450963, 11332, 291, 7, 33, "Text"],
Cell[451257, 11341, 277, 7, 33, "Text"],
Cell[451537, 11350, 257, 5, 33, "Text"],
Cell[451797, 11357, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

