(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     38327,       1017]*)
(*NotebookOutlinePosition[     39168,       1048]*)
(*  CellTagsIndexPosition[     39092,       1042]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 6  Complex Integration",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Overview",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tOf the two main topics studied in calculus - differentiation and \
integration - we have so far only studied derivatives of complex functions. \
We now turn to the problem of integrating complex functions. The theory you \
will learn is elegant, powerful, and a useful tool for physicists and \
engineers. It also connects widely with other branches of mathematics. For \
example, even though the ideas presented here belong to the general area of \
mathematics known as analysis, you will see as an application of them one of \
the simplest proofs of the fundamental theorem of algebra."
}], "Text"],

Cell[TextData[StyleBox["6.1  Complex Integrals",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
\tIn Chapter 3 we saw how the derivative of a complex function is defined.  \
We now turn our attention to the problem of integrating complex functions.  \
We will find that integrals of analytic functions are well behaved and that \
many properties from calculus carry over to the complex case.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe introduce the integral of a complex function by defining the integral of \
a complex-valued function of a real variable\
\>", "Text"],

Cell[TextData[{
  StyleBox["Definition 6.1 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Definite Integral",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/FundamentalTheoremsofCalculus.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[" of a Complex Integrand).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(f \((t)\)\  = \ u \((t)\) + \[ImaginaryI]\ v \((t)\)\)]],
  "  where ",
  StyleBox["u(t)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v(t)",
    FontFamily->"Courier New"],
  " are real-valued functions of the real variable ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " for  ",
  Cell[BoxData[
      \(a \[LessEqual] t \[LessEqual] b\)]],
  " .  Then\n\n",
  StyleBox["(6-1)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_a\%b\ 
          f \((t)\) \[DifferentialD]t\ \  = \ \ \ \(\[Integral]\_a\%b\((u \
\((t)\) + \[ImaginaryI]\ v \((t)\))\) \[DifferentialD]t\ \ \  = \ \ \
\[Integral]\_a\%b\ 
              u \((t)\) \[DifferentialD]t\ \  + \ \ \[ImaginaryI]\ \(\
\[Integral]\_a\%b\ v \((t)\) \[DifferentialD]t\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tWe generally evaluate integrals of this type by finding the \
antiderivatives of ",
  StyleBox["u(t)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v(t)",
    FontFamily->"Courier New"],
  " and evaluating the definite integrals on the right side of Equation ",
  StyleBox["(6-1)",
    FontColor->RGBColor[0, 0, 1]],
  ".  That is, if  ",
  Cell[BoxData[
      \(U' \((t)\)\  = \ u \((t)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(V' \((t)\)\  = \ v \((t)\)\)]],
  ",  we have  \n\n",
  StyleBox["(6-2)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_a\%b\ 
          f \((t)\) \[DifferentialD]t\ \  = \ \ \(\[Integral]\_a\%b\ 
              u \((t)\) \[DifferentialD]t\ \  + \ \ \[ImaginaryI]\ \(\
\[Integral]\_a\%b\ v \((t)\) \[DifferentialD]t\)\ \  = \ \ U \((b)\) - 
            U \((a)\)\  + \ \[ImaginaryI] \((V \((b)\) - V \((a)\))\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 6.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Integral]\_0\%1\ \(\((t - \[ImaginaryI])\)\^3\) \[DifferentialD]t\ \
\  = \ \(-\(5\/4\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We write the integrand in terms of its real and imaginary \
parts, i.e.,   ",
  Cell[BoxData[
      \(f \((t)\)\  = \ \(\((t - \[ImaginaryI])\)\^3\ \  = \ \ t\^3 - 
            3\ t\  + \ \[ImaginaryI]\ \((\(-3\)\ t\^2 + 1)\)\)\)]],
  ".  Here,  ",
  Cell[BoxData[
      \(u \((t)\)\  = \ \ t\^3 - 3\ t\)]],
  "  and  ",
  Cell[BoxData[
      \(v \((t)\)\  = \ \(-\ 3\)\ t\^2 + 1\)]],
  ".  The integrals of ",
  StyleBox["u(t)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v(t)",
    FontFamily->"Courier New"],
  " are  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_0\%1\ 
          u \((t)\) \[DifferentialD]t\ \  = \ \ \(\[Integral]\_0\%1\((t\^3 - 
                  3\ t)\) \[DifferentialD]t\ \  = \ \ \(\(\((t\^4\/4 - \(3\ t\
\^2\)\/2)\)\( \[VerticalSeparator] \+\(t = 0\)\%\(t = 
                    1\)\)\)\ \  = \ \ \(-\(5\/4\)\)\)\)\)]],
  ",   and  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_0\%1\ 
          v \((t)\) \[DifferentialD]t\ \  = \ \ \(\[Integral]\_0\%1\((\(-3\)\ \
t\^2 + 1)\) \[DifferentialD]t\ \ \  = \ \ \(\(\((\(-t\^3\) + 
                  t)\)\( \[VerticalSeparator] \+\(t = 0\)\%\(t = 
                    1\)\)\)\ \  = \ \ 0\)\)\)]],
  ".  \n\nHence, by Definition ",
  StyleBox["(6-1)",
    FontColor->RGBColor[0, 0, 1]],
  ",  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_0\%1\ \(\((t - \[ImaginaryI])\)\^3\) \
\[DifferentialD]t\ \  = \ \ \[Integral]\_0\%1\ 
            u \((t)\) \[DifferentialD]t\  + \ \[ImaginaryI]\ \(\[Integral]\_0\
\%1\ v \((t)\) \[DifferentialD]t\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \
\ \)\(\(-\(5\/4\)\) + \ 
            0  \[ImaginaryI]\ \  = \ \ \(\(-\(5\/4\)\)\(\ \)\)\)\)\)}]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Method (i).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Expand the integrand f[t] into its real and imaginary parts, then \
integrate u[t] and v[t]."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[t, u, v, w];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, Int, ImInt, ImVal, ReInt, ReVal, 
        Val];\)\ \), "\[IndentingNewLine]", 
    \(\(w = \((t\  - \ \[ImaginaryI])\)\^3;\)\ \), "\n", 
    \(\(f[t_]\  = \ ComplexExpand[w];\)\ \), "\n", 
    \(\(u[t_]\  = \ ComplexExpand[Re[f[t]]];\)\ \), "\n", 
    \(\(v[t_]\  = \ ComplexExpand[Im[f[t]]];\)\ \), "\[IndentingNewLine]", 
    \(\(U[
          t_]\  = \ \[Integral]u[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(V[t_]\  = \ \[Integral]v[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(Int\  = \ 
        U[t]\  + \ \[ImaginaryI]\ V[t];\)\ \), "\[IndentingNewLine]", 
    \(\(ReVal\  = \ \ \[Integral]\_0\%1 u[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(ImVal\  = \ \ \[Integral]\_0\%1 v[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(Val\  = \ ReVal\  + \ \[ImaginaryI]\ ImVal;\)\ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[t] = u[t] + \[ImaginaryI] v[t]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<u[t] = \>", u[t]];\)\ \), "\n", 
    \(\(Print["\<v[t] = \>", v[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<U[t] = \[Integral]u[t]\[DifferentialD]t = \>", 
        U[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<V[t] = \[Integral]v[t]\[DifferentialD]t = \>", 
        V[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \
\[Integral]v[t]\[DifferentialD]t = (\>", U[t], "\<) + \[ImaginaryI](\>", 
        V[t], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)\>\"", 
        w, \*"\"\<\[DifferentialD]t = \!\(\[Integral]\_0\%1\)u[t]\
\[DifferentialD]t + \[ImaginaryI] \
\!\(\[Integral]\_0\%1\)v[t]\[DifferentialD]t\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)\>\"", 
        w, "\<\[DifferentialD]t = (U[1]-U[0]) + \[ImaginaryI](V[1]-V[0])\>"];\
\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)\>\"", 
        w, "\<\[DifferentialD]t = (\>", ReVal, "\<) + \[ImaginaryI](\>", 
        ImVal, "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)\>\"", 
        w, "\<\[DifferentialD]t = \>", Val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method (ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Compute the integral directly using a complex function for the \
integrand."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, val];\)\ \), "\[IndentingNewLine]", 
    \(\(f[
          t_]\  = \ \((t\  - \ \[ImaginaryI])\)\^3;\)\ \), "\
\[IndentingNewLine]", 
    \(\(F[
          t_]\  = \ \[Integral]f[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(val\  = \ \[Integral]\_0\%1 f[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[t] = \[Integral]\>", f[t], "\<\[DifferentialD]t = \>", 
        F[t]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)\>\"", 
        f[t], "\<\[DifferentialD]t = F[1] - F[0]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)\>\"", 
        f[t], "\<\[DifferentialD]t = (\>", F[1]\ , "\<) - (\>", 
        F[0], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)\>\"", 
        f[t], "\<\[DifferentialD]t = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Integral]\_0\%\(\[Pi]/2\)\ \(\[ExponentialE]\^\(t + \[ImaginaryI]\ \
t\)\) \[DifferentialD]t\ \  = \ \ \(1\/2\) \((\[ExponentialE]\^\(\[Pi]\/2\) - 
                1)\)\  + \ \(\(\(\[ImaginaryI]\)\(\ \)\)\/2\) \((\
\[ExponentialE]\^\(\[Pi]\/2\) + 1)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We use the method suggested by Definitions ",
  StyleBox["(6-1)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(6-2)",
    FontColor->RGBColor[0, 0, 1]],
  ".  \n\n\t\t\t",
  Cell[BoxData[{
      \(\[Integral]\_0\%\(\[Pi]/2\)\ \(\[ExponentialE]\^\(t\  + \ \
\[ImaginaryI]\ t\)\) \[DifferentialD]t\ \  = \ \ \
\(\[Integral]\_0\%\(\[Pi]/2\)\ \(\[ExponentialE]\^t\) \(\[ExponentialE]\^\(\
\[ImaginaryI]\ t\)\) \[DifferentialD]t\ \  = \ \ \[Integral]\_0\%\(\[Pi]/2\)\ \
\[ExponentialE]\^t\ \((cos\ t + \[ImaginaryI]\ sin\ t)\) \[DifferentialD]t\)\ \
\ \[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(\[Integral]\_0\%\(\[Pi]/2\)\ \[ExponentialE]\^t\ cos\ t\
\ \ \[DifferentialD]t\  + \ \[ImaginaryI]\ \(\[Integral]\_0\%\(\[Pi]/2\)\ \
\[ExponentialE]\^t\ sin\ t\ \ \[DifferentialD]t\)\)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "We can evaluate each of the integrals via integration by parts.  For \
example,  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_0\%\(\[Pi]/2\)\ \[ExponentialE]\^t\ cos\ t\
\ \ \[DifferentialD]t\ \  = \ \ \((\[ExponentialE]\^t\ sin\ t)\)\( \
\[VerticalSeparator] \+\(t = 
                0\)\%\(t = \[Pi]/
                  2\)\)\ \ \ \(-\ \ \ \ \(\[Integral]\_0\%\(\[Pi]/2\)sin\ t\
\ \ \(\[ExponentialE]\^t\) \[DifferentialD]t\)\)\)\(\ \)\(\[IndentingNewLine]\
\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(\((\[ExponentialE]\^\(\[Pi]/2\)\ sin  \[Pi]\/2\  - \ \
\[ExponentialE]\^0\ sin\ 0)\)\ \  - \ \ \[Integral]\_0\%\(\[Pi]/2\)sin\ t\
\ \ \(\[ExponentialE]\^t\) \[DifferentialD]t\)\)\(\ \)\(\[IndentingNewLine]\)
      \(\ \)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(\((\(\[ExponentialE]\^\(\[Pi]/2\)\) 1 - 
              1*0)\)\ \  - \ \ \ \[Integral]\_0\%\(\[Pi]/2\)\ \(\
\[ExponentialE]\^t\) 
              sin\ t\ \ \[DifferentialD]t\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(\[ExponentialE]\^\(\[Pi]/2\)\ \  - \ \ \ \
\[Integral]\_0\%\(\[Pi]/2\)\ \(\[ExponentialE]\^t\) 
              sin\ t\ \ \[DifferentialD]t\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(\[ExponentialE]\^\(\[Pi]/2\)\ \  - \ \((\[ExponentialE]\^t\
\ \((\(-cos\)\ t)\))\)\( \[VerticalSeparator] \+\(t = 
                0\)\%\(t = \[Pi]/
                  2\)\)\ \ \(+\ \ \ \(\[Integral]\_0\%\(\[Pi]/2\)\((\(-\ 
                      cos\)\ t\ \[ExponentialE]\^t)\) \[DifferentialD]t\)\)\)\
\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(\[ExponentialE]\^\(\[Pi]/2\)\ \  + \ \((\[ExponentialE]\^t\
\ cos\ t)\)\( \[VerticalSeparator] \+\(t = 
                0\)\%\(t = \[Pi]/
                  2\)\)\ \ \(-\ \ \ \(\[Integral]\_0\%\(\[Pi]/2\)\ \(\
\[ExponentialE]\^t\) 
                cos\ t\ \ \[DifferentialD]t\)\)\)\)\(\ \
\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(\[ExponentialE]\^\(\[Pi]/2\)\ \  + \ \[ExponentialE]\^\(\
\[Pi]/2\)*0 - 
          1*1\ \  - \ \ \ \[Integral]\_0\%\(\[Pi]/2\)\ \(\[ExponentialE]\^t\) 
              cos\ t\ \ \[DifferentialD]t\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(=\)\(\ \ \)\(\[ExponentialE]\^\(\[Pi]/2\) - 
          1\ \  - \ \ \ \[Integral]\_0\%\(\[Pi]/2\)\ \(\[ExponentialE]\^t\) 
              cos\ t\ \ \(\(\[DifferentialD]t\)\(\ \)\)\)\)\)}]],
  "   "
}], "Text"],

Cell[TextData[{
  "Adding  ",
  Cell[BoxData[
      \(\[Integral]\_0\%\(\[Pi]/2\)\ \(\[ExponentialE]\^t\) 
          cos\ t\ \[DifferentialD]t\)]],
  "  to both sides of this equation and then dividing by ",
  StyleBox["2",
    FontFamily->"Courier New"],
  " gives  ",
  Cell[BoxData[
      \(\[Integral]\_0\%\(\[Pi]/2\)\ \[ExponentialE]\^t\ cos\ t\ \
\[DifferentialD]t\  = \ \(1\/2\) \((\[ExponentialE]\^\(\[Pi]/2\) - 1)\)\)]],
  ".  Likewise,  ",
  Cell[BoxData[
      \(\[ImaginaryI]\ \(\[Integral]\_0\%\(\[Pi]/2\)\[ExponentialE]\^t\ sin\ \
t\ \[DifferentialD]t\)\  = \ \[ImaginaryI]\ \(1\/2\) \((\[ExponentialE]\^\(\
\[Pi]/2\) + 1)\)\)]],
  ".  Therefore,  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_0\%\(\[Pi]/2\)\ \(\[ExponentialE]\^\(t + \[ImaginaryI]\ \
t\)\) \[DifferentialD]t\ \  = \ \ \(1\/2\) \((\[ExponentialE]\^\(\[Pi]\/2\) - 
                1)\)\  + \ \(\(\(\[ImaginaryI]\)\(\ \)\)\/2\) \((\
\[ExponentialE]\^\(\[Pi]\/2\) + 1)\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Method (i).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Expand the integrand f[t] into its real and imaginary parts, then \
integrate u[t] and v[t]."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[t, u, v, w];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, Int, ImInt, ImVal, ReInt, ReVal, 
        Val];\)\ \), "\[IndentingNewLine]", 
    \(\(w = \[ExponentialE]\^\(t\  + \ \[ImaginaryI]\ t\);\)\ \), "\n", 
    \(\(f[t_]\  = \ ComplexExpand[w];\)\ \), "\n", 
    \(\(u[t_]\  = \ ComplexExpand[Re[f[t]]];\)\ \), "\n", 
    \(\(v[t_]\  = \ ComplexExpand[Im[f[t]]];\)\ \), "\[IndentingNewLine]", 
    \(\(U[
          t_]\  = \ \[Integral]u[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(V[t_]\  = \ \[Integral]v[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(Int\  = \ 
        U[t]\  + \ \[ImaginaryI]\ V[t];\)\ \), "\[IndentingNewLine]", 
    \(\(ReVal\  = \ \ \[Integral]\_0\%\(\[Pi]/2\)u[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(ImVal\  = \ \ \[Integral]\_0\%\(\[Pi]/2\)v[
              t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(Val\  = \ ReVal\  + \ \[ImaginaryI]\ ImVal;\)\ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[t] = u[t] + \[ImaginaryI] v[t]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<u[t] = \>", u[t]];\)\ \), "\n", 
    \(\(Print["\<v[t] = \>", v[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<U[t] = \[Integral]u[t]\[DifferentialD]t = \>", 
        U[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<V[t] = \[Integral]v[t]\[DifferentialD]t = \>", 
        V[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<U[\!\(\[Pi]\/2\)] = \>\"", 
        U[\[Pi]\/2], "\<,   \>", \ "\<U[0] = \>", 
        U[0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<V[\!\(\[Pi]\/2\)] = \>\"", 
        V[\[Pi]\/2], "\<,   \>", "\<V[0] = \>", 
        V[0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \
\[Integral]v[t]\[DifferentialD]t = \>", Int];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\(\[Pi]/2\)\)\>\"", 
        w, \*"\"\<\[DifferentialD]t = \!\(\[Integral]\_0\%\(\[Pi]/2\)\)u[t]\
\[DifferentialD]t + \[ImaginaryI] \!\(\[Integral]\_0\%\(\[Pi]/2\)\)v[t]\
\[DifferentialD]t\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\(\[Pi]/2\)\)\>\"", 
        w, "\<\[DifferentialD]t = (U[1]-U[0]) + \[ImaginaryI](V[1]-V[0])\>"];\
\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\(\[Pi]/2\)\)\>\"", 
        w, "\<\[DifferentialD]t = \>", ReVal, "\< + \[ImaginaryI](\>", 
        ImVal, "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\(\[Pi]/2\)\)\>\"", 
        w, "\<\[DifferentialD]t = \>", Val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tComplex integrals have properties that are similar to those of real \
integrals.  We now trace through several commonalities.  Let  ",
  Cell[BoxData[
      \(f \((t)\) = u \((t)\) + \[ImaginaryI]\ v \((t)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(g \((t)\) = p \((t)\) + \[ImaginaryI]\ q \((t)\)\)]],
  "  be continuous on  ",
  Cell[BoxData[
      \(a\  \[LessEqual] \ t\  \[LessEqual] \ b\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Using Definition ",
  StyleBox["(6-1)",
    FontColor->RGBColor[0, 0, 1]],
  ", we can easily show that the integral of their sum is the sum of their \
integrals, that is\n\n",
  StyleBox["(6-3)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_a\%b\((f \((t)\) + 
                g \((t)\))\) \[DifferentialD]t\ \  = \ \ \[Integral]\_a\%b\ 
            f \((t)\) \[DifferentialD]t\ \  + \ \ \[Integral]\_a\%b\ 
            g \((t)\) \[DifferentialD]t\)]],
  ".  \n"
}], "Text"],

Cell[TextData[{
  "If we divide the interval  ",
  Cell[BoxData[
      \(a \[LessEqual] t \[LessEqual] b\)]],
  "  into  ",
  Cell[BoxData[
      \(a \[LessEqual] t \[LessEqual] c\)]],
  "  and  ",
  Cell[BoxData[
      \(c \[LessEqual] t \[LessEqual] b\)]],
  "  and integrate ",
  StyleBox["f(t)",
    FontFamily->"Courier New"],
  " over these subintervals by using ",
  StyleBox["(6-1)",
    FontColor->RGBColor[0, 0, 1]],
  ", then we get  \n\n",
  StyleBox["(6-4)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_a\%b\ 
          f \((t)\) \[DifferentialD]t\ \  = \ \ \[Integral]\_a\%c\ 
            f \((t)\) \[DifferentialD]t\ \  + \ \ \[Integral]\_c\%b\ 
            f \((t)\) \[DifferentialD]t\)]],
  ".  \n"
}], "Text"],

Cell[TextData[{
  "Similarly, if  ",
  Cell[BoxData[
      \(\[Alpha] + \[ImaginaryI]\ \[Beta]\)]],
  "  denotes a complex constant, then\n\n",
  StyleBox["(6-5)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_a\%b\((c + \[ImaginaryI]\ d)\) 
            f \((t)\) \[DifferentialD]t\ \  = \ \ \((c + \[ImaginaryI]\ d)\) \
\(\[Integral]\_a\%b\ \ f \((t)\) \[DifferentialD]t\)\)]],
  ".  \n"
}], "Text"],

Cell[TextData[{
  "If the limits of integration are reversed, then\n\n",
  StyleBox["(6-6)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_a\%b\ 
          f \((t)\) \[DifferentialD]t\ \  = \ \ \(-\ \(\[Integral]\_b\%a\ 
            f \((t)\) \[DifferentialD]t\)\)\)]],
  ".  \n"
}], "Text"],

Cell[TextData[{
  "The integral of the product ",
  StyleBox["f(t)g(t)",
    FontFamily->"Courier New"],
  " becomes\n\n",
  StyleBox["(6-7)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[{
      \(\[Integral]\_a\%b\ 
          f \((t)\) 
            g \((t)\) \[DifferentialD]t\ \  = \ \ \[Integral]\_a\%b\((u \((t)\
\) + \[ImaginaryI]\ v \((t)\))\) \((p \((t)\) + \[ImaginaryI]\ q \((t)\))\) \
\[DifferentialD]t\[IndentingNewLine]\ \), "\[IndentingNewLine]", 
      \(\ \(\(=\)\(\ \ \ \)\(\[Integral]\_a\%b\((u \((t)\)\ p \((t)\) - 
                  v \((t)\)\ q \((t)\))\) \[DifferentialD]t\ \  + \ \ \
\[ImaginaryI]\ \(\[Integral]\_a\%b\((u \((t)\)\ q \((t)\) + 
                    v \((t)\)\ p \((t)\))\) \[DifferentialD]t\)\)\)\)}]],
  "   \n"
}], "Text"],

Cell[TextData[{
  StyleBox["Example 6.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let us verify property ",
  StyleBox["(6-5)",
    FontColor->RGBColor[0, 0, 1]],
  ".  We start by writing \n\n\t\t\t",
  Cell[BoxData[{
      \(\ \(\(\((c + \[ImaginaryI]\ d)\) 
          f \((t)\)\ \  = \ \ \((c + \[ImaginaryI]\ d)\) \((u \((t)\) + \
\[ImaginaryI]\ v \((t)\))\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\
\)\(\ \ \)\(c\ u \((t)\) - 
          d\ v \((t)\)\ \  + \ \ \[ImaginaryI] \((c\ v \((t)\)\  + \ 
                d\ u \((t)\))\)\)\)\)}]],
  "  \n\nUsing Definition ",
  StyleBox["(6-1)",
    FontColor->RGBColor[0, 0, 1]],
  ", we write the left side of Equation ",
  StyleBox["(6-5)",
    FontColor->RGBColor[0, 0, 1]],
  " as  \n\n\t\t\t",
  Cell[BoxData[{
      \(\[Integral]\_a\%b\((c + \[ImaginaryI]\ d)\) \((u \((t)\) + \
\[ImaginaryI]\ v \((t)\))\) \[DifferentialD]t\ \ \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \ \)\(c\ \(\[Integral]\_a\%b\ 
              u \((t)\) \[DifferentialD]t\)\  - \ 
          d\ \(\[Integral]\_a\%b\ 
              v \((t)\) \[DifferentialD]t\)\ \  + \ \ \[ImaginaryI]\ c\ \(\
\[Integral]\_a\%b\ 
              v \((t)\) \[DifferentialD]t\)\  + \ \[ImaginaryI]\ d\ \(\
\[Integral]\_a\%b\ u \((t)\) \[DifferentialD]t\)\)\)\)}]],
  "  \n\nwhich is equivalent to  \n\n\t\t\t",
  Cell[BoxData[{
      \(\[Integral]\_a\%b\((c + \[ImaginaryI]\ d)\) \((u \((t)\) + \
\[ImaginaryI]\ v \((t)\))\) \[DifferentialD]t\ \ \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \ \)\(c\ \(\[Integral]\_a\%b\ 
              u \((t)\) \[DifferentialD]t\) + \ \[ImaginaryI]\ d\ \(\
\[Integral]\_a\%b\ 
              u \((t)\) \[DifferentialD]t\)\ \  + \ \ c\ \[ImaginaryI] \(\
\[Integral]\_a\%b\ 
              v \((t)\) \[DifferentialD]t\)\  + \[ImaginaryI]\ d\ \
\[ImaginaryI]\ \ \(\[Integral]\_a\%b\ 
              v \((t)\) \[DifferentialD]t\)\)\)\ \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \ \)\(\((c + \ \[ImaginaryI]\ d)\)\ \(\[Integral]\_a\%b\ 
              u \((t)\) \[DifferentialD]t\)\ \  + \ \ \((c + \[ImaginaryI]\ \
d)\)\ \[ImaginaryI]\ \(\[Integral]\_a\%b\ 
              v \((t)\) \[DifferentialD]t\)\)\)\ \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \ \)\(\((c + \ \[ImaginaryI]\ d)\) \((\ \[Integral]\_a\%b\ 
                u \((t)\) \[DifferentialD]t\  + \ \[ImaginaryI]\ \
\(\[Integral]\_a\%b\ v \((t)\) \[DifferentialD]t\)\ )\)\)\)\)}]],
  "   \n\nTherefore,  ",
  Cell[BoxData[
      \(\[Integral]\_a\%b\((c + \[ImaginaryI]\ d)\) 
            f \((t)\) \[DifferentialD]t\ \  = \ \ \((c + \[ImaginaryI]\ d)\) \
\(\[Integral]\_a\%b\ f \((t)\) \[DifferentialD]t\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[c, d, int1, int2, t, u, v];\)\ \), "\n", 
    \(\(int1\  = \[Integral]\((c\  + \ \[ImaginaryI]\ d)\) \((u[
                  t]\  + \ \[ImaginaryI]\ v[
                    t])\) \[DifferentialD]t;\)\ \), "\n", 
    \(\(int2\  = \ MapAll[Distribute, int1];\)\ \), "\n", 
    \(\(Print[int1, "\< = \>"];\)\ \), "\n", 
    \(\(Print[int2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tIt is worthwhile to point out the similarity between equation ",
  StyleBox["(6-2)",
    FontColor->RGBColor[0, 0, 1]],
  " and its counterpart in calculus.  Suppose that ",
  StyleBox["U",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["V",
    FontFamily->"Courier New"],
  " are differentiable on  ",
  Cell[BoxData[
      \(a < t < b\)]],
  "  \nand  ",
  Cell[BoxData[
      \(F \((t)\) = U \((t)\) + \[ImaginaryI]\ V \((t)\)\)]],
  ".  Since ",
  Cell[BoxData[
      \(F' \((t)\) = \(U' \((t)\) + \[ImaginaryI]\ V' \((t)\) = \(u \((t)\) + \
\[ImaginaryI]\ v \((t)\) = f \((t)\)\)\)\)]],
  ",  equation ",
  StyleBox["(6-2)",
    FontColor->RGBColor[0, 0, 1]],
  " takes on the familiar form \n\n",
  StyleBox["(6-8)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_a\%b\ 
          f \((t)\) \[DifferentialD]t\ \  = \ \ \(\(\(F \((t)\)\)\( | \_\(t = 
                  a\)\%\(t = b\)\)\)\ \  = \ \ F \((b)\) - F \((a)\)\)\)]],
  ".\n\t\t\t\nwhere ",
  Cell[BoxData[
      \(F' \((t)\) = f \((t)\)\)]],
  ".  We can view Equation ",
  StyleBox["(6-8)",
    FontColor->RGBColor[0, 0, 1]],
  " as an extension of the fundamental theorem of calculus.  In Section 6.5 \
we show how to generalize this extension to analytic functions of a complex \
variable.  For now, we simply note an important case of Equation ",
  StyleBox["(6-8)",
    FontColor->RGBColor[0, 0, 1]],
  ": \n\n",
  StyleBox["(6-9)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_a\%b\ f' \((t)\) \[DifferentialD]t\ \  = \ \ f \((b)\) - 
          f \((a)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 6.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Equation ",
  StyleBox["(6-8)",
    FontColor->RGBColor[0, 0, 1]],
  " to show that  ",
  Cell[BoxData[
      \(\[Integral]\_0\%\(\[Pi]/2\)\ \(\[ExponentialE]\^\(t + \[ImaginaryI]\ \
t\)\) \[DifferentialD]t\ \  = \ \ \(1\/2\) \((\[ExponentialE]\^\(\[Pi]/2\) - 
                1)\) + \(\(\(\[ImaginaryI]\)\(\ \)\)\/2\) \
\((\[ExponentialE]\^\(\[Pi]/2\) + 1)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We seek a function ",
  StyleBox["F",
    FontFamily->"Courier New"],
  " with the property that   ",
  Cell[BoxData[
      \(F' \((t)\) = \[ExponentialE]\^\(\((1 + \[ImaginaryI])\)\ t\)\)]],
  ".  We note that  ",
  Cell[BoxData[
      \(F \((t)\) = 
        1\/\(1 + \[ImaginaryI]\)\ \[ExponentialE]\^\(\((1 + \[ImaginaryI])\)\ \
t\)\)]],
  " satisfies this requirement, so \n\n\t\t\t",
  Cell[BoxData[{
      \(\[Integral]\_0\%\(\[Pi]/2\)\ \(\[ExponentialE]\^\(t + \[ImaginaryI]\ \
t\)\) \[DifferentialD]t\ \  = \ \ \(\(\((\ 
              1\/\(1 + \[ImaginaryI]\)\ \[ExponentialE]\^\(\((1 + \
\[ImaginaryI])\)\ t\))\)\( \[VerticalSeparator] \+\(t = 
                  0\)\%\(t = \[Pi]/
                    2\)\)\)\ \  = \ \ 1\/\(1 + \[ImaginaryI]\)\ \
\[ExponentialE]\^\(\((1 + \[ImaginaryI])\)\ \[Pi]/2\)\  - \ 
            1\/\(1 + \[ImaginaryI]\)\ \[ExponentialE]\^0\)\ \ \), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\
\(1\/\(1 + \[ImaginaryI]\)\ \(\[ExponentialE]\^\(\(\ \)\(\[Pi]/
                    2\)\)\) \[ExponentialE]\^\(\[ImaginaryI]\ \ \[Pi]/2\) - \ 
            1\/\(1 + \[ImaginaryI]\)\ \  = \ \ 1\/\(1 + \[ImaginaryI]\)\ \(\
\[ExponentialE]\^\(\(\ \)\(\[Pi]/2\)\)\) \[ImaginaryI]\  - \ 
            1\/\(1 + \[ImaginaryI]\)\)\)\ \ \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \ \
\)\(1\/\(1 + \[ImaginaryI]\)\ \((\[ImaginaryI]\ \[ExponentialE]\^\(\(\ \)\(\
\[Pi]/2\)\)\  - 
                1)\)\ \  = \ \ \(1\/2\) \((1 - \[ImaginaryI])\)\ \((\(-1\) + \
\[ImaginaryI]\ \[ExponentialE]\^\(\[Pi]/2\))\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \ \
\)\(1\/2\ \((\[ExponentialE]\^\(\[Pi]/2\) - 
                1)\) + \ \[ImaginaryI]\/2\ \((\ \[ExponentialE]\^\(\[Pi]/2\) \
+ 1)\)\)\)\)}]],
  "  \n\nwhich is the same result we obtained in Example 6.2, but with a lot \
less work."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 6.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "\n",
  StyleBox["Method (ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Compute the integral directly using a complex function for the \
integrand."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, val];\)\ \), "\[IndentingNewLine]", 
    \(\(f[
          t_] = \[ExponentialE]\^\(t\  + \ \[ImaginaryI]\ t\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(F[
          t_]\  = \ \[Integral]\(\[ExponentialE]\^\(t + \[ImaginaryI]\ t\)\) \
\[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(val\  = \ \[Integral]\_0\%\(\[Pi]/2\)f[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<F[t] = \[Integral]\>", f[t], "\<\[DifferentialD]t = \>", 
        F[t]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\(\[Pi]/2\)\)\>\"", 
        f[t], "\<\[DifferentialD]t = F[1] - F[0]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\(\[Pi]/2\)\)\>\"", 
        f[t], "\<\[DifferentialD]t = \>", F[1]\ , "\< - (\>", 
        F[0], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\(\[Pi]/2\)\)\>\"", 
        f[t], "\<\[DifferentialD]t = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\(\[Pi]/2\)\)\>\"", 
        f[t], "\<\[DifferentialD]t = \>", 
        ComplexExpand[val]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Which is the same result we obtained in Example 6.2, but with a lot less \
work.\
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark 6.1",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Example 6.4 illustrates the potential computational advantage we have \
when we lift our sights to the complex domain.  Using ordinary calculus \
techniques to evaluate ",
  Cell[BoxData[
      \(\[Integral]\_0\%\(\[Pi]/2\)\ \[ExponentialE]\^t\ cos\ t\
\ \ \[DifferentialD]t\)]],
  ", for example, required a lengthy integration by parts procedure (Example \
6.2).  When we recognize this expression as the real part of ",
  Cell[BoxData[
      \(\[Integral]\_0\%\(\[Pi]/2\)\ \(\[ExponentialE]\^\(t + \[ImaginaryI]\ \
t\)\) \[DifferentialD]t\)]],
  ", however, the solution comes quickly.  This is just one of the many \
reasons why good physicists and engineers, in addition to mathematicians, \
benefit from a thorough working knowledge of complex analysis."
}], "Text"],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Integral]\_0\%\[Pi]\ \(\[ExponentialE]\^\(\[ImaginaryI]\ t\)\) \
\[DifferentialD]t\  = \ 2  \[ImaginaryI]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution for Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell["\<\
Compute the integral directly using a complex function for the integrand.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[f, F, int, t, val];\)\ \), "\n", 
    \(\(f[
          t_]\  = \ \(\(\[ExponentialE]\)\(\ \)\)\^\(\[ImaginaryI]\ t\);\)\ \
\), "\n", 
    \(\(F[t_] = \[Integral]f[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(val\  = \ \[Integral]\_0\%\[Pi] f[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<F[t] = \[Integral]f[t]\[DifferentialD]t = \>", 
        F[t]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[\[Pi]] = \>", F[\[Pi]], "\<,  F[0] = \>", 
        F[0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\[Pi]\)f[t]\[DifferentialD]t = F[\
\[Pi]] - F[0]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\[Pi]\)f[t]\[DifferentialD]t = \
(\>\"", F[\[Pi]], "\<) - (\>", F[0], "\<) = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Complex Integral",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ComplexIntegralBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Contour Integrals",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ContourIntegralBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{923, 628},
WindowMargins->{{17, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 38971, 1034}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 120, 2, 33, "Text"],
Cell[2225, 66, 707, 12, 128, "Text"],
Cell[2935, 80, 112, 2, 33, "Text"],
Cell[3050, 84, 369, 7, 52, "Text",
  Evaluatable->False],
Cell[3422, 93, 148, 3, 33, "Text"],
Cell[3573, 98, 1341, 43, 91, "Text",
  Evaluatable->False],
Cell[4917, 143, 985, 30, 91, "Text",
  Evaluatable->False],
Cell[5905, 175, 309, 11, 36, "Text",
  Evaluatable->False],
Cell[6217, 188, 1824, 45, 278, "Text"],

Cell[CellGroupData[{
Cell[8066, 237, 111, 2, 33, "Text"],
Cell[8180, 241, 211, 6, 33, "Text"],
Cell[8394, 249, 2592, 49, 703, "Input"],
Cell[10989, 300, 243, 8, 33, "Text",
  Evaluatable->False],
Cell[11235, 310, 1109, 24, 320, "Input"]
}, Closed]],
Cell[12359, 337, 471, 13, 36, "Text",
  Evaluatable->False],
Cell[12833, 352, 932, 20, 113, "Text"],
Cell[13768, 374, 3064, 56, 397, "Text"],
Cell[16835, 432, 976, 24, 102, "Text"],

Cell[CellGroupData[{
Cell[17836, 460, 111, 2, 33, "Text"],
Cell[17950, 464, 259, 8, 33, "Text",
  Evaluatable->False],
Cell[18212, 474, 2971, 55, 786, "Input"]
}, Closed]],
Cell[21198, 532, 438, 12, 49, "Text"],
Cell[21639, 546, 533, 15, 91, "Text"],
Cell[22175, 563, 767, 26, 91, "Text"],
Cell[22945, 591, 438, 13, 91, "Text"],
Cell[23386, 606, 329, 10, 91, "Text"],
Cell[23718, 618, 780, 19, 132, "Text"],
Cell[24501, 639, 2904, 65, 464, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[27430, 708, 111, 2, 33, "Text"],
Cell[27544, 712, 443, 9, 143, "Input"]
}, Closed]],
Cell[28002, 724, 1655, 50, 184, "Text"],
Cell[29660, 776, 543, 16, 36, "Text",
  Evaluatable->False],
Cell[30206, 794, 2075, 42, 243, "Text"],

Cell[CellGroupData[{
Cell[32306, 840, 195, 7, 33, "Text"],
Cell[32504, 849, 251, 9, 52, "Text",
  Evaluatable->False],
Cell[32758, 860, 1365, 28, 354, "Input"],
Cell[34126, 890, 104, 3, 33, "Text"]
}, Closed]],
Cell[34245, 896, 877, 18, 89, "Text"],
Cell[35125, 916, 329, 11, 34, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[35479, 931, 211, 7, 33, "Text"],
Cell[35693, 940, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[35841, 946, 1011, 20, 323, "Input"]
}, Closed]],
Cell[36867, 969, 290, 7, 30, "Text"],
Cell[37160, 978, 317, 10, 33, "Text"],
Cell[37480, 990, 318, 10, 33, "Text"],
Cell[37801, 1002, 257, 5, 33, "Text"],
Cell[38061, 1009, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

