(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    265463,       6919]*)
(*NotebookOutlinePosition[    266602,       6959]*)
(*  CellTagsIndexPosition[    266525,       6953]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["6.2  Contours and Contour Integrals",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tIn Section 6.1 we learned how to evaluate integrals of the form  ",
  Cell[BoxData[
      \(\[Integral]\_a\%b\ f \((t)\) \[DifferentialD]t\)]],
  ",  where ",
  StyleBox["f(t)",
    FontFamily->"Courier New"],
  " was complex-valued and  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  "  was an interval on the real axis (so that ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " was real, with  ",
  Cell[BoxData[
      \(t \[Element] \([a, b]\)\)]],
  ").  In this section, we define and evaluate integrals of the form  ",
  Cell[BoxData[
      \(\[Integral]\_C\ f \((z)\)\ \[DifferentialD]z\)]],
  ",  where ",
  StyleBox["f(t)",
    FontFamily->"Courier New"],
  " is complex-valued and ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a contour in the plane (so that ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " is complex, with  ",
  Cell[BoxData[
      \(z \[Element] C\)]],
  ").  Our main result is Theorem 6.1, which shows how to transform the \
latter type of integral into the kind we investigated in Section 6.1. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tWe will use concepts first introduced in Section 1.6.  Recall that to \
represent a curve ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " we used the parametric notation\n\n",
  StyleBox["(6-10)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(C : \ z \((t)\) = \ x \((t)\) + \[ImaginaryI]\ y \((t)\)\)]],
  "  for ",
  Cell[BoxData[
      \(\(\(\ \)\(a \[LessEqual] t \[LessEqual] b\)\)\)]],
  ",\n\nwhere ",
  StyleBox["x(t)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["y(t)",
    FontFamily->"Courier New"],
  " are continuous functions.  We now place a few more restrictions on the \
type of curve to be described. The following discussion leads to the concept \
of a contour, which is a type of curve that is adequate for the study of \
integration."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tRecall that ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is simple if it does not cross itself, which means that  ",
  Cell[BoxData[
      \(z \((t\_1)\) \[NotEqual] z \((t\_2)\)\)]],
  "  whenever  ",
  Cell[BoxData[
      \(t\_1 \[NotEqual] t\_2\)]],
  ", except possibly when ",
  Cell[BoxData[
      \(t\_1 = a\)]],
  " and ",
  Cell[BoxData[
      \(t\_2 = b\)]],
  ".  A curve ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " with the property that ",
  Cell[BoxData[
      \(z \((a)\) = z \((b)\)\)]],
  "  is a closed curve.  If   ",
  Cell[BoxData[
      \(z \((a)\) = z \((b)\)\)]],
  "  is the only point of intersection, then we say that ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a simple closed curve.  As the parameter ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " increases from the value ",
  Cell[BoxData[
      \(t = a\)]],
  " to the value ",
  Cell[BoxData[
      \(t = b\)]],
  ", the point ",
  Cell[BoxData[
      \(z \((t)\)\)]],
  " starts at the initial point ",
  Cell[BoxData[
      \(z \((a)\)\)]],
  ", moves along the curve ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " , and ends up at the terminal point ",
  Cell[BoxData[
      \(z \((b)\)\)]],
  ". If ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is simple, then ",
  Cell[BoxData[
      \(z \((t)\)\)]],
  " moves continuously from ",
  Cell[BoxData[
      \(z \((a)\)\)]],
  " to ",
  Cell[BoxData[
      \(z \((b)\)\)]],
  " as ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " increases and the curve is given an orientation, which we indicate by \
drawing arrows along the curve.  Figure 6.1 illustrates how the terms simple \
and closed describe a curve."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.1",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0601.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The terms simple and closed used to describe curves."
}], "Text"],

Cell[TextData[{
  "\tThe complex-valued function  ",
  Cell[BoxData[
      \(z \((t)\) = \ x \((t)\) + \[ImaginaryI]\ y \((t)\)\)]],
  "  is said to be differentiable on ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  " if both ",
  Cell[BoxData[
      \(x \((t)\)\)]],
  " and ",
  Cell[BoxData[
      \(y \((t)\)\)]],
  " are differentiable for ",
  Cell[BoxData[
      \(\(\(\ \)\(a \[LessEqual] t \[LessEqual] b\)\)\)]],
  ".  Here we require the one-sided derivatives of ",
  Cell[BoxData[
      \(x \((t)\)\)]],
  " and ",
  Cell[BoxData[
      \(y \((t)\)\)]],
  " to exist at the endpoints of the interval.  As in Section 6.1, the \
derivative ",
  Cell[BoxData[
      \(z' \((t)\)\)]],
  " is \n\n\t\t\t",
  Cell[BoxData[
      \(z' \((t)\)\  = \ \ x' \((t)\) + \[ImaginaryI]\ y' \((t)\)\)]],
  "   for   ",
  Cell[BoxData[
      \(\(\(\ \)\(a \[LessEqual] t \[LessEqual] b\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe curve ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " defined by Equation ",
  StyleBox["(6-10)",
    FontColor->RGBColor[0, 0, 1]],
  " is said to be a smooth curve if ",
  Cell[BoxData[
      \(z' \((t)\)\)]],
  " is continuous and nonzero on the interval.  If ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a smooth curve, then ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " has a nonzero tangent vector at each point ",
  Cell[BoxData[
      \(z \((t)\)\)]],
  ", which is given by the vector ",
  Cell[BoxData[
      \(z' \((t)\)\)]],
  ".  If  ",
  Cell[BoxData[
      \(x' \((t\_0)\) = 0\)]],
  ",  then the tangent vector  ",
  Cell[BoxData[
      \(z' \((t\_0)\) = \[ImaginaryI]\ y' \((t\_0)\)\)]],
  "  is vertical.  If  ",
  Cell[BoxData[
      \(x' \((t\_0)\) \[NotEqual] 0\)]],
  ",  then the slope ",
  Cell[BoxData[
      \(dy\/dx\)]],
  " of the tangent line to ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " at the point ",
  Cell[BoxData[
      \(z \((t\_0)\)\)]],
  " is given by ",
  Cell[BoxData[
      \(\(y' \((t\_0)\)\)\/\(x' \((t\_0)\)\)\)]],
  ".  Hence for a smooth curve the angle of inclination ",
  Cell[BoxData[
      \(\[Theta] \((t)\)\)]],
  " of its tangent vector ",
  Cell[BoxData[
      \(z' \((t)\)\)]],
  " is defined for all values of ",
  Cell[BoxData[
      \(t \[Element] \([a, b]\)\)]],
  " and is continuous.  Thus a smooth curve has no corners or cusps.  Figure \
6.2 illustrates this concept."
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.2",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0602.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The term smooth used to describe curves."
}], "Text"],

Cell[TextData[{
  "\tIf ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a smooth curve, then ",
  Cell[BoxData[
      \(\[DifferentialD]s\)]],
  ", the differential of arc length, is given by  \n\n\t\t\t",
  Cell[BoxData[
      \(\[DifferentialD]s\  = \ \(\(\@\(\([x' \((t)\)]\)\^2 + \([y' \
\((t)\)]\)\^2\)\) \[DifferentialD]t\  = \ \(\(|\)\(z' \((t)\)\)\(|\)\(\
\[DifferentialD]t\)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe function  ",
  Cell[BoxData[
      \(s \((t)\)\  = \ \@\(\([x' \((t)\)]\)\^2 + \([y' \((t)\)]\)\^2\)\)]],
  "  is continuous, as ",
  Cell[BoxData[
      \(x' \((t)\)\)]],
  " and ",
  Cell[BoxData[
      \(y' \((t)\)\)]],
  " are continuous functions, so the ",
  StyleBox[ButtonBox["length",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ArcLength.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " ",
  Cell[BoxData[
      \(L \((C)\)\)]],
  " of the curve ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is  \n\n",
  StyleBox["(6-11)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(L \((C)\)\  = \ \(\[Integral]\_a\%b\ \(\@\(\([x' \((t)\)]\)\^2 + \
\([y' \((t)\)]\)\^2\)\) \[DifferentialD]t\  = \ \[Integral]\_a\%b\ \
\(\(|\)\(z' \((t)\)\)\(|\)\(\[DifferentialD]t\)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tNow consider ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " to be a curve with parameterization  \n\n\t\t\t",
  Cell[BoxData[
      \(C : \ \(z\_1\) \((t)\) = \ x \((t)\) + \[ImaginaryI]\ y \((t)\)\)]],
  "   for   ",
  Cell[BoxData[
      \(a \[LessEqual] t \[LessEqual] b\)]],
  ".  \n\n\tThe opposite curve",
  StyleBox[" ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " ",
  Cell[BoxData[
      \(\(-C\)\)]],
  "  traces out the same set of points in the plane, but in the reverse \
order, and has the parametrization  \n\n\t\t\t",
  Cell[BoxData[
      \(\(-\(C : \ \(z\_2\) \((t)\)\)\) = \ 
        x \((\(-t\))\) + \[ImaginaryI]\ y \((\(-t\))\)\)]],
  "   for   ",
  Cell[BoxData[
      \(a \[LessEqual] t \[LessEqual] b\)]],
  ".  \n\nSince  ",
  Cell[BoxData[
      \(\(z\_2\) \((t)\) = \(z\_1\) \((\(-t\))\)\)]],
  ",  ",
  Cell[BoxData[
      \(\(-C\)\)]],
  "  is merely ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " traversed in the opposite sense, as illustrated in Figure 6.3.  "
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.3",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0603.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The curve  ",
  Cell[BoxData[
      \(C\)]],
  "  and its opposite curve  ",
  Cell[BoxData[
      \(\(-C\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tA curve ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " that is constructed by joining finitely many smooth curves end to end is \
called a ",
  StyleBox[ButtonBox["contour",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Contour.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ".  Let  ",
  Cell[BoxData[
      RowBox[{\(C\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(C\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(C\_n\)}]]],
  "  denote ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " smooth curves such that the terminal point of the curve  ",
  Cell[BoxData[
      \(C\_k\)]],
  "  coincides with the initial point of  ",
  Cell[BoxData[
      \(C\_\(k + 1\)\)]],
  "  for  ",
  Cell[BoxData[
      RowBox[{\(k = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(n - 1\)}]]],
  ".  We express the contour C by the equation\n\n\t\t\t",
  Cell[BoxData[
      \(C = \(C\_1 + C\_2 +  ... \) + C\_n\)]],
  ".\n\nA synonym for contour is path.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 6.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find a parameterization of the polygonal path  ",
  Cell[BoxData[
      \(C = C\_1 + C\_2 + C\_3\)]],
  "  from  ",
  Cell[BoxData[
      RowBox[{\(-1\), "+", 
        RowBox[{"\[ImaginaryI]", "  ", 
          StyleBox["to",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", "3"}], "-", "\[ImaginaryI]"}]]],
  "  shown in Figure 6.4.\nHere  ",
  Cell[BoxData[
      \(C\_1\)]],
  "  is the line from  ",
  Cell[BoxData[
      RowBox[{\(-1\), "+", 
        RowBox[{"\[ImaginaryI]", "  ", 
          StyleBox["to",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], "  ", "-", "1"}]]],
  ",  ",
  Cell[BoxData[
      \(C\_2\)]],
  "  is the line from  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(-1\), "  ", 
          StyleBox["to",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", "1"}], "+", "\[ImaginaryI]"}]]],
  ",  and  ",
  Cell[BoxData[
      \(C\_3\)]],
  "  is the line from  ",
  Cell[BoxData[
      RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", "  ", 
          StyleBox["to",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", "3"}], "-", "\[ImaginaryI]"}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.238095 0.309017 0.294302 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 10 6.28125 ]
[.2494 .01472 -12 -4.5 ]
[.2494 .01472 0 4.5 ]
[.2494 .60332 -6 -4.5 ]
[.2494 .60332 0 4.5 ]
[.2619 .64303 -5 0 ]
[.2619 .64303 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(2)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.2619 .01472 m
.26815 .01472 L
s
[(-1)] .2494 .01472 1 0 Mshowa
.2619 .60332 m
.26815 .60332 L
s
[(1)] .2494 .60332 1 0 Mshowa
.2619 0 m
.2619 .61803 L
s
gsave
.2619 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02381 .59138 L
.02381 .57836 L
.02381 .56613 L
.02381 .55437 L
.02381 .54185 L
.02381 .5298 L
.02381 .517 L
.02381 .50466 L
.02381 .49279 L
.02381 .48016 L
.02381 .468 L
.02381 .45631 L
.02381 .44386 L
.02381 .43188 L
.02381 .41914 L
.02381 .40687 L
.02381 .39506 L
.02381 .3825 L
.02381 .37041 L
.02381 .35756 L
.02381 .34518 L
.02381 .33327 L
.02381 .3206 L
.02381 .30902 L
s
0 0 1 r
.02381 .30902 m
.04313 .32096 L
.06419 .33398 L
.08398 .3462 L
.10301 .35796 L
.12326 .37048 L
.14276 .38253 L
.16348 .39534 L
.18345 .40768 L
.20265 .41955 L
.22309 .43218 L
.24276 .44434 L
.26168 .45603 L
.28182 .46848 L
.30121 .48046 L
.32182 .4932 L
.34168 .50547 L
.36077 .51727 L
.3811 .52983 L
.40066 .54192 L
.42145 .55477 L
.44149 .56715 L
.46076 .57907 L
.48126 .59174 L
.5 .60332 L
s
0 1 0 r
.5 .60332 m
.51932 .57944 L
.54039 .5534 L
.56017 .52894 L
.5792 .50542 L
.59945 .48039 L
.61895 .45629 L
.63967 .43067 L
.65964 .406 L
.67884 .38225 L
.69928 .357 L
.71895 .33268 L
.73787 .30929 L
.75801 .2844 L
.7774 .26043 L
.79801 .23495 L
.81787 .21041 L
.83696 .18681 L
.85729 .16169 L
.87685 .13751 L
.89764 .11181 L
.91768 .08704 L
.93695 .06322 L
.95745 .03788 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oBP3oool0
0`000000oooo0?ooo`3C0?ooo`00BP3oool00`000000oooo0?ooo`3C0?ooo`00@P3oool5000000<0
oooo00<000000?ooo`3oool0d`3oool004@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`3C0?ooo`00A03oool00`000000oooo0?ooo`030?ooo`<00000/`3oool00`00o`00oooo0?oo
o`0M0?ooo`00?03oool4000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2b
0?ooo`03003o003oool0oooo01h0oooo00140?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0/@3oool00`00o`00oooo0?ooo`0O0?ooo`00@`3oool2000000D0oooo00<000000?ooo`3o
ool0/03oool00`00o`00oooo0?ooo`0P0?ooo`00BP3oool00`000000oooo0?ooo`2`0?ooo`03003o
003oool0oooo0200oooo001:0?ooo`030000003oool0oooo0:l0oooo00<00?l00?ooo`3oool08@3o
ool004X0oooo00<000000?ooo`3oool0[P3oool00`00o`00oooo0?ooo`0R0?ooo`00BP3oool00`00
0000oooo0?ooo`2]0?ooo`03003o003oool0oooo02<0oooo001:0?ooo`030000003oool0oooo0:`0
oooo00<00?l00?ooo`3oool0903oool004X0oooo00<000000?ooo`3oool0Z`3oool00`00o`00oooo
0?ooo`0U0?ooo`00BP3oool00`000000oooo0?ooo`2[0?ooo`03003o003oool0oooo02D0oooo001:
0?ooo`030000003oool0oooo0:X0oooo00<00?l00?ooo`3oool09P3oool004X0oooo00<000000?oo
o`3oool0Z@3oool00`00o`00oooo0?ooo`0W0?ooo`00BP3oool00`000000oooo0?ooo`2X0?ooo`03
003o003oool0oooo02P0oooo001:0?ooo`030000003oool0oooo0:L0oooo00<00?l00?ooo`3oool0
:@3oool004X0oooo00<000000?ooo`3oool0YP3oool00`00o`00oooo0?ooo`0Z0?ooo`00BP3oool0
0`000000oooo0?ooo`2V0?ooo`03003o003oool0oooo02X0oooo001:0?ooo`030000003oool0oooo
0:D0oooo00<00?l00?ooo`3oool0:`3oool004X0oooo00<000000?ooo`3oool0Y03oool00`00o`00
oooo0?ooo`0/0?ooo`00BP3oool00`000000oooo0?ooo`2S0?ooo`03003o003oool0oooo02d0oooo
001:0?ooo`030000003oool0oooo0:<0oooo00<00?l00?ooo`3oool0;@3oool004X0oooo00<00000
0?ooo`3oool0XP3oool00`00o`00oooo0?ooo`0^0?ooo`00BP3oool00`000000oooo0?ooo`2Q0?oo
o`03003o003oool0oooo02l0oooo001:0?ooo`030000003oool0oooo0:00oooo00<00?l00?ooo`3o
ool0<03oool004X0oooo00<000000?ooo`3oool0X03oool00`00o`00oooo0?ooo`0`0?ooo`00BP3o
ool00`000000oooo0?ooo`2O0?ooo`03003o003oool0oooo0340oooo001:0?ooo`030000003oool0
oooo09h0oooo00<00?l00?ooo`3oool0<P3oool004X0oooo00<000000?ooo`3oool0W@3oool00`00
o`00oooo0?ooo`0c0?ooo`00BP3oool00`000000oooo0?ooo`2L0?ooo`03003o003oool0oooo03@0
oooo001:0?ooo`030000003oool0oooo09`0oooo00<00?l00?ooo`3oool0=03oool004X0oooo00<0
00000?ooo`3oool0V`3oool00`00o`00oooo0?ooo`0e0?ooo`00BP3oool00`000000oooo0?ooo`2J
0?ooo`03003o003oool0oooo03H0oooo001:0?ooo`030000003oool0oooo09T0oooo00<00?l00?oo
o`3oool0=`3oool004X0oooo00<000000?ooo`3oool0V03oool00`00o`00oooo0?ooo`0h0?ooo`00
BP3oool00`000000oooo0?ooo`2G0?ooo`03003o003oool0oooo03T0oooo001:0?ooo`030000003o
ool0oooo09L0oooo00<00?l00?ooo`3oool0>@3oool004X0oooo00<000000?ooo`3oool0UP3oool0
0`00o`00oooo0?ooo`0j0?ooo`00BP3oool00`000000oooo0?ooo`2E0?ooo`03003o003oool0oooo
03/0oooo001:0?ooo`030000003oool0oooo09@0oooo00<00?l00?ooo`3oool0?03oool004X0oooo
00<000000?ooo`3oool0U03oool00`00o`00oooo0?ooo`0l0?ooo`00BP3oool00`000000oooo0?oo
o`2C0?ooo`03003o003oool0oooo03d0oooo001:0?ooo`030000003oool0oooo0980oooo00<00?l0
0?ooo`3oool0?P3oool004X0oooo00<000000?ooo`3oool0T@3oool00`00o`00oooo0?ooo`0o0?oo
o`00BP3oool00`000000oooo0?ooo`2A0?ooo`03003o003oool0oooo03l0oooo001:0?ooo`030000
003oool0oooo0900oooo00<00?l00?ooo`3oool0@03oool004X0oooo00<000000?ooo`3oool0S`3o
ool00`00o`00oooo0?ooo`110?ooo`00BP3oool00`000000oooo0?ooo`2>0?ooo`03003o003oool0
oooo0480oooo001:0?ooo`030000003oool0oooo08d0oooo00<00?l00?ooo`3oool0@`3oool004X0
oooo00<000000?ooo`3oool0S@3oool00`00o`00oooo0?ooo`130?ooo`00BP3oool00`000000oooo
0?ooo`2<0?ooo`03003o003oool0oooo04@0oooo001:0?ooo`030000003oool0oooo08/0oooo00<0
0?l00?ooo`3oool0A@3oool004X0oooo00<000000?ooo`3oool0RP3oool00`00o`00oooo0?ooo`16
0?ooo`00BP3oool00`000000oooo0?ooo`290?ooo`03003o003oool0oooo04L0oooo001:0?ooo`03
0000003oool0oooo08P0oooo00<00?l00?ooo`3oool0B03oool004X0oooo00<000000?ooo`3oool0
R03oool00`00o`00oooo0?ooo`180?ooo`00BP3oool00`000000oooo0?ooo`270?ooo`03003o003o
ool0oooo04T0oooo001:0?ooo`030000003oool0oooo08H0oooo00<00?l00?ooo`3oool0BP3oool0
04X0oooo00<000000?ooo`3oool0Q@3oool00`00o`00oooo0?ooo`1;0?ooo`00BP3oool00`000000
oooo0?ooo`240?ooo`03003o003oool0oooo04`0oooo001:0?ooo`030000003oool0oooo08<0oooo
00<00?l00?ooo`3oool0C@3oool004X0oooo00<000000?ooo`3oool0P`3oool00`00o`00oooo0?oo
o`1=0?ooo`00BP3oool00`000000oooo0?ooo`220?ooo`03003o003oool0oooo04h0oooo001:0?oo
o`030000003oool0oooo0840oooo00<00?l00?ooo`3oool0C`3oool004X0oooo00<000000?ooo`3o
ool0P03oool00`00o`00oooo0?ooo`1@0?ooo`003`3oool5000003H0oooo00<000000?ooo`3oool0
>03oool5000003L0oooo100000070?ooo`03003o003oool0oooo0300oooo0P00000O0?ooo`004@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`070?ooo`03003o003oool0oooo0300oooo00@000000?ooo`3oool00000
7P3oool00140oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0c0?ooo`030000003o
ool0oooo01d0oooo00090?ooo`@00000103oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`040?ooo`03003o003oool0
oooo03@0oooo00<000000?ooo`3oool0703oool00140oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo03L0oooo00@000000?ooo`3oool00000103oool0
0`00o`00oooo0?ooo`0b0?ooo`040000003oool0oooo000001h0oooo000@0?ooo`800000>03oool0
0`000000oooo0?ooo`0i0?ooo`800000>P3oool2000000@0oooo00<00?l00?ooo`3oool0=03oool2
000001l0oooo001:0?ooo`030000003oool0oooo07X0oooo00<00?l00?ooo`3oool0EP3oool004X0
oooo00<000000?ooo`3oool0N@3oool00`00o`00oooo0?ooo`1G0?ooo`00BP3oool00`000000oooo
0?ooo`1h0?ooo`03003o003oool0oooo05P0oooo001:0?ooo`030000003oool0oooo07P0oooo00<0
0?l00?ooo`3oool0AP3oool2000000030?ooo`000000000000d0oooo001:0?ooo`030000003oool0
oooo07L0oooo00<00?l00?ooo`3oool0B03oool00`000000oooo0000000>0?ooo`00203oool60000
00030000o`00000000000;80000000<00?l0000000000000@@0000090?ooo`030000003oool0oooo
00d0oooo000>0?ooo`030?l000000?l0003o03T0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0h0?ooo`03003o00000000oooo03/0oooo00<000000?ooo`3oool02`3oool200000003
0?ooo`000000000000d0oooo000>0?ooo`030?l0003oool0oooo0080003o=`3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo03P0oooo00<00?l00000003oool0>`3oool00`000000oooo
0?ooo`0M0?ooo`003P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo03@0oooo00<0
00000?ooo`3oool0M03oool00`00o`00oooo0?ooo`1L0?ooo`003P3oool00`3o0000oooo0?ooo`03
0?ooo`80003o=03oool00`000000oooo0?ooo`1c0?ooo`03003o003oool0oooo05d0oooo000>0?oo
o`030?l0003oool0oooo00D0oooo0P000?lb0?ooo`030000003oool0oooo07<0oooo00<00?l00?oo
o`3oool0G@3oool000h0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0_0?ooo`03
0000003oool0oooo0780oooo00<00?l00?ooo`3oool0GP3oool000h0oooo00<0o`000?ooo`3oool0
203oool20000obl0oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`1O0?ooo`003P3o
ool00`3o0000oooo0?ooo`0:0?ooo`80003o;@3oool00`000000oooo0?ooo`1`0?ooo`03003o003o
ool0oooo0600oooo000>0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0:P3oool0
0`000000oooo0?ooo`1_0?ooo`03003o003oool0oooo0640oooo000>0?ooo`030?l0003oool0oooo
00d0oooo0P000?lZ0?ooo`030000003oool0oooo06l0oooo00<00?l00?ooo`3oool0H@3oool000h0
oooo00<0o`000?ooo`3oool03`3oool20000obP0oooo00<000000?ooo`3oool0KP3oool00`00o`00
oooo0?ooo`1R0?ooo`003P3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo02D0oooo
00<000000?ooo`3oool0K@3oool00`00o`00oooo0?ooo`1S0?ooo`003P3oool00`3o0000oooo0?oo
o`0B0?ooo`030000o`3oool0oooo02@0oooo00<000000?ooo`3oool0K03oool00`00o`00oooo0?oo
o`1T0?ooo`003P3oool00`3o0000oooo0?ooo`0C0?ooo`80003o903oool00`000000oooo0?ooo`1[
0?ooo`03003o003oool0oooo06D0oooo000>0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?oo
o`3oool08@3oool00`000000oooo0?ooo`1Z0?ooo`03003o003oool0oooo06H0oooo000>0?ooo`03
0?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`1Z0?ooo`03
003o003oool0oooo06H0oooo000>0?ooo`030?l0003oool0oooo01L0oooo0P000?lP0?ooo`030000
003oool0oooo06T0oooo00<00?l00?ooo`3oool0I`3oool000h0oooo00<0o`000?ooo`3oool06@3o
ool20000oah0oooo00<000000?ooo`3oool0J03oool00`00o`00oooo0?ooo`1X0?ooo`003P3oool0
0`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo01/0oooo00<000000?ooo`3oool0I`3oool0
0`00o`00oooo0?ooo`1Y0?ooo`003P3oool00`3o0000oooo0?ooo`0L0?ooo`80003o6`3oool00`00
0000oooo0?ooo`1V0?ooo`03003o003oool0oooo06X0oooo000>0?ooo`030?l0003oool0oooo01h0
oooo0P000?lI0?ooo`030000003oool0oooo06D0oooo00<00?l00?ooo`3oool0J`3oool000h0oooo
00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo06@0oooo
00<00?l00?ooo`3oool0K03oool000h0oooo00<0o`000?ooo`3oool08@3oool20000oaH0oooo00<0
00000?ooo`3oool0I03oool00`00o`00oooo0?ooo`1/0?ooo`003P3oool00`3o0000oooo0?ooo`0S
0?ooo`80003o503oool00`000000oooo0?ooo`1S0?ooo`03003o003oool0oooo06d0oooo000>0?oo
o`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool04@3oool00`000000oooo0?ooo`1R0?oo
o`03003o003oool0oooo06h0oooo000>0?ooo`030?l0003oool0oooo02H0oooo0P000?lA0?ooo`03
0000003oool0oooo0640oooo00<00?l00?ooo`3oool0K`3oool000h0oooo00<0o`000?ooo`3oool0
:03oool20000o`l0oooo00<000000?ooo`3oool0H03oool00`00o`00oooo0?ooo`1`0?ooo`003P3o
ool00`3o0000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0G`3o
ool00`00o`00oooo0?ooo`1a0?ooo`003P3oool00`3o0000oooo0?ooo`0[0?ooo`80003o303oool0
0`000000oooo0?ooo`1O0?ooo`03003o003oool0oooo0740oooo000>0?ooo`030?l0003oool0oooo
02d0oooo0P000?l:0?ooo`030000003oool0oooo05h0oooo00<00?l00?ooo`3oool0LP3oool000h0
oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`070?ooo`030000003oool0oooo05d0
oooo00<00?l00?ooo`3oool0L`3oool000h0oooo00<0o`000?ooo`3oool0<03oool20000o`L0oooo
00<000000?ooo`3oool0G03oool00`00o`00oooo0?ooo`1d0?ooo`003P3oool00`3o0000oooo0?oo
o`0b0?ooo`80003o1@3oool00`000000oooo0?ooo`1K0?ooo`03003o003oool0oooo07D0oooo000>
0?ooo`030?l0003oool0oooo03@0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`1J
0?ooo`03003o003oool0oooo07H0oooo000>0?ooo`030?l0003oool0oooo03D0oooo0P000?l20?oo
o`030000003oool0oooo05X0oooo00<00?l00?ooo`3oool0MP3oool000h0oooo00<0o`000?ooo`3o
ool0=`3oool20000o`030000003oool0oooo05T0oooo00<00?l00?ooo`3oool0M`3oool000h0oooo
00<0o`000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`1H0?ooo`03003o003oool0oooo07P0oooo
000>0?ooo`030?l0003oool0oooo03T0oooo00<000000000o`3oool0E`3oool00`00o`00oooo0?oo
o`1i0?ooo`003P3oool00`3o0000oooo0?ooo`0i0?ooo`040000003oool0003o0000oeH0oooo00<0
0?l00?ooo`3oool0N@3oool000h0oooo00<0o`000?ooo`3oool0>@3oool01@000000oooo0?ooo`3o
ool0003o05@0oooo00<00?l00?ooo`3oool0NP3oool000h0oooo00<0o`000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`020?ooo`030000o`3oool0oooo0500oooo00<00?l00?ooo`3oool0N`3oool0
00h0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`030?ooo`80003oC`3oool00`00
o`00oooo0?ooo`1l0?ooo`003P3oool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo00D0
oooo0P000?m=0?ooo`03003o003oool0oooo07`0oooo000>0?ooo`030?l0003oool0oooo03T0oooo
00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`190?ooo`03003o003oool0oooo07d0oooo
000>0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool0203oool20000odP0oooo00<0
0?l00?ooo`3oool0OP3oool000h0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`0:
0?ooo`80003oA@3oool00`00o`00oooo0?ooo`1o0?ooo`003P3oool00`3o0000oooo0?ooo`0i0?oo
o`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool0@@3oool00`00o`00oooo0?ooo`200?oo
o`003P3oool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo00d0oooo0P000?m10?ooo`03
003o003oool0oooo0800oooo000>0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool0
3`3oool20000och0oooo00<00?l00?ooo`3oool0P@3oool000h0oooo00<0o`000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0A0?ooo`80003o>`3oool00`00o`00oooo0?ooo`220?ooo`003P3oool0
0`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo01<0oooo00<0003o0?ooo`3oool0=`3oool0
0`00o`00oooo0?ooo`230?ooo`003P3oool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo
01@0oooo0P000?lf0?ooo`03003o003oool0oooo08@0oooo000>0?ooo`030?l0003oool0oooo03T0
oooo00<000000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0b0?ooo`03003o003oool0oooo08D0
oooo000>0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool05`3oool20000oc80oooo
00<00?l00?ooo`3oool0Q@3oool000h0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?oo
o`0I0?ooo`80003o;`3oool00`00o`00oooo0?ooo`260?ooo`003P3oool00`3o0000oooo0?ooo`0i
0?ooo`030000003oool0oooo01/0oooo0P000?l/0?ooo`03003o003oool0oooo08L0oooo000>0?oo
o`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool07@3oool20000obT0oooo00<00?l00?oo
o`3oool0R03oool000h0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`0O0?ooo`80
003o9P3oool00`00o`00oooo0?ooo`290?ooo`003P3oool00`3o0000oooo0?ooo`0i0?ooo`030000
003oool0oooo0240oooo00<0003o0?ooo`3oool08P3oool00`00o`00oooo0?ooo`2:0?ooo`003P3o
ool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo0280oooo0P000?lR0?ooo`03003o003o
ool0oooo08X0oooo000>0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool0903oool2
0000oal0oooo00<00?l00?ooo`3oool0R`3oool000h0oooo00<0o`000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0V0?ooo`030000o`3oool0oooo01/0oooo00<00?l00?ooo`3oool0S03oool000h0
oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo01T0
oooo00<00?l00?ooo`3oool0S@3oool000h0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0X0?ooo`80003o6@3oool00`00o`00oooo0?ooo`2=0?ooo`003P3oool00`3o0000oooo0?oo
o`0i0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool05@3oool00`00o`00oooo0?oo
o`2>0?ooo`003P3oool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo02/0oooo00<0003o
0?ooo`3oool04`3oool00`00o`00oooo0?ooo`2?0?ooo`003P3oool00`3o0000oooo0?ooo`0i0?oo
o`030000003oool0oooo02`0oooo0P000?lB0?ooo`03003o003oool0oooo0900oooo000>0?ooo`03
0?l0003oool0oooo03T0oooo00<000000?ooo`3oool0;P3oool20000oa00oooo00<00?l00?ooo`3o
ool0T03oool000h0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`0`0?ooo`030000
o`3oool0oooo00`0oooo00<00?l00?ooo`3oool0T@3oool000h0oooo00<0o`000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0a0?ooo`80003o2`3oool00`00o`00oooo0?ooo`2B0?ooo`003P3oool0
0`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo03<0oooo0P000?l80?ooo`03003o003oool0
oooo09<0oooo000>0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool0=@3oool00`00
0?l0oooo0?ooo`040?ooo`03003o003oool0oooo09@0oooo000>0?ooo`030?l0003oool0oooo0340
oooo1@0000030?ooo`030000003oool0oooo03H0oooo0P000?l40?ooo`03003o003oool0oooo09@0
oooo000>0?ooo`030?l0003oool0oooo03<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0h0?ooo`80003o00<0oooo003o003oool0UP3oool000h0oooo00<0o`000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`030?ooo`<00000>P3oool00`00o`00oooo0?ooo`2F0?ooo`00A03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0=<0oooo00140?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0d`3oool004<0oooo0P0000050?ooo`030000003oool0oooo0=<0
oooo001:0?ooo`030000003oool0oooo0=<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo00180?ooo`800000eP3oool004T0oooo00<000000?ooo`3oool0e03oool004X0oooo00<0
00000?ooo`3oool0d`3oool004T0oooo00<000000?ooo`000000e03oool004P0oooo00@000000?oo
o`3oool00000e03oool004L0oooo0`0000000`3oool000000000003C0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1, -1, 0, 0}}],
  StyleBox["    \n\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.4",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0604.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The polygonal path ",
  Cell[BoxData[
      \(C = C\_1 + C\_2 + C\_3\)]],
  " from  ",
  Cell[BoxData[
      RowBox[{\(-1\), "+", 
        RowBox[{"\[ImaginaryI]", "  ", 
          StyleBox["to",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", "3"}], "-", "\[ImaginaryI]"}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Solution.  We express ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " as three smooth curves, or  ",
  Cell[BoxData[
      \(C = C\_1 + C\_2 + C\_3\)]],
  ".  If we set  ",
  Cell[BoxData[
      \(z\_0 = \(-1\) + \[ImaginaryI]\)]],
  "  and  ",
  Cell[BoxData[
      \(z\_1 = \(-1\)\)]],
  ",  we can use Equation ",
  StyleBox["(1-48)",
    FontColor->RGBColor[0, 0, 1],
    Background->None],
  " to get a formula for the straight-line segment joining two points:  \n\n\t\
\t\t",
  Cell[BoxData[
      \(\(C\_1\) : \ \ \(z\_1\) \((t)\)\ \  = \ \ \(z\_0\  + \ 
            t \((z\_1 - z\_0)\)\ \  = \ \ \((\(-1\) + \[ImaginaryI])\)\  + \ 
            t \((\(-1\) - \((\(-1\) + \[ImaginaryI])\))\)\)\)]],
  ",  \n\nfor ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  ".  When simplified, this formula becomes  \n\n\t\t\t",
  Cell[BoxData[
      \(\(C\_1\) : \ \ \(z\_1\) \((t)\)\ \  = \ \ \(-1\)\  + \ \[ImaginaryI]\ \
\((1 - t)\)\)]],
  ",   for   ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\nSimilarly, the segments ",
  Cell[BoxData[
      RowBox[{\(C\_2\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(C\_3\)}]]],
  " are given by  \n\n\t\t\t",
  Cell[BoxData[
      \(\(C\_2\) : \ \ \(z\_2\) \((t)\)\ \  = \ \ \(-1\) + 
          2  t\  + \ \[ImaginaryI]\ t\)]],
  ",   for   ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  ",   and   \n\n\t\t\t",
  Cell[BoxData[
      \(\(C\_3\) : \ \ \(z\_3\) \((t)\)\ \  = \ \ 1 + 
          2  t\  + \ \[ImaginaryI]\ \((1 - 2  t)\)\)]],
  ",   for   ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 6.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell["Enter the four points and construct the three line segments.", "Text"],

Cell[BoxData[{
    \(t = \(x = \(y = \(z = 0\)\)\); \ 
    Remove[t, x, y, z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[V1, V2, V3, Z1, Z2, Z3];\)\ \), "\n", 
    \(\(z\_0\  = \ \(-\ 1\)\  + \ \[ImaginaryI];\)\ \), "\n", 
    \(\(z\_1\  = \ \(-\ 1\);\)\ \), "\n", 
    \(x\_0 = Re[z\_0]; \ y\_0 = Im[z\_0]; \ x\_1 = Re[z\_1]; \ 
    y\_1 = Im[z\_1];\ \), "\n", 
    \(\(Z1[t_]\  = \ 
        x\_0\  + \ \((x\_1 - x\_0)\) 
            t\  + \ \[ImaginaryI] \((y\_0\  + \ \((y\_1 - y\_0)\) 
                  t)\);\)\ \), "\n", 
    \(\(z\_0\  = \ \(-\ 1\);\)\ \), "\n", 
    \(\(z\_1\  = \ 1\  + \ \[ImaginaryI];\)\ \), "\n", 
    \(x\_0 = Re[z\_0]; \ y\_0 = Im[z\_0]; \ x\_1 = Re[z\_1]; \ 
    y\_1 = Im[z\_1];\ \), "\n", 
    \(\(Z2[t_]\  = \ 
        x\_0\  + \ \((x\_1 - x\_0)\) 
            t\  + \ \[ImaginaryI] \((y\_0\  + \ \((y\_1 - y\_0)\) 
                  t)\);\)\ \), "\n", 
    \(\(z\_0\  = \ 1\  + \ \[ImaginaryI];\)\ \), "\n", 
    \(\(z\_1\  = \ 3\  - \ \[ImaginaryI];\)\ \), "\n", 
    \(x\_0 = Re[z\_0]; \ y\_0 = Im[z\_0]; \ x\_1 = Re[z\_1]; \ 
    y\_1 = Im[z\_1];\ \), "\n", 
    \(\(Z3[t_]\  = \ 
        x\_0\  + \ \((x\_1 - x\_0)\) 
            t\  + \ \[ImaginaryI] \((y\_0\  + \ \((y\_1 - y\_0)\) 
                  t)\);\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(Z\_1\)[t] = \>\"", 
        Z1[t], "\<,       for  0 \[LessEqual] t \[LessEqual] 1,\>"];\)\ \), "\
\n", 
    \(\(Print[\*"\"\<\!\(Z\_2\)[t] = \>\"", 
        Z2[t], "\<,       for  0 \[LessEqual] t \[LessEqual] 1,\>"];\)\ \), "\
\n", 
    \(\(Print[\*"\"\<\!\(Z\_3\)[t] = \>\"", 
        Z3[t], "\<,  for  0 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Z\_1\)[t] = \>\"", 
        Z1[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Z\_1\)[0] = \>\"", Z1[0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(Z\_1\)[1] = \>\"", 
        Z1[1]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Z\_2\)[t] = \>\"", 
        Z2[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Z\_2\)[0] = \>\"", Z2[0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(Z\_2\)[1] = \>\"", 
        Z2[1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Z\_3\)[t] = \>\"", 
        Z3[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Z\_3\)[0] = \>\"", Z3[0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(Z\_3\)[1] = \>\"", 
        Z3[1]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph these line segments."
}], "Text"],

Cell[BoxData[{
    \(\(V1[t_] = ComplexExpand[{Re[Z1[t]], Im[Z1[t]]}];\)\ \), "\n", 
    \(\(V2[t_] = ComplexExpand[{Re[Z2[t]], Im[Z2[t]]}];\)\ \), "\n", 
    \(\(V3[t_] = ComplexExpand[{Re[Z3[t]], Im[Z3[t]]}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[{V1[t], V2[t], V3[t]}], {t, 0, 1}, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Blue, Green}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(Z\_1\)[t] = \>\"", 
        Z1[t], "\<,     for 0 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\n\
", 
    \(\(Print[\*"\"\<   \!\(Z\_2\)[t] = \>\"", 
        Z2[t], "\<,     for 0 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\n\
", 
    \(\(Print[\*"\"\<   \!\(Z\_3\)[t] = \>\"", 
        Z3[t], "\<, for 0 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tWe are now ready to define the integral of a complex function along a \
contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " in the plane with initial point ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " and terminal point ",
  StyleBox["B",
    FontFamily->"Courier New"],
  ".  Our approach is to mimic what is done in calculus.  We create a \
partition  ",
  Cell[BoxData[
      RowBox[{\(P\_n\), "=", 
        RowBox[{"{", 
          RowBox[{\(z\_0 = A\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(z\_1\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(z\_2\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(z\_n = B\)}], "}"}]}]]],
  "  of points that proceed along ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " from ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " to ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " and form the differences  ",
  Cell[BoxData[
      \(\[CapitalDelta]z\_k = z\_k - z\_\(k - 1\)\)]],
  "  for  ",
  Cell[BoxData[
      RowBox[{\(k = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n"}]]],
  ".  Between each pair of partition points  ",
  Cell[BoxData[
      \(z\_\(k - 1\)\ \ and\ \ z\_k\)]],
  "  we select a point  ",
  Cell[BoxData[
      \(c\_k\)]],
  "  on ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", as shown in Figure 6.5, and evaluate the function  ",
  Cell[BoxData[
      \(f \((c\_k)\)\)]],
  ".  \nThese values are used to make a ",
  StyleBox[ButtonBox["Riemann Sum",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RiemannSum.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " for the partition:  \n\n",
  StyleBox["(6-12)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(S \((P\_n)\)\ \  = \ \ \(\[Sum]\+\(k = 1\)\%n 
              f \((c\_k)\) \((z\_k - 
                  z\_\(k - 1\))\)\ \  = \ \ \[Sum]\+\(k = 1\)\%n 
              f \((c\_k)\) \[CapitalDelta]z\_k\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.5",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0605.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Partition points ",
  Cell[BoxData[
      \({z\_k}\)]],
  " and function evaluation points ",
  Cell[BoxData[
      \({c\_k}\)]],
  " \n\t\t\t\t\tfor a Riemann sum along the contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " from ",
  Cell[BoxData[
      RowBox[{"z", "=", 
        RowBox[{
          RowBox[{"A", " ", 
            StyleBox["to",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", "z"}], "=", "B"}]}]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tAssume now that there exists a unique complex number ",
  StyleBox["L",
    FontFamily->"Courier New"],
  " that is the limit of every sequence ",
  Cell[BoxData[
      \({S \((P\_n)\)}\)]],
  " of ",
  StyleBox[ButtonBox["Riemann sums",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RiemannSum.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " given in Equation ",
  StyleBox["(6-12)",
    FontColor->RGBColor[0, 0, 1]],
  ", where the maximum of ",
  Cell[BoxData[
      \(\(\(|\)\(\[CapitalDelta]z\_k\)\(|\)\)\)]],
  " tends toward ",
  StyleBox["0",
    FontFamily->"Courier New"],
  " for the sequence of partitions. We define the number ",
  StyleBox["L",
    FontFamily->"Courier New"],
  " as the value of the integral of the function ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " taken along the contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 6.2 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Complex Integral",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ContourIntegral.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " be a contour.  Then  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\ 
          f \((z)\)\ \[DifferentialD]z\ \  = \ \ lim\+\(n\  \[Rule] \ \
\[Infinity]\)\ \(\[Sum]\+\(k = 1\)\%n f \((c\_k)\) \[CapitalDelta]z\_k\)\)]],
  ",  \n\nprovided that the limit exists in the sense previously discussed."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tNote that in Definition 6.2, the value of the integral depends on the \
contour.  In Section 6.3 the ",
  StyleBox[ButtonBox["Cauchy",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  StyleBox["-",
    FontSize->14,
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[ButtonBox["Goursat",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Goursat.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " theorem will establish the remarkable fact that, if ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic, then ",
  Cell[BoxData[
      \(\[Integral]\_C\ f \((z)\)\ \[DifferentialD]z\)]],
  " is independent of the contour."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 6.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use a Riemann sum to get an approximation for the integral  ",
  Cell[BoxData[
      \(\[Integral]\_C\ \[ExponentialE]\^z\ \[DifferentialD]z\)]],
  "  where ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a the line segment joining the point  ",
  Cell[BoxData[
      RowBox[{"A", " ", "=", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["to",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "B"}], 
          "=", \(2 + \(\[ImaginaryI]\ \[Pi]\)\/4\)}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  Set ",
  StyleBox["n=8",
    FontFamily->"Courier New"],
  " in Equation ",
  StyleBox["(6-12)",
    FontColor->RGBColor[0, 0, 1]],
  " and form the partition  ",
  Cell[BoxData[
      RowBox[{\(P\_8\), "=", 
        RowBox[{"{", 
          
          RowBox[{\(z\_k = k\/4 + \[ImaginaryI] \(\(\ \)\(k\ \[Pi]\)\)\/32\), 
            
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", 
            RowBox[{
              RowBox[{
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "  ", "k"}], "=", "0"}], 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "2", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "8"}], "}"}]}]]],
  ".  For this situation, we have a uniform increment  ",
  Cell[BoxData[
      \(\[CapitalDelta]z\_k = 1\/4 + \[ImaginaryI]  \[Pi]\/32\)]],
  ".  \nFor convenience we select  ",
  Cell[BoxData[
      \(c\_k\  = \ \(\(z\_\(k - 1\) + z\_k\)\/2\  = \ \(2  k - 1\)\/8 + \
\[ImaginaryI] \(\(\ \)\(\[Pi] \((2  k - 1)\)\)\)\/64\)\)]],
  "  for  ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{\(k = 0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "1", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "2", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "8"}]}]]],
  ".  Figure 6.6 shows the points ",
  Cell[BoxData[
      \({z\_k}\)]],
  " and ",
  Cell[BoxData[
      \({c\_k}\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.6",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0606.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Partition and evaluation points for the Riemann sum ",
  Cell[BoxData[
      \(S \((P\_8)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "One possible Riemann sum, then, is  \n\n\t\t\t",
  Cell[BoxData[
      \(S \((P\_8)\)\  = \ \(\[Sum]\+\(k = 1\)\%8 
              f \((c\_k)\) \[CapitalDelta]z\_k\  = \ \[Sum]\+\(k = 1\)\%8 
              exp \((\(2  k - 1\)\/8 + \[ImaginaryI] \(\(\ \)\(\[Pi] \((2  k \
- 1)\)\)\)\/64)\) \((1\/4 + \[ImaginaryI]  \[Pi]\/32)\)\)\)]],
  "  \n\nBy rounding the terms in this Riemann sum to five decimal digits, we \
obtain an approximation for the integral:  \n\n\t\t\t",
  Cell[BoxData[{
      \(S \((P\_8)\)\ \  \[TildeTilde] \ \ 0.27749\[InvisibleSpace] + 
          0.12501\ \[ImaginaryI]\  + \ 0.33885 + 0.19467\ \[ImaginaryI]\  + \ 
          0.40850\[InvisibleSpace] + 0.29140\ \[ImaginaryI]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(+\ 0.48532\)\[InvisibleSpace] + 
        0.42378\ \[ImaginaryI]\  + \ 0.56683 + 0.60261\ \[ImaginaryI]\  + \ 
        0.64848 + 0.84138\ \[ImaginaryI]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(+\ 0.72276\) + 
        1.15676\ \[ImaginaryI]\  + \ 0.77798 + 
        1.56912\ \[ImaginaryI]\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(S \((P\_8)\)\ \  \[TildeTilde] \ \ 4.226201\ \[InvisibleSpace]\  + \ \
\(\(5.20473\)\(\ \ \)\(\[ImaginaryI]\)\(\ \)\)\)}]],
  " \n\nThis result compares favorably with the precise value of the \
integral, which you will soon see equals  \n\n\t\t\t",
  Cell[BoxData[
      \(exp \((2 + \(\[ImaginaryI]\ \[Pi]\)\/4)\) - 
          1\ \  = \ \ \(\(-1\) + \(\[ExponentialE]\^2\) \@2\/2 + \ \
\[ImaginaryI]\ \(\[ExponentialE]\^2\) \@2\/2\ \  = \ \ 4.22485\
\[InvisibleSpace]\  + \ 5.22485\ \[ImaginaryI]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 6.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \[ExponentialE]\^z\)],
    AspectRatioFixed->True],
  "  and compute the approximating Riemann sum.  \n",
  StyleBox["For illustration.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  We use n = 8 terms in the sum."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[a, b, c, z];\)\ \), "\n", 
    \(\(Clear[dz, f, k, n, RiemannSum];\)\ \), "\n", 
    \(\(f[z_]\  = \ \[ExponentialE]\^z;\)\ \), "\n", 
    \(\(a\  = \ 0;\)\ \), "\n", 
    \(\(b\  = \ 2\  + \(\(\ \)\(\[ImaginaryI]\ \[Pi]\)\)\/4;\)\ \), "\n", 
    \(\(n\  = \ 8;\)\ \), "\n", 
    \(\(dz\  = \ \(b - a\)\/n;\)\ \), "\n", 
    \(\(z\_k_\  = \ Expand[a\  + \ k\ dz];\)\ \), "\n", 
    \(\(c\_k_\  = \ Expand[\(z\_\(k - 1\)\  + \ z\_k\)\/2];\)\ \), "\n", 
    \(\(RiemannSum\  = \[Sum]\+\(k = 1\)\%n f[c\_k] dz\ ;\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<n = \>", n];\)\ \), "\n", 
    \(\(Print[\*"\"\<{\!\(z\_k\)} = \>\"", 
        Table[z\_k, {k, 1, n}]];\)\ \), "\n", 
    \(\(Print[\*"\"\<{\!\(c\_k\)} = \>\"", 
        Table[c\_k, {k, 1, n}]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = 1\)\)\>\""\&n, \
\*"\"\<f[\!\(c\_k\)]\!\(dz\_k\) = \!\(\[Sum]\+\(k = 1\)\%8\)Exp[\!\(\(2  k - \
1\)\/8\)+\[ImaginaryI]\!\(\(\(\\\ \)\(\[Pi] \((2  k - \
1)\)\)\)\/64\)](\!\(1\/4\)+\[ImaginaryI]\!\(\[Pi]\/32\))\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = 1\)\)\>\""\&n, \
\*"\"\<f[\!\(c\_k\)]\!\(dz\_k\) = \>\""];\)\ \), "\n", 
    \(\(Print[RiemannSum];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = 1\)\)\>\""\&n, \
\*"\"\<f[\!\(c\_k\)]\!\(dz\_k\) = \>\""];\)\ \), "\n", 
    \(\(Print[\((\[Sum]\+\(k = 1\)\%n f[c\_k])\) dz];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = 1\)\)\>\""\&n, \
\*"\"\<f[\!\(c\_k\)]\!\(dz\_k\) = \>\"", N[RiemannSum]];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We are done!\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to check out some Riemann sum approximations."
}], "Text"],

Cell[BoxData[{
    \(\(S[n_] := 
        N[\[Sum]\+\(k = 1\)\%n 
                Exp[\(1\/n\) \((2  k - 
                      1 + \[ImaginaryI] \(\(\ \)\(\[Pi] \((2  k - \
1)\)\)\)\/8)\)] \(1\/n\) \((2 + \(\[ImaginaryI]\ \[Pi]\)\/4)\)];\)\), "\
\[IndentingNewLine]", 
    \(\(For[i = 3, 
        i \[LessEqual] 13, \(i++\), \[IndentingNewLine]m = 
          2\^i; \[IndentingNewLine]Print[\*"\"\<\!\(\[Sum]\+\(k = \
1\)\)\>\""\&m, \*"\"\< f[\!\(c\_k\)]\!\(dz\_k\) = \>\"", 
          NumberForm[S[m], {10, 10}]\ ];\ \ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tIn general, obtaining an exact value for an integral given by Definition \
6.2 is a daunting task. Fortunately, there is a beautiful theory that allows \
for an easy computation of many contour integrals.  Suppose that we have a \
parametrization of the contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " given by the function ",
  Cell[BoxData[
      \(z \((t)\)\)]],
  " for ",
  Cell[BoxData[
      \(a \[LessEqual] t \[LessEqual] b\)]],
  ".  That is, ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is the range of the function ",
  Cell[BoxData[
      \(z \((t)\)\)]],
  " over the interval ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], "]"}]]],
  ", as Figure 6.7 shows."
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.7",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0607.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  A parametrization of the contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " by ",
  Cell[BoxData[
      \(z \((t)\)\)]],
  " for ",
  Cell[BoxData[
      \(a \[LessEqual] t \[LessEqual] b\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tIt follows that  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(lim\+\(n \[Rule] \[Infinity]\)\ \(\[Sum]\+\(k = 1\)\%n 
              f \((c\_k)\) \[CapitalDelta]z\_k\)\ \  = \ \ lim\+\(n \[Rule] \
\[Infinity]\)\ \(\[Sum]\+\(k = 1\)\%n 
              f \((c\_k)\) \((z\_k - 
                  z\_\(k - 1\))\)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(lim\+\(n \[Rule] \[Infinity]\)\ \(\
\[Sum]\+\(k = 1\)\%n 
              f \((z \((\[Tau]\_k)\))\) \((z \((t\_k)\) - 
                  z \((t\_\(k - 1\))\))\)\)\)\)\)}]],
  "   \n\nwhere ",
  Cell[BoxData[
      \(\[Tau]\_k\)]],
  " and ",
  Cell[BoxData[
      \(t\_k\)]],
  " are the points contained in the interval ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], "]"}]]],
  " with the property that ",
  Cell[BoxData[
      \(c\_k = z \((\[Tau]\_k)\)\)]],
  " and ",
  Cell[BoxData[
      \(z\_k = z \((t\_k)\)\)]],
  ", as is also shown in Figure 6.7.  If for all ",
  StyleBox["k",
    FontFamily->"Courier New"],
  " we multiply the kth term in the last sum by ",
  Cell[BoxData[
      \(\(t\_k - t\_\(k - 1\)\)\/\(t\_k - t\_\(k - 1\)\)\)]],
  ", then we get  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(lim\+\(n \[Rule] \[Infinity]\)\ \(\[Sum]\+\(k = 1\)\%n 
              f \((c\_k)\) \[CapitalDelta]z\_k\)\ \  = \ \ lim\+\(n \[Rule] \
\[Infinity]\)\ \(\[Sum]\+\(k = 1\)\%n 
              f \((z \((\[Tau]\_k)\))\) \((\(z \((t\_k)\) - z \((t\_\(k - \
1\))\)\)\/\(t\_k - t\_\(k - 1\)\))\) \((t\_k - 
                  t\_\(k - 1\))\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(lim\+\(n \[Rule] \[Infinity]\)\ \(\
\[Sum]\+\(k = 1\)\%n 
              f \((z \((\[Tau]\_k)\))\) \((\(z \((t\_k)\) - z \((t\_\(k - \
1\))\)\)\/\(t\_k - t\_\(k - 1\)\))\) \[CapitalDelta]t\_k\)\)\)\)}]],
  "   "
}], "Text"],

Cell[TextData[{
  "\tThe quotient inside the last summation looks suspiciously like a \
derivative, and the entire quantity looks like a Riemann sum. Assuming no \
difficulties, this last expression should equal  ",
  Cell[BoxData[
      \(\[Integral]\_a\%b\ 
        f \((z \((t)\))\)\ z' \((t)\) \[DifferentialD]t\)]],
  ",  as defined in Section 6.1.  Of course, if we're to have any hope of \
this happening, we would have to get the same limit regardless of how we \
parametrize the contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".  As Theorem 6.1 states, this is indeed the case."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 6.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose that ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " is a continuous complex-valued function defined on a set containing the \
contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".  Let ",
  Cell[BoxData[
      \(z \((t)\)\)]],
  " be any parametrization of ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " for  ",
  Cell[BoxData[
      \(a \[LessEqual] t \[LessEqual] b\)]],
  ".  Then  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\ 
          f \((z)\)\ \[DifferentialD]z\ \  = \ \ \ \[Integral]\_a\%b\ 
          f \((z \((t)\))\)\ z' \((t)\) \[DifferentialD]t\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "\tWe omit the proof of Theorem 6.1 because it involves ideas (e.g., as the \
theory of the Riemann--Stieltjes integral) that are beyond the scope of this \
book. A more rigorous development of the contour integral based on Riemann \
sums is presented in advanced texts such as ",
  ButtonBox["Lars Valerian Ahlfors",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Ahlfors.\
html"], None},
    ButtonStyle->"Hyperlink"],
  ", ",
  "Complex Analysis, 3rd ed. (New York: McGraw-Hill, 1979).  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  "\tTwo important facets of Theorem 6.1 are worth mentioning.  First, \
Theorem 6.1 makes the problem of evaluating complex-valued functions along \
contours easy, as it reduces the task to the evaluation of complex - valued \
functions over real intervals - a procedure that you studied in Section 6.1.  \
Second, according to Theorem 6.1, this transformation yields the same answer \
regardless of the parametrization we choose for",
  " ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 6.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Give an exact calculation of the integral in Example 6.6:  ",
  Cell[BoxData[
      \(\[Integral]\_C\ \[ExponentialE]\^z\ \[DifferentialD]z\)]],
  "  where ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a the line segment joining the point  ",
  Cell[BoxData[
      RowBox[{"A", " ", "=", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["to",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "B"}], 
          "=", \(2 + \(\[ImaginaryI]\ \[Pi]\)\/4\)}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.5 [
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .19635 -16.1875 -9.125 ]
[-0.0125 .19635 0 9.125 ]
[-0.0125 .3927 -16.1875 -9.09375 ]
[-0.0125 .3927 0 9.09375 ]
[0 .525 -5 0 ]
[0 .525 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .19635 m
.00625 .19635 L
s
gsave
-0.0125 .19635 -77.1875 -13.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.25 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 9.313 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.750 15.125 moveto
(\\200\\200) show
69.000 15.125 moveto
(\\200) show
71.063 15.125 moveto
(\\200) show
66.063 21.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
0 .3927 m
.00625 .3927 L
s
gsave
-0.0125 .3927 -77.1875 -13.0938 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.1875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 9.313 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.750 15.125 moveto
(\\200\\200) show
69.000 15.125 moveto
(\\200) show
71.063 15.125 moveto
(\\200) show
66.063 21.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 0 m
0 .5 L
s
gsave
0 .525 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
0 0 m
.04057 .01593 L
.08481 .0333 L
.12636 .04962 L
.16632 .06531 L
.20885 .08202 L
.2498 .09809 L
.29331 .11518 L
.33524 .13165 L
.37557 .14749 L
.41848 .16434 L
.4598 .18056 L
.49953 .19616 L
.54183 .21278 L
.58254 .22876 L
.62583 .24576 L
.66752 .26213 L
.70762 .27788 L
.7503 .29464 L
.79139 .31078 L
.83505 .32792 L
.87712 .34444 L
.9176 .36034 L
.96065 .37725 L
1 .3927 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 144},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`00S`3oool5000006`0oooo1000000L0?ooo`00T@3oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo01d0oooo002A0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
703oool00940oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0K0?ooo`00T@3oool0
0`000000oooo0?ooo`1/0?ooo`040000003oool0oooo000001`0oooo002@0?ooo`800000K`3oool2
000001d0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooo`X0oooo0P0000000`3oool000000000000B0?ooo`00803oool20?l0on4000001`3oool00`00
0000oooo0000000C0?ooo`00803oool010000000oooo0?l0o`3o0?m]0?ooo`030000003oool0oooo
06h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`00803oool010000000
oooo0?ooo`3oool20?l0of/0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`040?oo
o`80000000<0oooo0000000000004P3oool00200oooo00<000000?ooo`3oool00`3oool20?l0ooP0
oooo000P0?ooo`030000003oool0oooo00D0oooo0`3o0?oe0?ooo`00803oool00`000000oooo0?oo
o`080?ooo`80o`3ol`3oool00200oooo00<000000?ooo`3oool02P3oool30?l0oo00oooo000P0?oo
o`030000003oool0oooo00d0oooo0P3o0?o^0?ooo`00803oool00`000000oooo0?ooo`0?0?ooo`<0
o`3oj`3oool00200oooo00<000000?ooo`3oool04P3oool20?l0onT0oooo000P0?ooo`030000003o
ool0oooo01@0oooo0P3o0?oW0?ooo`00803oool00`000000oooo0?ooo`0F0?ooo`80o`3oi@3oool0
0200oooo00<000000?ooo`3oool0603oool30?l0on80oooo000P0?ooo`030000003oool0oooo01/0
oooo0`3o0?oO0?ooo`00803oool00`000000oooo0?ooo`0N0?ooo`<0o`3og03oool00200oooo00<0
00000?ooo`3oool08@3oool30?l0omT0oooo000P0?ooo`030000003oool0oooo02@0oooo0P3o0?oG
0?ooo`00803oool00`000000oooo0?ooo`0V0?ooo`<0o`3oe03oool00200oooo00<000000?ooo`3o
ool0:@3oool20?l0om80oooo000P0?ooo`030000003oool0oooo02/0oooo0`3o0?o?0?ooo`00803o
ool00`000000oooo0?ooo`0^0?ooo`<0o`3oc03oool00200oooo00<000000?ooo`3oool0<@3oool3
0?l0olT0oooo000P0?ooo`030000003oool0oooo03@0oooo0`3o0?o60?ooo`00803oool00`000000
oooo0?ooo`0g0?ooo`80o`3oa03oool00200oooo00<000000?ooo`3oool0>@3oool30?l0ol40oooo
000P0?ooo`030000003oool0oooo03`0oooo0P3o0?no0?ooo`00803oool00`000000oooo0?ooo`0n
0?ooo`<0o`3o_03oool00200oooo00<000000?ooo`3oool0@@3oool20?l0okX0oooo000P0?ooo`03
0000003oool0oooo04<0oooo0P3o0?nh0?ooo`00803oool00`000000oooo0?ooo`150?ooo`80o`3o
]P3oool00200oooo00<000000?ooo`3oool0A`3oool30?l0ok<0oooo000P0?ooo`030000003oool0
oooo04X0oooo0P3o0?na0?ooo`00803oool00`000000oooo0?ooo`1<0?ooo`<0o`3o[P3oool00200
oooo00<000000?ooo`3oool0C`3oool20?l0oj`0oooo000P0?ooo`030000003oool0oooo0540oooo
0`3o0?nY0?ooo`00803oool00`000000oooo0?ooo`1D0?ooo`<0o`3oYP3oool00200oooo00<00000
0?ooo`3oool0E`3oool30?l0oj<0oooo000P0?ooo`030000003oool0oooo05X0oooo0`3o0?nP0?oo
o`00503oool2000000X0oooo00<000000?ooo`3oool0G@3oool20?l0oih0oooo000C0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool0G`3oool30?l0oi/0oooo000C0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool0HP3oool20?l0oiT0oooo000D0?ooo`800000
2P3oool00`000000oooo0?ooo`1T0?ooo`<0o`3oUP3oool001<0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`1W0?ooo`80o`3oU03oool001@0oooo0P00000:0?ooo`030000003o
ool0oooo06T0oooo0P3o0?nB0?ooo`00803oool00`000000oooo0?ooo`1[0?ooo`80o`3oT03oool0
0140oooo200000070?ooo`800000KP3oool30?l0ohd0oooo000P0?ooo`030000003oool0oooo0700
oooo0`3o0?n:0?ooo`00803oool00`000000oooo0?ooo`1c0?ooo`<0o`3oQ`3oool00200oooo00<0
00000?ooo`3oool0MP3oool30?l0oh@0oooo000B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`1i0?ooo`80o`3oPP3oool001<0oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`1k0?ooo`80o`3oP03oool001@0oooo00<000000?oo
o`0000002@3oool00`000000oooo0?ooo`1m0?ooo`80o`3oOP3oool001@0oooo00<000000?ooo`00
00002@3oool00`000000oooo0?ooo`1o0?ooo`<0o`3oN`3oool001<0oooo1@0000080?ooo`030000
003oool0oooo0880oooo0P3o0?mi0?ooo`00803oool00`000000oooo0?ooo`240?ooo`<0o`3oMP3o
ool00200oooo00<000000?ooo`3oool0Q`3oool20?l0og@0oooo000P0?ooo`030000003oool0oooo
08T0oooo0`3o0?ma0?ooo`00803oool00`000000oooo0?ooo`2<0?ooo`80o`3oK`3oool00200oooo
00<000000?ooo`3oool0SP3oool30?l0of`0oooo000P0?ooo`030000003oool0oooo0940oooo0P3o
0?mZ0?ooo`00803oool00`000000oooo0?ooo`2C0?ooo`<0o`3oI`3oool00200oooo00<000000?oo
o`3oool0UP3oool30?l0of@0oooo000P0?ooo`030000003oool0oooo09T0oooo0`3o0?mQ0?ooo`00
803oool00`000000oooo0?ooo`2L0?ooo`<0o`3oGP3oool00200oooo00<000000?ooo`3oool0W`3o
ool20?l0oe`0oooo000P0?ooo`030000003oool0oooo0:40oooo0P3o0?mJ0?ooo`00803oool00`00
0000oooo0?ooo`2S0?ooo`80o`3oF03oool00200oooo00<000000?ooo`3oool0Y@3oool30?l0oeD0
oooo000P0?ooo`030000003oool0oooo0:P0oooo0P3o0?mC0?ooo`00803oool00`000000oooo0?oo
o`2Z0?ooo`<0o`3oD03oool00200oooo00<000000?ooo`3oool0[@3oool20?l0odh0oooo000P0?oo
o`030000003oool0oooo0:l0oooo0`3o0?m;0?ooo`00803oool00`000000oooo0?ooo`2b0?ooo`<0
o`3oB03oool00200oooo00<000000?ooo`3oool0]@3oool30?l0odD0oooo000P0?ooo`030000003o
ool0oooo0;P0oooo0`3o0?m20?ooo`00803oool00`000000oooo0?ooo`2k0?ooo`80o`3o@03oool0
0200oooo00<000000?ooo`3oool0_@3oool30?l0ocd0oooo000P0?ooo`030000003oool0oooo0<00
oooo0P3o0?lk0?ooo`00803oool00`000000oooo0?ooo`320?ooo`<0o`3o>03oool00200oooo00<0
00000?ooo`3oool0a@3oool20?l0ocH0oooo000P0?ooo`030000003oool0oooo0<L0oooo0P3o0?ld
0?ooo`00803oool00`000000oooo0?ooo`390?ooo`80o`3o<P3oool001D0oooo0`0000080?ooo`03
0000003oool0oooo0</0oooo0`3o0?l_0?ooo`005P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0<h0oooo0P3o0?l]0?ooo`004`3oool5000000P0oooo00<000000?ooo`3oool0d03o
ool30?l0obX0oooo000C0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0d`3o
ool20?l0obP0oooo000D0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0e@3oool3
0?l0obD0oooo000E0?ooo`8000002@3oool00`000000oooo0?ooo`3H0?ooo`<0o`3o8P3oool00200
oooo00<000000?ooo`3oool0f`3oool30?l0oal0oooo000A0?ooo`P000001`3oool200000=l0oooo
0P3o0?lM0?ooo`00803oool00`000000oooo0?ooo`3m0?ooo`00803oool00`000000oooo0?ooo`3m
0?ooo`00803oool00`000000oooo0?ooo`3m0?ooo`00803oool00`000000oooo0?ooo`3m0?ooo`00
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
o@3oool001<0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`3m0?ooo`00503o
ool00`000000oooo000000090?ooo`030000003oool0oooo0?d0oooo000D0?ooo`030000003oool0
000000T0oooo00<000000?ooo`3oool0o@3oool001<0oooo1@0000080?ooo`030000003oool0oooo
0?d0oooo000P0?ooo`030000003oool0oooo0?d0oooo000P0?ooo`030000003oool0oooo0?d0oooo
000P0?ooo`030000003oool0oooo0?d0oooo000P0?ooo`030000003oool0oooo0?d0oooo000P0?oo
o`030000003oool0oooo0?d0oooo000P0?ooo`030000003oool0oooo0?d0oooo000P0?ooo`030000
003oool0oooo0?d0oooo000P0?ooo`030000003oool0oooo0?d0oooo000P0?ooo`030000003oool0
oooo0?d0oooo000P0?ooo`030000003oool0oooo0?d0oooo000P0?ooo`030000003oool0oooo0?d0
oooo000P0?ooo`030000003oool0oooo0?d0oooo000P0?ooo`030000003oool0oooo0?d0oooo000P
0?ooo`030000003oool0oooo0?d0oooo000P0?ooo`030000003oool0oooo0?d0oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo000N0?ooo`800000o`3oool10?ooo`007`3oool00`00
0000oooo0?ooo`3n0?ooo`00803oool00`000000oooo0?ooo`3m0?ooo`007`3oool00`000000oooo
0000003n0?ooo`007P3oool010000000oooo0?ooo`00003n0?ooo`007@3oool3000000030?ooo`00
000000000?d0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
0000\
\>"],
    ImageRangeCache->{{{0, 287}, {143, 0}} -> {0, 0, 0, 0}}],
  "   "
}], "Text"],

Cell[TextData[{
  "Solution.  We must compute  ",
  Cell[BoxData[
      \(\[Integral]\_C\ \[ExponentialE]\^z\ \[DifferentialD]z\ \  = \ \ \
\[Integral]\_C\ exp \((z)\)\ \[DifferentialD]z\)]],
  ",  where C is the line segment joining  ",
  Cell[BoxData[
      RowBox[{"A", " ", "=", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["to",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "B"}], 
          "=", \(2 + \(\[ImaginaryI]\ \[Pi]\)\/4\)}]}]]],
  ".  According to Equation ",
  StyleBox["(1-48)",
    FontColor->RGBColor[0, 0, 1]],
  ", we can parametrize ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " by  ",
  Cell[BoxData[
      \(z \((t)\)\  = \ \((2 + \[ImaginaryI]  \[Pi]\/4)\) t\)]],
  ",  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  ".  As  ",
  Cell[BoxData[
      \(z' \((t)\)\  = \ \((2 + \[ImaginaryI]  \[Pi]\/4)\)\)]],
  ",  Theorem 6.1 guarantees that  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_C\ \[ExponentialE]\^z\ \[DifferentialD]z\ \  = \ \ \
\(\[Integral]\_C\ exp \((z)\)\ \[DifferentialD]z\ \  = \ \ \[Integral]\_0\%1\ 
            Exp[z[t]] \(z'\)[t] \[DifferentialD]t\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\[Integral]\_0\%1 
              Exp[\((2 + \[ImaginaryI]  \[Pi]\/4)\)\ t] \((2 + \[ImaginaryI]  \
\[Pi]\/4)\) \[DifferentialD]t\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\((2 + \
\[ImaginaryI]  \[Pi]\/4)\) \(\[Integral]\_0\%1\ 
            Exp[\((2 + \[ImaginaryI]  \[Pi]\/4)\)\ t] \[DifferentialD]t\)\)\)\
\(\ \)\(\[IndentingNewLine]\)
      \(\ \)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\((2 + \
\[ImaginaryI]  \[Pi]\/4)\) \(\[Integral]\_0\%1\( \[ExponentialE]\^\(2  
                    t\)\) \(\[ExponentialE]\^\(\(\[ImaginaryI]\ \[Pi]\)\/4\ t\
\)\) \[DifferentialD]t\)\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\((2 + \
\[ImaginaryI]  \[Pi]\/4)\) \(\[Integral]\_0\%1\ \(\[ExponentialE]\^\(2  
                    t\)\) \((Cos[\(\[Pi]\ t\)\/4] + \[ImaginaryI]\ \ Sin[\(\
\[Pi]\ t\)\/4])\) \[DifferentialD]t\)\)\)\(\[IndentingNewLine]\)
      \(\ \)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\((2 + \
\[ImaginaryI]  \[Pi]\/4)\) \((\[Integral]\_0\%1\ \(\[ExponentialE]\^\(2  
                        t\)\) Cos[\(\[Pi]\ t\)\/4] \[DifferentialD]t\ \  + \ \
\ \[ImaginaryI] \(\[Integral]\_0\%1\ \(\[ExponentialE]\^\(2  t\)\) 
                    Sin[\(\[Pi]\ t\)\/4] \[DifferentialD]t\))\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\((2 + \
\[ImaginaryI]  \[Pi]\/4)\) \((\(2\ \(\@2\) \[ExponentialE]\^2\ \((\[Pi] + \
8)\)\)\/\(\[Pi]\^2 + 64\) - 
              32\/\(\[Pi]\^2 + 64\) + \[ImaginaryI] \((\(\(-2\)\ \(\@2\) \
\[ExponentialE]\^2\ \((\[Pi] - 8)\)\)\/\(\[Pi]\^2 + 64\) + \(4\ \[Pi]\)\/\(\
\[Pi]\^2 + 64\))\))\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(4.2248516741\ \  + 
          5.2248516741\ \[ImaginaryI]\)\)\)}]],
  "   \n\nEach integral in the last expression can be done using integration \
by parts. (There is a simpler way-see Remark 6.1.)  We leave as an exercise \
to show that the final answer simplifies to  ",
  Cell[BoxData[
      \(exp \((2 + \[ImaginaryI]  \[Pi]\/4)\) - 1\  = \ 
        4.2248516741 + 5.2248516741\ \[ImaginaryI]\)]],
  ",  as we claimed in Example 6.6. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 6.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \[ExponentialE]\^z\)],
    AspectRatioFixed->True],
  "  and set up the parameterization for the computing a contour integral."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[a, b, t, u, v, z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, int, val];\)\ \), "\n", 
    \(\(a\  = \ 0;\)\ \), "\n", 
    \(\(b\  = \ 2\  + \(\(\ \)\(\[ImaginaryI]\ \[Pi]\)\)\/4;\)\ \), "\n", 
    \(\(z[t_]\  = \ \ a\  + \ \((b\  - \ a)\)\ t;\)\ \), "\n", 
    \(\(F[Z_]\  = \ \[ExponentialE]\^Z;\)\ \), "\n", 
    \(\(f[t_]\  = \ \[ExponentialE]\^z[t];\)\ \), "\n", 
    \(\(u[t_]\  = \ ComplexExpand[Re[f[t]]];\)\ \), "\n", 
    \(\(v[t_]\  = \ ComplexExpand[Im[f[t]]];\)\ \), "\n", 
    \(\(Print["\<        F[z] = \>", F[z]];\)\ \), "\n", 
    \(\(Print["\<        z[t] = \>", z[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<     F[z[t]] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<        u[t] = \>", u[t]];\)\ \), "\n", 
    \(\(Print["\<        v[t] = \>", v[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<       z'[t] = \>", \(z'\)[t]];\)\ \), "\n", 
    \(\(Print["\<f[z[t]]z'[t] = \>", 
        f[t] \(z'\)[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method (i).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The first method uses a complex integrand  f[z[t]] z'[t]."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[int, val];\)\ \), "\[IndentingNewLine]", 
    \(\(int\  = \[Integral]f[t] \(z'\)[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(val\  = \ \[Integral]\_0\%1 f[t] \(z'\)[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(V[t_] = 
        ComplexExpand[{Re[z[t]], Im[z[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z[t]]z'[t] = \>", 
        f[t] \(z'\)[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< \[Integral]f[z[t]]z'[t]\[DifferentialD]t = \>", 
        int];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[z[t]]z'[t]\[DifferentialD]t = \
\>\"", val];\)\ \), "\[IndentingNewLine]", 
    \(\(val = ComplexExpand[FullSimplify[val]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[z[t]]z'[t]\[DifferentialD]t = \
\>\"", val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[z[t]]z'[t]\[DifferentialD]t = (\
\>\"", ComplexExpand[Re[val]], "\<) + \[ImaginaryI] (\>", 
        ComplexExpand[Im[val]], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[z[t]]z'[t]\[DifferentialD]t = \
\>\"", N[val]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[V[t]], {t, 0, 1}, 
        PlotRange \[Rule] {{0, 2}, {0, 1}}, AspectRatio \[Rule] 1\/2, 
        Ticks \[Rule] {Range[\(-1\), 2, 1], Range[0, \[Pi]\/4, \[Pi]\/8]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        F[z], "\<\[DifferentialD]z = \>", 
        ComplexExpand[FullSimplify[val]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        F[z], "\<\[DifferentialD]z = (\>", 
        ComplexExpand[Re[val]], "\<) + \[ImaginaryI](\>", 
        ComplexExpand[Im[val]], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        F[z], "\<\[DifferentialD]z = \>", 
        N[val]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<C: z[t] = \>", 
        z[t], "\<,  for  0 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Method (ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The second method uses a integrals of  u[t] z'[t] and  v[t] z'[t]."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[ImInt, ImVal, ReInt, ReVal, V, 
        Val];\)\ \), "\[IndentingNewLine]", 
    \(\(ReInt\  = \ \[Integral]u[t] \(z'\)[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(ImInt\  = \ \[Integral]v[t] \(z'\)[
              t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(ReVal\  = \ \ \[Integral]\_0\%1 u[t] \(z'\)[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(ImVal\  = \ \ \[Integral]\_0\%1 v[t] \(z'\)[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(Val\  = \ \ ReVal\  + \ \[ImaginaryI]\ ImVal;\)\ \), "\
\[IndentingNewLine]", 
    \(\(V[t_] = 
        ComplexExpand[{Re[z[t]], Im[z[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[t]z'[t] = \>", u[t] \(z'\)[t]];\)\ \), "\n", 
    \(\(Print["\<v[t]z'[t] = \>", 
        v[t] \(z'\)[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<\[Integral]u[t]z'[t]\[DifferentialD]t + \[ImaginaryI] \
\[Integral]v[t]z'[t]\[DifferentialD]t\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", ReInt, "\< + \[ImaginaryI](\>", 
        ImInt, "\<)\>"];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)u[t]z'[t]\[DifferentialD]t + \
\[ImaginaryI] \!\(\[Integral]\_0\%1\)v[t]z'[t]\[DifferentialD]t\>\""];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<= \>", ReVal, "\< + \[ImaginaryI](\>", 
        ImVal, "\<)\>"];\)\ \), "\n", 
    \(\(Print["\<= \>", ComplexExpand[Val]];\)\ \), "\n", 
    \(\(Print["\<= \>", 
        Apart[ComplexExpand[Val]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Val = 
        ComplexExpand[FullSimplify[Val]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", Val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= (\>", ComplexExpand[Re[Val]], "\<) + \[ImaginaryI] (\>", 
        ComplexExpand[Im[Val]], "\<)\>"];\)\ \), "\n", 
    \(\(Print["\<= \>", 
        N[ComplexExpand[Val]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[V[t]], {t, 0, 1}, 
        PlotRange \[Rule] {{0, 2}, {0, 1}}, AspectRatio \[Rule] 1\/2, 
        Ticks \[Rule] {Range[\(-1\), 2, 1], Range[0, \[Pi]\/4, \[Pi]\/8]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        F[z], "\<\[DifferentialD]z = \>", 
        ComplexExpand[FullSimplify[val]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        F[z], "\<\[DifferentialD]z = (\>", 
        ComplexExpand[Re[val]], "\<) + \[ImaginaryI](\>", 
        ComplexExpand[Im[val]], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        F[z], "\<\[DifferentialD]z = \>", 
        N[val]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<C: z[t] = \>", 
        z[t], "\<,  for  0 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Evaluate the contour integral  ",
  Cell[BoxData[
      \(\[Integral]\_C\ 1\/\(z - 2\)\ \[DifferentialD]z\)]],
  "  where ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a the upper semicircle with radius ",
  StyleBox["1",
    FontFamily->"Courier New"],
  " centered at  ",
  Cell[BoxData[
      \(x = 2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.333333 0 0.333333 [
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .33333 -6 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[0 .35833 -5 0 ]
[0 .35833 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.33333 0 m
.33333 .00625 L
s
[(1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(2)] .66667 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .33333 m
.00625 .33333 L
s
[(1)] -0.0125 .33333 1 0 Mshowa
0 0 m
0 .33333 L
s
gsave
0 .35833 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
1 0 m
1 .00129 L
.99999 .00247 L
.99998 .00383 L
.99996 .00511 L
.99992 .00739 L
.99985 .00987 L
.99976 .0126 L
.99964 .01549 L
.99936 .02067 L
.99898 .02601 L
.99855 .03101 L
.9973 .04237 L
.99561 .0539 L
.99372 .06439 L
.98824 .08776 L
.98212 .10772 L
.97402 .12901 L
.95402 .16894 L
.92988 .20452 L
.89944 .23859 L
.86597 .26719 L
.83048 .29031 L
.81143 .30026 L
.78983 .30974 L
.76846 .31741 L
.74856 .32312 L
.72761 .32772 L
.71596 .32967 L
.70487 .33114 L
.69431 .33219 L
.68896 .33259 L
.68306 .33293 L
.67803 .33314 L
.67521 .33322 L
.67387 .33326 L
.67262 .33328 L
.67142 .3333 L
.67034 .33331 L
.66913 .33332 L
.66784 .33333 L
.6666 .33333 L
.66525 .33333 L
.66398 .33332 L
.66281 .33331 L
.66143 .33329 L
.66013 .33327 L
.65767 .33321 L
.65503 .33313 L
.65216 .33302 L
Mistroke
.64699 .33275 L
.6422 .33243 L
.63125 .33145 L
.61964 .33 L
.60845 .32821 L
.59643 .32585 L
.57491 .32045 L
.554 .31372 L
.53248 .30513 L
.49536 .28595 L
.45882 .2606 L
.42713 .23181 L
.3978 .19703 L
.37427 .16004 L
.3564 .12184 L
.3491 .10132 L
.34285 .07907 L
.34055 .069 L
.33843 .05808 L
.33689 .04859 L
.33553 .03818 L
.33456 .02856 L
.33391 .0196 L
.33365 .01463 L
.33349 .01012 L
.33342 .00762 L
.33339 .0063 L
.33337 .00491 L
.33335 .00369 L
.33334 .00236 L
.33334 .00114 L
.33333 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 95.9375},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Gb000`400?l00000o`00003oo`3ooolQ
0?ooo`00J@3oool5000003d0oooo1000000o0?ooo`800000<03oool006/0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0o0?ooo`040000003oool0oooo000002l0oooo001[0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0^0?ooo`00
J`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
;@3oool006/0oooo00<000000?ooo`3oool0?@3oool010000000oooo0?ooo`00000n0?ooo`040000
003oool0oooo000002l0oooo001Z0?ooo`800000@03oool200000400oooo0P00000`0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00mP3oool2000000030?ooo`000000000002D0
oooo000Y0?oood80000000<0o`3o000000000000P@0000000`3o0?l0oooo0?ooo`050?ooo`030000
003oool0000002H0oooo000Y0?ooo`030000003oool0oooo03l0oooo00<0o`3o0?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0o0?ooo`030?l0o`3oool0oooo00H0oooo00<000000?ooo`3oool09@3o
ool002T0oooo00<000000?ooo`3oool0?`3oool00`3o0?l0oooo0?ooo`210?ooo`030?l0o`3oool0
oooo00@0oooo0P0000000`3oool000000000000U0?ooo`00:@3oool00`000000oooo0?ooo`0o0?oo
o`030?l0o`3oool0oooo0840oooo00<0o`3o0?ooo`3oool0;P3oool002T0oooo00<000000?ooo`3o
ool0?`3oool00`3o0?l0oooo0?ooo`210?ooo`030?l0o`3oool0oooo02h0oooo000Y0?ooo`030000
003oool0oooo03l0oooo00<0o`3o0?ooo`3oool0P03oool00`3o0?l0oooo0?ooo`0_0?ooo`00:@3o
ool00`000000oooo0?ooo`0o0?ooo`030?l0o`3oool0oooo0800oooo00<0o`3o0?ooo`3oool0;`3o
ool002T0oooo00<000000?ooo`3oool0?`3oool00`3o0?l0oooo0?ooo`200?ooo`030?l0o`3oool0
oooo02l0oooo000Y0?ooo`030000003oool0oooo03l0oooo00<0o`3o0?ooo`3oool0P03oool00`3o
0?l0oooo0?ooo`0_0?ooo`00:@3oool00`000000oooo0?ooo`0o0?ooo`030?l0o`3oool0oooo0800
oooo00<0o`3o0?ooo`3oool0;`3oool002T0oooo00<000000?ooo`3oool0?`3oool00`3o0?l0oooo
0?ooo`200?ooo`030?l0o`3oool0oooo02l0oooo000Y0?ooo`030000003oool0oooo03l0oooo00<0
o`3o0?ooo`3oool0P03oool00`3o0?l0oooo0?ooo`0_0?ooo`00:@3oool00`000000oooo0?ooo`10
0?ooo`030?l0o`3oool0oooo07h0oooo00<0o`3o0?ooo`3oool0<03oool002T0oooo00<000000?oo
o`3oool0@03oool00`3o0?l0oooo0?ooo`1n0?ooo`030?l0o`3oool0oooo0300oooo000Y0?ooo`03
0000003oool0oooo0400oooo00<0o`3o0?ooo`3oool0OP3oool00`3o0?l0oooo0?ooo`0`0?ooo`00
:@3oool00`000000oooo0?ooo`100?ooo`030?l0o`3oool0oooo07d0oooo00<0o`3o0?ooo`3oool0
<@3oool002T0oooo00<000000?ooo`3oool0@@3oool00`3o0?l0oooo0?ooo`1l0?ooo`030?l0o`3o
ool0oooo0340oooo000Y0?ooo`030000003oool0oooo0440oooo00<0o`3o0?ooo`3oool0O03oool0
0`3o0?l0oooo0?ooo`0a0?ooo`00:@3oool00`000000oooo0?ooo`110?ooo`030?l0o`3oool0oooo
07`0oooo00<0o`3o0?ooo`3oool0<@3oool002T0oooo00<000000?ooo`3oool0@P3oool00`3o0?l0
oooo0?ooo`1j0?ooo`030?l0o`3oool0oooo0380oooo000Y0?ooo`030000003oool0oooo0480oooo
00<0o`3o0?ooo`3oool0NP3oool00`3o0?l0oooo0?ooo`0b0?ooo`00:@3oool00`000000oooo0?oo
o`120?ooo`030?l0o`3oool0oooo07X0oooo00<0o`3o0?ooo`3oool0<P3oool002T0oooo00<00000
0?ooo`3oool0@P3oool00`3o0?l0oooo0?ooo`1j0?ooo`030?l0o`3oool0oooo0380oooo000Y0?oo
o`030000003oool0oooo04<0oooo00<0o`3o0?ooo`3oool0N@3oool00`3o0?l0oooo0?ooo`0b0?oo
o`00:@3oool00`000000oooo0?ooo`130?ooo`030?l0o`3oool0oooo07P0oooo00<0o`3o0?ooo`3o
ool0<`3oool002T0oooo00<000000?ooo`3oool0@`3oool00`3o0?l0oooo0?ooo`1h0?ooo`030?l0
o`3oool0oooo03<0oooo000Y0?ooo`030000003oool0oooo04@0oooo00<0o`3o0?ooo`3oool0M`3o
ool00`3o0?l0oooo0?ooo`0c0?ooo`00:@3oool00`000000oooo0?ooo`140?ooo`030?l0o`3oool0
oooo07H0oooo00<0o`3o0?ooo`3oool0=03oool002T0oooo00<000000?ooo`3oool0A@3oool00`3o
0?l0oooo0?ooo`1e0?ooo`030?l0o`3oool0oooo03@0oooo000Y0?ooo`030000003oool0oooo04D0
oooo00<0o`3o0?ooo`3oool0M03oool00`3o0?l0oooo0?ooo`0e0?ooo`00:@3oool00`000000oooo
0?ooo`160?ooo`030?l0o`3oool0oooo07<0oooo00<0o`3o0?ooo`3oool0=@3oool002T0oooo00<0
00000?ooo`3oool0AP3oool00`3o0?l0oooo0?ooo`1b0?ooo`030?l0o`3oool0oooo03H0oooo000Y
0?ooo`030000003oool0oooo04L0oooo00<0o`3o0?ooo`3oool0L@3oool00`3o0?l0oooo0?ooo`0f
0?ooo`00:@3oool00`000000oooo0?ooo`180?ooo`030?l0o`3oool0oooo06l0oooo00<0o`3o0?oo
o`3oool0=`3oool002T0oooo00<000000?ooo`3oool0B03oool00`3o0?l0oooo0?ooo`1^0?ooo`03
0?l0o`3oool0oooo03P0oooo000Y0?ooo`030000003oool0oooo04T0oooo00<0o`3o0?ooo`3oool0
K@3oool00`3o0?l0oooo0?ooo`0h0?ooo`00:@3oool00`000000oooo0?ooo`1:0?ooo`030?l0o`3o
ool0oooo06/0oooo00<0o`3o0?ooo`3oool0>@3oool002T0oooo00<000000?ooo`3oool0B`3oool0
0`3o0?l0oooo0?ooo`1Y0?ooo`030?l0o`3oool0oooo03X0oooo000Y0?ooo`030000003oool0oooo
04/0oooo00<0o`3o0?ooo`3oool0J@3oool00`3o0?l0oooo0?ooo`0j0?ooo`00:@3oool00`000000
oooo0?ooo`1<0?ooo`030?l0o`3oool0oooo06L0oooo00<0o`3o0?ooo`3oool0>`3oool002T0oooo
00<000000?ooo`3oool0C@3oool00`3o0?l0oooo0?ooo`1V0?ooo`030?l0o`3oool0oooo03/0oooo
000Y0?ooo`030000003oool0oooo04d0oooo00<0o`3o0?ooo`3oool0I@3oool00`3o0?l0oooo0?oo
o`0l0?ooo`00:@3oool00`000000oooo0?ooo`1>0?ooo`030?l0o`3oool0oooo06<0oooo00<0o`3o
0?ooo`3oool0?@3oool002T0oooo00<000000?ooo`3oool0C`3oool00`3o0?l0oooo0?ooo`1Q0?oo
o`030?l0o`3oool0oooo03h0oooo000Y0?ooo`030000003oool0oooo0500oooo00<0o`3o0?ooo`3o
ool0G`3oool00`3o0?l0oooo0?ooo`0o0?ooo`00:@3oool00`000000oooo0?ooo`1@0?ooo`030?l0
o`3oool0oooo05h0oooo00<0o`3o0?ooo`3oool0@03oool002T0oooo00<000000?ooo`3oool0D@3o
ool00`3o0?l0oooo0?ooo`1L0?ooo`030?l0o`3oool0oooo0440oooo000Y0?ooo`030000003oool0
oooo0580oooo00<0o`3o0?ooo`3oool0FP3oool00`3o0?l0oooo0?ooo`120?ooo`00:@3oool00`00
0000oooo0?ooo`1C0?ooo`030?l0o`3oool0oooo05P0oooo00<0o`3o0?ooo`3oool0@`3oool002T0
oooo00<000000?ooo`3oool0E03oool20?l0oeL0oooo00<0o`3o0?ooo`3oool0A03oool002T0oooo
00<000000?ooo`3oool0EP3oool00`3o0?l0oooo0?ooo`1B0?ooo`80o`3oA`3oool002T0oooo00<0
00000?ooo`3oool0E`3oool00`3o0?l0oooo0?ooo`1@0?ooo`030?l0o`3oool0oooo04L0oooo000Y
0?ooo`030000003oool0oooo05P0oooo00<0o`3o0?ooo`3oool0CP3oool00`3o0?l0oooo0?ooo`18
0?ooo`00:@3oool00`000000oooo0?ooo`1I0?ooo`80o`3oC@3oool00`3o0?l0oooo0?ooo`190?oo
o`00:@3oool00`000000oooo0?ooo`1K0?ooo`030?l0o`3oool0oooo04P0oooo0P3o0?m<0?ooo`00
:@3oool00`000000oooo0?ooo`1L0?ooo`030?l0o`3oool0oooo04D0oooo0P3o0?m>0?ooo`00:@3o
ool00`000000oooo0?ooo`1M0?ooo`80o`3o@`3oool20?l0oe00oooo000Y0?ooo`030000003oool0
oooo05l0oooo0P3o0?m00?ooo`030?l0o`3oool0oooo0500oooo000Y0?ooo`030000003oool0oooo
0640oooo0P3o0?ll0?ooo`80o`3oD`3oool002T0oooo00<000000?ooo`3oool0H`3oool20?l0ocP0
oooo0P3o0?mE0?ooo`00:@3oool00`000000oooo0?ooo`1U0?ooo`80o`3o=03oool20?l0oeL0oooo
000Y0?ooo`030000003oool0oooo06L0oooo0P3o0?l`0?ooo`80o`3oF@3oool002T0oooo00<00000
0?ooo`3oool0J@3oool40?l0obX0oooo0P3o0?mK0?ooo`00:@3oool00`000000oooo0?ooo`1]0?oo
o`<0o`3o903oool30?l0oed0oooo000Q0?ooo`D000000`3oool00`000000oooo0?ooo`1`0?ooo`80
o`3o7P3oool40?l0of00oooo000S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
LP3oool70?l0oa40oooo1P3o0?mT0?ooo`008`3oool00`000000oooo0?ooo`030?ooo`800000NP3o
oolA0?l0ofX0oooo000S0?ooo`030000003oool0oooo0?X0oooo000S0?ooo`030000003oool0oooo
0?X0oooo000R0?ooo`800000o03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool002L0oooo0P00003g0?ooo`00:03oool00`000000oooo0?ooo`3e0?ooo`00:@3o
ool00`000000oooo0?ooo`3d0?ooo`00:03oool00`000000oooo0000003e0?ooo`009`3oool01000
0000oooo0?ooo`00003e0?ooo`009P3oool3000000030?ooo`00000000000?@0oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {94.9375, 0}} -> {0, 0, 0, 0}}],
  "  "
}], "Text"],

Cell[TextData[{
  "Solution.  The function  ",
  Cell[BoxData[
      \(z \((t)\) = 2 + \[ExponentialE]\^\(\[ImaginaryI]\ t\)\)]],
  ",  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] \[Pi]\)]],
  "  is a parametrization for ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".  We apply Theorem 6.1 with  ",
  Cell[BoxData[
      \(f \((z)\) = 1\/\(z\  - \ 2\)\)]],
  ".  (Note: ",
  Cell[BoxData[
      \(f \((z \((t)\))\) = 1\/\(z \((t)\)\  - \ 2\)\)]],
  "), and  ",
  Cell[BoxData[
      \(z' \((t)\) = \[ImaginaryI]\ \[ExponentialE]\^\(\[ImaginaryI]\ \
t\)\)]],
  ".)  Hence  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\ 
          1\/\(z - 2\)\ \[DifferentialD]z\  = \(\[Integral]\_0\%\[Pi]\( 
                  1\/\(z \((t)\)\  - \ 2\)\) 
              z' \((t)\) \[DifferentialD]t\  = \ \(\[Integral]\_0\%\[Pi]\( 
                    1\/\(2 + \[ExponentialE]\^\(\[ImaginaryI]\ t\)\  - \ 
                      2\)\) \[ImaginaryI]\ \(\[ExponentialE]\^\(\[ImaginaryI]\
\ t\)\) \[DifferentialD]t\  = \ \(\[Integral]\_0\%\[Pi] \[ImaginaryI]\ \
\[DifferentialD]t\  = \ \[ImaginaryI]\ \[Pi]\)\)\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 6.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = 1\/\(z\  - \ 2\)\)],
    AspectRatioFixed->True],
  "  and set up the parameterization and compute the contour integral."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[t, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, int, val, V];\)\ \), "\n", 
    \(\(f[z_]\  = \ 1\/\(z\  - \ 2\);\)\ \), "\n", 
    \(\(z[t_]\  = \ 
        2\  + \ \[ExponentialE]\^\(\[ImaginaryI]\ t\);\)\ \), "\n", 
    \(\(int\  = \ \[Integral]f[z[t]] \(z'\)[
              t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(val\  = \ \[Integral]\_0\%\[Pi] f[z[t]] \(z'\)[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(V[t_] = ComplexExpand[{Re[z[t]], Im[z[t]]}];\)\ \), "\n", 
    \(\(Print["\<               f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<               z[t] = \>", z[t]];\)\ \), "\n", 
    \(\(Print["\<            f[z[t]] = \>", f[z[t]]];\)\ \), "\n", 
    \(\(Print["\<              z'[t] = \>", \(z'\)[
          t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       f[z[t]]z'[t] = \>", 
        f[z[t]], \(z'\)[t]];\)\ \), "\n", 
    \(\(Print["\<       f[z[t]]z'[t] = \>", 
        f[z[t]] \(z'\)[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<    \[Integral]f[z[t]]z'[t]\[DifferentialD]t = \>", 
        int];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(\[Integral]\_0\%\[Pi]\)f[z[t]]z'[t]\
\[DifferentialD]t = \>\"", val];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[V[t]], {t, 0, \[Pi]}, 
        PlotRange \[Rule] {{0, 3}, {0, 1}}, AspectRatio \[Rule] 1\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[0, 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\<\[DifferentialD]z = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<C: z[t] = \>", 
        z[t], "\<,  for  0 \[LessEqual] t \[LessEqual] \[Pi].\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tTo help convince yourself that the value of the integral is independent \
of the parametrization chosen for the given contour, try working through \
Example 6.8 with  ",
  Cell[BoxData[
      \(z \((t)\) = 2 + \[ExponentialE]\^\(\[ImaginaryI]\[Pi]\ t\)\)]],
  ",  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tA convenient bookkeeping device can help you remember how to apply \
Theorem 6.1.  \n\nBecause  ",
  Cell[BoxData[
      \(\[Integral]\_C\ 
          1\/\(z - 2\)\ \[DifferentialD]z\  = \[Integral]\_a\%b\( 
                1\/\(z \((t)\)\  - \ 2\)\) z' \((t)\) \[DifferentialD]t\)]],
  ",  you can symbolically equate ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " with ",
  StyleBox["z(t)",
    FontFamily->"Courier New"],
  " and ",
  Cell[BoxData[
      \(\[DifferentialD]z\)]],
  " with  ",
  Cell[BoxData[
      \(z' \((t)\) \[DifferentialD]t\)]],
  ".  \n\nThese identities should be easy to remember because ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " is supposed to be a point on the contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " parametrized by ",
  StyleBox["z(t)",
    FontFamily->"Courier New"],
  ", and ",
  Cell[BoxData[
      \(\[DifferentialD]z\/\[DifferentialD]t\  = \ z' \((t)\)\)]],
  ", according to the Leibniz notation for the derivative."
}], "Text"],

Cell[TextData[{
  "\tIf  ",
  Cell[BoxData[
      \(z \((t)\)\  = \ x \((t)\) + \[ImaginaryI]\ y \((t)\)\)]],
  ",  then by the preceding paragraph we have\n\n",
  StyleBox["(6-13)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[DifferentialD]z\  = \ \(z' \((t)\) \[DifferentialD]t\  = \ \(\((x' \
\((t)\) + \[ImaginaryI]\ y' \((t)\))\) \[DifferentialD]t\  = \ \
\[DifferentialD]x\  + \ \[ImaginaryI]\ \[DifferentialD]y\)\)\)]],
  "  \n\nwhere ",
  Cell[BoxData[
      RowBox[{\(\[DifferentialD]x\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(\[DifferentialD]y\)}]]],
  " are the differentials for ",
  Cell[BoxData[
      RowBox[{"x", \((t)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "y", \((t)\)}]]],
  ", respectively (i.e., ",
  Cell[BoxData[
      \(\[DifferentialD]x\)]],
  " is equated with ",
  Cell[BoxData[
      \(x' \((t)\) \[DifferentialD]t\)]],
  ", etc.).  The expression ",
  Cell[BoxData[
      \(\[DifferentialD]z\)]],
  " is often called the complex differential of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ". Just as ",
  Cell[BoxData[
      RowBox[{\(\[DifferentialD]x\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(\[DifferentialD]y\)}]]],
  " are intuitively considered to be small segments along the ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " axes in real variables, we can think of dz as representing a tiny piece \
of the contour  ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".  Moreover, if we write  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(\[DifferentialD]z\)\(|\)\)\  = \ \(\(\(|\)\(\((x' \((t)\) + \
\[ImaginaryI]\ y' \((t)\))\) \[DifferentialD]t\)\(|\)\)\  = \ \(\(\(|\)\((x' \
\((t)\) + \[ImaginaryI]\ y' \((t)\))\)\(|\)\(\[DifferentialD]t\)\)\ \  = \ \(\
\@\(\([x' \((t)\)]\)\^2 + \([y' \((t)\)]\)\^2\)\) \(\(\[DifferentialD]t\)\(\ \
\)\)\)\)\)]],
  "\n\nwe can put Equation ",
  StyleBox["(6-11)",
    FontColor->RGBColor[0, 0, 1]],
  " into the form  \n\n",
  StyleBox["(6-14)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(L \((C)\)\ \  = \ \ \(\[Integral]\_a\%b\ \(\@\(\([x' \((t)\)]\)\^2 + \
\([y' \((t)\)]\)\^2\)\) \[DifferentialD]t\ \  = \ \ \[Integral]\+C\ \(\(|\)\(\
\[DifferentialD]z\)\(|\)\)\)\)]],
  ".   \n\nso we can think of ",
  Cell[BoxData[
      \(\(\(|\)\(\[DifferentialD]z\)\(|\)\)\)]],
  " as representing the length of ",
  Cell[BoxData[
      \(\[DifferentialD]z\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tSuppose   ",
  Cell[BoxData[
      \(f \((z)\) = u \((z)\) + \[ImaginaryI]\ v \((t)\)\)]],
  " , and  ",
  Cell[BoxData[
      \(z \((t)\) = x \((t)\) + \[ImaginaryI]\ y \((t)\)\)]],
  "  is a parametrization for the contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".  Then\n\n",
  StyleBox["(6-15)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_C\ 
          f \((z)\)\ \[DifferentialD]z\ \  = \ \ \[Integral]\_a\%b\ 
          f \((z \((t)\))\) 
            z' \((t)\) \[DifferentialD]t\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\
\[Integral]\_a\%b\((u \((z \((t)\))\) + \[ImaginaryI]\ v \((z \((t)\))\))\) \
\((x' \((t)\) + \[ImaginaryI]\ y' \((t)\))\) \[DifferentialD]t\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\
\[Integral]\_a\%b\([u \((z \((t)\))\)\ x' \((t)\) - 
                v \((z \((t)\))\)\ y' \((t)\)]\) \[DifferentialD]t\)\)\ \ \), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(+\ \ \
\[ImaginaryI]\)\ \(\[Integral]\_a\%b\([v \((z \((t)\))\) x' \((t)\) + 
                u \((z \((t)\))\) 
                  y' \((t)\)]\) \[DifferentialD]t\)\)\(\[IndentingNewLine]\)
      \(\ \)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\
\[Integral]\_a\%b\((u\ x' - 
                  v\ \ y')\) \[DifferentialD]t\ \  + \ \ \[ImaginaryI]\ \(\
\[Integral]\_a\%b\((v\ x' + u\ y')\) \[DifferentialD]t\)\)\)\)}]],
  "  \n\nwhere we are equating ",
  StyleBox["u(t)",
    FontFamily->"Courier New"],
  " with ",
  StyleBox["u(z(t))",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["x'",
    FontFamily->"Courier New"],
  " with ",
  StyleBox["x'(t)",
    FontFamily->"Courier New"],
  ", and so on. "
}], "Text"],

Cell[TextData[{
  "\tIf we use the differentials given in Equation ",
  StyleBox["(6-13)",
    FontColor->RGBColor[0, 0, 1]],
  ", then we can write Equation ",
  StyleBox["(6-15)",
    FontColor->RGBColor[0, 0, 1]],
  " in terms of line integrals of the real-valued functions ",
  StyleBox["u(t)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v(t)",
    FontFamily->"Courier New"],
  " , giving\n\n",
  StyleBox["(6-16)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\ 
          f \((z)\)\ \[DifferentialD]z\ \  = \ \ \[Integral]\_a\%b\ 
            u \[DifferentialD]x\  - 
          v\ \[DifferentialD]y\ \  + \ \ \[ImaginaryI]\ \(\[Integral]\_a\%b\ 
              v\ \[DifferentialD]x\)\  + u\ \[DifferentialD]y\)]],
  ",\n\nwhich is easy to remember if we recall that symbolically\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\ \[DifferentialD]z\ \  = \ \((u + \[ImaginaryI]\ v)\) \
\((\[DifferentialD]x + \[ImaginaryI] \[DifferentialD]y)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(u \
\[DifferentialD]x\  - 
          v\ \[DifferentialD]y\ \  + \ \[ImaginaryI] \((\ 
              v\ \[DifferentialD]x\  + u\ \[DifferentialD]y)\)\)\)\)}]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tWe emphasize that Equation ",
  StyleBox["(6-16)",
    FontColor->RGBColor[0, 0, 1]],
  " is merely a notational device for applying Theorem 6.1. You should \
carefully apply Theorem 6.1as illustrated in Examples 6.7 and 6.8 before \
using any shortcuts suggested by the latter."
}], "Text"],

Cell[TextData[{
  StyleBox["Example  6.9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Integral]\_\(C\_1\)\ 
          z\ \[DifferentialD]z\  = \ \(\[Integral]\_\(C\_2\)\ 
            z\ \[DifferentialD]z\  = \ 4 + 2  \[ImaginaryI]\)\)]],
  ",   \nwhere  ",
  Cell[BoxData[
      \(C\_1\)]],
  " is the line segment from  ",
  Cell[BoxData[
      RowBox[{\(-1\), "-", 
        RowBox[{"\[ImaginaryI]", "  ", 
          StyleBox["to",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", "3"}], "+", "\[ImaginaryI]"}]]],
  ",  and ",
  Cell[BoxData[
      \(C\_2\)]],
  " is the portion of the parabola  ",
  Cell[BoxData[
      \(x = y\^2 + 2  y\)]],
  "  joining  ",
  Cell[BoxData[
      RowBox[{\(-1\), "-", 
        RowBox[{"\[ImaginaryI]", "  ", 
          StyleBox["to",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", "3"}], "+", "\[ImaginaryI]"}]]],
  ",  as indicated in Figure 6.8.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.25 0.333333 0.333333 [
[0 .32083 -6 -9 ]
[0 .32083 6 0 ]
[.5 .32083 -3 -9 ]
[.5 .32083 3 0 ]
[.75 .32083 -3 -9 ]
[.75 .32083 3 0 ]
[1 .32083 -3 -9 ]
[1 .32083 3 0 ]
[1.025 .33333 0 -6.28125 ]
[1.025 .33333 10 6.28125 ]
[.2375 0 -12 -4.5 ]
[.2375 0 0 4.5 ]
[.2375 .66667 -6 -4.5 ]
[.2375 .66667 0 4.5 ]
[.25 .69167 -5 0 ]
[.25 .69167 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .33333 m
0 .33958 L
s
[(-1)] 0 .32083 0 1 Mshowa
.5 .33333 m
.5 .33958 L
s
[(1)] .5 .32083 0 1 Mshowa
.75 .33333 m
.75 .33958 L
s
[(2)] .75 .32083 0 1 Mshowa
1 .33333 m
1 .33958 L
s
[(3)] 1 .32083 0 1 Mshowa
0 .33333 m
1 .33333 L
s
gsave
1.025 .33333 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 0 m
.25625 0 L
s
[(-1)] .2375 0 1 0 Mshowa
.25 .66667 m
.25625 .66667 L
s
[(1)] .2375 .66667 1 0 Mshowa
.25 0 m
.25 .66667 L
s
gsave
.25 .69167 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
0 0 m
.04057 .02704 L
.08481 .05654 L
.12636 .08424 L
.16632 .11088 L
.20885 .13924 L
.2498 .16653 L
.29331 .19554 L
.33524 .22349 L
.37557 .25038 L
.41848 .27899 L
.4598 .30653 L
.49953 .33302 L
.54183 .36122 L
.58254 .38836 L
.62583 .41722 L
.66752 .44501 L
.70762 .47175 L
.7503 .5002 L
.79139 .52759 L
.83505 .5567 L
.87712 .58475 L
.9176 .61173 L
.96065 .64043 L
1 .66667 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 192},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000`2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00@`3oool500000=P0oooo00150?ooo`030000003o
ool0oooo0=P0oooo000<0?ooo`030?l0o`3oool0oooo03H0oooo00<000000?ooo`3oool00`3oool3
00000=80oooo000=0?ooo`80o`3o;P3oool4000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3B0?ooo`003`3oool00`3o0?l0oooo0?ooo`0c0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0dP3oool00100oooo00<0o`3o0?ooo`3oool0<@3oool2000000D0oooo
00<000000?ooo`3oool0dP3oool00140oooo0P3o0?lh0?ooo`030000003oool0oooo0=80oooo000C
0?ooo`030?l0o`3oool0oooo03D0oooo00<000000?ooo`3oool0dP3oool001@0oooo0P3o0?le0?oo
o`030000003oool0oooo0=80oooo000F0?ooo`030?l0o`3oool0oooo0380oooo00<000000?ooo`3o
ool0dP3oool001L0oooo0P3o0?lb0?ooo`030000003oool0oooo0=80oooo000I0?ooo`030?l0o`3o
ool0oooo02l0oooo00<000000?ooo`3oool0dP3oool001X0oooo0P3o0?l_0?ooo`030000003oool0
oooo0=80oooo000L0?ooo`80o`3o;@3oool00`000000oooo0?ooo`3B0?ooo`007P3oool00`3o0?l0
oooo0?ooo`0Z0?ooo`030000003oool0oooo0=80oooo000O0?ooo`80o`3o:P3oool00`000000oooo
0?ooo`3B0?ooo`008@3oool00`3o0?l0oooo0?ooo`0W0?ooo`030000003oool0oooo0=80oooo000R
0?ooo`80o`3o9`3oool00`000000oooo0?ooo`3B0?ooo`00903oool00`3o0?l0oooo0?ooo`0T0?oo
o`030000003oool0oooo0=80oooo000U0?ooo`80o`3o903oool00`000000oooo0?ooo`3B0?ooo`00
9`3oool20?l0ob80oooo00<000000?ooo`3oool0dP3oool002T0oooo00<0o`3o0?ooo`3oool07`3o
ool00`000000oooo0?ooo`3B0?ooo`00:P3oool20?l0oal0oooo00<000000?ooo`3oool0dP3oool0
02`0oooo00<0o`3o0?ooo`3oool0703oool00`000000oooo0?ooo`3B0?ooo`00;@3oool20?l0oa`0
oooo00<000000?ooo`3oool0dP3oool002l0oooo00<0o`3o0?ooo`3oool06@3oool00`000000oooo
0?ooo`3B0?ooo`00<03oool00`3o0?l0oooo0?ooo`0H0?ooo`030000003oool0oooo0=80oooo000a
0?ooo`80o`3o603oool00`000000oooo0?ooo`3B0?ooo`00<`3oool00`3o0?l0oooo0?ooo`0E0?oo
o`030000003oool0oooo0=80oooo000d0?ooo`80o`3o5@3oool00`000000oooo0?ooo`3B0?ooo`00
=P3oool00`3o0?l0oooo0?ooo`0B0?ooo`030000003oool0oooo0=80oooo000g0?ooo`80o`3o4P3o
ool00`000000oooo0?ooo`3B0?ooo`00>@3oool00`3o0?l0oooo0?ooo`0?0?ooo`030000003oool0
oooo0=80oooo000j0?ooo`80o`3o3`3oool00`000000oooo0?ooo`3B0?ooo`00?03oool20?l0o`d0
oooo00<000000?ooo`3oool0dP3oool003h0oooo00<0o`3o0?ooo`3oool02P3oool00`000000oooo
0?ooo`3B0?ooo`00?`3oool20?l0o`X0oooo00<000000?ooo`3oool0dP3oool00440oooo00<0o`3o
0?ooo`3oool01`3oool00`000000oooo0?ooo`3B0?ooo`00@P3oool20?l0o`L0oooo00<000000?oo
o`3oool0dP3oool004@0oooo00<0o`3o0?ooo`3oool0103oool00`000000oooo0?ooo`3B0?ooo`00
A@3oool00`3o0?l0oooo0?ooo`030?ooo`030000003oool0oooo0=80oooo00160?ooo`80o`3o0`3o
ool00`000000oooo0?ooo`3B0?ooo`00B03oool0103o0?l0oooo0?ooo`00003D0?ooo`00B@3oool2
0?l0o`030000003oool0oooo0=80oooo001;0?ooo`030?l0o`3oool0oooo0=80oooo001;0?ooo`03
0000003o0?l0o`3o0=80oooo001;0?ooo`040000003oool0oooo0?l0om40oooo001;0?ooo`040000
003oool0oooo0?ooo`80o`3oc`3oool004/0oooo00<000000?ooo`3oool00`3oool20?l0old0oooo
001;0?ooo`030000003oool0oooo00D0oooo00<0o`3o0?ooo`3oool0bP3oool004/0oooo00<00000
0?ooo`3oool01P3oool20?l0olX0oooo001;0?ooo`030000003oool0oooo00P0oooo00<0o`3o0?oo
o`3oool0a`3oool004/0oooo00<000000?ooo`3oool02@3oool20?l0olL0oooo001;0?ooo`030000
003oool0oooo00/0oooo00<0o`3o0?ooo`3oool0a03oool004/0oooo00<000000?ooo`3oool0303o
ool00`3o0?l0oooo0?ooo`330?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`80o`3o``3oool0
04/0oooo00<000000?ooo`3oool03`3oool00`3o0?l0oooo0?ooo`300?ooo`00B`3oool00`000000
oooo0?ooo`0@0?ooo`80o`3o`03oool004/0oooo00<000000?ooo`3oool04P3oool00`3o0?l0oooo
0?ooo`2m0?ooo`00B`3oool00`000000oooo0?ooo`0C0?ooo`80o`3o_@3oool004/0oooo00<00000
0?ooo`3oool05@3oool00`3o0?l0oooo0?ooo`2j0?ooo`00B`3oool00`000000oooo0?ooo`0F0?oo
o`80o`3o^P3oool004/0oooo00<000000?ooo`3oool0603oool20?l0okP0oooo001;0?ooo`030000
003oool0oooo01X0oooo00<0o`3o0?ooo`3oool0]@3oool004/0oooo00<000000?ooo`3oool06`3o
ool20?l0okD0oooo001;0?ooo`030000003oool0oooo01d0oooo00<0o`3o0?ooo`3oool0/P3oool0
04/0oooo00<000000?ooo`3oool07P3oool20?l0ok80oooo001;0?ooo`030000003oool0oooo0200
oooo00<0o`3o0?ooo`3oool0[`3oool004/0oooo00<000000?ooo`3oool08@3oool00`3o0?l0oooo
0?ooo`2^0?ooo`00B`3oool00`000000oooo0?ooo`0R0?ooo`80o`3o[P3oool004/0oooo00<00000
0?ooo`3oool0903oool00`3o0?l0oooo0?ooo`2[0?ooo`00B`3oool00`000000oooo0?ooo`0U0?oo
o`80o`3oZ`3oool004/0oooo00<000000?ooo`3oool09`3oool00`3o0?l0oooo0?ooo`2X0?ooo`00
B`3oool00`000000oooo0?ooo`0X0?ooo`80o`3oZ03oool004/0oooo00<000000?ooo`3oool0:P3o
ool00`3o0?l0oooo0?ooo`2U0?ooo`003@3oool5000003T0oooo00<000000?ooo`3oool0:`3oool2
0?l0o`d0oooo1@00000j0?ooo`@00000?03oool2000001L0oooo000?0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0;@3oool20?l0o`d0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0l0?ooo`040000003oool0oooo000001H0oooo000?0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0;`3oool00`3o0?l0oooo0?ooo`0:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0E0?ooo`001`3oool4000000@0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0`0?ooo`80o`3o2P3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0503oool000l0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0b0?ooo`030?l0o`3oool0oooo00L0oooo
00<000000?ooo`3oool0>P3oool010000000oooo0?ooo`00000k0?ooo`040000003oool0oooo0000
01H0oooo000>0?ooo`800000>`3oool00`000000oooo0?ooo`0c0?ooo`80o`3o1P3oool2000003d0
oooo0P00000m0?ooo`8000005`3oool004/0oooo00<000000?ooo`3oool0=@3oool00`3o0?l0oooo
0?ooo`2J0?ooo`00B`3oool00`000000oooo0?ooo`0f0?ooo`030?l0o`3oool0oooo09T0oooo001;
0?ooo`030000003oool0oooo03L0oooo0P3o0?nI0?ooo`00B`3oool00`000000oooo0?ooo`0i0?oo
o`030?l0o`3oool0oooo08H0oooo0P0000000`3oool000000000000;0?ooo`00B`3oool00`000000
oooo0?ooo`0j0?ooo`80o`3oQ`3oool00`000000oooo0000000<0?ooo`00303ooomn000000030?l0
o`000000000007`000002@3oool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo03`0oooo00<000000?l0o`3o0?l0?03oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo00D0oooo0P0000000`3oool000000000000;0?ooo`00B`3oool0
0`000000oooo0?ooo`0o0?ooo`030?l0o`3oool0oooo0900oooo001;0?ooo`030000003oool0oooo
0400oooo00<0o`3o0?ooo`3oool0S`3oool004/0oooo00<000000?ooo`3oool0@@3oool20?l0ohl0
oooo001;0?ooo`030000003oool0oooo04<0oooo00<0o`3o0?ooo`3oool0S03oool004/0oooo00<0
00000?ooo`3oool0A03oool20?l0oh`0oooo001;0?ooo`030000003oool0oooo04H0oooo00<0o`3o
0?ooo`3oool0R@3oool004/0oooo00<000000?ooo`3oool0A`3oool20?l0ohT0oooo001;0?ooo`03
0000003oool0oooo04T0oooo00<0o`3o0?ooo`3oool0QP3oool004/0oooo00<000000?ooo`3oool0
BP3oool20?l0ohH0oooo001;0?ooo`030000003oool0oooo04`0oooo0P3o0?n40?ooo`00B`3oool0
0`000000oooo0?ooo`1>0?ooo`030?l0o`3oool0oooo0840oooo001;0?ooo`030000003oool0oooo
04l0oooo0P3o0?n10?ooo`00B`3oool00`000000oooo0?ooo`1A0?ooo`030?l0o`3oool0oooo07h0
oooo001;0?ooo`030000003oool0oooo0580oooo0P3o0?mn0?ooo`00B`3oool00`000000oooo0?oo
o`1D0?ooo`030?l0o`3oool0oooo07/0oooo001;0?ooo`030000003oool0oooo05D0oooo0P3o0?mk
0?ooo`00B`3oool00`000000oooo0?ooo`1G0?ooo`80o`3oN@3oool004/0oooo00<000000?ooo`3o
ool0F@3oool00`3o0?l0oooo0?ooo`1f0?ooo`00B`3oool00`000000oooo0?ooo`1J0?ooo`80o`3o
MP3oool004/0oooo00<000000?ooo`3oool0G03oool00`3o0?l0oooo0?ooo`1c0?ooo`00B`3oool0
0`000000oooo0?ooo`1M0?ooo`80o`3oL`3oool004/0oooo00<000000?ooo`3oool0G`3oool00`3o
0?l0oooo0?ooo`1`0?ooo`00B`3oool00`000000oooo0?ooo`1P0?ooo`030?l0o`3oool0oooo06l0
oooo001;0?ooo`030000003oool0oooo0640oooo0P3o0?m_0?ooo`00B`3oool00`000000oooo0?oo
o`1S0?ooo`030?l0o`3oool0oooo06`0oooo001;0?ooo`030000003oool0oooo06@0oooo0P3o0?m/
0?ooo`00B`3oool00`000000oooo0?ooo`1V0?ooo`030?l0o`3oool0oooo06T0oooo001;0?ooo`03
0000003oool0oooo06L0oooo0P3o0?mY0?ooo`00B`3oool00`000000oooo0?ooo`1Y0?ooo`030?l0
o`3oool0oooo06H0oooo001;0?ooo`030000003oool0oooo06X0oooo00<0o`3o0?ooo`3oool0I@3o
ool004/0oooo00<000000?ooo`3oool0J`3oool20?l0ofD0oooo001;0?ooo`030000003oool0oooo
06d0oooo00<0o`3o0?ooo`3oool0HP3oool004/0oooo00<000000?ooo`3oool0KP3oool20?l0of80
oooo001;0?ooo`030000003oool0oooo0700oooo00<0o`3o0?ooo`3oool0G`3oool004/0oooo00<0
00000?ooo`3oool0L@3oool20?l0oel0oooo001;0?ooo`030000003oool0oooo07<0oooo00<0o`3o
0?ooo`3oool0G03oool004/0oooo00<000000?ooo`3oool0M03oool20?l0oe`0oooo001;0?ooo`03
0000003oool0oooo07H0oooo0P3o0?mJ0?ooo`00B`3oool00`000000oooo0?ooo`1h0?ooo`030?l0
o`3oool0oooo05L0oooo001;0?ooo`030000003oool0oooo07T0oooo0P3o0?mG0?ooo`00B`3oool0
0`000000oooo0?ooo`1k0?ooo`030?l0o`3oool0oooo05@0oooo001;0?ooo`030000003oool0oooo
07`0oooo0P3o0?mD0?ooo`00B`3oool00`000000oooo0?ooo`1n0?ooo`030?l0o`3oool0oooo0540
oooo001;0?ooo`030000003oool0oooo07l0oooo00<0o`3o0?ooo`3oool0D03oool004/0oooo00<0
00000?ooo`3oool0P03oool20?l0oe00oooo001;0?ooo`030000003oool0oooo0880oooo00<0o`3o
0?ooo`3oool0C@3oool004/0oooo00<000000?ooo`3oool0P`3oool20?l0odd0oooo001;0?ooo`03
0000003oool0oooo08D0oooo00<0o`3o0?ooo`3oool0BP3oool004/0oooo00<000000?ooo`3oool0
QP3oool20?l0odX0oooo001;0?ooo`030000003oool0oooo08P0oooo00<0o`3o0?ooo`3oool0A`3o
ool004/0oooo00<000000?ooo`3oool0R@3oool20?l0odL0oooo001;0?ooo`030000003oool0oooo
08/0oooo0P3o0?m50?ooo`00B`3oool00`000000oooo0?ooo`2=0?ooo`030?l0o`3oool0oooo0480
oooo001;0?ooo`030000003oool0oooo08h0oooo0P3o0?m20?ooo`00B`3oool00`000000oooo0?oo
o`2@0?ooo`030?l0o`3oool0oooo03l0oooo001;0?ooo`030000003oool0oooo0940oooo0P3o0?lo
0?ooo`00B`3oool00`000000oooo0?ooo`2C0?ooo`030?l0o`3oool0oooo03`0oooo001;0?ooo`03
0000003oool0oooo09@0oooo0P3o0?ll0?ooo`00B`3oool00`000000oooo0?ooo`2F0?ooo`80o`3o
>P3oool004/0oooo00<000000?ooo`3oool0V03oool00`3o0?l0oooo0?ooo`0g0?ooo`00B`3oool0
0`000000oooo0?ooo`2I0?ooo`80o`3o=`3oool004/0oooo00<000000?ooo`3oool0V`3oool00`3o
0?l0oooo0?ooo`0d0?ooo`00B`3oool00`000000oooo0?ooo`2L0?ooo`80o`3o=03oool004/0oooo
00<000000?ooo`3oool0WP3oool00`3o0?l0oooo0?ooo`0a0?ooo`00B`3oool00`000000oooo0?oo
o`2O0?ooo`030?l0o`3oool0oooo0300oooo001;0?ooo`030000003oool0oooo0:00oooo0P3o0?l`
0?ooo`00B`3oool00`000000oooo0?ooo`2R0?ooo`030?l0o`3oool0oooo02d0oooo001;0?ooo`03
0000003oool0oooo0:<0oooo0P3o0?l]0?ooo`00B`3oool00`000000oooo0?ooo`2U0?ooo`030?l0
o`3oool0oooo02X0oooo001;0?ooo`030000003oool0oooo0:H0oooo0P3o0?lZ0?ooo`00B`3oool0
0`000000oooo0?ooo`2X0?ooo`030?l0o`3oool0oooo02L0oooo001;0?ooo`030000003oool0oooo
0:T0oooo0P3o0?lW0?ooo`00B`3oool00`000000oooo0?ooo`2[0?ooo`80o`3o9@3oool004/0oooo
00<000000?ooo`3oool0[@3oool00`3o0?l0oooo0?ooo`0R0?ooo`00B`3oool00`000000oooo0?oo
o`2^0?ooo`80o`3o8P3oool004/0oooo00<000000?ooo`3oool0/03oool00`3o0?l0oooo0?ooo`0O
0?ooo`00B`3oool00`000000oooo0?ooo`2a0?ooo`80o`3o7`3oool004/0oooo00<000000?ooo`3o
ool0/`3oool00`3o0?l0oooo0?ooo`0L0?ooo`00B`3oool00`000000oooo0?ooo`2d0?ooo`030?l0
o`3oool0oooo01/0oooo001;0?ooo`030000003oool0oooo0;D0oooo0P3o0?lK0?ooo`00@`3oool5
000000<0oooo00<000000?ooo`3oool0]`3oool00`3o0?l0oooo0?ooo`0H0?ooo`00A@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0;P0oooo0P3o0?lH0?ooo`00A@3oool00`000000
oooo0?ooo`030?ooo`<00000^P3oool00`3o0?l0oooo0?ooo`0E0?ooo`00A@3oool00`000000oooo
0?ooo`3H0?ooo`00A@3oool00`000000oooo0?ooo`3H0?ooo`00A03oool200000=X0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo00190?oo
o`800000e@3oool004X0oooo00<000000?ooo`3oool0d`3oool004/0oooo00<000000?ooo`3oool0
dP3oool004X0oooo00<000000?ooo`000000d`3oool004T0oooo00@000000?ooo`3oool00000d`3o
ool004P0oooo0`0000000`3oool000000000003B0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 287}, {191, 0}} -> {-1, -1, 0, 0}}],
  StyleBox["   ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.25 0.333333 0.333333 [
[0 .32083 -6 -9 ]
[0 .32083 6 0 ]
[.5 .32083 -3 -9 ]
[.5 .32083 3 0 ]
[.75 .32083 -3 -9 ]
[.75 .32083 3 0 ]
[1 .32083 -3 -9 ]
[1 .32083 3 0 ]
[1.025 .33333 0 -6.28125 ]
[1.025 .33333 10 6.28125 ]
[.2375 0 -12 -4.5 ]
[.2375 0 0 4.5 ]
[.2375 .66667 -6 -4.5 ]
[.2375 .66667 0 4.5 ]
[.25 .69167 -5 0 ]
[.25 .69167 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .33333 m
0 .33958 L
s
[(-1)] 0 .32083 0 1 Mshowa
.5 .33333 m
.5 .33958 L
s
[(1)] .5 .32083 0 1 Mshowa
.75 .33333 m
.75 .33958 L
s
[(2)] .75 .32083 0 1 Mshowa
1 .33333 m
1 .33958 L
s
[(3)] 1 .32083 0 1 Mshowa
0 .33333 m
1 .33333 L
s
gsave
1.025 .33333 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 0 m
.25625 0 L
s
[(-1)] .2375 0 1 0 Mshowa
.25 .66667 m
.25625 .66667 L
s
[(1)] .2375 .66667 1 0 Mshowa
.25 0 m
.25 .66667 L
s
gsave
.25 .69167 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
0 0 m
0 .00082 L
1e-005 .00157 L
1e-005 .00244 L
2e-005 .00325 L
5e-005 .00471 L
9e-005 .00628 L
.00014 .00802 L
.00022 .00986 L
.00039 .01317 L
.00062 .01658 L
.00088 .01977 L
.00165 .02704 L
.00267 .03446 L
.00383 .04125 L
.00719 .05654 L
.01097 .06983 L
.016 .08434 L
.02862 .11279 L
.04421 .14018 L
.06448 .16929 L
.08761 .19733 L
.11322 .22432 L
.14404 .25302 L
.17723 .28066 L
.21239 .30724 L
.25332 .33554 L
.29611 .36277 L
.34526 .39173 L
.39618 .41962 L
.44846 .44645 L
.50765 .475 L
.5681 .50248 L
.62942 .52891 L
.69819 .55705 L
.76772 .58413 L
.84529 .61293 L
.92352 .64067 L
1 .66667 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 192},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000`2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00@`3oool500000=P0oooo00150?ooo`030000003o
ool0oooo0=P0oooo000<0?ooo`03003o003oool0oooo03H0oooo00<000000?ooo`3oool00`3oool3
00000=80oooo000<0?ooo`03003o003oool0oooo02h0oooo100000040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0dP3oool000`0oooo00<00?l00?ooo`3oool0=P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0=80oooo000<0?ooo`03003o003oool0oooo03D0oooo
0P0000050?ooo`030000003oool0oooo0=80oooo000<0?ooo`03003o003oool0oooo03`0oooo00<0
00000?ooo`3oool0dP3oool000`0oooo00<00?l00?ooo`3oool0?03oool00`000000oooo0?ooo`3B
0?ooo`00303oool00`00o`00oooo0?ooo`0l0?ooo`030000003oool0oooo0=80oooo000=0?ooo`03
003o003oool0oooo03/0oooo00<000000?ooo`3oool0dP3oool000d0oooo00<00?l00?ooo`3oool0
>`3oool00`000000oooo0?ooo`3B0?ooo`003@3oool00`00o`00oooo0?ooo`0k0?ooo`030000003o
ool0oooo0=80oooo000=0?ooo`03003o003oool0oooo03/0oooo00<000000?ooo`3oool0dP3oool0
00d0oooo00<00?l00?ooo`3oool0>`3oool00`000000oooo0?ooo`3B0?ooo`003@3oool00`00o`00
oooo0?ooo`0k0?ooo`030000003oool0oooo0=80oooo000>0?ooo`03003o003oool0oooo03X0oooo
00<000000?ooo`3oool0dP3oool000h0oooo00<00?l00?ooo`3oool0>P3oool00`000000oooo0?oo
o`3B0?ooo`003P3oool00`00o`00oooo0?ooo`0j0?ooo`030000003oool0oooo0=80oooo000>0?oo
o`03003o003oool0oooo03X0oooo00<000000?ooo`3oool0dP3oool000l0oooo00<00?l00?ooo`3o
ool0>@3oool00`000000oooo0?ooo`3B0?ooo`003`3oool00`00o`00oooo0?ooo`0i0?ooo`030000
003oool0oooo0=80oooo000?0?ooo`03003o003oool0oooo03T0oooo00<000000?ooo`3oool0dP3o
ool00100oooo00<00?l00?ooo`3oool0>03oool00`000000oooo0?ooo`3B0?ooo`00403oool00`00
o`00oooo0?ooo`0h0?ooo`030000003oool0oooo0=80oooo000@0?ooo`03003o003oool0oooo03P0
oooo00<000000?ooo`3oool0dP3oool00140oooo00<00?l00?ooo`3oool0=`3oool00`000000oooo
0?ooo`3B0?ooo`004@3oool00`00o`00oooo0?ooo`0g0?ooo`030000003oool0oooo0=80oooo000B
0?ooo`03003o003oool0oooo03H0oooo00<000000?ooo`3oool0dP3oool00180oooo00<00?l00?oo
o`3oool0=P3oool00`000000oooo0?ooo`3B0?ooo`004`3oool00`00o`00oooo0?ooo`0e0?ooo`03
0000003oool0oooo0=80oooo000C0?ooo`03003o003oool0oooo03D0oooo00<000000?ooo`3oool0
dP3oool001@0oooo00<00?l00?ooo`3oool0=03oool00`000000oooo0?ooo`3B0?ooo`00503oool0
0`00o`00oooo0?ooo`0d0?ooo`030000003oool0oooo0=80oooo000E0?ooo`03003o003oool0oooo
03<0oooo00<000000?ooo`3oool0dP3oool001D0oooo00<00?l00?ooo`3oool0<`3oool00`000000
oooo0?ooo`3B0?ooo`005P3oool00`00o`00oooo0?ooo`0b0?ooo`030000003oool0oooo0=80oooo
000F0?ooo`03003o003oool0oooo0380oooo00<000000?ooo`3oool0dP3oool001L0oooo00<00?l0
0?ooo`3oool0<@3oool00`000000oooo0?ooo`3B0?ooo`00603oool00`00o`00oooo0?ooo`0`0?oo
o`030000003oool0oooo0=80oooo000H0?ooo`03003o003oool0oooo0300oooo00<000000?ooo`3o
ool0dP3oool001T0oooo00<00?l00?ooo`3oool0;`3oool00`000000oooo0?ooo`3B0?ooo`006@3o
ool00`00o`00oooo0?ooo`0_0?ooo`030000003oool0oooo0=80oooo000J0?ooo`03003o003oool0
oooo02h0oooo00<000000?ooo`3oool0dP3oool001/0oooo00<00?l00?ooo`3oool0;@3oool00`00
0000oooo0?ooo`3B0?ooo`006`3oool00`00o`00oooo0?ooo`0]0?ooo`030000003oool0oooo0=80
oooo000L0?ooo`03003o003oool0oooo02`0oooo00<000000?ooo`3oool0dP3oool001d0oooo00<0
0?l00?ooo`3oool0:`3oool00`000000oooo0?ooo`3B0?ooo`007P3oool00`00o`00oooo0?ooo`0Z
0?ooo`030000003oool0oooo0=80oooo000O0?ooo`03003o003oool0oooo02T0oooo00<000000?oo
o`3oool0dP3oool001l0oooo00<00?l00?ooo`3oool0:@3oool00`000000oooo0?ooo`3B0?ooo`00
803oool00`00o`00oooo0?ooo`0X0?ooo`030000003oool0oooo0=80oooo000Q0?ooo`03003o003o
ool0oooo02L0oooo00<000000?ooo`3oool0dP3oool00280oooo00<00?l00?ooo`3oool09P3oool0
0`000000oooo0?ooo`3B0?ooo`008`3oool00`00o`00oooo0?ooo`0U0?ooo`030000003oool0oooo
0=80oooo000T0?ooo`03003o003oool0oooo02@0oooo00<000000?ooo`3oool0dP3oool002D0oooo
0P00o`0T0?ooo`030000003oool0oooo0=80oooo000W0?ooo`03003o003oool0oooo0240oooo00<0
00000?ooo`3oool0dP3oool002P0oooo00<00?l00?ooo`3oool0803oool00`000000oooo0?ooo`3B
0?ooo`00:@3oool00`00o`00oooo0?ooo`0O0?ooo`030000003oool0oooo0=80oooo000Z0?ooo`03
003o003oool0oooo01h0oooo00<000000?ooo`3oool0dP3oool002/0oooo00<00?l00?ooo`3oool0
7@3oool00`000000oooo0?ooo`3B0?ooo`00;03oool00`00o`00oooo0?ooo`0L0?ooo`030000003o
ool0oooo0=80oooo000/0?ooo`03003o003oool0oooo01`0oooo00<000000?ooo`3oool0dP3oool0
02d0oooo00<00?l00?ooo`3oool06`3oool00`000000oooo0?ooo`3B0?ooo`00;P3oool00`00o`00
oooo0?ooo`0J0?ooo`030000003oool0oooo0=80oooo000_0?ooo`03003o003oool0oooo01T0oooo
00<000000?ooo`3oool0dP3oool00300oooo00<00?l00?ooo`3oool0603oool00`000000oooo0?oo
o`3B0?ooo`00<@3oool00`00o`00oooo0?ooo`0G0?ooo`030000003oool0oooo0=80oooo000b0?oo
o`800?l05`3oool00`000000oooo0?ooo`3B0?ooo`00=03oool00`00o`00oooo0?ooo`0D0?ooo`03
0000003oool0oooo0=80oooo000e0?ooo`03003o003oool0oooo01<0oooo00<000000?ooo`3oool0
dP3oool003H0oooo0P00o`0C0?ooo`030000003oool0oooo0=80oooo000h0?ooo`03003o003oool0
oooo0100oooo00<000000?ooo`3oool0dP3oool003T0oooo00<00?l00?ooo`3oool03`3oool00`00
0000oooo0?ooo`3B0?ooo`00>P3oool2003o00l0oooo00<000000?ooo`3oool0dP3oool000d0oooo
1@00000Z0?ooo`03003o003oool0oooo00`0oooo00<000000?ooo`3oool0>P3oool5000003X0oooo
1000000l0?ooo`8000005`3oool000l0oooo00<000000?ooo`3oool0:`3oool2003o00`0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03`0oooo00@0
00000?ooo`3oool000005P3oool000l0oooo00<000000?ooo`3oool0;@3oool00`00o`00oooo0?oo
o`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo01D0oooo00070?ooo`@00000103oool00`000000oooo0?ooo`0^
0?ooo`800?l02@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0D0?ooo`003`3oool00`000000oooo0?ooo`0`0?oo
o`03003o003oool0oooo00H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0j0?oo
o`040000003oool0oooo000003/0oooo00@000000?ooo`3oool000005P3oool000h0oooo0P00000c
0?ooo`800?l01P3oool00`000000oooo0?ooo`0k0?ooo`800000?@3oool2000003d0oooo0P00000G
0?ooo`00A@3oool00`00o`00oooo0?ooo`030?ooo`030000003oool0oooo0=80oooo00160?ooo`03
003o003oool0oooo0080oooo00<000000?ooo`3oool0dP3oool004L0oooo0P00o`020?ooo`030000
003oool0oooo0=80oooo00190?ooo`03003o003oool000000<@0oooo0P0000000`3oool000000000
000;0?ooo`00BP3oool2003o0<D0oooo00<000000?ooo`000000303oool000`0oooo@00000000`00
o`0000000000002j000000T0oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?ooo`3o
ool0?03oool010000000oooo003o0000o`0k0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000000000002`3oool004/0
oooo00D000000?ooo`3oool0oooo003o003@0?ooo`00B`3oool00`000000oooo0?ooo`020?ooo`80
0?l0cP3oool004/0oooo00<000000?ooo`3oool0103oool2003o0<`0oooo001;0?ooo`030000003o
ool0oooo00H0oooo00<00?l00?ooo`3oool0b@3oool004/0oooo00<000000?ooo`3oool01`3oool2
003o0<T0oooo001;0?ooo`030000003oool0oooo00T0oooo00<00?l00?ooo`3oool0aP3oool004/0
oooo00<000000?ooo`3oool02P3oool2003o0<H0oooo001;0?ooo`030000003oool0oooo00`0oooo
00<00?l00?ooo`3oool0``3oool004/0oooo00<000000?ooo`3oool03@3oool2003o0<<0oooo001;
0?ooo`030000003oool0oooo00l0oooo00<00?l00?ooo`3oool0`03oool004/0oooo00<000000?oo
o`3oool0403oool2003o0<00oooo001;0?ooo`030000003oool0oooo0180oooo00<00?l00?ooo`3o
ool0_@3oool004/0oooo00<000000?ooo`3oool04`3oool2003o0;d0oooo001;0?ooo`030000003o
ool0oooo01D0oooo00<00?l00?ooo`3oool0^P3oool004/0oooo00<000000?ooo`3oool05P3oool2
003o0;X0oooo001;0?ooo`030000003oool0oooo01P0oooo0P00o`2h0?ooo`00B`3oool00`000000
oooo0?ooo`0J0?ooo`800?l0]P3oool004/0oooo00<000000?ooo`3oool0703oool2003o0;@0oooo
001;0?ooo`030000003oool0oooo01h0oooo0P00o`2b0?ooo`00B`3oool00`000000oooo0?ooo`0P
0?ooo`800?l0/03oool004/0oooo00<000000?ooo`3oool08P3oool2003o0:h0oooo001;0?ooo`03
0000003oool0oooo02@0oooo0P00o`2/0?ooo`00B`3oool00`000000oooo0?ooo`0V0?ooo`800?l0
ZP3oool004/0oooo00<000000?ooo`3oool0:03oool2003o0:P0oooo001;0?ooo`030000003oool0
oooo02X0oooo0P00o`2V0?ooo`00B`3oool00`000000oooo0?ooo`0/0?ooo`800?l0Y03oool004/0
oooo00<000000?ooo`3oool0;P3oool3003o0:40oooo001;0?ooo`030000003oool0oooo0340oooo
0P00o`2O0?ooo`00B`3oool00`000000oooo0?ooo`0c0?ooo`800?l0W@3oool004/0oooo00<00000
0?ooo`3oool0=@3oool2003o09/0oooo001;0?ooo`030000003oool0oooo03L0oooo0P00o`2I0?oo
o`00B`3oool00`000000oooo0?ooo`0i0?ooo`800?l0U`3oool004/0oooo00<000000?ooo`3oool0
>`3oool2003o09D0oooo001;0?ooo`030000003oool0oooo03d0oooo0`00o`2B0?ooo`00B`3oool0
0`000000oooo0?ooo`100?ooo`800?l0T03oool004/0oooo00<000000?ooo`3oool0@P3oool2003o
08h0oooo001;0?ooo`030000003oool0oooo04@0oooo0P00o`2<0?ooo`00B`3oool00`000000oooo
0?ooo`160?ooo`800?l0RP3oool004/0oooo00<000000?ooo`3oool0B03oool2003o08P0oooo001;
0?ooo`030000003oool0oooo04X0oooo0P00o`260?ooo`00B`3oool00`000000oooo0?ooo`1<0?oo
o`<00?l0P`3oool004/0oooo00<000000?ooo`3oool0C`3oool2003o0840oooo001;0?ooo`030000
003oool0oooo0540oooo0P00o`1o0?ooo`00B`3oool00`000000oooo0?ooo`1C0?ooo`800?l0O@3o
ool004/0oooo00<000000?ooo`3oool0E@3oool2003o07/0oooo001;0?ooo`030000003oool0oooo
05L0oooo0P00o`1i0?ooo`00B`3oool00`000000oooo0?ooo`1I0?ooo`800?l0M`3oool004/0oooo
00<000000?ooo`3oool0F`3oool3003o07@0oooo001;0?ooo`030000003oool0oooo05h0oooo0P00
o`1b0?ooo`00B`3oool00`000000oooo0?ooo`1P0?ooo`<00?l0K`3oool004/0oooo00<000000?oo
o`3oool0H`3oool2003o06d0oooo001;0?ooo`030000003oool0oooo06D0oooo0`00o`1Z0?ooo`00
B`3oool00`000000oooo0?ooo`1X0?ooo`<00?l0I`3oool004/0oooo00<000000?ooo`3oool0J`3o
ool2003o06D0oooo001;0?ooo`030000003oool0oooo06d0oooo0`00o`1R0?ooo`00B`3oool00`00
0000oooo0?ooo`1`0?ooo`800?l0H03oool004/0oooo00<000000?ooo`3oool0LP3oool3003o05d0
oooo001;0?ooo`030000003oool0oooo07D0oooo0P00o`1K0?ooo`00B`3oool00`000000oooo0?oo
o`1g0?ooo`800?l0F@3oool004/0oooo00<000000?ooo`3oool0N@3oool3003o05H0oooo001;0?oo
o`030000003oool0oooo07`0oooo0P00o`1D0?ooo`00B`3oool00`000000oooo0?ooo`1n0?ooo`<0
0?l0D@3oool004/0oooo00<000000?ooo`3oool0P@3oool3003o04h0oooo001;0?ooo`030000003o
ool0oooo08@0oooo0`00o`1;0?ooo`00B`3oool00`000000oooo0?ooo`270?ooo`800?l0B@3oool0
04/0oooo00<000000?ooo`3oool0R@3oool3003o04H0oooo001;0?ooo`030000003oool0oooo08`0
oooo0`00o`130?ooo`00B`3oool00`000000oooo0?ooo`2?0?ooo`<00?l0@03oool004/0oooo00<0
00000?ooo`3oool0TP3oool3003o03d0oooo001;0?ooo`030000003oool0oooo09D0oooo0`00o`0j
0?ooo`00B`3oool00`000000oooo0?ooo`2H0?ooo`800?l0>03oool004/0oooo00<000000?ooo`3o
ool0VP3oool3003o03D0oooo001;0?ooo`030000003oool0oooo09d0oooo0`00o`0b0?ooo`00B`3o
ool00`000000oooo0?ooo`2P0?ooo`800?l0<03oool004/0oooo00<000000?ooo`3oool0XP3oool3
003o02d0oooo001;0?ooo`030000003oool0oooo0:D0oooo0`00o`0Z0?ooo`00B`3oool00`000000
oooo0?ooo`2X0?ooo`<00?l09`3oool004/0oooo00<000000?ooo`3oool0Z`3oool3003o02@0oooo
001;0?ooo`030000003oool0oooo0:h0oooo0P00o`0R0?ooo`00B`3oool00`000000oooo0?ooo`2`
0?ooo`<00?l07`3oool004<0oooo1@0000030?ooo`030000003oool0oooo0;<0oooo0`00o`0L0?oo
o`00A@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;H0oooo0`00o`0I0?ooo`00
A@3oool00`000000oooo0?ooo`030?ooo`<00000^@3oool2003o01L0oooo00150?ooo`030000003o
ool0oooo0=P0oooo00150?ooo`030000003oool0oooo0=P0oooo00140?ooo`800000fP3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool004T0
oooo0P00003E0?ooo`00BP3oool00`000000oooo0?ooo`3C0?ooo`00B`3oool00`000000oooo0?oo
o`3B0?ooo`00BP3oool00`000000oooo0000003C0?ooo`00B@3oool010000000oooo0?ooo`00003C
0?ooo`00B03oool3000000030?ooo`00000000000=80oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {191, 0}} -> {-1, -1, 0, 0}}],
  StyleBox["  \n\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.8",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0608.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The two contours ",
  Cell[BoxData[
      \(C\_1\)]],
  " and ",
  Cell[BoxData[
      \(C\_2\)]],
  " joining  ",
  Cell[BoxData[
      RowBox[{\(-1\), "-", 
        RowBox[{"\[ImaginaryI]", "  ", 
          StyleBox["to",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", "3"}], "+", "\[ImaginaryI]"}]]],
  "."
}], "Text"],

Cell[TextData[{
  "Solution.  The line segment joining ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{\(-1\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(-1\)}], ")"}], " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{"(", 
          RowBox[{"3", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1"}], ")"}]}]]],
  " is given by the slope intercept formula  ",
  Cell[BoxData[
      \(y = \(1\/2\) x - 1\/2\)]],
  ",  which can be written as  ",
  Cell[BoxData[
      \(x = 2  y + 1\)]],
  ".  \nIf we choose the parametrization  ",
  Cell[BoxData[
      \(y = t\)]],
  "  and  ",
  Cell[BoxData[
      \(x = 2  t + 1\)]],
  ",  we can write segment ",
  Cell[BoxData[
      \(C\_1\)]],
  " as\n\n\t\t\t",
  Cell[BoxData[
      \(\(C\_1\) : \ \ z \((t)\) = 2  t + 1 + \[ImaginaryI]\ t\)]],
  "   and   ",
  Cell[BoxData[
      \(dz = \((2 + \[ImaginaryI])\)\ dt\)]],
  "\n\nfor  ",
  Cell[BoxData[
      \(\(-1\) \[LessEqual] t \[LessEqual] 1\)]],
  ".\n\nAlong ",
  Cell[BoxData[
      \(C\_1\)]],
  " we have  ",
  Cell[BoxData[
      \(f \((z \((t)\))\) = 2  t + 1 + \[ImaginaryI]\ t\)]],
  ".  Applying Theorem 6.1 gives  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_\(C\_1\)\ 
          z\ \[DifferentialD]z\  = \ \(\[Integral]\_a\%b\( 
                  1\/\(z \((t)\)\  - \ 2\)\) 
              z' \((t)\) \[DifferentialD]t\  = \ \ \(\(=\)\(\ \)\(\[Integral]\
\_\(-1\)\%1\((2  t + 
                    1 + \[ImaginaryI]\ t)\) \((2 + \[ImaginaryI])\) \
\[DifferentialD]t\)\)\)\)]],
  ".  \n\nWe now multiply out the integrand and put it into its real and \
imaginary parts:  \n\n\t\t\t",
  Cell[BoxData[{
      \(\[Integral]\_\(C\_1\)\ 
          z\ \[DifferentialD]z\ \  = \ \ \[Integral]\_\(-1\)\%1\((2  t + 
                1 + \[ImaginaryI]\ t)\) \((2 + \[ImaginaryI])\) \
\[DifferentialD]t\ \[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(\[Integral]\_\(-1\)\%1\((3\ t + 
                2 + \[ImaginaryI]\ \((4\ t + 
                      1)\))\) \[DifferentialD]t\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(\[Integral]\_\(-1\)\%1\((3\ t + 
                  2)\) \[DifferentialD]t\  + \ \[ImaginaryI] \
\(\[Integral]\_\(-1\)\%1\((4\ t + 
                    1)\) \[DifferentialD]t\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(4\  + \ 
          2\ \[ImaginaryI]\)\)\)}]],
  "   "
}], "Text"],

Cell[TextData[{
  "Similarly, we can parametrize the portion of the parabola  ",
  Cell[BoxData[
      \(x = y\^2 + 2  y\)]],
  "  joining ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{\(-1\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(-1\)}], ")"}], " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{"(", 
          RowBox[{"3", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1"}], ")"}]}]]],
  " by  ",
  Cell[BoxData[
      \(y = t\)]],
  "  and ",
  Cell[BoxData[
      \(x = 2  t + 1\)]],
  " and  ",
  Cell[BoxData[
      \(x = t\^2 + 2  t\)]],
  " so that  \n\n\t\t\t",
  Cell[BoxData[
      \(\(C\_2\) : \ \ z \((t)\) = t\^2 + 2  t + \[ImaginaryI]\ t\)]],
  "   and   ",
  Cell[BoxData[
      \(dz = \((2  t + 2 + \[ImaginaryI])\)\ dt\)]],
  "\n\nfor  ",
  Cell[BoxData[
      \(\(-1\) \[LessEqual] t \[LessEqual] 1\)]],
  ".\n\nAlong ",
  Cell[BoxData[
      \(C\_2\)]],
  " we have  ",
  Cell[BoxData[
      \(f \((z \((t)\))\) = t\^2 + 2  t + \[ImaginaryI]\ t\)]],
  ".  Theorem 6.1 now gives  \n\n\t\t\t",
  Cell[BoxData[{
      \(\[Integral]\_\(C\_2\)\ 
          z\ \[DifferentialD]z\ \  = \ \ \[Integral]\_\(-1\)\%1\((t\^2 + 
                2  t + \[ImaginaryI]\ t)\) \((2  t + 
                2 + \[ImaginaryI])\) \[DifferentialD]t\ \[IndentingNewLine]\),
     "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(\[Integral]\_\(-1\)\%1\((2\ t\^3 + 6\ t\^2 + 
                3  t + \[ImaginaryI]\ \((3\ t\^2 + 
                      4  t)\))\) \[DifferentialD]t\)\)\n\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(\[Integral]\_\(-1\)\%1\((2\ t\^3 + 6\ t\^2 + 
                  3  t)\) \[DifferentialD]t\  + \ \[ImaginaryI] \(\[Integral]\
\_\(-1\)\%1\((3\ t\^2 + 4  t)\) \[DifferentialD]t\)\)\)\n\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(4\  + \ 
          2\ \[ImaginaryI]\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 6.9 (a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["\n(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the straight line segment connecting the points  ",
  Cell[BoxData[
      \(z\_1 = \(\(-1\) - i\ \ and\ \ z\_2 = 3 + i\)\)]],
  ",  set up the parameterization and compute the contour integral.  Enter \
the function  ",
  Cell[BoxData[
      \(f[z] = z\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[t, u, U, v, V, w, W, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, U1, U2, V1, V2, W1, W2, z1, z2];\)\ \), "\n", 
    \(\(f[z_]\  = \ z\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(z1[t_]\  = \ 2  t\  + \ 1\  + \ \[ImaginaryI]\ t;\)\ \), "\n", 
    \(\(w[t_]\  = \ ComplexExpand[f[z1[t]]\ \(z1'\)[t]];\)\ \), "\n", 
    \(\(u[t_]\  = \ ComplexExpand[Re[w[t]]];\)\ \), "\n", 
    \(\(v[t_]\  = \ ComplexExpand[Im[w[t]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<           f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<          \!\(z\_1\)[t] = \>\"", z1[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<       f[\!\(z\_1\)[t]] = \>\"", 
        f[z1[t]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<         \!\(z\_1\)'[t] = \>\"", \(z1'\)[
          t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<f[\!\(z\_1\)[t]] \!\(z\_1\)'[t] = \>\"", 
        w[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<           u[t] = \>", u[t]];\)\ \), "\n", 
    \(\(Print["\<           v[t] = \>", v[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method (i).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral can be computed using the real and imaginary parts."
}], "Text"],

Cell[BoxData[{
    \(\(U1\  = \[Integral]\_\(-1\)\%1 u[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(V1\  = \[Integral]\_\(-1\)\%1 v[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(W1\  = \ U1\  + \ \[ImaginaryI]\ V1;\)\ \), "\n", 
    \(\(U[t_]\  = \ \[Integral]u[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(V[
          t_]\  = \ \[Integral]v[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(reint\  = \ \[Integral]u[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(imint\  = \ \[Integral]v[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(P1[t_] = 
        ComplexExpand[{Re[z1[t]], Im[z1[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[t] = \>", u[t]];\)\ \), "\n", 
    \(\(Print["\<v[t] = \>", v[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \
\[Integral]v[t]\[DifferentialD]t = \>", reint, "\< + \[ImaginaryI] (\>", 
        imint, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<U[t] = \>", U[t], "\<,     V[t] = \>", V[t]];\)\ \), "\n", 
    \(\(Print["\<U[1] = \>", U[1], "\<,     V[1] = \>", V[1]];\)\ \), "\n", 
    \(\(Print["\<U[-1] = \>", U[\(-1\)], "\<,   V[-1] = \>", 
        V[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI]\!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = U[1]-U[-1] + \
\[ImaginaryI](V[1]-V[-1])\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI]\!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = \>\"", 
        U[1] - U[\(-1\)], "\< + \[ImaginaryI] (\>", 
        V[1] - V[\(-1\)], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI] \!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = \>\"", 
        W1];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[P1[t]], {t, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 2\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(z\_1\)[t] = \>\"", 
        z1[t], "\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method (ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral can be computed using a complex integrand."
}], "Text"],

Cell[BoxData[{
    \(\(W[t_]\  = \[Integral]w[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(W1\  = \[Integral]\_\(-1\)\%1 w[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(P1[t_] = 
        ComplexExpand[{Re[z1[t]], Im[z1[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[t] = \>", w[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<W[t] = \[Integral]w[t]\[DifferentialD]t = \>", 
        ComplexExpand[W[t]]];\)\ \), "\n", 
    \(\(Print["\<W[1] = \>", W[1], "\<,  W[-1] = \>", 
        W[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)w[t]\[DifferentialD]t = \
W[1]-W[-1] = \>\"", W[1], "\< - (\>", W[\(-1\)], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)w[t]\[DifferentialD]t = \
\>\"", W1];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[P1[t]], {t, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 2\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(z\_1\)[t] = \>\"", 
        z1[t], "\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 6.9 (b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the portion of a parabola connecting the points  ",
  Cell[BoxData[
      \(z\_1 = \(\(-1\) - i\ \ and\ \ z\_2 = 3 + i\)\)]],
  ",  set up the parameterization and compute the contour integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(z2[t_]\  = \ t\^2\  + \ 2  t\  + \ \[ImaginaryI]\ t;\)\ \), "\n", 
    \(\(w[t_]\  = \ ComplexExpand[f[z2[t]]\ \(z2'\)[t]];\)\ \), "\n", 
    \(\(u[t_]\  = \ ComplexExpand[Re[w[t]]];\)\ \), "\n", 
    \(\(v[t_]\  = \ ComplexExpand[Im[w[t]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<          \!\(z\_2\)[t] = \>\"", z2[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<       f[\!\(z\_2\)[t]] = \>\"", 
        f[z2[t]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<         \!\(z\_2\)'[t] = \>\"", \(z2'\)[
          t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<f[\!\(z\_2\)[t]] \!\(z\_2\)'[t] = \>\"", 
        w[t]];\)\ \), "\n", 
    \(\(Print["\<           u[t] = \>", u[t]];\)\ \), "\n", 
    \(\(Print["\<           v[t] = \>", v[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method (i).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral can be computed using the real and imaginary parts."
}], "Text"],

Cell[BoxData[{
    \(\(U2\  = \[Integral]\_\(-1\)\%1 u[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(V2\  = \[Integral]\_\(-1\)\%1 v[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(W2\  = \ U2\  + \ \[ImaginaryI]\ V2;\)\ \), "\n", 
    \(\(U[t_]\  = \ \[Integral]u[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(V[
          t_]\  = \ \[Integral]v[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(reint\  = \ \[Integral]u[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(imint\  = \ \[Integral]v[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(P2[t_] = 
        ComplexExpand[{Re[z2[t]], Im[z2[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[t] = \>", u[t]];\)\ \), "\n", 
    \(\(Print["\<v[t] = \>", v[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \
\[Integral]v[t]\[DifferentialD]t = \>", reint, "\< + \[ImaginaryI] (\>", 
        imint, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<U[t] = \>", U[t], "\<,     V[t] = \>", V[t]];\)\ \), "\n", 
    \(\(Print["\<U[1] = \>", U[1], "\<,     V[1] = \>", V[1]];\)\ \), "\n", 
    \(\(Print["\<U[-1] = \>", U[\(-1\)], "\<,   V[-1] = \>", 
        V[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI]\!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = U[1]-U[-1] + \
\[ImaginaryI](V[1]-V[-1])\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI]\!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = \>\"", 
        U[1] - U[\(-1\)], "\< + \[ImaginaryI] (\>", 
        V[1] - V[\(-1\)], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI] \!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = \>\"", 
        W2];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[P2[t]], {t, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 2\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Green];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(z\_2\)[t] = \>\"", 
        z2[t], "\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method (ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral can be computed using a complex integrand."
}], "Text"],

Cell[BoxData[{
    \(\(W[t_]\  = \[Integral]w[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(W2\  = \[Integral]\_\(-1\)\%1 w[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(P2[t_] = 
        ComplexExpand[{Re[z2[t]], Im[z2[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[t] = \>", w[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<W[t] = \[Integral]w[t]\[DifferentialD]t = \>", 
        ComplexExpand[W[t]]];\)\ \), "\n", 
    \(\(Print["\<W[1] = \>", W[1], "\<,  W[-1] = \>", 
        W[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)w[t]\[DifferentialD]t = \
W[1]-W[-1] = \>\"", W[1], "\< - (\>", W[\(-1\)], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W2];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[P2[t]], {t, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 2\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Green];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(z\_2\)[t] = \>\"", 
        z2[t], "\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Which is the same as the value along the other path because  ",
  Cell[BoxData[
      \(f \((z)\) = z\^2\)]],
  "  is an analytic function"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(P1[t_] = 
        ComplexExpand[{Re[z1[t]], Im[z1[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[P1[t]], {t, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 2\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(z\_1\)[t] = \>\"", 
        z1[t], "\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Evaluate the contour integrals  of  ",
  Cell[BoxData[
      \(f \((z)\) = z\^2\)]],
  "  starting at the points   ",
  Cell[BoxData[
      \(z\_1 = \(\(-1\) - i\ \ and\ \ z\_2 = 3 + i\)\)]],
  ".  \n",
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the line segment joining the points.  \n",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use a portion of a parabola joining the points.\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The example in the text used the function ",
  Cell[BoxData[
      \(f \((z)\) = z\)]],
  "  which is difficult for hand computations but it is not a challenge for \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", hence we choose to use the function ",
  Cell[BoxData[
      \(f \((z)\) = z\^2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution for Extra Example 1 (a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the straight line segment connecting the points  ",
  Cell[BoxData[
      \(z\_1 = \(\(-1\) - i\ \ and\ \ z\_2 = 3 + i\)\)]],
  ",  set up the parameterization and compute the contour integral.  Enter \
the function  ",
  Cell[BoxData[
      \(f[z] = z\^2\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[t, u, U, v, V, w, W, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, U1, U2, V1, V2, W1, W2, z1, z2];\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^2\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(z1[t_]\  = \ 2  t\  + \ 1\  + \ \[ImaginaryI]\ t;\)\ \), "\n", 
    \(\(w[t_]\  = \ ComplexExpand[f[z1[t]]\ \(z1'\)[t]];\)\ \), "\n", 
    \(\(u[t_]\  = \ ComplexExpand[Re[w[t]]];\)\ \), "\n", 
    \(\(v[t_]\  = \ ComplexExpand[Im[w[t]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<           f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<          \!\(z\_1\)[t] = \>\"", z1[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<       f[\!\(z\_1\)[t]] = \>\"", 
        f[z1[t]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<         \!\(z\_1\)'[t] = \>\"", \(z1'\)[
          t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<f[\!\(z\_1\)[t]] \!\(z\_1\)'[t] = \>\"", 
        w[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<           u[t] = \>", u[t]];\)\ \), "\n", 
    \(\(Print["\<           v[t] = \>", v[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method (i).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral can be computed using the real and imaginary parts."
}], "Text"],

Cell[BoxData[{
    \(\(U1\  = \[Integral]\_\(-1\)\%1 u[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(V1\  = \[Integral]\_\(-1\)\%1 v[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(W1\  = \ U1\  + \ \[ImaginaryI]\ V1;\)\ \), "\n", 
    \(\(U[t_]\  = \ \[Integral]u[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(V[
          t_]\  = \ \[Integral]v[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(reint\  = \ \[Integral]u[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(imint\  = \ \[Integral]v[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(P1[t_] = 
        ComplexExpand[{Re[z1[t]], Im[z1[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[t] = \>", u[t]];\)\ \), "\n", 
    \(\(Print["\<v[t] = \>", v[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \
\[Integral]v[t]\[DifferentialD]t = \>", reint, "\< + \[ImaginaryI] (\>", 
        imint, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<U[t] = \>", U[t], "\<,     V[t] = \>", V[t]];\)\ \), "\n", 
    \(\(Print["\<U[1] = \>", U[1], "\<,     V[1] = \>", V[1]];\)\ \), "\n", 
    \(\(Print["\<U[-1] = \>", U[\(-1\)], "\<,   V[-1] = \>", 
        V[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI]\!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = U[1]-U[-1] + \
\[ImaginaryI](V[1]-V[-1])\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI]\!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = \>\"", 
        U[1] - U[\(-1\)], "\< + \[ImaginaryI] (\>", 
        V[1] - V[\(-1\)], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI] \!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = \>\"", 
        W1];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[P1[t]], {t, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 2\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(z\_1\)[t] = \>\"", 
        z1[t], "\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method (ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral can be computed using a complex integrand."
}], "Text"],

Cell[BoxData[{
    \(\(W[t_]\  = \[Integral]w[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(W1\  = \[Integral]\_\(-1\)\%1 w[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(P1[t_] = 
        ComplexExpand[{Re[z1[t]], Im[z1[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[t] = \>", w[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<W[t] = \[Integral]w[t]\[DifferentialD]t = \>", 
        ComplexExpand[W[t]]];\)\ \), "\n", 
    \(\(Print["\<W[1] = \>", W[1], "\<,  W[-1] = \>", 
        W[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)w[t]\[DifferentialD]t = \
W[1]-W[-1] = \>\"", W[1], "\< - (\>", W[\(-1\)], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)w[t]\[DifferentialD]t = \
\>\"", W1];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[P1[t]], {t, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 2\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(z\_1\)[t] = \>\"", 
        z1[t], "\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution for Extra Example 1 (b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the portion of a parabola connecting the points  ",
  Cell[BoxData[
      \(z\_1 = \(\(-1\) - i\ \ and\ \ z\_2 = 3 + i\)\)]],
  ",  set up the parameterization and compute the contour integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(z2[t_]\  = \ t\^2\  + \ 2  t\  + \ \[ImaginaryI]\ t;\)\ \), "\n", 
    \(\(w[t_]\  = \ ComplexExpand[f[z2[t]]\ \(z2'\)[t]];\)\ \), "\n", 
    \(\(u[t_]\  = \ ComplexExpand[Re[w[t]]];\)\ \), "\n", 
    \(\(v[t_]\  = \ ComplexExpand[Im[w[t]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<          \!\(z\_2\)[t] = \>\"", z2[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<       f[\!\(z\_2\)[t]] = \>\"", 
        f[z2[t]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<         \!\(z\_2\)'[t] = \>\"", \(z2'\)[
          t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<f[\!\(z\_2\)[t]] \!\(z\_2\)'[t] = \>\"", 
        w[t]];\)\ \), "\n", 
    \(\(Print["\<           u[t] = \>", u[t]];\)\ \), "\n", 
    \(\(Print["\<           v[t] = \>", v[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method (i).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral can be computed using the real and imaginary parts."
}], "Text"],

Cell[BoxData[{
    \(\(U2\  = \[Integral]\_\(-1\)\%1 u[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(V2\  = \[Integral]\_\(-1\)\%1 v[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(W2\  = \ U2\  + \ \[ImaginaryI]\ V2;\)\ \), "\n", 
    \(\(U[t_]\  = \ \[Integral]u[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(V[
          t_]\  = \ \[Integral]v[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(reint\  = \ \[Integral]u[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(imint\  = \ \[Integral]v[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(P2[t_] = 
        ComplexExpand[{Re[z2[t]], Im[z2[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[t] = \>", u[t]];\)\ \), "\n", 
    \(\(Print["\<v[t] = \>", v[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \
\[Integral]v[t]\[DifferentialD]t = \>", reint, "\< + \[ImaginaryI] (\>", 
        imint, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<U[t] = \>", U[t], "\<,     V[t] = \>", V[t]];\)\ \), "\n", 
    \(\(Print["\<U[1] = \>", U[1], "\<,     V[1] = \>", V[1]];\)\ \), "\n", 
    \(\(Print["\<U[-1] = \>", U[\(-1\)], "\<,   V[-1] = \>", 
        V[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI]\!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = U[1]-U[-1] + \
\[ImaginaryI](V[1]-V[-1])\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI]\!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = \>\"", 
        U[1] - U[\(-1\)], "\< + \[ImaginaryI] (\>", 
        V[1] - V[\(-1\)], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI] \!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = \>\"", 
        W2];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[P2[t]], {t, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 2\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Green];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(z\_2\)[t] = \>\"", 
        z2[t], "\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method (ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral can be computed using a complex integrand."
}], "Text"],

Cell[BoxData[{
    \(\(W[t_]\  = \[Integral]w[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(W2\  = \[Integral]\_\(-1\)\%1 w[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(P2[t_] = 
        ComplexExpand[{Re[z2[t]], Im[z2[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[t] = \>", w[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<W[t] = \[Integral]w[t]\[DifferentialD]t = \>", 
        ComplexExpand[W[t]]];\)\ \), "\n", 
    \(\(Print["\<W[1] = \>", W[1], "\<,  W[-1] = \>", 
        W[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)w[t]\[DifferentialD]t = \
W[1]-W[-1] = \>\"", W[1], "\< - (\>", W[\(-1\)], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\<\[DifferentialD]z = \>", W2];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[P2[t]], {t, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 2\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Green];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \!\(z\^2\) \[DifferentialD]z = \
\>\"", W2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(z\_2\)[t] = \>\"", 
        z2[t], "\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Which is the same as the value along the other path because  ",
  Cell[BoxData[
      \(f \((z)\) = z\^2\)]],
  "  is an analytic function"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(P1[t_] = 
        ComplexExpand[{Re[z1[t]], Im[z1[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[P1[t]], {t, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 2\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(z\_1\)[t] = \>\"", 
        z1[t], "\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Evaluate the contour integrals  of  ",
  Cell[BoxData[
      \(f \((z)\) = \(\(\ \)\(z\)\)\&_\)]],
  "  starting at the points   ",
  Cell[BoxData[
      \(z\_1 = \(\(-1\) - i\ \ and\ \ z\_2 = 3 + i\)\)]],
  ".  \n",
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the line segment joining the points.  \n",
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use a portion of a parabola joining the points.\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  This example illustrates the situation when f(z) is not analytic."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution for Extra Example 2 (a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the straight line segment connecting the points  ",
  Cell[BoxData[
      \(z\_1 = \(\(-1\) - i\ \ and\ \ z\_2 = 3 + i\)\)]],
  ",  set up the parameterization and compute the contour integral.  Enter \
the function  ",
  Cell[BoxData[
      \(f \((z)\) = \(\(\ \)\(z\)\)\&_\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[t, u, U, v, V, w, W, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, U1, U2, V1, V2, W1, W2, z1, z2];\)\ \), "\n", 
    \(\(f[z_]\  = \ Conjugate[z];\)\ \), "\[IndentingNewLine]", 
    \(\(TagSet[t, Im[t], 0];\)\ \), "\n", 
    \(\(z1[t_]\  = \ 2  t\  + \ 1\  + \ \[ImaginaryI]\ t;\)\ \), "\n", 
    \(\(w[t_]\  = \ ComplexExpand[f[z1[t]]\ \(z1'\)[t]];\)\ \), "\n", 
    \(\(u[t_]\  = \ ComplexExpand[Re[w[t]]];\)\ \), "\n", 
    \(\(v[t_]\  = \ ComplexExpand[Im[w[t]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<           f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<        f[x+\[ImaginaryI]y] = \>", 
        ComplexExpand[
          f[x + \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<          \!\(z\_1\)[t] = \>\"", z1[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<       f[\!\(z\_1\)[t]] = \>\"", 
        ComplexExpand[\ f[z1[t]]\ ]];\)\ \), "\n", 
    \(\(Print[\*"\"\<         \!\(z\_1\)'[t] = \>\"", \(z1'\)[
          t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<f[\!\(z\_1\)[t]] \!\(z\_1\)'[t] = \>\"", 
        w[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<           u[t] = \>", u[t]];\)\ \), "\n", 
    \(\(Print["\<           v[t] = \>", v[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method (i).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral can be computed using the real and imaginary parts."
}], "Text"],

Cell[BoxData[{
    \(\(U1\  = \[Integral]\_\(-1\)\%1 u[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(V1\  = \[Integral]\_\(-1\)\%1 v[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(W1\  = \ U1\  + \ \[ImaginaryI]\ V1;\)\ \), "\n", 
    \(\(U[t_]\  = \ \[Integral]u[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(V[
          t_]\  = \ \[Integral]v[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(reint\  = \ \[Integral]u[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(imint\  = \ \[Integral]v[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(P1[t_] = 
        ComplexExpand[{Re[z1[t]], Im[z1[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[t] = \>", u[t]];\)\ \), "\n", 
    \(\(Print["\<v[t] = \>", v[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \
\[Integral]v[t]\[DifferentialD]t = \>", reint, "\< + \[ImaginaryI] (\>", 
        imint, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<U[t] = \>", U[t], "\<,     V[t] = \>", V[t]];\)\ \), "\n", 
    \(\(Print["\<U[1] = \>", U[1], "\<,     V[1] = \>", V[1]];\)\ \), "\n", 
    \(\(Print["\<U[-1] = \>", U[\(-1\)], "\<,   V[-1] = \>", 
        V[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI]\!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = U[1]-U[-1] + \
\[ImaginaryI](V[1]-V[-1])\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI]\!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = \>\"", 
        U[1] - U[\(-1\)], "\< + \[ImaginaryI] (\>", 
        V[1] - V[\(-1\)], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI] \!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = \>\"", 
        W1];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[P1[t]], {t, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 2\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(z\_1\)[t] = \>\"", 
        z1[t], "\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method (ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral can be computed using a complex integrand."
}], "Text"],

Cell[BoxData[{
    \(\(W[t_]\  = \[Integral]w[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(W1\  = \[Integral]\_\(-1\)\%1 w[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(P1[t_] = 
        ComplexExpand[{Re[z1[t]], Im[z1[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[t] = \>", w[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<W[t] = \[Integral]w[t]\[DifferentialD]t = \>", 
        ComplexExpand[W[t]]];\)\ \), "\n", 
    \(\(Print["\<W[1] = \>", W[1], "\<,  W[-1] = \>", 
        W[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)w[t]\[DifferentialD]t = \
W[1]-W[-1] = \>\"", W[1], "\< - (\>", W[\(-1\)], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)w[t]\[DifferentialD]t = \
\>\"", W1];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[P1[t]], {t, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 2\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(z\_1\)[t] = \>\"", 
        z1[t], "\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution for Extra Example 2 (b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the portion of a parabola connecting the points  ",
  Cell[BoxData[
      \(z\_1 = \(\(-1\) - i\ \ and\ \ z\_2 = 3 + i\)\)]],
  ",  set up the parameterization and compute the contour integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(TagSet[t, Im[t], 0];\)\ \), "\n", 
    \(\(z2[t_]\  = \ t\^2\  + \ 2  t\  + \ \[ImaginaryI]\ t;\)\ \), "\n", 
    \(\(w[t_]\  = \ ComplexExpand[f[z2[t]]\ \(z2'\)[t]];\)\ \), "\n", 
    \(\(u[t_]\  = \ ComplexExpand[Re[w[t]]];\)\ \), "\n", 
    \(\(v[t_]\  = \ ComplexExpand[Im[w[t]]];\)\ \), "\n", 
    \(\(Print[\*"\"\<          \!\(z\_2\)[t] = \>\"", z2[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<       f[\!\(z\_2\)[t]] = \>\"", 
        ComplexExpand[\ f[z2[t]]\ ]];\)\ \), "\n", 
    \(\(Print[\*"\"\<         \!\(z\_2\)'[t] = \>\"", \(z2'\)[
          t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<f[\!\(z\_2\)[t]] \!\(z\_2\)'[t] = \>\"", 
        w[t]];\)\ \), "\n", 
    \(\(Print["\<           u[t] = \>", u[t]];\)\ \), "\n", 
    \(\(Print["\<           v[t] = \>", v[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method (i).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral can be computed using the real and imaginary parts."
}], "Text"],

Cell[BoxData[{
    \(\(U2\  = \[Integral]\_\(-1\)\%1 u[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(V2\  = \[Integral]\_\(-1\)\%1 v[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(W2\  = \ U2\  + \ \[ImaginaryI]\ V2;\)\ \), "\n", 
    \(\(U[t_]\  = \ \[Integral]u[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(V[
          t_]\  = \ \[Integral]v[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(reint\  = \ \[Integral]u[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(imint\  = \ \[Integral]v[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(P2[t_] = 
        ComplexExpand[{Re[z2[t]], Im[z2[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[t] = \>", u[t]];\)\ \), "\n", 
    \(\(Print["\<v[t] = \>", v[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \
\[Integral]v[t]\[DifferentialD]t = \>", reint, "\< + \[ImaginaryI] (\>", 
        imint, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<U[t] = \>", U[t], "\<,     V[t] = \>", V[t]];\)\ \), "\n", 
    \(\(Print["\<U[1] = \>", U[1], "\<,     V[1] = \>", V[1]];\)\ \), "\n", 
    \(\(Print["\<U[-1] = \>", U[\(-1\)], "\<,   V[-1] = \>", 
        V[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI]\!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = U[1]-U[-1] + \
\[ImaginaryI](V[1]-V[-1])\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI]\!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = \>\"", 
        U[1] - U[\(-1\)], "\< + \[ImaginaryI] (\>", 
        V[1] - V[\(-1\)], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)u[t]\[DifferentialD]t + \
\[ImaginaryI] \!\(\[Integral]\_\(-1\)\%1\)v[t]\[DifferentialD]t = \>\"", 
        W2];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[P2[t]], {t, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 2\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Green];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(z\_2\)[t] = \>\"", 
        z2[t], "\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method (ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral can be computed using a complex integrand."
}], "Text"],

Cell[BoxData[{
    \(\(W[t_]\  = \[Integral]w[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(W2\  = \[Integral]\_\(-1\)\%1 w[
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(P2[t_] = 
        ComplexExpand[{Re[z2[t]], Im[z2[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[t] = \>", w[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<W[t] = \[Integral]w[t]\[DifferentialD]t = \>", 
        ComplexExpand[W[t]]];\)\ \), "\n", 
    \(\(Print["\<W[1] = \>", W[1], "\<,  W[-1] = \>", 
        W[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)w[t]\[DifferentialD]t = \
W[1]-W[-1] = \>\"", W[1], "\< - (\>", W[\(-1\)], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%1\)w[t]\[DifferentialD]t = \
\>\"", W2];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[P2[t]], {t, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 2\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Green];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(z\_2\)[t] = \>\"", 
        z2[t], "\<,  for  -1 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Which is ",
  StyleBox["different",
    FontColor->RGBColor[1, 0, 1]],
  " from the value for the straight line path because  ",
  Cell[BoxData[
      \(f \((z)\) = \(\(\ \)\(z\)\)\&_\)]],
  "  is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " an analytic function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(P1[t_] = 
        ComplexExpand[{Re[z1[t]], Im[z1[t]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[P1[t]], {t, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 2\/3, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<C: \!\(z\_1\)[t] = \>\"", 
        z1[t], "\<c  for  -1 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \)}], \
"Input",
  AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tIn Example 6.9, the value of the two integrals is the same.  This outcome \
doesn't hold in general, as Example 6.10 shows. \
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 6.10.  (a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Show that   ",
  Cell[BoxData[
      \(\[Integral]\_\(C\_1\)\ \(\(\ \)\(z\)\)\&_\ \[DifferentialD]z\  = \ \
\(-\[Pi]\)\ \[ImaginaryI]\)]],
  "   but that   ",
  Cell[BoxData[
      \(\[Integral]\_\(C\_2\)\ \(\(\ \)\(z\)\)\&_\ \[DifferentialD]z\  = \ \
\(-4\)\ \[ImaginaryI]\)]],
  ",  \n\nwhere ",
  Cell[BoxData[
      \(C\_1\)]],
  " is the semicircular path from ",
  Cell[BoxData[
      RowBox[{\(-1\), " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "1"}]]],
  ", in the upper half plane, and ",
  Cell[BoxData[
      \(C\_2\)]],
  " is the polygonal path from ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(-1\), "  ", 
          StyleBox["to",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], " ", "-", "1", "+", 
        RowBox[{"\[ImaginaryI]", "  ", 
          StyleBox["to",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], " "}]], "1"}], "+", 
        RowBox[{"\[ImaginaryI]", "  ", 
          StyleBox["to",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], " "}]], "1"}]}]]],
  ", respectively, shown in Figure 6.9.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.5 .525 -5 0 ]
[.5 .525 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 0 m
.5 .5 L
s
gsave
.5 .525 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
0 0 m
0 .00194 L
1e-005 .0037 L
3e-005 .00574 L
6e-005 .00766 L
.00012 .01109 L
.00022 .0148 L
.00036 .01889 L
.00054 .02323 L
.00096 .031 L
.00152 .03902 L
.00217 .04651 L
.00406 .06355 L
.00658 .08085 L
.00942 .09659 L
.01764 .13165 L
.02683 .16158 L
.03897 .19352 L
.06898 .25341 L
.10518 .30678 L
.15084 .35789 L
.20104 .40078 L
.25429 .43546 L
.28286 .45039 L
.31525 .46462 L
.34731 .47612 L
.37716 .48468 L
.40859 .49157 L
.42606 .4945 L
.44269 .49671 L
.45854 .49828 L
.46655 .49888 L
.47541 .4994 L
.48295 .49971 L
.48719 .49984 L
.4892 .49988 L
.49107 .49992 L
.49287 .49995 L
.4945 .49997 L
.49631 .49999 L
.49824 .5 L
.5001 .5 L
.50212 .5 L
.50403 .49998 L
.50578 .49997 L
.50785 .49994 L
.50981 .4999 L
.51349 .49982 L
.51745 .4997 L
.52177 .49953 L
Mistroke
.52952 .49913 L
.5367 .49865 L
.55312 .49717 L
.57054 .495 L
.58733 .49231 L
.60536 .48877 L
.63764 .48068 L
.669 .47057 L
.70128 .4577 L
.75696 .42892 L
.81177 .3909 L
.8593 .34771 L
.9033 .29554 L
.9386 .24006 L
.9654 .18276 L
.97634 .15197 L
.98573 .1186 L
.98917 .1035 L
.99235 .08712 L
.99466 .07289 L
.99671 .05727 L
.99816 .04284 L
.99913 .0294 L
.99952 .02195 L
.99977 .01518 L
.99987 .01143 L
.99991 .00946 L
.99995 .00737 L
.99997 .00554 L
.99999 .00353 L
1 .00171 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 144},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003oo`3ooolQ
0?ooo`006P3oool500000=X0oooo1@00000R0?ooo`00703oool00`000000oooo0?ooo`3L0?ooo`03
0000003oool0oooo0280oooo000L0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3oool0
8P3oool001@0oooo100000040?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3oool08P3o
ool001`0oooo00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`0R0?ooo`006`3oool20000
0=d0oooo0P00000T0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3oool40?ooo`80000000<0oooo000000000000603oool001T0oooo00<0o`3o00000000
0000g`0000000`3o0?l0oooo0?ooo`060?ooo`030000003oool0000001T0oooo000I0?ooo`030?l0
o`3oool0oooo06h0oooo00<000000?ooo`3oool0KP3oool00`3o0?l0oooo0?ooo`070?ooo`030000
003oool0oooo01P0oooo000I0?ooo`030?l0o`3oool0oooo06h0oooo00<000000?ooo`3oool0KP3o
ool00`3o0?l0oooo0?ooo`050?ooo`80000000<0oooo000000000000603oool001T0oooo00<0o`3o
0?ooo`3oool0KP3oool00`000000oooo0?ooo`1^0?ooo`030?l0o`3oool0oooo0280oooo000I0?oo
o`030?l0o`3oool0oooo06h0oooo00<000000?ooo`3oool0KP3oool00`3o0?l0oooo0?ooo`0R0?oo
o`006@3oool00`3o0?l0oooo0?ooo`1^0?ooo`030000003oool0oooo06h0oooo00<0o`3o0?ooo`3o
ool08P3oool001T0oooo00<0o`3o0?ooo`3oool0KP3oool00`000000oooo0?ooo`1^0?ooo`030?l0
o`3oool0oooo0280oooo000I0?ooo`030?l0o`3oool0oooo06h0oooo00<000000?ooo`3oool0KP3o
ool00`3o0?l0oooo0?ooo`0R0?ooo`006@3oool00`3o0?l0oooo0?ooo`1^0?ooo`030000003oool0
oooo06h0oooo00<0o`3o0?ooo`3oool08P3oool001X0oooo00<0o`3o0?ooo`3oool0K@3oool00`00
0000oooo0?ooo`1^0?ooo`030?l0o`3oool0oooo0280oooo000J0?ooo`030?l0o`3oool0oooo06d0
oooo00<000000?ooo`3oool0KP3oool00`3o0?l0oooo0?ooo`0R0?ooo`006P3oool00`3o0?l0oooo
0?ooo`1]0?ooo`030000003oool0oooo06h0oooo00<0o`3o0?ooo`3oool08P3oool001X0oooo00<0
o`3o0?ooo`3oool0K@3oool00`000000oooo0?ooo`1]0?ooo`030?l0o`3oool0oooo02<0oooo000J
0?ooo`030?l0o`3oool0oooo06d0oooo00<000000?ooo`3oool0K@3oool00`3o0?l0oooo0?ooo`0S
0?ooo`006P3oool00`3o0?l0oooo0?ooo`1]0?ooo`030000003oool0oooo06d0oooo00<0o`3o0?oo
o`3oool08`3oool001X0oooo00<0o`3o0?ooo`3oool0K@3oool00`000000oooo0?ooo`1]0?ooo`03
0?l0o`3oool0oooo02<0oooo000J0?ooo`030?l0o`3oool0oooo06d0oooo00<000000?ooo`3oool0
K@3oool00`3o0?l0oooo0?ooo`0S0?ooo`006P3oool00`3o0?l0oooo0?ooo`1]0?ooo`030000003o
ool0oooo06d0oooo00<0o`3o0?ooo`3oool08`3oool001/0oooo00<0o`3o0?ooo`3oool0K03oool0
0`000000oooo0?ooo`1]0?ooo`030?l0o`3oool0oooo02<0oooo000K0?ooo`030?l0o`3oool0oooo
06`0oooo00<000000?ooo`3oool0K03oool00`3o0?l0oooo0?ooo`0T0?ooo`006`3oool00`3o0?l0
oooo0?ooo`1/0?ooo`030000003oool0oooo06`0oooo00<0o`3o0?ooo`3oool0903oool001/0oooo
00<0o`3o0?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`030?l0o`3oool0oooo02@0oooo
000K0?ooo`030?l0o`3oool0oooo06`0oooo00<000000?ooo`3oool0K03oool00`3o0?l0oooo0?oo
o`0T0?ooo`006`3oool00`3o0?l0oooo0?ooo`1/0?ooo`030000003oool0oooo06`0oooo00<0o`3o
0?ooo`3oool0903oool001/0oooo00<0o`3o0?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?oo
o`030?l0o`3oool0oooo02@0oooo000L0?ooo`030?l0o`3oool0oooo06/0oooo00<000000?ooo`3o
ool0K03oool00`3o0?l0oooo0?ooo`0T0?ooo`00703oool00`3o0?l0oooo0?ooo`1[0?ooo`030000
003oool0oooo06/0oooo00<0o`3o0?ooo`3oool09@3oool001`0oooo00<0o`3o0?ooo`3oool0J`3o
ool00`000000oooo0?ooo`1[0?ooo`030?l0o`3oool0oooo02D0oooo000L0?ooo`030?l0o`3oool0
oooo06/0oooo00<000000?ooo`3oool0J`3oool00`3o0?l0oooo0?ooo`0U0?ooo`007@3oool00`3o
0?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo06X0oooo00<0o`3o0?ooo`3oool09P3oool001d0
oooo00<0o`3o0?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030?l0o`3oool0oooo02H0
oooo000M0?ooo`030?l0o`3oool0oooo06X0oooo00<000000?ooo`3oool0JP3oool00`3o0?l0oooo
0?ooo`0V0?ooo`007P3oool00`3o0?l0oooo0?ooo`1Y0?ooo`030000003oool0oooo06X0oooo00<0
o`3o0?ooo`3oool09P3oool001h0oooo00<0o`3o0?ooo`3oool0J@3oool00`000000oooo0?ooo`1Y
0?ooo`030?l0o`3oool0oooo02L0oooo000N0?ooo`030?l0o`3oool0oooo06T0oooo00<000000?oo
o`3oool0J@3oool00`3o0?l0oooo0?ooo`0W0?ooo`007P3oool00`3o0?l0oooo0?ooo`1Y0?ooo`03
0000003oool0oooo06T0oooo00<0o`3o0?ooo`3oool09`3oool001l0oooo00<0o`3o0?ooo`3oool0
J03oool00`000000oooo0?ooo`1Y0?ooo`030?l0o`3oool0oooo02L0oooo000O0?ooo`030?l0o`3o
ool0oooo06P0oooo00<000000?ooo`3oool0J03oool00`3o0?l0oooo0?ooo`0X0?ooo`007`3oool0
0`3o0?l0oooo0?ooo`1X0?ooo`030000003oool0oooo06P0oooo00<0o`3o0?ooo`3oool0:03oool0
0200oooo00<0o`3o0?ooo`3oool0I`3oool00`000000oooo0?ooo`1W0?ooo`030?l0o`3oool0oooo
02T0oooo000P0?ooo`030?l0o`3oool0oooo06L0oooo00<000000?ooo`3oool0I`3oool00`3o0?l0
oooo0?ooo`0Y0?ooo`008@3oool00`3o0?l0oooo0?ooo`1V0?ooo`030000003oool0oooo06H0oooo
00<0o`3o0?ooo`3oool0:P3oool00240oooo00<0o`3o0?ooo`3oool0IP3oool00`000000oooo0?oo
o`1V0?ooo`030?l0o`3oool0oooo02X0oooo000R0?ooo`030?l0o`3oool0oooo06D0oooo00<00000
0?ooo`3oool0IP3oool00`3o0?l0oooo0?ooo`0Z0?ooo`008P3oool00`3o0?l0oooo0?ooo`1U0?oo
o`030000003oool0oooo06D0oooo00<0o`3o0?ooo`3oool0:`3oool00280oooo00<0o`3o0?ooo`3o
ool0I@3oool00`000000oooo0?ooo`1U0?ooo`030?l0o`3oool0oooo02/0oooo000S0?ooo`030?l0
o`3oool0oooo06@0oooo00<000000?ooo`3oool0I03oool00`3o0?l0oooo0?ooo`0/0?ooo`008`3o
ool00`3o0?l0oooo0?ooo`1T0?ooo`030000003oool0oooo06@0oooo00<0o`3o0?ooo`3oool0;03o
ool002@0oooo00<0o`3o0?ooo`3oool0H`3oool00`000000oooo0?ooo`1S0?ooo`030?l0o`3oool0
oooo02d0oooo000T0?ooo`030?l0o`3oool0oooo06<0oooo00<000000?ooo`3oool0H`3oool00`3o
0?l0oooo0?ooo`0]0?ooo`009@3oool00`3o0?l0oooo0?ooo`1R0?ooo`030000003oool0oooo0680
oooo00<0o`3o0?ooo`3oool0;P3oool002D0oooo00<0o`3o0?ooo`3oool0HP3oool00`000000oooo
0?ooo`1R0?ooo`030?l0o`3oool0oooo02h0oooo000V0?ooo`030?l0o`3oool0oooo0640oooo00<0
00000?ooo`3oool0H@3oool00`3o0?l0oooo0?ooo`0_0?ooo`009P3oool00`3o0?l0oooo0?ooo`1Q
0?ooo`030000003oool0oooo0640oooo00<0o`3o0?ooo`3oool0;`3oool002L0oooo00<0o`3o0?oo
o`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030?l0o`3oool0oooo0300oooo000W0?ooo`03
0?l0o`3oool0oooo0600oooo00<000000?ooo`3oool0H03oool00`3o0?l0oooo0?ooo`0`0?ooo`00
:03oool00`3o0?l0oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<0o`3o0?ooo`3oool0
<@3oool002P0oooo00<0o`3o0?ooo`3oool0G`3oool00`000000oooo0?ooo`1O0?ooo`030?l0o`3o
ool0oooo0340oooo000Y0?ooo`030?l0o`3oool0oooo05h0oooo00<000000?ooo`3oool0GP3oool0
0`3o0?l0oooo0?ooo`0b0?ooo`00:P3oool00`3o0?l0oooo0?ooo`1M0?ooo`030000003oool0oooo
05d0oooo00<0o`3o0?ooo`3oool0<`3oool002X0oooo00<0o`3o0?ooo`3oool0G@3oool00`000000
oooo0?ooo`1M0?ooo`030?l0o`3oool0oooo03<0oooo000[0?ooo`030?l0o`3oool0oooo05`0oooo
00<000000?ooo`3oool0G03oool00`3o0?l0oooo0?ooo`0d0?ooo`00;03oool00`3o0?l0oooo0?oo
o`1K0?ooo`030000003oool0oooo05/0oooo00<0o`3o0?ooo`3oool0=@3oool002`0oooo00<0o`3o
0?ooo`3oool0F`3oool00`000000oooo0?ooo`1K0?ooo`030?l0o`3oool0oooo03D0oooo000]0?oo
o`030?l0o`3oool0oooo05X0oooo00<000000?ooo`3oool0FP3oool00`3o0?l0oooo0?ooo`0f0?oo
o`00;P3oool00`3o0?l0oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<0o`3o0?ooo`3o
ool0=`3oool002h0oooo00<0o`3o0?ooo`3oool0F@3oool00`000000oooo0?ooo`1I0?ooo`030?l0
o`3oool0oooo03L0oooo000_0?ooo`030?l0o`3oool0oooo05P0oooo00<000000?ooo`3oool0F03o
ool00`3o0?l0oooo0?ooo`0h0?ooo`00<03oool00`3o0?l0oooo0?ooo`1G0?ooo`030000003oool0
oooo05L0oooo00<0o`3o0?ooo`3oool0>@3oool00300oooo00<0o`3o0?ooo`3oool0E`3oool00`00
0000oooo0?ooo`1F0?ooo`030?l0o`3oool0oooo03X0oooo000a0?ooo`030?l0o`3oool0oooo05H0
oooo00<000000?ooo`3oool0E@3oool00`3o0?l0oooo0?ooo`0k0?ooo`00<P3oool00`3o0?l0oooo
0?ooo`1E0?ooo`030000003oool0oooo05D0oooo00<0o`3o0?ooo`3oool0>`3oool003<0oooo00<0
o`3o0?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030?l0o`3oool0oooo03`0oooo000d
0?ooo`030?l0o`3oool0oooo05<0oooo00<000000?ooo`3oool0D`3oool00`3o0?l0oooo0?ooo`0m
0?ooo`00=@3oool00`3o0?l0oooo0?ooo`1B0?ooo`030000003oool0oooo0580oooo00<0o`3o0?oo
o`3oool0?P3oool003H0oooo00<0o`3o0?ooo`3oool0D@3oool00`000000oooo0?ooo`1A0?ooo`03
0?l0o`3oool0oooo03l0oooo000f0?ooo`030?l0o`3oool0oooo0540oooo00<000000?ooo`3oool0
D03oool00`3o0?l0oooo0?ooo`100?ooo`00=`3oool00`3o0?l0oooo0?ooo`1@0?ooo`030000003o
ool0oooo0500oooo00<0o`3o0?ooo`3oool0@03oool003P0oooo00<0o`3o0?ooo`3oool0C`3oool0
0`000000oooo0?ooo`1?0?ooo`030?l0o`3oool0oooo0440oooo000i0?ooo`030?l0o`3oool0oooo
04h0oooo00<000000?ooo`3oool0CP3oool00`3o0?l0oooo0?ooo`120?ooo`00>P3oool00`3o0?l0
oooo0?ooo`1=0?ooo`030000003oool0oooo04d0oooo00<0o`3o0?ooo`3oool0@`3oool003/0oooo
00<0o`3o0?ooo`3oool0C03oool00`000000oooo0?ooo`1<0?ooo`030?l0o`3oool0oooo04@0oooo
000l0?ooo`030?l0o`3oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`3o0?l0oooo0?oo
o`150?ooo`00?@3oool00`3o0?l0oooo0?ooo`1:0?ooo`030000003oool0oooo04X0oooo00<0o`3o
0?ooo`3oool0AP3oool003h0oooo0P3o0?m:0?ooo`030000003oool0oooo04T0oooo00<0o`3o0?oo
o`3oool0A`3oool00400oooo00<0o`3o0?ooo`3oool0A`3oool00`000000oooo0?ooo`180?ooo`03
0?l0o`3oool0oooo04P0oooo00110?ooo`030?l0o`3oool0oooo04H0oooo00<000000?ooo`3oool0
A`3oool00`3o0?l0oooo0?ooo`190?ooo`00@P3oool00`3o0?l0oooo0?ooo`150?ooo`030000003o
ool0oooo04H0oooo00<0o`3o0?ooo`3oool0BP3oool004<0oooo00<0o`3o0?ooo`3oool0A03oool0
0`000000oooo0?ooo`150?ooo`030?l0o`3oool0oooo04/0oooo00140?ooo`80o`3oA03oool00`00
0000oooo0?ooo`140?ooo`030?l0o`3oool0oooo04`0oooo00160?ooo`030?l0o`3oool0oooo0440
oooo00<000000?ooo`3oool0@P3oool20?l0odl0oooo00170?ooo`030?l0o`3oool0oooo0400oooo
00<000000?ooo`3oool0@03oool20?l0oe40oooo00180?ooo`80o`3o@03oool00`000000oooo0?oo
o`0o0?ooo`030?l0o`3oool0oooo0540oooo001:0?ooo`030?l0o`3oool0oooo03d0oooo00<00000
0?ooo`3oool0?@3oool20?l0oe@0oooo001;0?ooo`80o`3o?@3oool00`000000oooo0?ooo`0l0?oo
o`030?l0o`3oool0oooo05@0oooo001=0?ooo`030?l0o`3oool0oooo03X0oooo00<000000?ooo`3o
ool0>P3oool20?l0oeL0oooo001>0?ooo`80o`3o>P3oool00`000000oooo0?ooo`0h0?ooo`80o`3o
F@3oool00500oooo00<0o`3o0?ooo`3oool0=`3oool00`000000oooo0?ooo`0g0?ooo`030?l0o`3o
ool0oooo05T0oooo001A0?ooo`80o`3o=`3oool00`000000oooo0?ooo`0e0?ooo`80o`3oG03oool0
05<0oooo00<0o`3o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`80o`3oGP3oool005@0
oooo0P3o0?ld0?ooo`030000003oool0oooo0380oooo00<0o`3o0?ooo`3oool0GP3oool005H0oooo
0P3o0?lb0?ooo`030000003oool0oooo0300oooo0P3o0?mQ0?ooo`00F03oool30?l0obl0oooo00<0
00000?ooo`3oool0;P3oool20?l0of<0oooo001K0?ooo`80o`3o;@3oool00`000000oooo0?ooo`0/
0?ooo`80o`3oI@3oool005d0oooo0P3o0?l[0?ooo`030000003oool0oooo02X0oooo0P3o0?mW0?oo
o`00G`3oool30?l0obP0oooo00<000000?ooo`3oool0:03oool20?l0ofT0oooo001R0?ooo`80o`3o
9P3oool00`000000oooo0?ooo`0U0?ooo`<0o`3oJ`3oool006@0oooo0`3o0?lS0?ooo`030000003o
ool0oooo0280oooo0`3o0?m^0?ooo`00I`3oool30?l0ob00oooo00<000000?ooo`3oool07P3oool4
0?l0og40oooo001Z0?ooo`<0o`3o7@3oool00`000000oooo0?ooo`0K0?ooo`<0o`3oM@3oool006d0
oooo1@3o0?lH0?ooo`030000003oool0oooo01L0oooo103o0?mh0?ooo`00LP3oool60?l0o`X0oooo
1@0000030?ooo`030000003oool0oooo01@0oooo0`3o0?ml0?ooo`00N03oool30?l0o`T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`P0o`3oO`3oool007/0oooo7P3o0?n7
0?ooo`00Q03oool00`000000oooo0?ooo`2I0?ooo`00Q03oool00`000000oooo0?ooo`2I0?ooo`00
P`3oool2000009/0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo00280?ooo`800000UP3oool008T0oooo00<000000?ooo`3oool0U03oool0
08X0oooo00<000000?ooo`3oool0T`3oool008T0oooo00<000000?ooo`000000U03oool008P0oooo
00@000000?ooo`3oool00000U03oool008L0oooo0`0000000`3oool000000000002C0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 287}, {143, 0}} -> {-1, 0, 0, 0}}],
  StyleBox["   ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0147151 0.588604 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6.28125 ]
[1.025 .01472 10 6.28125 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -5 0 ]
[.5 .64303 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-1)] .02381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .03859 L
.02381 .06463 L
.02381 .08909 L
.02381 .11261 L
.02381 .13765 L
.02381 .16175 L
.02381 .18736 L
.02381 .21204 L
.02381 .23578 L
.02381 .26104 L
.02381 .28536 L
.02381 .30874 L
.02381 .33364 L
.02381 .3576 L
.02381 .38308 L
.02381 .40762 L
.02381 .43123 L
.02381 .45635 L
.02381 .48053 L
.02381 .50623 L
.02381 .53099 L
.02381 .55482 L
.02381 .58016 L
.02381 .60332 L
s
0 0 1 r
.02381 .60332 m
.06244 .60332 L
.10458 .60332 L
.14415 .60332 L
.18221 .60332 L
.22272 .60332 L
.26171 .60332 L
.30316 .60332 L
.34309 .60332 L
.3815 .60332 L
.42237 .60332 L
.46172 .60332 L
.49955 .60332 L
.53984 .60332 L
.57861 .60332 L
.61984 .60332 L
.65954 .60332 L
.69774 .60332 L
.73838 .60332 L
.77751 .60332 L
.81909 .60332 L
.85916 .60332 L
.89771 .60332 L
.93871 .60332 L
.97619 .60332 L
s
0 1 0 r
.97619 .60332 m
.97619 .57944 L
.97619 .5534 L
.97619 .52894 L
.97619 .50542 L
.97619 .48039 L
.97619 .45629 L
.97619 .43067 L
.97619 .406 L
.97619 .38225 L
.97619 .357 L
.97619 .33268 L
.97619 .30929 L
.97619 .2844 L
.97619 .26043 L
.97619 .23495 L
.97619 .21041 L
.97619 .18681 L
.97619 .16169 L
.97619 .13751 L
.97619 .11181 L
.97619 .08704 L
.97619 .06322 L
.97619 .03788 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`005@3oool500000=l0oooo1@00000R0?ooo`005`3oool00`000000oooo0?ooo`3Q0?ooo`03
0000003oool0oooo0280oooo000G0?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool0
8P3oool000l0oooo100000040?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool08P3o
ool001L0oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`0R0?ooo`005P3oool20000
0>80oooo0P00000T0?ooo`00o`3ooolQ0?ooo`00Q`3oool00`000000oooo0?ooo`2F0?ooo`00Q`3o
ool00`000000oooo0?ooo`2F0?ooo`00Q`3oool00`000000oooo0?ooo`1n0?ooo`80000000<0oooo
0000000000004`3oool008L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0000000D0?oo
o`003P3oool6000000030?l00000000000000>@0000000<00?l00000000000000`0000090?ooo`03
0000003oool0oooo01<0oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0
L@3oool00`00o`00oooo0?ooo`0:0?ooo`80000000<0oooo0000000000004`3oool001@0oooo00<0
o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D
0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R
0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?oo
o`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03
003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0
L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003o
ool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool0
0`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo
0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000
oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo
00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo
000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?oo
o`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l0
0?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?oo
o`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3o
ool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000
003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03o
ool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0
oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o
0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0
oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280
oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo
0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<0
0?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a
0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?oo
o`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`03
0000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0
L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003o
ool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool0
0`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool0
01@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo
0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00
oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo
00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?oo
o`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<00000
0?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?oo
o`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3o
ool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0
003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503o
ool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3o
ool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0
oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00
o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740
oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo
0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<0
00000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`
0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?oo
o`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`03
0?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00
503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool0
8P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003o
ool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool0
0`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo
0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000
oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo
00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?oo
o`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`00
0?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?oo
o`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?oo
o`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3o
ool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o
003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3o
ool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0
oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`00
0000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700
oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo
0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0
o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D
0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R
0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?oo
o`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03
003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0
L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003o
ool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool0
0`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo
0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000
oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo
00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo
000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?oo
o`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l0
0?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?oo
o`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3o
ool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000
003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03o
ool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0
oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o
0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0
oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280
oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo
0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<0
0?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a
0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?oo
o`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`03
0000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0
L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003o
ool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool0
0`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool0
01@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo
0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00
oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo
00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?oo
o`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<00000
0?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?oo
o`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3o
ool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0
003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503o
ool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3o
ool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0
oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00
o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740
oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo
0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<0
00000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`
0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?oo
o`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`03
0?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00
503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool0
8P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003o
ool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool0
0`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo
0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000
oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo
00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?oo
o`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`00
0?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?oo
o`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?oo
o`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3o
ool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o
003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3o
ool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0
oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`00
0000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700
oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo
0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0
o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D
0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R
0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?oo
o`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03
003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0
L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003o
ool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool0
0`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo
0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000
oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo
00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo
000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?oo
o`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l0
0?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?oo
o`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3o
ool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1`0?ooo`030000
003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0oooo00<0o`000?ooo`3oool0L03o
ool00`000000oooo0?ooo`1a0?ooo`03003o003oool0oooo0280oooo000D0?ooo`030?l0003oool0
oooo0700oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503oool00`3o
0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<00?l00?ooo`3oool08P3oool001@0
oooo00<0o`000?ooo`3oool0J03oool5000000<0oooo00<000000?ooo`3oool0L@3oool00`00o`00
oooo0?ooo`0R0?ooo`00503oool00`3o0000oooo0?ooo`1Z0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0L@3oool00`00o`00oooo0?ooo`0R0?ooo`00503ooooW0000o`03003o003o
ool0oooo0280oooo00210?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0UP3oool0
0840oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2F0?ooo`00P03oool2000000D0
oooo00<000000?ooo`3oool0UP3oool008L0oooo00<000000?ooo`3oool0UP3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool008D0oooo0P00002I0?ooo`00QP3oool00`000000oooo
0?ooo`2G0?ooo`00Q`3oool00`000000oooo0?ooo`2F0?ooo`00QP3oool00`000000oooo0000002G
0?ooo`00Q@3oool010000000oooo0?ooo`00002G0?ooo`00Q03oool3000000030?ooo`0000000000
09H0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1, 0, 0, 0}}],
  StyleBox["\n\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.9",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0609.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The two contours ",
  Cell[BoxData[
      \(C\_1\)]],
  " and ",
  Cell[BoxData[
      \(C\_2\)]],
  " joining  ",
  Cell[BoxData[
      RowBox[{\(-1\), "  ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "1"}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Solution.  We parametrize the semicircle ",
  Cell[BoxData[
      \(C\_1\)]],
  " as \n\n\t\t\t",
  Cell[BoxData[
      \(\(C\_1\) : \ z \((t)\) = \(-\ cos\)\ t + \[ImaginaryI]\ sin\ t\)]],
  "   and   ",
  Cell[BoxData[
      \(\[DifferentialD]z = \((sin\ t + \[ImaginaryI]\ cos\ t)\) \
\[DifferentialD]t\)]],
  ",  \n\nfor  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] \[Pi]\)]],
  ".  \n\nApplying Theorem 6.1, we have  ",
  Cell[BoxData[
      \(f \((z)\) = \(\(\ \)\(z\)\)\&_\)]],
  ",  so  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z \((t)\))\)\  = \ \(\(\(\ \)\(z \((t)\)\)\)\&_\ \  = \ \ \(\
\(\ \)\(\(-\ cos\)\ t + \[ImaginaryI]\ sin\ t\)\)\&_\)\)\(\[IndentingNewLine]\
\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\(-\ 
              cos\)\ t\  - \ \[ImaginaryI]\ sin\ t\)\)\)}]],
  "    \n\t\t\t\n\t\t\tand \n\t\t\t\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_\(C\_1\)\ \(\(\ \)\(z\)\)\&_\ \[DifferentialD]z\ \  \
= \ \ \[Integral]\_0\%\[Pi]\((\(-\ 
                    cos\)\ t - \[ImaginaryI]\ sin\ t)\) \((sin\ t + \
\[ImaginaryI]\ cos\ t)\) \[DifferentialD]t\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\[Integral]\_0\
\%\[Pi]\((\(-\ \[ImaginaryI]\) \((\(cos\^2\) t + \(sin\^2\) 
                      t)\))\) \[DifferentialD]t\)\)\(\ \
\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(-\ \
\[ImaginaryI]\) \(\[Integral]\_0\%\[Pi]\((1)\) \[DifferentialD]t\)\ \  = \ \ \
\(\(-\ \[Pi]\)\(\ \)\(\[ImaginaryI]\)\(\ \)\)\)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "We parametrize ",
  Cell[BoxData[
      \(C\_2\)]],
  " in three parts, one for each line segment:\n\n\t\t\t",
  Cell[BoxData[GridBox[{
          {
            RowBox[{\(\(z\_1\) \((t)\)\  = \ \(-1\) + \[ImaginaryI]\ t\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], 
              StyleBox["             ",
                FontFamily->"Times New Roman"]}], 
            RowBox[{\(\[DifferentialD]z = \[ImaginaryI] \[DifferentialD]t\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], 
              StyleBox["     ",
                FontFamily->"Times New Roman"]}], 
            StyleBox["and",
              FontFamily->"Times New Roman"], 
            RowBox[{
              
              RowBox[{\(f \((\(z\_1\) \((t)\))\)\  = \ \(-1\) - \[ImaginaryI]\
\ t\), 
                StyleBox[";",
                  FontFamily->"Times New Roman"]}], 
              StyleBox["             ",
                FontFamily->"Times New Roman"]}]},
          {
            
            RowBox[{\(\(z\_2\) \((t)\)\  = \ \(-1\) + 2  t + \[ImaginaryI]\), 
              
              StyleBox[",",
                FontFamily->"Times New Roman"], 
              StyleBox["   ",
                FontFamily->"Times New Roman"]}], 
            RowBox[{\(\[DifferentialD]z = 2 \[DifferentialD]t\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], 
              StyleBox["     ",
                FontFamily->"Times New Roman"]}], 
            StyleBox["and",
              FontFamily->"Times New Roman"], 
            RowBox[{
              
              RowBox[{\(f \((\(z\_2\) \((t)\))\)\  = \ \(-1\) + 
                    2  t - \[ImaginaryI]\), 
                StyleBox[";",
                  FontFamily->"Times New Roman"]}], "  "}]},
          {
            
            RowBox[{\(\(z\_3\) \((t)\)\  = \ 1 + \[ImaginaryI] \((1 - t)\)\), 
              
              StyleBox[",",
                FontFamily->"Times New Roman"]}], 
            
            RowBox[{\(\[DifferentialD]z = \(-\[ImaginaryI]\) \
\[DifferentialD]t\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], 
              StyleBox[" ",
                FontFamily->"Times New Roman"]}], 
            StyleBox["and",
              FontFamily->"Times New Roman"], 
            
            RowBox[{\(f \((\(z\_3\) \((t)\))\)\  = \ 
                1 - \[ImaginaryI] \((1 - t)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman"]}]}
          }]]],
  "  \n\nwhere  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  "  in each case.  Integrating over these three line segments we obtain  \n\n\
\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_0\%1\ \(z\_1\) \((t)\) \(z\_1\%'\) \((t)\) \
\[DifferentialD]t\  = \ \(\[Integral]\_0\%1\((\(-1\) - \[ImaginaryI]\ t)\) \
\((\[ImaginaryI])\) \[DifferentialD]t\  = \ \(\[Integral]\_0\%1\((t - \
\[ImaginaryI])\) \[DifferentialD]t\  = \ 1\/2 - \[ImaginaryI]\)\)\)]],
  ", \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_0\%1\ \(z\_2\) \((t)\) \(z\_2\%'\) \((t)\) \
\[DifferentialD]t\  = \ \(\[Integral]\_0\%1\((\(-1\) + 
                  2  t - \[ImaginaryI])\) \((2)\) \[DifferentialD]t\  = \ \(\
\[Integral]\_0\%1\((\(-2\) + 4\ t - 
                    2\ \[ImaginaryI])\) \[DifferentialD]t\  = \ \(-2\)\ \
\[ImaginaryI]\)\)\)]],
  ", \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_0\%1\ \(z\_3\) \((t)\) \(z\_3\%'\) \((t)\) \
\[DifferentialD]t\  = \ \(\[Integral]\_0\%1\((1 - \[ImaginaryI] \((1 - 
                        t)\))\) \((\(-\[ImaginaryI]\))\) \[DifferentialD]t\  \
= \ \(\[Integral]\_0\%1\((\(-1\) + 
                    t - \[ImaginaryI])\) \[DifferentialD]t\  = \ \
\(-\(1\/2\)\) - \[ImaginaryI]\)\)\)]],
  ". \n\nWe get our answer by adding the three integrals along the three \
segments:  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_\(C\_2\)\ \(\(\ \)\(z\)\)\&_\ \[DifferentialD]z\ \  \
= \ \ \[Integral]\_0\%1\((t - \[ImaginaryI])\) \[DifferentialD]t + \ \
\[Integral]\_0\%1\((\(-2\) + 4\ t - 
                  2\ \[ImaginaryI])\) \[DifferentialD]t\  + \ \ \
\[Integral]\_0\%1\((\(-1\) + 
                  t - \[ImaginaryI])\) \[DifferentialD]t\)\(\ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1\/2 - \
\[ImaginaryI]\ \  - \ \ 2\ \[ImaginaryI]\ \  - 
            1\/2 - \[ImaginaryI]\ \ \  = \ \ \(-\ 
              4\)\ \[ImaginaryI]\)\)\)}]],
  "  \n\nNote that the value of the contour integral along ",
  Cell[BoxData[
      \(C\_1\)]],
  " isn't the same as the value of the contour integral along ",
  Cell[BoxData[
      \(C\_2\)]],
  ", although both integrals have the same initial and terminal points."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 6.10 (a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the semicircular path from -1 to 1 in the upper half plane,  set up \
the parameterization and compute the contour integral.  Enter the function  \
",
  Cell[BoxData[
      \(f \((z)\) = \(\(\ \)\(z\)\)\&_\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, t, u, v, w, W, W1, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ Conjugate[z];\)\ \), "\n", 
    \(\(Print["\<   f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<f[x+\[ImaginaryI]y] = \>", 
        ComplexExpand[
          f[x + \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(TagSet[t, Im[t], 0];\)\ \), "\n", 
    \(\(z[
          t_]\  = \ \ \(-\ 
            Cos[t]\)\  + \ \[ImaginaryI]\ Sin[t];\)\ \), "\n", 
    \(\(w[t_]\  = \ ComplexExpand[f[z[t]]\ \(z'\)[t]];\)\ \), "\n", 
    \(\(u[t_]\  = \ ComplexExpand[Re[w[t]]];\)\ \), "\n", 
    \(\(v[t_]\  = \ ComplexExpand[Im[w[t]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<f[x+\[ImaginaryI]y] = \>", 
        ComplexExpand[
          f[x + \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<   z[t] = \>", z[t]];\)\ \), "\n", 
    \(\(Print["\<f[z[t]] = \>", ComplexExpand[f[z[t]]]];\)\ \), "\n", 
    \(\(Print["\<  z'[t] = \>", \(z'\)[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<w[t] = f[z[t]] z'[t] = \>", w[t]];\)\ \), "\n", 
    \(\(w[t_]\  = \ Simplify[w[t]];\)\ \), "\n", 
    \(\(Print["\<w[t] = f[z[t]] z'[t] = \>", 
        w[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral can be computed using a complex integrand."
}], "Text"],

Cell[BoxData[{
    \(\(W[t_]\  = \[Integral]w[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(W1\  = \[Integral]\_0\%\[Pi] w[t] \[DifferentialD]t;\)\ \), "\n", 
    \(\(Print["\<W[t] = \[Integral]w[t]\[DifferentialD]t = \>", 
        W[t]];\)\ \), "\n", 
    \(\(Print["\<W[\[Pi]] = \>", W[\[Pi]], "\<,  W[0] = \>", 
        W[0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\[Pi]\)w[t]\[DifferentialD]t = W[\
\[Pi]]-W[0] = \>\"", W[\[Pi]] - W[0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\[Pi]\)w[t]\[DifferentialD]t = \
\>\"", W1];\)\ \), "\[IndentingNewLine]", 
    \(\(V[t_] = ComplexExpand[{Re[z[t]], Im[z[t]]}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[V[t]], {t, 0, \[Pi]}, 
        PlotRange \[Rule] {{\(-1\), 1}, {0, 1}}, AspectRatio \[Rule] 1\/2, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(C\_1\)\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(C\_1\): z[t] = \>\"", 
        z[t], "\<,  for  0 \[LessEqual] t \[LessEqual] \[Pi].\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 6.10 (b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the polygonal path from -1 to -1+i to 1+i to 1,  set up the \
parameterization and compute the contour integral. First, find a \
parameterization of the polygonal path  ",
  Cell[BoxData[
      \(C\_1\)]],
  "  from -1 to 1 consisting of the three line segments:\nLine segment 1 from \
-1 to -1+i,\nLine segment 2 from -1+i to 1+i,\nLine segment 3 from 1+i to 1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[t, V1, V2, V3, x0, x1, y0, y1, z1, Z, Z1];\)\ \), "\n", 
    \(\(z0\  = \ \(-\ 1\);\)\ \), "\n", 
    \(\(z1\  = \ \(-\ 1\)\  + \ \[ImaginaryI];\)\ \), "\n", 
    \(x0\  = \ Re[z0]; \ y0\  = \ Im[z0]; \ x1\  = \ Re[z1]; \ 
    y1\  = \ Im[z1];\ \), "\n", 
    \(\(Z1[t_]\  = \ 
        x0\  + \ \((x1 - x0)\) 
            t\  + \ \[ImaginaryI] \((y0\  + \ \((y1 - y0)\) 
                  t)\);\)\ \), "\n", 
    \(\(z0\  = \ \(-\ 1\)\  + \ \[ImaginaryI];\)\ \), "\n", 
    \(\(z1\  = \ 1\  + \ \[ImaginaryI];\)\ \), "\n", 
    \(x0\  = \ Re[z0]; \ y0\  = \ Im[z0]; \ x1\  = \ Re[z1]; \ 
    y1\  = \ Im[z1];\ \), "\n", 
    \(\(Z2[t_]\  = \ 
        x0\  + \ \((x1 - x0)\) 
            t\  + \ \[ImaginaryI] \((y0\  + \ \((y1 - y0)\) 
                  t)\);\)\ \), "\n", 
    \(\(z0\  = \ 1\  + \ \[ImaginaryI];\)\ \), "\n", 
    \(\(z1\  = \ 1;\)\ \), "\n", 
    \(x0\  = \ Re[z0]; \ y0\  = \ Im[z0]; \ x1\  = \ Re[z1]; \ 
    y1\  = \ Im[z1];\ \), "\n", 
    \(\(Z3[t_]\  = \ 
        x0\  + \ \((x1 - x0)\) 
            t\  + \ \[ImaginaryI] \((y0\  + \ \((y1 - y0)\) 
                  t)\);\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(Z\_1\)[t] = \>\"", Z1[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(Z\_2\)[t] = \>\"", Z2[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(Z\_3\)[t] = \>\"", 
        Z3[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral can be computed using a three complex integrands."
}], "Text"],

Cell[BoxData[{
    \(\(Wset\  = \ {f[Z1[t]] \(Z1'\)[t], f[Z2[t]] \(Z2'\)[t], 
          f[Z3[t]] \(Z3'\)[t]};\)\ \), "\n", 
    \(\(funset\  = \ MapAll[ComplexExpand, Wset];\)\ \), "\n", 
    \(\(Wint\  = \[Integral]funset \[DifferentialD]t;\)\ \), "\n", 
    \(\(val\  = \[Integral]\_0\%1 funset \[DifferentialD]t;\)\ \), "\n", 
    \(\(val2\  = ReplaceAll[val\ , List \[Rule] Plus];\)\ \), "\n", 
    \(\(Print[\*"\"\<{\!\(w\_1\)[t],\!\(w\_2\)[t],\!\(w\_3\)[t]}\>\""]\ ;\)\ \
\), "\n", 
    \(\(Print[\*"\"\<= \
{f[\!\(Z\_1\)[t]]\!\(Z\_1\)'[t],f[\!\(Z\_2\)[t]]\!\(Z\_2\)'[t],f[\!\(Z\_3\)[t]\
]\!\(Z\_3\)'[t]}\>\""];\)\ \), "\n", 
    \(\(Print["\<= \>", funset];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\[Integral]{\!\(w\_1\)[t],\!\(w\_2\)[t],\!\(w\_3\)[t]}\
\[DifferentialD]t = \>\""\ , Wint];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\){\!\(w\_1\)[t],\!\(w\_2\)[t],\!\(\
w\_3\)[t]}\[DifferentialD]t = \>\"", val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)w[t]\[DifferentialD]t =\!\(\
\[Integral]\_0\%1\)\!\(w\_1\)[t]\[DifferentialD]t \
+\!\(\[Integral]\_0\%1\)\!\(w\_2\)[t]\[DifferentialD]t +\!\(\[Integral]\_0\%1\
\)\!\(w\_3\)[t]\[DifferentialD]t\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)w[t]\[DifferentialD]t = (\>\"", 
        val\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<) \
+ (\>", val\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\), "\<) \
+ (\>", val\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\), "\<)\
\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)w[t]\[DifferentialD]t = \>\"", 
        val2];\)\ \), "\[IndentingNewLine]", 
    \(\(V1[t_] = ComplexExpand[{Re[Z1[t]], Im[Z1[t]]}];\)\ \), "\n", 
    \(\(V2[t_] = ComplexExpand[{Re[Z2[t]], Im[Z2[t]]}];\)\ \), "\n", 
    \(\(V3[t_] = ComplexExpand[{Re[Z3[t]], Im[Z3[t]]}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[{V1[t], V2[t], V3[t]}], {t, 0, 1}, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Blue, Green}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(C\_2\)\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(C\_2\): \!\(Z\_1\)[t] = \>\"", 
        Z1[t], "\<,      for  0 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\n\
", 
    \(\(Print[\*"\"\<    \!\(Z\_2\)[t] = \>\"", 
        Z2[t], "\<, for  0 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<    \!\(Z\_3\)[t] = \>\"", 
        Z3[t], "\<,  for  0 \[LessEqual] t \[LessEqual] 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Which is ",
  StyleBox["different",
    FontColor->RGBColor[1, 0, 1]],
  " from the value for the other path because  ",
  Cell[BoxData[
      \(f \((z)\) = \(\(\ \)\(z\)\)\&_\)]],
  "  is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " an analytic function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(V[t_] = ComplexExpand[{Re[z[t]], Im[z[t]]}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[Evaluate[V[t]], {t, 0, \[Pi]}, 
        PlotRange \[Rule] {{\(-1\), 1}, {0, 1}}, AspectRatio \[Rule] 1\/2, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(C\_1\)\) \>\"", 
        f[z], "\< \[DifferentialD]z = \>", 
        W1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(C\_1\): z[t] = \>\"", 
        z[t], "\<,  for  0 \[LessEqual] t \[LessEqual] \[Pi].\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\t Contour integrals have properties that are similar to those of \
integrals of a complex function of a real variable, which you studied in \
Section 6.1.  If ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is given by Equation ",
  StyleBox["(6-10)",
    FontColor->RGBColor[0, 0, 1]],
  ", then the integral for the opposite contour ",
  StyleBox["-C",
    FontFamily->"Courier New"],
  " is  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_\(-C\)\ 
          f \((z)\)\ \[DifferentialD]z\ \  = \ \ \[Integral]\_\(-b\)\%\(-a\)\ 
          f \((z \((\(-\[Tau]\))\))\) \((\(-\ 
                  z'\) \((\(-\[Tau]\))\))\) \[DifferentialD]\[Tau]\)]],
  "\n\n    Using the change of variable  ",
  Cell[BoxData[
      \(t = \(-\[Tau]\)\)]],
  "  in this last equation and the property that  ",
  Cell[BoxData[
      \(\(\(\ \)\(\[Integral]\_a\%b\ 
          f \((t)\) \[DifferentialD]t\  = \ \(-\ \(\[Integral]\_b\%a\ 
            f \((t)\) \[DifferentialD]t\)\)\)\)\)]],
  ",  we obtain  \n    \n",
  StyleBox["(6-17)",
    FontColor->RGBColor[0, 0, 1]],
  "    \t\t",
  Cell[BoxData[
      \(\[Integral]\_\(-C\)\ 
          f \((z)\)\ \[DifferentialD]z\ \  = \ \ \(-\(\[Integral]\_C\ 
            f \((z)\)\ \[DifferentialD]z\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tIf two functions ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["g",
    FontFamily->"Courier New"],
  " can be integrated over the same path of integration ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", then their sum can be integrated over ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", and we have the familiar result  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\ \((f \((z)\) + 
                g \((z)\))\)\ \[DifferentialD]z\ \  = \ \ \[Integral]\_C\ 
            f \((z)\)\ \[DifferentialD]z\ \  + \ \ \[Integral]\_C\ 
            g \((z)\)\ \[DifferentialD]z\)]],
  ".  \n"
}], "Text"],

Cell[TextData[{
  "\tConstant multiples also behave as we would expect: \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\ \((a + \[ImaginaryI]\ b)\) 
            f \((z)\)\ \[DifferentialD]z\ \  = \ \ \((a + \[ImaginaryI]\ b)\) \
\(\[Integral]\_C\ f \((z)\)\ \[DifferentialD]z\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tIf two contours ",
  Cell[BoxData[
      \(C\_1\)]],
  " and ",
  Cell[BoxData[
      \(C\_2\)]],
  " are placed end to end so that the terminal point of ",
  Cell[BoxData[
      \(C\_1\)]],
  " coincides with the initial point of ",
  Cell[BoxData[
      \(C\_2\)]],
  ", then the contour ",
  Cell[BoxData[
      \(C = C\_1 + C\_2\)]],
  " is a continuation of ",
  Cell[BoxData[
      \(C\_1\)]],
  ", and  \n\n",
  StyleBox["(6-18)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_\(C\_1 + C\_2\)f \((z)\)\ \[DifferentialD]z\ \  = \ \ \
\[Integral]\_\(C\_1\)f \((z)\)\ \[DifferentialD]z\ \  + \ \ \
\[Integral]\_\(C\_2\)f \((z)\)\ \[DifferentialD]z\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tIf the contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " has two parametrizations  \n\n\t\t\t",
  Cell[BoxData[
      \(C : \ \(z\_1\) \((t)\)\ \  = \ \ \(x\_1\) \((t)\) + \[ImaginaryI]\ \
\(y\_1\) \((t)\)\)]],
  "   for   ",
  Cell[BoxData[
      \(a \[LessEqual] t \[LessEqual] b\)]],
  ",   and \n\n\t\t\t",
  Cell[BoxData[
      \(C : \ \(z\_2\) \((\[Tau])\)\ \  = \ \ \(x\_2\) \((\[Tau])\) + \
\[ImaginaryI]\ \(y\_2\) \((\[Tau])\)\)]],
  "   for   ",
  Cell[BoxData[
      \(c \[LessEqual] \[Tau] \[LessEqual] d\)]],
  ",   \n\nand there exists a differentiable function  ",
  Cell[BoxData[
      \(\[Tau]\  = \ \[Phi] \((t)\)\)]],
  "  such that  \n\n",
  StyleBox["(6-19)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(c = \ \[Phi] \((a)\)\)]],
  ",    ",
  Cell[BoxData[
      \(d = \ \[Phi] \((b)\)\)]],
  ",    and    ",
  Cell[BoxData[
      \(\[Phi]' \((t)\) > 0\)]],
  "    for   ",
  Cell[BoxData[
      \(a \[LessEqual] t \[LessEqual] b\)]],
  ",\n\nthen we say that ",
  Cell[BoxData[
      \(\(z\_2\) \((\[Tau])\)\)]],
  " is a reparametrization of the contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".  If ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " is continuous on ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", then we have  \n\n",
  StyleBox["(6-20)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_a\%b\ 
          f \((\(z\_1\) \((t)\))\) \(z\_1\%'\) \((t)\) \[DifferentialD]t\ \  \
= \ \ \[Integral]\_c\%d\ 
          f \((\(z\_2\) \((\[Tau])\))\) \(z\_2\%'\) \((\[Tau])\) \
\[DifferentialD]\[Tau]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tEquation ",
  StyleBox["(6-20)",
    FontColor->RGBColor[0, 0, 1]],
  " shows that the value of a contour integral is invariant under a change in \
the parametric representation of its contour if the reparametrization \
satisfies Equations ",
  StyleBox["(6-19)",
    FontColor->RGBColor[0, 0, 1]],
  ". "
}], "Text"],

Cell["\<\
\tWe now give two important inequalities relating to complex integrals.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 6.2 (Absolute Value Inequality).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(f \((t)\) = u \((t)\) + \[ImaginaryI]\ v \((t)\)\)]],
  " is a continuous function of the real parameter ",
  StyleBox["t",
    FontFamily->"Courier New"],
  ", then  \n\n",
  StyleBox["(6-21)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(\[Integral]\_a\%b\ 
          f \((t)\) \[DifferentialD]t\)\(|\)\(\ \ \)\(\(\[LessEqual]\)\(\ \ \
\)\(\[Integral]\_a\%b\)\)\(\ \)\(|\)\(f \((t)\)\)\(|\)\(\[DifferentialD]t\)\)\
\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.2 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 6.3 (ML - Inequality).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(f \((z)\) = u \((x, y)\) + \[ImaginaryI]\ v \((x, y)\)\)]],
  " is continuous on the contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", then  \n\n",
  StyleBox["(6-23)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\ \(\(|\)\(f \((z)\)\)\(|\)\(\ \)\(\[DifferentialD]z\  \
\[LessEqual] \ M\ L\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.3 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Inequality ",
  StyleBox["(6-23)",
    FontColor->RGBColor[0, 0, 1]],
  " to show that  ",
  Cell[BoxData[
      \(\(\(|\)\(\[Integral]\_C\ 
          1\/\(z\^2 + 1\)\ \[DifferentialD]z\)\(|\)\(\(\[LessEqual]\)\(1\/\(2 \
\@ 5\)\)\)\)\)]],
  ", \nwhere ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is the straight-line segment from  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"2", "  ", 
          StyleBox["to",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", "2"}], "+", "\[ImaginaryI]"}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  Here  ",
  Cell[BoxData[
      \(\(\(|\)\(z\^2 + 1\)\(|\)\) = \(\(|\)\(z - \[ImaginaryI] || 
            z + \[ImaginaryI]\)\(|\)\)\)]],
  ",  and the terms  ",
  Cell[BoxData[
      RowBox[{"|", \(z - \[ImaginaryI]\), "|", " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "|", \(z + \[ImaginaryI]\), "|"}]]],
  "  represent the distance from the point ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " to the points ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], " ", "-", "\[ImaginaryI]"}]]],
  ", respectively.  Referring to Figure 6.10 and using a geometric argument, \
we get \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{"|", \(z - \[ImaginaryI]\), "|", 
        RowBox[{"\[GreaterEqual]", 
          RowBox[{"2", "   ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}], " ", "|", \(z + \[ImaginaryI]\), 
        "|", \(\(\[GreaterEqual]\)\(\@5\)\)}]]],
  ",   for ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " on ",
  StyleBox["C",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.10",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/contourintegral/\
ContourIntegralMod/Images/mat0610.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The distances ",
  Cell[BoxData[
      RowBox[{"|", \(z - \[ImaginaryI]\), "|", "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "|", \(z + \[ImaginaryI]\), "|"}]]],
  "  for ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " on ",
  StyleBox["C",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  "Thus we have  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(f \((z)\)\)\(|\)\)\  = \ \(\(\(|\)\(1\/\(z\^2 + 
                  1\)\)\(|\)\)\  = \ \(1\/\(\(|\)\(z - \[ImaginaryI] || z + \
\[ImaginaryI]\)\(|\)\)\ \  \[LessEqual] 1\/\(2 \@ 5\)\  = \ M\)\)\)]],
  ".\n\nBecause ",
  StyleBox["L",
    FontFamily->"Courier New"],
  ", the length of ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", equals ",
  StyleBox["1",
    FontFamily->"Courier New"],
  ", Inequality ",
  StyleBox["(6-23)",
    FontColor->RGBColor[0, 0, 1]],
  " implies that  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(\[Integral]\_C\ 
            1\/\(z\^2 + 1\)\ \[DifferentialD]z\)\(|\)\(\(\[LessEqual]\)\(\ \)\
\(M\ L\)\(\[LessEqual]\)\(\(1\/\(2 \@ 5\)\)\[Cross]1\)\)\)\  = \ 
        1\/\(2 \@ 5\)\)]],
  "."
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Complex Integral",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ComplexIntegralBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Contour Integrals",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ContourIntegralBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Green's Theorem",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/GreenTheoremBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Cauchy-Goursat Theorem",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/CauchyGoursatBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Cauchy's Integral Formula",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/CauchyIntegraBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{965, 649},
WindowMargins->{{Automatic, 25}, {Automatic, -4}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[66947, 1902, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[256915, 6629, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[258202, 6677, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 266108, 6936}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 125, 2, 33, "Text"],
Cell[2230, 66, 1130, 35, 73, "Text",
  Evaluatable->False],
Cell[3363, 103, 879, 26, 128, "Text",
  Evaluatable->False],
Cell[4245, 131, 1792, 69, 109, "Text",
  Evaluatable->False],
Cell[6040, 202, 441, 13, 33, "Text"],
Cell[6484, 217, 956, 35, 90, "Text",
  Evaluatable->False],
Cell[7443, 254, 1511, 54, 96, "Text"],
Cell[8957, 310, 429, 13, 33, "Text"],
Cell[9389, 325, 422, 13, 71, "Text"],
Cell[9814, 340, 909, 31, 72, "Text"],
Cell[10726, 373, 1061, 35, 185, "Text"],
Cell[11790, 410, 506, 19, 33, "Text"],
Cell[12299, 431, 2550, 78, 128, "Text"],
Cell[14852, 511, 2111, 67, 52, "Text",
  Evaluatable->False],
Cell[16966, 580, 19879, 441, 216, "Text"],
Cell[36848, 1023, 1076, 34, 166, "Text"],
Cell[37927, 1059, 857, 27, 128, "Text"],

Cell[CellGroupData[{
Cell[38809, 1090, 195, 7, 33, "Text"],
Cell[39007, 1099, 76, 0, 33, "Text"],
Cell[39086, 1101, 2638, 56, 610, "Input"],
Cell[41727, 1159, 131, 5, 33, "Text"],
Cell[41861, 1166, 978, 18, 210, "Input"]
}, Closed]],
Cell[42854, 1187, 3840, 116, 125, "Text"],
Cell[46697, 1305, 1052, 35, 52, "Text"],
Cell[47752, 1342, 969, 32, 52, "Text"],
Cell[48724, 1376, 835, 24, 110, "Text",
  Evaluatable->False],
Cell[49562, 1402, 931, 28, 55, "Text"],
Cell[50496, 1432, 894, 27, 36, "Text",
  Evaluatable->False],
Cell[51393, 1461, 4005, 114, 80, "Text"],
Cell[55401, 1577, 490, 16, 33, "Text"],
Cell[55894, 1595, 1706, 31, 309, "Text"],

Cell[CellGroupData[{
Cell[57625, 1630, 195, 7, 33, "Text"],
Cell[57823, 1639, 318, 10, 52, "Text"],
Cell[58144, 1651, 1809, 35, 690, "Input"],
Cell[59956, 1688, 251, 9, 71, "Text"],
Cell[60210, 1699, 537, 11, 133, "Input"]
}, Closed]],
Cell[60762, 1713, 1034, 32, 68, "Text"],
Cell[61799, 1747, 599, 22, 33, "Text"],
Cell[62401, 1771, 2361, 59, 262, "Text"],
Cell[64765, 1832, 613, 13, 72, "Text"],
Cell[65381, 1847, 772, 28, 91, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[66178, 1879, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[66326, 1885, 618, 15, 52, "Text",
  Evaluatable->False],
Cell[66947, 1902, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[67307, 1914, 526, 11, 68, "Text"],
Cell[67836, 1927, 893, 27, 36, "Text",
  Evaluatable->False],
Cell[68732, 1956, 12337, 349, 163, "Text"],
Cell[81072, 2307, 3958, 82, 486, "Text"],

Cell[CellGroupData[{
Cell[85055, 2393, 195, 7, 33, "Text"],
Cell[85253, 2402, 212, 6, 33, "Text"],
Cell[85468, 2410, 1127, 21, 405, "Input"],
Cell[86598, 2433, 175, 5, 33, "Text"],
Cell[86776, 2440, 2325, 42, 579, "Input"],
Cell[89104, 2484, 185, 5, 33, "Text"],
Cell[89292, 2491, 3092, 59, 724, "Input"]
}, Closed]],
Cell[92399, 2553, 495, 19, 33, "Text",
  Evaluatable->False],
Cell[92897, 2574, 11071, 311, 115, "Text"],
Cell[103971, 2887, 1147, 31, 103, "Text"],

Cell[CellGroupData[{
Cell[105143, 2922, 195, 7, 33, "Text"],
Cell[105341, 2931, 206, 6, 36, "Text"],
Cell[105550, 2939, 2072, 40, 572, "Input"]
}, Closed]],
Cell[107637, 2982, 373, 10, 49, "Text"],
Cell[108013, 2994, 1031, 32, 140, "Text"],
Cell[109047, 3028, 3207, 92, 309, "Text"],
Cell[112257, 3122, 1990, 51, 255, "Text"],
Cell[114250, 3175, 1306, 34, 184, "Text"],
Cell[115559, 3211, 312, 7, 52, "Text"],
Cell[115874, 3220, 1442, 45, 56, "Text",
  Evaluatable->False],
Cell[117319, 3267, 29991, 675, 230, "Text"],
Cell[147313, 3944, 3294, 92, 416, "Text"],
Cell[150610, 4038, 2717, 79, 309, "Text"],

Cell[CellGroupData[{
Cell[153352, 4121, 198, 7, 33, "Text"],
Cell[153553, 4130, 457, 15, 52, "Text",
  Evaluatable->False],
Cell[154013, 4147, 1240, 22, 370, "Input"],
Cell[155256, 4171, 183, 5, 33, "Text"],
Cell[155442, 4178, 2752, 49, 660, "Input"],
Cell[158197, 4229, 175, 5, 33, "Text"],
Cell[158375, 4236, 1636, 31, 413, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[160048, 4272, 198, 7, 30, "Text"],
Cell[160249, 4281, 356, 10, 33, "Text",
  Evaluatable->False],
Cell[160608, 4293, 812, 15, 230, "Input"],
Cell[161423, 4310, 183, 5, 33, "Text"],
Cell[161609, 4317, 2750, 49, 660, "Input"],
Cell[164362, 4368, 175, 5, 33, "Text"],
Cell[164540, 4375, 1654, 32, 412, "Input"],
Cell[166197, 4409, 218, 7, 33, "Text",
  Evaluatable->False],
Cell[166418, 4418, 839, 17, 178, "Input"]
}, Closed]],
Cell[167272, 4438, 1040, 35, 106, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[168337, 4477, 214, 7, 33, "Text"],
Cell[168554, 4486, 458, 15, 33, "Text",
  Evaluatable->False],
Cell[169015, 4503, 1243, 22, 370, "Input"],
Cell[170261, 4527, 183, 5, 33, "Text"],
Cell[170447, 4534, 2752, 49, 660, "Input"],
Cell[173202, 4585, 175, 5, 33, "Text"],
Cell[173380, 4592, 1636, 31, 413, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[175053, 4628, 214, 7, 30, "Text"],
Cell[175270, 4637, 356, 10, 33, "Text",
  Evaluatable->False],
Cell[175629, 4649, 812, 15, 230, "Input"],
Cell[176444, 4666, 183, 5, 33, "Text"],
Cell[176630, 4673, 2750, 49, 660, "Input"],
Cell[179383, 4724, 175, 5, 33, "Text"],
Cell[179561, 4731, 1624, 30, 412, "Input"],
Cell[181188, 4763, 218, 7, 33, "Text",
  Evaluatable->False],
Cell[181409, 4772, 839, 17, 178, "Input"]
}, Closed]],
Cell[182263, 4792, 803, 25, 87, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[183091, 4821, 214, 7, 33, "Text"],
Cell[183308, 4830, 477, 15, 33, "Text",
  Evaluatable->False],
Cell[183788, 4847, 1438, 26, 410, "Input"],
Cell[185229, 4875, 183, 5, 33, "Text"],
Cell[185415, 4882, 2752, 49, 660, "Input"],
Cell[188170, 4933, 175, 5, 33, "Text"],
Cell[188348, 4940, 1619, 31, 413, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[190004, 4976, 214, 7, 30, "Text"],
Cell[190221, 4985, 356, 10, 33, "Text",
  Evaluatable->False],
Cell[190580, 4997, 874, 16, 250, "Input"],
Cell[191457, 5015, 183, 5, 33, "Text"],
Cell[191643, 5022, 2750, 49, 660, "Input"],
Cell[194396, 5073, 175, 5, 33, "Text"],
Cell[194574, 5080, 1634, 31, 413, "Input"],
Cell[196211, 5113, 358, 13, 33, "Text",
  Evaluatable->False],
Cell[196572, 5128, 805, 16, 158, "Input"]
}, Closed]],
Cell[197392, 5147, 150, 3, 30, "Text"],
Cell[197545, 5152, 2781, 82, 75, "Text",
  Evaluatable->False],
Cell[200329, 5236, 33815, 772, 216, "Text"],
Cell[234147, 6010, 1708, 41, 383, "Text"],
Cell[235858, 6053, 4821, 117, 417, "Text"],

Cell[CellGroupData[{
Cell[240704, 6174, 199, 7, 33, "Text"],
Cell[240906, 6183, 408, 13, 33, "Text",
  Evaluatable->False],
Cell[241317, 6198, 1372, 28, 410, "Input"],
Cell[242692, 6228, 170, 5, 33, "Text"],
Cell[242865, 6235, 1425, 26, 373, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[244327, 6266, 199, 7, 30, "Text"],
Cell[244529, 6275, 525, 13, 109, "Text",
  Evaluatable->False],
Cell[245057, 6290, 1411, 31, 350, "Input"],
Cell[246471, 6323, 177, 5, 33, "Text"],
Cell[246651, 6330, 2933, 51, 650, "Input"],
Cell[249587, 6383, 350, 13, 33, "Text",
  Evaluatable->False],
Cell[249940, 6398, 798, 15, 181, "Input"]
}, Closed]],
Cell[250753, 6416, 1283, 35, 166, "Text"],
Cell[252039, 6453, 666, 20, 91, "Text"],
Cell[252708, 6475, 306, 7, 72, "Text"],
Cell[253017, 6484, 734, 28, 94, "Text"],
Cell[253754, 6514, 1678, 59, 262, "Text"],
Cell[255435, 6575, 338, 10, 52, "Text"],
Cell[255776, 6587, 95, 2, 33, "Text"],
Cell[255874, 6591, 691, 22, 72, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[256590, 6617, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[256738, 6623, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[256915, 6629, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[257275, 6641, 577, 20, 69, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[257877, 6665, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[258025, 6671, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[258202, 6677, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[258562, 6689, 905, 30, 63, "Text",
  Evaluatable->False],
Cell[259470, 6721, 1826, 53, 90, "Text"],
Cell[261299, 6776, 909, 30, 33, "Text"],
Cell[262211, 6808, 822, 25, 171, "Text"],
Cell[263036, 6835, 290, 7, 33, "Text"],
Cell[263329, 6844, 317, 10, 33, "Text"],
Cell[263649, 6856, 318, 10, 33, "Text"],
Cell[263970, 6868, 313, 10, 33, "Text"],
Cell[264286, 6880, 321, 10, 33, "Text"],
Cell[264610, 6892, 324, 10, 33, "Text"],
Cell[264937, 6904, 257, 5, 33, "Text"],
Cell[265197, 6911, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

