(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    158561,       4034]*)
(*NotebookOutlinePosition[    159889,       4080]*)
(*  CellTagsIndexPosition[    159812,       4074]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["6.3  The Cauchy-Goursat Theorem",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tThe Cauchy-Goursat theorem states that within certain domains the \
integral of an analytic function over a simple closed contour is zero.  An \
extension of this theorem allows us to replace integrals over certain \
complicated contours with integrals over contours that are easy to evaluate.  \
We demonstrate how to use the technique of partial fractions with the ",
  StyleBox[ButtonBox["Cauchy",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  StyleBox["-",
    FontSize->14,
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[ButtonBox["Goursat",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Goursat.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " ",
  StyleBox[ButtonBox["theorem",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CauchyIntegralTheorem.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " to evaluate certain integrals.  In Section 6.4 we will see that the \
Cauchy-Goursat theorem implies that an analytic function has an \
antiderivative.  To begin, we need to introduce some new concepts."
}], "Text"],

Cell[TextData[{
  "\tRecall from Section 1.6 that each simple closed contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " divides the plane into two domains.  One domain is bounded and is called \
the interior of ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ";  the other domain is unbounded and is called the exterior of ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".  Figure 6.15 illustrates this concept, which is known as the ",
  StyleBox[ButtonBox["Jordan",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Jordan.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " ",
  StyleBox[ButtonBox["curve theorem",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/JordanCurveTheorem.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.15",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/cauchygoursat/CauchyGoursatMod/\
Images/mat0615.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The interior and exterior of simple closed contours."
}], "Text"],

Cell[TextData[{
  "\tRecall also that a domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " is a connected open set.  In particular, if  ",
  Cell[BoxData[
      \(z\_1\ \ and\ \ z\_2\)]],
  "  are any pair of points in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", then they can be joined by a curve that lies entirely in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  A domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " is said to be a simply connected domain if the interior of any simple \
closed contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " contained in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " is contained in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  In other words, there are no \"holes\" in a simply connected domain.  A \
domain that is not simply connected is said to be a multiply connected \
domain.  Figure 6.16 illustrates uses of the terms simply connected and \
multiply connected."
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.16",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/cauchygoursat/CauchyGoursatMod/\
Images/mat0616.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "   Simply connected and multiply connected domains."
}], "Text"],

Cell[TextData[{
  "\tLet the simple closed contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " have the parametrization  ",
  Cell[BoxData[
      \(C : \ z \((t)\) = \ x \((t)\) + \[ImaginaryI]\ y \((t)\)\)]],
  "  for ",
  Cell[BoxData[
      \(\(\(\ \)\(a \[LessEqual] t \[LessEqual] b\)\)\)]],
  ".  Recall that if ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is parametrized so that the interior of ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is kept on the left as ",
  StyleBox["z(t)",
    FontFamily->"Courier New"],
  " moves around  ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", then we say that ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is oriented positively (counterclockwise); otherwise, ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is oriented negatively (clockwise).  If ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is positively oriented, then ",
  StyleBox["-C",
    FontFamily->"Courier New"],
  " is negatively oriented.  Figure 6.17 illustrates the concept of positive \
and negative orientation."
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.17",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/cauchygoursat/CauchyGoursatMod/\
Images/mat0617.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Simple closed contours that are positively and negatively oriented."
}], "Text"],

Cell[TextData[{
  ButtonBox["\t",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/GreensTheorem.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[ButtonBox["Green's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Green.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " ",
  StyleBox[ButtonBox["theorem",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/GreensTheorem.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " is an important result from the calculus of real variables.  It tells you \
how to evaluate the line integral of real-valued functions."
}], "Text"],

Cell[TextData[{
  " ",
  StyleBox["Theorem 6.4 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Greens Theorem",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/GreensTheorem.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["C",
    FontFamily->"Courier New"],
  "  be a simple closed contour with positive orientation and let ",
  StyleBox["R",
    FontFamily->"Courier New"],
  " be the domain that forms the interior of ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".  If P and Q are continuous and have continuous partial derivatives  ",
  Cell[BoxData[
      \(P\_x, P\_y, Q\_x, and\ \ Q\_y\)]],
  "  at all points on ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["R",
    FontFamily->"Courier New"],
  ", then  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\ 
            P \((x, y)\) \[DifferentialD]x\ \  + \ \ \[Integral]\_C\ 
            Q \((x, y)\) \[DifferentialD]y\ \  = \ \ \[Integral]\(\[Integral]\
\_R\((\(Q\_x\) \((x, y)\)\  - \ \(P\_y\) \((x, 
                      y)\))\) \[DifferentialD]x\ \[DifferentialD]y\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.4 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\tWe are now ready to state the main result of this section.", "Text"],

Cell[TextData[{
  " ",
  StyleBox["Theorem 6.5 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Cauchy-Goursat Theorem",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CauchyIntegralTheorem.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  "  be analytic in a simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  If ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a simple closed contour that lies in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", then  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\ f \((z)\) \[DifferentialD]z\ \  = \ \ 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.5 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let us recall that  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[ExponentialE]\^z\),
          FontSize->14], ",", " ", \(cos \((z)\)\), ",", 
        " ", \(and\ \ z\^n\)}]]],
  "  (where n is a positive integer) are all entire functions and have \
continuous derivatives.  The Cauchy-Goursat theorem implies that, for any \
simple closed contour, \n\n",
  StyleBox["(a)",
    FontColor->RGBColor[0, 0, 1]],
  "   \t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\ \(\[ExponentialE]\^z\) \[DifferentialD]z\ \  = \ \ \
0\)]],
  ",  \n\n",
  StyleBox["(b)",
    FontColor->RGBColor[0, 0, 1]],
  "   \t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\ cos \((z)\) \[DifferentialD]z\ \  = \ \ 0\)]],
  ",   and  \n\n",
  StyleBox["(c)",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  Cell[BoxData[
      \(\(\(\t\t\t\ \)\(\[Integral]\_C\ \(z\^n\) \[DifferentialD]z\ \  = \ \ \
0\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.12 (a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["For illustration.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  We use the function  ",
  Cell[BoxData[
      RowBox[{\(f \((z)\)\), "=", 
        StyleBox[\(\[ExponentialE]\^z\),
          FontSize->14]}]]],
  ".  Choose the contour",
  " ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " ",
  "to be the unit circle C: |z| = 1 with positive orientation. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[z];\)\ \ \), "\n", 
    \(\(Clear[f, F, \[Theta]];\)\ \ \), "\n", 
    \(\(f[z_]\  = \ \[ExponentialE]\^z;\)\ \ \), "\n", 
    \(\(z[\[Theta]_]\  = \ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\);\)\ \ \
\), "\n", 
    \(\(F[\[Theta]_]\  = \[Integral]f[
              z[\[Theta]]] \(z'\)[\[Theta]] \[DifferentialD]\[Theta];\)\ \ \
\), "\n", 
    \(\(val\  = \ \[Integral]\_0\%\(2  \[Pi]\)f[
              z[\[Theta]]] \(z'\)[\[Theta]] \[DifferentialD]\[Theta];\)\ \ \
\), "\n", 
    \(\(Print["\<              f[z] = \>", f[z]];\)\ \ \), "\n", 
    \(\(Print["\<              z[\[Theta]] = \>", 
        z[\[Theta]]];\)\ \ \), "\n", 
    \(\(Print["\<           f[z[\[Theta]]] = \>", 
        f[z[\[Theta]]]];\)\ \ \), "\n", 
    \(\(Print["\<             z'[\[Theta]] = \>", \(z'\)[\[Theta]]];\)\ \ \), \
"\n", 
    \(\(Print["\<     f[z[\[Theta]]] z'[\[Theta]] = \>", 
        f[z[\[Theta]]], \ \(z'\)[\[Theta]]];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print["\< F[\[Theta]] = \[Integral] f[z[\[Theta]]]z'[\[Theta]] \
\[DifferentialD]\[Theta] = \>", F[\[Theta]]];\)\ \ \), "\n", 
    \(\(Print["\<F[2\[Pi]] = \>", F[2  \[Pi]], "\<,  and  F[0] = \>", 
        F[0]];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\+0\%\(2  \[Pi]\)\)\>\"", \
"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>", \*"\"\<\!\(\
\[Integral]\+0\%\(2  \[Pi]\)\)\>\"", 
        f[z[\[Theta]]], \(z'\)[\[Theta]], "\< \[DifferentialD]\[Theta] = \>", 
        F[2  \[Pi]], "\< - \>", F[0], "\< = \>", 
        F[2  \[Pi]] - F[0]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\+0\%\(2  \[Pi]\)\)\>\"", \
"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>", 
        val];\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 1]}];\)\ \ \), "\n", 
    \(\(Show[contour, 
        PlotRange \[Rule] {{\(-3\)\/2, 3\/2}, {\(-3\)\/2, 3\/2}}, 
        Ticks \[Rule] {Range[\(-3\)\/2, 3\/2, 1\/2], 
            Range[\(-3\)\/2, 3\/2, 
              1\/2]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \ \), "\n", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) \>\"", 
      f[z], "\< \[DifferentialD]z = \>", val]\), "\n", 
    \(\(Print["\<The contour is the unit circle  C: |z| = 1.\>"];\)\ \ \)}], \
"Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.12 (b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["For illustration.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  We use the function  ",
  Cell[BoxData[
      \(f \((z)\) = Cos[z]\)]],
  ". Choose the contour",
  " ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " ",
  "to be the unit circle C: |z| = 1 with positive orientation. "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z];\)\ \ \), "\n", 
    \(\(Clear[f, F, \[Theta]];\)\ \ \), "\n", 
    \(\(f[z_]\  = \ Cos[z];\)\ \ \), "\n", 
    \(\(z[\[Theta]_]\  = \ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\);\)\ \ \
\), "\n", 
    \(\(F[\[Theta]_]\  = \[Integral]f[
              z[\[Theta]]] \(z'\)[\[Theta]] \[DifferentialD]\[Theta];\)\ \ \
\), "\n", 
    \(\(val\  = \ \[Integral]\_0\%\(2  \[Pi]\)f[
              z[\[Theta]]] \(z'\)[\[Theta]] \[DifferentialD]\[Theta];\)\ \ \
\), "\n", 
    \(\(Print["\<              f[z] = \>", f[z]];\)\ \ \), "\n", 
    \(\(Print["\<              z[\[Theta]] = \>", 
        z[\[Theta]]];\)\ \ \), "\n", 
    \(\(Print["\<           f[z[\[Theta]]] = \>", 
        f[z[\[Theta]]]];\)\ \ \), "\n", 
    \(\(Print["\<             z'[\[Theta]] = \>", \(z'\)[\[Theta]]];\)\ \ \), \
"\n", 
    \(\(Print["\<     f[z[\[Theta]]] z'[\[Theta]] = \>", 
        f[z[\[Theta]]]\ \(z'\)[\[Theta]]];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print["\< F[\[Theta]] = \[Integral] f[z[\[Theta]]]z'[\[Theta]] \
\[DifferentialD]\[Theta] = \>", F[\[Theta]]];\)\ \ \), "\n", 
    \(\(Print["\<F[2\[Pi]] = \>", F[2  \[Pi]], "\<,  and  F[0] = \>", 
        F[0]];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\+0\%\(2  \[Pi]\)\)\>\"", \
"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>", \*"\"\<\!\(\
\[Integral]\+0\%\(2  \[Pi]\)\)\>\"", 
        f[z[\[Theta]]], \(z'\)[\[Theta]], "\< \[DifferentialD]\[Theta] = \>", 
        F[2  \[Pi]], "\< - \>", F[0], "\< = \>", 
        F[2  \[Pi]] - F[0]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\+0\%\(2  \[Pi]\)\)\>\"", \
"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>", 
        val];\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 1]}];\)\ \ \), "\n", 
    \(\(Show[contour, 
        PlotRange \[Rule] {{\(-3\)\/2, 3\/2}, {\(-3\)\/2, 3\/2}}, 
        Ticks \[Rule] {Range[\(-3\)\/2, 3\/2, 1\/2], 
            Range[\(-3\)\/2, 3\/2, 
              1\/2]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \ \), "\n", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) \>\"", 
      f[z], "\< \[DifferentialD]z = \>", val]\), "\n", 
    \(\(Print["\<The contour is the unit circle  C: |z| = 1.\>"];\)\ \ \)}], \
"Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.12 (c)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["For illustration.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  We use  n=5  and use the function  ",
  Cell[BoxData[
      RowBox[{\(f \((z)\)\), "=", 
        StyleBox[\(z\^5\),
          FontSize->14]}]]],
  ".  Choose the contour",
  " ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " ",
  "to be the unit circle C: |z| = 1 with positive orientation. "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, \[Theta]];\)\ \ \), "\n", 
    \(\(f[z_]\  = \ z\^5;\)\ \ \), "\n", 
    \(\(z[\[Theta]_]\  = \ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\);\)\ \ \
\), "\n", 
    \(\(F[\[Theta]_]\  = \[Integral]f[
              z[\[Theta]]] \(z'\)[\[Theta]] \[DifferentialD]\[Theta];\)\ \ \
\), "\n", 
    \(\(val\  = \ \[Integral]\_0\%\(2  \[Pi]\)f[
              z[\[Theta]]] \(z'\)[\[Theta]] \[DifferentialD]\[Theta];\)\ \ \
\), "\n", 
    \(\(Print["\<              f[z] = \>", f[z]];\)\ \ \), "\n", 
    \(\(Print["\<              z[\[Theta]] = \>", 
        z[\[Theta]]];\)\ \ \), "\n", 
    \(\(Print["\<           f[z[\[Theta]]] = \>", 
        f[z[\[Theta]]]];\)\ \ \), "\n", 
    \(\(Print["\<             z'[\[Theta]] = \>", \(z'\)[\[Theta]]];\)\ \ \), \
"\n", 
    \(\(Print["\<     f[z[\[Theta]]] z'[\[Theta]] = \>", 
        f[z[\[Theta]]]\ \(z'\)[\[Theta]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print["\< F[\[Theta]] = \[Integral] f[z[\[Theta]]]z'[\[Theta]] \
\[DifferentialD]\[Theta] = \>", F[\[Theta]]];\)\ \ \), "\n", 
    \(\(Print["\<F[2\[Pi]] = \>", F[2  \[Pi]], "\<,  and  F[0] = \>", 
        F[0]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\+0\%\(2  \[Pi]\)\)\>\"", \
"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>", \*"\"\<\!\(\
\[Integral]\+0\%\(2  \[Pi]\)\)\>\"", 
        f[z[\[Theta]]] \(z'\)[\[Theta]], "\< \[DifferentialD]\[Theta] = \>", 
        F[2  \[Pi]], "\< - \>", F[0], "\< = \>", 
        F[2  \[Pi]] - F[0]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\+0\%\(2  \[Pi]\)\)\>\"", \
"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>", 
        val];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 1]}];\)\ \ \), "\n", 
    \(\(Show[contour, 
        PlotRange \[Rule] {{\(-3\)\/2, 3\/2}, {\(-3\)\/2, 3\/2}}, 
        Ticks \[Rule] {Range[\(-3\)\/2, 3\/2, 1\/2], 
            Range[\(-3\)\/2, 3\/2, 
              1\/2]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \ \), \
"\[IndentingNewLine]", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) \>\"", 
      f[z], "\< \[DifferentialD]z = \>", val]\), "\[IndentingNewLine]", 
    \(\(Print["\<The contour is the unit circle  C: |z| = 1.\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.13.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  If ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a simple closed contour such that the origin does not lie interior to \
",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", then there is a simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " that contains ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " in which  ",
  Cell[BoxData[
      \(f \((z)\) = 1\/z\^n\)]],
  "  is analytic, as is indicated in Figure 6.22.  The Cauchy-Goursat theorem \
implies that  ",
  Cell[BoxData[
      \(\[Integral]\_C\( 1\/z\^n\) \[DifferentialD]z\  = \ 0\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.22",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/cauchygoursat/CauchyGoursatMod/\
Images/mat0622.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  A simple connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " containing the simple closed contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " that does not contain the origin."
}], "Text"],

Cell[TextData[{
  "\tWe want to be able to replace integrals over certain complicated \
contours with integrals that are easy to evaluate.  If ",
  Cell[BoxData[
      \(C\_1\)]],
  " is a simple closed contour that can be \"continuously deformed'' into \
another simple closed contour ",
  Cell[BoxData[
      \(C\_2\)]],
  " without passing through a point where f is not analytic, then the value \
of the contour integral of f over ",
  Cell[BoxData[
      \(C\_1\)]],
  " is the same as the value of the integral of f over ",
  Cell[BoxData[
      \(C\_2\)]],
  ".  To be precise, we state the following result."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 6.6 (Deformation of Contour).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(C\_1\)]],
  "  and  ",
  Cell[BoxData[
      \(C\_2\)]],
  "  be two simple closed positively oriented contours such that  ",
  Cell[BoxData[
      \(C\_1\)]],
  "  lies interior to ",
  Cell[BoxData[
      \(C\_2\)]],
  ".  If  ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  "  is analytic in a domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " that contains both ",
  Cell[BoxData[
      \(\(\(\ \)\(C\_1\)\)\)]],
  "  and ",
  Cell[BoxData[
      \(C\_2\)]],
  "  and the region between them, as shown in Figure 6.23, then \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_\(C\_1\)f \((z)\) \[DifferentialD]z\ \  = \ \ \
\[Integral]\_\(C\_2\)f \((z)\) \[DifferentialD]z\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.23",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/cauchygoursat/CauchyGoursatMod/\
Images/mat0623.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "   The domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " that contains the simple closed contours ",
  Cell[BoxData[
      \(C\_1\)]],
  " and ",
  Cell[BoxData[
      \(C\_2\)]],
  " and the region between them. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.6 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\<\
\tWe now state as a corollary an important result that is implied by the \
deformation of contour theorem.  This result occurs several times in the \
theory to be developed and is an important tool for computations.  You may \
want to compare the proof of Corollary 6.1 with your solution to Exercise 23 \
from Section 6.2.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Corollary 6.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  denote a fixed complex value.  If ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a simple closed contour with positive orientation such that  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  lies interior to ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", then\n\n",
  StyleBox["(i)",
    FontColor->RGBColor[0, 0, 1]],
  "     \t\t\t ",
  Cell[BoxData[
      \(\[Integral]\_C\( 
                1\/\(z\  - \ 
                  z\_0\)\) \[DifferentialD]z\ \  = \ \ 2  \[Pi]\ \
\[ImaginaryI]\)]],
  ",   and  \n \n",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  "    \t\t\t ",
  Cell[BoxData[
      \(\[Integral]\_C\( 
                1\/\((z\  - \ z\_0)\)\^n\) \[DifferentialD]z\ \  = \ \ 0\)]],
  ",   where ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is any integer except ",
  Cell[BoxData[
      \(n = 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 6.1 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Demonstration for (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Show that ",
  Cell[BoxData[
      \(\[Integral]\_C\( 1\/\(z\  - \ z\_0\)\) \[DifferentialD]z = 
        2  \[Pi]\ \[ImaginaryI]\)]],
  ".  \n",
  StyleBox["For illustration.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  We use a circle of radius 1 centered at  ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Z = \(z = 0\); \ Remove[z, Z];\ \ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, \[Theta], z, Z];\)\ \ \), "\n", 
    \(\(f[z_]\  = \ 1\/\(z - Z\_0\);\)\ \ \), "\n", 
    \(\(z[\[Theta]_]\  = \ 
        Z\_0\  + \ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\);\)\ \ \), "\n\
", 
    \(\(F[\[Theta]_]\  = \[Integral]f[
              z[\[Theta]]] \(z'\)[\[Theta]] \[DifferentialD]\[Theta];\)\ \ \
\), "\n", 
    \(\(val\  = \ \[Integral]\_0\%\(2  \[Pi]\)f[
              z[\[Theta]]] \(z'\)[\[Theta]] \[DifferentialD]\[Theta];\)\ \ \
\), "\n", 
    \(\(Print["\<              f[z] = \>", f[z]];\)\ \ \), "\n", 
    \(\(Print["\<              z[\[Theta]] = \>", 
        z[\[Theta]]];\)\ \ \), "\n", 
    \(\(Print["\<           f[z[\[Theta]]] = \>", 
        f[z[\[Theta]]]];\)\ \ \), "\n", 
    \(\(Print["\<             z'[\[Theta]] = \>", \(z'\)[\[Theta]]];\)\ \ \), \
"\n", 
    \(\(Print["\<     f[z[\[Theta]]] z'[\[Theta]] = \>", 
        f[z[\[Theta]]]\ \(z'\)[\[Theta]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print["\< F[\[Theta]] = \[Integral] f[z[\[Theta]]]z'[\[Theta]] \
\[DifferentialD]\[Theta] = \>", F[\[Theta]]];\)\ \ \), "\n", 
    \(\(Print["\<F[2\[Pi]] = \>", F[2  \[Pi]], "\<,  and  F[0] = \>", 
        F[0]];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\+0\%\(2  \[Pi]\)\)\>\"", \
"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>", \*"\"\<\!\(\
\[Integral]\+0\%\(2  \[Pi]\)\)\>\"", 
        f[z[\[Theta]]] \(z'\)[\[Theta]], "\< \[DifferentialD]\[Theta] = \>", 
        F[2  \[Pi]], "\< - \>", F[0], "\< = \>", 
        F[2  \[Pi]] - F[0]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\+0\%\(2  \[Pi]\)\)\>\"", \
"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>", 
        val];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{Red, PointSize[0.03], 
            Point[{2, 5\/3}]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(center = \ 
        Graphics[{{Text[
                StyleForm[TraditionalForm[\*"\"\<\!\(z\_0\)\>\""], 
                  FontSize \[Rule] 12], {2, 1.6}, {0, 
                  1}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{2, 5\/3}, 1]}];\)\ \ \), "\n", 
    \(\(Show[center, contour, dot, PlotRange \[Rule] {{0, 4}, {0, 3}}, 
        Ticks \[Rule] None, \[IndentingNewLine]AspectRatio \[Rule] 3\/4, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \ \), \
"\[IndentingNewLine]", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) \>\"", 
      f[z], "\< \[DifferentialD]z = \>", val]\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The contour is the unit circle C: |z - \!\(z\_0\)| = \
1,\>\""];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<with positive orientation.\>"];\)\ \ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Demonstration for (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Show that  ",
  Cell[BoxData[
      \(\[Integral]\_C\( 1\/\((z\  - \ z\_0)\)\^n\) \[DifferentialD]z = 
        0\)]],
  ".  \n",
  StyleBox["For illustration.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  We use n = 5 and a circle of radius 1 centered at  ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Z = \(z = 0\); \ Remove[z, Z];\ \ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, \[Theta], z, Z];\)\ \ \), "\n", 
    \(\(f[z_]\  = \ 1\/\((z - Z\_0)\)\^5;\)\ \ \), "\n", 
    \(\(z[\[Theta]_]\  = \ 
        Z\_0\  + \ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\);\)\ \ \), "\n\
", 
    \(\(F[\[Theta]_]\  = \[Integral]f[
              z[\[Theta]]] \(z'\)[\[Theta]] \[DifferentialD]\[Theta];\)\ \ \
\), "\n", 
    \(\(val\  = \ \[Integral]\_0\%\(2  \[Pi]\)f[
              z[\[Theta]]] \(z'\)[\[Theta]] \[DifferentialD]\[Theta];\)\ \ \
\), "\n", 
    \(\(Print["\<              f[z] = \>", f[z]];\)\ \ \), "\n", 
    \(\(Print["\<              z[\[Theta]] = \>", 
        z[\[Theta]]];\)\ \ \), "\n", 
    \(\(Print["\<           f[z[\[Theta]]] = \>", 
        f[z[\[Theta]]]];\)\ \ \), "\n", 
    \(\(Print["\<             z'[\[Theta]] = \>", \(z'\)[\[Theta]]];\)\ \ \), \
"\n", 
    \(\(Print["\<     f[z[\[Theta]]] z'[\[Theta]] = \>", 
        f[z[\[Theta]]]\ \(z'\)[\[Theta]]];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print["\< F[\[Theta]] = \[Integral] f[z[\[Theta]]]z'[\[Theta]] \
\[DifferentialD]\[Theta] = \>", F[\[Theta]]];\)\ \ \), "\n", 
    \(\(Print["\<F[2\[Pi]] = \>", F[2  \[Pi]], "\<,  and  F[0] = \>", 
        F[0]];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\+0\%\(2  \[Pi]\)\)\>\"", \
"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>", \*"\"\<\!\(\
\[Integral]\+0\%\(2  \[Pi]\)\)\>\"", 
        f[z[\[Theta]]] \(z'\)[\[Theta]], "\< \[DifferentialD]\[Theta] = \>", 
        F[2  \[Pi]], "\< - \>", F[0], "\< = \>", 
        F[2  \[Pi]] - F[0]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\+0\%\(2  \[Pi]\)\)\>\"", \
"\<f[z[\[Theta]]]z'[\[Theta]]\[DifferentialD]\[Theta] = \>", 
        val];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{Red, PointSize[0.03], 
            Point[{2, 5\/3}]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(center = \ 
        Graphics[{{Text[
                StyleForm[TraditionalForm[\*"\"\<\!\(z\_0\)\>\""], 
                  FontSize \[Rule] 12], {2, 1.6}, {0, 
                  1}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{2, 5\/3}, 1]}];\)\ \ \), "\n", 
    \(\(Show[center, contour, dot, PlotRange \[Rule] {{0, 4}, {0, 3}}, 
        Ticks \[Rule] None, \[IndentingNewLine]AspectRatio \[Rule] 3\/4, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \ \), \
"\[IndentingNewLine]", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) \>\"", 
      f[z], "\< \[DifferentialD]z = \>", val]\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The contour is the unit circle C: |z - \!\(z\_0\)| = \
1,\>\""];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<with positive orientation.\>"];\)\ \ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tThe deformation of contour theorem is an extension of the Cauchy-Goursat \
theorem to a doubly connected domain in the following sense.  Let ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " be a domain that contains ",
  Cell[BoxData[
      \(C\_1\)]],
  " and ",
  Cell[BoxData[
      \(C\_2\)]],
  " and the region between them, as shown in Figure 6.23.  Then the contour \
",
  Cell[BoxData[
      \(C = C\_2 - C\_1\)]],
  " is a parametrization of the boundary of the region ",
  StyleBox["R",
    FontFamily->"Courier New"],
  " that lies between ",
  Cell[BoxData[
      RowBox[{\(C\_1\), 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(C\_2\)}]]],
  " so that the points of ",
  StyleBox["R",
    FontFamily->"Courier New"],
  " lie to the left of ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " as a point ",
  StyleBox["z(t)",
    FontFamily->"Courier New"],
  " moves around ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".  Hence ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a positive orientation of the boundary of ",
  StyleBox["R",
    FontFamily->"Courier New"],
  ", and Theorem 6.6 implies that ",
  Cell[BoxData[
      \(\[Integral]\_C\ f \((z)\) \[DifferentialD]z = 0\)]],
  ".  "
}], "Text"],

Cell["\<\
\tWe can extend Theorem 6.6 to multiply connected domains with more than one \
\"hole.''  The proof, which is left for the reader, involves the introduction \
of several cuts and is similar to the proof of Theorem 6.6.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 6.7 (Extended Cauchy-Goursat Theorem).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      RowBox[{"C", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(C\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(C\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(C\_n\)}]]],
  "   be simple closed positively oriented contours with the property that  \
",
  Cell[BoxData[
      \(C\_k\)]],
  "  lies interior to ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " for   ",
  Cell[BoxData[
      RowBox[{\(k = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman"], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman"], "n"}]]],
  "  and the set of interior to  ",
  Cell[BoxData[
      \(C\_k\)]],
  "  has no points in common with the set interior to  ",
  Cell[BoxData[
      \(C\_j\)]],
  "  if  ",
  Cell[BoxData[
      \(k \[NotEqual] j\)]],
  ".  Let  ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  "  be analytic on a domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " that contains all the contours and the region between ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " and  ",
  Cell[BoxData[
      \(\(C\_1 + C\_2 +  ... \) + C\_n\)]],
  ",  as shown in Figure 6.26. Then\n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\ 
          f \((z)\) \[DifferentialD]z\ \  = \ \ \[Sum]\+\(k = 1\)\%n\
\[Integral]\_\(C\_k\)f \((z)\) \[DifferentialD]z\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.26",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/cauchygoursat/CauchyGoursatMod/\
Images/mat0626.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The multiply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " and the contours  ",
  Cell[BoxData[
      RowBox[{"C", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(C\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(C\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(C\_n\)}]]],
  "  in the statement of the extended Cauchy-Goursat theorem."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.7 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.14.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Integral]\_C\(\( 2  z\)\/\(z\^2\  + \ 2\)\) \[DifferentialD]z\  = \ 
        4\ \[Pi]\ \[ImaginaryI]\)]],
  ",  where",
  " ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " ",
  "is the circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 2\)]],
  "  taken with positive orientation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.5 0.238095 [
[.02381 .4875 -6 -9 ]
[.02381 .4875 6 0 ]
[.2619 .4875 -6 -9 ]
[.2619 .4875 6 0 ]
[.7381 .4875 -3 -9 ]
[.7381 .4875 3 0 ]
[.97619 .4875 -3 -9 ]
[.97619 .4875 3 0 ]
[1.025 .5 0 -6.28125 ]
[1.025 .5 10 6.28125 ]
[.4875 .02381 -12 -4.5 ]
[.4875 .02381 0 4.5 ]
[.4875 .2619 -12 -4.5 ]
[.4875 .2619 0 4.5 ]
[.4875 .7381 -6 -4.5 ]
[.4875 .7381 0 4.5 ]
[.4875 .97619 -6 -4.5 ]
[.4875 .97619 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .5 m
.02381 .50625 L
s
[(-2)] .02381 .4875 0 1 Mshowa
.2619 .5 m
.2619 .50625 L
s
[(-1)] .2619 .4875 0 1 Mshowa
.7381 .5 m
.7381 .50625 L
s
[(1)] .7381 .4875 0 1 Mshowa
.97619 .5 m
.97619 .50625 L
s
[(2)] .97619 .4875 0 1 Mshowa
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .02381 m
.50625 .02381 L
s
[(-2)] .4875 .02381 1 0 Mshowa
.5 .2619 m
.50625 .2619 L
s
[(-1)] .4875 .2619 1 0 Mshowa
.5 .7381 m
.50625 .7381 L
s
[(1)] .4875 .7381 1 0 Mshowa
.5 .97619 m
.50625 .97619 L
s
[(2)] .4875 .97619 1 0 Mshowa
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.03 w
.5 .16328 Mdot
.5 .83672 Mdot
0 g
gsave
.5 .12757 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .801 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
newpath
.5 .5 .47619 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{194, 194},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000320000`R000`400?l00000o`00003o`P3oool0
05X0oooo00<000000?ooo`3oool0I@3oool005X0oooo00<000000?ooo`3oool0I@3oool005<0oooo
100000030?ooo`030000003oool0oooo06D0oooo001C0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0I@3oool00540oooo4P000?mO0?ooo`00B`3oool60000o`@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`H0003oF@3oool004L0oooo10000?l80?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0303oool40000oeD0oooo00130?ooo`@0
003o3@3oool2000000@0oooo00<000000?ooo`3oool0403oool40000oe40oooo000o0?ooo`@0003o
5`3oool00`000000oooo0?ooo`0D0?ooo`@0003oC@3oool003d0oooo0P000?lK0?ooo`030000003o
ool0oooo01P0oooo0P000?m;0?ooo`00>`3oool20000oad0oooo00<000000?ooo`3oool06P3oool2
0000odT0oooo000g0?ooo`@0003o7`3oool00`000000oooo0?ooo`0L0?ooo`@0003oA@3oool003D0
oooo0P000?lS0?ooo`030000003oool0oooo0200oooo0P000?m30?ooo`00=03oool00`000?l0oooo
0?ooo`0S0?ooo`030000003oool0oooo0280oooo0P000?m10?ooo`00<P3oool20000obH0oooo00<0
00000?ooo`3oool0903oool20000ocl0oooo000`0?ooo`80003o:03oool00`000000oooo0?ooo`0V
0?ooo`80003o?@3oool002h0oooo0P000?lZ0?ooo`030000003oool0oooo02P0oooo00<0003o0?oo
o`3oool0>P3oool002`0oooo0P000?l/0?ooo`030000003oool0oooo02T0oooo0P000?lj0?ooo`00
:`3oool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool0
=`3oool002/0oooo00<0003o0?ooo`3oool0;03oool00`000000oooo0?ooo`060?ooo`D000008@3o
ool00`000?l0oooo0?ooo`0f0?ooo`00:@3oool20000obl0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0R0?ooo`80003o=P3oool002L0oooo0P000?la0?ooo`030000003oool0oooo
00D000000`3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo03<0oooo000V0?ooo`03
0000o`3oool0oooo0340oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`0000009`3oool20000oc<0oooo000U0?ooo`030000o`3oool0oooo0380oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<0003o0?oo
o`3oool0<03oool002@0oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo0?ooo`800000:P3oool00`000?l0oooo0?ooo`0_0?ooo`008P3oool20000ocH0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02d0oooo00<0003o0?oo
o`3oool0;P3oool00240oooo00<0003o0?ooo`3oool0=P3oool010000000oooo0?ooo`3oool50000
02l0oooo0P000?l^0?ooo`00803oool00`000?l0oooo0?ooo`0f0?ooo`<0o`00=`3oool00`000?l0
oooo0?ooo`0/0?ooo`007`3oool00`000?l0oooo0?ooo`0f0?ooo`D0o`00=`3oool00`000?l0oooo
0?ooo`0[0?ooo`007P3oool00`000?l0oooo0?ooo`0g0?ooo`D0o`00>03oool00`000?l0oooo0?oo
o`0Z0?ooo`007@3oool00`000?l0oooo0?ooo`0h0?ooo`D0o`00>@3oool00`000?l0oooo0?ooo`0Y
0?ooo`00703oool00`000?l0oooo0?ooo`0j0?ooo`<0o`00>`3oool00`000?l0oooo0?ooo`0X0?oo
o`006`3oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo03/0oooo00<0003o0?ooo`3o
ool09`3oool001X0oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000
o`3oool0oooo02H0oooo000J0?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0?@3o
ool00`000?l0oooo0?ooo`0U0?ooo`00603oool20000od00oooo00<000000?ooo`3oool0?@3oool0
0`000?l0oooo0?ooo`0U0?ooo`005`3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo
03h0oooo00<0003o0?ooo`3oool0903oool001L0oooo00<0003o0?ooo`3oool0@03oool00`000000
oooo0?ooo`0o0?ooo`030000o`3oool0oooo02<0oooo000F0?ooo`030000o`3oool0oooo0440oooo
00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0R0?ooo`005P3oool00`000?l0oooo0?oo
o`110?ooo`030000003oool0oooo0440oooo00<0003o0?ooo`3oool08@3oool001D0oooo00<0003o
0?ooo`3oool0@P3oool00`000000oooo0?ooo`110?ooo`030000o`3oool0oooo0240oooo000E0?oo
o`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0P0?oo
o`004`3oool20000odD0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0O0?ooo`00
4P3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool0
7`3oool00180oooo00<0003o0?ooo`3oool0?P3oool500000080oooo00<000000?ooo`3oool0A03o
ool00`000?l0oooo0?ooo`0N0?ooo`004@3oool00`000?l0oooo0?ooo`110?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`0N0?ooo`004@3oool00`00
0?l0oooo0?ooo`110?ooo`030000003oool0oooo0080oooo0P0000160?ooo`030000o`3oool0oooo
01d0oooo000@0?ooo`030000o`3oool0oooo03X0oooo100000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`0M0?ooo`00403oool00`000?l0oooo
0?ooo`120?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0AP3oool00`000?l0oooo
0?ooo`0L0?ooo`003`3oool00`000?l0oooo0?ooo`120?ooo`800000103oool00`000000oooo0?oo
o`160?ooo`030000o`3oool0oooo01`0oooo000>0?ooo`030000o`3oool0oooo04T0oooo00<00000
0?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0K0?ooo`003P3oool00`000?l0oooo0?ooo`190?oo
o`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool06P3oool000d0oooo00<0003o0?ooo`3o
ool0BP3oool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo01X0oooo000=0?ooo`030000
o`3oool0oooo04X0oooo00<000000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`0I0?ooo`003@3o
ool00`000?l0oooo0?ooo`1:0?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3oool06@3o
ool000d0oooo00<0003o0?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?ooo`030000o`3oool0
oooo01P0oooo000<0?ooo`030000o`3oool0oooo04/0oooo00<000000?ooo`3oool0BP3oool00`00
0?l0oooo0?ooo`0H0?ooo`00303oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo04/0
oooo00<0003o0?ooo`3oool05`3oool000/0oooo00<0003o0?ooo`3oool0C03oool00`000000oooo
0?ooo`1;0?ooo`030000o`3oool0oooo01L0oooo000;0?ooo`030000o`3oool0oooo04`0oooo00<0
00000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0G0?ooo`002P3oool00`000?l0oooo0?ooo`1=
0?ooo`030000003oool0oooo04/0oooo00<0003o0?ooo`3oool05`3oool000X0oooo00<0003o0?oo
o`3oool0C@3oool00`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo01H0oooo000:0?ooo`03
0000o`3oool0oooo04d0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`0F0?ooo`00
2P3oool00`000?l0oooo0?ooo`1=0?ooo`030000003oool0oooo04d0oooo00<0003o0?ooo`3oool0
5@3oool000T0oooo00<0003o0?ooo`3oool0CP3oool00`000000oooo0?ooo`1=0?ooo`030000o`3o
ool0oooo01D0oooo00090?ooo`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool0C@3oool0
0`000?l0oooo0?ooo`0E0?ooo`002@3oool00`000?l0oooo0?ooo`1>0?ooo`030000003oool0oooo
04d0oooo00<0003o0?ooo`3oool05@3oool000T0oooo00<0003o0?ooo`3oool0CP3oool00`000000
oooo0?ooo`1>0?ooo`030000o`3oool0oooo01@0oooo00080?ooo`030000o`3oool0oooo04l0oooo
00<000000?ooo`3oool0CP3oool00`000?l0oooo0?ooo`0D0?ooo`00203oool00`000?l0oooo0?oo
o`1?0?ooo`030000003oool0oooo04h0oooo00<0003o0?ooo`3oool0503oool000P0oooo00<0003o
0?ooo`3oool0C`3oool00`000000oooo0?ooo`1>0?ooo`030000o`3oool0oooo01@0oooo00080?oo
o`030000o`3oool0oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000?l0oooo0?ooo`0C0?oo
o`001`3oool00`000?l0oooo0?ooo`1@0?ooo`030000003oool0oooo04l0oooo00<0003o0?ooo`3o
ool04`3oool000L0oooo00<0003o0?ooo`3oool0D03oool00`000000oooo0?ooo`1?0?ooo`030000
o`3oool0oooo01<0oooo00070?ooo`030000o`3oool0oooo0500oooo00<000000?ooo`3oool0C`3o
ool00`000?l0oooo0?ooo`0C0?ooo`001`3oool00`000?l0oooo0?ooo`1@0?ooo`030000003oool0
oooo04l0oooo00<0003o0?ooo`3oool04`3oool000L0oooo00<0003o0?ooo`3oool0D03oool00`00
0000oooo0?ooo`1?0?ooo`030000o`3oool0oooo01<0oooo00070?ooo`040000o`00000000000000
02H0oooo1@00000T0?ooo`030000003oool0oooo02D0oooo1@00000T0?ooo`80000000<0003o0000
003oool04P3oool000H0oooo00<0003o0000003oool0:P3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0903oool00`000000oooo0000o`0D0?ooo`00
1P3oool00`000?l0oooo0000000Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0U0?ooo`03000000000?l0oooo01<0oooo00000`3oool000000000
0002000000050?ooo`000?l0oooo0?ooo`0000008@3oool4000000@0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0
4P3oool000H0oooo00D0003o0000003oool0oooo0000000X0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0T0?ooo`040000003oool0003o000001<0
oooo00060?ooo`040000o`3oool00000000002P0oooo0P00000V0?ooo`030000003oool0oooo02H0
oooo0P00000W0?ooo`03000000000?l0oooo01<0oooo00060?ooo`030000o`3oool0oooo0540oooo
00<000000?ooo`3oool0D03oool00`000?l0oooo0?ooo`0B0?ooo`001P3oool00`000?l0oooo0?oo
o`1A0?ooo`030000003oool0oooo0500oooo00<0003o0?ooo`3oool04P3oool000H0oooo00<0003o
0?ooo`3oool0D@3oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo0180oooo00060?oo
o`030000o`3oool0oooo0540oooo00<000000?ooo`3oool0D03oool00`000?l0oooo0?ooo`080?oo
o`80000000<0oooo0000000000001@3oool000H0oooo00<0003o0?ooo`3oool0D@3oool00`000000
oooo0?ooo`1@0?ooo`030000o`3oool0oooo00T0oooo00<000000?ooo`0000001P3oool00080oooo
100000000`000?l000000000002T000000030000o`000000000000<000001`3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000?l0oooo0?ooo`0W0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo00P0oooo0P00
00000`3oool00000000000050?ooo`001P3oool00`000?l0oooo0?ooo`1A0?ooo`030000003oool0
oooo0500oooo00<0003o0?ooo`3oool04P3oool000H0oooo00<0003o0?ooo`3oool0D@3oool00`00
0000oooo0?ooo`1@0?ooo`030000o`3oool0oooo0180oooo00060?ooo`030000o`3oool0oooo0540
oooo00<000000?ooo`3oool0D03oool00`000?l0oooo0?ooo`0B0?ooo`001P3oool00`000?l0oooo
0?ooo`1A0?ooo`030000003oool0oooo0500oooo00<0003o0?ooo`3oool04P3oool000H0oooo00<0
003o0?ooo`3oool0D@3oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo0180oooo0006
0?ooo`030000o`3oool0oooo0540oooo00<000000?ooo`3oool0D03oool00`000?l0oooo0?ooo`0B
0?ooo`001P3oool00`000?l0oooo0?ooo`1A0?ooo`030000003oool0oooo0500oooo00<0003o0?oo
o`3oool04P3oool000H0oooo00<0003o0?ooo`3oool0D@3oool00`000000oooo0?ooo`1@0?ooo`03
0000o`3oool0oooo0180oooo00070?ooo`030000o`3oool0oooo0500oooo00<000000?ooo`3oool0
D03oool00`000?l0oooo0?ooo`0B0?ooo`001`3oool00`000?l0oooo0?ooo`1@0?ooo`030000003o
ool0oooo04l0oooo00<0003o0?ooo`3oool04`3oool000L0oooo00<0003o0?ooo`3oool0D03oool0
0`000000oooo0?ooo`1?0?ooo`030000o`3oool0oooo01<0oooo00070?ooo`030000o`3oool0oooo
0500oooo00<000000?ooo`3oool0C`3oool00`000?l0oooo0?ooo`0C0?ooo`001`3oool00`000?l0
oooo0?ooo`1@0?ooo`030000003oool0oooo04l0oooo00<0003o0?ooo`3oool04`3oool000L0oooo
00<0003o0?ooo`3oool0D03oool00`000000oooo0?ooo`1?0?ooo`030000o`3oool0oooo01<0oooo
00080?ooo`030000o`3oool0oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000?l0oooo0?oo
o`0C0?ooo`00203oool00`000?l0oooo0?ooo`1?0?ooo`030000003oool0oooo04h0oooo00<0003o
0?ooo`3oool0503oool000P0oooo00<0003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`1>0?oo
o`030000o`3oool0oooo01@0oooo00080?ooo`030000o`3oool0oooo04l0oooo00<000000?ooo`3o
ool0CP3oool00`000?l0oooo0?ooo`0D0?ooo`002@3oool00`000?l0oooo0?ooo`1>0?ooo`030000
003oool0oooo04h0oooo00<0003o0?ooo`3oool0503oool000T0oooo00<0003o0?ooo`3oool0CP3o
ool00`000000oooo0?ooo`1=0?ooo`030000o`3oool0oooo01D0oooo00090?ooo`030000o`3oool0
oooo04h0oooo00<000000?ooo`3oool0C@3oool00`000?l0oooo0?ooo`0E0?ooo`002@3oool00`00
0?l0oooo0?ooo`1>0?ooo`030000003oool0oooo04d0oooo00<0003o0?ooo`3oool05@3oool000X0
oooo00<0003o0?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000o`3oool0oooo01D0
oooo000:0?ooo`030000o`3oool0oooo04d0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo
0?ooo`0F0?ooo`002P3oool00`000?l0oooo0?ooo`1=0?ooo`030000003oool0oooo04`0oooo00<0
003o0?ooo`3oool05P3oool000X0oooo00<0003o0?ooo`3oool0C@3oool00`000000oooo0?ooo`1;
0?ooo`030000o`3oool0oooo01L0oooo000;0?ooo`030000o`3oool0oooo04`0oooo00<000000?oo
o`3oool0B`3oool00`000?l0oooo0?ooo`0G0?ooo`002`3oool00`000?l0oooo0?ooo`1<0?ooo`03
0000003oool0oooo04/0oooo00<0003o0?ooo`3oool05`3oool000`0oooo00<0003o0?ooo`3oool0
B`3oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo01L0oooo000<0?ooo`030000o`3o
ool0oooo04/0oooo00<000000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`0H0?ooo`003@3oool0
0`000?l0oooo0?ooo`1:0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool0603oool0
00d0oooo00<0003o0?ooo`3oool0BP3oool00`000000oooo0?ooo`190?ooo`030000o`3oool0oooo
01T0oooo000=0?ooo`030000o`3oool0oooo04X0oooo00<000000?ooo`3oool0B@3oool00`000?l0
oooo0?ooo`0I0?ooo`003@3oool00`000?l0oooo0?ooo`1:0?ooo`030000003oool0oooo04P0oooo
00<0003o0?ooo`3oool06P3oool000h0oooo00<0003o0?ooo`3oool0B@3oool00`000000oooo0?oo
o`180?ooo`030000o`3oool0oooo01X0oooo000>0?ooo`030000o`3oool0oooo04T0oooo00<00000
0?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0K0?ooo`003`3oool00`000?l0oooo0?ooo`180?oo
o`030000003oool0oooo04L0oooo00<0003o0?ooo`3oool06`3oool000l0oooo00<0003o0?ooo`3o
ool0B03oool00`000000oooo0?ooo`160?ooo`030000o`3oool0oooo01`0oooo000@0?ooo`030000
o`3oool0oooo0400oooo1@0000020?ooo`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool0
703oool00100oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo04D0oooo00<0003o0?ooo`3oool07@3oool00140oooo00<0003o0?ooo`3oool0@@3oool0
0`000000oooo0?ooo`020?ooo`800000AP3oool00`000?l0oooo0?ooo`0M0?ooo`004P3oool00`00
0?l0oooo0?ooo`100?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A03oool00`00
0?l0oooo0?ooo`0N0?ooo`004P3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0O0?ooo`004`3oool00`000?l0oooo
0?ooo`0n0?ooo`800000103oool00`000000oooo0?ooo`130?ooo`030000o`3oool0oooo01l0oooo
000D0?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?oo
o`0P0?ooo`005@3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo0480oooo00<0003o
0?ooo`3oool0803oool001D0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`110?oo
o`030000o`3oool0oooo0240oooo000F0?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3o
ool01`3oool3000003L0oooo00<0003o0?ooo`3oool08@3oool001L0oooo00<0003o0?ooo`3oool0
@03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03D0oooo0P000?lT0?ooo`005`3o
ool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo00D000000`3oool00`000000oooo0?oo
o`0c0?ooo`030000o`3oool0oooo02@0oooo000H0?ooo`030000o`3oool0oooo03l0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000=@3oool00`000?l0oooo
0?ooo`0T0?ooo`006@3oool20000ocl0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000003<0oooo00<0003o0?ooo`3oool09@3oool001X0oooo00<0003o
0?ooo`3oool0?@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0V0?ooo`006`3oool00`000?l0oooo0?ooo`0l0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0
oooo02L0oooo000K0?ooo`030000o`3oool0oooo03`0oooo00@000000?ooo`3oool0oooo1@00000d
0?ooo`030000o`3oool0oooo02P0oooo000L0?ooo`030000o`3oool0oooo03X0oooo0`3o000k0?oo
o`030000o`3oool0oooo02P0oooo000M0?ooo`030000o`3oool0oooo03P0oooo1@3o000i0?ooo`03
0000o`3oool0oooo02T0oooo000N0?ooo`030000o`3oool0oooo03L0oooo1@3o000h0?ooo`030000
o`3oool0oooo02X0oooo000O0?ooo`030000o`3oool0oooo03H0oooo1@3o000g0?ooo`030000o`3o
ool0oooo02/0oooo000P0?ooo`80003o=`3oool30?l003L0oooo00<0003o0?ooo`3oool0;03oool0
0280oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0d0?ooo`80003o;`3oool002<0
oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000o`3oool0oooo02l0
oooo000T0?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo
0?ooo`0`0?ooo`009@3oool20000oc<0oooo00<000000?ooo`3oool0<@3oool00`000?l0oooo0?oo
o`0a0?ooo`009`3oool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo02l0oooo0P000?ld
0?ooo`00:03oool00`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02h0oooo00<0003o0?oo
o`3oool0=03oool002T0oooo00<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`03
0000o`3oool0oooo03@0oooo000Z0?ooo`80003o;P3oool00`000000oooo0?ooo`0/0?ooo`80003o
=`3oool002`0oooo00<0003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`0Z0?ooo`80003o>@3o
ool002d0oooo0P000?l[0?ooo`030000003oool0oooo02P0oooo0P000?lk0?ooo`00;`3oool20000
obT0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0k0?ooo`00<@3oool20000obL0
oooo00<000000?ooo`3oool09@3oool20000och0oooo000c0?ooo`80003o9@3oool00`000000oooo
0?ooo`0S0?ooo`80003o@03oool003D0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?oo
o`0Q0?ooo`80003o@P3oool003H0oooo0P000?lR0?ooo`030000003oool0oooo01l0oooo0P000?m4
0?ooo`00>03oool20000ob00oooo00<000000?ooo`3oool07@3oool20000odH0oooo000j0?ooo`@0
003o703oool00`000000oooo0?ooo`0I0?ooo`@0003oB03oool003h0oooo0P000?lJ0?ooo`030000
003oool0oooo01L0oooo0P000?m<0?ooo`00@03oool40000oaH0oooo00<000000?ooo`3oool04`3o
ool40000odh0oooo00140?ooo`@0003o2`3oool4000000<0oooo00<000000?ooo`3oool03`3oool4
0000oe80oooo00180?ooo`H0003o1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00T0oooo1P000?mF0?ooo`00CP3ooolH0000oe`0oooo001E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0I@3oool005<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`1U0?ooo`00E03oool2000000@0oooo00<000000?ooo`3oool0I@3oool005X0oooo00<00000
0?ooo`3oool0I@3oool005X0oooo00<000000?ooo`3oool0I@3oool00<80oooo00320?ooo`00`P3o
ool00<80oooo00320?ooo`00`P3oool005P0oooo0P00001X0?ooo`00F@3oool00`000000oooo0?oo
o`1V0?ooo`00FP3oool00`000000oooo0?ooo`1U0?ooo`00F@3oool00`000000oooo0000001V0?oo
o`00F03oool010000000oooo0?ooo`00001V0?ooo`00E`3oool3000000030?ooo`000000000006D0
oooo00320?ooo`00`P3oool00<80oooo00320?ooo`00\
\>"],
    ImageRangeCache->{{{0, 193}, {193, 0}} -> {-2, -2, 0, 0}}],
  "  "
}], "Text"],

Cell[TextData[{
  "Solution.  Using partial fraction decomposition gives  \n\n\t\t\t",
  Cell[BoxData[
      \(\(2  z\)\/\(z\^2\  + \ 2\)\ \  = \ \ \(\(2  z\)\/\(\((z\  + \ \
\[ImaginaryI]\ \@2)\) \((z\  - \ \[ImaginaryI]\ \@2)\)\)\ \  = \ \ \ 1\/\(z\  \
+ \ \[ImaginaryI]\ \@2\) + 1\/\(z\  - \ \[ImaginaryI]\ \@2\)\)\)]],
  ",  so    \n\n",
  StyleBox["(6-38)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\(\( 2  z\)\/\(z\^2\  + \ 
                  2\)\) \[DifferentialD]z\ \  = \ \ \[Integral]\_C\( 
                  1\/\(z\  + \ \[ImaginaryI]\ \@2\)\) \[DifferentialD]z\ \  + \
\ \ \[Integral]\_C\( 
                  1\/\(z\  - \ \[ImaginaryI]\ \@2\)\) \[DifferentialD]z\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\nThe points  ",
  Cell[BoxData[
      \(z\  = \ \(\[PlusMinus]\ \[ImaginaryI]\)\ \@2\)]],
  "  lie interior to ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ",  so Corollary 6.1 implies that  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\( 
                1\/\(z\  \[PlusMinus] \ \[ImaginaryI]\ \@2\)\) \
\[DifferentialD]z\ \  = \ \ 2  \[Pi]\ \[ImaginaryI]\)]],
  ".  \n\nSubstituting these values into Equation ",
  StyleBox["(6-38)",
    FontColor->RGBColor[0, 0, 1]],
  " yields  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_C\(\( 2  z\)\/\(z\^2\  + \ 
                  2\)\) \[DifferentialD]z\ \  = \ \ \[Integral]\_C\( 
                  1\/\(z\  + \ \[ImaginaryI]\ \@2\)\) \[DifferentialD]z\ \  + \
\ \ \[Integral]\_C\( 
                  1\/\(z\  - \ \[ImaginaryI]\ \@2\)\) \[DifferentialD]z\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(2  \[Pi]\
\ \[ImaginaryI]\ \  + \ \ 2  \[Pi]\ \[ImaginaryI]\)\)\ \ \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(4  \[Pi]\
\ \[ImaginaryI]\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \(2  z\)\/\(z\^2\  + \ 2\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[R, W, z, Z];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, i, p, solset];\)\ \ \), "\n", 
    \(\(f[z_]\  = \ \(2  z\)\/\(z\^2\  + \ 2\);\)\ \ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "First, split the function up into partial fractions involving linear terms \
in the denominators. Don't worry about the subroutine.  It splits  ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  "  up into partial fractions.  The result will be an equivalent function \
named F[z].  The list of terms added to form F[z] have singularities in the \
same order in the list of points Z."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, z]];\)\ \ \), "\n", 
    \(\(Z\  = \ Table[0, {Length[solset]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(W\  = \ Table[0, {Length[solset]}];\)\ \ \), "\n", 
    \(\(R\  = \ Table[0, {Length[solset]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(F[z_]\  = \ 0;\)\ \ \), "\n", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[solset], \(i++\), \[IndentingNewLine]Z\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          ReplaceAll[z, 
            solset\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
]; \ \ \ \[IndentingNewLine]If[1 \[Equal] i, 
          p\  = \ 1]; \ \ \[IndentingNewLine]If[
          1 < i; \ \ Z\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\) \[Equal] 
            Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\), 
          p\  = \ p + 1, 
          p\  = \ 1]; \ \ \[IndentingNewLine]R\_\(\(\[LeftDoubleBracket]\)\(i\
\)\(\[RightDoubleBracket]\)\)\  = \ 
          Residue[\(\((z - 
                      Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\))\)\^\(p - 1\)\) f[z], {z, 
              Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)}];\
 \ \ \[IndentingNewLine]W\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\) = \ 
          R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\/\((z \
- Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\))\)\^p; \ \ \n\
\ \ \ F[z_]\  = \ 
          F[z]\  + 
            R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\/\((\
z - Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\))\)\^p;\ \ \
];\)\ \ \), "\n", 
    \(\(For[i = 1, 
        i \[LessEqual] Length[F[z]], \(i++\), \n\ \ \ soset\  = \ 
          Solve[Denominator[
                W\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]\
 \[Equal] 0, 
            z]; \ \ \n\ \ \ Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\)\  = \ 
          ReplaceAll[z, 
            soset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]\
; \ \ \n\ \ \ R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  \
= \ Residue[
            f[z], {z, 
              Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)}];\
\ \ ];\)\ \ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \ \), "\n", 
    \(\(Print["\<f[z] = \>", F[z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Determine which singularities lie inside  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<,  \
Is |\>", Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<| \
< 2 ?  \>", 
        N[Abs[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]] \
< 2];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\), "\<,   \
Is |\>", Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\), "\<| \
< 2 ?   \>", 
        N[Abs[Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)]] \
< 2];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Since both singularities lie inside ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", add the corresponding term in the sum forming F[z] times constant in the \
numerator that term times ",
  Cell[BoxData[
      \(2  \[Pi]\ \[ImaginaryI]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(val\  = \ 
        2  \[Pi]\ \[ImaginaryI]\ Numerator[\(F[z]\)\_\(\(\[LeftDoubleBracket]\
\)\(1\)\(\[RightDoubleBracket]\)\)] + 
          2  \[Pi]\ \[ImaginaryI]\ Numerator[\(F[z]\)\_\(\(\
\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], 
              Point[{Re[
                    Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\)], Im[
                    Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\)]}]}, {Red, PointSize[0.03], 
              Point[{Re[
                    Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\
\)\)], Im[
                    Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\
\)\)]}]}}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[
              StyleForm[TraditionalForm[\*"\"\<\!\(z\_1\)\>\""], 
                FontSize \[Rule] 12], {Re[
                  Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)], Im[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)] - 
                  0.15}, {\(-1\), 0}], 
            Text[StyleForm[TraditionalForm[\*"\"\<\!\(z\_2\)\>\""], 
                FontSize \[Rule] 12], {Re[
                  Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\
\)], Im[Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)] - 
                  0.15}, {\(-1\), 0}]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 2]}];\)\ \ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-2.1\), 2.1}, {\(-2.1\), 2.1}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = \>", \
\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        W\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<) \
\[DifferentialD]z + \>", \*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        W\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\), "\<) \
\[DifferentialD]z\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = \>", "\<(\>", 
        2  \[Pi]\ \[ImaginaryI]\ Numerator[\(F[z]\)\_\(\(\[LeftDoubleBracket]\
\)\(1\)\(\[RightDoubleBracket]\)\)], "\<) + \>", "\<(\>", 
        2  \[Pi]\ \[ImaginaryI]\ Numerator[\(F[z]\)\_\(\(\[LeftDoubleBracket]\
\)\(2\)\(\[RightDoubleBracket]\)\)], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = \>", 
        val];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The contour is the circle  C: |z| = 2,\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<with positive orientation.\>"];\)\ \ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.15.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Integral]\_C\(\( 2  z\)\/\(z\^2\  + \ 2\)\) \[DifferentialD]z\  = \ 
        2\ \[Pi]\ \[ImaginaryI]\)]],
  ",  where",
  " ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " ",
  "is the circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z - \[ImaginaryI]\)\(|\)\) = 1\)]],
  "  taken with positive orientation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.454545 0.0454545 0.454545 [
[.04545 .03295 -6 -9 ]
[.04545 .03295 6 0 ]
[.95455 .03295 -3 -9 ]
[.95455 .03295 3 0 ]
[1.025 .04545 0 -6.28125 ]
[1.025 .04545 10 6.28125 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .95455 -6 -4.5 ]
[.4875 .95455 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04545 .04545 m
.04545 .0517 L
s
[(-1)] .04545 .03295 0 1 Mshowa
.95455 .04545 m
.95455 .0517 L
s
[(1)] .95455 .03295 0 1 Mshowa
0 .04545 m
1 .04545 L
s
gsave
1.025 .04545 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .95455 m
.50625 .95455 L
s
[(2)] .4875 .95455 1 0 Mshowa
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.03 w
.5 .68828 Mdot
0 g
gsave
.5 .64282 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
newpath
.5 .5 .45455 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{194, 194},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000320000`R000`400?l00000o`00003o`P3oool0
00/0oooo1@00002E0?ooo`D00000603oool000d0oooo00<000000?ooo`3oool0U`3oool00`000000
oooo0?ooo`0H0?ooo`003@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo01P0oooo
00050?ooo`@00000103oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0603oool000d0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo01P0oooo000<0?ooo`800000B`3oool00`000000oooo0?ooo`1:0?oo
o`8000006P3oool005T0oooo00<000000?ooo`3oool0IP3oool005T0oooo00<000000?ooo`3oool0
IP3oool005T0oooo00<000000?ooo`3oool0IP3oool005T0oooo00<000000?ooo`3oool0FP3oool2
000000030?ooo`000000000000L0oooo001I0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`000000203oool00080ooooC@00000E0000od`00000203oool00`000000oooo0?ooo`070?ooo`00
2P3oool00`000000oooo0?ooo`0l0?ooo`H0003o2P3oool00`000000oooo0?ooo`080?ooo`D0003o
?P3oool00`000000oooo0?ooo`0<0?ooo`80000000<0oooo0000000000001`3oool004D0oooo1000
0?l@0?ooo`030000003oool0oooo00d0oooo10000?mE0?ooo`00@P3oool30000oa@0oooo00<00000
0?ooo`3oool04@3oool40000oe40oooo000n0?ooo`@0003o5`3oool00`000000oooo0?ooo`0E0?oo
o`@0003oC@3oool003`0oooo0P000?lK0?ooo`030000003oool0oooo01T0oooo0P000?m;0?ooo`00
>P3oool20000oad0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`180?ooo`00=`3o
ool30000oal0oooo00<000000?ooo`3oool0703oool40000odH0oooo000e0?ooo`80003o8P3oool0
0`000000oooo0?ooo`0P0?ooo`80003oA03oool003<0oooo0P000?lT0?ooo`030000003oool0oooo
0280oooo00<0003o0?ooo`3oool0@@3oool00380oooo00<0003o0?ooo`3oool0903oool00`000000
oooo0?ooo`0S0?ooo`80003o@@3oool00300oooo0P000?lW0?ooo`030000003oool0oooo02D0oooo
0P000?lo0?ooo`00;P3oool20000obT0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?oo
o`0l0?ooo`00;@3oool00`000?l0oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo0P000?ll
0?ooo`00:`3oool20000ob`0oooo00<000000?ooo`3oool0:P3oool20000ocX0oooo000Z0?ooo`03
0000o`3oool0oooo02`0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`0h0?ooo`00
:@3oool00`000?l0oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<0003o0?ooo`3oool0
=`3oool002P0oooo00<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`80003o=`3o
ool002H0oooo0P000?la0?ooo`030000003oool0oooo02l0oooo0P000?le0?ooo`009@3oool00`00
0?l0oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<0003o0?ooo`3oool0<P3oool002@0
oooo00<0003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo0340
oooo000S0?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo
0?ooo`0`0?ooo`008P3oool00`000?l0oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<0
003o0?ooo`3oool0;`3oool00240oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0e
0?ooo`030000o`3oool0oooo02h0oooo000P0?ooo`030000o`3oool0oooo03H0oooo00<000000?oo
o`3oool0=@3oool00`000?l0oooo0?ooo`0^0?ooo`007`3oool00`000?l0oooo0?ooo`0g0?ooo`03
0000003oool0oooo03H0oooo00<0003o0?ooo`3oool0;@3oool001h0oooo00<0003o0?ooo`3oool0
>03oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo02`0oooo000N0?ooo`030000o`3o
ool0oooo03P0oooo00<000000?ooo`3oool0>03oool00`000?l0oooo0?ooo`0[0?ooo`007@3oool0
0`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<0003o0?ooo`3oool0:P3oool0
01/0oooo0P000?ll0?ooo`030000003oool0oooo03X0oooo00<0003o0?ooo`3oool0:@3oool001X0
oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`0j0?ooo`030000o`3oool0oooo02T0
oooo000J0?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0>`3oool00`000?l0oooo
0?ooo`0X0?ooo`006@3oool00`000?l0oooo0?ooo`0m0?ooo`030000003oool0oooo03`0oooo0P00
0?lX0?ooo`00603oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0oooo03d0oooo00<0003o
0?ooo`3oool09P3oool001P0oooo00<0003o0?ooo`3oool0?P3oool00`000000oooo0?ooo`0n0?oo
o`030000o`3oool0oooo02D0oooo000G0?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3o
ool0?P3oool00`000?l0oooo0?ooo`0U0?ooo`005`3oool00`000?l0oooo0?ooo`0o0?ooo`030000
003oool0oooo03l0oooo00<0003o0?ooo`3oool0903oool001H0oooo00<0003o0?ooo`3oool0@03o
ool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo02<0oooo000E0?ooo`030000o`3oool0
oooo0440oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0S0?ooo`005@3oool00`00
0?l0oooo0?ooo`110?ooo`030000003oool0oooo0440oooo00<0003o0?ooo`3oool08P3oool001@0
oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`110?ooo`030000o`3oool0oooo0280
oooo000D0?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo
0?ooo`0Q0?ooo`004`3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo04<0oooo00<0
003o0?ooo`3oool0803oool00180oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`13
0?ooo`030000o`3oool0oooo0200oooo000B0?ooo`030000o`3oool0oooo04@0oooo00<000000?oo
o`3oool0A03oool00`000?l0oooo0?ooo`0O0?ooo`004@3oool00`000?l0oooo0?ooo`150?ooo`03
0000003oool0oooo04@0oooo00<0003o0?ooo`3oool07`3oool00140oooo00<0003o0?ooo`3oool0
A@3oool00`000000oooo0?ooo`140?ooo`030000o`3oool0oooo01l0oooo000@0?ooo`030000o`3o
ool0oooo04H0oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`0O0?ooo`00403oool0
0`000?l0oooo0?ooo`160?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool07P3oool0
0100oooo00<0003o0?ooo`3oool0AP3oool00`000000oooo0?ooo`150?ooo`030000o`3oool0oooo
01h0oooo000@0?ooo`030000o`3oool0oooo04H0oooo00<000000?ooo`3oool0AP3oool00`000?l0
oooo0?ooo`0M0?ooo`003`3oool00`000?l0oooo0?ooo`170?ooo`030000003oool0oooo04L0oooo
00<0003o0?ooo`3oool0703oool000h0oooo00<0003o0?ooo`3oool0B03oool00`000000oooo0?oo
o`170?ooo`030000o`3oool0oooo01`0oooo000>0?ooo`030000o`3oool0oooo04P0oooo00<00000
0?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0L0?ooo`003P3oool00`000?l0oooo0?ooo`180?oo
o`030000003oool0oooo04L0oooo00<0003o0?ooo`3oool0703oool000h0oooo00<0003o0?ooo`3o
ool0B03oool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo01/0oooo000=0?ooo`030000
o`3oool0oooo04T0oooo00<000000?ooo`3oool0B03oool00`000?l0oooo0?ooo`0K0?ooo`003@3o
ool00`000?l0oooo0?ooo`190?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool06`3o
ool000d0oooo00<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`180?ooo`030000o`3oool0
oooo01/0oooo000=0?ooo`030000o`3oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`00
0?l0oooo0?ooo`0J0?ooo`00303oool00`000?l0oooo0?ooo`1:0?ooo`030000003oool0oooo04T0
oooo00<0003o0?ooo`3oool06P3oool000`0oooo00<0003o0?ooo`3oool0BP3oool00`000000oooo
0?ooo`190?ooo`030000o`3oool0oooo01X0oooo000<0?ooo`030000o`3oool0oooo04X0oooo00<0
00000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`0J0?ooo`00303oool00`000?l0oooo0?ooo`1:
0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool06@3oool000/0oooo00<0003o0?oo
o`3oool0B`3oool00`000000oooo0?ooo`1:0?ooo`030000o`3oool0oooo01T0oooo000;0?ooo`03
0000o`3oool0oooo04/0oooo00<000000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`0I0?ooo`00
2`3oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool0
6@3oool000/0oooo00<0003o0?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000o`3o
ool0oooo01P0oooo000;0?ooo`030000o`3oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool0
0`000?l0oooo0?ooo`0H0?ooo`002`3oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo
04/0oooo00<0003o0?ooo`3oool0603oool000/0oooo00<0003o0?ooo`3oool0B`3oool00`000000
oooo0?ooo`1;0?ooo`030000o`3oool0oooo01P0oooo000;0?ooo`030000o`3oool0oooo04/0oooo
00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0H0?ooo`002`3oool00`000?l0oooo0?oo
o`1;0?ooo`030000003oool0oooo04/0oooo00<0003o0?ooo`3oool0603oool000X0oooo00<0003o
0?ooo`3oool0C03oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo01P0oooo000:0?oo
o`030000o`3oool0oooo04`0oooo00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0H0?oo
o`002P3oool00`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo04/0oooo00<0003o0?ooo`3o
ool0603oool000X0oooo00<0003o0?ooo`3oool0A@3oool500000080oooo00<000000?ooo`3oool0
B`3oool00`000?l0oooo0?ooo`0H0?ooo`002P3oool00`000?l0oooo0?ooo`170?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0H0?ooo`002P3oool0
0`000?l0oooo0?ooo`170?ooo`030000003oool0oooo0080oooo0P00001<0?ooo`030000o`3oool0
oooo01P0oooo000:0?ooo`030000o`3oool0oooo04L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1;0?ooo`030000o`3oool0oooo01P0oooo000:0?ooo`030000o`3oool0oooo04L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo01P0
oooo000:0?ooo`030000o`3oool0oooo04H0oooo0P0000040?ooo`030000003oool0oooo04/0oooo
00<0003o0?ooo`3oool0603oool000X0oooo00<0003o0?ooo`3oool0C03oool00`000000oooo0?oo
o`1;0?ooo`030000o`3oool0oooo01P0oooo000:0?ooo`030000o`3oool0oooo04`0oooo00<00000
0?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0H0?ooo`002`3oool00`000?l0oooo0?ooo`1;0?oo
o`030000003oool0oooo04/0oooo00<0003o0?ooo`3oool0603oool000/0oooo00<0003o0?ooo`3o
ool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo01P0oooo000;0?ooo`030000
o`3oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0H0?ooo`002`3o
ool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<0003o0?ooo`3oool0603o
ool000/0oooo00<0003o0?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0
oooo01P0oooo000;0?ooo`030000o`3oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`00
0?l0oooo0?ooo`0H0?ooo`002`3oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo04/0
oooo00<0003o0?ooo`3oool0603oool000/0oooo00<0003o0?ooo`3oool0B`3oool00`000000oooo
0?ooo`1:0?ooo`030000o`3oool0oooo01T0oooo000;0?ooo`030000o`3oool0oooo04/0oooo00<0
00000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`0I0?ooo`002`3oool00`000?l0oooo0?ooo`1;
0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool06@3oool000`0oooo00<0003o0?oo
o`3oool0BP3oool00`000000oooo0?ooo`1:0?ooo`030000o`3oool0oooo01T0oooo000<0?ooo`03
0000o`3oool0oooo04X0oooo00<000000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`0J0?ooo`00
303oool00`000?l0oooo0?ooo`1:0?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3oool0
6P3oool000`0oooo00<0003o0?ooo`3oool0BP3oool00`000000oooo0?ooo`190?ooo`030000o`3o
ool0oooo01X0oooo000=0?ooo`030000o`3oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool0
0`000?l0oooo0?ooo`0J0?ooo`003@3oool00`000?l0oooo0?ooo`190?ooo`030000003oool0oooo
04P0oooo00<0003o0?ooo`3oool06`3oool000d0oooo00<0003o0?ooo`3oool0B@3oool00`000000
oooo0?ooo`070?ooo`<00000?P3oool00`000?l0oooo0?ooo`0K0?ooo`003P3oool00`000?l0oooo
0?ooo`180?ooo`030000003oool0oooo00D000000P3oool00`000000oooo0?ooo`0n0?ooo`030000
o`3oool0oooo01/0oooo000>0?ooo`030000o`3oool0oooo04P0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`000000?P3oool00`000?l0oooo0?ooo`0L0?ooo`00
3P3oool00`000?l0oooo0?ooo`180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0l0?ooo`030000o`3oool0oooo01`0oooo000>0?ooo`030000o`3o
ool0oooo04P0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`00
0000?@3oool00`000?l0oooo0?ooo`0L0?ooo`003`3oool00`000?l0oooo0?ooo`170?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000003h0oooo00<0003o0?oo
o`3oool0703oool000l0oooo00<0003o0?ooo`3oool0A`3oool010000000oooo0?ooo`3oool50000
0400oooo00<0003o0?ooo`3oool07@3oool00100oooo00<0003o0?ooo`3oool0AP3oool00`000000
oooo0?ooo`160?ooo`030000o`3oool0oooo01d0oooo000@0?ooo`030000o`3oool0oooo04H0oooo
00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`0N0?ooo`00403oool00`000?l0oooo0?oo
o`150?ooo`<0o`00AP3oool00`000?l0oooo0?ooo`0N0?ooo`00403oool00`000?l0oooo0?ooo`14
0?ooo`D0o`00A03oool00`000?l0oooo0?ooo`0O0?ooo`004@3oool00`000?l0oooo0?ooo`130?oo
o`D0o`00A03oool00`000?l0oooo0?ooo`0O0?ooo`004P3oool00`000?l0oooo0?ooo`120?ooo`D0
o`00A03oool00`000?l0oooo0?ooo`0O0?ooo`004P3oool00`000?l0oooo0?ooo`130?ooo`<0o`00
A03oool00`000?l0oooo0?ooo`0P0?ooo`004`3oool00`000?l0oooo0?ooo`130?ooo`030000003o
ool0oooo04<0oooo00<0003o0?ooo`3oool0803oool001<0oooo00<0003o0?ooo`3oool0@`3oool0
0`000000oooo0?ooo`120?ooo`030000o`3oool0oooo0240oooo000D0?ooo`030000o`3oool0oooo
0480oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0Q0?ooo`005@3oool00`000?l0
oooo0?ooo`110?ooo`030000003oool0oooo0440oooo00<0003o0?ooo`3oool08P3oool001D0oooo
00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo02<0oooo
000F0?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0?oo
o`0S0?ooo`005P3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo03l0oooo00<0003o
0?ooo`3oool0903oool001L0oooo00<0003o0?ooo`3oool0?`3oool00`000000oooo0?ooo`0o0?oo
o`030000o`3oool0oooo02@0oooo000H0?ooo`030000o`3oool0oooo03h0oooo00<000000?ooo`3o
ool0?P3oool00`000?l0oooo0?ooo`0U0?ooo`00603oool00`000?l0oooo0?ooo`0n0?ooo`030000
003oool0oooo03d0oooo00<0003o0?ooo`3oool09P3oool001T0oooo00<0003o0?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo02H0oooo000I0?ooo`030000o`3oool0
oooo03d0oooo00<000000?ooo`3oool0?03oool00`000?l0oooo0?ooo`0W0?ooo`006P3oool00`00
0?l0oooo0?ooo`0l0?ooo`030000003oool0oooo03/0oooo00<0003o0?ooo`3oool0:03oool001/0
oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000o`3oool0oooo02T0
oooo000L0?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo
0?ooo`0Z0?ooo`007@3oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<0
003o0?ooo`3oool0:P3oool001h0oooo00<0003o0?ooo`3oool0>03oool00`000000oooo0?ooo`0h
0?ooo`030000o`3oool0oooo02/0oooo000N0?ooo`030000o`3oool0oooo03P0oooo00<000000?oo
o`3oool0=`3oool00`000?l0oooo0?ooo`0/0?ooo`007`3oool00`000?l0oooo0?ooo`0g0?ooo`03
0000003oool0oooo03H0oooo00<0003o0?ooo`3oool0;@3oool00200oooo0P000?lg0?ooo`030000
003oool0oooo03D0oooo00<0003o0?ooo`3oool0;P3oool00280oooo00<0003o0?ooo`3oool0=03o
ool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo02l0oooo000S0?ooo`030000o`3oool0
oooo03<0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`0`0?ooo`00903oool00`00
0?l0oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3oool0<@3oool002D0
oooo00<0003o0?ooo`3oool0<@3oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo0380
oooo000V0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0<03oool00`000?l0oooo
0?ooo`0c0?ooo`009`3oool00`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02l0oooo00<0
003o0?ooo`3oool0=03oool002P0oooo00<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0^
0?ooo`030000o`3oool0oooo03D0oooo000Y0?ooo`030000o`3oool0oooo02d0oooo00<000000?oo
o`3oool0;03oool20000ocP0oooo000Z0?ooo`80003o;@3oool00`000000oooo0?ooo`0[0?ooo`03
0000o`3oool0oooo03P0oooo000/0?ooo`80003o:`3oool00`000000oooo0?ooo`0Y0?ooo`80003o
>`3oool002h0oooo00<0003o0?ooo`3oool0:03oool00`000000oooo0?ooo`0W0?ooo`80003o?@3o
ool002l0oooo0P000?lX0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0?@3oool0
0340oooo0P000?lV0?ooo`030000003oool0oooo02@0oooo0P000?m00?ooo`00<`3oool00`000?l0
oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo0P000?m20?ooo`00=03oool20000ob<0oooo
00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`120?ooo`00=P3oool20000ob40oooo00<0
00000?ooo`3oool07`3oool20000odD0oooo000h0?ooo`80003o7`3oool00`000000oooo0?ooo`0M
0?ooo`80003oA`3oool003X0oooo0`000?lL0?ooo`030000003oool0oooo01X0oooo0`000?m90?oo
o`00?@3oool20000oaX0oooo00<000000?ooo`3oool0603oool20000od`0oooo000o0?ooo`@0003o
5P3oool00`000000oooo0?ooo`0D0?ooo`@0003oCP3oool004<0oooo0`000?lC0?ooo`030000003o
ool0oooo0100oooo10000?mB0?ooo`00AP3oool40000o`P0oooo100000030?ooo`030000003oool0
oooo00`0oooo10000?mF0?ooo`00BP3oool80000o`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool70000oeX0oooo001B0?ooo`l0003oH@3oool005@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1V0?ooo`00DP3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo06H0oooo001C0?ooo`800000103oool00`000000oooo0?ooo`1V0?ooo`00F@3oool0
0`000000oooo0?ooo`1V0?ooo`00F@3oool00`000000oooo0?ooo`1V0?ooo`00F@3oool00`000000
oooo0?ooo`1V0?ooo`00F@3oool00`000000oooo0?ooo`1V0?ooo`00F@3oool00`000000oooo0?oo
o`1V0?ooo`00`P3oool00<80oooo00320?ooo`00`P3oool00<80oooo00320?ooo`00E`3oool20000
06T0oooo001H0?ooo`030000003oool0oooo06L0oooo001I0?ooo`030000003oool0oooo06H0oooo
001H0?ooo`030000003oool0000006L0oooo001G0?ooo`040000003oool0oooo000006L0oooo001F
0?ooo`<0000000<0oooo000000000000IP3oool00<80oooo00320?ooo`00`P3oool00<80oooo0000
\
\>"],
    ImageRangeCache->{{{0, 193}, {193, 0}} -> {-1, 0, 0, 0}}],
  "  ",
  StyleBox["\n\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.27",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/cauchygoursat/CauchyGoursatMod/\
Images/mat0627.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z - \[ImaginaryI]\)\(|\)\) = 1\)]],
  "  and the points  ",
  Cell[BoxData[
      \(z = \(\[PlusMinus]\ \[ImaginaryI]\)\ \@2\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Solution.  Using partial fractions again, we have  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\(\( 2  z\)\/\(z\^2\  + \ 
                  2\)\) \[DifferentialD]z\ \  = \ \ \[Integral]\_C\( 
                  1\/\(z\  + \ \[ImaginaryI]\ \@2\)\) \[DifferentialD]z\ \  + \
\ \ \[Integral]\_C\( 
                  1\/\(z\  - \ \[ImaginaryI]\ \@2\)\) \[DifferentialD]z\)]],
  "\n\nIn this case,  ",
  Cell[BoxData[
      \(z = \[ImaginaryI]\ \@2\)]],
  "  lies interior to ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " but  ",
  Cell[BoxData[
      \(z = \(-\ \[ImaginaryI]\)\ \@2\)]],
  "  does not, as shown in Figure 6.27.  By Corollary 6.1, the second \
integral on the right side of the above equation has the value  ",
  Cell[BoxData[
      \(2\ \[Pi]\ \[ImaginaryI]\)]],
  ".  The first integral equals zero by the Cauchy-Goursat theorem because \
the function  ",
  Cell[BoxData[
      \(f \((z)\) = 1\/\(z\  + \ \[ImaginaryI]\ \@2\)\)]],
  " is analytic on a simply connected domain that contains ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".  Thus  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_C\(\( 2  z\)\/\(z\^2\  + \ 
                  2\)\) \[DifferentialD]z\ \  = \ \ \[Integral]\_C\( 
                  1\/\(z\  + \ \[ImaginaryI]\ \@2\)\) \[DifferentialD]z\ \  + \
\ \ \[Integral]\_C\( 
                  1\/\(z\  - \ \[ImaginaryI]\ \@2\)\) \[DifferentialD]z\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(0\ \  \
+ \ \ 2  \[Pi]\ \[ImaginaryI]\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(2  \[Pi]\
\ \[ImaginaryI]\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.15.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \(2  z\)\/\(z\^2\  + \ 2\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[R, W, z, Z];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, i, p, solset];\)\ \ \), "\n", 
    \(\(f[z_]\  = \ \(2  z\)\/\(z\^2\  + \ 2\);\)\ \ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "First, split the function up into partial fractions involving linear terms \
in the denominators.  Don't worry about the subroutine.  It splits  ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  "  up into partial fractions.  The result will be an equivalent function \
named F[z].  The list of terms added to form F[z] have singularities in the \
same order in the list of points Z."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, z]];\)\ \ \), "\n", 
    \(\(Z\  = \ Table[0, {Length[solset]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(W\  = \ Table[0, {Length[solset]}];\)\ \ \), "\n", 
    \(\(R\  = \ Table[0, {Length[solset]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(F[z_]\  = \ 0;\)\ \ \), "\n", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[solset], \(i++\), \[IndentingNewLine]Z\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          ReplaceAll[z, 
            solset\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
]; \ \ \ \[IndentingNewLine]If[1 \[Equal] i, 
          p\  = \ 1]; \ \ \[IndentingNewLine]If[
          1 < i; \ \ Z\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\) \[Equal] 
            Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\), 
          p\  = \ p + 1, 
          p\  = \ 1]; \ \ \[IndentingNewLine]R\_\(\(\[LeftDoubleBracket]\)\(i\
\)\(\[RightDoubleBracket]\)\)\  = \ 
          Residue[\(\((z - 
                      Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\))\)\^\(p - 1\)\) f[z], {z, 
              Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)}];\
 \ \ \[IndentingNewLine]W\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\) = \ 
          R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\/\((z \
- Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\))\)\^p; \ \ \n\
\ \ \ F[z_]\  = \ 
          F[z]\  + 
            R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\/\((\
z - Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\))\)\^p;\ \ \
];\)\ \ \), "\n", 
    \(\(For[i = 1, 
        i \[LessEqual] Length[F[z]], \(i++\), \n\ \ \ soset\  = \ 
          Solve[Denominator[
                W\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]\
 \[Equal] 0, 
            z]; \ \ \n\ \ \ Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\)\  = \ 
          ReplaceAll[z, 
            soset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]\
; \ \ \n\ \ \ R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  \
= \ Residue[
            f[z], {z, 
              Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)}];\
\ \ ];\)\ \ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \ \), "\n", 
    \(\(Print["\<f[z] = \>", F[z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Determine which singularities lie inside  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z - \[ImaginaryI]\)\(|\)\) = 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<,  \
Is |\>", Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\< - \
\[ImaginaryI]| < 1 ?   \>", 
        N[Abs[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\) - \
\ \[ImaginaryI]]] < 1];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\), "\<,   \
 Is |\>", 
        Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\), "\< - \
\[ImaginaryI]| < 1 ?   \>", 
        N[Abs[Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\) - \
\ \[ImaginaryI]]] < 1];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Since only the second singularity lies inside ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", add the first term in the sum forming F[z] times constant in the \
numerator that term times ",
  Cell[BoxData[
      \(2  \[Pi]\ \[ImaginaryI]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(val\  = \ 
        2  \[Pi]\ \[ImaginaryI]\ Numerator[\(F[z]\)\_\(\(\[LeftDoubleBracket]\
\)\(2\)\(\[RightDoubleBracket]\)\)];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], 
              Point[{Re[
                    Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\
\)\)], Im[
                    Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\
\)\)]}]}}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[
              StyleForm[TraditionalForm[\*"\"\<\!\(z\_2\)\>\""], 
                FontSize \[Rule] 12], {Re[
                  Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\
\)], Im[Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)] - 
                  0.1}, {\(-1\), 0}]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 1}, 1]}];\)\ \ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-1.1\), 1.1}, {\(-0.1\), 2.1}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = \>", \
\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        W\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<) \
\[DifferentialD]z + \>", \*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        W\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\), "\<) \
\[DifferentialD]z\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = \>", "\<(\>", 0, "\<) + \>", "\<(\>", 
        2  \[Pi]\ \[ImaginaryI]\ Numerator[\(F[z]\)\_\(\(\[LeftDoubleBracket]\
\)\(2\)\(\[RightDoubleBracket]\)\)], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
      f[z], "\<) \[DifferentialD]z = \>", val]\), "\[IndentingNewLine]", 
    \(\(Print["\<The contour is the circle  C: |z-\[ImaginaryI]| = 1,\>"];\)\ \
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<with positive orientation.\>"];\)\ \ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.16.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Integral]\_C\(\( z\  - \ 2\)\/\(z\^2\  - \ 
                  z\)\) \[DifferentialD]z\  = \ \(-6\)\ \[Pi]\ \
\[ImaginaryI]\)]],
  ",  where ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is the \"figure eight\" contour shown in Figure 6.28. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.272727 0.454545 0.309017 0.309017 [
[.72727 .29652 -3 -9 ]
[.72727 .29652 3 0 ]
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 10 6.28125 ]
[.26023 0 -12 -4.5 ]
[.26023 0 0 4.5 ]
[.26023 .61803 -6 -4.5 ]
[.26023 .61803 0 4.5 ]
[.27273 .64303 -5 0 ]
[.27273 .64303 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.72727 .30902 m
.72727 .31527 L
s
[(1)] .72727 .29652 0 1 Mshowa
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.27273 0 m
.27898 0 L
s
[(-1)] .26023 0 1 0 Mshowa
.27273 .61803 m
.27898 .61803 L
s
[(1)] .26023 .61803 1 0 Mshowa
.27273 0 m
.27273 .61803 L
s
gsave
.27273 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.03 w
.27273 .30902 Mdot
0 1 1 r
.72727 .30902 Mdot
0 g
gsave
.30455 .37082 -69.4063 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75909 .37082 -69.4063 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.38636 .55623 -69.4063 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.61364 .55623 -69.4063 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.5 .30902 m
.55777 .2311 L
.61968 .15203 L
.67574 .08865 L
.72684 .04174 L
.75178 .02399 L
.7773 .01027 L
.78928 .00563 L
.79545 .00373 L
.8019 .00215 L
.80745 .00112 L
.81057 .00068 L
.81346 .00037 L
.81481 .00026 L
.81609 .00017 L
.81724 .0001 L
.81848 5e-005 L
.81982 2e-005 L
.82057 0 L
.82125 0 L
.82256 1e-005 L
.8238 3e-005 L
.82502 8e-005 L
.82632 .00015 L
.82754 .00023 L
.82866 .00032 L
.83136 .00061 L
.8339 .00097 L
.83888 .00193 L
.8442 .00335 L
.85342 .00683 L
.86164 .01113 L
.8702 .01695 L
.8779 .02348 L
.89418 .04213 L
.90836 .06517 L
.91978 .0901 L
.92984 .11896 L
.93892 .1539 L
.94564 .18968 L
.94859 .21062 L
.95076 .23009 L
.95244 .24992 L
.95356 .26844 L
.95398 .27818 L
.95417 .28379 L
.9543 .28893 L
.95442 .29435 L
.95446 .29734 L
.9545 .30018 L
Mistroke
.95452 .30279 L
.95454 .30522 L
.95454 .30788 L
.95455 .30937 L
.95454 .31072 L
.95454 .31318 L
.95452 .31547 L
.9545 .31799 L
.95446 .32068 L
.95437 .32618 L
.95425 .33119 L
.95394 .34082 L
.95354 .34991 L
.95231 .36999 L
.95139 .38121 L
.9504 .39149 L
.94577 .42752 L
.94238 .44724 L
.9387 .46512 L
.9298 .49921 L
.91997 .52747 L
.90828 .55303 L
.89368 .57659 L
.87814 .59433 L
.86875 .60218 L
.8598 .60797 L
.8553 .61032 L
.85044 .61248 L
.84616 .61406 L
.84148 .61546 L
.83881 .61612 L
.83636 .61663 L
.83384 .61707 L
.83148 .61741 L
.82872 .61771 L
.82726 .61783 L
.82569 .61792 L
.82433 .61798 L
.82304 .61802 L
.82231 .61803 L
.82163 .61803 L
.82088 .61803 L
.8201 .61802 L
.81878 .61799 L
.81804 .61797 L
.81735 .61794 L
.81609 .61787 L
.81474 .61777 L
.81239 .61756 L
.8098 .61725 L
Mistroke
.80398 .61631 L
.79844 .61509 L
.78831 .61208 L
.77715 .6077 L
.75136 .59377 L
.72572 .57541 L
.67433 .52792 L
.61662 .46227 L
.55907 .38865 L
.5 .30902 L
Mfstroke
1 0 1 r
.5 .30902 m
.44223 .2311 L
.38032 .15203 L
.32426 .08865 L
.27316 .04174 L
.24822 .02399 L
.2227 .01027 L
.21072 .00563 L
.20455 .00373 L
.1981 .00215 L
.19255 .00112 L
.18943 .00068 L
.18654 .00037 L
.18519 .00026 L
.18391 .00017 L
.18276 .0001 L
.18152 5e-005 L
.18018 2e-005 L
.17943 0 L
.17875 0 L
.17744 1e-005 L
.1762 3e-005 L
.17498 8e-005 L
.17368 .00015 L
.17246 .00023 L
.17134 .00032 L
.16864 .00061 L
.1661 .00097 L
.16112 .00193 L
.1558 .00335 L
.14658 .00683 L
.13836 .01113 L
.1298 .01695 L
.1221 .02348 L
.10582 .04213 L
.09164 .06517 L
.08022 .0901 L
.07016 .11896 L
.06108 .1539 L
.05436 .18968 L
.05141 .21062 L
.04924 .23009 L
.04756 .24992 L
.04644 .26844 L
.04602 .27818 L
.04583 .28379 L
.0457 .28893 L
.04558 .29435 L
.04554 .29734 L
.0455 .30018 L
Mistroke
.04548 .30279 L
.04546 .30522 L
.04546 .30788 L
.04545 .30937 L
.04546 .31072 L
.04546 .31318 L
.04548 .31547 L
.0455 .31799 L
.04554 .32068 L
.04563 .32618 L
.04575 .33119 L
.04606 .34082 L
.04646 .34991 L
.04769 .36999 L
.04861 .38121 L
.0496 .39149 L
.05423 .42752 L
.05762 .44724 L
.0613 .46512 L
.0702 .49921 L
.08003 .52747 L
.09172 .55303 L
.10632 .57659 L
.12186 .59433 L
.13125 .60218 L
.1402 .60797 L
.1447 .61032 L
.14956 .61248 L
.15384 .61406 L
.15852 .61546 L
.16119 .61612 L
.16364 .61663 L
.16616 .61707 L
.16852 .61741 L
.17128 .61771 L
.17274 .61783 L
.17431 .61792 L
.17567 .61798 L
.17696 .61802 L
.17769 .61803 L
.17837 .61803 L
.17912 .61803 L
.1799 .61802 L
.18122 .61799 L
.18196 .61797 L
.18265 .61794 L
.18391 .61787 L
.18526 .61777 L
.18761 .61756 L
.1902 .61725 L
Mistroke
.19602 .61631 L
.20156 .61509 L
.21169 .61208 L
.22285 .6077 L
.24864 .59377 L
.27428 .57541 L
.32567 .52792 L
.38338 .46227 L
.44093 .38865 L
.5 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00AP3oool500000=D0oooo00180?ooo`030000003oool0oooo0=D0oooo
000d0?ooo`L0o`3o3@3oool00`000000oooo0?ooo`030?ooo`<00000PP3oool80000odD0oooo000a
0?ooo`<0o`3o1`3oool50?l0o`@00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo07h0oooo10000?l80?ooo`<0003o@P3oool002l0oooo0P3o0?l?0?ooo`80o`3o1P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo07`0oooo0P000?l?0?ooo`80003o@03oool002d0
oooo0P3o0?lC0?ooo`030?l0o`3oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo07X0
oooo0P000?lC0?ooo`80003o?P3oool002/0oooo0P3o0?lF0?ooo`80o`3o2@3oool00`000000oooo
0?ooo`1h0?ooo`80003o5`3oool20000oc`0oooo000Z0?ooo`030?l0o`3oool0oooo01P0oooo0P3o
0?l70?ooo`030000003oool0oooo07H0oooo0P000?lK0?ooo`030000o`3oool0oooo03T0oooo000Y
0?ooo`030?l0o`3oool0oooo01/0oooo0P3o0?l50?ooo`030000003oool0oooo07@0oooo0P000?lN
0?ooo`030000o`3oool0oooo03P0oooo000X0?ooo`030?l0o`3oool0oooo01h0oooo0P3o0?l30?oo
o`030000003oool0oooo0780oooo0P000?lQ0?ooo`030000o`3oool0oooo03L0oooo000W0?ooo`03
0?l0o`3oool0oooo0240oooo00@0o`3o0?ooo`3oool00000L`3oool00`000?l0oooo0?ooo`0R0?oo
o`030000o`3oool0oooo03H0oooo000W0?ooo`030?l0o`3oool0oooo0280oooo0P3o0?l00`000000
oooo0?ooo`1_0?ooo`80003o9@3oool00`000?l0oooo0?ooo`0f0?ooo`009P3oool00`3o0?l0oooo
0?ooo`0U0?ooo`030?l0o`3oool0oooo06h0oooo00<0003o0?ooo`3oool09P3oool00`000?l0oooo
0?ooo`0e0?ooo`009@3oool00`3o0?l0oooo0?ooo`0V0?ooo`030000003o0?l0oooo06d0oooo00<0
003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0d0?ooo`00903oool00`3o0?l0oooo0?ooo`0W
0?ooo`030000003oool0o`3o06`0oooo00<0003o0?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0c
0?ooo`008`3oool00`3o0?l0oooo0?ooo`0X0?ooo`040000003oool0oooo0?l0ofX0oooo00<0003o
0?ooo`3oool0:`3oool00`000?l0oooo0?ooo`0c0?ooo`008`3oool00`3o0?l0oooo0?ooo`0X0?oo
o`050000003oool0oooo0?ooo`3o0?l0J03oool00`000?l0oooo0?ooo`0]0?ooo`030000o`3oool0
oooo0380oooo000R0?ooo`030?l0o`3oool0oooo02T0oooo00<000000?ooo`3oool00P3oool00`3o
0?l0oooo0?ooo`1T0?ooo`030000o`3oool0oooo02h0oooo00<0003o0?ooo`3oool0<P3oool00240
oooo00<0o`3o0?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`80o`3oH`3oool00`000?l0
oooo0?ooo`0`0?ooo`030000o`3oool0oooo0340oooo000Q0?ooo`030?l0o`3oool0oooo02X0oooo
00<000000?ooo`3oool01@3oool00`3o0?l0oooo0?ooo`1O0?ooo`030000o`3oool0oooo0340oooo
00<0003o0?ooo`3oool0<@3oool00200oooo00<0o`3o0?ooo`3oool0:`3oool00`000000oooo0?oo
o`060?ooo`030?l0o`3oool0oooo05d0oooo00<0003o0?ooo`3oool0<`3oool00`000?l0oooo0?oo
o`0`0?ooo`00803oool00`3o0?l0oooo0?ooo`0[0?ooo`030000003oool0oooo00L0oooo00<0o`3o
0?ooo`3oool0F`3oool00`000?l0oooo0?ooo`0d0?ooo`030000o`3oool0oooo0300oooo000P0?oo
o`030?l0o`3oool0oooo02/0oooo00<000000?ooo`3oool0203oool00`3o0?l0oooo0?ooo`1I0?oo
o`030000o`3oool0oooo03H0oooo00<0003o0?ooo`3oool0;`3oool001l0oooo00<0o`3o0?ooo`3o
ool0;03oool00`000000oooo0?ooo`090?ooo`030?l0o`3oool0oooo05L0oooo00<0003o0?ooo`3o
ool0=`3oool00`000?l0oooo0?ooo`0_0?ooo`007`3oool00`3o0?l0oooo0?ooo`0/0?ooo`030000
003oool0oooo00X0oooo00<0o`3o0?ooo`3oool0E@3oool00`000?l0oooo0?ooo`0i0?ooo`030000
o`3oool0oooo02h0oooo000O0?ooo`030?l0o`3oool0oooo02`0oooo00<000000?ooo`3oool02`3o
ool00`3o0?l0oooo0?ooo`1C0?ooo`030000o`3oool0oooo03X0oooo00<0003o0?ooo`3oool0;P3o
ool001h0oooo00<0o`3o0?ooo`3oool0;@3oool00`000000oooo0?ooo`0<0?ooo`030?l0o`3oool0
oooo0540oooo00<0003o0?ooo`3oool0?03oool00`000?l0oooo0?ooo`0]0?ooo`007P3oool00`3o
0?l0oooo0?ooo`0]0?ooo`030000003oool0oooo00d0oooo00<0o`3o0?ooo`3oool0C`3oool00`00
0?l0oooo0?ooo`0m0?ooo`030000o`3oool0oooo02d0oooo000M0?ooo`030?l0o`3oool0oooo02h0
oooo00<000000?ooo`3oool03@3oool00`3o0?l0oooo0?ooo`1>0?ooo`030000o`3oool0oooo03h0
oooo00<0003o0?ooo`3oool0;@3oool001d0oooo00<0o`3o0?ooo`3oool0;P3oool00`000000oooo
0?ooo`0>0?ooo`030?l0o`3oool0oooo04d0oooo00<0003o0?ooo`3oool0?`3oool00`000?l0oooo
0?ooo`0/0?ooo`007@3oool00`3o0?l0oooo0?ooo`0^0?ooo`030000003oool0oooo00l0oooo00<0
o`3o0?ooo`3oool0B`3oool00`000?l0oooo0?ooo`100?ooo`030000o`3oool0oooo02`0oooo000L
0?ooo`030?l0o`3oool0oooo02l0oooo00<000000?ooo`3oool0403oool00`3o0?l0oooo0?ooo`19
0?ooo`030000o`3oool0oooo0480oooo00<0003o0?ooo`3oool0:`3oool001`0oooo00<0o`3o0?oo
o`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`030?l0o`3oool0oooo04L0oooo00<0003o0?oo
o`3oool0@`3oool00`000?l0oooo0?ooo`0[0?ooo`00703oool00`3o0?l0oooo0?ooo`0_0?ooo`03
0000003oool0oooo0180oooo00<0o`3o0?ooo`3oool0A@3oool00`000?l0oooo0?ooo`140?ooo`03
0000o`3oool0oooo02/0oooo000K0?ooo`030?l0o`3oool0oooo0300oooo00<000000?ooo`3oool0
4`3oool00`3o0?l0oooo0?ooo`130?ooo`030000o`3oool0oooo04D0oooo00<0003o0?ooo`3oool0
:`3oool001/0oooo00<0o`3o0?ooo`3oool0<03oool00`000000oooo0?ooo`0D0?ooo`030?l0o`3o
ool0oooo0440oooo00<0003o0?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0Z0?ooo`006`3oool0
0`3o0?l0oooo0?ooo`0`0?ooo`030000003oool0oooo01@0oooo00<0o`3o0?ooo`3oool0@03oool0
0`000?l0oooo0?ooo`180?ooo`030000o`3oool0oooo02X0oooo000K0?ooo`030?l0o`3oool0oooo
0300oooo00<000000?ooo`3oool05@3oool00`3o0?l0oooo0?ooo`0o0?ooo`030000o`3oool0oooo
04P0oooo00<0003o0?ooo`3oool0:P3oool001X0oooo00<0o`3o0?ooo`3oool0<@3oool00`000000
oooo0?ooo`0F0?ooo`030?l0o`3oool0oooo03d0oooo00<0003o0?ooo`3oool0B@3oool00`000?l0
oooo0?ooo`0Z0?ooo`006P3oool00`3o0?l0oooo0?ooo`0a0?ooo`030000003oool0oooo01L0oooo
00<0o`3o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`1;0?ooo`030000o`3oool0oooo02T0oooo
000J0?ooo`030?l0o`3oool0oooo0340oooo00<000000?ooo`3oool0603oool00`3o0?l0oooo0?oo
o`0i0?ooo`030000o`3oool0oooo04`0oooo00<0003o0?ooo`3oool0:@3oool001X0oooo00<0o`3o
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0I0?ooo`030?l0o`3oool0oooo03L0oooo00<0003o
0?ooo`3oool0C@3oool00`000?l0oooo0?ooo`0Y0?ooo`006P3oool00`3o0?l0oooo0?ooo`0a0?oo
o`030000003oool0oooo01X0oooo00<0o`3o0?ooo`3oool0=@3oool00`000?l0oooo0?ooo`1>0?oo
o`030000o`3oool0oooo02T0oooo000I0?ooo`030?l0o`3oool0oooo0380oooo00<000000?ooo`3o
ool06P3oool00`3o0?l0oooo0?ooo`0e0?ooo`030000o`3oool0oooo04l0oooo00<0003o0?ooo`3o
ool0:03oool001T0oooo00<0o`3o0?ooo`3oool0<P3oool00`000000oooo0?ooo`0K0?ooo`030?l0
o`3oool0oooo03<0oooo00<0003o0?ooo`3oool0D03oool00`000?l0oooo0?ooo`0X0?ooo`006@3o
ool00`3o0?l0oooo0?ooo`0b0?ooo`030000003oool0oooo01`0oooo00<0o`3o0?ooo`3oool0<@3o
ool00`000?l0oooo0?ooo`1A0?ooo`030000o`3oool0oooo02P0oooo000I0?ooo`030?l0o`3oool0
oooo0380oooo00<000000?ooo`3oool07@3oool00`3o0?l0oooo0?ooo`0_0?ooo`030000o`3oool0
oooo0580oooo00<0003o0?ooo`3oool0:03oool001P0oooo00<0o`3o0?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0N0?ooo`030?l0o`3oool0oooo02d0oooo00<0003o0?ooo`3oool0E03oool00`00
0?l0oooo0?ooo`0W0?ooo`00603oool00`3o0?l0oooo0?ooo`0c0?ooo`030000003oool0oooo01h0
oooo00<0o`3o0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`1D0?ooo`030000o`3oool0oooo02L0
oooo000H0?ooo`030?l0o`3oool0oooo03<0oooo00<000000?ooo`3oool07`3oool00`3o0?l0oooo
0?ooo`0[0?ooo`030000o`3oool0oooo05D0oooo00<0003o0?ooo`3oool09`3oool001P0oooo00<0
o`3o0?ooo`3oool0<`3oool00`000000oooo0?ooo`0P0?ooo`030?l0o`3oool0oooo02T0oooo00<0
003o0?ooo`3oool0EP3oool00`000?l0oooo0?ooo`0W0?ooo`00603oool00`3o0?l0oooo0?ooo`0c
0?ooo`030000003oool0oooo0240oooo00<0o`3o0?ooo`3oool09`3oool00`000?l0oooo0?ooo`1G
0?ooo`030000o`3oool0oooo02L0oooo000G0?ooo`030?l0o`3oool0oooo03@0oooo00<000000?oo
o`3oool08P3oool00`3o0?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo05P0oooo00<0003o0?oo
o`3oool09`3oool001L0oooo00<0o`3o0?ooo`3oool0=03oool00`000000oooo0?ooo`0R0?ooo`03
0?l0o`3oool0oooo02D0oooo00<0003o0?ooo`3oool0F03oool00`000?l0oooo0?ooo`0W0?ooo`00
5`3oool00`3o0?l0oooo0?ooo`0d0?ooo`030000003oool0oooo02<0oooo00<0o`3o0?ooo`3oool0
8`3oool00`000?l0oooo0?ooo`1I0?ooo`030000o`3oool0oooo02L0oooo000G0?ooo`030?l0o`3o
ool0oooo03@0oooo00<000000?ooo`3oool0903oool00`3o0?l0oooo0?ooo`0Q0?ooo`030000o`3o
ool0oooo05X0oooo00<0003o0?ooo`3oool09`3oool001L0oooo00<0o`3o0?ooo`3oool0=03oool0
0`000000oooo0?ooo`0U0?ooo`030?l0o`3oool0oooo01l0oooo00<0003o0?ooo`3oool0F`3oool0
0`000?l0oooo0?ooo`0W0?ooo`005`3oool00`3o0?l0oooo0?ooo`0d0?ooo`030000003oool0oooo
02H0oooo00<0o`3o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`1M0?ooo`030000o`3oool0oooo
02H0oooo000G0?ooo`030?l0o`3oool0oooo03@0oooo00<000000?ooo`3oool09P3oool00`3o0?l0
oooo0?ooo`0M0?ooo`030000o`3oool0oooo05d0oooo00<0003o0?ooo`3oool09P3oool001L0oooo
00<0o`3o0?ooo`3oool0=03oool00`000000oooo0?ooo`0W0?ooo`030?l0o`3oool0oooo01/0oooo
00<0003o0?ooo`3oool0GP3oool00`000?l0oooo0?ooo`0V0?ooo`005`3oool00`3o0?l0oooo0?oo
o`0d0?ooo`030000003oool0oooo02P0oooo00<0o`3o0?ooo`3oool06@3oool00`000?l0oooo0?oo
o`1O0?ooo`030000o`3oool0oooo02H0oooo000G0?ooo`030?l0o`3oool0oooo03@0oooo00<00000
0?ooo`3oool0:@3oool00`3o0?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo0600oooo00<0003o
0?ooo`3oool09P3oool001H0oooo00<0o`3o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0Y0?oo
o`030?l0o`3oool0oooo01L0oooo00<0003o0?ooo`3oool0H03oool00`000?l0oooo0?ooo`0V0?oo
o`005P3oool00`3o0?l0oooo0?ooo`0e0?ooo`030000003oool0oooo02X0oooo00<0o`3o0?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`1Q0?ooo`030000o`3oool0oooo02H0oooo000F0?ooo`030?l0
o`3oool0oooo03D0oooo00<000000?ooo`3oool0:`3oool00`3o0?l0oooo0?ooo`0C0?ooo`030000
o`3oool0oooo0680oooo00<0003o0?ooo`3oool09P3oool001H0oooo00<0o`3o0?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0/0?ooo`030?l0o`3oool0oooo0140oooo00<0003o0?ooo`3oool0H`3o
ool00`000?l0oooo0?ooo`0V0?ooo`005P3oool00`3o0?l0oooo0?ooo`0e0?ooo`030000003oool0
oooo02`0oooo00<0o`3o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`1S0?ooo`030000o`3oool0
oooo02H0oooo000F0?ooo`030?l0o`3oool0oooo03D0oooo00<000000?ooo`3oool0;@3oool00`3o
0?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo06D0oooo00<0003o0?ooo`3oool09@3oool001H0
oooo00<0o`3o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0^0?ooo`030?l0o`3oool0oooo00d0
oooo00<0003o0?ooo`3oool0:`3oool5000003H0oooo00<0003o0?ooo`3oool09@3oool001H0oooo
00<0o`3o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0_0?ooo`030?l0o`3oool0oooo00/0oooo
00<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0f0?ooo`030000o`3oool0oooo02D0oooo
000F0?ooo`030?l0o`3oool0oooo03D0oooo00<000000?ooo`3oool0;`3oool00`3o0?l0oooo0?oo
o`0;0?ooo`030000o`3oool0oooo02h0oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo0?oo
o`0U0?ooo`005P3oool00`3o0?l0oooo0?ooo`0e0?ooo`030000003oool0oooo0300oooo00<0o`3o
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo03H0oooo00<0003o
0?ooo`3oool09@3oool001H0oooo00<0o`3o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0a0?oo
o`030?l0o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0<03oool00`000000oooo0?ooo`0f0?oo
o`030000o`3oool0oooo02D0oooo000F0?ooo`030?l0o`3oool0oooo03D0oooo00<000000?ooo`3o
ool0<P3oool00`3o0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0300oooo0P00000h0?ooo`03
0000o`3oool0oooo02D0oooo000F0?ooo`030?l0o`3oool0oooo03D0oooo00<000000?ooo`3oool0
<P3oool00`3o0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo06X0oooo00<0003o0?ooo`3oool0
9@3oool001H0oooo00<0o`3o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0c0?ooo`030?l0o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0J`3oool00`000?l0oooo0?ooo`0U0?ooo`005P3oool0
0`3o0?l0oooo0?ooo`0d0?ooo`<0o`00=@3oool01@3o0?l0oooo0?ooo`3oool0003o03@0oooo0`00
oolg0?ooo`030000o`3oool0oooo02D0oooo000F0?ooo`030?l0o`3oool0oooo03<0oooo1@3o000e
0?ooo`030?l0o`3oool0003o03@0oooo1@00oolf0?ooo`030000o`3oool0oooo0100oooo0P000000
0`3oool000000000000@0?ooo`005P3oool00`3o0?l0oooo0?ooo`0b0?ooo`L0o`00=03oool00`3o
0?l0oooo0000o`0c0?ooo`L00?oo=@3oool00`000?l0oooo0?ooo`0A0?ooo`030000003oool00000
0140oooo000;0?ooo`/0000000<0o`3o000000000000<P0000070?l003D0000000<0o`3o00000000
0000<P000007003oocD0000000<0003o0000000000002@0000090?ooo`030000003oool0oooo0100
oooo000F0?ooo`030?l0o`3oool0oooo0380oooo1`3o000d0?ooo`030?l0o`3oool0003o03<0oooo
1`00oole0?ooo`030000o`3oool0oooo0100oooo0P0000000`3oool000000000000@0?ooo`005P3o
ool00`3o0?l0oooo0?ooo`0c0?ooo`D0o`00=03oool0103o0?l0oooo0?ooo`000?ld0?ooo`D00?oo
=P3oool00`000?l0oooo0?ooo`0U0?ooo`005P3oool00`3o0?l0oooo0?ooo`0d0?ooo`<0o`00=@3o
ool01@3o0?l0oooo0?ooo`3oool0003o03@0oooo0`00oolg0?ooo`030000o`3oool0oooo02D0oooo
000F0?ooo`030?l0o`3oool0oooo03D0oooo00<000000?ooo`3oool0<`3oool00`3o0?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo06/0oooo00<0003o0?ooo`3oool09@3oool001H0oooo00<0o`3o
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0b0?ooo`030?l0o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool0JP3oool00`000?l0oooo0?ooo`0U0?ooo`005P3oool00`3o0?l0oooo0?ooo`0e0?oo
o`030000003oool0oooo00H0oooo1@00000V0?ooo`030?l0o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool0>`3oool3000002`0oooo00<0003o0?ooo`3oool09@3oool001H0oooo00<0o`3o0?ooo`3o
ool0=@3oool00`000000oooo0?ooo`05000000<0oooo00<000000?ooo`3oool09P3oool00`3o0?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo03<0oooo1@0000020?ooo`030000003oool0oooo02`0
oooo00<0003o0?ooo`3oool09@3oool001H0oooo00<0o`3o0?ooo`3oool0=@3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000W0?ooo`030?l0o`3oool0oooo
00T0oooo00<0003o0?ooo`3oool0<`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo02/0oooo00<0003o0?ooo`3oool09@3oool001H0oooo00<0o`3o0?ooo`3oool0=@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`3o
0?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo02D0oooo000F0?ooo`030?l0o`3oool0oooo03D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02<0
oooo00<0o`3o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0d0?ooo`070000003oool0oooo0?oo
o`000000oooo0000000/0?ooo`030000o`3oool0oooo02D0oooo000F0?ooo`030?l0o`3oool0oooo
03D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo008000009@3oool0
0`3o0?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo0340oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo02D0oooo000F0?ooo`030?l0o`3oool0
oooo03D0oooo00@000000?ooo`3oool0oooo1@00000W0?ooo`030?l0o`3oool0oooo00l0oooo00<0
003o0?ooo`3oool0<03oool500000300oooo00<0003o0?ooo`3oool09@3oool001H0oooo00<0o`3o
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0/0?ooo`030?l0o`3oool0oooo0140oooo00<0003o
0?ooo`3oool0H`3oool00`000?l0oooo0?ooo`0V0?ooo`005P3oool00`3o0?l0oooo0?ooo`0e0?oo
o`030000003oool0oooo02/0oooo00<0o`3o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`1S0?oo
o`030000o`3oool0oooo02H0oooo000F0?ooo`030?l0o`3oool0oooo03D0oooo00<000000?ooo`3o
ool0:`3oool00`3o0?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo0680oooo00<0003o0?ooo`3o
ool09P3oool001H0oooo00<0o`3o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0Z0?ooo`030?l0
o`3oool0oooo01D0oooo00<0003o0?ooo`3oool0H@3oool00`000?l0oooo0?ooo`0V0?ooo`005`3o
ool00`3o0?l0oooo0?ooo`0d0?ooo`030000003oool0oooo02T0oooo00<0o`3o0?ooo`3oool05`3o
ool00`000?l0oooo0?ooo`1P0?ooo`030000o`3oool0oooo02H0oooo000G0?ooo`030?l0o`3oool0
oooo03@0oooo00<000000?ooo`3oool0:03oool00`3o0?l0oooo0?ooo`0H0?ooo`030000o`3oool0
oooo0600oooo00<0003o0?ooo`3oool09P3oool001L0oooo00<0o`3o0?ooo`3oool0=03oool00`00
0000oooo0?ooo`0X0?ooo`030?l0o`3oool0oooo01T0oooo00<0003o0?ooo`3oool0G`3oool00`00
0?l0oooo0?ooo`0V0?ooo`005`3oool00`3o0?l0oooo0?ooo`0d0?ooo`030000003oool0oooo02L0
oooo00<0o`3o0?ooo`3oool06`3oool00`000?l0oooo0?ooo`1N0?ooo`030000o`3oool0oooo02H0
oooo000G0?ooo`030?l0o`3oool0oooo03@0oooo00<000000?ooo`3oool09P3oool00`3o0?l0oooo
0?ooo`0M0?ooo`030000o`3oool0oooo05d0oooo00<0003o0?ooo`3oool09P3oool001L0oooo00<0
o`3o0?ooo`3oool0=03oool00`000000oooo0?ooo`0U0?ooo`030?l0o`3oool0oooo01l0oooo00<0
003o0?ooo`3oool0G03oool00`000?l0oooo0?ooo`0V0?ooo`005`3oool00`3o0?l0oooo0?ooo`0d
0?ooo`030000003oool0oooo02D0oooo00<0o`3o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`1L
0?ooo`030000o`3oool0oooo02H0oooo000G0?ooo`030?l0o`3oool0oooo03@0oooo00<000000?oo
o`3oool0903oool00`3o0?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo05/0oooo00<0003o0?oo
o`3oool09P3oool001P0oooo00<0o`3o0?ooo`3oool0<`3oool00`000000oooo0?ooo`0S0?ooo`03
0?l0o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0F@3oool00`000?l0oooo0?ooo`0W0?ooo`00
603oool00`3o0?l0oooo0?ooo`0c0?ooo`030000003oool0oooo0280oooo00<0o`3o0?ooo`3oool0
9@3oool00`000?l0oooo0?ooo`1H0?ooo`030000o`3oool0oooo02L0oooo000H0?ooo`030?l0o`3o
ool0oooo03<0oooo00<000000?ooo`3oool08P3oool00`3o0?l0oooo0?ooo`0U0?ooo`030000o`3o
ool0oooo05P0oooo00<0003o0?ooo`3oool09`3oool001P0oooo00<0o`3o0?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0Q0?ooo`030?l0o`3oool0oooo02L0oooo00<0003o0?ooo`3oool0E`3oool0
0`000?l0oooo0?ooo`0W0?ooo`00603oool00`3o0?l0oooo0?ooo`0c0?ooo`030000003oool0oooo
0200oooo00<0o`3o0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`1F0?ooo`030000o`3oool0oooo
02L0oooo000H0?ooo`030?l0o`3oool0oooo03<0oooo00<000000?ooo`3oool07`3oool00`3o0?l0
oooo0?ooo`0[0?ooo`030000o`3oool0oooo05D0oooo00<0003o0?ooo`3oool09`3oool001P0oooo
00<0o`3o0?ooo`3oool0<`3oool00`000000oooo0?ooo`0N0?ooo`030?l0o`3oool0oooo02d0oooo
00<0003o0?ooo`3oool0E03oool00`000?l0oooo0?ooo`0W0?ooo`006@3oool00`3o0?l0oooo0?oo
o`0b0?ooo`030000003oool0oooo01h0oooo00<0o`3o0?ooo`3oool0;@3oool00`000?l0oooo0?oo
o`1C0?ooo`030000o`3oool0oooo02P0oooo000I0?ooo`030?l0o`3oool0oooo0380oooo00<00000
0?ooo`3oool07@3oool00`3o0?l0oooo0?ooo`0_0?ooo`030000o`3oool0oooo0580oooo00<0003o
0?ooo`3oool0:03oool001T0oooo00<0o`3o0?ooo`3oool0<P3oool00`000000oooo0?ooo`0L0?oo
o`030?l0o`3oool0oooo0340oooo00<0003o0?ooo`3oool0D@3oool00`000?l0oooo0?ooo`0X0?oo
o`006@3oool00`3o0?l0oooo0?ooo`0b0?ooo`030000003oool0oooo01/0oooo00<0o`3o0?ooo`3o
ool0<`3oool00`000?l0oooo0?ooo`1@0?ooo`030000o`3oool0oooo02P0oooo000I0?ooo`030?l0
o`3oool0oooo0380oooo00<000000?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`0c0?ooo`030000
o`3oool0oooo0500oooo00<0003o0?ooo`3oool0:03oool001X0oooo00<0o`3o0?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0J0?ooo`030?l0o`3oool0oooo03D0oooo00<0003o0?ooo`3oool0CP3o
ool00`000?l0oooo0?ooo`0Y0?ooo`006P3oool00`3o0?l0oooo0?ooo`0a0?ooo`030000003oool0
oooo01T0oooo00<0o`3o0?ooo`3oool0=`3oool00`000?l0oooo0?ooo`1=0?ooo`030000o`3oool0
oooo02T0oooo000J0?ooo`030?l0o`3oool0oooo0340oooo00<000000?ooo`3oool0603oool00`3o
0?l0oooo0?ooo`0i0?ooo`030000o`3oool0oooo04`0oooo00<0003o0?ooo`3oool0:@3oool001X0
oooo00<0o`3o0?ooo`3oool0<@3oool00`000000oooo0?ooo`0G0?ooo`030?l0o`3oool0oooo03/0
oooo00<0003o0?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0Y0?ooo`006P3oool00`3o0?l0oooo
0?ooo`0a0?ooo`030000003oool0oooo01H0oooo00<0o`3o0?ooo`3oool0?@3oool00`000?l0oooo
0?ooo`190?ooo`030000o`3oool0oooo02X0oooo000K0?ooo`030?l0o`3oool0oooo0300oooo00<0
00000?ooo`3oool05@3oool00`3o0?l0oooo0?ooo`0n0?ooo`030000o`3oool0oooo04T0oooo00<0
003o0?ooo`3oool0:P3oool001/0oooo00<0o`3o0?ooo`3oool0<03oool00`000000oooo0?ooo`0E
0?ooo`030?l0o`3oool0oooo03l0oooo00<0003o0?ooo`3oool0B03oool00`000?l0oooo0?ooo`0Z
0?ooo`006`3oool00`3o0?l0oooo0?ooo`0`0?ooo`030000003oool0oooo01@0oooo00<0o`3o0?oo
o`3oool0@@3oool00`000?l0oooo0?ooo`170?ooo`030000o`3oool0oooo02X0oooo000K0?ooo`03
0?l0o`3oool0oooo0300oooo00<000000?ooo`3oool04`3oool00`3o0?l0oooo0?ooo`130?ooo`03
0000o`3oool0oooo04D0oooo00<0003o0?ooo`3oool0:`3oool001`0oooo00<0o`3o0?ooo`3oool0
;`3oool00`000000oooo0?ooo`0B0?ooo`030?l0o`3oool0oooo04D0oooo00<0003o0?ooo`3oool0
A03oool00`000?l0oooo0?ooo`0[0?ooo`00703oool00`3o0?l0oooo0?ooo`0_0?ooo`030000003o
ool0oooo0140oooo00<0o`3o0?ooo`3oool0A`3oool00`000?l0oooo0?ooo`130?ooo`030000o`3o
ool0oooo02/0oooo000L0?ooo`030?l0o`3oool0oooo02l0oooo00<000000?ooo`3oool0403oool0
0`3o0?l0oooo0?ooo`190?ooo`030000o`3oool0oooo0480oooo00<0003o0?ooo`3oool0:`3oool0
01d0oooo00<0o`3o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0?0?ooo`030?l0o`3oool0oooo
04/0oooo00<0003o0?ooo`3oool0@03oool00`000?l0oooo0?ooo`0/0?ooo`007@3oool00`3o0?l0
oooo0?ooo`0^0?ooo`030000003oool0oooo00h0oooo00<0o`3o0?ooo`3oool0C03oool00`000?l0
oooo0?ooo`100?ooo`030000o`3oool0oooo02`0oooo000M0?ooo`030?l0o`3oool0oooo02h0oooo
00<000000?ooo`3oool03P3oool00`3o0?l0oooo0?ooo`1=0?ooo`030000o`3oool0oooo03h0oooo
00<0003o0?ooo`3oool0;@3oool001d0oooo00<0o`3o0?ooo`3oool0;P3oool00`000000oooo0?oo
o`0=0?ooo`030?l0o`3oool0oooo00X0oooo1@00000e0?ooo`<00000203oool00`000?l0oooo0?oo
o`0m0?ooo`030000o`3oool0oooo02d0oooo000N0?ooo`030?l0o`3oool0oooo02d0oooo00<00000
0?ooo`3oool0303oool00`3o0?l0oooo0?ooo`0=0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3oool0oooo02h0oooo000N0?oo
o`030?l0o`3oool0oooo02d0oooo00<000000?ooo`3oool02`3oool00`3o0?l0oooo0?ooo`070?oo
o`<00000103oool00`000000oooo0?ooo`0_0?ooo`<00000103oool00`000000oooo0?ooo`090?oo
o`030000o`3oool0oooo03X0oooo00<0003o0?ooo`3oool0;P3oool001h0oooo00<0o`3o0?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0:0?ooo`030?l0o`3oool0oooo00L0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00X0oooo00<0003o0?ooo`3oool0>@3oool00`000?l0oooo0?ooo`0^
0?ooo`007`3oool00`3o0?l0oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo00<0o`3o0?oo
o`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0103oool00`000000oooo0000000<0?ooo`030000o`3oool0oooo03L0oooo00<0003o0?oo
o`3oool0;`3oool001l0oooo00<0o`3o0?ooo`3oool0;03oool00`000000oooo0?ooo`080?ooo`03
0?l0o`3oool0oooo00T0oooo00<000000?ooo`3oool0103oool200000300oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo03H0oooo00<0003o0?ooo`3o
ool0;`3oool00200oooo00<0o`3o0?ooo`3oool0:`3oool00`000000oooo0?ooo`070?ooo`030?l0
o`3oool0oooo00X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0E0?ooo`030000
o`3oool0oooo03@0oooo00<0003o0?ooo`3oool0<03oool00200oooo00<0o`3o0?ooo`3oool0:`3o
ool00`000000oooo0?ooo`060?ooo`030?l0o`3oool0oooo00/0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo03<0oooo00<0003o0?ooo`3oool0<03o
ool00240oooo00<0o`3o0?ooo`3oool0:P3oool00`000000oooo0?ooo`040?ooo`80o`3o3`3oool0
0`000000oooo0?ooo`02000003@0oooo00<000000?ooo`3oool00P00000D0?ooo`80003o<P3oool0
0`000?l0oooo0?ooo`0a0?ooo`008@3oool00`3o0?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo
00<0oooo00<0o`3o0?ooo`3oool0403oool2000000030?ooo`000000oooo03@0oooo0P0000000`3o
ool000000?ooo`0E0?ooo`030000o`3oool0oooo02l0oooo00<0003o0?ooo`3oool0<@3oool00280
oooo00<0o`3o0?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`030?l0o`3oool0oooo06D0
oooo00<0003o0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0b0?ooo`008`3oool00`3o0?l0oooo
0?ooo`0X0?ooo`050000003oool0oooo0?ooo`3o0?l0J@3oool00`000?l0oooo0?ooo`0/0?ooo`03
0000o`3oool0oooo0380oooo000S0?ooo`030?l0o`3oool0oooo02P0oooo00@000000?ooo`3oool0
o`3oJ`3oool00`000?l0oooo0?ooo`0Z0?ooo`030000o`3oool0oooo03<0oooo000T0?ooo`030?l0
o`3oool0oooo02L0oooo00<000000?ooo`3o0?l0K@3oool00`000?l0oooo0?ooo`0Y0?ooo`030000
o`3oool0oooo03<0oooo000U0?ooo`030?l0o`3oool0oooo02H0oooo00<000000?l0o`3oool0KP3o
ool00`000?l0oooo0?ooo`0W0?ooo`030000o`3oool0oooo03@0oooo000V0?ooo`030?l0o`3oool0
oooo02@0oooo0P3o0?ma0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool0=@3oool0
02L0oooo00<0o`3o0?ooo`3oool08P3oool00`3o0?l0oooo0000001b0?ooo`030000o`3oool0oooo
02<0oooo00<0003o0?ooo`3oool0=P3oool002L0oooo00<0o`3o0?ooo`3oool08@3oool0103o0?l0
oooo0?ooo`00001c0?ooo`80003o8`3oool00`000?l0oooo0?ooo`0f0?ooo`00:03oool00`3o0?l0
oooo0?ooo`0N0?ooo`80o`3o0`3oool00`000000oooo0?ooo`1c0?ooo`030000o`3oool0oooo01l0
oooo00<0003o0?ooo`3oool0=`3oool002T0oooo00<0o`3o0?ooo`3oool0703oool00`3o0?l0oooo
0?ooo`030?ooo`030000003oool0oooo07@0oooo0P000?lN0?ooo`030000o`3oool0oooo03P0oooo
000Z0?ooo`030?l0o`3oool0oooo01T0oooo0P3o0?l60?ooo`030000003oool0oooo07H0oooo0P00
0?lK0?ooo`030000o`3oool0oooo03T0oooo000[0?ooo`030?l0o`3oool0oooo01H0oooo0P3o0?l8
0?ooo`030000003oool0oooo07P0oooo0P000?lG0?ooo`80003o?03oool002`0oooo0P3o0?lC0?oo
o`<0o`3o2P3oool00`000000oooo0?ooo`1j0?ooo`<0003o4P3oool20000och0oooo000^0?ooo`<0
o`3o3P3oool20?l0o`D0oooo1@0000030?ooo`030000003oool0oooo07d0oooo0P000?l>0?ooo`80
003o@03oool00340oooo103o0?l60?ooo`@0o`3o2@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo07l0oooo0`000?l70?ooo`@0003o@P3oool003@0oooo1`3o0?l=0?ooo`030000003o
ool0oooo00<0oooo0`0000220?ooo`L0003oAP3oool004P0oooo00<000000?ooo`3oool0e@3oool0
04P0oooo00<000000?ooo`3oool0e@3oool004L0oooo0P00003G0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00C03oool200000=80oooo
001=0?ooo`030000003oool0oooo0=00oooo001>0?ooo`030000003oool0oooo0<l0oooo001=0?oo
o`030000003oool000000=00oooo001<0?ooo`040000003oool0oooo00000=00oooo001;0?ooo`<0
000000<0oooo000000000000c`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00001\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0, -1, 0, 0}}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.28",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/cauchygoursat/CauchyGoursatMod/\
Images/mat0628.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The contour  ",
  Cell[BoxData[
      \(C = C\_1 + C\_2\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Solution.  Again, we use partial fractions to express the integral:  \n\n\
",
  StyleBox["(6-39)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\(\( z\  - \ 2\)\/\(z\^2\  - \ 
                  z\)\) \[DifferentialD]z\ \  = \ \ \(\[Integral]\_C\((2\/z\  \
- \ 1\/\(z - 1\))\) \[DifferentialD]z\ \  = \ \ 2 \(\[Integral]\_C\( 
                      1\/z\) \[DifferentialD]z\)\ \  - \ \ \[Integral]\_C\( 
                    1\/\(z - 1\)\) \[DifferentialD]z\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Using the Cauchy-Goursat theorem, Property ",
  StyleBox["(6-17)",
    FontColor->RGBColor[0, 0, 1]],
  ", and Corollary 6.1 (with ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  "), we compute the value of the first integral on the right side of \
Equation ",
  StyleBox["(6-39)",
    FontColor->RGBColor[0, 0, 1]],
  ":  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(2 \(\[Integral]\_C\( 
                  1\/z\) \[DifferentialD]z\)\ \  = \ \ 2 \
\(\[Integral]\_\(C\_1\)\(1\/z\) \[DifferentialD]z\)\ \  + \ \ 2 \(\[Integral]\
\_\(C\_2\)\(1\/z\) \[DifferentialD]z\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(-2\) \(\
\[Integral]\_\(-C\_1\)\(1\/z\) \[DifferentialD]z\)\ \  + \ \ 0\)\)\(\
\[IndentingNewLine]\)
      \(\ \)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(-2\) \((2  \
\[Pi]\ \[ImaginaryI])\)\)\)\ \ \[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(-\ 
            4\) \[Pi]\ \[ImaginaryI]\)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "Similarly, we find that  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(-\(\[Integral]\_C\( 
                  1\/\(z - 
                    1\)\) \[DifferentialD]z\)\)\ \  = \ \ \
\(-\(\[Integral]\_\(C\_1\)\(1\/\(z - 
                      1\)\) \[DifferentialD]z\)\)\ \  + \ \ \
\(-\(\[Integral]\_\(C\_2\)\(1\/\(z - 
                      1\)\) \[DifferentialD]z\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(0\ \  - \ 
          2  \[Pi]\ \[ImaginaryI]\)\)\ \ \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(-\ 
            2\) \[Pi]\ \[ImaginaryI]\)\)\)}]],
  "   "
}], "Text"],

Cell[TextData[{
  "If we substitute the results of the last two equations into Equation ",
  StyleBox["(6-39)",
    FontColor->RGBColor[0, 0, 1]],
  " we get  \n\n\t\t\t",
  Cell[BoxData[{
      \(\[Integral]\_C\(\( z\  - \ 2\)\/\(z\^2\  - \ 
                  z\)\) \[DifferentialD]z\ \  = \ \ 2 \(\[Integral]\_C\( 
                    1\/z\) \[DifferentialD]z\)\ \  - \ \ \[Integral]\_C\( 
                  1\/\(z - 1\)\) \[DifferentialD]z\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(-\ 
              4\) \[Pi]\ \[ImaginaryI]\ \  - \ \ 2  \[Pi]\ \[ImaginaryI]\)\)\ \
\ \[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(-\ 
            6\) \[Pi]\ \[ImaginaryI]\)\)\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.16.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \(z\  - \ 2\)\/\(z\^2\  - \ z\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[R, W, z, Z];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, i, p, solset];\)\ \ \), "\n", 
    \(\(f[z_]\  = \ \(z\  - \ 2\)\/\(z\^2\  - z\);\)\ \ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "First, split the function up into partial fractions involving linear terms \
in the denominators.  Don't worry about the subroutine. It splits  ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  "  up into partial fractions.  The result will be an equivalent function \
named F[z].  The list of terms added to form F[z] have singularities in the \
same order in the list of points Z."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, z]];\)\ \ \), "\n", 
    \(\(Z\  = \ Table[0, {Length[solset]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(W\  = \ Table[0, {Length[solset]}];\)\ \ \), "\n", 
    \(\(R\  = \ Table[0, {Length[solset]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(F[z_]\  = \ 0;\)\ \ \), "\n", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[solset], \(i++\), \[IndentingNewLine]Z\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          ReplaceAll[z, 
            solset\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
]; \ \ \ \[IndentingNewLine]If[1 \[Equal] i, 
          p\  = \ 1]; \ \ \[IndentingNewLine]If[
          1 < i; \ \ Z\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\) \[Equal] 
            Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\), 
          p\  = \ p + 1, 
          p\  = \ 1]; \ \ \[IndentingNewLine]R\_\(\(\[LeftDoubleBracket]\)\(i\
\)\(\[RightDoubleBracket]\)\)\  = \ 
          Residue[\(\((z - 
                      Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\))\)\^\(p - 1\)\) f[z], {z, 
              Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)}];\
 \ \ \[IndentingNewLine]W\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\) = \ 
          Together[
            R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\/\((\
z - Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\))\)\^p]; \ \ \
\[IndentingNewLine]F[z_]\  = \ 
          F[z]\  + 
            W\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\);\ \ \
];\)\ \ \), "\n", 
    \(\(For[i = 1, 
        i \[LessEqual] Length[F[z]], \(i++\), \n\ \ \ soset\  = \ 
          Solve[Denominator[
                W\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]\
 \[Equal] 0, 
            z]; \ \ \n\ \ \ Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\)\  = \ 
          ReplaceAll[z, 
            soset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]\
; \ \ \n\ \ \ R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  \
= \ Residue[f[z], {z, 
              Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)}];\
\ \ ];\)\ \ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \ \), "\n", 
    \(\(Print["\<f[z] = \>", F[z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Determine which singularities corresponds to the contour ",
  Cell[BoxData[
      \(C\_1\)]],
  "  and ",
  Cell[BoxData[
      \(C\_2\)]],
  ".  The first term will correspond to the singularity at ",
  Cell[BoxData[
      \(z = 1\)]],
  " used with contour ",
  Cell[BoxData[
      \(C\_2\)]],
  " and the second term corresponds to the singularity at ",
  Cell[BoxData[
      \(z = 0\)]],
  " used with contour ",
  Cell[BoxData[
      \(C\_1\)]],
  ".  \n\nSince ",
  Cell[BoxData[
      \(C\_2\)]],
  " has positive orientation, we add the first term in the sum forming  F(z)  \
times constant in the numerator of that term times ",
  Cell[BoxData[
      \(2\ \[Pi]\ \[ImaginaryI]\)]],
  ".  And since the ",
  Cell[BoxData[
      \(C\_1\)]],
  " has negative orientation, we subtract the second term in the sum forming  \
F(z)  times constant in the numerator of that term times ",
  Cell[BoxData[
      \(2\ \[Pi]\ \[ImaginaryI]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(val1\  = \ 
        2\ \[Pi]\ \[ImaginaryI]\ Numerator[
            R\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\/\((\
z - Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\))\)\^p];\)\ \
\ \), "\[IndentingNewLine]", 
    \(\(val2\  = \ 
        2\ \[Pi]\ \[ImaginaryI]\ Numerator[
            R\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)\/\((\
z - Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\))\)\^p];\)\ \
\ \), "\[IndentingNewLine]", 
    \(\(val\  = \ \(-val1\) + val2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], 
              Point[{Re[
                    Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\)], Im[
                    Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\)]}]}, {Cyan, PointSize[0.03], 
              Point[{Re[
                    Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\
\)\)], Im[
                    Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\
\)\)]}]}}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(contour = 
        ParametricPlot[{{0.5 + Cos[t], Sin[2  t]}, {0.5 + Cos[t + \[Pi]], 
              Sin[2 \((t + \[Pi])\)]}}, {t, \(-\[Pi]\)\/2, \[Pi]\/2}, 
          PlotStyle \[Rule] {Blue, Magenta}, 
          Ticks \[Rule] {Range[0, 1, 1], Range[\(-1\), 1, 1]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[dots, contour, 
        PlotRange \[Rule] {{\(-0.6\), 1.6}, {\(-1.0\), 1.0}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[\(-2\), 2, 1]}, 
        Axes \[Rule] True, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Left contour \!\(C\_1\) , right contour \
\!\(C\_2\)\>\""];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(z\_1\) = \>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), \ \
\*"\"\<             \!\(z\_2\) = \>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)\ ];\)\ \
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+\(C\_1\)\) (\>\"", 
        R\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\/\((z - \
Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\))\)\^p, "\<) \
\[DifferentialD]z = \>", \(-val1\)];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The contour \!\(C\_1\) has negative \
orientation.\>\""];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+\(C\_2\)\) (\>\"", \(-R\_\(\(\
\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)\)\/\((z - Z\_\(\(\
\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\))\)\^p, "\<) \
\[DifferentialD]z = \>", \(-val2\)];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+\(C\_2\)\) (\>\"", 
        R\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)\/\((z - \
Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\))\)\^p, "\<) \
\[DifferentialD]z = \>", val2];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+\(C\_2\)\) (\>\"", 
        W\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\), "\<) \
\[DifferentialD]z = \>", val2];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The contour \!\(C\_2\) has positive \
orientation.\>\""];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        F[z], "\<) \[DifferentialD]z = -(\>", val1, "\<) + (\>", 
        val2, "\<)\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        F[z], "\<) \[DifferentialD]z = \>", 
        val];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<   \>", F[z], "\< = \>", 
        f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Therefore\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = \>", 
        val];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Complex Integral",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ComplexIntegralBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Contour Integrals",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ContourIntegralBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Green's Theorem",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/GreenTheoremBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Cauchy-Goursat Theorem",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/CauchyGoursatBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Cauchy's Integral Formula",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/CauchyIntegraBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1006, 640},
WindowMargins->{{Automatic, 3}, {Automatic, 3}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[10392, 324, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[12099, 386, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[26712, 806, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[28844, 883, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[42827, 1283, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 159205, 4051}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 121, 2, 33, "Text"],
Cell[2226, 66, 1368, 33, 94, "Text"],
Cell[3597, 101, 912, 26, 52, "Text"],
Cell[4512, 129, 438, 13, 33, "Text"],
Cell[4953, 144, 1000, 30, 71, "Text"],
Cell[5956, 176, 435, 13, 33, "Text"],
Cell[6394, 191, 1104, 36, 71, "Text"],
Cell[7501, 229, 453, 13, 33, "Text"],
Cell[7957, 244, 729, 20, 33, "Text"],
Cell[8689, 266, 1353, 42, 91, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[10067, 312, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[10215, 318, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[10392, 324, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[10752, 336, 76, 0, 30, "Text"],
Cell[10831, 338, 918, 32, 72, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[11774, 374, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[11922, 380, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[12099, 386, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[12459, 398, 1063, 35, 166, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[13547, 437, 115, 2, 33, "Text"],
Cell[13665, 441, 470, 17, 33, "Text",
  Evaluatable->False],
Cell[14138, 460, 2487, 49, 607, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[16662, 514, 115, 2, 30, "Text"],
Cell[16780, 518, 348, 13, 33, "Text"],
Cell[17131, 533, 2473, 49, 607, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19641, 587, 115, 2, 30, "Text"],
Cell[19759, 591, 422, 15, 33, "Text"],
Cell[20184, 608, 2625, 51, 627, "Input"]
}, Closed]],
Cell[22824, 662, 767, 27, 55, "Text",
  Evaluatable->False],
Cell[23594, 691, 592, 19, 33, "Text"],
Cell[24189, 712, 628, 17, 71, "Text"],
Cell[24820, 731, 930, 35, 94, "Text",
  Evaluatable->False],
Cell[25753, 768, 609, 22, 33, "Text"],

Cell[CellGroupData[{
Cell[26387, 794, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[26535, 800, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[26712, 806, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[27072, 818, 347, 6, 49, "Text"],
Cell[27422, 826, 1070, 41, 125, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[28517, 871, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[28665, 877, 176, 4, 33, "Text",
  Evaluatable->False],
Cell[28844, 883, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{
Cell[29226, 897, 112, 2, 30, "Text"],
Cell[29341, 901, 485, 18, 60, "Text",
  Evaluatable->False],
Cell[29829, 921, 2996, 59, 732, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[32862, 985, 113, 2, 30, "Text"],
Cell[32978, 989, 479, 18, 60, "Text",
  Evaluatable->False],
Cell[33460, 1009, 2984, 59, 732, "Input"]
}, Closed]],
Cell[36459, 1071, 1494, 51, 69, "Text"],
Cell[37956, 1124, 242, 4, 52, "Text"],
Cell[38201, 1130, 2576, 84, 113, "Text",
  Evaluatable->False],
Cell[40780, 1216, 1697, 51, 33, "Text"],

Cell[CellGroupData[{
Cell[42502, 1271, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[42650, 1277, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[42827, 1283, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[43187, 1295, 506, 19, 34, "Text",
  Evaluatable->False],
Cell[43696, 1316, 22896, 501, 213, "Text"],
Cell[66595, 1819, 743, 17, 133, "Text"],
Cell[67341, 1838, 1215, 30, 268, "Text"],

Cell[CellGroupData[{
Cell[68581, 1872, 112, 2, 33, "Text"],
Cell[68696, 1876, 152, 6, 37, "Text"],
Cell[68851, 1884, 306, 6, 124, "Input"],
Cell[69160, 1892, 468, 10, 52, "Text",
  Evaluatable->False],
Cell[69631, 1904, 2535, 51, 434, "Input"],
Cell[72169, 1957, 188, 7, 33, "Text",
  Evaluatable->False],
Cell[72360, 1966, 710, 14, 70, "Input"],
Cell[73073, 1982, 335, 11, 33, "Text",
  Evaluatable->False],
Cell[73411, 1995, 3149, 59, 363, "Input"]
}, Closed]],
Cell[76575, 2057, 522, 19, 34, "Text",
  Evaluatable->False],
Cell[77100, 2078, 20398, 419, 232, "Text"],
Cell[97501, 2499, 1794, 43, 278, "Text"],

Cell[CellGroupData[{
Cell[99320, 2546, 112, 2, 33, "Text"],
Cell[99435, 2550, 152, 6, 37, "Text"],
Cell[99590, 2558, 306, 6, 124, "Input"],
Cell[99899, 2566, 469, 10, 52, "Text",
  Evaluatable->False],
Cell[100371, 2578, 2535, 51, 434, "Input"],
Cell[102909, 2631, 204, 7, 33, "Text",
  Evaluatable->False],
Cell[103116, 2640, 789, 15, 70, "Input"],
Cell[103908, 2657, 337, 11, 33, "Text",
  Evaluatable->False],
Cell[104248, 2670, 2377, 43, 343, "Input"]
}, Closed]],
Cell[106640, 2716, 458, 15, 34, "Text",
  Evaluatable->False],
Cell[107101, 2733, 36369, 910, 197, "Text"],
Cell[143473, 3645, 451, 16, 33, "Text"],
Cell[143927, 3663, 541, 13, 75, "Text"],
Cell[144471, 3678, 1139, 27, 195, "Text"],
Cell[145613, 3707, 742, 17, 151, "Text"],
Cell[146358, 3726, 839, 17, 151, "Text"],

Cell[CellGroupData[{
Cell[147222, 3747, 112, 2, 33, "Text"],
Cell[147337, 3751, 157, 6, 36, "Text"],
Cell[147497, 3759, 309, 6, 124, "Input"],
Cell[147809, 3767, 468, 10, 52, "Text",
  Evaluatable->False],
Cell[148280, 3779, 2478, 50, 414, "Input"],
Cell[150761, 3831, 1027, 36, 109, "Text",
  Evaluatable->False],
Cell[151791, 3869, 4328, 78, 775, "Input"]
}, Closed]],
Cell[156134, 3950, 290, 7, 30, "Text"],
Cell[156427, 3959, 317, 10, 33, "Text"],
Cell[156747, 3971, 318, 10, 33, "Text"],
Cell[157068, 3983, 313, 10, 33, "Text"],
Cell[157384, 3995, 321, 10, 33, "Text"],
Cell[157708, 4007, 324, 10, 33, "Text"],
Cell[158035, 4019, 257, 5, 33, "Text"],
Cell[158295, 4026, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

