(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     98859,       2552]*)
(*NotebookOutlinePosition[     99893,       2589]*)
(*  CellTagsIndexPosition[     99817,       2583]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["6.4  The Fundamental Theorems of Integration",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tLet ",
  StyleBox["f",
    FontFamily->"Courier New"],
  " be analytic in the simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  The theorems in this section show that an antiderivative ",
  StyleBox["F",
    FontFamily->"Courier New"],
  " can be constructed by contour integration.  A consequence will be the \
fact that in a simply connected domain, the integral of an analytic function \
f along any contour joining  ",
  Cell[BoxData[
      \(z\_1\ \ to\ \ z\_2\)]],
  "  is the same, and its value is given by  ",
  Cell[BoxData[
      \(F \((z\_2)\) - F \((z\_1)\)\)]],
  ".  As a result, we can use the antiderivative formulas from calculus to \
compute the value of definite integrals.  The next two theorems are \
generalizations of the ",
  StyleBox[ButtonBox["Fundamental Theorems of Calculus",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/FundamentalTheoremsofCalculus.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Theorem 6.8 (Indefinite Integrals or Antiderivatives).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " be analytic in the simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  If  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  is a fixed value in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " and if ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is any contour in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " with initial point  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  and terminal point ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ", then the function \n\n\t\t\t",
  Cell[BoxData[
      \(F \((z)\)\ \  = \ \ \(\[Integral]\_C\ \ f \((z)\)\ \[DifferentialD]z\ \
\  = \ \ \[Integral]\_\(z\_0\)\%z\ 
            f \((\[Zeta])\) \[DifferentialD]\[Zeta]\)\)]],
  "  \n\nis well-defined and analytic in D, with its derivative given by  ",
  Cell[BoxData[
      \(F' \((z)\) = f \((z)\)\)]],
  ".   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.8 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark 6.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  It is important to stress that the line integral of an analytic function \
is independent of path.  In Example 6.9 we showed that  ",
  Cell[BoxData[
      \(\[Integral]\_\(C\_1\)\ 
          z\ \[DifferentialD]z\  = \ \(\[Integral]\_\(C\_2\)\ 
            z\ \[DifferentialD]z\  = \ 4 + 2  \[ImaginaryI]\)\)]],
  ",  where ",
  Cell[BoxData[
      \(C\_1\)]],
  " and ",
  Cell[BoxData[
      \(C\_2\)]],
  " were different contours joining  ",
  Cell[BoxData[
      RowBox[{\(-1\), "-", 
        RowBox[{"\[ImaginaryI]", "  ", 
          StyleBox["to",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", "3"}], "+", "\[ImaginaryI]"}]]],
  ".  Because the integrand  ",
  Cell[BoxData[
      \(f \((z)\) = z\)]],
  " is an analytic function, Theorem 6.8 lets us know ahead of time that the \
value of the two integrals is the same; hence one calculation would have \
sufficed.  If you ever have to compute a line integral of an analytic \
function over a difficult contour, change the contour to something easier.  \
You are guaranteed to get the same answer.  Of course, you must be sure that \
the function you're dealing with is analytic in a simply connected domain \
containing your original and new contours."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = z\)],
    AspectRatioFixed->True],
  "  and the initial point  ",
  Cell[BoxData[
      \(Z\_0 = \(-1\) - \[ImaginaryI]\)],
    AspectRatioFixed->True],
  "  and terminal point  ",
  Cell[BoxData[
      \(Z\_1 = 3 + \[ImaginaryI]\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, Z];\)\ \), "\n", 
    \(\(Clear[f, F, path, val1, val2];\)\ \), "\n", 
    \(\(f[z_]\  = \ z;\)\ \), "\n", 
    \(\(Z\_0 = \(-1\) - \[ImaginaryI];\)\ \), "\n", 
    \(\(Z\_1 = 3 + \[ImaginaryI];\)\ \), "\n", 
    \(\(F[z_]\  = \[Integral]f[z] \[DifferentialD]z;\)\ \), "\n", 
    \(\(val1\  = \ F[Z\_1]\  - \ F[Z\_0];\)\ \), "\n", 
    \(\(val2\  = \ \[Integral]\_\(Z\_0\)\%\(Z\_1\)f[
              z] \[DifferentialD]z;\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(path\  = \ 
        Graphics[{{Blue, PointSize[0.035], 
              Point[{Re[Z\_0], Im[Z\_0]}]}, {Red, PointSize[0.035], 
              Point[{Re[Z\_1], Im[Z\_1]}]}, \[IndentingNewLine]{Green, 
              Dashing[{0.03, 0.03}], 
              Arrow[{Re[Z\_0], Im[Z\_0]}, {Re[Z\_1], Im[Z\_1]}, 
                HeadScaling \[Rule] Absolute]}}];\)\ \), "\n", 
    \(\(Show[path, PlotRange \[Rule] {{\(-1.2\), 3.2}, {\(-1.2\), 1.2}}, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], 
            Range[\(-1\), 1, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<   f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<   F[z] = \[Integral]\>", "\<(\>", 
        f[z], "\<)\[DifferentialD]z = \>", F[z]];\)\ \), "\n", 
    \(\(Print["\<F[\>", Z\_1, "\<] = \>", F[Z\_1], "\<,  and  F[\>", 
        Z\_0, "\<] = \>", F[Z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<It is permissible to use the straight line path.\>"];\)\ \), \
"\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]\>"\+\(Z\_0\)\%\(Z\_1\), "\<(\>", 
        f[z], "\<)\[DifferentialD]z = F[\>", Z\_1, "\<] - F[\>", 
        Z\_0, "\<]\>"];\)\ \), "\n", 
    \(\(Print["\<         = (\>", F[Z\_1]\ , "\<) - (\>", \ 
        F[Z\_0], "\<)\>"];\)\ \), "\n", 
    \(\(Print["\<         = \>", 
        ComplexExpand[val1]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<\[Integral]\>"\+\(Z\_0\)\%\(Z\_1\), "\<(\>", 
        f[z], "\<)\[DifferentialD]z = \>", 
        ComplexExpand[val2]];\)\ \), "\n", 
    \(\(Print["\<\[Integral]\>"\+\(Z\_0\)\%\(Z\_1\), "\<(\>", 
        f[z], "\<)\[DifferentialD]z = \>", 
        N[val2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tIf we set ",
  Cell[BoxData[
      \(z = z\_1\)]],
  " in Theorem 6.8, then we obtain the following familiar result for \
evaluating a definite integral of an analytic function. "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 6.9 (Definite Integrals).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  "  be analytic in a simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  If  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  and  ",
  Cell[BoxData[
      \(z\_1\)]],
  "  are two points in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " joined by a contour C, then \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_\(z\_0\)\%\(z\_1\)\ 
          f \((z)\) \[DifferentialD]z\ \  = \ \ F \((z\_1)\) - 
          F \((z\_0)\)\)]],
  ",  \n\nwhere ",
  StyleBox["F(z)",
    FontFamily->"Courier New"],
  " is any antiderivative of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.9 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\<\
\tTheorem 6.9 gives an important method for evaluating definite integrals \
when the integrand is an analytic function in a simply connected domain.  In \
essence, it permits you to use all the rules of integration that you learned \
in calculus.  When the conditions of Theorem 6.9 are met, applying it is \
generally much easier than parametrizing a contour.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 6.17.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Integral]\_C\ 1\/\(2  z\^\(1/2\)\)\ \[DifferentialD]z = 
        1 + \[ImaginaryI]\)]],
  " where ",
  Cell[BoxData[
      \(z\^\(1/2\)\)]],
  " is the principal branch of the square root function and ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is the line segment joining  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"4", "  ", 
          StyleBox["to",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", "8"}], 
        "+", \(6  \[ImaginaryI]\)}]]],
  ".  \n\nRemark. Sometimes we write this as   ",
  Cell[BoxData[
      \(\[Integral]\_4\%\(8\  + \ 6  \[ImaginaryI]\)\(z\^\(\(-1\)/2\)\/2\) \
\[DifferentialD]z = 1 + \[ImaginaryI]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .57 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0178125 0.0890625 [
[.2619 .00531 -3 -9 ]
[.2619 .00531 3 0 ]
[.5 .00531 -3 -9 ]
[.5 .00531 3 0 ]
[.7381 .00531 -3 -9 ]
[.7381 .00531 3 0 ]
[.97619 .00531 -3 -9 ]
[.97619 .00531 3 0 ]
[1.025 .01781 0 -6.28125 ]
[1.025 .01781 10 6.28125 ]
[.01131 .19594 -6 -4.5 ]
[.01131 .19594 0 4.5 ]
[.01131 .37406 -6 -4.5 ]
[.01131 .37406 0 4.5 ]
[.01131 .55219 -6 -4.5 ]
[.01131 .55219 0 4.5 ]
[.02381 .595 -5 0 ]
[.02381 .595 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .57 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01781 m
.2619 .02406 L
s
[(2)] .2619 .00531 0 1 Mshowa
.5 .01781 m
.5 .02406 L
s
[(4)] .5 .00531 0 1 Mshowa
.7381 .01781 m
.7381 .02406 L
s
[(6)] .7381 .00531 0 1 Mshowa
.97619 .01781 m
.97619 .02406 L
s
[(8)] .97619 .00531 0 1 Mshowa
0 .01781 m
1 .01781 L
s
gsave
1.025 .01781 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .19594 m
.03006 .19594 L
s
[(2)] .01131 .19594 1 0 Mshowa
.02381 .37406 m
.03006 .37406 L
s
[(4)] .01131 .37406 1 0 Mshowa
.02381 .55219 m
.03006 .55219 L
s
[(6)] .01131 .55219 1 0 Mshowa
.02381 0 m
.02381 .57 L
s
gsave
.02381 .595 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .57 L
0 .57 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 0 1 r
.035 w
.5 .01781 Mdot
1 0 0 r
.97619 .55219 Mdot
0 1 0 r
.5 Mabswid
[ .03 .03 ] 0 setdash
.5 .01781 m
.97619 .55219 L
s
% Start of user PostScript
4. 0 8. 6. MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{299, 170.125},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004[0000ZR000`400?l00000o`00003oo`3oool/
0?ooo`00D03oool4000003X0oooo0`00000g0?ooo`<00000>@3oool2000002D0oooo001@0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool0=P3oool010000000oooo0?ooo`00000g0?oo
o`040000003oool0oooo000002@0oooo001A0?ooo`030000003oool0oooo03P0oooo1@00000g0?oo
o`040000003oool0oooo000003L0oooo00@000000?ooo`3oool00000903oool00580oooo00<00000
0?ooo`3oool0=`3oool010000000oooo0?ooo`00000h0?ooo`<00000>@3oool2000002D0oooo001@
0?ooo`040000003oool0oooo000003T0oooo00<000000?ooo`000000>@3oool00`000000oooo0?oo
o`0g0?ooo`040000003oool0oooo000002@0oooo001A0?ooo`800000>`3oool2000003T0oooo0`00
000h0?ooo`8000009@3oool00?l0oooo;03oool001L0oooo00<000000?ooo`3oool0o`3ooolB0?oo
o`005`3oool00`000000oooo0?ooo`1c0?ooo`80003oW03oool001L0oooo00<000000?ooo`3oool0
L@3oool60000oiX0oooo000G0?ooo`030000003oool0oooo0740oooo1P000?n20?ooo`80000000<0
oooo0000000000004`3oool001L0oooo00<000000?ooo`3oool0L03oool80000oh80oooo00<00000
0?ooo`000000503oool00140ooooN@0000040000o`04003o00000?l0003o0000ogX000002@3oool0
0`000000oooo0?ooo`0C0?ooo`005`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
03H0oooo10000?l00`00o`00003o0?ooo`0h0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool02`3oool2000000030?ooo`000000000001<0oooo000G0?ooo`030000003oool0oooo0740
oooo1@000?l00`00o`00oooo0?ooo`2H0?ooo`005`3oool00`000000oooo0?ooo`1c0?ooo`80003o
0P3oool00`00o`00oooo0?ooo`2G0?ooo`005`3oool00`000000oooo0?ooo`1h0?ooo`03003o003o
ool0oooo09H0oooo000G0?ooo`030000003oool0oooo07T0oooo00<00?l00?ooo`3oool0U@3oool0
01L0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`005`3oool00`000000oooo0?ooo`3o0?oooa80
oooo000G0?ooo`030000003oool0oooo0?l0oooo4P3oool001L0oooo00<000000?ooo`3oool0o`3o
oolB0?ooo`005`3oool00`000000oooo0?ooo`3o0?oooa80oooo000G0?ooo`030000003oool0oooo
07h0oooo00<00?l00?ooo`3oool0T03oool001L0oooo00<000000?ooo`3oool0O`3oool00`00o`00
oooo0?ooo`2?0?ooo`005`3oool00`000000oooo0?ooo`200?ooo`03003o003oool0oooo08h0oooo
000G0?ooo`030000003oool0oooo0840oooo00<00?l00?ooo`3oool0S@3oool001L0oooo00<00000
0?ooo`3oool0PP3oool00`00o`00oooo0?ooo`2<0?ooo`005`3oool00`000000oooo0?ooo`230?oo
o`03003o003oool0oooo08/0oooo000G0?ooo`030000003oool0oooo0?l0oooo4P3oool001L0oooo
00<000000?ooo`3oool0o`3ooolB0?ooo`005`3oool00`000000oooo0?ooo`3o0?oooa80oooo000G
0?ooo`030000003oool0oooo0?l0oooo4P3oool001L0oooo00<000000?ooo`3oool0o`3ooolB0?oo
o`005`3oool00`000000oooo0?ooo`280?ooo`03003o003oool0oooo08H0oooo000G0?ooo`030000
003oool0oooo08T0oooo00<00?l00?ooo`3oool0Q@3oool001L0oooo00<000000?ooo`3oool0RP3o
ool00`00o`00oooo0?ooo`240?ooo`005`3oool00`000000oooo0?ooo`2:0?ooo`03003o003oool0
oooo08@0oooo000G0?ooo`030000003oool0oooo08/0oooo00<00?l00?ooo`3oool0P`3oool001L0
oooo00<000000?ooo`3oool0S03oool00`00o`00oooo0?ooo`220?ooo`005`3oool00`000000oooo
0?ooo`2=0?ooo`03003o003oool0oooo0840oooo000G0?ooo`030000003oool0oooo0?l0oooo4P3o
ool001L0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`005`3oool00`000000oooo0?ooo`3o0?oo
oa80oooo000G0?ooo`030000003oool0oooo0?l0oooo4P3oool001L0oooo00<000000?ooo`3oool0
TP3oool00`00o`00oooo0?ooo`1l0?ooo`005`3oool00`000000oooo0?ooo`2C0?ooo`03003o003o
ool0oooo07/0oooo000G0?ooo`030000003oool0oooo09@0oooo00<00?l00?ooo`3oool0NP3oool0
01L0oooo00<000000?ooo`3oool0U03oool00`00o`00oooo0?ooo`1j0?ooo`005`3oool00`000000
oooo0?ooo`2E0?ooo`03003o003oool0oooo07T0oooo000G0?ooo`030000003oool0oooo09H0oooo
00<00?l00?ooo`3oool0N03oool001L0oooo00<000000?ooo`3oool0U`3oool00`00o`00oooo0?oo
o`1g0?ooo`005`3oool00`000000oooo0?ooo`3o0?oooa80oooo000G0?ooo`030000003oool0oooo
0?l0oooo4P3oool000l0oooo100000040?ooo`030000003oool0oooo0?l0oooo4P3oool000l0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oooa80oooo000@0?ooo`030000003o
ool0oooo00@0oooo0P00002M0?ooo`03003o003oool0oooo0780oooo000A0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0W@3oool00`00o`00oooo0?ooo`1a0?ooo`003`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo09h0oooo00<00?l00?ooo`3oool0L03oool0
0100oooo0P0000050?ooo`030000003oool0oooo09h0oooo00<00?l00?ooo`3oool0L03oool001L0
oooo00<000000?ooo`3oool0W`3oool00`00o`00oooo0?ooo`1_0?ooo`005`3oool00`000000oooo
0?ooo`2P0?ooo`03003o003oool0oooo06h0oooo000G0?ooo`030000003oool0oooo0:40oooo00<0
0?l00?ooo`3oool0K@3oool001L0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`005`3oool00`00
0000oooo0?ooo`3o0?oooa80oooo000G0?ooo`030000003oool0oooo0?l0oooo4P3oool001L0oooo
00<000000?ooo`3oool0o`3ooolB0?ooo`005`3oool00`000000oooo0?ooo`3o0?oooa80oooo000G
0?ooo`030000003oool0oooo0:H0oooo00<00?l00?ooo`3oool0J03oool001L0oooo00<000000?oo
o`3oool0Y`3oool00`00o`00oooo0?ooo`1W0?ooo`005`3oool00`000000oooo0?ooo`2X0?ooo`03
003o003oool0oooo06H0oooo000G0?ooo`030000003oool0oooo0:T0oooo00<00?l00?ooo`3oool0
I@3oool001L0oooo00<000000?ooo`3oool0ZP3oool00`00o`00oooo0?ooo`1T0?ooo`005`3oool0
0`000000oooo0?ooo`2[0?ooo`03003o003oool0oooo06<0oooo000G0?ooo`030000003oool0oooo
0?l0oooo4P3oool001L0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`005`3oool00`000000oooo
0?ooo`3o0?oooa80oooo000G0?ooo`030000003oool0oooo0?l0oooo4P3oool001L0oooo00<00000
0?ooo`3oool0o`3ooolB0?ooo`005`3oool00`000000oooo0?ooo`2`0?ooo`03003o003oool0oooo
05h0oooo000G0?ooo`030000003oool0oooo0;40oooo00<00?l00?ooo`3oool0G@3oool001L0oooo
00<000000?ooo`3oool0/P3oool00`00o`00oooo0?ooo`1L0?ooo`005`3oool00`000000oooo0?oo
o`2c0?ooo`03003o003oool0oooo05/0oooo000G0?ooo`030000003oool0oooo0;@0oooo00<00?l0
0?ooo`3oool0FP3oool001L0oooo00<000000?ooo`3oool0]@3oool00`00o`00oooo0?ooo`1I0?oo
o`005`3oool00`000000oooo0?ooo`3o0?oooa80oooo000G0?ooo`030000003oool0oooo0?l0oooo
4P3oool001L0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`005`3oool00`000000oooo0?ooo`3o
0?oooa80oooo000G0?ooo`030000003oool0oooo0?l0oooo4P3oool001L0oooo00<000000?ooo`3o
ool0^P3oool00`00o`00oooo0?ooo`1D0?ooo`005`3oool00`000000oooo0?ooo`2k0?ooo`03003o
003oool0oooo05<0oooo000G0?ooo`030000003oool0oooo0;`0oooo00<00?l00?ooo`3oool0DP3o
ool001L0oooo00<000000?ooo`3oool0_03oool00`00o`00oooo0?ooo`1B0?ooo`005`3oool00`00
0000oooo0?ooo`2m0?ooo`03003o003oool0oooo0540oooo000G0?ooo`030000003oool0oooo0;h0
oooo00<00?l00?ooo`3oool0D03oool001L0oooo00<000000?ooo`3oool0_`3oool00`00o`00oooo
0?ooo`1?0?ooo`005`3oool00`000000oooo0?ooo`3o0?oooa80oooo000G0?ooo`030000003oool0
oooo0?l0oooo4P3oool00140oooo0`0000030?ooo`030000003oool0oooo0?l0oooo4P3oool00180
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oooa80oooo000?0?ooo`D00000
0`3oool200000<D0oooo00<00?l00?ooo`3oool0BP3oool000l0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`350?ooo`03003o003oool0oooo04T0oooo000@0?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool0aP3oool00`00o`00oooo0?ooo`180?ooo`004@3oool2
000000@0oooo00<000000?ooo`3oool0aP3oool00`00o`00oooo0?ooo`180?ooo`005`3oool00`00
0000oooo0?ooo`370?ooo`03003o003oool0oooo04L0oooo000G0?ooo`030000003oool0oooo0<P0
oooo00<00?l00?ooo`3oool0AP3oool001L0oooo00<000000?ooo`3oool0b@3oool00`00o`00oooo
0?ooo`150?ooo`005`3oool00`000000oooo0?ooo`3o0?oooa80oooo000G0?ooo`030000003oool0
oooo0?l0oooo4P3oool001L0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`005`3oool00`000000
oooo0?ooo`3o0?oooa80oooo000G0?ooo`030000003oool0oooo0<h0oooo00<00?l00?ooo`3oool0
@03oool001L0oooo00<000000?ooo`3oool0c`3oool00`00o`00oooo0?ooo`0o0?ooo`005`3oool0
0`000000oooo0?ooo`3@0?ooo`03003o003oool0oooo03h0oooo000G0?ooo`030000003oool0oooo
0=00oooo00<00?l00?ooo`3oool0?P3oool001L0oooo00<000000?ooo`3oool0d@3oool00`00o`00
oooo0?ooo`0m0?ooo`005`3oool00`000000oooo0?ooo`3B0?ooo`03003o003oool0oooo03`0oooo
000G0?ooo`030000003oool0oooo0=<0oooo00<00?l00?ooo`3oool0>`3oool001L0oooo00<00000
0?ooo`3oool0o`3ooolB0?ooo`005`3oool00`000000oooo0?ooo`3o0?oooa80oooo000G0?ooo`03
0000003oool0oooo0?l0oooo4P3oool001L0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`005`3o
ool00`000000oooo0?ooo`3o0?oooa80oooo000G0?ooo`030000003oool0oooo0=P0oooo00<00?l0
0?ooo`3oool0=P3oool001L0oooo00<000000?ooo`3oool0f@3oool00`00o`00oooo0?ooo`0e0?oo
o`005`3oool00`000000oooo0?ooo`3J0?ooo`03003o003oool0oooo03@0oooo000G0?ooo`030000
003oool0oooo0=/0oooo00<00?l00?ooo`3oool0<`3oool001L0oooo00<000000?ooo`3oool0g03o
ool00`00o`00oooo0?ooo`0b0?ooo`005`3oool00`000000oooo0?ooo`3M0?ooo`03003o003oool0
oooo0340oooo000G0?ooo`030000003oool0oooo0?l0oooo4P3oool001L0oooo00<000000?ooo`3o
ool0o`3ooolB0?ooo`005`3oool00`000000oooo0?ooo`3S0?ooo`800?l0;03oool001L0oooo00<0
00000?ooo`3oool0hP3oool4003o02/0oooo000G0?ooo`030000003oool0oooo0>40oooo1@00o`0[
0?ooo`005`3oool00`000000oooo0?ooo`3O0?ooo`P00?l0:P3oool001L0oooo00<000000?ooo`3o
ool0gP3oool9003o02X0oooo000G0?ooo`030000003oool0oooo0=h0oooo2P00o`0Y0?ooo`005`3o
ool00`000000oooo0?ooo`3P0?ooo`T00?l0:03oool001L0oooo00<000000?ooo`3oool0h@3oool8
003o02P0oooo000G0?ooo`030000003oool0oooo0><0oooo1`00o`0W0?ooo`005`3oool00`000000
oooo0?ooo`3T0?ooo`H00?l09`3oool001L0oooo00<000000?ooo`3oool0iP3oool5003o00030?l0
003oool0oooo02<0oooo000?0?ooo`<000001@3oool00`000000oooo0?ooo`3W0?ooo`@00?l00`3o
000S0?ooo`003`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0>P0oooo00@0
o`00003o0000o`000?l00P3o000S0?ooo`003`3oool010000000oooo0?ooo`0000040?ooo`800000
j03oool30?l000800?l00`3o000R0?ooo`003`3oool3000000D0oooo00<000000?ooo`3oool0i`3o
ool80?l00280oooo000@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0j03oool6
0?l002<0oooo000@0?ooo`<00000103oool00`000000oooo0?ooo`3X0?ooo`H0o`008`3oool001L0
oooo00<000000?ooo`3oool0jP3oool20?l002D0oooo000G0?ooo`030000003oool0oooo0?l0oooo
4P3oool00?l0oooo;03oool00?l0oooo;03oool00?l0oooo;03oool00?l0oooo;03oool00?l0oooo
;03oool00?l0oooo;03oool00?l0oooo;03oool00?l0oooo;03oool001D0oooo0P00003o0?oooaD0
oooo000F0?ooo`030000003oool0oooo0?l0oooo4`3oool001L0oooo00<000000?ooo`3oool0o`3o
oolB0?ooo`005P3oool00`000000oooo0000003o0?oooa<0oooo000E0?ooo`040000003oool0oooo
00000?l0oooo4`3oool001@0oooo0`0000000`3oool000000000003o0?oooa80oooo003o0?ooob`0
oooo003o0?ooob`0oooo003o0?ooob`0oooo003o0?ooob`0oooo0000\
\>"],
    ImageRangeCache->{{{0, 298}, {169.125, 0}} -> {0, 0, 0, 0}}],
  "   "
}], "Text"],

Cell[TextData[{
  "Solution.  We showed in Chapter 3 that if  ",
  Cell[BoxData[
      \(F \((z)\) = z\^\(1\/2\)\)]],
  ",  then  ",
  Cell[BoxData[
      \(F' \((z)\) = 1\/\(2  z\^\(1/2\)\)\)]],
  ",  where the principal branch of the square root function is used in both \
the formulas for ",
  StyleBox["F(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["F'(z)",
    FontFamily->"Courier New"],
  ".  We note that ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is contained in the simply connected domain ",
  Cell[BoxData[
      \(\(D\_4\) \((6 + 3  \[ImaginaryI])\)\)]],
  ", which is the open disk of radius ",
  StyleBox["4",
    FontFamily->"Courier New"],
  " centered at the midpoint of the segment C.  Since  ",
  Cell[BoxData[
      \(f \((z)\) = 1\/\(2  z\^\(1/2\)\)\)]],
  "  is analytic in the domain ",
  Cell[BoxData[
      \(\(D\_4\) \((6 + 3  \[ImaginaryI])\)\)]],
  " and ",
  Cell[BoxData[
      \(F \((z)\)\)]],
  "is an anti-derivative of ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  ", Theorem 6.9 guarantees that  \n\n\t\t\t",
  Cell[BoxData[{
      \(\[Integral]\_C\ 
          1\/\(2  z\^\(1/2\)\)\ \[DifferentialD]z\ \  = \ \ \
\(\[Integral]\_4\%\(8\  + \ 6  \[ImaginaryI]\)\(z\^\(\(-1\)/2\)\/2\) \
\[DifferentialD]z\ \  = \ \ F \((8 + 6  \[ImaginaryI])\)\  - \ F \((4)\)\)\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\((8\  + 6  \[ImaginaryI])\)\^\(1\/2\)\ \  - \ \ \((4)\)\^\(1\/2\)\ \  = \
\ \ 3 + \[ImaginaryI]\ \  - \ \ 2\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1\  \
+ \ \[ImaginaryI]\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.17.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = z\^\(\(-1\)/2\)\/2\)],
    AspectRatioFixed->True],
  "  and the initial point  ",
  Cell[BoxData[
      \(Z\_0 = 4\)],
    AspectRatioFixed->True],
  "  and terminal point  ",
  Cell[BoxData[
      \(Z\_1 = 8 + 6  \[ImaginaryI]\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, Z];\)\ \), "\n", 
    \(\(Clear[f, F, path, val1, val2];\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^\(\(-1\)/2\)\/2;\)\ \), "\n", 
    \(\(Z\_0 = 4;\)\ \), "\n", 
    \(\(Z\_1 = 8 + 6  \[ImaginaryI];\)\ \), "\n", 
    \(\(F[z_]\  = \[Integral]f[z] \[DifferentialD]z;\)\ \), "\n", 
    \(\(val1\  = \ F[Z\_1]\  - \ F[Z\_0];\)\ \), "\n", 
    \(\(val2\  = \ \[Integral]\_\(Z\_0\)\%\(Z\_1\)f[
              z] \[DifferentialD]z;\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(path\  = \ 
        Graphics[{{Blue, PointSize[0.035], 
              Point[{Re[Z\_0], Im[Z\_0]}]}, {Red, PointSize[0.035], 
              Point[{Re[Z\_1], Im[Z\_1]}]}, \[IndentingNewLine]{Green, 
              Dashing[{0.03, 0.03}], 
              Arrow[{Re[Z\_0], Im[Z\_0]}, {Re[Z\_1], Im[Z\_1]}, 
                HeadScaling \[Rule] Absolute]}}];\)\ \), "\n", 
    \(\(Show[path, PlotRange \[Rule] {{\(-0.2\), 8.2}, {\(-0.2\), 6.2}}, 
        Ticks \[Rule] {Range[0, 8, 2], 
            Range[0, 6, 2]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print["\<    f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<    F[z] = \[Integral]\>", "\<(\>", 
        f[z], "\<)\[DifferentialD]z = \>", F[z]];\)\ \), "\n", 
    \(\(Print["\<F[\>", Z\_1, "\<] = \>", F[Z\_1], "\<,  and  F[\>", 
        Z\_0, "\<] = \>", F[Z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<It is permissible to use the straight line path.\>"];\)\ \), \
"\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]\>"\+\(Z\_0\)\%\(Z\_1\), "\<(\>", 
        f[z], "\<)\[DifferentialD]z = F[\>", Z\_1, "\<] - F[\>", 
        Z\_0, "\<]\>"];\)\ \), "\n", 
    \(\(Print["\<              = (\>", F[Z\_1]\ , "\<) - (\>", \ 
        F[Z\_0], "\<)\>"];\)\ \), "\n", 
    \(\(Print["\<              = \>", 
        ComplexExpand[val1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<\[Integral]\>"\+\(Z\_0\)\%\(Z\_1\), "\<(\>", 
        f[z], "\<)\[DifferentialD]z = \>", 
        ComplexExpand[val2]];\)\ \), "\n", 
    \(\(Print["\<\[Integral]\>"\+\(Z\_0\)\%\(Z\_1\), "\<(\>", 
        f[z], "\<)\[DifferentialD]z = \>", 
        N[val2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.18.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Integral]\_C\ 
          cos \((z)\)\ \[DifferentialD]z\ \  = \ \ \(-\ 
              sin\)\ 1\ \  + \ \[ImaginaryI]\ sinh\ 1\)]],
  ",  where ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is the line segment between ",
  Cell[BoxData[
      RowBox[{"1", " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "\[ImaginaryI]"}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0833333 0.833333 0.0833333 0.833333 [
[.5 .07083 -8.09375 -20.125 ]
[.5 .07083 8.09375 0 ]
[.91667 .07083 -3 -9 ]
[.91667 .07083 3 0 ]
[1.025 .08333 0 -6.28125 ]
[1.025 .08333 10 6.28125 ]
[.07083 .5 -16.1875 -10.0625 ]
[.07083 .5 0 10.0625 ]
[.07083 .91667 -6 -4.5 ]
[.07083 .91667 0 4.5 ]
[.08333 1.025 -5 0 ]
[.08333 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .08333 m
.5 .08958 L
s
gsave
.5 .07083 -69.0938 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.91667 .08333 m
.91667 .08958 L
s
[(1)] .91667 .07083 0 1 Mshowa
0 .08333 m
1 .08333 L
s
gsave
1.025 .08333 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .5 m
.08958 .5 L
s
gsave
.07083 .5 -77.1875 -14.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.08333 .91667 m
.08958 .91667 L
s
[(1)] .07083 .91667 1 0 Mshowa
.08333 0 m
.08333 1 L
s
gsave
.08333 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 0 1 r
.035 w
.91667 .08333 Mdot
1 0 0 r
.08333 .91667 Mdot
0 1 0 r
.5 Mabswid
[ .03 .03 ] 0 setdash
.91667 .08333 m
.08333 .91667 L
s
% Start of user PostScript
1. 0 0 1. MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{173, 173},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002]0000[B000`400?l00000o`00003o[@3oool0
0:d0oooo001@0?ooo`@00000F@3oool00500oooo00<000000?ooo`3oool0FP3oool00540oooo00<0
00000?ooo`3oool0F@3oool00580oooo00<000000?ooo`3oool0F03oool00500oooo00@000000?oo
o`3oool00000F@3oool00540oooo0P00001J0?ooo`00[@3oool00:d0oooo000E0?ooo`030000003o
ool0oooo03D0oooo100000000`3oool0000000000002000005L0oooo000E0?ooo`030000003oool0
oooo09D0oooo000E0?ooo`030000003oool0oooo09D0oooo000E0?ooo`030000003oool0oooo07@0
oooo1@00000L0?ooo`005@3oool00`000000oooo0?ooo`0h0?ooo`D00000>@3oool00`000000oooo
0?ooo`0L0?ooo`005@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0703oool001D0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo01`0oooo000E0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`005@3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo03P0oooo0P00000N0?ooo`005@3oool00`000000oooo0?ooo`0i0?ooo`800000
FP3oool001D0oooo00<000000?ooo`3oool0M@3oool30000oad0oooo000E0?ooo`030000003oool0
oooo07@0oooo1@000?l?0?ooo`80000000<0oooo000000000000203oool000T0ooooP`0000020000
o`03003o00000?l0003o00/000001@3oool00`000000oooo000000090?ooo`005@3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo03L0oooo00<0003o003o00000?l00P000?lA0?ooo`03
0000003oool0oooo00P0oooo000E0?ooo`030000003oool0oooo07@0oooo00@00?l00000o`000?l0
003o403oool2000000030?ooo`000000000000P0oooo000E0?ooo`030000003oool0oooo07@0oooo
00<00?l00?ooo`3oool07P3oool001D0oooo00<000000?ooo`3oool0L`3oool00`00o`00oooo0?oo
o`0O0?ooo`005@3oool00`000000oooo0?ooo`2E0?ooo`005@3oool00`000000oooo0?ooo`2E0?oo
o`005@3oool00`000000oooo0?ooo`1`0?ooo`03003o003oool0oooo0280oooo000E0?ooo`030000
003oool0oooo06l0oooo00<00?l00?ooo`3oool08`3oool001D0oooo00<000000?ooo`3oool0KP3o
ool00`00o`00oooo0?ooo`0T0?ooo`005@3oool00`000000oooo0?ooo`1]0?ooo`03003o003oool0
oooo02D0oooo000E0?ooo`030000003oool0oooo09D0oooo000E0?ooo`030000003oool0oooo09D0
oooo000E0?ooo`030000003oool0oooo06X0oooo00<00?l00?ooo`3oool0:03oool001D0oooo00<0
00000?ooo`3oool0J@3oool00`00o`00oooo0?ooo`0Y0?ooo`005@3oool00`000000oooo0?ooo`1X
0?ooo`03003o003oool0oooo02X0oooo000E0?ooo`030000003oool0oooo06L0oooo00<00?l00?oo
o`3oool0:`3oool001D0oooo00<000000?ooo`3oool0U@3oool001D0oooo00<000000?ooo`3oool0
U@3oool001D0oooo00<000000?ooo`3oool0I03oool00`00o`00oooo0?ooo`0^0?ooo`005@3oool0
0`000000oooo0?ooo`1S0?ooo`03003o003oool0oooo02l0oooo000E0?ooo`030000003oool0oooo
0680oooo00<00?l00?ooo`3oool0<03oool001D0oooo00<000000?ooo`3oool0H@3oool00`00o`00
oooo0?ooo`0a0?ooo`005@3oool00`000000oooo0?ooo`2E0?ooo`005@3oool00`000000oooo0?oo
o`2E0?ooo`005@3oool00`000000oooo0?ooo`1N0?ooo`03003o003oool0oooo03@0oooo000E0?oo
o`030000003oool0oooo05d0oooo00<00?l00?ooo`3oool0=@3oool001D0oooo00<000000?ooo`3o
ool0G03oool00`00o`00oooo0?ooo`0f0?ooo`005@3oool00`000000oooo0?ooo`1K0?ooo`03003o
003oool0oooo03L0oooo000E0?ooo`030000003oool0oooo09D0oooo000E0?ooo`030000003oool0
oooo09D0oooo000E0?ooo`030000003oool0oooo05L0oooo00<00?l00?ooo`3oool0>`3oool001D0
oooo00<000000?ooo`3oool0EP3oool00`00o`00oooo0?ooo`0l0?ooo`005@3oool00`000000oooo
0?ooo`1E0?ooo`03003o003oool0oooo03d0oooo000E0?ooo`030000003oool0oooo05D0oooo00<0
0?l00?ooo`3oool0?@3oool001D0oooo00<000000?ooo`3oool0E03oool00`00o`00oooo0?ooo`0n
0?ooo`005@3oool00`000000oooo0?ooo`2E0?ooo`005@3oool00`000000oooo0?ooo`2E0?ooo`00
5@3oool00`000000oooo0?ooo`1A0?ooo`03003o003oool0oooo0440oooo000E0?ooo`030000003o
ool0oooo0500oooo00<00?l00?ooo`3oool0@P3oool001D0oooo00<000000?ooo`3oool0C`3oool0
0`00o`00oooo0?ooo`130?ooo`005@3oool00`000000oooo0?ooo`1>0?ooo`03003o003oool0oooo
04@0oooo000E0?ooo`030000003oool0oooo09D0oooo000E0?ooo`030000003oool0oooo09D0oooo
000E0?ooo`030000003oool0oooo04/0oooo00<00?l00?ooo`3oool0A`3oool001D0oooo00<00000
0?ooo`3oool0BP3oool00`00o`00oooo0?ooo`180?ooo`005@3oool00`000000oooo0?ooo`190?oo
o`03003o003oool0oooo04T0oooo000E0?ooo`030000003oool0oooo04P0oooo00<00?l00?ooo`3o
ool0BP3oool001D0oooo00<000000?ooo`3oool0U@3oool001D0oooo00<000000?ooo`3oool0U@3o
ool001D0oooo00<000000?ooo`3oool0A@3oool00`00o`00oooo0?ooo`1=0?ooo`005@3oool00`00
0000oooo0?ooo`140?ooo`03003o003oool0oooo04h0oooo000E0?ooo`030000003oool0oooo04<0
oooo00<00?l00?ooo`3oool0C`3oool000T0oooo100000080?ooo`030000003oool0oooo0480oooo
00<00?l00?ooo`3oool0D03oool000T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`2E0?ooo`002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09D0oooo000;0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0?`3oool00`00o`00oooo0?ooo`1C0?oo
o`002@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo03h0oooo00<00?l00?oo
o`3oool0E03oool000X0oooo0P0000090?ooo`030000003oool0oooo03d0oooo00<00?l00?ooo`3o
ool0E@3oool001D0oooo00<000000?ooo`3oool0?03oool00`00o`00oooo0?ooo`1F0?ooo`001`3o
ool8000000H0oooo00<000000?ooo`3oool0U@3oool001D0oooo0P00002F0?ooo`005@3oool00`00
0000oooo0?ooo`0h0?ooo`03003o003oool0oooo05X0oooo000E0?ooo`030000003oool0oooo03L0
oooo00<00?l00?ooo`3oool0F`3oool001D0oooo00<000000?ooo`3oool0=P3oool00`00o`00oooo
0?ooo`1L0?ooo`002@3oool5000000L0oooo00<000000?ooo`3oool0=P3oool00`00o`00oooo0?oo
o`1L0?ooo`002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03D0oooo00<00?l0
0?ooo`3oool0G@3oool000/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2E0?oo
o`002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo09D0oooo000;0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0<P3oool00`00o`00oooo0?ooo`1P0?ooo`002P3o
ool2000000T0oooo00<000000?ooo`3oool0<@3oool00`00o`00oooo0?ooo`1Q0?ooo`005@3oool0
0`000000oooo0?ooo`0`0?ooo`03003o003oool0oooo0680oooo000E0?ooo`030000003oool0oooo
02l0oooo00<00?l00?ooo`3oool0H`3oool001D0oooo00<000000?ooo`3oool0U@3oool001D0oooo
00<000000?ooo`3oool0U@3oool001D0oooo00<000000?ooo`3oool0;03oool00`00o`00oooo0?oo
o`1V0?ooo`005@3oool00`000000oooo0?ooo`0[0?ooo`03003o003oool0oooo06L0oooo000E0?oo
o`030000003oool0oooo02X0oooo00<00?l00?ooo`3oool0J03oool001D0oooo00<000000?ooo`3o
ool0:@3oool00`00o`00oooo0?ooo`1Y0?ooo`005@3oool00`000000oooo0?ooo`2E0?ooo`005@3o
ool00`000000oooo0?ooo`2E0?ooo`005@3oool00`000000oooo0?ooo`0V0?ooo`03003o003oool0
oooo06`0oooo000E0?ooo`030000003oool0oooo02D0oooo00<00?l00?ooo`3oool0K@3oool001D0
oooo00<000000?ooo`3oool0903oool00`00o`00oooo0?ooo`1^0?ooo`005@3oool00`000000oooo
0?ooo`0S0?ooo`03003o003oool0oooo06l0oooo000E0?ooo`030000003oool0oooo09D0oooo000E
0?ooo`030000003oool0oooo09D0oooo000E0?ooo`030000003oool0oooo0200oooo00<00?l00?oo
o`3oool0LP3oool001D0oooo00<000000?ooo`3oool07`3oool00`00o`00oooo0?ooo`1c0?ooo`00
5@3oool00`000000oooo0?ooo`0N0?ooo`03003o003oool0oooo07@0oooo000E0?ooo`030000003o
ool0oooo01d0oooo00<00?l00?ooo`3oool0M@3oool001D0oooo00<000000?ooo`3oool0U@3oool0
01D0oooo00<000000?ooo`3oool0U@3oool001D0oooo00<000000?ooo`3oool06@3oool00`00o`00
oooo0?ooo`1i0?ooo`005@3oool00`000000oooo0?ooo`0H0?ooo`03003o003oool0oooo07X0oooo
000E0?ooo`030000003oool0oooo01L0oooo00<00?l00?ooo`3oool0N`3oool001D0oooo00<00000
0?ooo`3oool05`3oool00`00o`00oooo0?ooo`1k0?ooo`005@3oool00`000000oooo0?ooo`0F0?oo
o`03003o003oool0oooo07`0oooo000E0?ooo`030000003oool0oooo09D0oooo000E0?ooo`030000
003oool0oooo09D0oooo000E0?ooo`030000003oool0oooo01<0oooo00<00?l00?ooo`3oool0O`3o
ool001D0oooo00<000000?ooo`3oool04P3oool00`00o`00oooo0?ooo`200?ooo`005@3oool00`00
0000oooo0?ooo`0A0?ooo`03003o003oool0oooo0840oooo000E0?ooo`030000003oool0oooo0100
oooo00<00?l00?ooo`3oool0PP3oool001D0oooo00<000000?ooo`3oool0U@3oool001D0oooo00<0
00000?ooo`3oool0U@3oool001D0oooo00<000000?ooo`3oool03@3oool00`00o`00oooo0?ooo`25
0?ooo`005@3oool00`000000oooo0?ooo`0<0?ooo`03003o003oool0oooo08H0oooo000E0?ooo`03
0000003oool0oooo00/0oooo00<00?l00?ooo`3oool0Q`3oool001D0oooo00<000000?ooo`3oool0
103oool2003o00@0oooo00<00?l00?ooo`3oool0R03oool001D0oooo00<000000?ooo`3oool0103o
ool3003o08h0oooo000E0?ooo`030000003oool0oooo00<0oooo1@00o`2=0?ooo`005@3oool00`00
0000oooo0?ooo`030?ooo`H00?l0S03oool001D0oooo00<000000?ooo`3oool00P3oool8003o08/0
oooo000E0?ooo`040000003oool0oooo0?ooo`X00?l0RP3oool001D0oooo00@000000?ooo`3oool0
oooo2@00o`2;0?ooo`005@3oool00`000000oooo0?ooo`09003o08`0oooo000E0?ooo`030000003o
ool0oooo00L00?l0SP3oool001D0oooo00<000000?ooo`00o`001@00o`2@0?ooo`005@3oool00`00
00000?l0003o0004003o0940oooo000>0?ooo`D0000000<0oooo0?l0003o00001000o`2C0?ooo`00
403oool00`000000oooo0?ooo`020?l000<00?l0U@3oool00100oooo00<000000?ooo`3oool00P3o
0002003o00030?l0003oool0oooo09<0oooo000@0?ooo`030000003oool0oooo00D0o`00U@3oool0
0100oooo00@000000?ooo`3oool0oooo0`3o002F0?ooo`003`3oool2000000@0oooo00<000000?oo
o`3oool0U@3oool001D0oooo00<000000?ooo`3oool0U@3oool001D0oooo00<000000?ooo`3oool0
U@3oool001D0oooo00<000000?ooo`3oool0U@3oool001D0oooo00<000000?ooo`3oool0U@3oool0
01D0oooo00<000000?ooo`3oool0U@3oool001D0oooo00<000000?ooo`3oool0U@3oool001D0oooo
00<000000?ooo`3oool0U@3oool001D0oooo00<000000?ooo`3oool0U@3oool001D0oooo00<00000
0?ooo`3oool0U@3oool00:d0oooo002]0?ooo`00[@3oool00:d0oooo002]0?ooo`00[@3oool001<0
oooo0P00002H0?ooo`00503oool00`000000oooo0?ooo`2F0?ooo`005@3oool00`000000oooo0?oo
o`2E0?ooo`00503oool00`000000oooo0000002F0?ooo`004`3oool010000000oooo0?ooo`00002F
0?ooo`004P3oool3000000030?ooo`000000000009D0oooo002]0?ooo`00[@3oool00:d0oooo002]
0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 172}, {172, 0}} -> {0, 0, 0, 0}}],
  "   "
}], "Text"],

Cell[TextData[{
  "Solution.  An antiderivative of  ",
  Cell[BoxData[
      \(f \((z)\) = cos\ z\)]],
  "  is  ",
  Cell[BoxData[
      \(F \((z)\) = sin\ z\)]],
  ".  Because ",
  StyleBox["F(z)",
    FontFamily->"Courier New"],
  " is entire, we use Theorem 6.9 to conclude that \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_C\ 
          cos \((z)\)\ \[DifferentialD]z\ \  = \ \ \[Integral]\_1\%\
\[ImaginaryI]\ cos \((z)\) \[DifferentialD]z\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \
\ \)\(\[Integral]\_1\%\[ImaginaryI]\ 
            f \((z)\) \[DifferentialD]z\ \  = \ \ F \((\[ImaginaryI])\) - 
            F \((1)\)\)\)\(\[IndentingNewLine]\)
      \(\ \)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \
\ \)\(sin\ \[ImaginaryI]\ \  - \ \ sin\ 1\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \
\ \)\(\[ImaginaryI]\ sinh\ 1\ \  - \ \ sin\ 1\)\)\(\ \ \
\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \
\ \)\(\(-\ \ sin\)\ 1\ \  + \ \ \[ImaginaryI]\ sinh\ 1\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(\(-\ 0.8414709848078965`\)\  + \ 
          1.1752011936438014`\ \[ImaginaryI]\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = Cos[z]\)],
    AspectRatioFixed->True],
  "  and the initial point  ",
  Cell[BoxData[
      \(Z\_0 = 1\)],
    AspectRatioFixed->True],
  "  and terminal point  ",
  Cell[BoxData[
      \(Z\_1 = \[ImaginaryI]\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, path, val1, val2];\)\ \), "\n", 
    \(\(f[z_]\  = \ Cos[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_0 = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_1 = \[ImaginaryI];\)\ \), "\n", 
    \(\(g[z_]\  = \[Integral]f[z] \[DifferentialD]z;\)\ \), "\n", 
    \(\(val1\  = \ g[Z\_1]\  - \ g[Z\_0];\)\ \), "\n", 
    \(\(val2\  = \ \[Integral]\_\(Z\_0\)\%\(Z\_1\)f[
              z] \[DifferentialD]z;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(path\  = \ 
        Graphics[{{Blue, PointSize[0.035], 
              Point[{Re[Z\_0], Im[Z\_0]}]}, {Red, PointSize[0.035], 
              Point[{Re[Z\_1], Im[Z\_1]}]}, \[IndentingNewLine]{Green, 
              Dashing[{0.03, 0.03}], 
              Arrow[{Re[Z\_0], Im[Z\_0]}, {Re[Z\_1], Im[Z\_1]}, 
                HeadScaling \[Rule] Absolute]}}];\)\ \), "\n", 
    \(\(Show[path, PlotRange \[Rule] {{\(-0.1\), 1.1}, {\(-0.1\), 1.1}}, 
        Ticks \[Rule] {Range[0, 1, 1\/2], 
            Range[0, 1, 1\/2]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[z] = \[Integral]\>", "\<(\>", 
        f[z], "\<)\[DifferentialD]z = \>", 
        g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[\>", Z\_1, "\<] = \>", g[Z\_1], "\<,  and  g[\>", 
        Z\_0, "\<] = \>", g[Z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<It is permissible to use the straight line path.\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]\>"\+\(Z\_0\)\%\(Z\_1\), "\<(\>", 
        f[z], "\<)\[DifferentialD]z = g[\>", Z\_1, "\<] - g[\>", 
        Z\_0, "\<]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<            = (\>", g[Z\_1]\ , "\<) - (\>", \ 
        g[Z\_0], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<            = \>", 
        ComplexExpand[val1]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]\>"\+\(Z\_0\)\%\(Z\_1\), "\<(\>", 
        f[z], "\<)\[DifferentialD]z = \>", 
        ComplexExpand[val2]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]\>"\+\(Z\_0\)\%\(Z\_1\), "\<(\>", 
        f[z], "\<)\[DifferentialD]z = \>", 
        N[val2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.19.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" ",
    FontWeight->"Bold"],
  " We let ",
  Cell[BoxData[
      \(D = {z = 
            r\ \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\) : \ 
                r > 0\ and\  - \[Pi] < \[Theta] < \[Pi]\)}\)]],
  " be the simply connected domain which is the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-plane slit along the negative ",
  StyleBox["x",
    FontFamily->"Courier New"],
  "-axis, shown in Figure 6.32.  We know that ",
  Cell[BoxData[
      \(f \((z)\) = 1\/z\)]],
  " is analytic in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", and has an antiderivative ",
  Cell[BoxData[
      \(f \((z)\) = Log \((z)\)\)]],
  " for all z in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  If ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a contour in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " that joins the point ",
  Cell[BoxData[
      \(z\_1\)]],
  " to the point ",
  Cell[BoxData[
      \(z\_2\)]],
  ", then Theorem 6.9 implies that  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_\(z\_1\)\%\(z\_2\)\ \(1\/z\) \[DifferentialD]z\ \  = \ \ \
Log\ z\_2 - Log\ z\_1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.454545 0.5 0.454545 [
[.04545 .4875 -6 -9 ]
[.04545 .4875 6 0 ]
[.95455 .4875 -3 -9 ]
[.95455 .4875 3 0 ]
[1.025 .5 0 -6.28125 ]
[1.025 .5 10 6.28125 ]
[.4875 .04545 -12 -4.5 ]
[.4875 .04545 0 4.5 ]
[.4875 .95455 -6 -4.5 ]
[.4875 .95455 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04545 .5 m
.04545 .50625 L
s
[(-1)] .04545 .4875 0 1 Mshowa
.95455 .5 m
.95455 .50625 L
s
[(1)] .95455 .4875 0 1 Mshowa
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .04545 m
.50625 .04545 L
s
[(-1)] .4875 .04545 1 0 Mshowa
.5 .95455 m
.50625 .95455 L
s
[(1)] .4875 .95455 1 0 Mshowa
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.03 w
.04545 .50945 Mdot
1 0 0 r
.04545 .49055 Mdot
0 1 0 r
.5 Mabswid
[ .031 .031 ] 0 setdash
newpath
.5 .5 .45455 -179.049 179.049 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{206, 206},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003>0000cR000`400?l00000o`00003oG`3oool0
0`000000oooo0?ooo`1/0?ooo`00G`3oool00`000000oooo0?ooo`1/0?ooo`00G`3oool00`000000
oooo0?ooo`1/0?ooo`00G`3oool00`000000oooo0?ooo`1/0?ooo`00G`3oool00`000000oooo0?oo
o`1/0?ooo`00G`3oool00`000000oooo0?ooo`1/0?ooo`00G`3oool00`000000oooo0?ooo`1/0?oo
o`00E`3oool5000000<0oooo00<000000?ooo`3oool0K03oool005T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1/0?ooo`00F@3oool00`0000000?l0003o0005003o00D0oooo00<0
0?l00?ooo`3oool0I@3oool00540oooo1000o`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool5003o0680oooo001>0?ooo`<00?l0203oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00l0oooo0P00o`1K0?ooo`00A`3oool3003o00h0oooo0P0000050?ooo`03
0000003oool0oooo0140oooo1000o`1G0?ooo`00A@3oool2003o01P0oooo00<000000?ooo`3oool0
5@3oool00`00o`00oooo0?ooo`1D0?ooo`00@`3oool2003o01X0oooo00<000000?ooo`3oool06P3o
ool00`00o`00oooo0?ooo`1?0?ooo`00G`3oool00`000000oooo0?ooo`0K0?ooo`800?l0C`3oool0
03d0oooo0P00o`0P0?ooo`030000003oool0oooo01d0oooo0P00o`1=0?ooo`00>`3oool2003o0280
oooo00<000000?ooo`3oool07`3oool2003o04/0oooo000h0?ooo`<00?l0903oool00`000000oooo
0?ooo`1/0?ooo`00G`3oool00`000000oooo0?ooo`0U0?ooo`03003o003oool0oooo04@0oooo001O
0?ooo`030000003oool0oooo02H0oooo0P00o`140?ooo`00<`3oool00`00o`00oooo0?ooo`0Y0?oo
o`030000003oool0oooo02P0oooo0P00o`120?ooo`00<P3oool00`00o`00oooo0?ooo`0Z0?ooo`03
0000003oool0oooo02X0oooo00<00?l00?ooo`3oool0?`3oool00300oooo0P00o`0]0?ooo`030000
003oool0oooo06`0oooo000^0?ooo`800?l0;`3oool00`000000oooo0?ooo`1/0?ooo`00G`3oool0
0`000000oooo0?ooo`0_0?ooo`03003o003oool0oooo03X0oooo001O0?ooo`030000003oool0oooo
0300oooo00<00?l00?ooo`3oool0>@3oool002X0oooo00<00?l00?ooo`3oool0<P3oool00`000000
oooo0?ooo`0a0?ooo`03003o003oool0oooo03P0oooo000Y0?ooo`03003o003oool0oooo03<0oooo
00<000000?ooo`3oool0<P3oool00`00o`00oooo0?ooo`0g0?ooo`00:03oool00`00o`00oooo0?oo
o`0d0?ooo`030000003oool0oooo03<0oooo00<00?l00?ooo`3oool0=P3oool002H0oooo0P00o`0g
0?ooo`030000003oool0oooo06`0oooo000U0?ooo`03003o003oool0oooo03L0oooo00<000000?oo
o`3oool0K03oool005l0oooo00<000000?ooo`3oool0K03oool005l0oooo00<000000?ooo`3oool0
>03oool00`00o`00oooo0?ooo`0a0?ooo`00G`3oool00`000000oooo0?ooo`0i0?ooo`03003o003o
ool0oooo0300oooo000Q0?ooo`03003o003oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool0
0`00o`00oooo0?ooo`0_0?ooo`00803oool00`00o`00oooo0?ooo`0l0?ooo`030000003oool0oooo
03/0oooo00<00?l00?ooo`3oool0;P3oool001l0oooo00<00?l00?ooo`3oool0?@3oool00`000000
oooo0?ooo`0l0?ooo`03003o003oool0oooo02d0oooo000O0?ooo`03003o003oool0oooo03d0oooo
00<000000?ooo`3oool0K03oool001d0oooo0P00o`100?ooo`030000003oool0oooo06`0oooo000M
0?ooo`03003o003oool0oooo03l0oooo00<000000?ooo`3oool0K03oool005l0oooo00<000000?oo
o`3oool0@03oool00`00o`00oooo0?ooo`0Y0?ooo`00G`3oool00`000000oooo0?ooo`100?ooo`03
003o003oool0oooo02T0oooo001O0?ooo`030000003oool0oooo0400oooo00<00?l00?ooo`3oool0
:@3oool001X0oooo00<00?l00?ooo`3oool0@P3oool00`000000oooo0?ooo`110?ooo`03003o003o
ool0oooo02P0oooo000I0?ooo`03003o003oool0oooo04<0oooo00<000000?ooo`3oool0@P3oool2
003o02P0oooo000H0?ooo`03003o003oool0oooo04@0oooo00<000000?ooo`3oool0@`3oool00`00
o`00oooo0?ooo`0V0?ooo`005`3oool00`00o`00oooo0?ooo`150?ooo`030000003oool0oooo06`0
oooo000G0?ooo`03003o003oool0oooo04D0oooo00<000000?ooo`3oool0K03oool001H0oooo00<0
0?l00?ooo`3oool0AP3oool00`000000oooo0?ooo`1/0?ooo`00G`3oool00`000000oooo0?ooo`1/
0?ooo`00G`3oool00`000000oooo0?ooo`160?ooo`03003o003oool0oooo02<0oooo001O0?ooo`03
0000003oool0oooo04H0oooo00<00?l00?ooo`3oool08`3oool005l0oooo00<000000?ooo`3oool0
A`3oool00`00o`00oooo0?ooo`0R0?ooo`004`3oool00`00o`00oooo0?ooo`190?ooo`030000003o
ool0oooo04P0oooo00<00?l00?ooo`3oool08@3oool001<0oooo00<00?l00?ooo`3oool0B@3oool0
0`000000oooo0?ooo`180?ooo`03003o003oool0oooo0240oooo000B0?ooo`03003o003oool0oooo
04X0oooo00<000000?ooo`3oool0B@3oool00`00o`00oooo0?ooo`0P0?ooo`004P3oool00`00o`00
oooo0?ooo`1:0?ooo`030000003oool0oooo06`0oooo000A0?ooo`03003o003oool0oooo04/0oooo
00<000000?ooo`3oool0K03oool00140oooo00<00?l00?ooo`3oool0B`3oool00`000000oooo0?oo
o`1/0?ooo`00G`3oool00`000000oooo0?ooo`1/0?ooo`00G`3oool00`000000oooo0?ooo`1;0?oo
o`03003o003oool0oooo01h0oooo001O0?ooo`030000003oool0oooo04`0oooo00<00?l00?ooo`3o
ool07@3oool005l0oooo00<000000?ooo`3oool0C03oool00`00o`00oooo0?ooo`0M0?ooo`00G`3o
ool00`000000oooo0?ooo`1<0?ooo`03003o003oool0oooo01d0oooo000?0?ooo`03003o003oool0
oooo04d0oooo00<000000?ooo`3oool0C03oool00`00o`00oooo0?ooo`0M0?ooo`003P3oool00`00
o`00oooo0?ooo`1>0?ooo`030000003oool0oooo04d0oooo00<00?l00?ooo`3oool0703oool000d0
oooo00<00?l00?ooo`3oool0C`3oool00`000000oooo0?ooo`1=0?ooo`03003o003oool0oooo01`0
oooo000=0?ooo`03003o003oool0oooo04l0oooo00<000000?ooo`3oool0K03oool000d0oooo00<0
0?l00?ooo`3oool0C`3oool00`000000oooo0?ooo`1/0?ooo`003@3oool00`00o`00oooo0?ooo`1?
0?ooo`030000003oool0oooo06`0oooo001O0?ooo`030000003oool0oooo06`0oooo001O0?ooo`03
0000003oool0oooo04l0oooo00<00?l00?ooo`3oool06P3oool005l0oooo00<000000?ooo`3oool0
C`3oool00`00o`00oooo0?ooo`0J0?ooo`00G`3oool00`000000oooo0?ooo`1?0?ooo`03003o003o
ool0oooo01X0oooo001O0?ooo`030000003oool0oooo04l0oooo00<00?l00?ooo`3oool06P3oool0
00/0oooo00<00?l00?ooo`3oool0D@3oool00`000000oooo0?ooo`1@0?ooo`03003o003oool0oooo
01T0oooo000;0?ooo`03003o003oool0oooo0540oooo00<000000?ooo`3oool0D03oool00`00o`00
oooo0?ooo`0I0?ooo`002`3oool00`00o`00oooo0?ooo`1A0?ooo`030000003oool0oooo0500oooo
00<00?l00?ooo`3oool06@3oool000/0oooo00<00?l00?ooo`3oool0D@3oool00`000000oooo0?oo
o`1/0?ooo`002P3oool00`00o`00oooo0?ooo`1B0?ooo`030000003oool0oooo06`0oooo000:0?oo
o`03003o003oool0oooo0580oooo00<000000?ooo`3oool0K03oool005l0oooo00<000000?ooo`3o
ool0K03oool005l0oooo00<000000?ooo`3oool0K03oool000X0oooo1@00001@0?ooo`030000003o
ool0oooo0500oooo00<00000003o000000000P00000G0?ooo`00303oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo0540oooo00<00?l00000003oool0603oool000`0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`1B0?ooo`03003o003oool0oooo01L0oooo00040?ooo`@0
00000P3oool00`00o`00oooo0000001B0?ooo`030000003oool0oooo0580oooo00<00?l00?ooo`3o
ool05`3oool000T0oooo00@00?l00?ooo`3oool00000DP3oool00`000000oooo0?ooo`1B0?ooo`03
003o003oool0oooo01L0oooo00090?ooo`04003o003oool0000000000580oooo00<000000?ooo`3o
ool0D@3oool00`0000000?l00?ooo`0H0?ooo`002@3oool00`00o`00oooo0?ooo`1C0?ooo`030000
003oool0oooo0580oooo00<00?l00?ooo`3oool05`3oool000P0oooo00<0o`00003o003o0000E03o
ool00`000000oooo0?ooo`1/0?ooo`001`3oool20?l00003003o003o0000o`0005<0oooo00<00000
0?ooo`3oool0K03oool000L0oooo0P3o00000`00o`00o`000?l0001C0?ooo`030000003oool0oooo
0640oooo0P0000000`3oool00000000000060?ooo`0000<0oooo000000000000100000050?l00:P0
000000<00?l00000000000001`0000060?ooo`030000003oool0000000L0oooo00070?ooo`050000
o`3o0000o`000?l000000?l0D`3oool00`000000oooo0?ooo`1B0?ooo`03003o003oool0oooo00h0
oooo00<000000?ooo`3oool01P3oool000L0oooo1@000?mC0?ooo`030000003oool0oooo0580oooo
00<00?l00?ooo`3oool0303oool2000000030?ooo`000000000000H0oooo00070?ooo`D0003oD`3o
ool00`000000oooo0?ooo`1B0?ooo`03003o003oool0oooo01L0oooo00080?ooo`<0003oE03oool0
0`000000oooo0?ooo`1B0?ooo`03003o003oool0oooo01L0oooo001O0?ooo`030000003oool0oooo
0580oooo00<00?l00?ooo`3oool05`3oool005l0oooo00<000000?ooo`3oool0DP3oool00`00o`00
oooo0?ooo`0G0?ooo`002@3oool00`00o`00oooo0?ooo`1C0?ooo`030000003oool0oooo06`0oooo
000:0?ooo`03003o003oool0oooo0580oooo00<000000?ooo`3oool0K03oool000X0oooo00<00?l0
0?ooo`3oool0DP3oool00`000000oooo0?ooo`1/0?ooo`002P3oool00`00o`00oooo0?ooo`1B0?oo
o`030000003oool0oooo06`0oooo000:0?ooo`03003o003oool0oooo0580oooo00<000000?ooo`3o
ool0K03oool000X0oooo00<00?l00?ooo`3oool0DP3oool00`000000oooo0?ooo`1A0?ooo`03003o
003oool0oooo01P0oooo001O0?ooo`030000003oool0oooo0540oooo00<00?l00?ooo`3oool0603o
ool005l0oooo00<000000?ooo`3oool0D@3oool00`00o`00oooo0?ooo`0H0?ooo`00G`3oool00`00
0000oooo0?ooo`1A0?ooo`03003o003oool0oooo01P0oooo001O0?ooo`030000003oool0oooo0500
oooo00<00?l00?ooo`3oool06@3oool005l0oooo00<000000?ooo`3oool0D03oool00`00o`00oooo
0?ooo`0I0?ooo`002`3oool00`00o`00oooo0?ooo`1A0?ooo`030000003oool0oooo0500oooo00<0
0?l00?ooo`3oool06@3oool000/0oooo00<00?l00?ooo`3oool0D@3oool00`000000oooo0?ooo`1/
0?ooo`00303oool00`00o`00oooo0?ooo`1@0?ooo`030000003oool0oooo06`0oooo000<0?ooo`03
003o003oool0oooo0500oooo00<000000?ooo`3oool0K03oool000`0oooo00<00?l00?ooo`3oool0
D03oool00`000000oooo0?ooo`1/0?ooo`00303oool00`00o`00oooo0?ooo`1@0?ooo`030000003o
ool0oooo04l0oooo00<00?l00?ooo`3oool06P3oool000d0oooo00<00?l00?ooo`3oool0C`3oool0
0`000000oooo0?ooo`1>0?ooo`03003o003oool0oooo01/0oooo001O0?ooo`030000003oool0oooo
04h0oooo00<00?l00?ooo`3oool06`3oool005l0oooo00<000000?ooo`3oool0CP3oool00`00o`00
oooo0?ooo`0K0?ooo`00G`3oool00`000000oooo0?ooo`1>0?ooo`03003o003oool0oooo01/0oooo
001O0?ooo`030000003oool0oooo04d0oooo00<00?l00?ooo`3oool0703oool000h0oooo00<00?l0
0?ooo`3oool0CP3oool00`000000oooo0?ooo`1=0?ooo`03003o003oool0oooo01`0oooo000?0?oo
o`03003o003oool0oooo04d0oooo00<000000?ooo`3oool0K03oool000l0oooo00<00?l00?ooo`3o
ool0C@3oool00`000000oooo0?ooo`1/0?ooo`003`3oool00`00o`00oooo0?ooo`1=0?ooo`030000
003oool0oooo06`0oooo000?0?ooo`03003o003oool0oooo04d0oooo00<000000?ooo`3oool0K03o
ool00100oooo00<00?l00?ooo`3oool0C03oool00`000000oooo0?ooo`1;0?ooo`03003o003oool0
oooo01h0oooo000@0?ooo`03003o003oool0oooo04`0oooo00<000000?ooo`3oool0B`3oool00`00
o`00oooo0?ooo`0N0?ooo`00G`3oool00`000000oooo0?ooo`1:0?ooo`03003o003oool0oooo01l0
oooo001O0?ooo`030000003oool0oooo04X0oooo00<00?l00?ooo`3oool07`3oool005l0oooo00<0
00000?ooo`3oool0B@3oool00`00o`00oooo0?ooo`0P0?ooo`00G`3oool00`000000oooo0?ooo`19
0?ooo`03003o003oool0oooo0200oooo000C0?ooo`03003o003oool0oooo04T0oooo00<000000?oo
o`3oool0B03oool00`00o`00oooo0?ooo`0Q0?ooo`004`3oool00`00o`00oooo0?ooo`190?ooo`03
0000003oool0oooo06`0oooo000D0?ooo`03003o003oool0oooo04P0oooo00<000000?ooo`3oool0
K03oool001D0oooo00<00?l00?ooo`3oool0A`3oool00`000000oooo0?ooo`1/0?ooo`005@3oool0
0`00o`00oooo0?ooo`170?ooo`030000003oool0oooo06`0oooo000F0?ooo`03003o003oool0oooo
04H0oooo00<000000?ooo`3oool0AP3oool00`00o`00oooo0?ooo`0S0?ooo`00G`3oool00`000000
oooo0?ooo`150?ooo`03003o003oool0oooo02@0oooo001O0?ooo`030000003oool0oooo04@0oooo
00<00?l00?ooo`3oool09@3oool005l0oooo00<000000?ooo`3oool0A03oool00`00o`00oooo0?oo
o`0U0?ooo`00G`3oool00`000000oooo0?ooo`130?ooo`03003o003oool0oooo02H0oooo000I0?oo
o`800?l0A03oool00`000000oooo0?ooo`120?ooo`03003o003oool0oooo02L0oooo000J0?ooo`03
003o003oool0oooo0480oooo00<000000?ooo`3oool0K03oool001/0oooo00<00?l00?ooo`3oool0
@@3oool00`000000oooo0?ooo`1/0?ooo`006`3oool00`00o`00oooo0?ooo`110?ooo`030000003o
ool0oooo06`0oooo000L0?ooo`800?l0@@3oool00`000000oooo0?ooo`0o0?ooo`03003o003oool0
oooo02X0oooo001O0?ooo`030000003oool0oooo03h0oooo00<00?l00?ooo`3oool0:`3oool005l0
oooo00<000000?ooo`3oool0?@3oool00`00o`00oooo0?ooo`0/0?ooo`00G`3oool00`000000oooo
0?ooo`0l0?ooo`03003o003oool0oooo02d0oooo001O0?ooo`030000003oool0oooo03/0oooo00<0
0?l00?ooo`3oool0;P3oool00200oooo00<00?l00?ooo`3oool0?03oool00`000000oooo0?ooo`0k
0?ooo`03003o003oool0oooo02h0oooo000Q0?ooo`800?l0?03oool00`000000oooo0?ooo`1/0?oo
o`008`3oool00`00o`00oooo0?ooo`0i0?ooo`030000003oool0oooo06`0oooo000T0?ooo`03003o
003oool0oooo03P0oooo00<000000?ooo`3oool0K03oool002D0oooo00<00?l00?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0f0?ooo`800?l0=03oool005l0oooo00<000000?ooo`3oool0=@3oool0
0`00o`00oooo0?ooo`0d0?ooo`00G`3oool00`000000oooo0?ooo`0e0?ooo`03003o003oool0oooo
03@0oooo001O0?ooo`030000003oool0oooo03<0oooo0P00o`0g0?ooo`00:@3oool00`00o`00oooo
0?ooo`0c0?ooo`030000003oool0oooo03<0oooo00<00?l00?ooo`3oool0=P3oool002X0oooo0P00
o`0c0?ooo`030000003oool0oooo06`0oooo000/0?ooo`03003o003oool0oooo0300oooo00<00000
0?ooo`3oool0K03oool002d0oooo0P00o`0`0?ooo`030000003oool0oooo02h0oooo00<00?l00?oo
o`3oool0>`3oool005l0oooo00<000000?ooo`3oool0;03oool2003o03h0oooo001O0?ooo`030000
003oool0oooo02/0oooo00<00?l00?ooo`3oool0?P3oool003<0oooo00<00?l00?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0Y0?ooo`800?l0@@3oool003@0oooo00<00?l00?ooo`3oool0:03oool0
0`000000oooo0?ooo`1/0?ooo`00=@3oool00`00o`00oooo0?ooo`0W0?ooo`030000003oool0oooo
06`0oooo000f0?ooo`<00?l09P3oool00`000000oooo0?ooo`0S0?ooo`800?l0A`3oool005l0oooo
00<000000?ooo`3oool08P3oool00`00o`00oooo0?ooo`170?ooo`00G`3oool00`000000oooo0?oo
o`0P0?ooo`800?l0BP3oool003d0oooo00<00?l00?ooo`3oool07`3oool00`000000oooo0?ooo`0O
0?ooo`03003o003oool0oooo04X0oooo000n0?ooo`@00?l07@3oool00`000000oooo0?ooo`1/0?oo
o`00@P3oool00`00o`00oooo0?ooo`0J0?ooo`030000003oool0oooo01P0oooo0P00o`1B0?ooo`00
G`3oool00`000000oooo0?ooo`0D0?ooo`@00?l0E03oool004P0oooo1000o`0C0?ooo`030000003o
ool0oooo01@0oooo00<00?l00?ooo`3oool0E@3oool004`0oooo0`00o`080?ooo`D000000`3oool0
0`000000oooo0?ooo`0<0?ooo`<00?l0G@3oool005<0oooo1@00o`000`3oool000000?ooo`040?oo
o`030000003oool0oooo00P0oooo1000o`1P0?ooo`00F03oool2003o00D0oooo1`00o`1X0?ooo`00
F@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06`0oooo001I0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0K03oool005P0oooo0P0000050?ooo`030000003oool0
oooo06`0oooo001O0?ooo`030000003oool0oooo06`0oooo001O0?ooo`030000003oool0oooo06`0
oooo001O0?ooo`030000003oool0oooo06`0oooo001O0?ooo`030000003oool0oooo06`0oooo001O
0?ooo`030000003oool0oooo06`0oooo003>0?ooo`00cP3oool00<h0oooo003>0?ooo`00cP3oool0
0<h0oooo003>0?ooo`00G@3oool2000006l0oooo001N0?ooo`030000003oool0oooo06d0oooo001O
0?ooo`030000003oool0oooo06`0oooo001N0?ooo`030000003oool0000006d0oooo001M0?ooo`04
0000003oool0oooo000006d0oooo001L0?ooo`<0000000<0oooo000000000000K03oool00<h0oooo
003>0?ooo`00cP3oool00<h0oooo0000\
\>"],
    ImageRangeCache->{{{0, 205}, {205, 0}} -> {-1, -1, 0, 0}}],
  "  ",
  StyleBox["\n\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 6.32",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003%5Cfuntheoremcalculus%\
5CFunTheoremCalculusMod%5CImages%5Cmat0632.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " shown in Examples 6.19 and 6.20."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 6.20.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" ",
    FontWeight->"Bold"],
  " Show that  ",
  Cell[BoxData[
      \(\[Integral]\_C\( 1\/z\) \[DifferentialD]z\  = \ 
        2\ \[Pi]\ \[ImaginaryI]\)]],
  ",  where ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is the unit circle  ",
  Cell[BoxData[
      \(C : \ \(\(|\)\(z\)\(|\)\) = 1\)]],
  ",  taken with positive orientation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  We let ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " be that circle with the point ",
  StyleBox["-1",
    FontFamily->"Courier New"],
  " omitted, as shown in Figure 6.32(b).  The contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is contained in the simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " of Example 6.19.  We know that  ",
  Cell[BoxData[
      \(f \((z)\) = 1\/z\)]],
  "  is analytic in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", and has an antiderivative  ",
  Cell[BoxData[
      \(F \((z)\) = Log \((z)\)\)]],
  ",  for all  ",
  Cell[BoxData[
      \(z\[Epsilon]\ D\)]],
  ".  Therefore, if we let ",
  Cell[BoxData[
      \(z\_2\)]],
  " approach ",
  StyleBox["-1",
    FontFamily->"Courier New"],
  " on ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " through the upper half-plane and ",
  Cell[BoxData[
      \(z\_1\)]],
  " approach ",
  StyleBox["-1",
    FontFamily->"Courier New"],
  " on ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " through the lower half-plane,  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_C\ \(1\/z\) \[DifferentialD]z\ \  = \ \(lim\+\ \
\)\+\(\(z\_2 \[Rule] \(-1\)\ \((\(z\_2\) \[Epsilon]\ C, Im\ z\_2 > \
0)\)\)\+\(z\_1 \[Rule] \(-1\)\ \((\(z\_1\) \[Epsilon]\ C, Im\ z\_1 < 0)\)\)\)\
\ \[Integral]\_\(z\_1\)\%\(z\_2\)\ \(1\/z\) \[DifferentialD]z\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(\(lim\+\ \
\)\+\(z\_2 \[Rule] \(-1\)\ \((\(z\_2\) \[Epsilon]\ C, Im\ z\_2 > 0)\)\)Log \
\((z\_2)\)\ \  - \ \ \ \(lim\+\ \)\+\(z\_1 \[Rule] \(-1\)\ \((\(z\_1\) \
\[Epsilon]\ C, Im\ z\_1 < 0)\)\)Log \((z\_1)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\[ImaginaryI]\ \
\[Pi]\ \  - \ \ \((\(-\[ImaginaryI]\)\ \[Pi])\)\)\)\(\ \ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(2  \[Pi]\ \
\[ImaginaryI]\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.20.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = 1\/z\)],
    AspectRatioFixed->True],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, Z];\)\ \), "\n", 
    \(\(Clear[f, g, path, val1, val2];\)\ \), "\n", 
    \(\(f[z_]\  = \ 1\/z;\)\ \), "\n", 
    \(\(Z\_0 = \(-1\) + \[ImaginaryI]\ 0.0208;\)\ \), "\n", 
    \(\(Z\_1 = \(-1\) - \[ImaginaryI]\ 0.0208;\)\ \), "\n", 
    \(\(g[z_]\  = \[Integral]f[z] \[DifferentialD]z;\)\ \), "\n", 
    \(\(z[\[Theta]_]\  = \ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\);\)\ \
\), "\n", 
    \(\(lim2\  = \ 
        Limit[g[z[\[Theta]]], \[Theta] \[Rule] \[Pi], 
          Direction \[Rule] 1];\)\ \), "\n", 
    \(\(lim1\  = \ 
        Limit[g[z[\[Theta]]], \[Theta] \[Rule] \(-\[Pi]\), 
          Direction \[Rule] \(-1\)];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<g[z] = \[Integral]\>", "\<(\>", 
        f[z], "\<)\[DifferentialD]z = \>", g[z]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(limit\_2\) = \!\(lim\+\(\[Theta] \[Rule] \[Pi]\)\) \
Log[\!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)] = \>\"", 
        lim2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(limit\_1\) = \!\(lim\+\(\[Theta] \[Rule] \
\(-\[Pi]\)\)\) Log[\!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)] = \>\"", 
        lim1];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<g[\>", 
        Re[Z\_1], \*"\"\<+ \[ImaginaryI] \!\(\(0\^+\)\)] = \>\"", 
        lim2, "\<,      g[\>", 
        Re[Z\_0], \*"\"\<+ \[ImaginaryI] \!\(\(0\^-\)\)] = \>\"", 
        lim1];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(path\  = \ 
        Graphics[{{Blue, PointSize[0.03], Point[{Re[Z\_0], Im[Z\_0]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_1], Im[Z\_1]}]}, \[IndentingNewLine]{Green, 
              Dashing[{0.031, 0.031}], \[IndentingNewLine]Circle[{0, 0}, 
                1, {\(-3.125\), 3.125}]\[IndentingNewLine]}}];\)\ \), "\n", 
    \(\(Show[path, PlotRange \[Rule] {{\(-1.1\), 1.1}, {\(-1.1\), 1.1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], 
            Range[\(-1\), 1, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\+C\)(\>\"", 
        f[z], \*"\"\<)\[DifferentialD]z = \!\(limit\_2\) - \!\(limit\_1\) = (\
\>\"", lim2, "\<) - (\>", lim1, "\<)\>"];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
      f[z], "\<) \[DifferentialD]z = \>", lim2 - lim1]\), "\n", 
    \(\(Print["\<The contour is the unit circle  C: |z| = 1.\>"];\)\ \)}], \
"Input",
  AspectRatioFixed->True],

Cell["\<\

Another approach is to parameterize the integrand.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(w\  = \ f[z[\[Theta]]] \(z'\)[\[Theta]];\)\ \), "\n", 
    \(\(G[\[Theta]_]\ \  = \ \[Integral]w\ \[DifferentialD]\[Theta];\)\ \), "\
\n", 
    \(\(val\  = \ G[\[Pi]]\  - \ G[\(-\[Pi]\)];\)\ \), "\n", 
    \(\(Print["\<         z[\[Theta]] = \>", \ z[\[Theta]]];\)\ \), "\n", 
    \(\(Print["\<        z'[\[Theta]] = \>", \ \(z'\)[\[Theta]]];\)\ \), "\n\
", 
    \(\(Print["\<         f[z] = \>", \ f[z]]\ ;\)\ \), "\n", 
    \(\(Print["\< f[z[\[Theta]]]z'[\[Theta]] = \>", \ 
        w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<  G[\[Theta]] = \[Integral]f[z[\[Theta]]]z'[\[Theta]]\
\[DifferentialD]\[Theta] = \[Integral](\>", 
        w, "\<)\[DifferentialD]\[Theta] = \>"\ , 
        G[\[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<  G[\[Pi]] = \>", \ G[\[Pi]], \ "\<,  G[-\[Pi]] = \>", 
        G[\(-\[Pi]\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\+C\)(\>\"", 
        f[z], "\<)\[DifferentialD]z = G[\[Pi]] - G[-\[Pi]] = (\>", 
        G[\[Pi]], "\<) - (\>", 
        G[\(-\[Pi]\)], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
      f[z], "\<) \[DifferentialD]z = \>", val]\), "\[IndentingNewLine]", 
    \(\(Print["\<The contour is the unit circle C: |z| = 1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that   ",
  Cell[BoxData[
      \(\[Integral]\_0\%\(2\  + \ \(\[ImaginaryI]\ \[Pi]\)\/4\)\(\
\[ExponentialE]\^z\) \[DifferentialD]z\ \  = \ \ \(\((1\  + \ \
\[ImaginaryI])\)\ \[ExponentialE]\^2\)\/\@2\  - \ 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.454545 0.0833333 0.833333 [
[.5 .07083 -3 -9 ]
[.5 .07083 3 0 ]
[.95455 .07083 -3 -9 ]
[.95455 .07083 3 0 ]
[1.025 .08333 0 -6.28125 ]
[1.025 .08333 10 6.28125 ]
[.03295 .41058 -16.1875 -9.125 ]
[.03295 .41058 0 9.125 ]
[.03295 .73783 -16.1875 -9.09375 ]
[.03295 .73783 0 9.09375 ]
[.04545 1.025 -5 0 ]
[.04545 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .08333 m
.5 .08958 L
s
[(1)] .5 .07083 0 1 Mshowa
.95455 .08333 m
.95455 .08958 L
s
[(2)] .95455 .07083 0 1 Mshowa
0 .08333 m
1 .08333 L
s
gsave
1.025 .08333 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.04545 .41058 m
.0517 .41058 L
s
gsave
.03295 .41058 -77.1875 -13.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.25 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 9.313 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.750 15.125 moveto
(\\200\\200) show
69.000 15.125 moveto
(\\200) show
71.063 15.125 moveto
(\\200) show
66.063 21.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.04545 .73783 m
.0517 .73783 L
s
gsave
.03295 .73783 -77.1875 -13.0938 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.1875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 9.313 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.750 15.125 moveto
(\\200\\200) show
69.000 15.125 moveto
(\\200) show
71.063 15.125 moveto
(\\200) show
66.063 21.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.04545 0 m
.04545 1 L
s
gsave
.04545 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 0 1 r
.035 w
.04545 .08333 Mdot
1 0 0 r
.95455 .73783 Mdot
0 1 0 r
.5 Mabswid
[ .03 .03 ] 0 setdash
.04545 .08333 m
.95455 .73783 L
s
% Start of user PostScript
0 0 2. 0.785398 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{172, 172},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002/0000[2000`400?l00000o`00003o[03oool0
0:`0oooo002/0?ooo`00[03oool00:`0oooo000B0?ooo`030000003oool0oooo09L0oooo000B0?oo
o`030000003oool0oooo09L0oooo000B0?ooo`030000003oool0oooo03d0oooo1@00000m0?ooo`@0
0000503oool00180oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo01D0oooo000B0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0D0?ooo`004P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool04`3oool00180oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0m0?ooo`040000003oool0oooo000001@0oooo000B0?ooo`030000003oool0oooo
03h0oooo0P0000100?ooo`8000005@3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo
00<000000?ooo`3oool0U`3oool00140oooo0`000?nH0?ooo`00403oool50000ohh0oooo0P000000
0`3oool00000000000040?ooo`002`3oool500000080003o00<00?l00000o`000?l0R@0000060?oo
o`030000003oool0000000D0oooo000@0?ooo`<0003o00<00?l00000o`3oool0?P3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00140oooo
0`000?l00`00o`00oooo0?ooo`2<0?ooo`80000000<0oooo000000000000103oool00180oooo00@0
00000?ooo`3oool00?l0UP3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo00<00000
0?ooo`3oool0103oool00`00o`00oooo0?ooo`2@0?ooo`004P3oool00`000000oooo0?ooo`050?oo
o`03003o003oool0oooo08l0oooo000B0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3o
ool0SP3oool00180oooo00<000000?ooo`3oool01`3oool00`00o`00oooo0?ooo`2=0?ooo`004P3o
ool00`000000oooo0?ooo`2G0?ooo`004P3oool00`000000oooo0?ooo`0;0?ooo`03003o003oool0
oooo08T0oooo000B0?ooo`030000003oool0oooo00`0oooo00<00?l00?ooo`3oool0R03oool00180
oooo00<000000?ooo`3oool03@3oool00`00o`00oooo0?ooo`270?ooo`004P3oool00`000000oooo
0?ooo`0>0?ooo`03003o003oool0oooo08H0oooo000B0?ooo`030000003oool0oooo09L0oooo000B
0?ooo`030000003oool0oooo0180oooo00<00?l00?ooo`3oool0PP3oool00180oooo00<000000?oo
o`3oool04`3oool00`00o`00oooo0?ooo`210?ooo`004P3oool00`000000oooo0?ooo`0D0?ooo`03
003o003oool0oooo0800oooo000B0?ooo`030000003oool0oooo01D0oooo00<00?l00?ooo`3oool0
O`3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0U`3oool0
0180oooo00<000000?ooo`3oool06@3oool00`00o`00oooo0?ooo`1k0?ooo`004P3oool00`000000
oooo0?ooo`0J0?ooo`800?l0N`3oool00180oooo00<000000?ooo`3oool0703oool00`00o`00oooo
0?ooo`1h0?ooo`004P3oool00`000000oooo0?ooo`2G0?ooo`004P3oool00`000000oooo0?ooo`2G
0?ooo`004P3oool00`000000oooo0?ooo`0P0?ooo`03003o003oool0oooo07@0oooo000B0?ooo`03
0000003oool0oooo0240oooo0P00o`1d0?ooo`004P3oool00`000000oooo0?ooo`0S0?ooo`800?l0
LP3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0U`3oool0
0180oooo00<000000?ooo`3oool09`3oool00`00o`00oooo0?ooo`1]0?ooo`004P3oool00`000000
oooo0?ooo`0X0?ooo`800?l0K@3oool00180oooo00<000000?ooo`3oool0:P3oool2003o06/0oooo
000B0?ooo`030000003oool0oooo09L0oooo000B0?ooo`030000003oool0oooo09L0oooo000B0?oo
o`030000003oool0oooo02h0oooo00<00?l00?ooo`3oool0IP3oool00180oooo00<000000?ooo`3o
ool0;`3oool2003o06H0oooo000B0?ooo`030000003oool0oooo0340oooo0P00o`1T0?ooo`004P3o
ool00`000000oooo0?ooo`2G0?ooo`004P3oool00`000000oooo0?ooo`2G0?ooo`001`3oool20000
00T0oooo00<000000?ooo`3oool0=@3oool00`00o`00oooo0?ooo`1O0?ooo`001P3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo03H0oooo00<00?l00?ooo`3oool0GP3oool000H0
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0g0?ooo`800?l0GP3oool000L0
oooo0P0000090?ooo`030000003oool0oooo03T0oooo00<00?l00?ooo`3oool0F`3oool000H0oooo
00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`2G0?ooo`001`3oool2000000T0oooo
00<000000?ooo`3oool0?03oool00`00o`00oooo0?ooo`1H0?ooo`004P3oool00`000000oooo0?oo
o`0m0?ooo`03003o003oool0oooo05L0oooo00030?ooo`@0000000<0oooo0000000000000P000006
0?ooo`030000003oool0oooo03h0oooo0P00o`1G0?ooo`004P3oool00`000000oooo0?ooo`100?oo
o`03003o003oool0oooo05@0oooo000B0?ooo`030000003oool0oooo09L0oooo000B0?ooo`030000
003oool0oooo04@0oooo00<00?l00?ooo`3oool0D03oool00180oooo00<000000?ooo`3oool0A@3o
ool00`00o`00oooo0?ooo`1?0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0AP3oool00`00o`00oooo0?ooo`1>0?ooo`001P3oool01000
0000oooo0?ooo`0000080?ooo`030000003oool0oooo04L0oooo00<00?l00?ooo`3oool0C@3oool0
00L0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`2G0?ooo`001`3oool00`000000
oooo000000080?ooo`030000003oool0oooo04/0oooo00<00?l00?ooo`3oool0B@3oool000H0oooo
1@0000070?ooo`030000003oool0oooo04`0oooo00<00?l00?ooo`3oool0B03oool00180oooo00<0
00000?ooo`3oool0C@3oool00`00o`00oooo0?ooo`170?ooo`004P3oool00`000000oooo0?ooo`1>
0?ooo`03003o003oool0oooo04H0oooo000B0?ooo`030000003oool0oooo09L0oooo000B0?ooo`03
0000003oool0oooo09L0oooo000B0?ooo`030000003oool0oooo0580oooo00<00?l00?ooo`3oool0
@P3oool00180oooo00<000000?ooo`3oool0D`3oool2003o0480oooo000B0?ooo`030000003oool0
oooo05D0oooo00<00?l00?ooo`3oool0?`3oool00180oooo00<000000?ooo`3oool0U`3oool00180
oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0F@3oool00`00o`00oooo
0?ooo`0k0?ooo`004P3oool00`000000oooo0?ooo`1J0?ooo`800?l0>`3oool00180oooo00<00000
0?ooo`3oool0G03oool00`00o`00oooo0?ooo`0h0?ooo`004P3oool00`000000oooo0?ooo`2G0?oo
o`004P3oool00`000000oooo0?ooo`2G0?ooo`004P3oool00`000000oooo0?ooo`1P0?ooo`03003o
003oool0oooo03@0oooo000B0?ooo`030000003oool0oooo0640oooo0P00o`0d0?ooo`004P3oool0
0`000000oooo0?ooo`1S0?ooo`800?l0<P3oool00180oooo00<000000?ooo`3oool0U`3oool00180
oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0I`3oool00`00o`00oooo
0?ooo`0]0?ooo`004P3oool00`000000oooo0?ooo`1X0?ooo`800?l0;@3oool00180oooo00<00000
0?ooo`3oool0JP3oool2003o02/0oooo000B0?ooo`030000003oool0oooo09L0oooo000B0?ooo`03
0000003oool0oooo09L0oooo000B0?ooo`030000003oool0oooo06h0oooo00<00?l00?ooo`3oool0
9P3oool00180oooo00<000000?ooo`3oool0K`3oool00`00o`00oooo0?ooo`0U0?ooo`004P3oool0
0`000000oooo0?ooo`1`0?ooo`800?l01@3oool2003o01h0oooo000B0?ooo`030000003oool0oooo
0780oooo00@00?l00?ooo`3oool0oooo1000o`0M0?ooo`004P3oool00`000000oooo0?ooo`1e0?oo
o`D00?l07@3oool00180oooo00<000000?ooo`3oool0M@3oool6003o01`0oooo000B0?ooo`030000
003oool0oooo07@0oooo2000o`0K0?ooo`00203oool3000000L0oooo00<000000?ooo`3oool0L`3o
ool:003o01X0oooo00090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0L`3oool;
003o01T0oooo00060?ooo`D000001`3oool00`000000oooo0?ooo`1d0?ooo`/00?l0603oool000H0
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`1g0?ooo`T00?l05`3oool000L0
oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`1i0?ooo`L00?l05`3oool000P0oooo
0P0000080?ooo`030000003oool0oooo07`0oooo1@00o`020?l001@0oooo000B0?ooo`030000003o
ool0oooo07h0oooo1000o`020?l001<0oooo00030?ooo`@0000000<0oooo0000000000000P000006
0?ooo`030000003oool0oooo07l0oooo0P3o00000`00o`00o`000?l0000C0?ooo`004P3oool00`00
0000oooo0?ooo`1o0?ooo`D0o`004`3oool00180oooo00<000000?ooo`3oool0P03oool30?l001@0
oooo000B0?ooo`030000003oool0oooo09L0oooo00050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`2G0?ooo`001P3oool010000000oooo0?ooo`00
00080?ooo`030000003oool0oooo09L0oooo00070?ooo`030000003oool0000000P0oooo00<00000
0?ooo`3oool0U`3oool000L0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`2G0?oo
o`001P3oool5000000L0oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0
U`3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0U`3oool0
0180oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo
00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo00<00000
0?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3o
ool0U`3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0U`3o
ool00180oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0U`3oool00180
oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo00<0
00000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?oo
o`3oool0U`3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0
U`3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0U`3oool0
0180oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo
00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo00<00000
0?ooo`3oool0U`3oool00180oooo00<000000?ooo`3oool0U`3oool00180oooo00<000000?ooo`3o
ool0U`3oool00:`0oooo002/0?ooo`00[03oool00:`0oooo002/0?ooo`00403oool2000009X0oooo
000A0?ooo`030000003oool0oooo09P0oooo000B0?ooo`030000003oool0oooo09L0oooo000A0?oo
o`030000003oool0000009P0oooo000@0?ooo`040000003oool0oooo000009P0oooo000?0?ooo`<0
000000<0oooo000000000000U`3oool00:`0oooo002/0?ooo`00[03oool00:`0oooo002/0?ooo`00
[03oool00:`0oooo002/0?ooo`00[03oool00001\
\>"],
    ImageRangeCache->{{{0, 171}, {171, 0}} -> {0, 0, 0, 0}}],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution for Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \[ExponentialE]\^z\)],
    AspectRatioFixed->True],
  "  and the initial point  ",
  Cell[BoxData[
      \(Z\_0 = 0\)],
    AspectRatioFixed->True],
  "  and terminal point  ",
  Cell[BoxData[
      \(Z\_1 = 2 + \(\[ImaginaryI]\ \[Pi]\)\/4\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, path, val1, val2];\)\ \), "\n", 
    \(\(f[z_]\  = \ \[ExponentialE]\^z;\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_1 = 2 + \(\[ImaginaryI]\ \[Pi]\)\/4;\)\ \), "\n", 
    \(\(g[z_]\  = \[Integral]f[z] \[DifferentialD]z;\)\ \), "\n", 
    \(\(val1\  = \ g[Z\_1]\  - \ g[Z\_0];\)\ \), "\n", 
    \(\(val2\  = \ \[Integral]\_\(Z\_0\)\%\(Z\_1\)f[
              z] \[DifferentialD]z;\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Arrow`\>"];\)\), "\[IndentingNewLine]", 
    \(\(path\  = \ 
        Graphics[{{Blue, PointSize[0.035], 
              Point[{Re[Z\_0], Im[Z\_0]}]}, {Red, PointSize[0.035], 
              Point[{Re[Z\_1], Im[Z\_1]}]}, \[IndentingNewLine]{Green, 
              Dashing[{0.03, 0.03}], 
              Arrow[{Re[Z\_0], Im[Z\_0]}, {Re[Z\_1], Im[Z\_1]}, 
                HeadScaling \[Rule] Absolute]}}];\)\ \), "\n", 
    \(\(Show[path, PlotRange \[Rule] {{\(-0.1\), 2.1}, {\(-0.1\), 1.1}}, 
        Ticks \[Rule] {Range[0, 2, 1], 
            Range[0, \[Pi]\/4, \[Pi]\/8]}, \[IndentingNewLine]AspectRatio \
\[Rule] 1, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[z] = \[Integral]\>", "\<(\>", 
        f[z], "\<)\[DifferentialD]z = \>", 
        g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[\>", Z\_1, "\<] = \>", g[Z\_1], "\<,      g[\>", 
        Z\_0, "\<] = \>", g[Z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<It is permissible to use the straight line path.\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]\>"\+\(Z\_0\)\%\(Z\_1\), "\<(\>", 
        f[z], "\<)\[DifferentialD]z = g[\>", Z\_1, "\<] - g[\>", 
        Z\_0, "\<]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<      = (\>", g[Z\_1]\ , "\<) - (\>", \ 
        g[Z\_0], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<      = (\>", ComplexExpand[g[Z\_1]]\ , "\<) - (\>", \ 
        ComplexExpand[g[Z\_0]], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<      = \>", 
        ComplexExpand[val1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]\>"\+\(Z\_0\)\%\(Z\_1\), "\<(\>", 
        f[z], "\<)\[DifferentialD]z = \>", 
        ComplexExpand[val2]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]\>"\+\(Z\_0\)\%\(Z\_1\), "\<(\>", 
        f[z], "\<)\[DifferentialD]z = (\>", 
        ComplexExpand[Re[val2]], "\<) + \[ImaginaryI](\>", 
        ComplexExpand[Im[val2]], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]\>"\+\(Z\_0\)\%\(Z\_1\), "\<(\>", 
        f[z], "\<)\[DifferentialD]z = \>", 
        N[val2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The integral could be computed parametrically as suggested in the textbook.\
\>", "Text"],

Cell[BoxData[{
    \(\(Remove[t];\)\ \), "\n", 
    \(\(F[
          t_] = \((2 + \(\[ImaginaryI]\ \[Pi]\)\/4)\) \(\[Integral]\(\
\[ExponentialE]\^\(2  
                      t + \[ImaginaryI]\ \[Pi]\ t/
                        4\)\) \[DifferentialD]t\);\)\), \
"\[IndentingNewLine]", 
    \(\(Fun = \[ExponentialE]\^\(2  t + \[ImaginaryI]\ \[Pi]\ t/4\);\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<F[t] = (2+\!\(\(\[ImaginaryI]\\\ \
\[Pi]\)\/4\))\[Integral](\>\"", Fun, "\<\[DifferentialD]t = \>", 
        F[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Val = F[1] - F[0]\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[1]-F[0] = (\>", F[1], "\<) - (\>", 
        F[0], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[1]-F[0] = \>", Val];\)\ \), "\n", 
    \(\(Print["\<F[1]-F[0] = \>", 
        Simplify[Val]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<(2+\!\(\(\[ImaginaryI]\\\ \[Pi]\)\/4\))\>\"", \
\*"\"\<\!\(\[Integral]\_0\%1\)\>\"", Fun, "\<\[DifferentialD]t = \>", 
        Simplify[Val]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<(2+\!\(\(\[ImaginaryI]\\\ \[Pi]\)\/4\))\>\"", \
\*"\"\<\!\(\[Integral]\_0\%1\)\>\"", Fun, "\<\[DifferentialD]t = \>", 
        ComplexExpand[Simplify[Val]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<(2+\!\(\(\[ImaginaryI]\\\ \[Pi]\)\/4\))\>\"", \
\*"\"\<\!\(\[Integral]\_0\%1\)\>\"", Fun, "\<\[DifferentialD]t = (\>", 
        Simplify[ComplexExpand[Re[Val]]], "\<) + \[ImaginaryI](\>", 
        Simplify[
          ComplexExpand[Im[Val]]], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<(2+\!\(\(\[ImaginaryI]\\\ \[Pi]\)\/4\))\>\"", \
\*"\"\<\!\(\[Integral]\_0\%1\)\>\"", Fun, "\<\[DifferentialD]t = \>", 
        N[Val]];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Fundamental Theorem of Calculus",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/FunTheoremCalculusBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{942, 646},
WindowMargins->{{17, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[4824, 153, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[11239, 338, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 99503, 2569}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 134, 2, 33, "Text"],
Cell[2239, 66, 1109, 30, 90, "Text",
  Evaluatable->False],
Cell[3351, 98, 1123, 39, 132, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4499, 141, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[4647, 147, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[4824, 153, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[5184, 165, 1547, 38, 110, "Text"],

Cell[CellGroupData[{
Cell[6756, 207, 102, 2, 33, "Text"],
Cell[6861, 211, 355, 14, 33, "Text"],
Cell[7219, 227, 2518, 48, 665, "Input"]
}, Closed]],
Cell[9752, 278, 212, 6, 30, "Text"],
Cell[9967, 286, 922, 36, 113, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[10914, 326, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[11062, 332, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[11239, 338, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[11599, 350, 384, 6, 49, "Text"],
Cell[11986, 358, 1084, 34, 84, "Text",
  Evaluatable->False],
Cell[13073, 394, 13671, 335, 190, "Text"],
Cell[26747, 731, 1726, 49, 194, "Text"],

Cell[CellGroupData[{
Cell[28498, 784, 112, 2, 33, "Text"],
Cell[28613, 788, 354, 14, 37, "Text"],
Cell[28970, 804, 2517, 48, 682, "Input"]
}, Closed]],
Cell[31502, 855, 779, 26, 31, "Text",
  Evaluatable->False],
Cell[32284, 883, 15192, 414, 192, "Text"],
Cell[47479, 1299, 1586, 36, 265, "Text"],

Cell[CellGroupData[{
Cell[49090, 1339, 112, 2, 33, "Text"],
Cell[49205, 1343, 335, 14, 33, "Text"],
Cell[49543, 1359, 2707, 49, 680, "Input"]
}, Closed]],
Cell[52265, 1411, 1317, 48, 113, "Text",
  Evaluatable->False],
Cell[53585, 1461, 16597, 328, 244, "Text"],
Cell[70185, 1791, 520, 19, 36, "Text",
  Evaluatable->False],
Cell[70708, 1812, 2122, 63, 262, "Text"],

Cell[CellGroupData[{
Cell[72855, 1879, 112, 2, 33, "Text"],
Cell[72970, 1883, 129, 6, 36, "Text"],
Cell[73102, 1891, 2634, 51, 642, "Input"],
Cell[75739, 1944, 123, 5, 52, "Text",
  Evaluatable->False],
Cell[75865, 1951, 1481, 28, 392, "Input"]
}, Closed]],
Cell[77361, 1982, 397, 12, 48, "Text",
  Evaluatable->False],
Cell[77761, 1996, 14336, 397, 191, "Text"],

Cell[CellGroupData[{
Cell[92122, 2397, 127, 2, 33, "Text"],
Cell[92252, 2401, 365, 14, 36, "Text"],
Cell[92620, 2417, 3094, 55, 760, "Input"],
Cell[95717, 2474, 99, 2, 33, "Text"],
Cell[95819, 2478, 1861, 34, 404, "Input"]
}, Closed]],
Cell[97695, 2515, 290, 7, 30, "Text"],
Cell[97988, 2524, 342, 11, 33, "Text"],
Cell[98333, 2537, 257, 5, 33, "Text"],
Cell[98593, 2544, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

