(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    171759,       4293]*)
(*NotebookOutlinePosition[    173092,       4339]*)
(*  CellTagsIndexPosition[    173015,       4333]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["6.5  Integral Representations for Analytic Functions",
  
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tWe now present some major results in the theory of functions of a \
complex variable.  The first result is known as ",
  StyleBox[ButtonBox["Cauchy's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " ",
  StyleBox[ButtonBox["integral formula",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CauchyIntegralFormula.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " and shows that the value of an analytic function ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " can be represented by a certain contour integral.  The  ",
  Cell[BoxData[
      \(n\^th\)]],
  "  derivative,  ",
  Cell[BoxData[
      \(\(f\^\((n)\)\) \((z)\)\)]],
  ",  will have a similar representation.  In Chapter 7, we use the Cauchy \
integral formulas to prove ",
  StyleBox[ButtonBox["Taylor's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Taylor.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " ",
  StyleBox[ButtonBox["theorem",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/TaylorsTheorem.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " and also establish the power series representation for analytic \
functions. The Cauchy integral formulas are a convenient tool for evaluating \
certain contour integrals."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Theorem 6.10 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Cauchy Integral Formula",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CauchyIntegralFormula.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " be analytic in the simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ",  and let ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " be a simple closed positively oriented contour that lies in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  If  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  is a point that lies interior to ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", then   \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z\_0)\)\ \  = \ \ \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \(\
\[Integral]\_C\(\( f \((z)\)\)\/\(z\  - \ z\_0\)\) \[DifferentialD]z\)\)]],
  ".   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.10 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.21.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Integral]\_C\( \[ExponentialE]\^z\/\(z\  - \ 
                  1\)\) \[DifferentialD]z\ \  = \ \ \[ImaginaryI]\ 2\ \[Pi]\ \
\[ExponentialE]\)]],
  ",  where ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is the circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 2\)]],
  "  with positive orientation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.5 0.238095 [
[.02381 .4875 -6 -9 ]
[.02381 .4875 6 0 ]
[.2619 .4875 -6 -9 ]
[.2619 .4875 6 0 ]
[.7381 .4875 -3 -9 ]
[.7381 .4875 3 0 ]
[.97619 .4875 -3 -9 ]
[.97619 .4875 3 0 ]
[1.025 .5 0 -6.28125 ]
[1.025 .5 10 6.28125 ]
[.4875 .02381 -12 -4.5 ]
[.4875 .02381 0 4.5 ]
[.4875 .2619 -12 -4.5 ]
[.4875 .2619 0 4.5 ]
[.4875 .7381 -6 -4.5 ]
[.4875 .7381 0 4.5 ]
[.4875 .97619 -6 -4.5 ]
[.4875 .97619 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .5 m
.02381 .50625 L
s
[(-2)] .02381 .4875 0 1 Mshowa
.2619 .5 m
.2619 .50625 L
s
[(-1)] .2619 .4875 0 1 Mshowa
.7381 .5 m
.7381 .50625 L
s
[(1)] .7381 .4875 0 1 Mshowa
.97619 .5 m
.97619 .50625 L
s
[(2)] .97619 .4875 0 1 Mshowa
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .02381 m
.50625 .02381 L
s
[(-2)] .4875 .02381 1 0 Mshowa
.5 .2619 m
.50625 .2619 L
s
[(-1)] .4875 .2619 1 0 Mshowa
.5 .7381 m
.50625 .7381 L
s
[(1)] .4875 .7381 1 0 Mshowa
.5 .97619 m
.50625 .97619 L
s
[(2)] .4875 .97619 1 0 Mshowa
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.03 w
.7381 .5 Mdot
0 g
gsave
.7381 .54762 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
newpath
.5 .5 .47619 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{175, 175},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002_0000[b000`400?l00000o`00003o[`3oool0
0540oooo00<000000?ooo`3oool0F`3oool00540oooo00<000000?ooo`3oool0F`3oool004X0oooo
100000030?ooo`030000003oool0oooo05/0oooo001:0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0F`3oool004T0oooo40000?mF0?ooo`00@P3oool70000o`<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`L0003oC`3oool003h0oooo10000?l80?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0303oool40000od/0oooo000k0?ooo`<0
003o3@3oool2000000@0oooo00<000000?ooo`3oool0403oool40000odL0oooo000g0?ooo`@0003o
5P3oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo04@0oooo000e0?ooo`80003o6P3o
ool00`000000oooo0?ooo`0E0?ooo`@0003o@P3oool003@0oooo00<0003o0?ooo`3oool06P3oool0
0`000000oooo0?ooo`0I0?ooo`80003o@03oool00300oooo10000?lM0?ooo`030000003oool0oooo
01/0oooo0`000?lm0?ooo`00;`3oool00`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo01h0
oooo0P000?lk0?ooo`00;@3oool20000ob80oooo00<000000?ooo`3oool0803oool00`000?l0oooo
0?ooo`0h0?ooo`00:`3oool20000ob@0oooo00<000000?ooo`3oool08@3oool20000ocP0oooo000Z
0?ooo`030000o`3oool0oooo02@0oooo00<000000?ooo`3oool08`3oool20000ocH0oooo000X0?oo
o`80003o9`3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo03<0oooo000W0?ooo`03
0000o`3oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000oc<0oooo000U0?ooo`80003o
:P3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0300oooo000S0?ooo`80003o;03o
ool00`000000oooo0?ooo`0Y0?ooo`80003o<03oool00280oooo00<0003o0?ooo`3oool0;03oool0
0`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo02d0oooo000Q0?ooo`030000o`3oool0oooo
02d0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0/0?ooo`00803oool00`000?l0
oooo0?ooo`0^0?ooo`030000003oool0oooo02d0oooo00<0003o0?ooo`3oool0:`3oool001l0oooo
00<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo02X0oooo
000N0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0;`3oool20000obX0oooo000M
0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0W
0?ooo`00703oool00`000?l0oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<0003o0?oo
o`3oool09P3oool001/0oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`03
0000o`3oool0oooo02H0oooo000J0?ooo`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool0
<`3oool00`000?l0oooo0?ooo`0U0?ooo`006@3oool00`000?l0oooo0?ooo`0e0?ooo`030000003o
ool0oooo03@0oooo00<0003o0?ooo`3oool0903oool001T0oooo00<0003o0?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0e0?ooo`030000o`3oool0oooo02<0oooo000H0?ooo`030000o`3oool0oooo
03H0oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`0R0?ooo`005`3oool00`000?l0
oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<0003o0?ooo`3oool08@3oool001H0oooo
00<0003o0?ooo`3oool0>03oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo0240oooo
000E0?ooo`030000o`3oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000?l0oooo0?oo
o`0P0?ooo`00503oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo03T0oooo00<0003o
0?ooo`3oool07`3oool001<0oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0i0?oo
o`030000o`3oool0oooo01l0oooo000C0?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3o
ool0>P3oool00`000?l0oooo0?ooo`0N0?ooo`004P3oool00`000?l0oooo0?ooo`0l0?ooo`030000
003oool0oooo03/0oooo00<0003o0?ooo`3oool07@3oool00140oooo00<0003o0?ooo`3oool0=P3o
ool500000080oooo00<000000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`0M0?ooo`004@3oool0
0`000?l0oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool0
0`000?l0oooo0?ooo`0L0?ooo`00403oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo
0080oooo0P00000n0?ooo`030000o`3oool0oooo01/0oooo000?0?ooo`030000o`3oool0oooo0380
oooo100000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?@3oool00`000?l0
oooo0?ooo`0K0?ooo`003`3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0?P3oool00`000?l0oooo0?ooo`0J0?ooo`003P3oool00`000?l0oooo0?oo
o`0j0?ooo`800000103oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo01X0oooo000>
0?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0I
0?ooo`003@3oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo0400oooo00<0003o0?oo
o`3oool0603oool000d0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`03
0000o`3oool0oooo01P0oooo000=0?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0
@@3oool00`000?l0oooo0?ooo`0G0?ooo`00303oool00`000?l0oooo0?ooo`120?ooo`030000003o
ool0oooo0440oooo00<0003o0?ooo`3oool05`3oool000`0oooo00<0003o0?ooo`3oool0@P3oool0
0`000000oooo0?ooo`110?ooo`030000o`3oool0oooo01L0oooo000;0?ooo`030000o`3oool0oooo
04<0oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0F0?ooo`002`3oool00`000?l0
oooo0?ooo`130?ooo`030000003oool0oooo0480oooo00<0003o0?ooo`3oool05P3oool000/0oooo
00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`130?ooo`030000o`3oool0oooo01D0oooo
000:0?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?oo
o`0E0?ooo`002P3oool00`000?l0oooo0?ooo`140?ooo`030000003oool0oooo04<0oooo00<0003o
0?ooo`3oool05@3oool000T0oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`130?oo
o`030000o`3oool0oooo01D0oooo00090?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3o
ool0A03oool00`000?l0oooo0?ooo`0D0?ooo`002@3oool00`000?l0oooo0?ooo`150?ooo`030000
003oool0oooo04D0oooo00<0003o0?ooo`3oool04`3oool000P0oooo00<0003o0?ooo`3oool0AP3o
ool00`000000oooo0?ooo`150?ooo`030000o`3oool0oooo01<0oooo00080?ooo`030000o`3oool0
oooo04H0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`0C0?ooo`00203oool00`00
0?l0oooo0?ooo`160?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool04`3oool000P0
oooo00<0003o0?ooo`3oool0AP3oool00`000000oooo0?ooo`150?ooo`030000o`3oool0oooo01<0
oooo00080?ooo`030000o`3oool0oooo04H0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo
0?ooo`0C0?ooo`00203oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo04H0oooo00<0
003o0?ooo`3oool04P3oool000L0oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`16
0?ooo`030000o`3oool0oooo0180oooo00070?ooo`030000o`3oool0oooo04L0oooo00<000000?oo
o`3oool0AP3oool00`000?l0oooo0?ooo`0B0?ooo`001`3oool00`000?l0oooo0?ooo`170?ooo`03
0000003oool0oooo04H0oooo00<0003o0?ooo`3oool04P3oool000L0oooo00<0003o0?ooo`3oool0
A`3oool00`000000oooo0?ooo`160?ooo`030000o`3oool0oooo0180oooo00070?ooo`040000o`00
0000000000000240oooo1@00000P0?ooo`030000003oool0oooo0200oooo1@00000P0?ooo`800000
00<0003o0000003oool04@3oool000H0oooo00<0003o0000003oool09@3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0803oool00`000000oooo0000
o`0C0?ooo`001P3oool00`000?l0oooo0000000U0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`03000000000?l0oooo0180oooo00000`3o
ool0000000000002000000050?ooo`000?l0oooo0?ooo`000000703oool4000000@0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<0003o
0?ooo`3oool04@3oool000H0oooo00D0003o0000003oool0oooo0000000S0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0P0?ooo`040000003oool0
003o00000180oooo00060?ooo`040000o`3oool00000000002<0oooo0P00000R0?ooo`030000003o
ool0oooo0240oooo0P00000S0?ooo`03000000000?l0oooo0180oooo00060?ooo`030000o`3oool0
oooo04P0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0A0?ooo`001P3oool00`00
0?l0oooo0?ooo`180?ooo`030000003oool0oooo04L0oooo00<0003o0?ooo`3oool04@3oool000H0
oooo00<0003o0?ooo`3oool0B03oool00`000000oooo0?ooo`0Q0?ooo`80o`00903oool00`000?l0
oooo0?ooo`070?ooo`80000000<0oooo0000000000001@3oool000H0oooo00<0003o0?ooo`3oool0
B03oool00`000000oooo0?ooo`0P0?ooo`@0o`008`3oool00`000?l0oooo0?ooo`080?ooo`030000
003oool0000000H0oooo00020?ooo`@0000000<0003o000000000000J`0000040?l002<0000000<0
003o0000000000000P0000070?ooo`030000003oool0oooo00D0oooo00060?ooo`030000o`3oool0
oooo0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Q0?ooo`80o`00903oool0
0`000?l0oooo0?ooo`070?ooo`80000000<0oooo0000000000001@3oool000H0oooo00<0003o0?oo
o`3oool0B03oool00`000000oooo0?ooo`170?ooo`030000o`3oool0oooo0140oooo00060?ooo`03
0000o`3oool0oooo04P0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0A0?ooo`00
1P3oool00`000?l0oooo0?ooo`180?ooo`030000003oool0oooo02/0oooo1@00000G0?ooo`030000
o`3oool0oooo0140oooo00060?ooo`030000o`3oool0oooo04P0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0140oooo00060?ooo`030000o`3oool0
oooo04P0oooo00<000000?ooo`3oool09@3oool5000000<0oooo00<000000?ooo`3oool05`3oool0
0`000?l0oooo0?ooo`0A0?ooo`001P3oool00`000?l0oooo0?ooo`180?ooo`030000003oool0oooo
02H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0G0?ooo`030000o`3oool0
oooo0140oooo00060?ooo`030000o`3oool0oooo04P0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<0003o0?ooo`3oool04@3oool000L0
oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`0X0?ooo`040000003oool0oooo0?oo
o`8000006@3oool00`000?l0oooo0?ooo`0A0?ooo`001`3oool00`000?l0oooo0?ooo`170?ooo`03
0000003oool0oooo02H0oooo00@000000?ooo`3oool00000703oool00`000?l0oooo0?ooo`0B0?oo
o`001`3oool00`000?l0oooo0?ooo`170?ooo`030000003oool0oooo02H0oooo1@00000K0?ooo`03
0000o`3oool0oooo0180oooo00070?ooo`030000o`3oool0oooo04L0oooo00<000000?ooo`3oool0
AP3oool00`000?l0oooo0?ooo`0B0?ooo`001`3oool00`000?l0oooo0?ooo`170?ooo`030000003o
ool0oooo04H0oooo00<0003o0?ooo`3oool04P3oool000P0oooo00<0003o0?ooo`3oool0AP3oool0
0`000000oooo0?ooo`160?ooo`030000o`3oool0oooo0180oooo00080?ooo`030000o`3oool0oooo
04H0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`0C0?ooo`00203oool00`000?l0
oooo0?ooo`160?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool04`3oool000P0oooo
00<0003o0?ooo`3oool0AP3oool00`000000oooo0?ooo`150?ooo`030000o`3oool0oooo01<0oooo
00080?ooo`030000o`3oool0oooo04H0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?oo
o`0C0?ooo`00203oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo04D0oooo00<0003o
0?ooo`3oool04`3oool000T0oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`150?oo
o`030000o`3oool0oooo01<0oooo00090?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3o
ool0A03oool00`000?l0oooo0?ooo`0D0?ooo`002@3oool00`000?l0oooo0?ooo`150?ooo`030000
003oool0oooo04@0oooo00<0003o0?ooo`3oool0503oool000X0oooo00<0003o0?ooo`3oool0A03o
ool00`000000oooo0?ooo`130?ooo`030000o`3oool0oooo01D0oooo000:0?ooo`030000o`3oool0
oooo04@0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0E0?ooo`002`3oool00`00
0?l0oooo0?ooo`130?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool05@3oool000/0
oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`120?ooo`030000o`3oool0oooo01H0
oooo000;0?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo
0?ooo`0F0?ooo`002`3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo0440oooo00<0
003o0?ooo`3oool05`3oool000`0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`11
0?ooo`030000o`3oool0oooo01L0oooo000=0?ooo`030000o`3oool0oooo0440oooo00<000000?oo
o`3oool0@@3oool00`000?l0oooo0?ooo`0G0?ooo`003@3oool00`000?l0oooo0?ooo`110?ooo`03
0000003oool0oooo0400oooo00<0003o0?ooo`3oool0603oool000d0oooo00<0003o0?ooo`3oool0
@@3oool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo01P0oooo000=0?ooo`030000o`3o
ool0oooo0440oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0I0?ooo`003P3oool0
0`000?l0oooo0?ooo`100?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool06@3oool0
00l0oooo00<0003o0?ooo`3oool0>03oool500000080oooo00<000000?ooo`3oool0?P3oool00`00
0?l0oooo0?ooo`0J0?ooo`003`3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0K0?ooo`00403oool00`000?l0oooo
0?ooo`0i0?ooo`030000003oool0oooo0080oooo0P00000n0?ooo`030000o`3oool0oooo01/0oooo
000@0?ooo`030000o`3oool0oooo03T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0l0?ooo`030000o`3oool0oooo01`0oooo000A0?ooo`030000o`3oool0oooo03P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0l0?ooo`030000o`3oool0oooo01`0oooo000B0?oo
o`030000o`3oool0oooo03H0oooo0P0000040?ooo`030000003oool0oooo03/0oooo00<0003o0?oo
o`3oool07@3oool00180oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`0j0?ooo`03
0000o`3oool0oooo01h0oooo000C0?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0
>P3oool00`000?l0oooo0?ooo`0N0?ooo`00503oool00`000?l0oooo0?ooo`0j0?ooo`030000003o
ool0oooo03T0oooo00<0003o0?ooo`3oool07`3oool001@0oooo00<0003o0?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo01l0oooo000E0?ooo`030000o`3oool0oooo
03T0oooo00<000000?ooo`3oool0>03oool00`000?l0oooo0?ooo`0P0?ooo`005P3oool00`000?l0
oooo0?ooo`0h0?ooo`030000003oool0oooo03L0oooo00<0003o0?ooo`3oool08@3oool001H0oooo
00<0003o0?ooo`3oool0>03oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo0240oooo
000G0?ooo`030000o`3oool0oooo03L0oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo0?oo
o`0R0?ooo`00603oool20000ocL0oooo00<000000?ooo`3oool0=03oool20000obD0oooo000J0?oo
o`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`0U0?oo
o`006`3oool00`000?l0oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3o
ool09P3oool001`0oooo00<0003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000
o`3oool0oooo02H0oooo000M0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0<@3o
ool00`000?l0oooo0?ooo`0W0?ooo`007P3oool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0
oooo0300oooo00<0003o0?ooo`3oool0:03oool001h0oooo00<0003o0?ooo`3oool0<03oool00`00
0000oooo0?ooo`0_0?ooo`030000o`3oool0oooo02T0oooo000O0?ooo`030000o`3oool0oooo02l0
oooo00<000000?ooo`3oool0;P3oool00`000?l0oooo0?ooo`0Z0?ooo`00803oool20000obl0oooo
00<000000?ooo`3oool0;03oool20000obd0oooo000R0?ooo`030000o`3oool0oooo02`0oooo00<0
00000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`0]0?ooo`008`3oool20000ob`0oooo00<00000
0?ooo`3oool0:@3oool20000oc00oooo000U0?ooo`030000o`3oool0oooo02T0oooo00<000000?oo
o`3oool0:03oool00`000?l0oooo0?ooo`0`0?ooo`009P3oool20000obT0oooo00<000000?ooo`3o
ool09`3oool00`000?l0oooo0?ooo`0a0?ooo`00:03oool00`000?l0oooo0?ooo`0V0?ooo`030000
003oool0oooo02D0oooo0P000?ld0?ooo`00:@3oool20000obH0oooo00<000000?ooo`3oool0903o
ool00`000?l0oooo0?ooo`0d0?ooo`00:`3oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0
oooo0280oooo0P000?lg0?ooo`00;03oool20000ob<0oooo00<000000?ooo`3oool0803oool20000
ocT0oooo000^0?ooo`80003o8@3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo03T0
oooo000`0?ooo`030000o`3oool0oooo01h0oooo00<000000?ooo`3oool07@3oool20000oc`0oooo
000a0?ooo`@0003o703oool00`000000oooo0?ooo`0J0?ooo`<0003o?P3oool003D0oooo00<0003o
0?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`80003o@@3oool003H0oooo10000?lG0?oo
o`030000003oool0oooo01@0oooo10000?m30?ooo`00>P3oool30000oa@0oooo00<000000?ooo`3o
ool04@3oool30000odL0oooo000m0?ooo`@0003o2@3oool4000000<0oooo00<000000?ooo`3oool0
3@3oool40000odX0oooo00110?ooo`H0003o0`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00P0oooo1@000?m>0?ooo`00A`3ooolE0000oe<0oooo001<0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0F`3oool004X0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`1K0?ooo`00B`3oool2000000@0oooo00<000000?ooo`3oool0F`3oool00540oooo
00<000000?ooo`3oool0F`3oool00:l0oooo002_0?ooo`00[`3oool00:l0oooo002_0?ooo`00[`3o
ool004l0oooo0P00001N0?ooo`00D03oool00`000000oooo0?ooo`1L0?ooo`00D@3oool00`000000
oooo0?ooo`1K0?ooo`00D03oool00`000000oooo0000001L0?ooo`00C`3oool010000000oooo0?oo
o`00001L0?ooo`00CP3oool3000000030?ooo`000000000005/0oooo002_0?ooo`00[`3oool00:l0
oooo002_0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 174}, {174, 0}} -> {-2, -2, 0, 0}}],
  "   "
}], "Text"],

Cell[TextData[{
  "Solution.  We have  ",
  Cell[BoxData[
      \(f \((z)\) = \[ExponentialE]\^z\)]],
  "  and  ",
  Cell[BoxData[
      \(f \((1)\) = \[ExponentialE]\)]],
  ".  The point  ",
  Cell[BoxData[
      \(z\_0 = 1\)]],
  "  lies interior to the circle, so Cauchy's integral formula implies that  \
\n\n\t\t\t",
  Cell[BoxData[
      \(\[ExponentialE]\  = \ \(f \((1)\)\  = \ \(\(1\/\(2  \[Pi]\ \
\[ImaginaryI]\)\) \(\[Integral]\_C\(\( f \((z)\)\)\/\(z\  - \ 
                        z\_0\)\) \[DifferentialD]z\)\  = \ \(1\/\(2  \[Pi]\ \
\[ImaginaryI]\)\) \(\[Integral]\_C\( \[ExponentialE]\^z\/\(z\  - \ 
                        1\)\) \[DifferentialD]z\)\)\)\)]],
  ",  \n\nand multiplication by  ",
  Cell[BoxData[
      \(2  \[Pi]\ \[ImaginaryI]\)]],
  "  establishes the desired result."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the integrand  ",
  Cell[BoxData[
      \(w[z] = \[ExponentialE]\^z\/\(z\  - \ 1\)\)],
    AspectRatioFixed->True],
  "  and locate the singularities."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[w, z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, i, solset, val];\)\ \), "\n", 
    \(\(w[z_]\  = \ \[ExponentialE]\^z\/\(z - 1\);\)\ \), "\n", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[w[z]] \[Equal] 0, z]];\)\ \), "\n", 
    \(\(Z\  = \ Table[0, {Length[solset]}];\)\ \), "\n", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[solset], \(i++\), \[IndentingNewLine]\(Z\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
            ReplaceAll[z, 
              solset\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\
\)];\)\ ];\)\ \), "\n", 
    \(\(Print["\<w[z] = \>", w[z]];\)\ \), "\n", 
    \(\(Print["\<The set of singularities is \>", 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Find the singularity that lie inside  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(Print[\*"\"\<\!\(z\_1\) = \>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<,   \
 Is |\>", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<| < \
2 ?    \>", 
        N[Abs[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]] \
< 2];\)\(\ \)\(\[IndentingNewLine]\)
    \)\)], "Input",
  AspectRatioFixed->True],

Cell["The function f(z) in the numerator ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_]\  = \ 
        w[z]\ \((z\  - \ 
              Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\))\)\
;\)\ \), "\n", 
    \(\(Print["\<w[z] = \>", w[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[z] = (\>", f[z], "\<)/(\>", 
        z\  - \ Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\),\
 "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use Cauchy's Integral Formula to evaluate the integral of  ",
  Cell[BoxData[
      \(w[z] = \[ExponentialE]\^z\/\(z\  - \ 1\)\)],
    AspectRatioFixed->True],
  " taken over",
  " ",
  StyleBox["C",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(val\  = \ 
        2\ \[Pi]\ \[ImaginaryI]\ f[
            Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[z] = \>", "\<f[z]\>"\/\(z\  - \ \
Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\ \
\), "\n", 
    \(\(Print[\*"\"\<f[\!\(z\_1\)] = \>\"", \ 
        f[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Use Cauchy's Integral Formula\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\)\!\(\(f \((z)\)\)\/\(z - z\_1\)\)\
\[DifferentialD]z = 2\[Pi]\[ImaginaryI] f(\!\(z\_1\))\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        w[z], "\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI] f[\>", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<] = \
2\[Pi]\[ImaginaryI](\>", 
        f[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)], \
"\<) = \>", val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Thus, we have found the value of the contour integral.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{Red, PointSize[0.03], 
            Point[{Re[
                  Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)], Im[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]}]}];\)\
\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[
              StyleForm[TraditionalForm[\*"\"\<\!\(z\_1\)\>\""], 
                FontSize \[Rule] 12], {Re[
                  Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)], Im[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)] + 
                  0.2}, {\(-1\), 0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 2]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-2.1\), 2.1}, {\(-2.1\), 2.1}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
      w[z], "\<) \[DifferentialD]z = \>", val]\), "\[IndentingNewLine]", 
    \(\(Print["\<The contour is the circle  C: |z| = 2,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<with positive orientation.\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.22.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Integral]\_C\(\( 
                  sin \((z)\)\)\/\(4  
                    z\  + \ \ \[Pi]\)\) \[DifferentialD]z\ \  = \ \ \(-\ \
\[ImaginaryI]\) \(\(\ \)\(\[Pi] \@ 2\)\)\/4\)]],
  ",  where",
  " ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is the circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 1\)]],
  "  with positive orientation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.454545 0.5 0.454545 [
[.143 .4875 -11.4063 -18.1875 ]
[.143 .4875 11.4063 0 ]
[.95455 .4875 -3 -9 ]
[.95455 .4875 3 0 ]
[1.025 .5 0 -6.28125 ]
[1.025 .5 10 6.28125 ]
[.4875 .04545 -12 -4.5 ]
[.4875 .04545 0 4.5 ]
[.4875 .95455 -6 -4.5 ]
[.4875 .95455 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.143 .5 m
.143 .50625 L
s
gsave
.143 .4875 -72.4063 -22.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.1875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 15.125 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 9.313 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
71.375 15.125 moveto
(\\200\\200) show
75.625 15.125 moveto
(\\200) show
77.688 15.125 moveto
(\\200) show
72.688 21.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.95455 .5 m
.95455 .50625 L
s
[(1)] .95455 .4875 0 1 Mshowa
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .04545 m
.50625 .04545 L
s
[(-1)] .4875 .04545 1 0 Mshowa
.5 .95455 m
.50625 .95455 L
s
[(1)] .4875 .95455 1 0 Mshowa
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.03 w
.143 .5 Mdot
0 g
gsave
.143 .54545 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
newpath
.5 .5 .45455 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{175, 175},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002_0000[b000`400?l00000o`00003oD03oool0
0`000000oooo0?ooo`1L0?ooo`00D03oool00`000000oooo0?ooo`1L0?ooo`00D03oool00`000000
oooo0?ooo`1L0?ooo`00D03oool00`000000oooo0?ooo`1L0?ooo`00D03oool00`000000oooo0?oo
o`1L0?ooo`00D03oool00`000000oooo0?ooo`1L0?ooo`00B@3oool500000080oooo00<000000?oo
o`3oool0G03oool004/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1L0?ooo`00
A@3ooolF0000oe@0oooo00100?ooo`D0003o0P0000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool50000odl0oooo000l0?ooo`@0003o2`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00d0oooo10000?m;0?ooo`00>@3oool30000o`h0oooo0P0000040?oo
o`030000003oool0oooo0140oooo0`000?m80?ooo`00=`3oool20000oaL0oooo00<000000?ooo`3o
ool0503oool20000odH0oooo000d0?ooo`<0003o6@3oool00`000000oooo0?ooo`0F0?ooo`<0003o
@`3oool00380oooo0P000?lL0?ooo`030000003oool0oooo01T0oooo0P000?m10?ooo`00<03oool2
0000oah0oooo00<000000?ooo`3oool06`3oool20000ocl0oooo000]0?ooo`<0003o803oool00`00
0000oooo0?ooo`0M0?ooo`<0003o?03oool002`0oooo00<0003o0?ooo`3oool08@3oool00`000000
oooo0?ooo`0P0?ooo`030000o`3oool0oooo03T0oooo000Z0?ooo`80003o903oool00`000000oooo
0?ooo`0Q0?ooo`80003o>@3oool002T0oooo00<0003o0?ooo`3oool0903oool00`000000oooo0?oo
o`0S0?ooo`030000o`3oool0oooo03H0oooo000W0?ooo`80003o9`3oool00`000000oooo0?ooo`0T
0?ooo`80003o=P3oool002H0oooo00<0003o0?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?oo
o`030000o`3oool0oooo03<0oooo000T0?ooo`80003o:P3oool00`000000oooo0?ooo`0W0?ooo`80
003o<`3oool002<0oooo00<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000
o`3oool0oooo0300oooo000R0?ooo`030000o`3oool0oooo02/0oooo00<000000?ooo`3oool0:P3o
ool00`000?l0oooo0?ooo`0_0?ooo`008@3oool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0
oooo02/0oooo00<0003o0?ooo`3oool0;P3oool00200oooo00<0003o0?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo02d0oooo000O0?ooo`030000o`3oool0oooo02h0
oooo00<000000?ooo`3oool0;@3oool20000obd0oooo000N0?ooo`030000o`3oool0oooo02l0oooo
00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0Z0?ooo`007@3oool00`000?l0oooo0?oo
o`0`0?ooo`030000003oool0oooo0300oooo00<0003o0?ooo`3oool0:@3oool001`0oooo00<0003o
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0oooo02T0oooo000K0?oo
o`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0X0?oo
o`006P3oool00`000?l0oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3o
ool09`3oool001T0oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000
o`3oool0oooo02H0oooo000H0?ooo`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0=03o
ool00`000?l0oooo0?ooo`0U0?ooo`005`3oool00`000?l0oooo0?ooo`0f0?ooo`030000003oool0
oooo03D0oooo00<0003o0?ooo`3oool0903oool001H0oooo00<0003o0?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0f0?ooo`030000o`3oool0oooo02<0oooo000E0?ooo`030000o`3oool0oooo03P0
oooo00<000000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0R0?ooo`005@3oool00`000?l0oooo
0?ooo`0h0?ooo`030000003oool0oooo03L0oooo00<0003o0?ooo`3oool08P3oool001@0oooo00<0
003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo0240oooo000C
0?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`0P
0?ooo`004`3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo03T0oooo00<0003o0?oo
o`3oool0803oool00180oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`03
0000o`3oool0oooo01l0oooo000B0?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0
>`3oool00`000?l0oooo0?ooo`0N0?ooo`004@3oool00`000?l0oooo0?ooo`0l0?ooo`030000003o
ool0oooo03/0oooo00<0003o0?ooo`3oool07P3oool00140oooo00<0003o0?ooo`3oool0?03oool0
0`000000oooo0?ooo`0k0?ooo`030000o`3oool0oooo01h0oooo000@0?ooo`030000o`3oool0oooo
03d0oooo00<000000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`0N0?ooo`00403oool00`000?l0
oooo0?ooo`0m0?ooo`030000003oool0oooo03`0oooo00<0003o0?ooo`3oool07@3oool000l0oooo
00<0003o0?ooo`3oool0?P3oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo01`0oooo
000>0?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0?oo
o`0L0?ooo`003P3oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo03h0oooo00<0003o
0?ooo`3oool06`3oool000h0oooo00<0003o0?ooo`3oool0?`3oool00`000000oooo0?ooo`0o0?oo
o`030000o`3oool0oooo01X0oooo000=0?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3o
ool0?`3oool00`000?l0oooo0?ooo`0J0?ooo`003@3oool00`000?l0oooo0?ooo`100?ooo`030000
003oool0oooo03l0oooo00<0003o0?ooo`3oool06P3oool000`0oooo00<0003o0?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0oooo01X0oooo000<0?ooo`030000o`3oool0
oooo0440oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0I0?ooo`00303oool00`00
0?l0oooo0?ooo`110?ooo`030000003oool0oooo0400oooo00<0003o0?ooo`3oool06@3oool000/0
oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo01T0
oooo000;0?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo
0?ooo`0H0?ooo`002`3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo0440oooo00<0
003o0?ooo`3oool0603oool000/0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`11
0?ooo`030000o`3oool0oooo01P0oooo000:0?ooo`030000o`3oool0oooo00h0oooo0`00000b0?oo
o`030000003oool0oooo0440oooo00<0003o0?ooo`3oool0603oool000X0oooo00<0003o0?ooo`3o
ool03`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0480oooo00<0003o0?ooo`3o
ool05`3oool000X0oooo00<0003o0?ooo`3oool0303oool500000380oooo00<000000?ooo`3oool0
@P3oool00`000?l0oooo0?ooo`0G0?ooo`002@3oool00`000?l0oooo0?ooo`0=0?ooo`040000003o
ool0oooo000003<0oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0G0?ooo`002@3o
ool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0000003<0oooo00<000000?ooo`3oool0@`3o
ool00`000?l0oooo0?ooo`0F0?ooo`002@3oool00`000?l0oooo0?ooo`0?0?ooo`800000<`3oool0
0`000000oooo0?ooo`130?ooo`030000o`3oool0oooo01H0oooo00090?ooo`030000o`3oool0oooo
04@0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0F0?ooo`002@3oool00`000?l0
oooo0?ooo`030?ooo`@000000`3oool4000000030?ooo`000000000000800000<@3oool00`000000
oooo0?ooo`130?ooo`030000o`3oool0oooo01H0oooo00090?ooo`030000o`3oool0oooo04@0oooo
00<000000?ooo`3oool0@P3oool00`000000003o00000002000001D0oooo00080?ooo`030000o`3o
ool0oooo04D0oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`0E0?ooo`00203oool0
0`000?l0oooo0?ooo`150?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool05@3oool0
00P0oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`140?ooo`030000o`3oool0oooo
01D0oooo00080?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool05@3oool000P0oooo
00<0003o0?ooo`3oool03P3oool010000000oooo0?ooo`00000c0?ooo`030000003oool0oooo04<0
oooo00<000000000o`3oool05P3oool000P0oooo00<0003o0?ooo`3oool03`3oool00`000000oooo
0000000c0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool05@3oool000P0oooo00<0
003o0?ooo`3oool03`3oool00`000000oooo0000000c0?ooo`030000003oool0oooo04@0oooo00<0
003o0?ooo`3oool05@3oool000P0oooo00<0003o0?ooo`3oool03P3oool500000380oooo00<00000
0?ooo`3oool0A03oool00`000?l0oooo0?ooo`0E0?ooo`00203oool00`000?l0oooo0?ooo`0;0?oo
o`80o`00>03oool00`000000oooo0?ooo`140?ooo`030000o`3oool0oooo00X0oooo0P0000000`3o
ool00000000000060?ooo`0000<0oooo0000000000001@0000000`000?l000000000000:000000@0
o`00OP0000000`000?l0000000000005000000H0oooo00<000000?ooo`0000001`3oool000P0oooo
00<0003o0?ooo`3oool02P3oool40?l003L0oooo00<000000?ooo`3oool0A03oool00`000?l0oooo
0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000o`3oool0oooo00/0oooo0P3o
000h0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool02P3oool2000000030?ooo`00
0000000000H0oooo00080?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool0A03oool0
0`000?l0oooo0?ooo`0E0?ooo`00203oool00`000?l0oooo0?ooo`0F0?ooo`D00000:P3oool00`00
0000oooo0?ooo`140?ooo`030000o`3oool0oooo01D0oooo00080?ooo`030000o`3oool0oooo01P0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`140?ooo`030000o`3oool0oooo01D0
oooo00080?ooo`030000o`3oool0oooo00l0oooo1@0000040?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`0E0?ooo`00203oool00`000?l0oooo0?oo
o`0@0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`140?ooo`030000o`3oool0oooo01D0oooo00080?ooo`030000o`3oool0oooo0140oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04@0oooo00<0
003o0?ooo`3oool05@3oool000P0oooo00<0003o0?ooo`3oool04P3oool00`000000oooo0?ooo`02
0?ooo`800000;03oool00`000000oooo0?ooo`140?ooo`030000o`3oool0oooo01D0oooo00080?oo
o`030000o`3oool0oooo0100oooo00@000000?ooo`3oool00000<@3oool00`000000oooo0?ooo`13
0?ooo`030000o`3oool0oooo01H0oooo00090?ooo`030000o`3oool0oooo00l0oooo1@00000`0?oo
o`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool05P3oool000T0oooo00<0003o0?ooo`3o
ool0A03oool00`000000oooo0?ooo`130?ooo`030000o`3oool0oooo01H0oooo00090?ooo`030000
o`3oool0oooo04@0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0F0?ooo`002@3o
ool00`000?l0oooo0?ooo`140?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool05P3o
ool000T0oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`120?ooo`030000o`3oool0
oooo01L0oooo000:0?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0@P3oool00`00
0?l0oooo0?ooo`0G0?ooo`002P3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo0480
oooo00<0003o0?ooo`3oool05`3oool000X0oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo
0?ooo`120?ooo`030000o`3oool0oooo01L0oooo000:0?ooo`030000o`3oool0oooo04<0oooo00<0
00000?ooo`3oool0@@3oool00`000?l0oooo0?ooo`0H0?ooo`002`3oool00`000?l0oooo0?ooo`12
0?ooo`030000003oool0oooo0440oooo00<0003o0?ooo`3oool0603oool000/0oooo00<0003o0?oo
o`3oool0@P3oool00`000000oooo0?ooo`110?ooo`030000o`3oool0oooo01P0oooo000;0?ooo`03
0000o`3oool0oooo0480oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0I0?ooo`00
303oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo0400oooo00<0003o0?ooo`3oool0
6@3oool000`0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`030000o`3o
ool0oooo01T0oooo000<0?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0@03oool0
0`000?l0oooo0?ooo`0I0?ooo`003@3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo
03l0oooo00<0003o0?ooo`3oool06P3oool000d0oooo00<0003o0?ooo`3oool0@03oool00`000000
oooo0?ooo`0o0?ooo`030000o`3oool0oooo01X0oooo000>0?ooo`030000o`3oool0oooo03l0oooo
00<000000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0J0?ooo`003P3oool00`000?l0oooo0?oo
o`0o0?ooo`030000003oool0oooo03h0oooo00<0003o0?ooo`3oool06`3oool000h0oooo00<0003o
0?ooo`3oool0?`3oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo01/0oooo000?0?oo
o`030000o`3oool0oooo03h0oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0L0?oo
o`003`3oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0oooo03`0oooo00<0003o0?ooo`3o
ool07@3oool00100oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000
o`3oool0oooo01d0oooo000A0?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0>`3o
ool00`000?l0oooo0?ooo`0N0?ooo`004@3oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0
oooo03/0oooo00<0003o0?ooo`3oool07P3oool00180oooo00<0003o0?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0k0?ooo`030000o`3oool0oooo01h0oooo000B0?ooo`030000o`3oool0oooo03/0
oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0O0?ooo`004P3oool00`000?l0oooo
0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0003o0?ooo`3oool07`3oool001<0oooo00<0
003o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo0200oooo000C
0?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`0P
0?ooo`00503oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo00<0003o0?oo
o`3oool08@3oool001D0oooo00<0003o0?ooo`3oool0>03oool00`000000oooo0?ooo`0g0?ooo`03
0000o`3oool0oooo0280oooo000F0?ooo`030000o`3oool0oooo03L0oooo00<000000?ooo`3oool0
=P3oool00`000?l0oooo0?ooo`0S0?ooo`005`3oool00`000?l0oooo0?ooo`0f0?ooo`030000003o
ool0oooo03D0oooo00<0003o0?ooo`3oool0903oool001P0oooo00<0003o0?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo02D0oooo000I0?ooo`030000o`3oool0oooo
03@0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`0V0?ooo`006P3oool00`000?l0
oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3oool09`3oool001X0oooo
00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo02L0oooo
000K0?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0<@3oool00`000?l0oooo0?oo
o`0X0?ooo`00703oool20000oc80oooo00<000000?ooo`3oool0<03oool00`000?l0oooo0?ooo`0Y
0?ooo`007P3oool00`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02l0oooo00<0003o0?oo
o`3oool0:P3oool001l0oooo00<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`03
0000o`3oool0oooo02/0oooo000O0?ooo`030000o`3oool0oooo02h0oooo00<000000?ooo`3oool0
;@3oool00`000?l0oooo0?ooo`0/0?ooo`00803oool00`000?l0oooo0?ooo`0]0?ooo`030000003o
ool0oooo02`0oooo00<0003o0?ooo`3oool0;@3oool00240oooo0P000?l]0?ooo`030000003oool0
oooo02X0oooo0P000?l`0?ooo`008`3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo
02T0oooo00<0003o0?ooo`3oool0<03oool002@0oooo0P000?lZ0?ooo`030000003oool0oooo02L0
oooo0P000?lc0?ooo`009P3oool00`000?l0oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo
00<0003o0?ooo`3oool0<`3oool002L0oooo0P000?lW0?ooo`030000003oool0oooo02@0oooo0P00
0?lf0?ooo`00:@3oool00`000?l0oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<0003o
0?ooo`3oool0=P3oool002X0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`0Q0?oo
o`80003o>@3oool002/0oooo0P000?lS0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3o
ool0>@3oool002d0oooo00<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000
o`3oool0oooo03X0oooo000^0?ooo`80003o803oool00`000000oooo0?ooo`0M0?ooo`80003o?@3o
ool00300oooo00<0003o0?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0
oooo03d0oooo000a0?ooo`@0003o6`3oool00`000000oooo0?ooo`0H0?ooo`@0003o@03oool003D0
oooo00<0003o0?ooo`3oool0603oool00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0480
oooo000f0?ooo`@0003o5P3oool00`000000oooo0?ooo`0C0?ooo`@0003oA@3oool003X0oooo0`00
0?lC0?ooo`030000003oool0oooo0100oooo0`000?m90?ooo`00?@3oool50000o`L0oooo1@000002
0?ooo`030000003oool0oooo00/0oooo1@000?m<0?ooo`00@P3oool70000o`80oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`L0003oD@3oool004T0oooo3P000?mH0?ooo`00
B`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05`0oooo001;0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0G03oool004X0oooo0P0000040?ooo`030000003oool0
oooo05`0oooo001@0?ooo`030000003oool0oooo05`0oooo001@0?ooo`030000003oool0oooo05`0
oooo001@0?ooo`030000003oool0oooo05`0oooo001@0?ooo`030000003oool0oooo05`0oooo002_
0?ooo`00[`3oool00:l0oooo002_0?ooo`00[`3oool00:l0oooo001>0?ooo`800000G`3oool004l0
oooo00<000000?ooo`3oool0G@3oool00500oooo00<000000?ooo`3oool0G03oool004l0oooo00<0
00000?ooo`000000G@3oool004h0oooo00@000000?ooo`3oool00000G@3oool004d0oooo0`000000
0`3oool000000000001L0?ooo`00[`3oool00:l0oooo002_0?ooo`00[`3oool00001\
\>"],
    ImageRangeCache->{{{0, 174}, {174, 0}} -> {-1, -1, 0, 0}}],
  "   "
}], "Text"],

Cell[TextData[{
  "Solution.  Here we have  ",
  Cell[BoxData[
      \(f \((z)\) = sin \((z)\)\)]],
  ".  We manipulate the integral and use Cauchy's integral formula to obtain  \
\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_C\(\( 
                  sin \((z)\)\)\/\(4  
                    z\  + \ \ \[Pi]\)\) \[DifferentialD]z\ \  = \ \ \
\(\(1\/4\) \(\[Integral]\_C\(\( 
                      sin \((z)\)\)\/\(z\  + \ \[Pi]\/4\)\) \[DifferentialD]z\
\)\ \ \  = \ \ \ \(1\/4\) \(\[Integral]\_C\(\( 
                      sin \((z)\)\)\/\(z\  - \ \((\(-\(\[Pi]\/4\)\))\)\)\) \
\[DifferentialD]z\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\(1\/4\) \((2  \[Pi]\ \[ImaginaryI])\) 
            f \((\(-\(\[Pi]\/4\)\))\)\ \  = \ \ \(1\/4\) \((2  \[Pi]\ \
\[ImaginaryI])\) sin \((\(-\(\[Pi]\/4\)\))\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(\(\
\[Pi]\ \[ImaginaryI]\)\/2\) \((\(-\(\@2\/2\)\))\)\ \  = \ \ \ \(-\ \
\[ImaginaryI]\) \(\(\ \)\(\[Pi] \@ 2\)\)\/4\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.22.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the integrand  ",
  Cell[BoxData[
      \(w[z] = Sin[z]\/\(4  z\  + \ \[Pi]\)\)],
    AspectRatioFixed->True],
  "  and locate the singularities."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[w, z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, i, solset, val];\)\ \), "\n", 
    \(\(w[z_]\  = \ Sin[z]\/\(4  z\  + \ \[Pi]\);\)\ \), "\n", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[w[z]] \[Equal] 0, z]];\)\ \), "\n", 
    \(\(Z\  = \ Table[0, {Length[solset]}];\)\ \), "\n", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[solset], \(i++\), \[IndentingNewLine]\(Z\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
            ReplaceAll[z, 
              solset\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\
\)];\)\ ];\)\ \), "\n", 
    \(\(Print["\<w[z] = \>", w[z]];\)\ \), "\n", 
    \(\(Print["\<The set of singularities is \>", 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Find the singularity that lie inside  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(Print[\*"\"\<\!\(z\_1\) = \>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<,   \
 Is |\>", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<| < \
1 ?    \>", 
        N[Abs[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]] \
< 1];\)\(\ \)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell["The integrand f(z) is to be used is", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_]\  = \ 
        Simplify[
          w[z]\ \((z\  - \ 
                Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\))\
\)];\)\ \), "\n", 
    \(\(Print["\<w[z] = \>", w[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[z] = (\>", f[z], "\<)/(\>", 
        z\  - \ Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\),\
 "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use Cauchy's Integral Formula to evaluate the integral of  ",
  Cell[BoxData[
      \(w[z] = Sin[z]\/\(4  z\  + \ \[Pi]\)\)],
    AspectRatioFixed->True],
  " taken over",
  " ",
  StyleBox["C",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(val\  = \ 
        2\ \[Pi]\ \[ImaginaryI]\ f[
            Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[z] = \>", "\<f[z]\>"\/\(z\  - \ \
Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\ \
\), "\n", 
    \(\(Print[\*"\"\<f[\!\(z\_1\)] = \>\"", \ 
        f[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Use Cauchy's Integral Formula\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\)\!\(\(f \((z)\)\)\/\(z - z\_1\)\)\
\[DifferentialD]z = 2\[Pi]\[ImaginaryI] f(\!\(z\_1\))\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        w[z], "\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI] f[\>", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<] = \
2\[Pi]\[ImaginaryI](\>", 
        f[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)], \
"\<) = \>", val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Thus, we have found the value of the contour integral.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{Red, PointSize[0.03], 
            Point[{Re[
                  Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)], Im[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]}]}];\)\
\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[
              StyleForm[TraditionalForm[\*"\"\<\!\(z\_1\)\>\""], 
                FontSize \[Rule] 12], {Re[
                  Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)], Im[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)] + 
                  0.1}, {\(-1\), 0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 1]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-1.1\), 1.1}, {\(-1.1\), 1.1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], 
            Range[\(-1\), 1, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
      w[z], "\<) \[DifferentialD]z = \>", val]\), "\[IndentingNewLine]", 
    \(\(Print["\<The contour is the circle  C: |z| = 1,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<with positive orientation.\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.23.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(\[Integral]\_C\( \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\ z\)\/\(2 
                     z\^2\  - \ 5  z\  + \ 
                  2\)\) \[DifferentialD]z\  = \ \(2\ \[Pi]\)\/3\)]],
  ",  where",
  " ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " ",
  "is the circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 1\)]],
  "  with positive orientation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.454545 0.5 0.454545 [
[.04545 .4875 -6 -9 ]
[.04545 .4875 6 0 ]
[.27273 .4875 -11.4063 -20.125 ]
[.27273 .4875 11.4063 0 ]
[.72727 .4875 -8.09375 -20.125 ]
[.72727 .4875 8.09375 0 ]
[.95455 .4875 -3 -9 ]
[.95455 .4875 3 0 ]
[1.025 .5 0 -6.28125 ]
[1.025 .5 10 6.28125 ]
[.4875 .04545 -12 -4.5 ]
[.4875 .04545 0 4.5 ]
[.4875 .27273 -22.8125 -10.0625 ]
[.4875 .27273 0 10.0625 ]
[.4875 .72727 -16.1875 -10.0625 ]
[.4875 .72727 0 10.0625 ]
[.4875 .95455 -6 -4.5 ]
[.4875 .95455 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04545 .5 m
.04545 .50625 L
s
[(-1)] .04545 .4875 0 1 Mshowa
.27273 .5 m
.27273 .50625 L
s
gsave
.27273 .4875 -72.4063 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.063 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.375 17.063 moveto
(\\200\\200) show
75.625 17.063 moveto
(\\200) show
77.688 17.063 moveto
(\\200) show
72.688 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.72727 .5 m
.72727 .50625 L
s
gsave
.72727 .4875 -69.0938 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.95455 .5 m
.95455 .50625 L
s
[(1)] .95455 .4875 0 1 Mshowa
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .04545 m
.50625 .04545 L
s
[(-1)] .4875 .04545 1 0 Mshowa
.5 .27273 m
.50625 .27273 L
s
gsave
.4875 .27273 -83.8125 -14.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.063 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.375 17.063 moveto
(\\200\\200) show
75.625 17.063 moveto
(\\200) show
77.688 17.063 moveto
(\\200) show
72.688 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .72727 m
.50625 .72727 L
s
gsave
.4875 .72727 -77.1875 -14.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .95455 m
.50625 .95455 L
s
[(1)] .4875 .95455 1 0 Mshowa
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.03 w
.72727 .5 Mdot
0 g
gsave
.72727 .54545 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
newpath
.5 .5 .45455 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{175, 175},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002_0000[b000`400?l00000o`00003oD03oool0
0`000000oooo0?ooo`1L0?ooo`00D03oool00`000000oooo0?ooo`1L0?ooo`00D03oool00`000000
oooo0?ooo`1L0?ooo`00D03oool00`000000oooo0?ooo`1L0?ooo`00D03oool00`000000oooo0?oo
o`1L0?ooo`00D03oool00`000000oooo0?ooo`1L0?ooo`00B@3oool500000080oooo00<000000?oo
o`3oool0G03oool004/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1L0?ooo`00
A@3ooolF0000oe@0oooo00100?ooo`D0003o0P0000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool50000odl0oooo000l0?ooo`@0003o2`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00d0oooo10000?m;0?ooo`00>@3oool30000o`h0oooo0P0000040?oo
o`030000003oool0oooo0140oooo0`000?m80?ooo`00=`3oool20000oaL0oooo00<000000?ooo`3o
ool0503oool20000odH0oooo000d0?ooo`<0003o6@3oool00`000000oooo0?ooo`0F0?ooo`<0003o
@`3oool00380oooo0P000?lL0?ooo`030000003oool0oooo01T0oooo0P000?m10?ooo`00<03oool2
0000oah0oooo00<000000?ooo`3oool06`3oool20000ocl0oooo000]0?ooo`<0003o803oool00`00
0000oooo0?ooo`0M0?ooo`<0003o?03oool002`0oooo00<0003o0?ooo`3oool08@3oool00`000000
oooo0?ooo`0P0?ooo`030000o`3oool0oooo03T0oooo000Z0?ooo`80003o903oool00`000000oooo
0?ooo`0Q0?ooo`80003o>@3oool002T0oooo00<0003o0?ooo`3oool0903oool00`000000oooo0?oo
o`0S0?ooo`030000o`3oool0oooo03H0oooo000W0?ooo`80003o9`3oool00`000000oooo0?ooo`0T
0?ooo`80003o=P3oool002H0oooo00<0003o0?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?oo
o`030000o`3oool0oooo03<0oooo000T0?ooo`80003o:P3oool00`000000oooo0?ooo`0W0?ooo`80
003o<`3oool002<0oooo00<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`030000
o`3oool0oooo0300oooo000R0?ooo`030000o`3oool0oooo02/0oooo00<000000?ooo`3oool0:P3o
ool00`000?l0oooo0?ooo`0_0?ooo`008@3oool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0
oooo02/0oooo00<0003o0?ooo`3oool0;P3oool00200oooo00<0003o0?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo02d0oooo000O0?ooo`030000o`3oool0oooo02h0
oooo00<000000?ooo`3oool0;@3oool20000obd0oooo000N0?ooo`030000o`3oool0oooo02l0oooo
00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0Z0?ooo`007@3oool00`000?l0oooo0?oo
o`0`0?ooo`030000003oool0oooo0300oooo00<0003o0?ooo`3oool0:@3oool001`0oooo00<0003o
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0oooo02T0oooo000K0?oo
o`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0X0?oo
o`006P3oool00`000?l0oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3o
ool09`3oool001T0oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000
o`3oool0oooo02H0oooo000H0?ooo`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0=03o
ool00`000?l0oooo0?ooo`0U0?ooo`005`3oool00`000?l0oooo0?ooo`0Y0?ooo`@000002@3oool0
0`000000oooo0?ooo`0e0?ooo`030000o`3oool0oooo02@0oooo000F0?ooo`030000o`3oool0oooo
02X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0f0?ooo`030000o`3oool0oooo
02<0oooo000E0?ooo`030000o`3oool0oooo02`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0g0?ooo`030000o`3oool0oooo0280oooo000E0?ooo`030000o`3oool0oooo02d0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo0280oooo
000D0?ooo`030000o`3oool0oooo02`0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`0h0?ooo`030000o`3oool0oooo0240oooo000C0?ooo`030000o`3oool0oooo02h0oooo0P00
000:0?ooo`030000003oool0oooo03T0oooo00<0003o0?ooo`3oool0803oool001<0oooo00<0003o
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo0200oooo000B0?oo
o`030000o`3oool0oooo02D0oooo100000030?ooo`P000001`3oool00`000000oooo0?ooo`0j0?oo
o`030000o`3oool0oooo01l0oooo000B0?ooo`030000o`3oool0oooo03/0oooo0P00000l0?ooo`03
0000o`3oool0oooo01h0oooo000A0?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0
>`3oool00`000?l0oooo0?ooo`0N0?ooo`004@3oool00`000?l0oooo0?ooo`0l0?ooo`030000003o
ool0oooo03/0oooo00<0003o0?ooo`3oool07P3oool00100oooo00<0003o0?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0k0?ooo`030000o`3oool0oooo01h0oooo000@0?ooo`030000o`3oool0oooo
0300oooo1@0000080?ooo`030000003oool0oooo03`0oooo00<0003o0?ooo`3oool07@3oool000l0
oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03d0
oooo00<0003o0?ooo`3oool0703oool000h0oooo00<0003o0?ooo`3oool0=03oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo03d0oooo00<0003o0?ooo`3oool0703oool000h0oooo00<0
003o0?ooo`3oool0=03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03h0oooo00<0
003o0?ooo`3oool06`3oool000h0oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool06P3oool000d0oooo00<0003o0?oo
o`3oool0=03oool2000000X0oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0J0?oo
o`003@3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3o
ool06P3oool000`0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`0o0?ooo`030000
o`3oool0oooo01X0oooo000<0?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0@03o
ool00`000?l0oooo0?ooo`0I0?ooo`00303oool00`000?l0oooo0?ooo`110?ooo`030000003oool0
oooo0400oooo00<0003o0?ooo`3oool06@3oool000/0oooo00<0003o0?ooo`3oool0@P3oool00`00
0000oooo0?ooo`100?ooo`030000o`3oool0oooo01T0oooo000;0?ooo`030000o`3oool0oooo0480
oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo0?ooo`0H0?ooo`002`3oool00`000?l0oooo
0?ooo`0O0?ooo`@000007`3oool00`000000oooo0?ooo`0N0?ooo`@000007`3oool00`000?l0oooo
0?ooo`0H0?ooo`002`3oool00`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo01P0oooo000:
0?ooo`030000o`3oool0oooo0240oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0603oool000X0oooo00<0003o0?oo
o`3oool08P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool07`3oool00`000?l0oooo0?ooo`0G0?ooo`002P3oool00`000?l0oooo0?ooo`0P0?ooo`04
0000003oool0oooo000001l0oooo00<000000?ooo`3oool07P3oool010000000oooo0?ooo`00000P
0?ooo`030000o`3oool0oooo01L0oooo00090?ooo`030000o`3oool0oooo0280oooo0P00000P0?oo
o`030000003oool0oooo01l0oooo0P00000Q0?ooo`030000o`3oool0oooo01L0oooo00090?ooo`03
0000o`3oool0oooo04@0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0F0?ooo`00
2@3oool00`000?l0oooo0?ooo`0G0?ooo`@00000103oool8000001d0oooo00<000000?ooo`3oool0
703oool8000001l0oooo00<0003o0?ooo`3oool05P3oool000T0oooo00<0003o0?ooo`3oool0A03o
ool00`000000oooo0?ooo`130?ooo`030000o`3oool0oooo01H0oooo00090?ooo`030000o`3oool0
oooo04@0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0F0?ooo`002@3oool00`00
0?l000000000000200000480oooo00<000000?ooo`3oool0@P3oool00`000000003o000000020000
01D0oooo00080?ooo`040000o`3oool0oooo000004@0oooo00<000000?ooo`3oool0A03oool00`00
0?l0oooo0?ooo`0E0?ooo`00203oool010000?l0oooo0?ooo`00000Q0?ooo`D000007P3oool00`00
0000oooo0?ooo`0N0?ooo`D000008@3oool00`000?l0oooo0?ooo`0E0?ooo`000`3oool400000005
0?ooo`000?l0oooo0?ooo`0000008`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`0E0?ooo`00203oool010000?l0
oooo0?ooo`00000S0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo01D0oooo00080?ooo`040000o`3oool000000000
02<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0200oooo00<000000000o`3oool05P3oool000P0oooo00<0003o0?ooo`3oool0903oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3oool00`000?l0
oooo0?ooo`0E0?ooo`00203oool00`000?l0oooo0?ooo`0S0?ooo`800000803oool00`000000oooo
0?ooo`0O0?ooo`8000008`3oool00`000?l0oooo0?ooo`0E0?ooo`00203oool00`000?l0oooo0?oo
o`150?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool05@3oool000P0oooo00<0003o
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0P0?ooo`80o`008P3oool00`000?l0oooo0?ooo`0:
0?ooo`80000000<0oooo0000000000001P3oool000030?ooo`000000000000D0000000<0003o0000
00000000I`0000040?l00240000000<0003o0000000000001@0000060?ooo`030000003oool00000
00L0oooo00080?ooo`030000o`3oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0O0?ooo`@0o`008@3oool00`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo00H0
oooo00080?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool0803oool20?l00280oooo
00<0003o0?ooo`3oool02P3oool2000000030?ooo`000000000000H0oooo00080?ooo`030000o`3o
ool0oooo04D0oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`0E0?ooo`00203oool0
0`000?l0oooo0?ooo`150?ooo`030000003oool0oooo02X0oooo1@00000E0?ooo`030000o`3oool0
oooo01D0oooo00080?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01D0oooo00080?ooo`030000o`3oool0oooo04D0
oooo00<000000?ooo`3oool08`3oool5000000@0oooo00<000000?ooo`3oool05@3oool00`000?l0
oooo0?ooo`0E0?ooo`00203oool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo02@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01D0
oooo00080?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool05@3oool000P0oooo00<0
003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo0P00
000G0?ooo`030000o`3oool0oooo01D0oooo00080?ooo`030000o`3oool0oooo04D0oooo00<00000
0?ooo`3oool0903oool010000000oooo0?ooo`00000K0?ooo`030000o`3oool0oooo01H0oooo0009
0?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0903oool5000001X0oooo00<0003o
0?ooo`3oool05P3oool000T0oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`130?oo
o`030000o`3oool0oooo01H0oooo00090?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3o
ool0@`3oool00`000?l0oooo0?ooo`0F0?ooo`002@3oool00`000?l0oooo0?ooo`140?ooo`030000
003oool0oooo04<0oooo00<0003o0?ooo`3oool05P3oool000T0oooo00<0003o0?ooo`3oool0A03o
ool00`000000oooo0?ooo`120?ooo`030000o`3oool0oooo01L0oooo000:0?ooo`030000o`3oool0
oooo04<0oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0G0?ooo`002P3oool00`00
0?l0oooo0?ooo`130?ooo`030000003oool0oooo0480oooo00<0003o0?ooo`3oool05`3oool000X0
oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`120?ooo`030000o`3oool0oooo01L0
oooo000:0?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo
0?ooo`0H0?ooo`002`3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo0440oooo00<0
003o0?ooo`3oool0603oool000/0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`11
0?ooo`030000o`3oool0oooo01P0oooo000;0?ooo`030000o`3oool0oooo0480oooo00<000000?oo
o`3oool0@03oool00`000?l0oooo0?ooo`0I0?ooo`00303oool00`000?l0oooo0?ooo`110?ooo`03
0000003oool0oooo0400oooo00<0003o0?ooo`3oool06@3oool000`0oooo00<0003o0?ooo`3oool0
@@3oool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo01T0oooo000<0?ooo`030000o`3o
ool0oooo0440oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0I0?ooo`003@3oool0
0`000?l0oooo0?ooo`100?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool06P3oool0
00d0oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0oooo
01X0oooo000>0?ooo`030000o`3oool0oooo0380oooo100000090?ooo`030000003oool0oooo03l0
oooo00<0003o0?ooo`3oool06P3oool000h0oooo00<0003o0?ooo`3oool0<P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo03h0oooo00<0003o0?ooo`3oool06`3oool000h0oooo00<0
003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03h0oooo00<0
003o0?ooo`3oool06`3oool000l0oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo03d0oooo00<0003o0?ooo`3oool0703oool000l0oooo00<0003o0?oo
o`3oool0<@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo03`0oooo00<0003o
0?ooo`3oool07@3oool00100oooo00<0003o0?ooo`3oool0<@3oool2000000X0oooo00<000000?oo
o`3oool0?03oool00`000?l0oooo0?ooo`0M0?ooo`004@3oool00`000?l0oooo0?ooo`0l0?ooo`03
0000003oool0oooo03/0oooo00<0003o0?ooo`3oool07P3oool00140oooo00<0003o0?ooo`3oool0
;@3oool8000000L0oooo00<000000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`0N0?ooo`004P3o
ool00`000?l0oooo0?ooo`0k0?ooo`800000?03oool00`000?l0oooo0?ooo`0N0?ooo`004P3oool0
0`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0003o0?ooo`3oool07`3oool0
0180oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000o`3oool0oooo
01l0oooo000C0?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0>@3oool00`000?l0
oooo0?ooo`0P0?ooo`004`3oool00`000?l0oooo0?ooo`0]0?ooo`D00000203oool00`000000oooo
0?ooo`0i0?ooo`030000o`3oool0oooo0200oooo000D0?ooo`030000o`3oool0oooo02h0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo0240oooo000E
0?ooo`030000o`3oool0oooo02d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0g
0?ooo`030000o`3oool0oooo0280oooo000F0?ooo`030000o`3oool0oooo02`0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0f0?ooo`030000o`3oool0oooo02<0oooo000G0?ooo`03
0000o`3oool0oooo02/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0e0?ooo`03
0000o`3oool0oooo02@0oooo000H0?ooo`030000o`3oool0oooo02T0oooo0P00000:0?ooo`030000
003oool0oooo03@0oooo00<0003o0?ooo`3oool09@3oool001T0oooo00<0003o0?ooo`3oool0=03o
ool00`000000oooo0?ooo`0c0?ooo`030000o`3oool0oooo02H0oooo000J0?ooo`030000o`3oool0
oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`0W0?ooo`006P3oool00`00
0?l0oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3oool09`3oool001/0
oooo00<0003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo02P0
oooo000L0?ooo`80003o<P3oool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0oooo02T0oooo
000N0?ooo`030000o`3oool0oooo02l0oooo00<000000?ooo`3oool0;`3oool00`000?l0oooo0?oo
o`0Z0?ooo`007`3oool00`000?l0oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo00<0003o
0?ooo`3oool0:`3oool001l0oooo00<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?oo
o`030000o`3oool0oooo02`0oooo000P0?ooo`030000o`3oool0oooo02d0oooo00<000000?ooo`3o
ool0;03oool00`000?l0oooo0?ooo`0]0?ooo`008@3oool20000obd0oooo00<000000?ooo`3oool0
:P3oool20000oc00oooo000S0?ooo`030000o`3oool0oooo02X0oooo00<000000?ooo`3oool0:@3o
ool00`000?l0oooo0?ooo`0`0?ooo`00903oool20000obX0oooo00<000000?ooo`3oool09`3oool2
0000oc<0oooo000V0?ooo`030000o`3oool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`00
0?l0oooo0?ooo`0c0?ooo`009`3oool20000obL0oooo00<000000?ooo`3oool0903oool20000ocH0
oooo000Y0?ooo`030000o`3oool0oooo02@0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo
0?ooo`0f0?ooo`00:P3oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo0240oooo0P00
0?li0?ooo`00:`3oool20000ob<0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`0i
0?ooo`00;@3oool00`000?l0oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<0003o0?oo
o`3oool0>P3oool002h0oooo0P000?lP0?ooo`030000003oool0oooo01d0oooo0P000?lm0?ooo`00
<03oool00`000?l0oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0
?@3oool00340oooo10000?lK0?ooo`030000003oool0oooo01P0oooo10000?m00?ooo`00=@3oool0
0`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo00<0003o0?ooo`3oool0@P3oool0
03H0oooo10000?lF0?ooo`030000003oool0oooo01<0oooo10000?m50?ooo`00>P3oool30000oa<0
oooo00<000000?ooo`3oool0403oool30000odT0oooo000m0?ooo`D0003o1`3oool500000080oooo
00<000000?ooo`3oool02`3oool50000od`0oooo00120?ooo`L0003o0P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo1`000?mA0?ooo`00B@3oool>0000oeP0oooo001;0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0G03oool004/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1L0?ooo`00BP3oool2000000@0oooo00<000000?ooo`3oool0
G03oool00500oooo00<000000?ooo`3oool0G03oool00500oooo00<000000?ooo`3oool0G03oool0
0500oooo00<000000?ooo`3oool0G03oool00500oooo00<000000?ooo`3oool0G03oool00:l0oooo
002_0?ooo`00[`3oool00:l0oooo002_0?ooo`00[`3oool004h0oooo0P00001O0?ooo`00C`3oool0
0`000000oooo0?ooo`1M0?ooo`00D03oool00`000000oooo0?ooo`1L0?ooo`00C`3oool00`000000
oooo0000001M0?ooo`00CP3oool010000000oooo0?ooo`00001M0?ooo`00C@3oool3000000030?oo
o`000000000005`0oooo002_0?ooo`00[`3oool00:l0oooo002_0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 174}, {174, 0}} -> {-1, -1, 0, 0}}],
  "   "
}], "Text"],

Cell[TextData[{
  "Solution.  We see that  ",
  Cell[BoxData[
      \(2  z\^2 - 5  z + 2\  = \ \(\((2\ z - 1)\)\ \((z - 2)\)\  = \ 
          2 \((z - 1\/2)\) \((z - 2)\)\)\)]],
  ".  The only zero of this expression that lies in the interior of",
  " ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is ",
  Cell[BoxData[
      \(z\_0 = 1\/2\)]],
  ".  \nWe set  ",
  Cell[BoxData[
      \(f \((z)\) = \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\ z\)\/\((z - 2)\)\
\)]],
  "  and use Theorem 6.10 to conclude that  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_C\( \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\ \
z\)\/\(2  z\^2\  - \ 5  z\  + \ 
                  2\)\) \[DifferentialD]z\ \  = \ \ \(\[Integral]\_C\( \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\ z\)\/\(2 \((z - 1\/2)\) \((z - 
                        2)\)\)\) \[DifferentialD]z\  = \ \ \(1\/2\) \(\
\[Integral]\_C\( \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\ z\)\/\((z - 
                        2)\)\) \(1\/\((z - 
                        1\/2)\)\) \
\[DifferentialD]z\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(\(1\/2\) \(\[Integral]\_C\ \(\(f \((z)\)\)\/\((z - 
                        1\/2)\)\) \[DifferentialD]z\)\  = 
          1\/2\ \((2  \[Pi]\ \[ImaginaryI])\) 
            f \((1\/2)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(1\/2\ \((2  \[Pi]\ \[ImaginaryI])\) \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Pi]/2\)\/\((1\/2 - 2)\)\ \  = \ \ \((\[Pi]\ \[ImaginaryI])\)\
\ \[ImaginaryI]\/\((\(-\(3\/2\)\))\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\
\)\(\ \ \)\(\(2\ \[Pi]\)\/3\)\)\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.23.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the integrand  ",
  Cell[BoxData[
      \(w[
          z] = \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\ z\)\/\(2  z\^2\  - \ \
5  z\  + \ 2\)\)],
    AspectRatioFixed->True],
  "  and locate the singularities."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[w, z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, i, solset, val];\)\ \), "\n", 
    \(\(w[
          z_]\  = \ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\ z\)\/\(2  z\^2\  \
- \ 5  z\  + \ 2\);\)\ \), "\n", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[w[z]] \[Equal] 0, z]];\)\ \), "\n", 
    \(\(Z\  = \ Table[0, {Length[solset]}];\)\ \), "\n", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[solset], \(i++\), \[IndentingNewLine]\(Z\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
            ReplaceAll[z, 
              solset\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\
\)];\)\ ];\)\ \), "\n", 
    \(\(Print["\<w[z] = \>", w[z]];\)\ \), "\n", 
    \(\(Print["\<The set of singularities is \>", 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Find the singularity that lie inside",
  " ",
  StyleBox["C",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<,   \
 Is |\>", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<| < \
1 ?   \>", 
        N[Abs[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]] \
< 1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\), "\<,   \
  Is |\>", 
        Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\), "\<| < \
1 ?    \>", 
        N[Abs[Z\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)]] \
< 1];\)\ \), "\n", 
    \(\)}], "Input"],

Cell[TextData[{
  "Thus,  ",
  Cell[BoxData[
      \(z = 1\/2\)]],
  "  the only singularity that lies inside  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 1\)]],
  ".  \n\nThe integrand f(z) is to be used is"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_]\  = \ 
        Simplify[
          w[z]\ \((z\  - \ 
                Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\))\
\)];\)\ \), "\n", 
    \(\(Print["\<w[z] = \>", w[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[z] = (\>", f[z], "\<)/(\>", 
        z\  - \ Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\),\
 "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use Cauchy's Integral Formula to evaluate the integral of  ",
  Cell[BoxData[
      \(w[
          z] = \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\ z\)\/\(2  z\^2\  - \ \
5  z\  + \ 2\)\)],
    AspectRatioFixed->True],
  " taken over",
  " ",
  StyleBox["C",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(val\  = \ 
        2\ \[Pi]\ \[ImaginaryI]\ f[
            Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[z] = \>", "\<f[z]\>"\/\(z\  - \ \
Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\ \
\), "\n", 
    \(\(Print[\*"\"\<f[\!\(z\_1\)] = \>\"", \ 
        f[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Use Cauchy's Integral Formula\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\)\!\(\(f \((z)\)\)\/\(z - z\_1\)\)\
\[DifferentialD]z = 2\[Pi]\[ImaginaryI] f(\!\(z\_1\))\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        w[z], \*"\"\< \[DifferentialD]z = \!\(\[Integral]\_C\) \>\"", \
"\<(\>", f[z], "\<)/(\>", 
        z\  - \ Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\),\
 "\<)\>", "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        w[z], "\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI] f[\>", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<] = \
2\[Pi]\[ImaginaryI](\>", 
        f[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)], \
"\<) = \>", val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Thus, we have found the value of the contour integral.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{Red, PointSize[0.03], 
            Point[{Re[
                  Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)], Im[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]}]}];\)\
\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[
              StyleForm[TraditionalForm[\*"\"\<\!\(z\_1\)\>\""], 
                FontSize \[Rule] 12], {Re[
                  Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)], Im[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)] + 
                  0.1}, {\(-1\), 0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 1]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-1.1\), 1.1}, {\(-1.1\), 1.1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1\/2], 
            Range[\(-1\), 1, 1\/2]}, \[IndentingNewLine]AspectRatio \[Rule] 
          1, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
      w[z], "\<) \[DifferentialD]z = \>", val]\), "\[IndentingNewLine]", 
    \(\(Print["\<The contour is the circle  C: |z| = 1,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<with positive orientation.\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 6.11 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Leibniz's Rule",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LeibnizIntegralRule.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["G",
    FontFamily->"Courier New"],
  " be an open set,  and let  ",
  Cell[BoxData[
      \(I : \ a \[LessEqual] t \[LessEqual] b\)]],
  "  be an interval of real numbers.  Let ",
  Cell[BoxData[
      \(g \((z, t)\)\)]],
  " and its partial derivative ",
  Cell[BoxData[
      \(\(g\_z\) \((z, t)\)\)]],
  " with respect to ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " be continuous functions for all ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " in ",
  StyleBox["G",
    FontFamily->"Courier New"],
  " and all ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " in ",
  StyleBox["I",
    FontFamily->"Courier New"],
  ".  Then  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \ \)\(F \((z)\)\  = \ \[Integral]\_a\%b\ 
          g \((z, t)\) \[DifferentialD]t\)\)\)]],
  "   is analytic for z in G, and  \n\n\t\t\t",
  Cell[BoxData[
      \(F' \((z)\)\  = \ \[Integral]\_a\%b\ \(g\_z\) \((z, 
              t)\) \[DifferentialD]t\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "\tThe proof is presented in some advanced texts.  See, for instance, ",
  ButtonBox["Rolf Nevanlinna",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Nevanlinna.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " and V. Paatero, ",
  StyleBox["Introduction to Complex Analysis",
    FontSlant->"Italic"],
  " (Reading, Massachusetts: Addison-Wesley Publishing Company, 1969), \
Section 9.7."
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Demonstration for Theorem 6.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[t, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F];\)\ \), "\[IndentingNewLine]", 
    \(\(F[
          z_] = \[Integral]\_a\%b f[z, 
              t] \[DifferentialD]t;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Rule Leibniz's Rule is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F'[z] = \>", \(F'\)[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<where\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[PartialD]\_z\ 
          f[z, t], \*"\"\< = \!\(\[PartialD]\_z\) f[z,t]\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tWe now generalize Theorem 6.10 to give an integral representation for \
the ",
  Cell[BoxData[
      \(n\^th\)]],
  " derivative, ",
  Cell[BoxData[
      \(\(f\^\((n)\)\) \((z)\)\)]],
  ". We use ",
  StyleBox[ButtonBox["Leibniz's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Leibniz.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " ",
  StyleBox[ButtonBox["rule",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LeibnizIntegralRule.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " in the proof and note that this method of proof is a mnemonic device for \
remembering Theorem 6.12."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 6.12 (Cauchy's Integral Formulae for Derivatives).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " be analytic in the simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", and let ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " be a simple closed positively oriented contour that lies in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  If ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " is a point that lies interior to ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", then for any integer ",
  Cell[BoxData[
      \(n \[GreaterEqual] 0\)]],
  ", we have",
  StyleBox["\n\n\t\t\t",
    FontColor->RGBColor[1, 0, 1]],
  Cell[BoxData[
      \(\(f\^\((n)\)\) \((z)\)\ \  = \ \ \(\(n!\)\/\(2  \[Pi]\ \
\[ImaginaryI]\)\) \(\[Integral]\_C\(\( 
                    f \((\[Zeta])\)\)\/\((\[Zeta] - z)\)\^\(n + 1\)\) \
\[DifferentialD]\[Zeta]\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.12 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.24.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  denote a fixed complex value.  Show that, if ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a simple closed positively oriented contour such that  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  lies interior to ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", then  \n\n   \t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\( 
                1\/\(z\  - \ 
                  z\_0\)\) \[DifferentialD]z\ \  = \ \ 2  \[Pi]\ \
\[ImaginaryI]\)]],
  ",   and\n",
  StyleBox["(6-50)",
    FontColor->RGBColor[0, 0, 1]],
  "\n   \t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\( 
                1\/\((z\  - \ z\_0)\)\^\(n + 1\)\) \[DifferentialD]z\ \  = \ \
\ 0\)]],
  ",   for any integer  ",
  Cell[BoxData[
      \(n \[GreaterEqual] 1\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.25 [
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[0 .775 -5 0 ]
[0 .775 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
0 .75 L
s
gsave
0 .775 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
gsave
.5 .4 -69.4063 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
newpath
.5 .41667 .25 0 365.73 arc
s
1 0 0 r
.03 w
.5 .41667 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{233.313, 175},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003Y0000[b000`400?l00000o`00003oj@3oool0
0>T0oooo003Y0?ooo`00j@3oool00>T0oooo003J0?ooo`80000000<0oooo0000000000002P3oool0
0=/0oooo00<000000?ooo`0000002`3oool000/0oooob@0000080?ooo`030000003oool0oooo00X0
oooo000;0?ooo`030000003oool0oooo0<`0oooo0P0000000`3oool000000000000:0?ooo`002`3o
ool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`00
0000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo
0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K
0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`00
2`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool0
0`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000
oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?oo
o`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?oo
o`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3o
ool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`00
0000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo
0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K
0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`00
2`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool0
0`000000oooo0?ooo`1L0?ooo`X0003oM@3oool000/0oooo00<000000?ooo`3oool0E@3oool70000
o`X0oooo1`000?m^0?ooo`002`3oool00`000000oooo0?ooo`1C0?ooo`80003o603oool30000of/0
oooo000;0?ooo`030000003oool0oooo0500oooo0`000?lM0?ooo`80003oJ@3oool000/0oooo00<0
00000?ooo`3oool0CP3oool20000ob80oooo0P000?mW0?ooo`002`3oool00`000000oooo0?ooo`1<
0?ooo`80003o9P3oool20000ofD0oooo000;0?ooo`030000003oool0oooo04X0oooo0P000?lZ0?oo
o`<0003oHP3oool000/0oooo00<000000?ooo`3oool0B03oool20000obl0oooo0P000?mP0?ooo`00
2`3oool00`000000oooo0?ooo`160?ooo`80003o<`3oool20000oeh0oooo000;0?ooo`030000003o
ool0oooo04@0oooo0P000?lg0?ooo`030000o`3oool0oooo05/0oooo000;0?ooo`030000003oool0
oooo04<0oooo00<0003o0?ooo`3oool0>03oool00`000?l0oooo0?ooo`1J0?ooo`002`3oool00`00
0000oooo0?ooo`110?ooo`80003o?03oool20000oeX0oooo000;0?ooo`030000003oool0oooo0400
oooo00<0003o0?ooo`3oool0?P3oool00`000?l0oooo0?ooo`1G0?ooo`002`3oool00`000000oooo
0?ooo`100?ooo`030000o`3oool0oooo03l0oooo00<0003o0?ooo`3oool0EP3oool000/0oooo00<0
00000?ooo`3oool0?P3oool20000od<0oooo0P000?mF0?ooo`002`3oool00`000000oooo0?ooo`0m
0?ooo`030000o`3oool0oooo04@0oooo00<0003o0?ooo`3oool0E03oool000/0oooo00<000000?oo
o`3oool0?03oool00`000?l0oooo0?ooo`160?ooo`030000o`3oool0oooo05<0oooo000;0?ooo`03
0000003oool0oooo03/0oooo00<0003o0?ooo`3oool0B03oool00`000?l0oooo0?ooo`1B0?ooo`00
2`3oool00`000000oooo0?ooo`0j0?ooo`030000o`3oool0oooo04X0oooo00<0003o0?ooo`3oool0
D@3oool000/0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`1<0?ooo`030000o`3o
ool0oooo0500oooo000;0?ooo`030000003oool0oooo03T0oooo00<0003o0?ooo`3oool0C@3oool0
0`000?l0oooo0?ooo`1?0?ooo`002`3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo
04h0oooo00<0003o0?ooo`3oool0C`3oool000/0oooo00<000000?ooo`3oool0=`3oool00`000?l0
oooo0?ooo`1@0?ooo`030000o`3oool0oooo04h0oooo000;0?ooo`030000003oool0oooo03H0oooo
00<0003o0?ooo`3oool0D@3oool00`000?l0oooo0?ooo`1>0?ooo`002`3oool00`000000oooo0?oo
o`0f0?ooo`030000o`3oool0oooo0580oooo00<0003o0?ooo`3oool0C@3oool000/0oooo00<00000
0?ooo`3oool0=@3oool00`000?l0oooo0?ooo`1D0?ooo`030000o`3oool0oooo04`0oooo000;0?oo
o`030000003oool0oooo03D0oooo00<0003o0?ooo`3oool0E@3oool00`000?l0oooo0?ooo`1;0?oo
o`002`3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo05H0oooo00<0003o0?ooo`3o
ool0B`3oool000/0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`1G0?ooo`030000
o`3oool0oooo04X0oooo000;0?ooo`030000003oool0oooo03@0oooo00<0003o0?ooo`3oool0E`3o
ool00`000?l0oooo0?ooo`1:0?ooo`002`3oool00`000000oooo0?ooo`0c0?ooo`030000o`3oool0
oooo05T0oooo00<0003o0?ooo`3oool0B@3oool000/0oooo00<000000?ooo`3oool0<`3oool00`00
0?l0oooo0?ooo`1I0?ooo`030000o`3oool0oooo04T0oooo000;0?ooo`030000003oool0oooo0380
oooo00<0003o0?ooo`3oool0FP3oool00`000?l0oooo0?ooo`190?ooo`002`3oool00`000000oooo
0?ooo`0b0?ooo`030000o`3oool0oooo05/0oooo00<0003o0?ooo`3oool0B03oool000/0oooo00<0
00000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`1L0?ooo`030000o`3oool0oooo04P0oooo000;
0?ooo`030000003oool0oooo0340oooo00<0003o0?ooo`3oool0G03oool00`000?l0oooo0?ooo`18
0?ooo`002`3oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo05`0oooo00<0003o0?oo
o`3oool0B03oool000/0oooo00<000000?ooo`3oool0<03oool00`000?l0oooo0?ooo`0`0?ooo`03
0000003oool0oooo02/0oooo00<0003o0?ooo`3oool0A`3oool000/0oooo00<000000?ooo`3oool0
<03oool00`000?l0oooo0?ooo`0_0?ooo`030000003oool0000002`0oooo00<0003o0?ooo`3oool0
A`3oool000/0oooo00<000000?ooo`3oool0<03oool00`000?l0oooo0?ooo`0X0?ooo`D000000P3o
ool00`000000oooo0000000/0?ooo`030000o`3oool0oooo04L0oooo000;0?ooo`030000003oool0
oooo0300oooo00<0003o0?ooo`3oool0:@3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0000002d0oooo00<0003o0?ooo`3oool0AP3oool000/0oooo00<000000?ooo`3oool0<03oool0
0`000?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000;@3oool0
0`000?l0oooo0?ooo`160?ooo`002`3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0oooo
02`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0/0?ooo`030000o`3oool0oooo
04H0oooo000;0?ooo`030000003oool0oooo02l0oooo00<0003o0?ooo`3oool0:P3oool010000000
oooo0?ooo`00000b0?ooo`030000o`3oool0oooo04H0oooo000;0?ooo`030000003oool0oooo02l0
oooo00<0003o0?ooo`3oool0:P3oool500000340oooo00<0003o0?ooo`3oool0AP3oool000/0oooo
00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`1P0?ooo`030000o`3oool0oooo04H0oooo
000;0?ooo`030000003oool0oooo02l0oooo00<0003o0?ooo`3oool0H03oool00`000?l0oooo0?oo
o`160?ooo`002`3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0oooo0640oooo00<0003o
0?ooo`3oool0A@3oool000/0oooo00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0^0?oo
o`80o`00<@3oool00`000?l0oooo0?ooo`150?ooo`002`3oool00`000000oooo0?ooo`0_0?ooo`03
0000o`3oool0oooo02d0oooo103o000`0?ooo`030000o`3oool0oooo04D0oooo000;0?ooo`030000
003oool0oooo02l0oooo00<0003o0?ooo`3oool0;03oool60?l002l0oooo00<0003o0?ooo`3oool0
A@3oool000/0oooo00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0/0?ooo`H0o`00;`3o
ool00`000?l0oooo0?ooo`150?ooo`002`3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0
oooo02d0oooo103o000`0?ooo`030000o`3oool0oooo04D0oooo000;0?ooo`030000003oool0oooo
02l0oooo00<0003o0?ooo`3oool0;P3oool20?l00340oooo00<0003o0?ooo`3oool0A@3oool000/0
oooo00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`1P0?ooo`030000o`3oool0oooo04H0
oooo000;0?ooo`030000003oool0oooo02l0oooo00<0003o0?ooo`3oool0H03oool00`000?l0oooo
0?ooo`160?ooo`002`3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0oooo0600oooo00<0
003o0?ooo`3oool0AP3oool000/0oooo00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`1P
0?ooo`030000o`3oool0oooo04H0oooo000;0?ooo`030000003oool0oooo02l0oooo00<0003o0?oo
o`3oool0H03oool00`000?l0oooo0?ooo`160?ooo`002`3oool00`000000oooo0?ooo`0_0?ooo`03
0000o`3oool0oooo0600oooo00<0003o0?ooo`3oool0AP3oool000/0oooo00<000000?ooo`3oool0
<03oool00`000?l0oooo0?ooo`1O0?ooo`030000o`3oool0oooo04H0oooo000;0?ooo`030000003o
ool0oooo0300oooo00<0003o0?ooo`3oool0G`3oool00`000?l0oooo0?ooo`160?ooo`002`3oool0
0`000000oooo0?ooo`0`0?ooo`030000o`3oool0oooo05h0oooo00<0003o0?ooo`3oool0A`3oool0
00/0oooo00<000000?ooo`3oool0<03oool00`000?l0oooo0?ooo`1N0?ooo`030000o`3oool0oooo
04L0oooo000;0?ooo`030000003oool0oooo0300oooo00<0003o0?ooo`3oool0G@3oool00`000?l0
oooo0?ooo`180?ooo`002`3oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo05`0oooo
00<0003o0?ooo`3oool0B03oool000/0oooo00<000000?ooo`3oool0<@3oool00`000?l0oooo0?oo
o`1L0?ooo`030000o`3oool0oooo04P0oooo000;0?ooo`030000003oool0oooo0380oooo00<0003o
0?ooo`3oool0F`3oool00`000?l0oooo0?ooo`180?ooo`002`3oool00`000000oooo0?ooo`0b0?oo
o`030000o`3oool0oooo05/0oooo00<0003o0?ooo`3oool0B03oool000/0oooo00<000000?ooo`3o
ool0<`3oool00`000?l0oooo0?ooo`1I0?ooo`030000o`3oool0oooo04T0oooo000;0?ooo`030000
003oool0oooo03<0oooo00<0003o0?ooo`3oool0F@3oool00`000?l0oooo0?ooo`190?ooo`002`3o
ool00`000000oooo0?ooo`0c0?ooo`030000o`3oool0oooo05P0oooo00<0003o0?ooo`3oool0BP3o
ool000/0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`1G0?ooo`030000o`3oool0
oooo04X0oooo000;0?ooo`030000003oool0oooo03@0oooo00<0003o0?ooo`3oool0EP3oool00`00
0?l0oooo0?ooo`1;0?ooo`002`3oool00`000000oooo0?ooo`0e0?ooo`030000o`3oool0oooo05D0
oooo00<0003o0?ooo`3oool0B`3oool000/0oooo00<000000?ooo`3oool0=@3oool00`000?l0oooo
0?ooo`1D0?ooo`030000o`3oool0oooo04`0oooo000;0?ooo`030000003oool0oooo03H0oooo00<0
003o0?ooo`3oool0DP3oool00`000?l0oooo0?ooo`1=0?ooo`002`3oool00`000000oooo0?ooo`0f
0?ooo`030000o`3oool0oooo0540oooo00<0003o0?ooo`3oool0CP3oool000/0oooo00<000000?oo
o`3oool0=`3oool00`000?l0oooo0?ooo`1@0?ooo`030000o`3oool0oooo04h0oooo000;0?ooo`03
0000003oool0oooo03P0oooo00<0003o0?ooo`3oool0CP3oool00`000?l0oooo0?ooo`1?0?ooo`00
2`3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo04d0oooo00<0003o0?ooo`3oool0
C`3oool000/0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`1<0?ooo`030000o`3o
ool0oooo0500oooo000;0?ooo`030000003oool0oooo03X0oooo00<0003o0?ooo`3oool0BP3oool0
0`000?l0oooo0?ooo`1A0?ooo`002`3oool00`000000oooo0?ooo`0k0?ooo`030000o`3oool0oooo
04P0oooo00<0003o0?ooo`3oool0DP3oool000/0oooo00<000000?ooo`3oool0?03oool00`000?l0
oooo0?ooo`160?ooo`030000o`3oool0oooo05<0oooo000;0?ooo`030000003oool0oooo03d0oooo
00<0003o0?ooo`3oool0A03oool00`000?l0oooo0?ooo`1D0?ooo`002`3oool00`000000oooo0?oo
o`0n0?ooo`030000o`3oool0oooo04<0oooo00<0003o0?ooo`3oool0E03oool000/0oooo00<00000
0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`110?ooo`030000o`3oool0oooo05D0oooo000;0?oo
o`030000003oool0oooo0400oooo00<0003o0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`1F0?oo
o`002`3oool00`000000oooo0?ooo`110?ooo`030000o`3oool0oooo03`0oooo0P000?mI0?ooo`00
2`3oool00`000000oooo0?ooo`120?ooo`030000o`3oool0oooo03X0oooo00<0003o0?ooo`3oool0
F@3oool000/0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0h0?ooo`030000o`3o
ool0oooo05X0oooo000;0?ooo`030000003oool0oooo04@0oooo0P000?lf0?ooo`80003oG@3oool0
00/0oooo00<000000?ooo`3oool0AP3oool20000oc<0oooo00<0003o0?ooo`3oool0G@3oool000/0
oooo00<000000?ooo`3oool0B03oool00`000?l0oooo0?ooo`0^0?ooo`80003oH03oool000/0oooo
00<000000?ooo`3oool0B@3oool20000ob`0oooo0P000?mR0?ooo`002`3oool00`000000oooo0?oo
o`1;0?ooo`80003o:03oool20000of@0oooo000;0?ooo`030000003oool0oooo04d0oooo0`000?lS
0?ooo`80003oIP3oool000/0oooo00<000000?ooo`3oool0D03oool50000oaT0oooo1@000?mX0?oo
o`002`3oool00`000000oooo0?ooo`1E0?ooo`@0003o403oool50000ofd0oooo000;0?ooo`030000
003oool0oooo05T0oooo40000?mb0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool0
0`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000
oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?oo
o`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?oo
o`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3o
ool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`00
0000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo
0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K0?ooo`002`3oool00`000000oooo0?ooo`3K
0?ooo`00j@3oool00>T0oooo003Y0?ooo`00j@3oool00>T0oooo003Y0?ooo`00j@3oool000T0oooo
0P00003N0?ooo`002P3oool00`000000oooo0?ooo`3L0?ooo`002`3oool00`000000oooo0?ooo`3K
0?ooo`002P3oool00`000000oooo0000003L0?ooo`002@3oool010000000oooo0?ooo`00003L0?oo
o`00203oool3000000030?ooo`00000000000=/0oooo003Y0?ooo`00j@3oool00>T0oooo003Y0?oo
o`00\
\>"],
    ImageRangeCache->{{{0, 232.313}, {174, 0}} -> {0, 0, 0, 0}}],
  "   "
}], "Text"],

Cell[TextData[{
  "Solution.  We let ",
  Cell[BoxData[
      \(f \((z)\) = 1\)]],
  ".  Then ",
  Cell[BoxData[
      \(\(f\^\((n)\)\) \((z)\) = 0\)]],
  " for ",
  Cell[BoxData[
      \(n \[GreaterEqual] 1\)]],
  ".  Theorem 6.10 implies that the value of the first integral in Equations \
",
  StyleBox["(6-50)",
    FontColor->RGBColor[0, 0, 1]],
  " is\n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\( 
                1\/\(z\  - \ 
                  z\_0\)\) \[DifferentialD]z\ \  = \ \ \(2  \[Pi]\ \
\[ImaginaryI]\ f \((z\_0)\)\ \  = \ \ 2  \[Pi]\ \[ImaginaryI]\)\)]],
  ",  \n\nand Theorem 6.12 further implies that  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\( 
                1\/\((z\  - \ z\_0)\)\^\(n + 1\)\) \[DifferentialD]z\ \  = \ \
\ \(\(\(2  \[Pi]\ \[ImaginaryI]\)\/\(n!\)\) \(f\^\((n)\)\) \((z\_0)\)\ \  = \ \
\ 0\)\)]],
  ".  \n\nThis result is the same as that proven earlier in Corollary 6.1.  \
Obviously, though, the technique of using Theorems 6.10 and 6.12 is easier."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.24 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Show that ",
  Cell[BoxData[
      \(\[Integral]\_C\( 1\/\(z\  - \ z\_0\)\) \[DifferentialD]z = 
        2  \[Pi]\ \[ImaginaryI]\)]],
  ".  Use the Cauchy Integral Formula in the form ",
  Cell[BoxData[
      \(\[Integral]\_C\(\( f \((z)\)\)\/\(z\  - \ 
                  z\_0\)\) \[DifferentialD]z = 
        2  \[Pi]\ \[ImaginaryI]\ f \((z\_0)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, w];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(z0 = z\_0;\)\ \), "\[IndentingNewLine]", 
    \(\(w[z_]\  = \ 1\/\(z - z0\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(z\_0\)] = \>\"", 
        f[z0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Use Cauchy's Integral Formula\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\)\!\(\(f \((z)\)\)\/\(z - z\_0\)\)\
\[DifferentialD]z = 2\[Pi]\[ImaginaryI] f(\!\(z\_0\)) = \
2\[Pi]\[ImaginaryI](\>\"", f[z0], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\)\!\(\(f \((z)\)\)\/\(z - z\_0\)\)\
\[DifferentialD]z = \>\"", 
        2\ \[Pi]\ \[ImaginaryI]\ f[z0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Thus, we have found the value of the contour integral.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{Red, PointSize[0.03], 
            Point[{2, 5\/3}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(center = 
        Graphics[{Text[
              StyleForm[TraditionalForm[\*"\"\<\!\(z\_0\)\>\""], 
                FontSize \[Rule] 12], {2, 1.6}, {0, 
                1}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{2, 5\/3}, 1]}];\)\ \), "\n", 
    \(\(Show[center, contour, dot, PlotRange \[Rule] {{0, 4}, {0, 3}}, 
        Ticks \[Rule] None, \[IndentingNewLine]AspectRatio \[Rule] 3\/4, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) \>\"", 
      w[z], "\< \[DifferentialD]z = \>", 
      2\ \[Pi]\ \[ImaginaryI]\ f[z0]]\), "\[IndentingNewLine]", 
    \(\(Print["\<For illustration,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<a contour could be the unit circle C: |z - \!\(z\_0\)| = \
r,\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<with positive orientation.\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.24 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Show that  ",
  Cell[BoxData[
      \(\[Integral]\_C\( 1\/\((z\  - \ z\_0)\)\^m\) \[DifferentialD]z = 
        0\)]],
  ",  when  ",
  Cell[BoxData[
      \(m \[NotEqual] 1\)]],
  "  is an integer. \n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  If  m  is an integer and  m < 0,  then  m = -n,  where  n  is a positive \
integer and the integrand is  ",
  Cell[BoxData[
      \(f \((z)\) = \((z - z\_0)\)\^n\)]],
  "\n which is a polynomial of degree n.  Hence in this case, f(z) would be \
analytic and the Cauchy-Goursat theorem implies that the value of the \
integral is zero.\n \n Now we consider the case when m is a positive integer \
and  m > 1.\n Use the Cauchy's Integral Formulae for Derivatives in the form  \
",
  Cell[BoxData[
      \(\[Integral]\_C\(\( 
                  f \((z)\)\)\/\((z - z\_0)\)\^\(n + 1\)\) \[DifferentialD]z \
= \(\(2  \[Pi]\ \[ImaginaryI]\)\/\(n!\)\) \(f\^\((n)\)\) \((z\_0)\)\)]],
  "\n \n",
  StyleBox[" For illustration.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  We use m = 5,  and  f(z) = 1.  Then  m = 5 = n + 1 implies that  n = 4."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, w];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, z0];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(n\  = \ 4;\)\ \), "\[IndentingNewLine]", 
    \(\(z0 = z\_0;\)\ \), "\[IndentingNewLine]", 
    \(\(w[z_]\  = \ 
        1\/\((z - z0)\)\^\(n + 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(fn[z_] = D[f[z], {z, n}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<n = \>", n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(f\^\((n)\)\)[z] = \>\"", 
        fn[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(z\_0\) = \>\"", 
        z0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(f\^\((n)\)\)[\>\"", z0, "\<] = \>", 
        fn[z0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Use Cauchy's Integral Formulae for Derivatives\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\)\!\(\(f \((z)\)\)\/\((z - \
z\_0)\)\^\(n + 1\)\)\[DifferentialD]z = \!\(\(2  \[Pi]\\\ \
\[ImaginaryI]\)\/\(n!\)\) \!\(f\^\((n)\)\)[\>\"", 
        z0, \*"\"\<] = \!\(\(2  \[Pi]\\\ \[ImaginaryI]\)\/\(n!\)\)(\>\"", 
        fn[z0], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\)\!\(\(f \((z)\)\)\/\((z - \
z\_0)\)\^\(n + 1\)\)\[DifferentialD]z = \>\"", 
        2\ \[Pi]\ \[ImaginaryI]\ fn[z0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Thus, we have found the value of the contour integral.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{Red, PointSize[0.03], 
            Point[{2, 5\/3}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(center = 
        Graphics[{Text[
              StyleForm[TraditionalForm[\*"\"\<\!\(z\_0\)\>\""], 
                FontSize \[Rule] 12], {2, 1.6}, {0, 
                1}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{2, 5\/3}, 1]}];\)\ \), "\n", 
    \(\(Show[center, contour, dot, PlotRange \[Rule] {{0, 4}, {0, 3}}, 
        Ticks \[Rule] None, \[IndentingNewLine]AspectRatio \[Rule] 3\/4, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) \>\"", 
      w[z], "\< \[DifferentialD]z = \>", 
      2\ \[Pi]\ \[ImaginaryI]\ f[z0]]\), "\[IndentingNewLine]", 
    \(\(Print["\<For illustration,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<a contour could be the unit circle C :|z - \!\(z\_0\)| = \
r,\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<with positive orientation.\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.25.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that",
  Cell[BoxData[
      \(\[Integral]\_C\( \[ExponentialE]\^\(z\^2\)\/\((z\  - \ \[ImaginaryI])\
\)\^4\) \[DifferentialD]z = \(\(-\ 4\)\ \[Pi]\)\/\(3\ \[ExponentialE]\)\)]],
  ",  where",
  " ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is the circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 2\)]],
  "  with positive orientation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.5 0.238095 [
[.02381 .4875 -6 -9 ]
[.02381 .4875 6 0 ]
[.2619 .4875 -6 -9 ]
[.2619 .4875 6 0 ]
[.7381 .4875 -3 -9 ]
[.7381 .4875 3 0 ]
[.97619 .4875 -3 -9 ]
[.97619 .4875 3 0 ]
[1.025 .5 0 -6.28125 ]
[1.025 .5 10 6.28125 ]
[.4875 .02381 -12 -4.5 ]
[.4875 .02381 0 4.5 ]
[.4875 .2619 -12 -4.5 ]
[.4875 .2619 0 4.5 ]
[.4875 .7381 -6 -4.5 ]
[.4875 .7381 0 4.5 ]
[.4875 .97619 -6 -4.5 ]
[.4875 .97619 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .5 m
.02381 .50625 L
s
[(-2)] .02381 .4875 0 1 Mshowa
.2619 .5 m
.2619 .50625 L
s
[(-1)] .2619 .4875 0 1 Mshowa
.7381 .5 m
.7381 .50625 L
s
[(1)] .7381 .4875 0 1 Mshowa
.97619 .5 m
.97619 .50625 L
s
[(2)] .97619 .4875 0 1 Mshowa
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .02381 m
.50625 .02381 L
s
[(-2)] .4875 .02381 1 0 Mshowa
.5 .2619 m
.50625 .2619 L
s
[(-1)] .4875 .2619 1 0 Mshowa
.5 .7381 m
.50625 .7381 L
s
[(1)] .4875 .7381 1 0 Mshowa
.5 .97619 m
.50625 .97619 L
s
[(2)] .4875 .97619 1 0 Mshowa
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.03 w
.5 .7381 Mdot
0 g
gsave
.5 .7619 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 14.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
newpath
.5 .5 .47619 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{175, 175},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002_0000[b000`400?l00000o`00003o[`3oool0
0540oooo00<000000?ooo`3oool0F`3oool00540oooo00<000000?ooo`3oool0F`3oool004X0oooo
100000030?ooo`030000003oool0oooo05/0oooo001:0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0F`3oool004T0oooo40000?mF0?ooo`00@P3oool70000o`<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`L0003oC`3oool003h0oooo10000?l80?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0303oool40000od/0oooo000k0?ooo`<0
003o3@3oool2000000@0oooo00<000000?ooo`3oool0403oool40000odL0oooo000g0?ooo`@0003o
5P3oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo04@0oooo000e0?ooo`80003o6P3o
ool00`000000oooo0?ooo`0E0?ooo`@0003o@P3oool003@0oooo00<0003o0?ooo`3oool06P3oool0
0`000000oooo0?ooo`0I0?ooo`80003o@03oool00300oooo10000?lM0?ooo`030000003oool0oooo
01/0oooo0`000?lm0?ooo`00;`3oool00`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo01h0
oooo0P000?lk0?ooo`00;@3oool20000ob80oooo00<000000?ooo`3oool0803oool00`000?l0oooo
0?ooo`0h0?ooo`00:`3oool20000ob@0oooo00<000000?ooo`3oool08@3oool20000ocP0oooo000Z
0?ooo`030000o`3oool0oooo02@0oooo00<000000?ooo`3oool08`3oool20000ocH0oooo000X0?oo
o`80003o9`3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo03<0oooo000W0?ooo`03
0000o`3oool0oooo02L0oooo00<000000?ooo`3oool09P3oool20000oc<0oooo000U0?ooo`80003o
:P3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0300oooo000S0?ooo`80003o;03o
ool00`000000oooo0?ooo`0Y0?ooo`80003o<03oool00280oooo00<0003o0?ooo`3oool0;03oool0
0`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo02d0oooo000Q0?ooo`030000o`3oool0oooo
02d0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0/0?ooo`00803oool00`000?l0
oooo0?ooo`0^0?ooo`030000003oool0oooo02d0oooo00<0003o0?ooo`3oool0:`3oool001l0oooo
00<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo02X0oooo
000N0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0;`3oool20000obX0oooo000M
0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0W
0?ooo`00703oool00`000?l0oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<0003o0?oo
o`3oool09P3oool001/0oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`03
0000o`3oool0oooo02H0oooo000J0?ooo`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool0
<`3oool00`000?l0oooo0?ooo`0U0?ooo`006@3oool00`000?l0oooo0?ooo`0e0?ooo`030000003o
ool0oooo03@0oooo00<0003o0?ooo`3oool0903oool001T0oooo00<0003o0?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0e0?ooo`030000o`3oool0oooo02<0oooo000H0?ooo`030000o`3oool0oooo
03H0oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`0R0?ooo`005`3oool00`000?l0
oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<0003o0?ooo`3oool08@3oool001H0oooo
00<0003o0?ooo`3oool0>03oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo0240oooo
000E0?ooo`030000o`3oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`000?l0oooo0?oo
o`0P0?ooo`00503oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo03T0oooo00<0003o
0?ooo`3oool07`3oool001<0oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0i0?oo
o`030000o`3oool0oooo01l0oooo000C0?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3o
ool0>P3oool00`000?l0oooo0?ooo`0N0?ooo`004P3oool00`000?l0oooo0?ooo`0l0?ooo`030000
003oool0oooo03/0oooo00<0003o0?ooo`3oool07@3oool00140oooo00<0003o0?ooo`3oool0=P3o
ool500000080oooo00<000000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`0M0?ooo`004@3oool0
0`000?l0oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool0
0`000?l0oooo0?ooo`0L0?ooo`00403oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo
0080oooo0P00000n0?ooo`030000o`3oool0oooo01/0oooo000?0?ooo`030000o`3oool0oooo0380
oooo100000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?@3oool00`000?l0
oooo0?ooo`0K0?ooo`003`3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0?P3oool00`000?l0oooo0?ooo`0J0?ooo`003P3oool00`000?l0oooo0?oo
o`0j0?ooo`800000103oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo01X0oooo000>
0?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0I
0?ooo`003@3oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo0400oooo00<0003o0?oo
o`3oool0603oool000d0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`03
0000o`3oool0oooo01P0oooo000=0?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0
@@3oool00`000?l0oooo0?ooo`0G0?ooo`00303oool00`000?l0oooo0?ooo`120?ooo`030000003o
ool0oooo0440oooo00<0003o0?ooo`3oool05`3oool000`0oooo00<0003o0?ooo`3oool0@P3oool0
0`000000oooo0?ooo`110?ooo`030000o`3oool0oooo01L0oooo000;0?ooo`030000o`3oool0oooo
04<0oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0F0?ooo`002`3oool00`000?l0
oooo0?ooo`130?ooo`030000003oool0oooo0480oooo00<0003o0?ooo`3oool05P3oool000/0oooo
00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`130?ooo`030000o`3oool0oooo01D0oooo
000:0?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?oo
o`0E0?ooo`002P3oool00`000?l0oooo0?ooo`140?ooo`030000003oool0oooo04<0oooo00<0003o
0?ooo`3oool05@3oool000T0oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`130?oo
o`030000o`3oool0oooo01D0oooo00090?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3o
ool0A03oool00`000?l0oooo0?ooo`0D0?ooo`002@3oool00`000?l0oooo0?ooo`150?ooo`030000
003oool0oooo04D0oooo00<0003o0?ooo`3oool04`3oool000P0oooo00<0003o0?ooo`3oool0AP3o
ool00`000000oooo0?ooo`150?ooo`030000o`3oool0oooo01<0oooo00080?ooo`030000o`3oool0
oooo04H0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`0C0?ooo`00203oool00`00
0?l0oooo0?ooo`160?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool04`3oool000P0
oooo00<0003o0?ooo`3oool0AP3oool00`000000oooo0?ooo`150?ooo`030000o`3oool0oooo01<0
oooo00080?ooo`030000o`3oool0oooo04H0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo
0?ooo`0C0?ooo`00203oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo04H0oooo00<0
003o0?ooo`3oool04P3oool000L0oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`16
0?ooo`030000o`3oool0oooo0180oooo00070?ooo`030000o`3oool0oooo04L0oooo00<000000?oo
o`3oool0AP3oool00`000?l0oooo0?ooo`0B0?ooo`001`3oool00`000?l0oooo0?ooo`170?ooo`03
0000003oool0oooo04H0oooo00<0003o0?ooo`3oool04P3oool000L0oooo00<0003o0?ooo`3oool0
A`3oool00`000000oooo0?ooo`160?ooo`030000o`3oool0oooo0180oooo00070?ooo`040000o`00
0000000000000240oooo1@00000P0?ooo`030000003oool0oooo0200oooo1@00000P0?ooo`800000
00<0003o0000003oool04@3oool000H0oooo00<0003o0000003oool09@3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0803oool00`000000oooo0000
o`0C0?ooo`001P3oool00`000?l0oooo0000000U0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`03000000000?l0oooo0180oooo00000`3o
ool0000000000002000000050?ooo`000?l0oooo0?ooo`000000703oool4000000@0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<0003o
0?ooo`3oool04@3oool000H0oooo00D0003o0000003oool0oooo0000000S0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0P0?ooo`040000003oool0
003o00000180oooo00060?ooo`040000o`3oool00000000002<0oooo0P00000R0?ooo`030000003o
ool0oooo0240oooo0P00000S0?ooo`03000000000?l0oooo0180oooo00060?ooo`030000o`3oool0
oooo04P0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0A0?ooo`001P3oool00`00
0?l0oooo0?ooo`180?ooo`030000003oool0oooo04L0oooo00<0003o0?ooo`3oool04@3oool000H0
oooo00<0003o0?ooo`3oool0B03oool00`000000oooo0?ooo`170?ooo`030000o`3oool0oooo00L0
oooo0P0000000`3oool00000000000050?ooo`001P3oool00`000?l0oooo0?ooo`180?ooo`030000
003oool0oooo04L0oooo00<0003o0?ooo`3oool0203oool00`000000oooo000000060?ooo`000P3o
ool4000000030000o`00000000000980000000<0003o0000000000000P0000070?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000o`3oool0oooo0280oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool01`3oool2
000000030?ooo`000000000000D0oooo00060?ooo`030000o`3oool0oooo04P0oooo00<000000?oo
o`3oool0A`3oool00`000?l0oooo0?ooo`0A0?ooo`001P3oool00`000?l0oooo0?ooo`180?ooo`03
0000003oool0oooo04L0oooo00<0003o0?ooo`3oool04@3oool000H0oooo00<0003o0?ooo`3oool0
B03oool00`000000oooo0?ooo`170?ooo`030000o`3oool0oooo0140oooo00060?ooo`030000o`3o
ool0oooo04P0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0A0?ooo`001P3oool0
0`000?l0oooo0?ooo`180?ooo`030000003oool0oooo04L0oooo00<0003o0?ooo`3oool04@3oool0
00H0oooo00<0003o0?ooo`3oool0B03oool00`000000oooo0?ooo`170?ooo`030000o`3oool0oooo
0140oooo00060?ooo`030000o`3oool0oooo04P0oooo00<000000?ooo`3oool0A`3oool00`000?l0
oooo0?ooo`0A0?ooo`001`3oool00`000?l0oooo0?ooo`170?ooo`030000003oool0oooo04L0oooo
00<0003o0?ooo`3oool04@3oool000L0oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?oo
o`160?ooo`030000o`3oool0oooo0180oooo00070?ooo`030000o`3oool0oooo04L0oooo00<00000
0?ooo`3oool0AP3oool00`000?l0oooo0?ooo`0B0?ooo`001`3oool00`000?l0oooo0?ooo`170?oo
o`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool04P3oool000L0oooo00<0003o0?ooo`3o
ool0A`3oool00`000000oooo0?ooo`160?ooo`030000o`3oool0oooo0180oooo00080?ooo`030000
o`3oool0oooo04H0oooo00<000000?ooo`3oool0AP3oool00`000?l0oooo0?ooo`0B0?ooo`00203o
ool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool04`3o
ool000P0oooo00<0003o0?ooo`3oool0AP3oool00`000000oooo0?ooo`150?ooo`030000o`3oool0
oooo01<0oooo00080?ooo`030000o`3oool0oooo04H0oooo00<000000?ooo`3oool0A@3oool00`00
0?l0oooo0?ooo`0C0?ooo`00203oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo04D0
oooo00<0003o0?ooo`3oool04`3oool000P0oooo00<0003o0?ooo`3oool0AP3oool00`000000oooo
0?ooo`150?ooo`030000o`3oool0oooo01<0oooo00090?ooo`030000o`3oool0oooo04D0oooo00<0
00000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`0C0?ooo`002@3oool00`000?l0oooo0?ooo`15
0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool0503oool000T0oooo00<0003o0?oo
o`3oool0A@3oool00`000000oooo0?ooo`140?ooo`030000o`3oool0oooo01@0oooo000:0?ooo`03
0000o`3oool0oooo04@0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0E0?ooo`00
2P3oool00`000?l0oooo0?ooo`140?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool0
5@3oool000/0oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`130?ooo`030000o`3o
ool0oooo01D0oooo000;0?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0@P3oool0
0`000?l0oooo0?ooo`0F0?ooo`002`3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo
0480oooo00<0003o0?ooo`3oool05P3oool000/0oooo00<0003o0?ooo`3oool0@`3oool00`000000
oooo0?ooo`110?ooo`030000o`3oool0oooo01L0oooo000<0?ooo`030000o`3oool0oooo0480oooo
00<000000?ooo`3oool0@@3oool00`000?l0oooo0?ooo`0G0?ooo`003@3oool00`000?l0oooo0?oo
o`110?ooo`030000003oool0oooo0440oooo00<0003o0?ooo`3oool05`3oool000d0oooo00<0003o
0?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo01P0oooo000=0?oo
o`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0H0?oo
o`003@3oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3o
ool06@3oool000h0oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`0o0?ooo`030000
o`3oool0oooo01T0oooo000?0?ooo`030000o`3oool0oooo03P0oooo1@0000020?ooo`030000003o
ool0oooo03h0oooo00<0003o0?ooo`3oool06P3oool000l0oooo00<0003o0?ooo`3oool0>P3oool0
10000000oooo0?ooo`3oool20?l003l0oooo00<0003o0?ooo`3oool06`3oool00100oooo00<0003o
0?ooo`3oool0>@3oool00`000000oooo0?ooo`040?l000L0oooo1@00000b0?ooo`030000o`3oool0
oooo01/0oooo000@0?ooo`030000o`3oool0oooo03T0oooo00<000000?ooo`3oool0103o00090?oo
o`030000003oool0oooo0340oooo00<0003o0?ooo`3oool0703oool00140oooo00<0003o0?ooo`3o
ool0>03oool010000000oooo0?ooo`3oool20?l00080oooo1@0000030?ooo`030000003oool0oooo
0340oooo00<0003o0?ooo`3oool0703oool00180oooo00<0003o0?ooo`3oool0=P3oool2000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000<P3oool0
0`000?l0oooo0?ooo`0M0?ooo`004P3oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0oooo
01h0oooo000C0?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`3oool200000340oooo00<0003o0?ooo`3oool07P3oool001@0oooo00<0003o0?ooo`3o
ool0>P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0<P3oool00`00
0?l0oooo0?ooo`0O0?ooo`00503oool00`000?l0oooo0?ooo`0j0?ooo`040000003oool0oooo0?oo
o`D00000<`3oool00`000?l0oooo0?ooo`0O0?ooo`005@3oool00`000?l0oooo0?ooo`0i0?ooo`03
0000003oool0oooo03P0oooo00<0003o0?ooo`3oool0803oool001H0oooo00<0003o0?ooo`3oool0
>03oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo0240oooo000F0?ooo`030000o`3o
ool0oooo03P0oooo00<000000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0Q0?ooo`005`3oool0
0`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo03H0oooo00<0003o0?ooo`3oool08P3oool0
01P0oooo0P000?lg0?ooo`030000003oool0oooo03@0oooo0P000?lU0?ooo`006P3oool00`000?l0
oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0003o0?ooo`3oool09@3oool001/0oooo
00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo02H0oooo
000L0?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo0?oo
o`0V0?ooo`007@3oool00`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<0003o
0?ooo`3oool09`3oool001h0oooo00<0003o0?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?oo
o`030000o`3oool0oooo02P0oooo000N0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3o
ool0;`3oool00`000?l0oooo0?ooo`0Y0?ooo`007`3oool00`000?l0oooo0?ooo`0_0?ooo`030000
003oool0oooo02h0oooo00<0003o0?ooo`3oool0:P3oool00200oooo0P000?l_0?ooo`030000003o
ool0oooo02`0oooo0P000?l]0?ooo`008P3oool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0
oooo02/0oooo00<0003o0?ooo`3oool0;@3oool002<0oooo0P000?l/0?ooo`030000003oool0oooo
02T0oooo0P000?l`0?ooo`009@3oool00`000?l0oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0
oooo00<0003o0?ooo`3oool0<03oool002H0oooo0P000?lY0?ooo`030000003oool0oooo02L0oooo
00<0003o0?ooo`3oool0<@3oool002P0oooo00<0003o0?ooo`3oool09P3oool00`000000oooo0?oo
o`0U0?ooo`80003o=03oool002T0oooo0P000?lV0?ooo`030000003oool0oooo02@0oooo00<0003o
0?ooo`3oool0=03oool002/0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?oo
o`80003o=`3oool002`0oooo0P000?lS0?ooo`030000003oool0oooo0200oooo0P000?li0?ooo`00
;P3oool20000ob40oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0i0?ooo`00<03o
ool00`000?l0oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo0P000?ll0?ooo`00<@3oool4
0000oa`0oooo00<000000?ooo`3oool06P3oool30000och0oooo000e0?ooo`030000o`3oool0oooo
01T0oooo00<000000?ooo`3oool0603oool20000od40oooo000f0?ooo`@0003o5`3oool00`000000
oooo0?ooo`0D0?ooo`@0003o@`3oool003X0oooo0`000?lD0?ooo`030000003oool0oooo0140oooo
0`000?m70?ooo`00?@3oool40000o`T0oooo100000030?ooo`030000003oool0oooo00d0oooo1000
0?m:0?ooo`00@@3oool60000o`<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`08
0?ooo`D0003oCP3oool004L0oooo5@000?mC0?ooo`00C03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo05/0oooo001:0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0F`3oool004/0oooo0P0000040?ooo`030000003oool0oooo05/0oooo001A0?ooo`030000003o
ool0oooo05/0oooo002_0?ooo`00[`3oool00:l0oooo002_0?ooo`00[`3oool00:l0oooo001?0?oo
o`800000GP3oool00500oooo00<000000?ooo`3oool0G03oool00540oooo00<000000?ooo`3oool0
F`3oool00500oooo00<000000?ooo`000000G03oool004l0oooo00@000000?ooo`3oool00000G03o
ool004h0oooo0`0000000`3oool000000000001K0?ooo`00[`3oool00:l0oooo002_0?ooo`00[`3o
ool00001\
\>"],
    ImageRangeCache->{{{0, 174}, {174, 0}} -> {-2, -2, 0, 0}}],
  "   "
}], "Text"],

Cell[TextData[{
  "Solution.  If we set  ",
  Cell[BoxData[
      \(f \((z)\) = \[ExponentialE]\^\(z\^2\)\)]],
  ",  then a straightforward calculation shows that  ",
  Cell[BoxData[
      \(\(f\^\((3)\)\) \((z)\)\  = \ \ \((\ 
            12\ z + 8\ z\^3)\) \[ExponentialE]\^\(z\^2\)\)]],
  ".   Using Cauchy's integral formulas with ",
  Cell[BoxData[
      \(n = 3\)]],
  ", we conclude that  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_C\( \[ExponentialE]\^\(z\^2\)\/\((z\  - \ \
\[ImaginaryI])\)\^4\) \[DifferentialD]z\ \  = \ \ \(\(\(2  \[Pi]\ \
\[ImaginaryI]\)\/\(3!\)\) \(f\^\((3)\)\) \((\[ImaginaryI])\)\ \  = \ \ \(\(2  \
\[Pi]\ \[ImaginaryI]\)\/\(3!\)\) \((\ 
              12\ \[ImaginaryI] + 
                8\ \[ImaginaryI]\^3)\) \
\[ExponentialE]\^\(\[ImaginaryI]\^2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\(\(2  \[Pi]\ \[ImaginaryI]\)\/\(3!\)\) \((\ 
              12\ \[ImaginaryI] - 
                8\ \[ImaginaryI])\) \[ExponentialE]\^\(-1\)\ \ \  = \ \ \ \
\(\(2  \[Pi]\ \[ImaginaryI]\)\/\(3!\)\) \(4\ \[ImaginaryI]\)\/\[ExponentialE]\
\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\
\(-\(\(4\ \[Pi]\)\/\(3\ \[ExponentialE]\)\)\)\)\)}]],
  "  \n"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 6.25.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the integrand  ",
  Cell[BoxData[
      \(w[z] = \[ExponentialE]\^\(z\^2\)\/\((z\  - \ \[ImaginaryI])\)\^4\)],
    AspectRatioFixed->True],
  "  and locate the singularities."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[w, z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, i, solset, val];\)\ \), "\n", 
    \(\(w[
          z_]\  = \ \[ExponentialE]\^\(z\^2\)\/\((z\  - \ \
\[ImaginaryI])\)\^4;\)\ \), "\n", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[w[z]] \[Equal] 0, z]];\)\ \), "\n", 
    \(\(Z\  = \ Table[0, {Length[solset]}];\)\ \), "\n", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[solset], \(i++\), \[IndentingNewLine]\(Z\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
            ReplaceAll[z, 
              solset\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\
\)];\)\ ];\)\ \), "\n", 
    \(\(Print["\<w[z] = \>", w[z]];\)\ \), "\n", 
    \(\(Print["\<The set of singularities is \>", 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Find the singularity that lie inside  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(Print[\*"\"\<\!\(z\_1\) = \>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<,   \
 Is |\>", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), "\<| < \
2 ?    \>", 
        N[Abs[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]] \
< 2];\)\(\ \)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[TextData[{
  "Since  z = i  is a singularity of order  n = 4 , multiply the integrand by \
",
  Cell[BoxData[
      \(\((z - \[ImaginaryI])\)\^4\)]],
  " to obtain the function f(z)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_]\  = \ 
        w[z]\ \((z\  - \ Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\))\)\^4;\)\ \), "\n", 
    \(\(Print["\<w[z] = \>", w[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[z] = (\>", 
        f[z], "\<)/(\>", \((z\  - \ Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\))\)\^4, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use Cauchy's Integral Formula for Derivatives to evaluate the integral of  \
",
  Cell[BoxData[
      \(w[z] = \[ExponentialE]\^\(z\^2\)\/\((z\  - \ \[ImaginaryI])\)\^4\)],
    AspectRatioFixed->True],
  " taken over ",
  StyleBox["C",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f3\  = \ Simplify[Expand[\(\(\(f'\)'\)'\)[z]]];\)\ \), "\n", 
    \(\(val\  = \ \(2\ \[Pi]\ \[ImaginaryI]\)\/\(3!\)\ \(\(\(f'\)'\)'\)[
            Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = \>", "\<f[z]\>"\/\((z\  - \ \
Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\))\)\^4];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f'''[z] = \>", f3];\)\ \), "\n", 
    \(\(Print[\*"\"\<      \!\(z\_1\) = \>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\ \
\), "\n", 
    \(\(Print[\*"\"\<f'''[\!\(z\_1\)] = \>\"", \ \(\(\(f'\)'\)'\)[
          Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<       n = 3\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<Use Cauchy's Integral Formulae for Derivatives\>"]; \ 
    Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
      w[z], \*"\"\< \[DifferentialD]z = \!\(\[Integral]\_C\)\!\(\(f \((z)\)\)\
\/\((z - z\_1)\)\^\(n + 1\)\)\[DifferentialD]z = \!\(\(2  \[Pi]\\\ \
\[ImaginaryI]\)\/\(n!\)\) \!\(f\^\((n)\)\)[\!\(z\_1\)]\>\""]\), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_C\) \>\"", 
        w[z], \*"\"\< \[DifferentialD]z = \!\(\(2  \[Pi]\\\ \[ImaginaryI]\)\/\
\(3!\)\) f'''[\>\"", 
        Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), \
\*"\"\<] = \!\(\(2  \[Pi]\\\ \[ImaginaryI]\)\/\(3!\)\)(\>\"", \(f'''\)[
          Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)], \
"\<) = \>", val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Thus, we have found the value of the contour integral.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{Red, PointSize[0.03], 
            Point[{Re[
                  Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)], Im[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]}]}];\)\
\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[
              StyleForm[TraditionalForm[\*"\"\<\!\(z\_1\)\>\""], 
                FontSize \[Rule] 12], {Re[
                  Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)], Im[Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)] + 
                  0.1}, {\(-1\), 0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 2]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-2.1\), 2.1}, {\(-2.1\), 2.1}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\n", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
      w[z], "\<) \[DifferentialD]z = \>", val]\), "\[IndentingNewLine]", 
    \(\(Print["\<The contour is the circle  C: |z| = 2,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<with positive orientation.\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell["\tWe now state two important corollaries of Theorem 6.12. ", "Text"],

Cell[TextData[{
  StyleBox["Corollary 6.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " is analytic in the domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", then all derivatives  ",
  Cell[BoxData[
      RowBox[{\(f' \((z)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(f'' \((z)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  " ",
  Cell[BoxData[
      RowBox[{\(\(f\^\((n)\)\) \((z)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  "  exists for  ",
  Cell[BoxData[
      \(z \[Element] D\)]],
  "  (and therefore are analytic in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ")."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 6.2 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark 6.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  This result is interesting, as it illustrates a big difference between \
real and complex functions.  A real function ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " can have the property that ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " exists everywhere in a domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", but ",
  Cell[BoxData[
      \(f'' \((z)\)\)]],
  " exists nowhere.  Corollary 6.2 states that if a complex function ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " has the property that ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  "exists everywhere in a domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", then, remarkably, all derivatives of ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " exist in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Corollary 6.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If ",
  Cell[BoxData[
      RowBox[{"u", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " is a harmonic function at each point ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"x", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "y"}], ")"}]]],
  " in the domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", then all partial derivatives  ",
  Cell[BoxData[
      RowBox[{\(u\_x\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ", ",
  Cell[BoxData[
      RowBox[{\(u\_y\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ", ",
  Cell[BoxData[
      RowBox[{\(u\_xx\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ", ",
  Cell[BoxData[
      RowBox[{\(u\_xy\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ", ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_yy\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  "  exists and are harmonic functions.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 6.3 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the partial derivatives of  ",
  Cell[BoxData[
      \(u \((x, y)\)\  = \ 
        x\^7 - 21\ x\^5\ y\^2 + 35\ x\^3\ y\^4 - 7\ x\ y\^6\)]],
  " are harmonic functions.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[x, y, u, z];\)\ \), "\[IndentingNewLine]", 
    \(\(TagSet[x, Im[x], 0];\)\ \), "\n", 
    \(\(TagSet[y, Im[y], 0];\)\ \), "\n", 
    \(\(TagSet[x, Re[x], x];\)\ \), "\n", 
    \(\(TagSet[y, Re[y], y];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = z\^7;\)\), "\[IndentingNewLine]", 
    \(\(u[x_, y_]\  = \ 
        ComplexExpand[
          Re[f[x + \[ImaginaryI]\ y]]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<    f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x+\[ImaginaryI] y] = \>", 
        f[x + \[ImaginaryI]\ y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x+\[ImaginaryI] y] = \>", 
        ComplexExpand[
          f[x + \[ImaginaryI]\ y]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The real part is u[x,y]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = Re[f[z]]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = Re[\>", 
        ComplexExpand[
          f[x + \[ImaginaryI]\ y]], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", u[x, y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Therefore, u[x,y] is a harmonic function.\>"];\)\)}], "Input"],

Cell[TextData[{
  "According to Corollary 6.3, all of its partial derivatives  ",
  Cell[BoxData[
      RowBox[{\(u\_x\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ", ",
  Cell[BoxData[
      RowBox[{\(u\_y\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ", ",
  Cell[BoxData[
      RowBox[{\(u\_xx\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ", ",
  Cell[BoxData[
      RowBox[{\(u\_xy\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ", ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(u\_yy\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  "  exists and are harmonic functions.  \n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to verify Laplace's equation for some of these functions. "
}], "Text"],

Cell[BoxData[
    \(\(\(laplace[u0_]\  := \ 
        Module[{\[Phi]}, \[IndentingNewLine]Apply[
            Set, {\[Phi][x_, y_], 
              u0}]; \[IndentingNewLine]Print["\<   \[Phi][x,y] = \>", \[Phi][
              x, y]]; \[IndentingNewLine]Print[\*"\"\<\!\(\[PartialD]\_\(x, x\
\)\)\[Phi][x,y] = \>\"", \[PartialD]\_\(x, x\)\[Phi][x, 
                y]]; \[IndentingNewLine]Print[\*"\"\<\!\(\[PartialD]\_\(y, \
y\)\)\[Phi][x,y] = \>\"", \[PartialD]\_\(y, y\)\[Phi][x, 
                y]]; \[IndentingNewLine]lap = 
            FullSimplify[\[PartialD]\_\(x, x\)\[Phi][x, 
                    y]\  + \ \[PartialD]\_\(y, y\)\[Phi][x, 
                    y]]; \[IndentingNewLine]Print[\*"\"\<\!\(\[PartialD]\_\(x,\
 x\)\)\[Phi][x,y] + \!\(\[PartialD]\_\(y, y\)\)\[Phi][x,y] = \>\"", 
            lap\ ]; \ \ \[IndentingNewLine]If[
            lap \[Equal] 
              0, \(Print["\<Therefore, \[Phi][x,y] is harmonic.\>"\ ];\)\ ];\ \
\ ];\)\(\ \)\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<   \[Phi][x,y] = u[x,y]\>"];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_x\)u[x,y]\>\""];\)\), \
"\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_x\ u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_y\)u[x,y]\>\""];\)\), \
"\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_y\ u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(x, \
x\)\)u[x,y]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(x, x\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(x, \
y\)\)u[x,y]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(x, y\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(y, \
y\)\)u[x,y]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(y, y\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(x, x, \
x\)\)u[x,y]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(x, x, x\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(x, x, \
y\)\)u[x,y]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(x, x, y\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(x, y, \
y\)\)u[x,y]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(x, y, y\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(y, y, \
y\)\)u[x,y]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(y, y, y\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(x, x, x, x\)\)u[x,y]\
\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(x, x, x, x\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(x, x, x, y\)\)u[x,y]\
\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(x, x, x, y\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(x, x, y, y\)\)u[x,y]\
\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(x, x, y, y\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(x, y, y, y\)\)u[x,y]\
\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(x, y, y, y\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(y, y, y, y\)\)u[x,y]\
\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(y, y, y, y\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(x, x, x, x, \
x\)\)u[x,y]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(x, x, x, x, x\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(x, x, x, x, \
y\)\)u[x,y]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(x, x, x, x, y\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(x, x, x, y, \
y\)\)u[x,y]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(x, x, x, y, y\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(x, x, y, y, \
y\)\)u[x,y]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(x, x, y, y, y\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(x, y, y, y, \
y\)\)u[x,y]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(x, y, y, y, y\)u[x, y]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \[Phi][x,y] = \!\(\[PartialD]\_\(y, y, y, y, \
y\)\)u[x,y]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(laplace[\ \[PartialD]\_\(y, y, y, y, y\)u[x, y]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Cauchy-Goursat Theorem",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/CauchyGoursatBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Cauchy's Integral Formula",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/CauchyIntegraBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{987, 650},
WindowMargins->{{Automatic, 12}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[5388, 168, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[96617, 2404, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[100092, 2519, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[155155, 3809, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[160264, 3981, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 172403, 4310}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 145, 3, 33, "Text"],
Cell[2250, 67, 1631, 45, 90, "Text",
  Evaluatable->False],
Cell[3884, 114, 1153, 38, 98, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5062, 156, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[5210, 162, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[5388, 168, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[5748, 180, 528, 18, 34, "Text",
  Evaluatable->False],
Cell[6279, 200, 19684, 418, 194, "Text"],
Cell[25966, 620, 813, 22, 117, "Text"],

Cell[CellGroupData[{
Cell[26804, 646, 112, 2, 33, "Text"],
Cell[26919, 650, 188, 6, 36, "Text"],
Cell[27110, 658, 825, 18, 225, "Input"],
Cell[27938, 678, 184, 7, 33, "Text",
  Evaluatable->False],
Cell[28125, 687, 404, 9, 50, "Input"],
Cell[28532, 698, 99, 2, 33, "Text",
  Evaluatable->False],
Cell[28634, 702, 562, 12, 130, "Input"],
Cell[29199, 716, 316, 12, 36, "Text",
  Evaluatable->False],
Cell[29518, 730, 1383, 28, 277, "Input"],
Cell[30904, 760, 118, 2, 33, "Text",
  Evaluatable->False],
Cell[31025, 764, 1438, 28, 234, "Input"]
}, Closed]],
Cell[32478, 795, 569, 20, 40, "Text",
  Evaluatable->False],
Cell[33050, 817, 20024, 441, 194, "Text"],
Cell[53077, 1260, 1188, 25, 188, "Text"],

Cell[CellGroupData[{
Cell[54290, 1289, 112, 2, 33, "Text"],
Cell[54405, 1293, 183, 6, 37, "Text"],
Cell[54591, 1301, 824, 18, 224, "Input"],
Cell[55418, 1321, 184, 7, 33, "Text",
  Evaluatable->False],
Cell[55605, 1330, 378, 8, 50, "Input"],
Cell[55986, 1340, 99, 2, 33, "Text",
  Evaluatable->False],
Cell[56088, 1344, 585, 13, 130, "Input"],
Cell[56676, 1359, 311, 12, 37, "Text",
  Evaluatable->False],
Cell[56990, 1373, 1383, 28, 277, "Input"],
Cell[58376, 1403, 118, 2, 33, "Text",
  Evaluatable->False],
Cell[58497, 1407, 1438, 28, 234, "Input"]
}, Closed]],
Cell[59950, 1438, 573, 20, 38, "Text",
  Evaluatable->False],
Cell[60526, 1460, 25421, 644, 194, "Text"],
Cell[85950, 2106, 1909, 42, 271, "Text"],

Cell[CellGroupData[{
Cell[87884, 2152, 112, 2, 33, "Text"],
Cell[87999, 2156, 244, 8, 39, "Text"],
Cell[88246, 2166, 885, 20, 228, "Input"],
Cell[89134, 2188, 178, 8, 33, "Text",
  Evaluatable->False],
Cell[89315, 2198, 687, 15, 70, "Input"],
Cell[90005, 2215, 277, 10, 74, "Text",
  Evaluatable->False],
Cell[90285, 2227, 585, 13, 130, "Input"],
Cell[90873, 2242, 372, 14, 39, "Text",
  Evaluatable->False],
Cell[91248, 2258, 1680, 33, 310, "Input"],
Cell[92931, 2293, 118, 2, 33, "Text",
  Evaluatable->False],
Cell[93052, 2297, 1446, 28, 249, "Input"]
}, Closed]],
Cell[94513, 2328, 1457, 51, 127, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[95995, 2383, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[96143, 2389, 471, 13, 52, "Text"],
Cell[96617, 2404, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{
Cell[96999, 2418, 169, 4, 30, "Text",
  Evaluatable->False],
Cell[97171, 2424, 715, 14, 224, "Input"]
}, Closed]],
Cell[97901, 2441, 769, 24, 49, "Text"],
Cell[98673, 2467, 1068, 36, 98, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[99766, 2507, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[99914, 2513, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[100092, 2519, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[100452, 2531, 921, 34, 122, "Text"],
Cell[101376, 2567, 15439, 327, 194, "Text"],
Cell[116818, 2896, 1020, 28, 201, "Text"],

Cell[CellGroupData[{
Cell[117863, 2928, 116, 2, 33, "Text"],
Cell[117982, 2932, 471, 14, 41, "Text"],
Cell[118456, 2948, 986, 18, 296, "Input"],
Cell[119445, 2968, 118, 2, 33, "Text",
  Evaluatable->False],
Cell[119566, 2972, 1201, 23, 297, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[120804, 3000, 116, 2, 30, "Text"],
Cell[120923, 3004, 1255, 33, 182, "Text"],
Cell[122181, 3039, 1580, 29, 421, "Input"],
Cell[123764, 3070, 118, 2, 33, "Text",
  Evaluatable->False],
Cell[123885, 3074, 1201, 23, 297, "Input"]
}, Closed]],
Cell[125101, 3100, 532, 18, 40, "Text",
  Evaluatable->False],
Cell[125636, 3120, 19591, 417, 194, "Text"],
Cell[145230, 3539, 1395, 31, 188, "Text"],

Cell[CellGroupData[{
Cell[146650, 3574, 112, 2, 33, "Text"],
Cell[146765, 3578, 212, 6, 42, "Text"],
Cell[146980, 3586, 866, 20, 234, "Input"],
Cell[147849, 3608, 184, 7, 33, "Text",
  Evaluatable->False],
Cell[148036, 3617, 378, 8, 50, "Input"],
Cell[148417, 3627, 248, 8, 33, "Text",
  Evaluatable->False],
Cell[148668, 3637, 559, 11, 131, "Input"],
Cell[149230, 3650, 352, 12, 42, "Text",
  Evaluatable->False],
Cell[149585, 3664, 1864, 33, 356, "Input"],
Cell[151452, 3699, 118, 2, 33, "Text",
  Evaluatable->False],
Cell[151573, 3703, 1438, 28, 234, "Input"]
}, Closed]],
Cell[153026, 3734, 74, 0, 30, "Text"],
Cell[153103, 3736, 1700, 57, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[154828, 3797, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[154976, 3803, 176, 4, 33, "Text",
  Evaluatable->False],
Cell[155155, 3809, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[155515, 3821, 909, 33, 68, "Text"],
Cell[156427, 3856, 3485, 109, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[159937, 3969, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[160085, 3975, 176, 4, 33, "Text",
  Evaluatable->False],
Cell[160264, 3981, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[160624, 3993, 351, 11, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[161000, 4008, 115, 2, 33, "Text"],
Cell[161118, 4012, 1333, 25, 370, "Input"],
Cell[162454, 4039, 2631, 79, 71, "Text"],
Cell[165088, 4120, 1000, 18, 170, "Input"],
Cell[166091, 4140, 135, 2, 50, "Input"],
Cell[166229, 4144, 179, 3, 50, "Input"],
Cell[166411, 4149, 179, 3, 50, "Input"],
Cell[166593, 4154, 191, 3, 50, "Input"],
Cell[166787, 4159, 191, 3, 50, "Input"],
Cell[166981, 4164, 191, 3, 50, "Input"],
Cell[167175, 4169, 197, 3, 50, "Input"],
Cell[167375, 4174, 197, 3, 50, "Input"],
Cell[167575, 4179, 197, 3, 50, "Input"],
Cell[167775, 4184, 197, 3, 50, "Input"],
Cell[167975, 4189, 203, 3, 50, "Input"],
Cell[168181, 4194, 203, 3, 50, "Input"],
Cell[168387, 4199, 203, 3, 50, "Input"],
Cell[168593, 4204, 203, 3, 50, "Input"],
Cell[168799, 4209, 203, 3, 50, "Input"],
Cell[169005, 4214, 209, 3, 50, "Input"],
Cell[169217, 4219, 209, 3, 50, "Input"],
Cell[169429, 4224, 209, 3, 50, "Input"],
Cell[169641, 4229, 209, 3, 50, "Input"],
Cell[169853, 4234, 209, 3, 50, "Input"],
Cell[170065, 4239, 209, 3, 50, "Input"]
}, Closed]],
Cell[170289, 4245, 290, 7, 30, "Text"],
Cell[170582, 4254, 321, 10, 33, "Text"],
Cell[170906, 4266, 324, 10, 33, "Text"],
Cell[171233, 4278, 257, 5, 33, "Text"],
Cell[171493, 4285, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

