(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    159799,       3424]*)
(*NotebookOutlinePosition[    161155,       3471]*)
(*  CellTagsIndexPosition[    161078,       3465]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["7.2  Taylor Series Representations",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tIn Section 4.4 we showed that functions defined by power series have \
derivatives of all orders (Theorem 4.16).  In Section 6.5 we demonstrated \
that analytic functions also have derivatives of all orders (Corollary 6.2).  \
It seems natural, therefore, that there would be some connection between \
analytic functions and power series.  As you might guess, the connection \
exists via the ",
  StyleBox[ButtonBox["Taylor",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Taylor.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " and ",
  StyleBox[ButtonBox["Maclaurin",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Maclaurin.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " series  of analytic functions."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition  7.2  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Taylor Series",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/TaylorSeries.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  "  is analytic at ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ", then the series \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((\[Alpha])\) + 
          f' \((\[Alpha])\) \((z - \[Alpha])\)\  + \(\(f\^\((2)\)\) \((\
\[Alpha])\)\)\/\(2!\)\ \((z - \[Alpha])\)\^2 + \(\(f\^\((2)\)\) \
\((\[Alpha])\)\)\/\(3!\)\ \((z - \[Alpha])\)\^3\  +  ... \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \ \)\(\[Sum]\+\(k = 0\)\%\[Infinity]\(\(\( 
                      f\^\((k)\)\) \((\[Alpha])\)\)\/\(k!\)\) \((z - \
\[Alpha])\)\^k\)\)\)}]],
  "\n\t\nis called the Taylor series for ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " centered at ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ".  When the center is  ",
  Cell[BoxData[
      \(\[Alpha] = 0\)]],
  ", the series is called the Maclaurin series for ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
\tTo investigate when these series converge we will need the following lemma.\
\
\>", "Text"],

Cell[TextData[{
  StyleBox["Lemma 7.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(z, z\_0\ \ and\ \ \[Alpha]\)]],
  "  are complex numbers  with  ",
  Cell[BoxData[
      \(z \[NotEqual] z\_0\)]],
  ",  and  ",
  Cell[BoxData[
      \(z \[NotEqual] \[Alpha]\)]],
  ",  then  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(1\/\(z\  - \ z\_0\)\), " ", "=", " ", 
        InterpretationBox[\(\(1\/\(z\  - \ \[Alpha]\) + \(z\_0\  - \ \[Alpha]\
\)\/\((z\  - \ \[Alpha])\)\^2 + \((z\_0\  - \ \[Alpha])\)\^2\/\((z\  - \ \
\[Alpha])\)\^3 +  ... \) + \((z\_0\  - \ \[Alpha])\)\^n\/\((z\  - \ \[Alpha])\
\)\^\(n + 1\) + \ \(1\/\(z - 
                    z\_0\)\) \((z\_0\  - \ \[Alpha])\)\^\(n + 1\)\/\((z\  - \ \
\[Alpha])\)\^\(n + 1\)\),
          SeriesData[ z0, \[Alpha], {
            Power[ 
              Plus[ z, 
                Times[ -1, \[Alpha]]], -1], 
            Power[ 
              Plus[ z, 
                Times[ -1, \[Alpha]]], -2], 
            Power[ 
              Plus[ z, 
                Times[ -1, \[Alpha]]], -3], 
            Power[ 
              Plus[ z, 
                Times[ -1, \[Alpha]]], -4], 
            Power[ 
              Plus[ z, 
                Times[ -1, \[Alpha]]], -5]}, 0, 5, 1]]}]]],
  "  \n\nwhere n is a positive integer.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Proof of ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  StyleBox["Lemma 7.1",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[" is in the book.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\<\
\tWe are now ready for the main result of this section.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 7.4 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Taylor's Theorem",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/TaylorsTheorem.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " Suppose ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic in a domain ",
  StyleBox["G",
    FontFamily->"Courier New"],
  ", and that ",
  Cell[BoxData[
      \(\(D\_R\) \((\[Alpha])\) = {z : \(\(|\)\(z - \[Alpha]\)\(|\)\(\(<\)\(R\
\)\)\)}\)]],
  " is any disk contained in ",
  StyleBox["G",
    FontFamily->"Courier New"],
  ".  Then the Taylor series for ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " converges to ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " for all z in ",
  Cell[BoxData[
      \(\(D\_R\) \((\[Alpha])\)\)]],
  ";  that is, \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\) = \[Sum]\+\(k = 0\)\%\[Infinity]\(\(\( 
                      f\^\((k)\)\) \((\[Alpha])\)\)\/\(k!\)\) \((z - \
\[Alpha])\)\^k\)]],
  "   for all   ",
  Cell[BoxData[
      \(z \[Element] \(D\_R\) \((\[Alpha])\)\)]],
  ".  \n\nFurthermore, for any r, 0<r<R, the convergence is uniform on the \
closed subdisk  ",
  Cell[BoxData[
      \(\(\(D\_r\)\&_\) \((\[Alpha])\) = {z : \(\(|\)\(z - \
\[Alpha]\)\(|\)\(\(\[LessEqual]\)\(r\)\)\)}\ \ for\ \ 0\  < \ r\  < \ R\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.4 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  "\n\tA singular point of a function is a point at which the function fails \
to be analytic.  You will see in Section 7.4 that singular points of a \
function can be classified according to how badly the function behaves at \
those points.  Loosely speaking, a nonremovable singular point of a function \
has the property that it is impossible to redefine the value of the function \
at that point so as to make it analytic there.  For example, the function ",
  Cell[BoxData[
      \(f \((z)\) = 1\/\(1\  - \ z\)\)]],
  " has a nonremovable singularity at z=1.  We give a formal definition of \
this concept in Section 7.4, but with this language we can nuance Taylor's \
theorem a bit."
}], "Text"],

Cell[TextData[{
  StyleBox["Corollary 7.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  "  is analytic in the domain ",
  StyleBox["G",
    FontFamily->"Courier New"],
  " that contains the point  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ".  Let  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  be a nonremovable singular point of minimum distance to the point  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ".  If  ",
  Cell[BoxData[
      \(\(\(\[VerticalSeparator]\)\(\(z\_0 - \[Alpha]\)\(\[VerticalSeparator]\
\)\)\) = \ R\)]],
  ",  then\n\n\t",
  StyleBox["(i)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "the Taylor series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\(\(\( 
                    f\^\((n)\)\) \((\[Alpha])\)\)\/\(n!\)\) \((z - \
\[Alpha])\)\^n\)]],
  "  converges to ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " on all of  ",
  Cell[BoxData[
      \(\(D\_R\) \((\[Alpha])\)\)]],
  ",  \nand\n\t",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "if ",
  Cell[BoxData[
      \(\(\(\[VerticalSeparator]\)\(z\_1 - \[Alpha]\)\(\[VerticalSeparator]\)\
\) = S > \ R\)]],
  ",  the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\(\(\( 
                    f\^\((n)\)\) \((\[Alpha])\)\)\/\(n!\)\) \((z\_1 - \
\[Alpha])\)\^n\)]],
  "  does not converges to ",
  Cell[BoxData[
      \(f \((z\_1)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 7.3 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(1\/\((1\  - \ z)\)\^2\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\((n + 
                1)\)\ z\^n\)]],
  "  is valid for all  ",
  Cell[BoxData[
      \(z \[Element] \(D\_1\) \((0)\) = {z : \
\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)}\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Solution.  In Example 4.24 we established this identity with the use of \
Theorem 4.17.  We now do so via Theorem 7.4.  If  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ 1\/\((1\  - \ z)\)\^2\)]],
  ",  then a standard induction argument (which we leave as an exercise) will \
show that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((n)\),
              Derivative],
            MultilineFunction->None], \((z)\)}], " ", "=", 
        " ", \(\(\((n + 1)\)!\)\/\((1\  - \ z)\)\^\(n + 2\)\)}]]],
  "  for  ",
  Cell[BoxData[
      \(z \[Element] \(D\_1\) \((0)\)\)]],
  ".  Thus  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((n)\),
              Derivative],
            MultilineFunction->None], \((0)\)}], " ", "=", 
        " ", \(\((n + 1)\)!\)}]]],
  ",  and Taylor's theorem gives  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(1\/\((1\  - \ z)\)\^2\  = \ \(\[Sum]\+\(n = 0\)\%\
\[Infinity]\(\(\( f\^\((n)\)\) \((0)\)\)\/\(n!\)\) 
                z\^n\  = \ \ \(\[Sum]\+\(n = 0\)\%\[Infinity]\(\(\((n + 
                            1)\)!\)\/\(n!\)\) 
                  z\^n\  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\((n + 1)\) 
                  z\^n\)\)\)\)]],
  ",  \n\nand since",
  " ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " ",
  "is analytic in ",
  Cell[BoxData[
      \(\(D\_1\) \((0)\)\)]],
  ", this series expansion is valid for all ",
  Cell[BoxData[
      \(z \[Element] \(D\_1\) \((0)\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 7.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = 1\/\((1\  - \ z)\)\^2\)]],
  " and find the first few terms of the Maclaurin series."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(z = 0; \ Remove[z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, n, S17, S\[Infinity]];\)\ \), "\n", 
    \(\(f[z_]\  = \ 1\/\((1 - z)\)\^2;\)\ \), "\n", 
    \(\(S17[z_]\  = \ Normal[Series[f[z], {z, 0, 17}]];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_17\)[z] = \>\"", 
        S17[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = \>", 
        S17[z], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Sum up the terms to verify that we have things right.", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(S17[
          z_]\ \ \  = \ \[Sum]\+\(n = 0\)\%17\((n + 1)\)\ z\^n;\)\ \), "\n", 
    \(\(S\[Infinity][
          z_]\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\((n + 1)\) 
            z\^n;\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_17\)[z] = \>\"", 
        S17[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_\[Infinity]\)[z] =  \!\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\)(n+1)\!\(z\^n\) = \>\"", 
        S\[Infinity][z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some partial sums for  ",
  Cell[BoxData[
      \(f[z] = 1\/\((1\  - \ z)\)\^2\)]],
  ".  Since convergence will be more rapid in a smaller disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(r\)\)\)\)]],
  "  we will use the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(0.6\)\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, j, m, n, s, z];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = 1\/\((1 - z)\)\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(For\ [j = 2, 
        j \[LessEqual] 4, \(j++\), \[IndentingNewLine]m = 
          4\ j; \ \[IndentingNewLine]s[
            z_] = \[Sum]\+\(n = 0\)\%m\((n + 1)\) 
              z\^n; \ \[IndentingNewLine]PolarMap[
          s, {0, 0.6, 0.05}, {0, 2  \[Pi], \[Pi]\/16}, 
          PlotRange \[Rule] {{0, 4}, {\(-2\), 2}}, AspectRatio \[Rule] 1, 
          Ticks \[Rule] {Range[0, 4, 1], Range[\(-2\), 2, 1]}, 
          AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Red, 
              Blue}]; \ \ \[IndentingNewLine]Print["\<w = s[z,\>", 
          m, "\<] = \>", s[z]];\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[f, {0, 0.6, 0.05}, {0, 2  \[Pi], \[Pi]\/16}, 
        PlotRange \[Rule] {{0, 4}, {\(-2\), 2}}, AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[0, 4, 1], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \ \), "\n", 
    \(\(Print["\<  The mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.4",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[".",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that, for  ",
  Cell[BoxData[
      \(z \[Element] \(D\_1\) \((0)\)\)]],
  ",   \n\n",
  StyleBox["(7-12)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(1\/\(1\  - \ z\^2\) = \[Sum]\+\(n = 0\)\%\[Infinity] z\^\(2  n\)\)]],
  "    and    ",
  Cell[BoxData[
      \(1\/\(1\  + \ z\^2\) = \[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\
\) z\^\(2  n\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  For the real variable case we have the following series approximations \
that were studied in calculus. Observe that their interval of convergence is \
the open interval ",
  Cell[BoxData[
      \(\((\(-1\), 1)\)\)]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009A0001KR000`400?l0
0000o`00003oo`3ooooo0?oooe<0oooo003o0?ooool0ooooD`3oool00?l0
ooooo`3ooomC0?ooo`00o`3ooooo0?oooe<0oooo003o0?ooool0ooooD`3o
ool00?l0ooooo`3ooomC0?ooo`00o`3ooooo0?oooe<0oooo003o0?ooool0
ooooD`3oool00?l0ooooo`3ooomC0?ooo`00o`3ooooo0?oooe<0oooo0028
0?ooo`@00000o`3oool]0?ooo`@00000U@3oool008P0oooo00<000000?oo
o`3oool0o`3oool^0?ooo`030000003oool0oooo09H0oooo000T0?ooo`03
0?l0o`3oool0oooo0140oooo00<00?l00?ooo`3oool0CP3oool00`000000
oooo0?ooo`050?ooo`030?l000000000oooo05D0oooo00<00?l00?ooo`3o
ool04@3oool00`3o0?l0oooo0?ooo`1X0?ooo`03003o003oool0oooo04h0
oooo00<000000?ooo`3oool01@3oool00`3o000000000?ooo`1E0?ooo`03
003o003oool0oooo03D0oooo000S0?ooo`030?l0o`3oool0oooo0180oooo
00<00?l00?ooo`3oool0A`3oool4000000@0oooo00<000000?ooo`3oool0
103oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo0180oooo
00<0o`3o0?ooo`3oool0I`3oool00`00o`00oooo0?ooo`170?ooo`@00000
103oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo05D0oooo
00<00?l00?ooo`3oool0=@3oool002<0oooo00<0o`3o0?ooo`3oool04P3o
ool00`00o`00oooo0?ooo`1=0?ooo`040000003oool0oooo000000D0oooo
00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0C0?ooo`030?l0
o`3oool0oooo06H0oooo00<00?l00?ooo`3oool0C@3oool010000000oooo
0?ooo`0000050?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3o
ool0=@3oool00280oooo00<0o`3o0?ooo`3oool04`3oool00`00o`00oooo
0?ooo`1>0?ooo`8000001P3oool00`3o0000oooo0?ooo`1E0?ooo`03003o
003oool0oooo01@0oooo00<0o`3o0?ooo`3oool0I@3oool00`00o`00oooo
0?ooo`1>0?ooo`8000001P3oool00`3o0000oooo0?ooo`1E0?ooo`03003o
003oool0oooo03D0oooo000Q0?ooo`030?l0o`3oool0oooo01@0oooo00<0
0?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003o
ool0oooo01@0oooo00<0o`3o0?ooo`3oool0I@3oool00`00o`00oooo0?oo
o`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0=@3o
ool00200oooo00<0o`3o0?ooo`3oool05@3oool00`00o`00oooo0?ooo`1F
0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool05@3oool0
0`3o0?l0oooo0?ooo`1T0?ooo`03003o003oool0oooo05H0oooo00<0o`00
0?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00803oool00`3o
0?l0oooo0?ooo`0E0?ooo`03003o003oool0oooo05H0oooo00<0o`000?oo
o`3oool0E@3oool00`00o`00oooo0?ooo`0F0?ooo`030?l0o`3oool0oooo
06<0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?oo
o`03003o003oool0oooo03D0oooo000O0?ooo`030?l0o`3oool0oooo01H0
oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03
003o003oool0oooo01H0oooo00<0o`3o0?ooo`3oool0H`3oool00`00o`00
oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3o
ool0=@3oool001h0oooo00<0o`3o0?ooo`3oool05`3oool00`00o`00oooo
0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0
5`3oool00`3o0?l0oooo0?ooo`1R0?ooo`03003o003oool0oooo05H0oooo
00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`007@3o
ool00`3o0?l0oooo0?ooo`0H0?ooo`03003o003oool0oooo05H0oooo00<0
o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0G0?ooo`030?l0o`3o
ool0oooo0680oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?oo
o`1E0?ooo`03003o003oool0oooo03D0oooo000L0?ooo`030?l0o`3oool0
oooo01T0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E
0?ooo`03003o003oool0oooo01P0oooo00<0o`3o0?ooo`3oool0H@3oool0
0`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l0
0?ooo`3oool0=@3oool001X0oooo0P3o0?lL0?ooo`03003o003oool0oooo
05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0I0?oo
o`80o`3oH@3oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo
05D0oooo00<00?l00?ooo`3oool0=@3oool001T0oooo00<0o`3o0?ooo`3o
ool0703oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0
oooo00<00?l00?ooo`3oool06`3oool00`3o0?l0oooo0?ooo`1N0?ooo`03
003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00
oooo0?ooo`0e0?ooo`005`3oool20?l0oal0oooo00<00?l00?ooo`3oool0
EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo01`0oooo
0P3o0?mN0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0
E@3oool00`00o`00oooo0?ooo`0e0?ooo`005P3oool00`3o0?l0oooo0?oo
o`0O0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3o
ool00`00o`00oooo0?ooo`0N0?ooo`80o`3oG03oool00`00o`00oooo0?oo
o`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0=@3o
ool001@0oooo0P3o0?lR0?ooo`03003o003oool0oooo05H0oooo00<0o`00
0?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0P0?ooo`030?l0o`3oool0
oooo05T0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E
0?ooo`03003o003oool0oooo03D0oooo000B0?ooo`80o`3o903oool00`00
o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?oo
o`3oool08@3oool20?l0oeT0oooo00<00?l00?ooo`3oool0EP3oool00`3o
0000oooo0?ooo`1E0?ooo`03003o003oool0oooo03D0oooo000A0?ooo`03
0?l0o`3oool0oooo02@0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000
oooo0?ooo`1E0?ooo`03003o003oool0oooo02<0oooo0P3o0?mG0?ooo`03
003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00
oooo0?ooo`0e0?ooo`003`3oool20?l0obL0oooo00<00?l00?ooo`3oool0
EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo02D0oooo
0P3o0?mE0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0
E@3oool00`00o`00oooo0?ooo`0e0?ooo`003@3oool20?l0obT0oooo00<0
0?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003o
ool0oooo02L0oooo0P3o0?mC0?ooo`03003o003oool0oooo05H0oooo00<0
o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00303oool0
0`3o0?l0oooo0?ooo`0Y0?ooo`03003o003oool0oooo05H0oooo00<0o`00
0?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0Y0?ooo`80o`3oD@3oool0
0`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l0
0?ooo`3oool0=@3oool000L0oooo1@0000020?ooo`800000103oool20000
0280oooo00<00?l00000000000000`00000R0?ooo`800000103oool20000
00@0oooo0P00000S0?ooo`030?l0003oool0oooo0280oooo0P0000040?oo
o`800000103oool2000002<0oooo0P0000000`00o`0000000000000R0?oo
o`D000000P3oool2000000@0oooo0P00000J0?ooo`D000000P3oool20000
00@0oooo0P00000R0?ooo`03003o00000000000000<000008P3oool20000
00@0oooo0P0000040?ooo`8000008`3oool00`3o0000oooo0?ooo`0R0?oo
o`800000103oool2000000@0oooo0P00000S0?ooo`80000000<00?l00000
000000008P3oool500000080oooo0P0000040?ooo`800000103oool000T0
oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000Q0?oo
o`04003o003oool0oooo000002<0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000R0?ooo`030?l0003oool0oooo0240oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000T0?oo
o`03003o003oool0oooo02@0oooo00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`00000K0?ooo`030000003oool0oooo00L0oooo00@00000
0?ooo`3oool000008@3oool01000o`00oooo0?ooo`00000S0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000008P3oool00`3o
0000oooo0?ooo`0Q0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool00000903oool00`00o`00oooo0?ooo`0T0?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`3oool000000`3oool000T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0O0?ooo`04003o003o
ool0oooo000002<0oooo00@000000?ooo`3oool000002`3oool00`000000
oooo0?ooo`0P0?ooo`030?l0003oool0oooo0240oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`0R0?ooo`03003o003oool0oooo
02@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool07`3oool01000
o`00oooo0?ooo`00000S0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool0803oool00`3o0000oooo0?ooo`0Q0?ooo`040000003o
ool0oooo000000/0oooo00<000000?ooo`3oool08P3oool00`00o`00oooo
0?ooo`0T0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0@3oool000030?ooo`000000000000800000103oool00`000000oooo0?oo
o`080?ooo`8000007@3oool4000000050?ooo`00o`00oooo0?ooo`000000
7@3oool400000080oooo00@000000?ooo`3oool000002@3oool2000002<0
oooo00<0o`000?ooo`3oool08@3oool010000000oooo0?ooo`0000090?oo
o`8000009@3oool00`00o`00oooo0?ooo`0T0?ooo`030000003oool0oooo
00P0oooo0P00000D0?ooo`@00000103oool00`000000oooo0?ooo`080?oo
o`8000007@3oool4000000050?ooo`00o`00oooo0?ooo`0000007@3oool4
00000080oooo00@000000?ooo`3oool000002@3oool2000002<0oooo00<0
o`000?ooo`3oool08@3oool010000000oooo0?ooo`0000090?ooo`800000
9@3oool00`00o`00oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo
0P0000040?ooo`002@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0240oooo00@00?l00?ooo`3oool000008`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3o
ool08@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
02@0oooo00<00?l00?ooo`3oool0903oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0Q0?ooo`04003o003oool0oooo000002<0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`0R0?ooo`030?l0003o
ool0oooo0240oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`0T0?ooo`03003o003oool0oooo02@0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`030?ooo`00203oool2000000X0oooo0`00
000Q0?ooo`04003o003oool00000000002@0oooo0P00000:0?ooo`<00000
8P3oool00`3o0000oooo0?ooo`0R0?ooo`8000002P3oool3000002<0oooo
00<00000003o003oool0903oool2000000X0oooo0`00000J0?ooo`800000
2P3oool300000240oooo00@00?l00?ooo`0000000000903oool2000000X0
oooo0`00000R0?ooo`030?l0003oool0oooo0280oooo0P00000:0?ooo`<0
00008`3oool00`0000000?l00?ooo`0T0?ooo`8000002P3oool3000000<0
oooo000h0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0
E@3oool00`00o`00oooo0?ooo`1l0?ooo`03003o003oool0oooo05H0oooo
00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00>03o
ool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<0
0?l00?ooo`3oool0O03oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003o
ool0oooo05D0oooo00<00?l00?ooo`3oool0=@3oool003P0oooo00<00?l0
0?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0
oooo07`0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E
0?ooo`03003o003oool0oooo03D0oooo000h0?ooo`03003o003oool0oooo
05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`1l0?oo
o`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00
o`00oooo0?ooo`0e0?ooo`00>03oool00`00o`00oooo0?ooo`1F0?ooo`03
0?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0O03oool00`00o`00
oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3o
ool0=@3oool003P0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo
0?ooo`1E0?ooo`03003o003oool0oooo07`0oooo00<00?l00?ooo`3oool0
EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo03D0oooo
000<0?ooob`0000000<00?l0000000000000EP0000000`3o000000000000
001E00000003003o00000000000002/000009@3oool/00000003003o0000
0000000005H0000000<0o`00000000000000E@0000000`00o`0000000000
000[000000X0oooo000<0?ooo`030000003oool0oooo02T0oooo00<00?l0
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0
oooo02T0oooo00<000000?ooo`3oool0:@3oool00`00o`00oooo0?ooo`0Z
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:@3oool0
0`00o`00oooo0?ooo`0Y0?ooo`030000003oool0oooo02X0oooo00<0o`00
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`03003o003oool0
oooo02X0oooo00<000000?ooo`3oool0203oool003P0oooo00<00?l00?oo
o`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo
07`0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?oo
o`03003o003oool0oooo03D0oooo000h0?ooo`03003o003oool0oooo05H0
oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`1l0?ooo`03
003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00
oooo0?ooo`0e0?ooo`00>03oool00`00o`00oooo0?ooo`1F0?ooo`030?l0
003oool0oooo05D0oooo00<00?l00?ooo`3oool0O03oool00`00o`00oooo
0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0
=@3oool003P0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?oo
o`1E0?ooo`03003o003oool0oooo0500oooo403o0?lL0?ooo`03003o003o
ool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?oo
o`0I0?oooa80o`3o2P3oool003P0oooo00<00?l00?ooo`3oool0EP3oool0
0`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo0600oooo303o0?l@
0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool0
0`00o`00oooo0?ooo`0>0?ooo`/0o`3o703oool003P0oooo00<00?l00?oo
o`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo
06`0oooo2`3o0?l50?ooo`03003o003oool0oooo05H0oooo00<0o`000?oo
o`3oool0E@3oool00`00o`00oooo0?ooo`030?ooo`/0o`3o9`3oool003P0
oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03
003o003oool0oooo07L0oooo1@3o0?l00`00o`00o`3o0?l0o`030?l0oe<0
oooo00<0o`000?ooo`3oool0D03oool50?l0o`03003o003o0?l0o`3o00<0
o`3o<P3oool003P0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo
0?ooo`1E0?ooo`03003o003oool0oooo07`0oooo00<00?l00?ooo`3oool0
0`3oool;0?l0odP0oooo00<0o`000?ooo`3oool0A@3oool;0?l0o`D0oooo
00<00?l00?ooo`3oool0=@3oool003P0oooo00<00?l00?ooo`3oool0EP3o
ool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo07`0oooo00<0
0?l00?ooo`3oool0203oool>0000od00oooo00<0o`000?ooo`3oool0?@3o
ool20?l0o``0003o2P3oool00`00o`00oooo0?ooo`0e0?ooo`00>03oool0
0`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l0
0?ooo`3oool0O03oool00`00o`00oooo0?ooo`040?ooo`D0003o3@3oool6
0000ocX0oooo00<0o`000?ooo`3oool0<`3oool<0000o`/0oooo1@000?l6
0?ooo`03003o003oool0oooo03D0oooo000h0?ooo`03003o003oool0oooo
05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`1l0?oo
o`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool05P3oool80000
o`030?l0o`3oool0oooo02l0oooo00<0o`000?ooo`3oool0;@3oool60000
o`@0o`3o603oool20000o`@0oooo00<00?l00?ooo`3oool0=@3oool003P0
oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03
003o003oool0oooo07`0oooo00<00?l00?ooo`3oool00`000?lQ0?ooo``0
003o9P3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0o`000?l0003o00H0
003o0P3o0?lR0?ooo`80003o0P3oool00`00o`00oooo0?ooo`0e0?ooo`00
>03oool00`00o`00oooo0?ooo`1E0?ooo`80o`00E`3oool00`00o`00oooo
0?ooo`1l0?ooo`03003o003oool0003o02l0oooo00<0o`3o0000o`000?l0
20000?lK0?ooo`80o`006`3oool00`3o0?l0003o0000o`090000obh0oooo
00<0003o0?ooo`00o`00=`3oool003P0oooo00<00?l00?ooo`3oool0E03o
ool40?l005H0oooo00<00?l00?ooo`3oool0O03oool00`00o`00003o0?oo
o`0g0?ooo`<0o`3o20000?l00`3o0?l0oooo0?ooo`0?0?ooo`@0o`004P3o
ool90000ocX0oooo00<0003o003o003oool0=P3oool003P0oooo00<00?l0
0?ooo`3oool0B@3oool:0000o`H0o`0020000?l40?l0odT0oooo00<00?l0
0?ooo`3oool0O03oool00`00o`00oooo0?ooo`120?oooa40003o1P3o000A
0000od@0oooo00<00?l00?ooo`3oool0=@3oool003P0oooo00<00?l00?oo
o`3oool0?@3oool<0000o`80o`3o203oool60?l000P0oooo30000?l30?l0
och0oooo00<00?l00?ooo`3oool0N`3oool00`000?l00?l00?ooo`1D0?oo
o`H0o`00E@3oool00`00o`00003o0?ooo`0e0?ooo`00>03oool00`00o`00
oooo0?ooo`0g0?ooo`H0003o0P3o0?lE0?ooo`@0o`005@3oool60000o`80
o`3o>@3oool00`00o`00oooo0?ooo`1j0?ooo`030000o`3oool00?l005H0
oooo103o001F0?ooo`03003o003oool0003o03D0oooo000h0?ooo`03003o
003oool0oooo0340oooo1P000?l20?l0oa`0oooo0P3o000L0?ooo`H0003o
0P3o0?lc0?ooo`03003o003oool0oooo07X0oooo00<0003o0?ooo`00o`00
E`3oool20?l005L0oooo00<00?l00?ooo`000?l0=@3oool003P0oooo00<0
0?l00?ooo`3oool0;@3oool40000o`80o`3o8`3oool00`3o0000oooo0?oo
o`0P0?ooo`H0003o;`3oool00`00o`00oooo0?ooo`1i0?ooo`040000o`3o
ool0oooo003o05P0oooo00<0o`000?ooo`3oool0E@3oool01000o`00oooo
0?ooo`000?ld0?ooo`00>03oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0
o`000?l0003o02T0oooo00<0o`000?ooo`3oool09P3oool40000ob/0oooo
00<00?l00?ooo`3oool0N@3oool010000?l0oooo0?ooo`00o`1H0?ooo`03
0?l0003oool0oooo05D0oooo00@00?l00?ooo`3oool0003o=03oool003P0
oooo00<00?l00?ooo`3oool0:03oool30000ob/0oooo00<0o`000?ooo`3o
ool0:@3oool00`3o0?l0003o0000o`0Y0?ooo`03003o003oool0oooo07P0
oooo00D0003o0?ooo`3oool0oooo003o001H0?ooo`030?l0003oool0oooo
05D0oooo00D00?l00?ooo`3oool0oooo0000o`0c0?ooo`00>03oool00`00
o`00oooo0?ooo`0U0?ooo`<0003o;P3oool00`3o0000oooo0?ooo`0[0?oo
o`030?l0o`000?l0003o02L0oooo00<00?l00?ooo`3oool0N03oool01@00
0?l0oooo0?ooo`3oool00?l005P0oooo00<0o`000?ooo`3oool0E@3oool0
0`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo0300oooo000h0?oo
o`03003o003oool0oooo02<0oooo0P000?l00`3o0?l0oooo0?ooo`0^0?oo
o`030?l0003oool0oooo02d0oooo00<0o`3o0000o`000?l09@3oool00`00
o`00oooo0?ooo`1g0?ooo`030000o`3oool0oooo0080oooo00<00?l00?oo
o`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo
0080oooo00<0003o0?ooo`3oool0<03oool003P0oooo00<00?l00?ooo`3o
ool08@3oool20000oc<0oooo00<0o`000?ooo`3oool0;`3oool00`3o0?l0
003o0000o`0S0?ooo`03003o003oool0oooo07L0oooo00<0003o0?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0
oooo00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`0_0?ooo`00
>03oool00`00o`00oooo0?ooo`0O0?ooo`80003o=@3oool00`3o0000oooo
0?ooo`0b0?ooo`80003o8@3oool00`00o`00oooo0?ooo`1f0?ooo`030000
o`3oool0oooo00<0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo
0?ooo`1E0?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool0
;`3oool003P0oooo00<00?l00?ooo`3oool07@3oool00`3o0?l0003o0?oo
o`0f0?ooo`030?l0003oool0oooo03@0oooo00<0003o0?l0o`3oool07P3o
ool00`00o`00oooo0?ooo`1f0?ooo`030000o`3oool0oooo00<0oooo00<0
0?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003o
ool0oooo00<0oooo00<0003o0?ooo`3oool0;`3oool003P0oooo00<00?l0
0?ooo`3oool0703oool20000ocP0oooo00<0o`000?ooo`3oool0=@3oool2
0000oah0oooo00<00?l00?ooo`3oool0M@3oool00`000?l0oooo0?ooo`04
0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool0
0`00o`00oooo0?ooo`040?ooo`030000o`3oool0oooo02h0oooo000h0?oo
o`03003o003oool0oooo01X0oooo0P000?lj0?ooo`030?l0003oool0oooo
03L0oooo00<0003o0?l0o`3oool06`3oool00`00o`00oooo0?ooo`1e0?oo
o`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool0EP3oool00`3o
0000oooo0?ooo`1E0?ooo`03003o003oool0oooo00@0oooo00<0003o0?oo
o`3oool0;P3oool003P0oooo00<00?l00?ooo`3oool06@3oool00`000?l0
o`3o0?ooo`0j0?ooo`030?l0003oool0oooo03P0oooo00<0003o0?l0o`3o
ool06P3oool00`00o`00oooo0?ooo`1e0?ooo`030000o`3oool0oooo00@0
oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03
003o003oool0oooo00@0oooo00<0003o0?ooo`3oool0;P3oool003P0oooo
00<00?l00?ooo`3oool0603oool00`000?l0o`3o0?ooo`0b0?ooo`@00000
1@3oool00`3o0000oooo0?ooo`0i0?ooo`80003o6P3oool00`00o`00oooo
0?ooo`1e0?ooo`030000o`3oool0oooo00@0oooo00<00?l00?ooo`3oool0
C@3oool4000000D0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo
0?ooo`050?ooo`030000o`3oool0oooo02d0oooo000h0?ooo`03003o003o
ool0oooo01L0oooo00<0003o0?l0o`3oool0<`3oool00`000000oooo0?oo
o`060?ooo`030?l0003oool0oooo03X0oooo00<0o`3o0000o`3oool0603o
ool00`00o`00oooo0?ooo`1d0?ooo`030000o`3oool0oooo00D0oooo00<0
0?l00?ooo`3oool0C@3oool00`000000oooo0?ooo`060?ooo`030?l0003o
ool0oooo05D0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0]0?ooo`00>03oool00`00o`00oooo0?ooo`0F0?ooo`030000o`3o0?l0
oooo03D0oooo00<000000?ooo`3oool01@3oool00`3o000000000?ooo`0k
0?ooo`030?l0o`000?l0oooo01L0oooo00<00?l00?ooo`3oool0M03oool0
0`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo04h0oooo00<00000
0?ooo`3oool01@3oool00`3o000000000?ooo`1E0?ooo`03003o003oool0
oooo00D0oooo00<0003o0?ooo`3oool0;@3oool003P0oooo00<00?l00?oo
o`3oool05@3oool00`000?l0o`3o0?ooo`0g0?ooo`030000003oool0oooo
00@0oooo00<0o`000?ooo`3oool0?03oool00`3o0?l0003o0?ooo`0F0?oo
o`03003o003oool0oooo07@0oooo00<0003o0?ooo`3oool01@3oool00`00
o`00oooo0?ooo`1?0?ooo`030000003oool0oooo00@0oooo00<0o`000?oo
o`3oool0E@3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo
02d0oooo000h0?ooo`03003o003oool0oooo01@0oooo00<0003o0?l0o`3o
ool0=P3oool010000000oooo0?ooo`0000050?ooo`030?l0003oool0oooo
03d0oooo00<0o`3o0000o`3oool05@3oool00`00o`00oooo0?ooo`1c0?oo
o`030000o`3oool0oooo00H0oooo00<00?l00?ooo`3oool0C@3oool01000
0000oooo0?ooo`0000050?ooo`030?l0003oool0oooo05D0oooo00<00?l0
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0/0?ooo`00>03oool00`00
o`00oooo0?ooo`0C0?ooo`030000o`3o0?l0oooo03P0oooo0P0000060?oo
o`030?l0003oool0oooo03h0oooo00<0o`3o0000o`3oool0503oool00`00
o`00oooo0?ooo`1c0?ooo`030000o`3oool0oooo00H0oooo00<00?l00?oo
o`3oool0CP3oool2000000H0oooo00<0o`000?ooo`3oool0E@3oool00`00
o`00oooo0?ooo`060?ooo`030000o`3oool0oooo02`0oooo000h0?ooo`03
003o003oool0oooo0180oooo00<0003o0?l0o`3oool0@@3oool00`3o0000
oooo0?ooo`0n0?ooo`030?l0o`000?l0oooo01@0oooo00<00?l00?ooo`3o
ool0L`3oool00`000?l0oooo0?ooo`060?ooo`03003o003oool0oooo05H0
oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`060?ooo`03
0000o`3oool0oooo02`0oooo000h0?ooo`03003o003oool0oooo0180oooo
00<0003o0?ooo`3oool0@@3oool00`3o0000oooo0?ooo`0o0?ooo`030?l0
o`000?l0oooo01<0oooo00<00?l00?ooo`3oool0L`3oool00`000?l0oooo
0?ooo`060?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0
E@3oool00`00o`00oooo0?ooo`070?ooo`030000o`3oool0oooo02/0oooo
000h0?ooo`03003o003oool0oooo0140oooo00<0003o0?l0o`3oool0@P3o
ool00`3o0000oooo0?ooo`0o0?ooo`030?l0o`000?l0oooo01<0oooo00<0
0?l00?ooo`3oool0LP3oool00`000?l0oooo0?ooo`070?ooo`03003o003o
ool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?oo
o`070?ooo`030000o`3oool0oooo02/0oooo000h0?ooo`03003o003oool0
oooo0100oooo00<0003o0?l0o`3oool0@`3oool00`3o0000oooo0?ooo`10
0?ooo`030?l0o`000?l0oooo0180oooo00<00?l00?ooo`3oool0LP3oool0
0`000?l0oooo0?ooo`070?ooo`03003o003oool0oooo05H0oooo00<0o`00
0?ooo`3oool0E@3oool00`00o`00oooo0?ooo`070?ooo`030000o`3oool0
oooo02/0oooo000h0?ooo`03003o003oool0oooo0100oooo00<0003o0?l0
o`3oool0@`3oool00`3o0000oooo0?ooo`110?ooo`030?l0o`000?l0oooo
0140oooo00<00?l00?ooo`3oool0LP3oool00`000?l0oooo0?ooo`070?oo
o`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00
o`00oooo0?ooo`070?ooo`030000o`3oool0oooo02/0oooo000h0?ooo`03
003o003oool0oooo00l0oooo00<0003o0?l0o`3oool0A03oool00`3o0000
oooo0?ooo`110?ooo`030?l0o`000?l0oooo0140oooo00<00?l00?ooo`3o
ool0LP3oool00`000?l0oooo0?ooo`070?ooo`03003o003oool0oooo05H0
oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`080?ooo`03
0000o`3oool0oooo02X0oooo000h0?ooo`03003o003oool0oooo00l0oooo
00<0003o0?ooo`3oool0A03oool00`3o0000oooo0?ooo`120?ooo`030?l0
o`000?l0oooo0100oooo00<00?l00?ooo`3oool0L@3oool00`000?l0oooo
0?ooo`080?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0
E@3oool00`00o`00oooo0?ooo`080?ooo`030000o`3oool0oooo02X0oooo
000h0?ooo`03003o003oool0oooo00h0oooo00<0003o0?l0o`3oool0A@3o
ool00`3o0000oooo0?ooo`120?ooo`030?l0o`000?l0oooo0100oooo00<0
0?l00?ooo`3oool0L@3oool00`000?l0oooo0?ooo`080?ooo`03003o003o
ool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?oo
o`080?ooo`030000o`3oool0oooo02X0oooo000h0?ooo`03003o003oool0
oooo00d0oooo00<0003o0?l0o`3oool0AP3oool00`3o0000oooo0?ooo`13
0?ooo`030?l0o`000?l0oooo00l0oooo00<00?l00?ooo`3oool0L@3oool0
0`000?l0oooo0?ooo`080?ooo`03003o003oool0oooo05H0oooo00<0o`00
0?ooo`3oool0E@3oool00`00o`00oooo0?ooo`080?ooo`030000o`3oool0
oooo02X0oooo000h0?ooo`03003o003oool0oooo00d0oooo00<0003o0?l0
o`3oool0AP3oool00`3o0000oooo0?ooo`130?ooo`030?l0o`000?l0oooo
00l0oooo00<00?l00?ooo`3oool0L@3oool00`000?l0oooo0?ooo`080?oo
o`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00
o`00oooo0?ooo`080?ooo`030000o`3oool0oooo02X0oooo000h0?ooo`03
003o003oool0oooo00`0oooo00<0003o0?l0o`3oool0A`3oool00`3o0000
oooo0?ooo`140?ooo`030?l0o`000?l0oooo00h0oooo00<00?l00?ooo`3o
ool0L@3oool00`000?l0oooo0?ooo`080?ooo`03003o003oool0oooo05H0
oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`090?ooo`03
0000o`3oool0oooo02T0oooo000h0?ooo`03003o003oool0oooo00`0oooo
00<0003o0?l0o`3oool0A`3oool00`3o0000oooo0?ooo`140?ooo`030?l0
o`000?l0oooo00h0oooo00<00?l00?ooo`3oool0L03oool00`000?l0oooo
0?ooo`090?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0
E@3oool00`00o`00oooo0?ooo`090?ooo`030000o`3oool0oooo02T0oooo
000h0?ooo`03003o003oool0oooo00/0oooo00<0003o0?ooo`3o0?l0B03o
ool00`3o0000oooo0?ooo`150?ooo`030?l0o`000?l0oooo00d0oooo00<0
0?l00?ooo`3oool0L03oool00`000?l0oooo0?ooo`090?ooo`03003o003o
ool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?oo
o`090?ooo`030000o`3oool0oooo02T0oooo000h0?ooo`03003o003oool0
oooo00/0oooo00<0003o0?ooo`3o0?l0B03oool00`3o0000oooo0?ooo`15
0?ooo`030?l0o`000?l0oooo00d0oooo00<00?l00?ooo`3oool0L03oool0
0`000?l0oooo0?ooo`090?ooo`03003o003oool0oooo05H0oooo00<0o`00
0?ooo`3oool0E@3oool00`00o`00oooo0?ooo`090?ooo`030000o`3oool0
oooo02T0oooo000h0?ooo`03003o003oool0oooo00/0oooo00<0003o0?l0
o`3oool0B03oool00`3o0000oooo0?ooo`150?ooo`030?l0o`000?l0oooo
00d0oooo00<00?l00?ooo`3oool0L03oool00`000?l0oooo0?ooo`090?oo
o`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00
o`00oooo0?ooo`090?ooo`030000o`3oool0oooo02T0oooo000h0?ooo`03
003o003oool0oooo00/0oooo00<0003o0?l0o`3oool0B03oool00`3o0000
oooo0?ooo`160?ooo`030?l0o`000?l0oooo00`0oooo00<00?l00?ooo`3o
ool0L03oool00`000?l0oooo0?ooo`090?ooo`03003o003oool0oooo05H0
oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo02P0oooo000h0?ooo`03003o003oool0oooo00X0oooo
00<0003o0?ooo`3o0?l0B@3oool00`3o0000oooo0?ooo`160?ooo`030?l0
o`000?l0oooo00`0oooo00<00?l00?ooo`3oool0L03oool00`000?l0oooo
0?ooo`090?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0
E@3oool00`00o`00oooo0?ooo`0:0?ooo`030000o`3oool0oooo02P0oooo
000h0?ooo`03003o003oool0oooo00X0oooo00<0003o0?ooo`3o0?l0B@3o
ool00`3o0000oooo0?ooo`160?ooo`030?l0o`3oool0003o00`0oooo00<0
0?l00?ooo`3oool0K`3oool00`000?l0oooo0?ooo`0:0?ooo`03003o003o
ool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?oo
o`0:0?ooo`030000o`3oool0oooo02P0oooo000h0?ooo`03003o003oool0
oooo00T0oooo00<0003o0?ooo`3o0?l0BP3oool00`3o0000oooo0?ooo`16
0?ooo`030?l0o`3oool0003o00`0oooo00<00?l00?ooo`3oool0K`3oool0
0`000?l0oooo0?ooo`0:0?ooo`03003o003oool0oooo05H0oooo00<0o`00
0?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0:0?ooo`030000o`3oool0
oooo02P0oooo000h0?ooo`03003o003oool0oooo00T0oooo00<0003o0?oo
o`3o0?l0BP3oool00`3o0000oooo0?ooo`170?ooo`030?l0o`3oool0003o
00/0oooo00<00?l00?ooo`3oool0K`3oool00`000?l0oooo0?ooo`0:0?oo
o`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00
o`00oooo0?ooo`0:0?ooo`030000o`3oool0oooo02P0oooo000h0?ooo`03
003o003oool0oooo00T0oooo00<0003o0?ooo`3o0?l0BP3oool00`3o0000
oooo0?ooo`170?ooo`030?l0o`3oool0003o00/0oooo00<00?l00?ooo`3o
ool0K`3oool00`000?l0oooo0?ooo`0:0?ooo`03003o003oool0oooo05H0
oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo02P0oooo000h0?ooo`03003o003oool0oooo00P0oooo
00@0003o0?ooo`3oool0o`3oBP3oool00`3o0000oooo0?ooo`170?ooo`03
0?l0o`3oool0003o00/0oooo00<00?l00?ooo`3oool0K`3oool00`000?l0
oooo0?ooo`0:0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3o
ool0E@3oool00`00o`00oooo0?ooo`0;0?ooo`030000o`3oool0oooo02L0
oooo000h0?ooo`03003o003oool0oooo00P0oooo00<0003o0?ooo`3o0?l0
B`3oool00`3o0000oooo0?ooo`170?ooo`040?l0o`3oool0oooo0000o`X0
oooo00<00?l00?ooo`3oool0KP3oool00`000?l0oooo0?ooo`0;0?ooo`03
003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00
oooo0?ooo`0;0?ooo`030000o`3oool0oooo02L0oooo000h0?ooo`03003o
003oool0oooo00P0oooo00<0003o0?ooo`3o0?l0B`3oool00`3o0000oooo
0?ooo`180?ooo`030?l0o`3oool0003o00X0oooo00<00?l00?ooo`3oool0
KP3oool00`000?l0oooo0?ooo`0;0?ooo`03003o003oool0oooo05H0oooo
00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0;0?ooo`030000
o`3oool0oooo02L0oooo000h0?ooo`03003o003oool0oooo00P0oooo00<0
003o0?ooo`3o0?l0B`3oool00`3o0000oooo0?ooo`180?ooo`030?l0o`3o
ool0003o00X0oooo00<00?l00?ooo`3oool0KP3oool00`000?l0oooo0?oo
o`0;0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3o
ool00`00o`00oooo0?ooo`0;0?ooo`030000o`3oool0oooo02L0oooo000h
0?ooo`03003o003oool0oooo00L0oooo00<0003o0?ooo`3o0?l0C03oool0
0`3o0000oooo0?ooo`190?ooo`030?l0o`3oool0003o00T0oooo00<00?l0
0?ooo`3oool0KP3oool00`000?l0oooo0?ooo`0;0?ooo`03003o003oool0
oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0;
0?ooo`030000o`3oool0oooo02L0oooo000h0?ooo`03003o003oool0oooo
00L0oooo00<0003o0?ooo`3o0?l0C03oool00`3o0000oooo0?ooo`190?oo
o`030?l0o`3oool0003o00T0oooo00<00?l00?ooo`3oool0KP3oool00`00
0?l0oooo0?ooo`0;0?ooo`03003o003oool0oooo05H0oooo00<0o`000?oo
o`3oool0E@3oool00`00o`00oooo0?ooo`0;0?ooo`030000o`3oool0oooo
02L0oooo000h0?ooo`03003o003oool0oooo00L0oooo00<0003o0?ooo`3o
0?l0A@3oool3000000@0oooo00<0o`000?ooo`3oool0B@3oool00`3o0?l0
oooo0000o`090?ooo`03003o003oool0oooo06h0oooo00<0003o0?ooo`3o
ool02`3oool00`00o`00oooo0?ooo`1?0?ooo`<00000103oool00`3o0000
oooo0?ooo`1E0?ooo`03003o003oool0oooo00`0oooo00<0003o0?ooo`3o
ool09P3oool003P0oooo00<00?l00?ooo`3oool01`3oool00`000?l0oooo
0?l0o`160?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0
B@3oool0103o0?l0oooo0?ooo`000?l80?ooo`03003o003oool0oooo06h0
oooo00<0003o0?ooo`3oool02`3oool00`00o`00oooo0?ooo`1@0?ooo`03
0000003oool0oooo00<0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00
oooo0?ooo`0<0?ooo`030000o`3oool0oooo02H0oooo000h0?ooo`03003o
003oool0oooo00H0oooo00@0003o0?ooo`3oool0o`3o@`3oool5000000@0
oooo00<0o`000000003oool0B@3oool0103o0?l0oooo0?ooo`000?l80?oo
o`03003o003oool0oooo06d0oooo00<0003o0?ooo`3oool0303oool00`00
o`00oooo0?ooo`1=0?ooo`D00000103oool00`3o000000000?ooo`1E0?oo
o`03003o003oool0oooo00`0oooo00<0003o0?ooo`3oool09P3oool003P0
oooo00<00?l00?ooo`3oool01P3oool00`000?l0oooo0?l0o`140?ooo`04
0000003oool0oooo000000D0oooo00<0o`000?ooo`3oool0B@3oool0103o
0?l0oooo0?ooo`000?l80?ooo`03003o003oool0oooo06d0oooo00<0003o
0?ooo`3oool0303oool00`00o`00oooo0?ooo`1=0?ooo`040000003oool0
oooo000000D0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?oo
o`0<0?ooo`030000o`3oool0oooo02H0oooo000h0?ooo`03003o003oool0
oooo00H0oooo00<0003o0?ooo`3o0?l0A@3oool00`000000oooo00000005
0?ooo`030?l0003oool0oooo04X0oooo00@0o`3o0?ooo`3oool0003o1`3o
ool00`00o`00oooo0?ooo`1]0?ooo`030000o`3oool0oooo00`0oooo00<0
0?l00?ooo`3oool0CP3oool00`000000oooo000000050?ooo`030?l0003o
ool0oooo05D0oooo00<00?l00?ooo`3oool0303oool00`000?l0oooo0?oo
o`0V0?ooo`00>03oool00`00o`00oooo0?ooo`060?ooo`030000o`3oool0
o`3o04H0oooo0P0000050?ooo`030?l0003oool0oooo04X0oooo00@0o`3o
0?ooo`3oool0003o1`3oool00`00o`00oooo0?ooo`1]0?ooo`030000o`3o
ool0oooo00`0oooo00<00?l00?ooo`3oool0C`3oool2000000D0oooo00<0
o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo02H0oooo000h0?ooo`03003o003oool0oooo00D0oooo00@0003o
0?ooo`3oool0o`3oC@3oool00`3o0000oooo0?ooo`1:0?ooo`040?l0o`3o
ool0oooo0000o`L0oooo00<00?l00?ooo`3oool0K@3oool00`000?l0oooo
0?ooo`0<0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0
E@3oool00`00o`00oooo0?ooo`0=0?ooo`030000o`3oool0oooo02D0oooo
000h0?ooo`03003o003oool0oooo00D0oooo00@0003o0?ooo`3oool0o`3o
C@3oool00`3o0000oooo0?ooo`1:0?ooo`040?l0o`3oool0oooo0000o`L0
oooo00<00?l00?ooo`3oool0K@3oool00`000?l0oooo0?ooo`0<0?ooo`03
003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00
oooo0?ooo`0=0?ooo`030000o`3oool0oooo02D0oooo000h0?ooo`03003o
003oool0oooo00D0oooo00@0003o0?ooo`3oool0o`3oC@3oool00`3o0000
oooo0?ooo`1:0?ooo`050?l0o`3oool0oooo0?ooo`000?l01P3oool00`00
o`00oooo0?ooo`1]0?ooo`030000o`3oool0oooo00`0oooo00<00?l00?oo
o`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo
00d0oooo00<0003o0?ooo`3oool09@3oool003P0oooo00<00?l00?ooo`3o
ool01@3oool010000?l0oooo0?ooo`3o0?m=0?ooo`030?l0003oool0oooo
04X0oooo00D0o`3o0?ooo`3oool0oooo0000o`060?ooo`03003o003oool0
oooo06d0oooo00<0003o0?ooo`3oool0303oool00`00o`00oooo0?ooo`1F
0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0U0?ooo`00>03oool00`00o`00oooo0?ooo`040?oo
o`050000o`3oool0oooo0?ooo`3o0?l0C@3oool00`3o0000oooo0?ooo`1;
0?ooo`040?l0o`3oool0oooo0000o`H0oooo00<00?l00?ooo`3oool0K@3o
ool00`000?l0oooo0?ooo`0<0?ooo`03003o003oool0oooo05H0oooo00<0
o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo02D0oooo000h0?ooo`03003o003oool0oooo00@0oooo00D0003o
0?ooo`3oool0oooo0?l0o`1=0?ooo`030?l0003oool0oooo04/0oooo00@0
o`3o0?ooo`3oool0003o1P3oool00`00o`00oooo0?ooo`1/0?ooo`030000
o`3oool0oooo00d0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo
0?ooo`1E0?ooo`03003o003oool0oooo00d0oooo00<0003o0?ooo`3oool0
9@3oool003P0oooo00<00?l00?ooo`3oool0103oool010000?l0oooo0?oo
o`3o0?m>0?ooo`030?l0003oool0oooo04/0oooo00D0o`3o0?ooo`3oool0
oooo0000o`050?ooo`03003o003oool0oooo06`0oooo00<0003o0?ooo`3o
ool03@3oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0
oooo00<00?l00?ooo`3oool03@3oool00`000?l0oooo0?ooo`0U0?ooo`00
>03oool00`00o`00oooo0?ooo`040?ooo`040000o`3oool0oooo0?l0odh0
oooo00<0o`000?ooo`3oool0B`3oool01@3o0?l0oooo0?ooo`3oool0003o
00D0oooo00<00?l00?ooo`3oool0K03oool00`000?l0oooo0?ooo`0=0?oo
o`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00
o`00oooo0?ooo`0=0?ooo`030000o`3oool0oooo02D0oooo000h0?ooo`03
003o003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l0o`1>0?oo
o`030?l0003oool0oooo04/0oooo00D0o`3o0?ooo`3oool0oooo0000o`05
0?ooo`03003o003oool0oooo06`0oooo00<0003o0?ooo`3oool03@3oool0
0`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l0
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0U0?ooo`00>03oool00`00
o`00oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o0?l0CP3oool0
0`3o0000oooo0?ooo`1;0?ooo`050?l0o`3oool0oooo0?ooo`000?l01@3o
ool00`00o`00oooo0?ooo`1/0?ooo`030000o`3oool0oooo00d0oooo00<0
0?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003o
ool0oooo00d0oooo00<0003o0?ooo`3oool09@3oool003P0oooo00<00?l0
0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0o`3o04h0oooo00<0
o`000?ooo`3oool0C03oool0103o0?l0oooo0?ooo`000?l50?ooo`03003o
003oool0oooo06`0oooo00<0003o0?ooo`3oool03@3oool00`00o`00oooo
0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`0T0?ooo`00>03oool00`00o`00oooo0?oo
o`030?ooo`050000o`3oool0oooo0?ooo`3o0?l0CP3oool00`3o0000oooo
0?ooo`1<0?ooo`050?l0o`3oool0oooo0?ooo`000?l0103oool00`00o`00
oooo0?ooo`1/0?ooo`030000o`3oool0oooo00d0oooo00<00?l00?ooo`3o
ool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo00h0
oooo00<0003o0?ooo`3oool0903oool003P0oooo00<00?l00?ooo`3oool0
0`3oool01@000?l0oooo0?ooo`3oool0o`3o04h0oooo00<0o`000?ooo`3o
ool0C03oool01@3o0?l0oooo0?ooo`3oool0003o00@0oooo00<00?l00?oo
o`3oool0K03oool00`000?l0oooo0?ooo`0=0?ooo`03003o003oool0oooo
05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0>0?oo
o`030000o`3oool0oooo02@0oooo000h0?ooo`03003o003oool0oooo0080
oooo00<0003o0?ooo`3oool00P3oool00`3o0?l0oooo0?ooo`1<0?ooo`03
0?l0003oool0oooo04`0oooo00D0o`3o0?ooo`3oool0oooo0000o`040?oo
o`03003o003oool0oooo06`0oooo00<0003o0?ooo`3oool03@3oool00`00
o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?oo
o`3oool03P3oool00`000?l0oooo0?ooo`0T0?ooo`00>03oool00`00o`00
oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0?l0C`3oool00`3o
0000oooo0?ooo`1<0?ooo`050?l0o`3oool0oooo0?ooo`000?l0103oool0
0`00o`00oooo0?ooo`1[0?ooo`030000o`3oool0oooo00h0oooo00<00?l0
0?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0
oooo00h0oooo00<0003o0?ooo`3oool0903oool003P0oooo00<00?l00?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`3o04l0oooo00<0o`00
0?ooo`3oool0C03oool01@3o0?l0oooo0?ooo`3oool0003o00@0oooo00<0
0?l00?ooo`3oool0J`3oool00`000?l0oooo0?ooo`0>0?ooo`03003o003o
ool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?oo
o`0>0?ooo`030000o`3oool0oooo02@0oooo000h0?ooo`03003o003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0o`1?0?ooo`030?l0003o
ool0oooo04`0oooo00D0o`3o0?ooo`3oool0oooo0000o`040?ooo`03003o
003oool0oooo06/0oooo00<0003o0?ooo`3oool03P3oool00`00o`00oooo
0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`0T0?ooo`00>03oool00`00o`00oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o0?l0C`3oool00`3o0000oooo
0?ooo`1<0?ooo`030?l0o`3oool0oooo0080oooo00D0003o0?ooo`3oool0
oooo003o001]0?ooo`030000o`3oool0oooo00h0oooo00<00?l00?ooo`3o
ool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo00h0
oooo00<0003o0?ooo`3oool0903oool003P0oooo00<00?l00?ooo`3oool0
0P3oool01@000?l0oooo0?ooo`3oool0o`3o04l0oooo00<0o`000?ooo`3o
ool0C03oool00`3o0?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?oo
o`00o`00K@3oool00`000?l0oooo0?ooo`0>0?ooo`03003o003oool0oooo
05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0>0?oo
o`030000o`3oool0oooo02@0oooo000h0?ooo`05003o003oool0oooo0?oo
o`000?l0103oool00`3o0?l0oooo0?ooo`1=0?ooo`030?l0003oool0oooo
04`0oooo00<0o`3o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0
0?l006d0oooo00<0003o0?ooo`3oool03P3oool00`00o`00oooo0?ooo`1F
0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0T0?ooo`00>03oool01@00o`00oooo0?ooo`3oool0
003o00<0oooo00<0o`3o0?ooo`3oool0CP3oool00`3o0000oooo0?ooo`1<
0?ooo`030?l0o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo003o
001]0?ooo`030000o`3oool0oooo00h0oooo00<00?l00?ooo`3oool0EP3o
ool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo00h0oooo00<0
003o0?ooo`3oool0903oool003P0oooo00D00?l00?ooo`3oool0oooo0000
o`030?ooo`030?l0o`3oool0oooo04h0oooo00<0o`000?ooo`3oool0C03o
ool00`3o0?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`00o`00
K@3oool00`000?l0oooo0?ooo`0>0?ooo`03003o003oool0oooo05H0oooo
00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0>0?ooo`030000
o`3oool0oooo02@0oooo000h0?ooo`05003o003oool0oooo0?ooo`000?l0
0`3oool00`3o0?l0oooo0?ooo`1>0?ooo`030?l0003oool0oooo04`0oooo
00<0o`3o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool00?l006d0
oooo00<0003o0?ooo`3oool03P3oool00`00o`00oooo0?ooo`1F0?ooo`03
0?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool03`3oool00`000?l0
oooo0?ooo`0S0?ooo`00>03oool01@00o`00oooo0?ooo`3oool0003o00<0
oooo00<0o`3o0?ooo`3oool0CP3oool00`3o0000oooo0?ooo`1=0?ooo`03
0?l0o`3oool0oooo0080oooo00@0003o0?ooo`3oool00?l0K@3oool00`00
0?l0oooo0?ooo`0>0?ooo`03003o003oool0oooo05H0oooo00<0o`000?oo
o`3oool0E@3oool00`00o`00oooo0?ooo`0?0?ooo`030000o`3oool0oooo
02<0oooo000h0?ooo`05003o003oool0oooo0?ooo`000?l00`3oool00`3o
0?l0oooo0?ooo`1>0?ooo`030?l0003oool0oooo04d0oooo00<0o`3o0?oo
o`3oool00P3oool010000?l0oooo0?ooo`00o`1/0?ooo`030000o`3oool0
oooo00l0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E
0?ooo`03003o003oool0oooo00l0oooo00<0003o0?ooo`3oool08`3oool0
03P0oooo00@00?l00?ooo`3oool0003o103oool00`3o0?l0oooo0?ooo`1>
0?ooo`030?l0003oool0oooo04d0oooo00<0o`3o0?ooo`3oool00P3oool0
10000?l0oooo0?ooo`00o`1/0?ooo`030000o`3oool0oooo00l0oooo00<0
0?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003o
ool0oooo00l0oooo00<0003o0?ooo`3oool08`3oool003P0oooo00@00?l0
0?ooo`3oool0003o103oool00`3o0?l0oooo0?ooo`1>0?ooo`030?l0003o
ool0oooo04d0oooo00<0o`3o0?ooo`3oool00P3oool010000?l0oooo0?oo
o`00o`1/0?ooo`030000o`3oool0oooo00l0oooo00<00?l00?ooo`3oool0
EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo00l0oooo
00<0003o0?ooo`3oool08`3oool003P0oooo00@00?l00?ooo`3oool0003o
103oool00`3o0?l0oooo0?ooo`150?ooo`<000001P3oool00`3o0000oooo
0?ooo`1=0?ooo`030?l0o`3oool0oooo0080oooo00@0003o0?ooo`3oool0
0?l0K03oool00`000?l0oooo0?ooo`0?0?ooo`03003o003oool0oooo04d0
oooo0`0000060?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0S0?ooo`00>03oool01000o`00oooo
0?ooo`000?l30?ooo`030?l0o`3oool0oooo04H0oooo00@000000?ooo`3o
ool000001@3oool00`3o0000oooo0?ooo`1=0?ooo`030?l0o`3oool0oooo
0080oooo00@0003o0?ooo`3oool00?l0K03oool00`000?l0oooo0?ooo`0?
0?ooo`03003o003oool0oooo04d0oooo00@000000?ooo`3oool000001@3o
ool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo00l0oooo00<0
003o0?ooo`3oool08`3oool003P0oooo00@00?l00?ooo`3oool0003o0`3o
ool00`3o0?l0oooo0?ooo`160?ooo`040000003oool0oooo000000D0oooo
00<0o`000000003oool0C@3oool00`3o0?l0oooo0?ooo`030?ooo`030000
o`3oool00?l006`0oooo00<0003o0?ooo`3oool03`3oool00`00o`00oooo
0?ooo`1=0?ooo`040000003oool0oooo000000D0oooo00<0o`000000003o
ool0E@3oool00`00o`00oooo0?ooo`0?0?ooo`030000o`3oool0oooo02<0
oooo000h0?ooo`04003o003oool0oooo0000o`<0oooo00<0o`3o0?ooo`3o
ool0AP3oool3000000H0oooo00<0o`000?ooo`3oool0C@3oool00`3o0?l0
oooo0?ooo`030?ooo`030000o`3oool00?l006`0oooo00<0003o0?ooo`3o
ool03`3oool00`00o`00oooo0?ooo`1=0?ooo`<000001P3oool00`3o0000
oooo0?ooo`1E0?ooo`03003o003oool0oooo00l0oooo00<0003o0?ooo`3o
ool08`3oool003P0oooo00<00?l00?ooo`000?l0103oool00`3o0?l0oooo
0?ooo`170?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool0
CP3oool00`3o0?l0oooo0?ooo`020?ooo`030000o`3oool00?l006`0oooo
00<0003o0?ooo`3oool03`3oool00`00o`00oooo0?ooo`1>0?ooo`030000
003oool0oooo00D0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo
0?ooo`0?0?ooo`030000o`3oool0oooo02<0oooo000h0?ooo`03003o003o
ool0003o00@0oooo00<0o`3o0?ooo`3oool0A`3oool3000000D0oooo00<0
o`000?ooo`3oool0CP3oool00`3o0?l0oooo0?ooo`020?ooo`030000o`3o
ool00?l006`0oooo00<0003o0?ooo`3oool03`3oool00`00o`00oooo0?oo
o`1>0?ooo`<000001@3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003o
ool0oooo00l0oooo00<0003o0?ooo`3oool08`3oool003P0oooo00<00?l0
0?ooo`000?l0103oool00`3o0?l0oooo0?ooo`1?0?ooo`030?l0003oool0
oooo04h0oooo00<0o`3o0?ooo`3oool00P3oool00`000?l0oooo003o001/
0?ooo`030000o`3oool0oooo00l0oooo00<00?l00?ooo`3oool0EP3oool0
0`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo0100oooo00<0003o
0?ooo`3oool08P3oool003P0oooo00<00?l00?ooo`000?l0103oool00`3o
0?l0oooo0?ooo`1?0?ooo`030?l0003oool0oooo04h0oooo00<0o`3o0?oo
o`3oool00P3oool00`000?l0oooo003o001[0?ooo`030000o`3oool0oooo
0100oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?oo
o`03003o003oool0oooo0100oooo00<0003o0?ooo`3oool08P3oool003P0
oooo00<00?l00?ooo`000?l0103oool00`3o0?l0oooo0?ooo`1?0?ooo`03
0?l0003oool0oooo04h0oooo00<0o`3o0?ooo`3oool00`3oool00`000?l0
0?l00?ooo`1Z0?ooo`030000o`3oool0oooo0100oooo00<00?l00?ooo`3o
ool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo0100
oooo00<0003o0?ooo`3oool08P3oool003P0oooo00<00?l00?ooo`000?l0
103oool00`3o0?l0oooo0?ooo`1?0?ooo`030?l0003oool0oooo04h0oooo
00<0o`3o0?ooo`3oool00`3oool00`000?l00?l00?ooo`1Z0?ooo`030000
o`3oool0oooo0100oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo
0?ooo`1E0?ooo`03003o003oool0oooo0100oooo00<0003o0?ooo`3oool0
8P3oool003P0oooo00<00?l00000o`3oool0103oool00`3o0?l0oooo0?oo
o`1?0?ooo`030?l0003oool0oooo04h0oooo00<0o`3o0?ooo`3oool00`3o
ool00`000?l00?l00?ooo`1Z0?ooo`030000o`3oool0oooo0100oooo00<0
0?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003o
ool0oooo0100oooo00<0003o0?ooo`3oool08P3oool003P0oooo00<00?l0
0000o`3oool0103oool00`3o0?l0oooo0?ooo`1?0?ooo`030?l0003oool0
oooo04h0oooo00<0o`3o0?ooo`3oool00`3oool00`000?l00?l00?ooo`1Z
0?ooo`030000o`3oool0oooo0100oooo00<00?l00?ooo`3oool0EP3oool0
0`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo0100oooo00<0003o
0?ooo`3oool08P3oool003P0oooo00<00?l00000o`3oool0103oool00`3o
0?l0oooo0?ooo`1?0?ooo`030?l0003oool0oooo04h0oooo00<0o`3o0?oo
o`3oool00`3oool00`000?l00?l00?ooo`1Z0?ooo`030000o`3oool0oooo
0100oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?oo
o`03003o003oool0oooo0100oooo00<0003o0?ooo`3oool08P3oool003P0
oooo00<00?l00000o`3oool0103oool00`3o0?l0oooo0?ooo`1?0?ooo`03
0?l0003oool0oooo04h0oooo00<0o`3o0?ooo`3oool00`3oool00`000?l0
0?l00?ooo`1Z0?ooo`030000o`3oool0oooo0100oooo00<00?l00?ooo`3o
ool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo0100
oooo00<0003o0?ooo`3oool08P3oool003P0oooo00<00?l00000o`3oool0
103oool00`3o0?l0oooo0?ooo`1?0?ooo`030?l0003oool0oooo04l0oooo
00<0o`3o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`1Y0?ooo`030000
o`3oool0oooo0100oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo
0?ooo`1E0?ooo`03003o003oool0oooo0100oooo00<0003o0?ooo`3oool0
8P3oool003P0oooo00<00?l00000o`3oool0103oool00`3o0?l0oooo0?oo
o`1?0?ooo`030?l0003oool0oooo04l0oooo00<0o`3o0?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`1Y0?ooo`030000o`3oool0oooo0100oooo00<0
0?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003o
ool0oooo0100oooo00<0003o0?ooo`3oool08P3oool003P0oooo00<00?l0
0?ooo`3oool0103oool00`3o0?l0oooo0?ooo`1?0?ooo`030?l0003oool0
oooo04l0oooo00<0o`3o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`1Y
0?ooo`030000o`3oool0oooo0100oooo00<00?l00?ooo`3oool0EP3oool0
0`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo0100oooo00<0003o
0?ooo`3oool08P3oool003P0oooo00<00?l00?ooo`3oool0103oool00`3o
0?l0oooo0?ooo`1?0?ooo`030?l0003oool0oooo04l0oooo00<0o`3o0?oo
o`3oool00`3oool00`00o`00oooo0?ooo`1Y0?ooo`030000o`3oool0oooo
0100oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?oo
o`03003o003oool0oooo0100oooo00<0003o0?ooo`3oool08P3oool003P0
oooo00<00?l00?ooo`3oool0103oool00`3o0?l0oooo0?ooo`1?0?ooo`03
0?l0003oool0oooo04l0oooo00<0o`3o0?ooo`3oool00`3oool00`00o`00
oooo0?ooo`1X0?ooo`030000o`3oool0oooo0140oooo00<00?l00?ooo`3o
ool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo0140
oooo00<0003o0?ooo`3oool08@3oool003P0oooo00<00?l00?ooo`3oool0
103oool00`3o0?l0oooo0?ooo`1?0?ooo`030?l0003oool0oooo04l0oooo
00<0o`3o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`1X0?ooo`030000
o`3oool0oooo0140oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo
0?ooo`1E0?ooo`03003o003oool0oooo0140oooo00<0003o0?ooo`3oool0
8@3oool003P0oooo00<00?l00?ooo`3oool0103oool00`3o0?l0oooo0?oo
o`1?0?ooo`030?l0003oool0oooo04l0oooo00<0o`3o0?ooo`3oool00`3o
ool00`00o`00oooo0?ooo`1X0?ooo`030000o`3oool0oooo0140oooo00<0
0?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003o
ool0oooo0140oooo00<0003o0?ooo`3oool08@3oool003P0oooo00<00?l0
0?ooo`3oool0103oool00`3o0?l0oooo0?ooo`1?0?ooo`030?l0003oool0
oooo04l0oooo00<0o`3o0?ooo`3oool00`3oool00`00o`00003o0?ooo`1X
0?ooo`030000o`3oool0oooo0140oooo00<00?l00?ooo`3oool0EP3oool0
0`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo0140oooo00<0003o
0?ooo`3oool08@3oool003P0oooo00<00?l00?ooo`3oool00`3oool00`3o
0?l0oooo0?ooo`1@0?ooo`030?l0003oool0oooo04l0oooo00<0o`3o0?oo
o`3oool00`3oool00`00o`00003o0?ooo`1X0?ooo`030000o`3oool0oooo
0140oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?oo
o`03003o003oool0oooo0140oooo00<0003o0?ooo`3oool08@3oool003L0
oooo00<0003o003o003oool0103oool00`3o0?l0oooo0?ooo`1@0?ooo`03
0?l0003oool0oooo04l0oooo00<0o`3o0?ooo`3oool00`3oool00`00o`00
003o0?ooo`1X0?ooo`030000o`3oool0oooo0140oooo00<00?l00?ooo`3o
ool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo0140
oooo00<0003o0?ooo`3oool08@3oool003L0oooo00<0003o003o003oool0
103oool00`3o0?l0oooo0?ooo`1@0?ooo`030?l0003oool0oooo04l0oooo
00<0o`3o0?ooo`3oool00`3oool00`00o`00003o0?ooo`1X0?ooo`030000
o`3oool0oooo0140oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo
0?ooo`1E0?ooo`03003o003oool0oooo0140oooo00<0003o0?ooo`3oool0
8@3oool003L0oooo00<0003o003o003oool0103oool00`3o0?l0oooo0?oo
o`1@0?ooo`030?l0003oool0oooo04l0oooo00<0o`3o0?ooo`3oool00`3o
ool00`00o`00003o0?ooo`1X0?ooo`030000o`3oool0oooo0140oooo00<0
0?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003o
ool0oooo0140oooo00<0003o0?ooo`3oool08@3oool003L0oooo00<0003o
003o003oool0103oool00`3o0?l0oooo0?ooo`1@0?ooo`030?l0003oool0
oooo04l0oooo00<0o`3o0?ooo`3oool00`3oool00`00o`00003o0?ooo`1X
0?ooo`030000o`3oool0oooo0140oooo00<00?l00?ooo`3oool0EP3oool0
0`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo0140oooo00<0003o
0?ooo`3oool08@3oool003L0oooo00<0003o003o003oool0103oool00`3o
0?l0oooo0?ooo`1@0?ooo`030?l0003oool0oooo04l0oooo00<0o`3o0?oo
o`3oool00`3oool00`00o`00003o0?ooo`1X0?ooo`030000o`3oool0oooo
0140oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?oo
o`03003o003oool0oooo0140oooo00<0003o0?ooo`3oool08@3oool003L0
oooo00<0003o003o003oool0103oool00`3o0?l0oooo0?ooo`1@0?ooo`03
0?l0003oool0oooo04l0oooo00<0o`3o0?ooo`3oool00`3oool00`00o`00
oooo0000o`1X0?ooo`030000o`3oool0oooo0140oooo00<00?l00?ooo`3o
ool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo0140
oooo00<0003o0?ooo`3oool08@3oool003L0oooo00<0003o003o003oool0
103oool00`3o0?l0oooo0?ooo`1@0?ooo`030?l0003oool0oooo04l0oooo
00<0o`3o0?ooo`3oool00`3oool00`00o`00oooo0000o`1X0?ooo`030000
o`3oool0oooo0140oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo
0?ooo`1E0?ooo`03003o003oool0oooo0140oooo00<0003o0?ooo`3oool0
8@3oool003L0oooo00<0003o003o003oool0103oool00`3o0?l0oooo0?oo
o`1@0?ooo`030?l0003oool0oooo04l0oooo00<0o`3o0?ooo`3oool00`3o
ool00`00o`00oooo0000o`1W0?ooo`030000o`3oool0oooo0180oooo00<0
0?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003o
ool0oooo0180oooo00<0003o0?ooo`3oool0803oool003H0oooo00<0003o
0?ooo`00o`001@3oool00`3o0?l0oooo0?ooo`1@0?ooo`030?l0003oool0
oooo04l0oooo00<0o`3o0?ooo`3oool00`3oool00`00o`00oooo0000o`1W
0?ooo`030000o`3oool0oooo0180oooo00<00?l00?ooo`3oool0EP3oool0
0`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo0180oooo00<0003o
0?ooo`3oool0803oool003H0oooo00<0003o0?ooo`00o`001@3oool00`3o
0?l0oooo0?ooo`1@0?ooo`030?l0003oool0oooo04l0oooo00<0o`3o0?oo
o`3oool00`3oool00`00o`00oooo0000o`1W0?ooo`030000o`3oool0oooo
0180oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?oo
o`03003o003oool0oooo0180oooo00<0003o0?ooo`3oool0803oool003H0
oooo00<0003o0?ooo`00o`001@3oool00`3o0?l0oooo0?ooo`180?ooo`80
00001P3oool00`3o0000oooo0?ooo`1?0?ooo`030?l0o`3oool0oooo00<0
oooo00<00?l00?ooo`000?l0I`3oool00`000?l0oooo0?ooo`0B0?ooo`03
003o003oool0oooo04h0oooo0P0000060?ooo`030?l0003oool0oooo05D0
oooo00<00?l00?ooo`3oool04P3oool00`000?l0oooo0?ooo`0P0?ooo`00
=P3oool00`000?l0oooo003o00050?ooo`030?l0o`3oool0oooo04L0oooo
00@000000?ooo`3oool000001@3oool00`3o0000oooo0?ooo`1?0?ooo`03
0?l0o`3oool0oooo00<0oooo00<00?l00?ooo`000?l0I`3oool00`000?l0
oooo0?ooo`0B0?ooo`03003o003oool0oooo04d0oooo00@000000?ooo`3o
ool000001@3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo
0180oooo00<0003o0?ooo`3oool0803oool003H0oooo00<0003o0?ooo`00
o`001@3oool00`3o0?l0oooo0?ooo`170?ooo`040000003oool0oooo0000
00D0oooo00<0o`000000003oool0C`3oool00`3o0?l0oooo0?ooo`030?oo
o`03003o003oool0003o06L0oooo00<0003o0?ooo`3oool04P3oool00`00
o`00oooo0?ooo`1=0?ooo`040000003oool0oooo000000D0oooo00<0o`00
0000003oool0E@3oool00`00o`00oooo0?ooo`0B0?ooo`030000o`3oool0
oooo0200oooo00290?ooo`800000o`3oool_0?ooo`800000UP3oool008P0
oooo00@000000?ooo`3oool00000o`3oool]0?ooo`040000003oool0oooo
000009D0oooo00290?ooo`800000o`3oool_0?ooo`800000UP3oool00?l0
ooooo`3ooomC0?ooo`00o`3ooooo0?oooe<0oooo003o0?ooool0ooooD`3o
ool00?l0ooooo`3ooomC0?ooo`00o`3ooooo0?oooe<0oooo003o0?ooool0
ooooD`3oool00?l0ooooo`3ooomC0?ooo`00o`3ooooo0?oooe<0oooo003o
0?ooool0ooooD`3oool00?l0ooooo`3ooomC0?ooo`00o`3ooooo0?oooe<0
oooo003o0?ooool0ooooD`3oool008P0oooo1000003o0?ooobd0oooo1000
002E0?ooo`00R03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<00000
0?ooo`3oool0UP3oool002@0oooo00<0o`3o0?ooo`3oool04@3oool00`00
o`00oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<0o`000000
003oool0E@3oool00`00o`00oooo0?ooo`0A0?ooo`030?l0o`3oool0oooo
05X0oooo00<0003o0?ooo`3oool02`3oool00`00o`00oooo0?ooo`1>0?oo
o`030000003oool0oooo00D0oooo00<0o`000000003oool0E@3oool00`00
o`00oooo0?ooo`0;0?ooo`030000o`3oool0oooo02L0oooo000S0?ooo`03
0?l0o`3oool0oooo0180oooo00<00?l00?ooo`3oool0A`3oool4000000@0
oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`1E0?ooo`03
003o003oool0oooo0180oooo00<0o`3o0?ooo`3oool0F@3oool00`000?l0
oooo0?ooo`0;0?ooo`03003o003oool0oooo04L0oooo100000040?ooo`03
0000003oool0oooo00@0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00
oooo0?ooo`0;0?ooo`030000o`3oool0oooo02L0oooo000S0?ooo`030?l0
o`3oool0oooo0180oooo00<00?l00?ooo`3oool0C@3oool010000000oooo
0?ooo`0000050?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3o
ool04`3oool00`3o0?l0oooo0?ooo`1H0?ooo`030000o`3oool0oooo00/0
oooo00<00?l00?ooo`3oool0C@3oool010000000oooo0?ooo`0000050?oo
o`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0X0?ooo`008P3oool00`3o0?l0oooo0?ooo`0C0?ooo`03
003o003oool0oooo04h0oooo0P0000060?ooo`030?l0003oool0oooo05D0
oooo00<00?l00?ooo`3oool0503oool00`3o0?l0oooo0?ooo`1H0?ooo`03
0000o`3oool0oooo00X0oooo00<00?l00?ooo`3oool0CP3oool2000000H0
oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo02P0oooo000Q0?ooo`030?l0o`3oool0oooo01@0oooo
00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o
003oool0oooo01@0oooo00<0o`3o0?ooo`3oool0F03oool00`000?l0oooo
0?ooo`0:0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0
E@3oool00`00o`00oooo0?ooo`0:0?ooo`030000o`3oool0oooo02P0oooo
000P0?ooo`030?l0o`3oool0oooo01D0oooo00<00?l00?ooo`3oool0EP3o
ool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo01D0oooo00<0
o`3o0?ooo`3oool0E`3oool00`000?l0oooo0?ooo`0:0?ooo`03003o003o
ool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?oo
o`0:0?ooo`030000o`3oool0oooo02P0oooo000P0?ooo`030?l0o`3oool0
oooo01D0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E
0?ooo`03003o003oool0oooo01H0oooo00<0o`3o0?ooo`3oool0EP3oool0
0`000?l0oooo0?ooo`0:0?ooo`03003o003oool0oooo05H0oooo00<0o`00
0?ooo`3oool0E@3oool00`00o`00oooo0?ooo`090?ooo`030000o`3oool0
oooo02T0oooo000O0?ooo`030?l0o`3oool0oooo01H0oooo00<00?l00?oo
o`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo
01H0oooo00<0o`3o0?ooo`3oool0E`3oool00`000?l0oooo0?ooo`090?oo
o`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00
o`00oooo0?ooo`090?ooo`030000o`3oool0oooo02T0oooo000N0?ooo`03
0?l0o`3oool0oooo01L0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000
oooo0?ooo`1E0?ooo`03003o003oool0oooo01L0oooo00<0o`3o0?ooo`3o
ool0EP3oool00`000?l0oooo0?ooo`090?ooo`03003o003oool0oooo05H0
oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`090?ooo`03
0000o`3oool0oooo02T0oooo000M0?ooo`030?l0o`3oool0oooo01P0oooo
00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o
003oool0oooo01L0oooo00<0o`3o0?ooo`3oool0EP3oool00`000?l0oooo
0?ooo`090?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0
E@3oool00`00o`00oooo0?ooo`090?ooo`030000o`3oool0oooo02T0oooo
000L0?ooo`030?l0o`3oool0oooo01T0oooo00<00?l00?ooo`3oool0EP3o
ool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo01P0oooo00<0
o`3o0?ooo`3oool0E@3oool00`000?l0oooo0?ooo`090?ooo`03003o003o
ool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?oo
o`080?ooo`030000o`3oool0oooo02X0oooo000J0?ooo`80o`3o703oool0
0`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l0
0?ooo`3oool06@3oool20?l0oeH0oooo00<0003o0?ooo`3oool0203oool0
0`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l0
0?ooo`3oool0203oool00`000?l0oooo0?ooo`0Z0?ooo`006@3oool00`3o
0?l0oooo0?ooo`0L0?ooo`03003o003oool0oooo05H0oooo00<0o`000?oo
o`3oool0E@3oool00`00o`00oooo0?ooo`0K0?ooo`030?l0o`3oool0oooo
05<0oooo00<0003o0?ooo`3oool0203oool00`00o`00oooo0?ooo`1F0?oo
o`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0[0?ooo`005`3oool20?l0oal0oooo00<00?l00?ooo`3o
ool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo01`0
oooo0P3o0?mC0?ooo`030000o`3oool0oooo00P0oooo00<00?l00?ooo`3o
ool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo00L0
oooo00<0003o0?ooo`3oool0:`3oool001H0oooo00<0o`3o0?ooo`3oool0
7`3oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo
00<00?l00?ooo`3oool07P3oool20?l0oe80oooo00<0003o0?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo
00<00?l00?ooo`3oool01`3oool00`000?l0oooo0?ooo`0[0?ooo`00503o
ool20?l0ob80oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?oo
o`1E0?ooo`03003o003oool0oooo0200oooo00<0o`3o0?ooo`3oool0C`3o
ool00`000?l0oooo0?ooo`070?ooo`03003o003oool0oooo05H0oooo00<0
o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`060?ooo`030000o`3o
ool0oooo02`0oooo000B0?ooo`80o`3o903oool00`00o`00oooo0?ooo`1F
0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool08@3oool2
0?l0oe00oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`1F
0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`0/0?ooo`004@3oool00`3o0?l0oooo0?ooo`0T0?oo
o`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00
o`00oooo0?ooo`0S0?ooo`80o`3oCP3oool00`000?l0oooo0?ooo`060?oo
o`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00
o`00oooo0?ooo`060?ooo`030000o`3oool0oooo02`0oooo000?0?ooo`80
o`3o9`3oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0
oooo00<00?l00?ooo`3oool09@3oool20?l0odd0oooo00<0003o0?ooo`3o
ool01@3oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0
oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`0]0?ooo`00
3@3oool20?l0obT0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo
0?ooo`1E0?ooo`03003o003oool0oooo02L0oooo0P3o0?m;0?ooo`030000
o`3oool0oooo00D0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo
0?ooo`1E0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool0
;@3oool000`0oooo00<0o`3o0?ooo`3oool0:@3oool00`00o`00oooo0?oo
o`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0:@3o
ool20?l0odT0oooo00<0003o0?ooo`3oool01@3oool00`00o`00oooo0?oo
o`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0]0?ooo`001`3oool500000080oooo0P000004
0?ooo`8000008P3oool00`00o`0000000000000300000280oooo0P000004
0?ooo`800000103oool2000002<0oooo00<0o`000?ooo`3oool08P3oool2
000000@0oooo0P0000040?ooo`8000008`3oool200000003003o00000000
00000280oooo1@0000020?ooo`800000103oool2000001X0oooo1@000002
0?ooo`800000103oool2000001/0oooo00<0003o0?ooo`3oool0103oool0
0`00o`0000000000000300000280oooo0P0000040?ooo`800000103oool2
000002<0oooo00<0o`000?ooo`3oool08P3oool2000000@0oooo0P000004
0?ooo`8000008`3oool200000003003o00000000000000@0oooo00<0003o
0?ooo`3oool06`3oool500000080oooo0P0000040?ooo`800000103oool0
00T0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000Q
0?ooo`04003o003oool0oooo000002<0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000R0?ooo`030?l0003oool0oooo0240
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000T
0?ooo`03003o003oool0oooo02@0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`00000K0?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`3oool000006P3oool00`000?l0oooo0?ooo`040?ooo`04003o
003oool0oooo000002<0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`00000R0?ooo`030?l0003oool0oooo0240oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000T0?ooo`03003o
003oool0oooo00@0oooo00<0003o0?ooo`3oool07@3oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo000000<0oooo00090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool07`3oool01000o`00oooo
0?ooo`00000S0?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool0803oool00`3o0000oooo0?ooo`0Q0?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`3oool08P3oool00`00o`00oooo0?ooo`0T
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01T0oooo00<0003o
0?ooo`3oool00`3oool01000o`00oooo0?ooo`00000S0?ooo`040000003o
ool0oooo000000/0oooo00<000000?ooo`3oool0803oool00`3o0000oooo
0?ooo`0Q0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3o
ool08P3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo01h0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`00
00<0oooo0000000000000P0000040?ooo`030000003oool0oooo00P0oooo
0P00000M0?ooo`@0000000D0oooo003o003oool0oooo0000000M0?ooo`@0
00000P3oool010000000oooo0?ooo`0000090?ooo`8000008`3oool00`3o
0000oooo0?ooo`0Q0?ooo`040000003oool0oooo000000T0oooo0P00000U
0?ooo`03003o003oool0oooo02@0oooo00<000000?ooo`3oool0203oool2
000001@0oooo100000040?ooo`030000003oool0oooo00P0oooo0P00000L
0?ooo`030000o`00000000000080000000D0oooo003o003oool0oooo0000
000M0?ooo`@000000P3oool010000000oooo0?ooo`0000090?ooo`800000
8`3oool00`3o0000oooo0?ooo`0Q0?ooo`040000003oool0oooo000000T0
oooo0P00000U0?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3o
ool07P3oool00`000000oooo0?ooo`080?ooo`800000103oool000T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`04003o
003oool0oooo000002<0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo0240oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`0T0?ooo`03003o003oool0
oooo02@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703oool0
0`000?l0oooo0?ooo`020?ooo`04003o003oool0oooo000002<0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`0R0?ooo`030?l0
003oool0oooo0240oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`0T0?ooo`03003o003oool0oooo0080oooo00<0003o0?ooo`3o
ool07`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0
oooo00080?ooo`8000002P3oool300000240oooo00@00?l00?ooo`000000
0000903oool2000000X0oooo0`00000R0?ooo`030?l0003oool0oooo0280
oooo0P00000:0?ooo`<000008`3oool00`0000000?l00?ooo`0T0?ooo`80
00002P3oool3000001X0oooo0P00000:0?ooo`<00000703oool00`000?l0
oooo0?ooo`020?ooo`04003o003oool00000000002@0oooo0P00000:0?oo
o`<000008P3oool00`3o0000oooo0?ooo`0R0?ooo`8000002P3oool30000
02<0oooo00<00000003o003oool00`3oool00`000?l0oooo0?ooo`0N0?oo
o`8000002P3oool3000000<0oooo000h0?ooo`03003o003oool0oooo05H0
oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`1h0?ooo`05
0000o`3oool0oooo0?ooo`00o`00F03oool00`3o0000oooo0?ooo`1E0?oo
o`05003o003oool0oooo0?ooo`000?l0<`3oool003P0oooo00<00?l00?oo
o`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo
07P0oooo00D0003o0?ooo`3oool0oooo003o001H0?ooo`030?l0003oool0
oooo05D0oooo00D00?l00?ooo`3oool0oooo0000o`0c0?ooo`00>03oool0
0`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l0
0?ooo`3oool0N@3oool010000?l0oooo0?ooo`00o`1H0?ooo`030?l0003o
ool0oooo05D0oooo00@00?l00?ooo`3oool0003o=03oool003P0oooo00<0
0?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003o
ool0oooo07T0oooo00@0003o0?ooo`3oool00?l0F03oool00`3o0000oooo
0?ooo`1E0?ooo`03003o003oool0003o03D0oooo000h0?ooo`03003o003o
ool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?oo
o`1j0?ooo`030000o`3oool00?l005P0oooo00<0o`000?ooo`3oool0E@3o
ool00`00o`00003o0?ooo`0e0?ooo`00>03oool00`00o`00oooo0?ooo`1F
0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0N`3oool0
0`000?l00?l00?ooo`1G0?ooo`030?l0003oool0oooo05D0oooo00<00?l0
0?ooo`3oool0=@3oool000`0oooo;00000000`00o`0000000000001F0000
00030?l000000000000005D0000000<00?l0000000000000:`00000U0?oo
ob`0000000<00?l0000000000000EP0000000`3o000000000000001D0000
00030000o`00o`00000002`000002P3oool000`0oooo00<000000?ooo`3o
ool0:@3oool00`00o`00oooo0?ooo`0Y0?ooo`030000003oool0oooo02X0
oooo00<0o`000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`03
003o003oool0oooo02X0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0Y0?ooo`03003o00000?l0003o02T0oooo00<000000?ooo`3o
ool0:P3oool00`3o0000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0
oooo00<0003o003o003oool0:`3oool00`000000oooo0?ooo`080?ooo`00
>03oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo
00<00?l00?ooo`3oool0O03oool01000o`00oooo0?ooo`000?mE0?ooo`03
0?l0003oool0oooo05<0oooo00<0003o0?ooo`00o`00=`3oool003P0oooo
00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o
003oool0oooo07`0oooo00D00?l00?ooo`3oool0oooo0000o`1D0?ooo`03
0?l0003oool0oooo0540oooo0P000?l20?ooo`03003o003oool0oooo03D0
oooo000h0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0
E@3oool00`00o`00oooo0?ooo`1l0?ooo`03003o003oool0oooo0080oooo
00<0003o0?ooo`3oool0D@3oool00`3o0000oooo0?ooo`1@0?ooo`030000
o`3oool0oooo0080oooo00<00?l00?ooo`3oool0=@3oool003P0oooo00<0
0?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003o
ool0oooo0500oooo403o0?lL0?ooo`03003o003oool0oooo00<0oooo0P00
0?mA0?ooo`030?l0003oool0oooo04h0oooo0P000?l50?ooo`03003o003o
ool0oooo01T0oooo4P3o0?l:0?ooo`00>03oool00`00o`00oooo0?ooo`1F
0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0H03oool<
0?l0oa00oooo00<00?l00?ooo`3oool01@3oool20000odl0oooo00<0o`00
0?ooo`3oool0C03oool20000o`L0oooo00<00?l00?ooo`3oool03P3oool;
0?l0oa`0oooo000h0?ooo`03003o003oool0oooo05H0oooo00<0o`000?oo
o`3oool0E@3oool00`00o`00oooo0?ooo`1/0?ooo`/0o`3o1@3oool00`00
o`00oooo0?ooo`070?ooo`<0003oC03oool00`3o0000oooo0?ooo`1:0?oo
o`80003o2@3oool00`00o`00oooo0?ooo`030?ooo`/0o`3o9`3oool003P0
oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03
003o003oool0oooo07L0oooo1@3o0?l00`00o`00o`3o0?l0o`030?l0o`L0
oooo0`000?m90?ooo`030?l0003oool0oooo04L0oooo0`000?l60?ooo`D0
o`3o00<00?l00?l0o`3o0?l00`3o0?lb0?ooo`00>03oool00`00o`00oooo
0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0
O03oool00`00o`00oooo0?ooo`030?ooo`X0o`3o10000?m50?ooo`030?l0
003oool0oooo04<0oooo10000?l90?l0o`D0oooo00<00?l00?ooo`3oool0
=@3oool003P0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?oo
o`1E0?ooo`03003o003oool0oooo07`0oooo00<00?l00?ooo`3oool03P3o
ool30?l0o`D0003o@03oool00`3o0000oooo0?ooo`0k0?ooo`P0003o0P3o
0?l@0?ooo`03003o003oool0oooo03D0oooo000h0?ooo`03003o003oool0
oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`1l
0?ooo`03003o003oool0oooo01H0oooo1P000?lj0?ooo`030?l0003oool0
oooo03<0oooo20000?l20?l0oaP0oooo00<00?l00?ooo`3oool0=@3oool0
03P0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?oo
o`03003o003oool0oooo07`0oooo00<00?l00?ooo`3oool0703oool90000
oc40oooo00<0o`000?ooo`3oool0;@3oool60000o`@0o`3o7P3oool00`00
o`00oooo0?ooo`0e0?ooo`00>03oool00`00o`00oooo0?ooo`1F0?ooo`03
0?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0O03oool00`00o`00
oooo0?ooo`0U0?ooo`/0003o9P3oool00`3o0000oooo0?ooo`0T0?ooo`03
0?l0o`000?l0003o00H0003o0P3o0?lV0?ooo`03003o003oool0oooo03D0
oooo000h0?ooo`03003o003oool0oooo05D0oooo0P3o001G0?ooo`03003o
003oool0oooo07`0oooo00<00?l00?ooo`3oool0;`3oool00`3o0?l0003o
0000o`060000oad0oooo0P3o000K0?ooo`030?l0o`000?l0003o00T0003o
<03oool00`00o`00oooo0?ooo`0e0?ooo`00>03oool00`00o`00oooo0?oo
o`1D0?ooo`@0o`00EP3oool00`00o`00oooo0?ooo`1l0?ooo`03003o003o
ool0oooo03L0oooo00<0o`3o0000o`000?l02@000?lA0?ooo`@0o`004P3o
ool00`3o0?l0003o0000o`060000oc/0oooo00<00?l00?ooo`3oool0=@3o
ool003P0oooo00<00?l00?ooo`3oool0BP3oool90000o`H0o`002@000?l3
0?l0odT0oooo00<00?l00?ooo`3oool0O03oool00`00o`00oooo0?ooo`13
0?oooa00003o1P3o000B0000od<0oooo00<00?l00?ooo`3oool0=@3oool0
03P0oooo00<00?l00?ooo`3oool0?P3oool<0000o`030?l0o`3oool0oooo
00H0oooo1P3o00090?ooo``0003o0P3o0?ln0?ooo`03003o003oool0oooo
07`0oooo00<00?l00?ooo`3oool0D`3oool60?l005D0oooo00<00?l00?oo
o`3oool0=@3oool003P0oooo00<00?l00?ooo`3oool0>@3oool50000o`03
0?l0o`3oool0oooo01<0oooo103o000F0?ooo`H0003o00<0o`3o0?ooo`3o
ool0=`3oool00`00o`00oooo0?ooo`1l0?ooo`03003o003oool0oooo05@0
oooo103o001F0?ooo`03003o003oool0oooo03D0oooo000h0?ooo`03003o
003oool0oooo03<0oooo1P000?lL0?ooo`80o`007@3oool60000o`030?l0
o`3oool0oooo0340oooo00<00?l00?ooo`3oool0O03oool00`00o`00oooo
0?ooo`1E0?ooo`80o`00E`3oool00`00o`00oooo0?ooo`0e0?ooo`00>03o
ool00`00o`00oooo0?ooo`0]0?ooo`030?l0o`000?l0003o00<0003o8`3o
ool00`3o0000oooo0?ooo`0Q0?ooo`D0003o;`3oool00`00o`00oooo0?oo
o`1l0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3o
ool00`00o`00oooo0?ooo`0e0?ooo`00>03oool00`00o`00oooo0?ooo`0Y
0?ooo`D0003o:03oool00`3o0000oooo0?ooo`0V0?ooo`80003o00<0o`3o
0?ooo`3oool0:P3oool00`00o`00oooo0?ooo`1l0?ooo`03003o003oool0
oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e
0?ooo`00>03oool00`00o`00oooo0?ooo`0V0?ooo`<0003o00<0o`3o0?oo
o`3oool0:P3oool00`3o0000oooo0?ooo`0X0?ooo`<0003o:P3oool00`00
o`00oooo0?ooo`1l0?ooo`03003o003oool0oooo05H0oooo00<0o`000?oo
o`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00>03oool00`00o`00
oooo0?ooo`0T0?ooo`80003o0P3o0?l^0?ooo`030?l0003oool0oooo02/0
oooo0P000?lX0?ooo`03003o003oool0oooo07`0oooo00<00?l00?ooo`3o
ool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo03D0
oooo000h0?ooo`03003o003oool0oooo0280oooo0P000?l20?l0oc00oooo
00<0o`000?ooo`3oool0;@3oool30000obD0oooo00<00?l00?ooo`3oool0
O03oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo
00<00?l00?ooo`3oool0=@3oool003P0oooo00<00?l00?ooo`3oool0803o
ool20000o`030?l0o`3oool0oooo0340oooo00<0o`000?ooo`3oool0;`3o
ool0103o0?l0003o0000o`000?lR0?ooo`03003o003oool0oooo07`0oooo
00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o
003oool0oooo03D0oooo000h0?ooo`03003o003oool0oooo01l0oooo00<0
003o0?l0o`3oool0=03oool00`3o0000oooo0?ooo`0b0?ooo`030?l0o`00
0?l0003o0200oooo00<00?l00?ooo`3oool0O03oool00`00o`00oooo0?oo
o`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0=@3o
ool003P0oooo00<00?l00?ooo`3oool07@3oool20000ocL0oooo00<0o`00
0?ooo`3oool0=03oool00`3o0?l0003o0?ooo`0N0?ooo`03003o003oool0
oooo07`0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E
0?ooo`03003o003oool0oooo03D0oooo000h0?ooo`03003o003oool0oooo
01`0oooo00<0003o0?ooo`3oool0=`3oool00`3o0000oooo0?ooo`0f0?oo
o`80003o7@3oool00`00o`00oooo0?ooo`1l0?ooo`03003o003oool0oooo
05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?oo
o`00>03oool00`00o`00oooo0?ooo`0J0?ooo`80003o>P3oool00`3o0000
oooo0?ooo`0g0?ooo`030?l0o`000?l0oooo01/0oooo00<00?l00?ooo`3o
ool0O03oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0
oooo00<00?l00?ooo`3oool0=@3oool003P0oooo00<00?l00?ooo`3oool0
6@3oool00`000?l0o`3o0?ooo`0j0?ooo`030?l0003oool0oooo03T0oooo
00<0003o0?ooo`3oool06@3oool00`00o`00oooo0?ooo`1l0?ooo`03003o
003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo
0?ooo`0e0?ooo`00>03oool00`00o`00oooo0?ooo`0H0?ooo`030000o`3o
0?l0oooo0380oooo100000050?ooo`030?l0003oool0oooo03X0oooo00<0
003o0?ooo`3oool0603oool00`00o`00oooo0?ooo`1l0?ooo`03003o003o
ool0oooo04d0oooo100000050?ooo`030?l0003oool0oooo05D0oooo00<0
0?l00?ooo`3oool0=@3oool003P0oooo00<00?l00?ooo`3oool05`3oool0
0`000?l0o`3o0?ooo`0c0?ooo`030000003oool0oooo00H0oooo00<0o`00
0?ooo`3oool0>P3oool00`3o0?l0003o0?ooo`0H0?ooo`03003o003oool0
oooo07`0oooo00<00?l00?ooo`3oool0C@3oool00`000000oooo0?ooo`06
0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0=@3oool0
03P0oooo00<00?l00?ooo`3oool05P3oool00`000?l0o`3o0?ooo`0e0?oo
o`030000003oool0oooo00D0oooo00<0o`000000003oool0>`3oool00`3o
0?l0003o0?ooo`0G0?ooo`03003o003oool0oooo07`0oooo00<00?l00?oo
o`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030?l000000000oooo
05D0oooo00<00?l00?ooo`3oool0=@3oool003P0oooo00<00?l00?ooo`3o
ool05@3oool00`000?l0o`3o0?ooo`0g0?ooo`030000003oool0oooo00@0
oooo00<0o`000?ooo`3oool0?03oool00`3o0?l0003o0?ooo`0F0?ooo`03
003o003oool0oooo07`0oooo00<00?l00?ooo`3oool0C`3oool00`000000
oooo0?ooo`040?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3o
ool0=@3oool003P0oooo00<00?l00?ooo`3oool0503oool00`000?l0o`3o
0?ooo`0f0?ooo`040000003oool0oooo000000D0oooo00<0o`000?ooo`3o
ool0?@3oool00`3o0?l0003o0?ooo`0E0?ooo`03003o003oool0oooo07`0
oooo00<00?l00?ooo`3oool0C@3oool010000000oooo0?ooo`0000050?oo
o`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0=@3oool003P0
oooo00<00?l00?ooo`3oool04`3oool00`000?l0o`3o0?ooo`0h0?ooo`80
00001P3oool00`3o0000oooo0?ooo`0n0?ooo`030?l0o`000?l0oooo01@0
oooo00<00?l00?ooo`3oool0O03oool00`00o`00oooo0?ooo`1>0?ooo`80
00001P3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo03D0
oooo000h0?ooo`03003o003oool0oooo0180oooo00<0003o0?l0o`3oool0
@@3oool00`3o0000oooo0?ooo`0n0?ooo`030?l0o`3oool0003o01@0oooo
00<00?l00?ooo`3oool0O03oool00`00o`00oooo0?ooo`1F0?ooo`030?l0
003oool0oooo05D0oooo00<00?l00?ooo`3oool0=@3oool003P0oooo00<0
0?l00?ooo`3oool04P3oool00`000?l0oooo0?ooo`110?ooo`030?l0003o
ool0oooo03l0oooo00<0o`3o0000o`3oool04`3oool00`00o`00oooo0?oo
o`1l0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3o
ool00`00o`00oooo0?ooo`0e0?ooo`00>03oool00`00o`00oooo0?ooo`0A
0?ooo`030000o`3o0?l0oooo0480oooo00<0o`000?ooo`3oool0?`3oool0
0`3o0?l0oooo0000o`0C0?ooo`03003o003oool0oooo07`0oooo00<00?l0
0?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0
oooo03D0oooo000h0?ooo`03003o003oool0oooo0100oooo00<0003o0?l0
o`3oool0@`3oool00`3o0000oooo0?ooo`100?ooo`030?l0o`3oool0003o
0180oooo00<00?l00?ooo`3oool0O03oool00`00o`00oooo0?ooo`1F0?oo
o`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0=@3oool003P0
oooo00<00?l00?ooo`3oool03`3oool00`000?l0oooo0?l0o`140?ooo`03
0?l0003oool0oooo0440oooo00<0o`3o0?ooo`000?l04@3oool00`00o`00
oooo0?ooo`1l0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3o
ool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00>03oool00`00o`00oooo
0?ooo`0?0?ooo`030000o`3o0?l0oooo04@0oooo00<0o`000?ooo`3oool0
@@3oool00`3o0?l0oooo0000o`0A0?ooo`03003o003oool0oooo07`0oooo
00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o
003oool0oooo03D0oooo000h0?ooo`03003o003oool0oooo00h0oooo00<0
003o0?l0o`3oool0A@3oool00`3o0000oooo0?ooo`120?ooo`030?l0o`3o
ool0003o0100oooo00<00?l00?ooo`3oool0O03oool00`00o`00oooo0?oo
o`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0=@3o
ool003P0oooo00<00?l00?ooo`3oool03@3oool00`000?l0oooo0?l0o`16
0?ooo`030?l0003oool0oooo0480oooo00@0o`3o0?ooo`3oool0003o3`3o
ool00`00o`00oooo0?ooo`1l0?ooo`03003o003oool0oooo05H0oooo00<0
o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00>03oool0
0`00o`00oooo0?ooo`0=0?ooo`030000o`3o0?l0oooo04H0oooo00<0o`00
0?ooo`3oool0@`3oool00`3o0?l0oooo0000o`0?0?ooo`03003o003oool0
oooo07`0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E
0?ooo`03003o003oool0oooo03D0oooo000h0?ooo`03003o003oool0oooo
00`0oooo00<0003o0?ooo`3o0?l0A`3oool00`3o0000oooo0?ooo`130?oo
o`040?l0o`3oool0oooo0000o`h0oooo00<00?l00?ooo`3oool0O03oool0
0`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l0
0?ooo`3oool0=@3oool003P0oooo00<00?l00?ooo`3oool0303oool00`00
0?l0o`3o0?ooo`170?ooo`030?l0003oool0oooo04@0oooo00<0o`3o0?oo
o`000?l03P3oool00`00o`00oooo0?ooo`1l0?ooo`03003o003oool0oooo
05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?oo
o`00>03oool00`00o`00oooo0?ooo`0;0?ooo`030000o`3oool0o`3o04P0
oooo00<0o`000?ooo`3oool0A03oool0103o0?l0oooo0?ooo`000?l=0?oo
o`03003o003oool0oooo07`0oooo00<00?l00?ooo`3oool0EP3oool00`3o
0000oooo0?ooo`1E0?ooo`03003o003oool0oooo03D0oooo000h0?ooo`03
003o003oool0oooo00/0oooo00<0003o0?ooo`3o0?l0B03oool00`3o0000
oooo0?ooo`150?ooo`030?l0o`3oool0003o00d0oooo00<00?l00?ooo`3o
ool0O03oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0
oooo00<00?l00?ooo`3oool0=@3oool003P0oooo00<00?l00?ooo`3oool0
2P3oool00`000?l0oooo0?l0o`190?ooo`030?l0003oool0oooo04D0oooo
00@0o`3o0?ooo`3oool0003o303oool00`00o`00oooo0?ooo`1l0?ooo`03
003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00
oooo0?ooo`0e0?ooo`00>03oool00`00o`00oooo0?ooo`0:0?ooo`030000
o`3oool0o`3o04T0oooo00<0o`000?ooo`3oool0AP3oool00`3o0?l0oooo
0000o`0<0?ooo`03003o003oool0oooo07`0oooo00<00?l00?ooo`3oool0
EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo03D0oooo
000h0?ooo`03003o003oool0oooo00X0oooo00<0003o0?ooo`3o0?l0B@3o
ool00`3o0000oooo0?ooo`160?ooo`040?l0o`3oool0oooo0000o`/0oooo
00<00?l00?ooo`3oool0O03oool00`00o`00oooo0?ooo`1F0?ooo`030?l0
003oool0oooo05D0oooo00<00?l00?ooo`3oool0=@3oool003P0oooo00<0
0?l00?ooo`3oool02@3oool010000?l0oooo0?ooo`3o0?m90?ooo`030?l0
003oool0oooo04H0oooo00@0o`3o0?ooo`3oool0003o2`3oool00`00o`00
oooo0?ooo`1l0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3o
ool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00>03oool00`00o`00oooo
0?ooo`090?ooo`030000o`3oool0o`3o04X0oooo00<0o`000?ooo`3oool0
AP3oool0103o0?l0oooo0?ooo`000?l;0?ooo`03003o003oool0oooo07`0
oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03
003o003oool0oooo03D0oooo000h0?ooo`03003o003oool0oooo00T0oooo
00<0003o0?ooo`3o0?l0BP3oool00`3o0000oooo0?ooo`170?ooo`030?l0
o`3oool0003o00/0oooo00<00?l00?ooo`3oool0O03oool00`00o`00oooo
0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0
=@3oool003P0oooo00<00?l00?ooo`3oool0203oool010000?l0oooo0?oo
o`3o0?m:0?ooo`030?l0003oool0oooo04L0oooo00@0o`3o0?ooo`3oool0
003o2P3oool00`00o`00oooo0?ooo`1l0?ooo`03003o003oool0oooo05H0
oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00
>03oool00`00o`00oooo0?ooo`080?ooo`040000o`3oool0oooo0?l0odX0
oooo00<0o`000?ooo`3oool0A`3oool0103o0?l0oooo0?ooo`000?l:0?oo
o`03003o003oool0oooo07`0oooo00<00?l00?ooo`3oool0EP3oool00`3o
0000oooo0?ooo`1E0?ooo`03003o003oool0oooo03D0oooo000h0?ooo`03
003o003oool0oooo00L0oooo00@0003o0?ooo`3oool0o`3oB`3oool00`3o
0000oooo0?ooo`170?ooo`040?l0o`3oool0oooo0000o`X0oooo00<00?l0
0?ooo`3oool0O03oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0
oooo05D0oooo00<00?l00?ooo`3oool0=@3oool003P0oooo00<00?l00?oo
o`3oool01`3oool010000?l0oooo0?ooo`3o0?m;0?ooo`030?l0003oool0
oooo04P0oooo00@0o`3o0?ooo`3oool0003o2@3oool00`00o`00oooo0?oo
o`1l0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3o
ool00`00o`00oooo0?ooo`0e0?ooo`00>03oool00`00o`00oooo0?ooo`07
0?ooo`040000o`3oool0oooo0?l0od/0oooo00<0o`000?ooo`3oool0B03o
ool0103o0?l0oooo0?ooo`000?l90?ooo`03003o003oool0oooo07`0oooo
00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o
003oool0oooo03D0oooo000h0?ooo`03003o003oool0oooo00H0oooo00@0
003o0?ooo`3oool0o`3oC03oool00`3o0000oooo0?ooo`190?ooo`030?l0
o`3oool0003o00T0oooo00<00?l00?ooo`3oool0O03oool00`00o`00oooo
0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0
=@3oool003P0oooo00<00?l00?ooo`3oool01P3oool010000?l0oooo0?oo
o`3o0?m<0?ooo`030?l0003oool0oooo04T0oooo00@0o`3o0?ooo`3oool0
003o203oool00`00o`00oooo0?ooo`1l0?ooo`03003o003oool0oooo05H0
oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00
>03oool00`00o`00oooo0?ooo`060?ooo`040000o`3oool0oooo0?l0odD0
oooo0`0000040?ooo`030?l0003oool0oooo04T0oooo00@0o`3o0?ooo`3o
ool0003o203oool00`00o`00oooo0?ooo`1l0?ooo`03003o003oool0oooo
04l0oooo0`0000040?ooo`030?l0003oool0oooo05D0oooo00<00?l00?oo
o`3oool0=@3oool003P0oooo00<00?l00?ooo`3oool01@3oool01@000?l0
oooo0?ooo`3oool0o`3o04H0oooo00<000000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`190?ooo`050?l0o`3oool0oooo0?ooo`000?l01`3oool0
0`00o`00oooo0?ooo`1l0?ooo`03003o003oool0oooo0500oooo00<00000
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0
oooo03D0oooo000h0?ooo`03003o003oool0oooo00D0oooo00D0003o0?oo
o`3oool0oooo0?l0o`130?ooo`D00000103oool00`3o000000000?ooo`19
0?ooo`050?l0o`3oool0oooo0?ooo`000?l01`3oool00`00o`00oooo0?oo
o`1l0?ooo`03003o003oool0oooo04d0oooo1@0000040?ooo`030?l00000
0000oooo05D0oooo00<00?l00?ooo`3oool0=@3oool003P0oooo00<00?l0
0?ooo`3oool01@3oool010000?l0oooo0?ooo`3o0?m40?ooo`040000003o
ool0oooo000000D0oooo00<0o`000?ooo`3oool0B@3oool01@3o0?l0oooo
0?ooo`3oool0003o00L0oooo00<00?l00?ooo`3oool0O03oool00`00o`00
oooo0?ooo`1=0?ooo`040000003oool0oooo000000D0oooo00<0o`000?oo
o`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00>03oool00`00o`00
oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`3o0?l0A@3oool00`00
0000oooo000000050?ooo`030?l0003oool0oooo04X0oooo00D0o`3o0?oo
o`3oool0oooo0000o`060?ooo`03003o003oool0oooo07`0oooo00<00?l0
0?ooo`3oool0CP3oool00`000000oooo000000050?ooo`030?l0003oool0
oooo05D0oooo00<00?l00?ooo`3oool0=@3oool003P0oooo00<00?l00?oo
o`3oool0103oool01@000?l0oooo0?ooo`3oool0o`3o04H0oooo0P000005
0?ooo`030?l0003oool0oooo04X0oooo00D0o`3o0?ooo`3oool0oooo0000
o`060?ooo`03003o003oool0oooo07`0oooo00<00?l00?ooo`3oool0C`3o
ool2000000D0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?oo
o`0e0?ooo`00>03oool00`00o`00oooo0?ooo`040?ooo`050000o`3oool0
oooo0?ooo`3o0?l0C@3oool00`3o0000oooo0?ooo`1:0?ooo`050?l0o`3o
ool0oooo0?ooo`000?l01P3oool00`00o`00oooo0?ooo`1l0?ooo`03003o
003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo
0?ooo`0e0?ooo`00>03oool00`00o`00oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0o`3o0?ooo`3oool0B`3oool00`3o0000oooo0?oo
o`1:0?ooo`050?l0o`3oool0oooo0?ooo`000?l01P3oool00`00o`00oooo
0?ooo`1l0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0
E@3oool00`00o`00oooo0?ooo`0e0?ooo`00>03oool00`00o`00oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<0o`3o0?ooo`3oool0B`3o
ool00`3o0000oooo0?ooo`1:0?ooo`030?l0o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`1l0?ooo`03003o003o
ool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?oo
o`0e0?ooo`00>03oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00<0o`3o0?ooo`3oool0B`3oool00`3o0000oooo0?ooo`1:
0?ooo`030?l0o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`00o`00oooo0?ooo`1l0?ooo`03003o003oool0oooo05H0oooo00<0o`00
0?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00>03oool00`00
o`00oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`3o0?oo
o`3oool0B`3oool00`3o0000oooo0?ooo`1;0?ooo`050?l0o`3oool0oooo
0?ooo`000?l01@3oool00`00o`00oooo0?ooo`1l0?ooo`03003o003oool0
oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e
0?ooo`00>03oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo
00<0oooo00<0o`3o0?ooo`3oool0B`3oool00`3o0000oooo0?ooo`1;0?oo
o`030?l0o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`00
o`00oooo0?ooo`1l0?ooo`03003o003oool0oooo05H0oooo00<0o`000?oo
o`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00>03oool00`00o`00
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`3o0?ooo`3o
ool0C03oool00`3o0000oooo0?ooo`1;0?ooo`030?l0o`3oool0oooo0080
oooo00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`1l0?ooo`03
003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00
oooo0?ooo`0e0?ooo`00>03oool00`00o`00oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo00<0o`3o0?ooo`3oool0C03oool00`3o0000oooo
0?ooo`1;0?ooo`030?l0o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`00o`00oooo0?ooo`1l0?ooo`03003o003oool0oooo05H0oooo
00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00>03o
ool01@00o`00oooo0?ooo`3oool0003o00D0oooo00<0o`3o0?ooo`3oool0
C03oool00`3o0000oooo0?ooo`1;0?ooo`030?l0o`3oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool00`00o`00oooo0?ooo`1l0?ooo`03003o
003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo
0?ooo`0e0?ooo`00>03oool01@00o`00oooo0?ooo`3oool0003o00D0oooo
00<0o`3o0?ooo`3oool0C03oool00`3o0000oooo0?ooo`1;0?ooo`030?l0
o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo003o001n0?ooo`03
003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00
oooo0?ooo`0e0?ooo`00>03oool01@00o`00oooo0?ooo`3oool0003o00D0
oooo00<0o`3o0?ooo`3oool0C03oool00`3o0000oooo0?ooo`1<0?ooo`03
0?l0o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo003o001n0?oo
o`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00
o`00oooo0?ooo`0e0?ooo`00>03oool01@00o`00oooo0?ooo`3oool0003o
00D0oooo00<0o`3o0?ooo`3oool0C03oool00`3o0000oooo0?ooo`1<0?oo
o`030?l0o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo003o001n
0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool0
0`00o`00oooo0?ooo`0e0?ooo`00>03oool01000o`00oooo0?ooo`000?l6
0?ooo`030?l0o`3oool0oooo04`0oooo00<0o`000?ooo`3oool0C03oool0
0`3o0?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`00o`00OP3o
ool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<0
0?l00?ooo`3oool0=@3oool003P0oooo00@00?l00?ooo`3oool0003o1P3o
ool00`3o0?l0oooo0?ooo`1<0?ooo`030?l0003oool0oooo04`0oooo00<0
o`3o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool00?l007h0oooo
00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o
003oool0oooo03D0oooo000h0?ooo`04003o003oool0oooo0000o`D0oooo
00<0o`3o0?ooo`3oool0C@3oool00`3o0000oooo0?ooo`1<0?ooo`030?l0
o`3oool0oooo00<0oooo00@0003o0?ooo`3oool00?l0OP3oool00`00o`00
oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3o
ool0=@3oool003P0oooo00@00?l00?ooo`3oool0003o1@3oool00`3o0?l0
oooo0?ooo`1=0?ooo`030?l0003oool0oooo04`0oooo00<0o`3o0?ooo`3o
ool00`3oool010000?l0oooo0?ooo`00o`1n0?ooo`03003o003oool0oooo
05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?oo
o`00>03oool00`00o`00oooo0000o`060?ooo`030?l0o`3oool0oooo04d0
oooo00<0o`000?ooo`3oool0C03oool00`3o0?l0oooo0?ooo`030?ooo`04
0000o`3oool0oooo003o07h0oooo00<00?l00?ooo`3oool0EP3oool00`3o
0000oooo0?ooo`1E0?ooo`03003o003oool0oooo03D0oooo000h0?ooo`03
003o003oool0003o00H0oooo00<0o`3o0?ooo`3oool0C@3oool00`3o0000
oooo0?ooo`1<0?ooo`030?l0o`3oool0oooo00<0oooo00@0003o0?ooo`3o
ool00?l0OP3oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo
05D0oooo00<00?l00?ooo`3oool0=@3oool003P0oooo00<00?l00?ooo`00
0?l01P3oool00`3o0?l0oooo0?ooo`1=0?ooo`030?l0003oool0oooo04`0
oooo00<0o`3o0?ooo`3oool00`3oool010000?l0oooo0?ooo`00o`1n0?oo
o`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00
o`00oooo0?ooo`0e0?ooo`00>03oool00`00o`00oooo0000o`060?ooo`03
0?l0o`3oool0oooo04d0oooo00<0o`000?ooo`3oool0C03oool00`3o0?l0
oooo0?ooo`040?ooo`030000o`3oool00?l007h0oooo00<00?l00?ooo`3o
ool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo03D0
oooo000h0?ooo`03003o00000?l0oooo00D0oooo00<0o`3o0?ooo`3oool0
CP3oool00`3o0000oooo0?ooo`1<0?ooo`030?l0o`3oool0oooo00@0oooo
00<0003o0?ooo`00o`00OP3oool00`00o`00oooo0?ooo`1F0?ooo`030?l0
003oool0oooo05D0oooo00<00?l00?ooo`3oool0=@3oool003P0oooo00<0
0?l00000o`3oool01@3oool00`3o0?l0oooo0?ooo`1>0?ooo`030?l0003o
ool0oooo04`0oooo00<0o`3o0?ooo`3oool0103oool00`000?l0oooo003o
001n0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3o
ool00`00o`00oooo0?ooo`0e0?ooo`00>03oool00`00o`00003o0?ooo`05
0?ooo`030?l0o`3oool0oooo04h0oooo00<0o`000?ooo`3oool0C03oool0
0`3o0?l0oooo0?ooo`040?ooo`030000o`3oool00?l007h0oooo00<00?l0
0?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0
oooo03D0oooo000h0?ooo`03003o00000?l0oooo00D0oooo00<0o`3o0?oo
o`3oool0CP3oool00`3o0000oooo0?ooo`1=0?ooo`030?l0o`3oool0oooo
00@0oooo00<0003o003o003oool0O@3oool00`00o`00oooo0?ooo`1F0?oo
o`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0=@3oool003P0
oooo00<00?l00?ooo`3oool01@3oool00`3o0?l0oooo0?ooo`1>0?ooo`03
0?l0003oool0oooo04d0oooo00<0o`3o0?ooo`3oool0103oool00`000?l0
0?l00?ooo`1m0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3o
ool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00>03oool00`00o`00oooo
0?ooo`050?ooo`030?l0o`3oool0oooo04h0oooo00<0o`000?ooo`3oool0
C@3oool00`3o0?l0oooo0?ooo`040?ooo`030000o`00o`00oooo07d0oooo
00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o
003oool0oooo03D0oooo000h0?ooo`03003o003oool0oooo00D0oooo00<0
o`3o0?ooo`3oool0CP3oool00`3o0000oooo0?ooo`1=0?ooo`030?l0o`3o
ool0oooo00@0oooo00<0003o003o003oool0O@3oool00`00o`00oooo0?oo
o`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0=@3o
ool003P0oooo00<00?l00?ooo`3oool01@3oool00`3o0?l0oooo0?ooo`15
0?ooo`<000001P3oool00`3o0000oooo0?ooo`1=0?ooo`030?l0o`3oool0
oooo00@0oooo00<0003o003o003oool0O@3oool00`00o`00oooo0?ooo`1=
0?ooo`<000001P3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0
oooo03D0oooo000h0?ooo`03003o003oool0oooo00@0oooo00<0o`3o0?oo
o`3oool0AP3oool010000000oooo0?ooo`0000050?ooo`030?l0003oool0
oooo04d0oooo00<0o`3o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`1l
0?ooo`03003o003oool0oooo04d0oooo00@000000?ooo`3oool000001@3o
ool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo03D0oooo000h
0?ooo`03003o003oool0oooo00@0oooo00<0o`3o0?ooo`3oool0AP3oool0
10000000oooo0?ooo`0000050?ooo`030?l000000000oooo04d0oooo00<0
o`3o0?ooo`3oool01@3oool00`00o`00oooo0?ooo`1l0?ooo`03003o003o
ool0oooo04d0oooo00@000000?ooo`3oool000001@3oool00`3o00000000
0?ooo`1E0?ooo`03003o003oool0oooo03D0oooo000h0?ooo`03003o003o
ool0oooo00@0oooo00<0o`3o0?ooo`3oool0AP3oool3000000H0oooo00<0
o`000?ooo`3oool0C@3oool00`3o0?l0oooo0?ooo`050?ooo`03003o003o
ool0oooo07`0oooo00<00?l00?ooo`3oool0C@3oool3000000H0oooo00<0
o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00=`3oool0
0`000?l00?l00?ooo`050?ooo`030?l0o`3oool0oooo04L0oooo00<00000
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`1>0?ooo`030?l0o`3oool0
oooo00@0oooo00<00?l00?ooo`3oool0O03oool00`00o`00oooo0?ooo`1>
0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool0E@3oool0
0`00o`00oooo0?ooo`0e0?ooo`00=`3oool00`000?l00?l00?ooo`050?oo
o`030?l0o`3oool0oooo04L0oooo0`0000050?ooo`030?l0003oool0oooo
04h0oooo00<0o`3o0?ooo`3oool0103oool00`00o`00oooo0?ooo`1l0?oo
o`03003o003oool0oooo04h0oooo0`0000050?ooo`030?l0003oool0oooo
05D0oooo00<00?l00?ooo`3oool0=@3oool003L0oooo00<0003o003o003o
ool01@3oool00`3o0?l0oooo0?ooo`1?0?ooo`030?l0003oool0oooo04h0
oooo00<0o`3o0?ooo`3oool0103oool00`00o`00003o0?ooo`1l0?ooo`03
003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00
oooo0?ooo`0e0?ooo`00=`3oool00`000?l00?l00?ooo`050?ooo`030?l0
o`3oool0oooo04l0oooo00<0o`000?ooo`3oool0CP3oool00`3o0?l0oooo
0?ooo`040?ooo`03003o00000?l0oooo07`0oooo00<00?l00?ooo`3oool0
EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo03D0oooo
000g0?ooo`030000o`00o`00oooo00D0oooo00<0o`3o0?ooo`3oool0C`3o
ool00`3o0000oooo0?ooo`1>0?ooo`030?l0o`3oool0oooo00@0oooo00<0
0?l00000o`3oool0O03oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003o
ool0oooo05D0oooo00<00?l00?ooo`3oool0=@3oool003L0oooo00<0003o
003o003oool01@3oool00`3o0?l0oooo0?ooo`1?0?ooo`030?l0003oool0
oooo04h0oooo00<0o`3o0?ooo`3oool0103oool00`00o`00003o0?ooo`1l
0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool0
0`00o`00oooo0?ooo`0e0?ooo`00=`3oool00`000?l00?l00?ooo`050?oo
o`030?l0o`3oool0oooo04l0oooo00<0o`000?ooo`3oool0CP3oool00`3o
0?l0oooo0?ooo`040?ooo`03003o00000?l0oooo07`0oooo00<00?l00?oo
o`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo
03D0oooo000g0?ooo`030000o`00o`00oooo00D0oooo00<0o`3o0?ooo`3o
ool0C`3oool00`3o0000oooo0?ooo`1>0?ooo`030?l0o`3oool0oooo00@0
oooo00<00?l00000o`3oool0O03oool00`00o`00oooo0?ooo`1F0?ooo`03
0?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0=@3oool003H0oooo
00<0003o0?ooo`00o`001P3oool00`3o0?l0oooo0?ooo`1?0?ooo`030?l0
003oool0oooo04h0oooo00<0o`3o0?ooo`3oool0103oool00`00o`00oooo
0000o`1l0?ooo`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0
E@3oool00`00o`00oooo0?ooo`0e0?ooo`00=P3oool00`000?l0oooo003o
00060?ooo`030?l0o`3oool0oooo04l0oooo00<0o`000?ooo`3oool0CP3o
ool00`3o0?l0oooo0?ooo`040?ooo`03003o003oool0003o07`0oooo00<0
0?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003o
ool0oooo03D0oooo000f0?ooo`030000o`3oool00?l000H0oooo00<0o`3o
0?ooo`3oool0C`3oool00`3o0000oooo0?ooo`1?0?ooo`030?l0o`3oool0
oooo00<0oooo00<00?l00?ooo`000?l0O03oool00`00o`00oooo0?ooo`1F
0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0=@3oool0
03H0oooo00<0003o0?ooo`00o`001P3oool00`3o0?l0oooo0?ooo`1?0?oo
o`030?l0003oool0oooo04l0oooo00<0o`3o0?ooo`3oool00`3oool00`00
o`00oooo0000o`1l0?ooo`03003o003oool0oooo05H0oooo00<0o`000?oo
o`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00=P3oool00`000?l0
oooo003o00060?ooo`030?l0o`3oool0oooo04l0oooo00<0o`000?ooo`3o
ool0C`3oool00`3o0?l0oooo0?ooo`030?ooo`03003o003oool0003o07`0
oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03
003o003oool0oooo03D0oooo000f0?ooo`030000o`3oool00?l000H0oooo
00<0o`3o0?ooo`3oool0C`3oool00`3o0000oooo0?ooo`1?0?ooo`030?l0
o`3oool0oooo00<0oooo00<00?l00?ooo`000?l0O03oool00`00o`00oooo
0?ooo`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0
=@3oool003H0oooo00<0003o0?ooo`00o`001P3oool00`3o0?l0oooo0?oo
o`1?0?ooo`030?l0003oool0oooo04l0oooo00<0o`3o0?ooo`3oool00`3o
ool01000o`00oooo0?ooo`000?mk0?ooo`03003o003oool0oooo05H0oooo
00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00=P3o
ool00`000?l0oooo003o00060?ooo`030?l0o`3oool0oooo04l0oooo00<0
o`000?ooo`3oool0C`3oool00`3o0?l0oooo0?ooo`030?ooo`04003o003o
ool0oooo0000og/0oooo00<00?l00?ooo`3oool0EP3oool00`3o0000oooo
0?ooo`1E0?ooo`03003o003oool0oooo03D0oooo000e0?ooo`040000o`3o
ool0oooo003o00H0oooo00<0o`3o0?ooo`3oool0C`3oool00`3o0000oooo
0?ooo`1?0?ooo`030?l0o`3oool0oooo00<0oooo00@00?l00?ooo`3oool0
003oN`3oool00`00o`00oooo0?ooo`1F0?ooo`030?l0003oool0oooo05D0
oooo00<00?l00?ooo`3oool0=@3oool003D0oooo00@0003o0?ooo`3oool0
0?l01P3oool00`3o0?l0oooo0?ooo`1?0?ooo`030?l0003oool0oooo04l0
oooo00<0o`3o0?ooo`3oool00`3oool01000o`00oooo0?ooo`000?mk0?oo
o`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00
o`00oooo0?ooo`0e0?ooo`00=@3oool010000?l0oooo0?ooo`00o`050?oo
o`030?l0o`3oool0oooo0500oooo00<0o`000?ooo`3oool0C`3oool00`3o
0?l0oooo0?ooo`030?ooo`04003o003oool0oooo0000og/0oooo00<00?l0
0?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0
oooo03D0oooo000e0?ooo`040000o`3oool0oooo003o00D0oooo00<0o`3o
0?ooo`3oool0D03oool00`3o0000oooo0?ooo`1?0?ooo`030?l0o`3oool0
oooo00<0oooo00@00?l00?ooo`3oool0003oN`3oool00`00o`00oooo0?oo
o`1F0?ooo`030?l0003oool0oooo05D0oooo00<00?l00?ooo`3oool0=@3o
ool003D0oooo00@0003o0?ooo`3oool00?l01@3oool00`3o0?l0oooo0?oo
o`1@0?ooo`030?l0003oool0oooo04l0oooo00<0o`3o0?ooo`3oool00`3o
ool01@00o`00oooo0?ooo`3oool0003o07X0oooo00<00?l00?ooo`3oool0
EP3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo03D0oooo
000e0?ooo`040000o`3oool0oooo003o00D0oooo00<0o`3o0?ooo`3oool0
D03oool00`3o0000oooo0?ooo`1?0?ooo`030?l0o`3oool0oooo00<0oooo
00D00?l00?ooo`3oool0oooo0000o`1j0?ooo`03003o003oool0oooo05H0
oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00
=03oool01@000?l0oooo0?ooo`3oool00?l000D0oooo00<0o`3o0?ooo`3o
ool0D03oool00`3o0000oooo0?ooo`1?0?ooo`030?l0o`3oool0oooo00<0
oooo00D00?l00?ooo`3oool0oooo0000o`1j0?ooo`03003o003oool0oooo
05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?oo
o`00=03oool01@000?l0oooo0?ooo`3oool00?l000D0oooo00<0o`3o0?oo
o`3oool0D03oool00`3o0000oooo0?ooo`1?0?ooo`030?l0o`3oool0oooo
00<0oooo00D00?l00?ooo`3oool0oooo0000o`1j0?ooo`03003o003oool0
oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e
0?ooo`00=03oool01@000?l0oooo0?ooo`3oool00?l000D0oooo00<0o`3o
0?ooo`3oool0D03oool00`3o0000oooo0?ooo`1?0?ooo`030?l0o`3oool0
oooo00<0oooo00D00?l00?ooo`3oool0oooo0000o`1j0?ooo`03003o003o
ool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?oo
o`0e0?ooo`00=03oool01@000?l0oooo0?ooo`3oool00?l000D0oooo00<0
o`3o0?ooo`3oool0D03oool00`3o0000oooo0?ooo`1?0?ooo`030?l0o`3o
ool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0000o`1j0?ooo`03003o
003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo
0?ooo`0e0?ooo`00=03oool01@000?l0oooo0?ooo`3oool00?l000D0oooo
00<0o`3o0?ooo`3oool0D03oool00`3o0000oooo0?ooo`1?0?ooo`030?l0
o`3oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0000o`1j0?ooo`03
003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00o`00
oooo0?ooo`0e0?ooo`00=03oool01@000?l0oooo0?ooo`3oool00?l000D0
oooo00<0o`3o0?ooo`3oool0D03oool00`3o0000oooo0?ooo`1?0?ooo`03
0?l0o`3oool0oooo00<0oooo00D00?l00?ooo`3oool0oooo0000o`1j0?oo
o`03003o003oool0oooo05H0oooo00<0o`000?ooo`3oool0E@3oool00`00
o`00oooo0?ooo`0e0?ooo`00<`3oool00`000?l0oooo0?ooo`020?ooo`03
003o003oool0oooo00<0oooo00<0o`3o0?ooo`3oool0D03oool00`3o0000
oooo0?ooo`1?0?ooo`030?l0o`3oool0oooo00<0oooo00<00?l00?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`1g0?ooo`03003o003oool0oooo05H0
oooo00<0o`000?ooo`3oool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00
<`3oool00`000?l0oooo0?ooo`020?ooo`03003o003oool0oooo00<0oooo
00<0o`3o0?ooo`3oool0B03oool2000000H0oooo00<0o`000?ooo`3oool0
C`3oool00`3o0?l0oooo0?ooo`030?ooo`03003o003oool0oooo0080oooo
00<0003o0?ooo`3oool0M`3oool00`00o`00oooo0?ooo`1>0?ooo`800000
1P3oool00`3o0000oooo0?ooo`1E0?ooo`03003o003oool0oooo03D0oooo
000c0?ooo`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool00`3o
ool00`3o0?l0oooo0?ooo`170?ooo`040000003oool0oooo000000D0oooo
00<0o`000?ooo`3oool0C`3oool00`3o0?l0oooo0?ooo`030?ooo`03003o
003oool0oooo0080oooo00<0003o0?ooo`3oool0M`3oool00`00o`00oooo
0?ooo`1=0?ooo`040000003oool0oooo000000D0oooo00<0o`000?ooo`3o
ool0E@3oool00`00o`00oooo0?ooo`0e0?ooo`00<`3oool00`000?l0oooo
0?ooo`020?ooo`03003o003oool0oooo00<0oooo00<0o`3o0?ooo`3oool0
A`3oool010000000oooo0?ooo`0000050?ooo`030?l000000000oooo04l0
oooo00<0o`3o0?ooo`3oool00`3oool00`00o`00oooo0?ooo`020?ooo`03
0000o`3oool0oooo07L0oooo00<00?l00?ooo`3oool0C@3oool010000000
oooo0?ooo`0000050?ooo`030?l000000000oooo05D0oooo00<00?l00?oo
o`3oool0=@3oool008T0oooo0P00003o0?ooobl0oooo0P00002F0?ooo`00
R03oool010000000oooo0?ooo`00003o0?ooobd0oooo00@000000?ooo`3o
ool00000U@3oool008T0oooo0P00003o0?ooobl0oooo0P00002F0?ooo`00
o`3ooooo0?oooe<0oooo003o0?ooool0ooooD`3oool00?l0ooooo`3ooomC
0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{593, 366},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009300005b000`400?l0
0000o`00003oo`3ooooo0?ooodD0oooo003o0?oooe`0oooo00<000000?oo
o`3oool0i@3oool003T0oooo1@00000:0?ooo`040000003oool0oooo0000
02/0oooo0P0000020?ooo`030000003oool0000000<000000P3oool00`00
0000oooo0?ooo`0c0?ooo`8000000P3oool00`000000oooo000000030000
0080oooo00<000000?ooo`3oool0RP3oool5000000@0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`00000[0?ooo`8000000P3oool0
0`000000oooo0000000300000080oooo00<000000?ooo`3oool0F03oool2
00000080oooo00<000000?ooo`0000000`0000020?ooo`030000003oool0
oooo03d0oooo000k0?ooo`030000003oool0oooo00<0oooo100000040?oo
o`8000007P3oool>000000050?ooo`000000oooo0?ooo`0000001P3oool0
0`000000oooo0000000V0?ooo`h0000000D0oooo0000003oool0oooo0000
00060?ooo`030000003oool0000008d0oooo00<000000?ooo`3oool00P3o
ool5000000@0oooo0P00000N0?ooo`h0000000D0oooo0000003oool0oooo
000000060?ooo`030000003oool0000004/0oooo3P0000001@3oool00000
0?ooo`3oool0000000H0oooo00<000000?ooo`000000?P3oool003/0oooo
00<000000?ooo`3oool02`3oool200000080oooo0`00000I0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`0000000P3oool00`000000oooo
00000003000000040?ooo`000000oooo000002H0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo000000020?ooo`030000003oool0000000<0
000000@0oooo0000003oool00000S@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo0P0000020?ooo`<000006@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool000000080oooo00<000000?oo
o`0000000`000000103oool000000?ooo`00001;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`0000000P3oool00`000000oooo00000003
000000040?ooo`000000oooo000003h0oooo000k0?ooo`030000003oool0
oooo00X0oooo00H000000?ooo`3oool000000?ooo`00000L0?ooo`030000
003oool0oooo00T0oooo1@0000070?ooo`030000003oool0000002L0oooo
00<000000?ooo`3oool02@3oool5000000L0oooo00<000000?ooo`000000
S@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00H000000?ooo`3oool000000?ooo`00000L0?ooo`030000003oool0oooo
00T0oooo1@0000070?ooo`030000003oool0000004`0oooo00<000000?oo
o`3oool02@3oool5000000L0oooo00<000000?ooo`000000?P3oool003/0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0000000X0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0000002=0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`000000C@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`00
0000?P3oool003X0oooo0P00000B0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`2;0?ooo`8000004P3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`00C@3o
ool00`000000oooo0000000M0?ooo`030000003oool0oooo02h0oooo0P00
000?0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`0000007@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0803oool2000000h0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0200oooo001>
0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`00000000003@3o
ool00`000000oooo0?ooo`0H0?ooo`8000000P3oool200000100oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0G0?ooo`8000000P3o
ool2000009L0oooo00<000000?ooo`3oool0303oool010000000oooo0000
0000000=0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
2P3oool5000000@0oooo00<000000?ooo`3oool02@3oool200000080oooo
0P00000A0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0:0?ooo`D00000103oool00`000000oooo
0?ooo`0:0?ooo`8000000P3oool2000000l0oooo001N0?ooo`040000003o
ool0oooo000000d0oooo00<000000?ooo`3oool0603oool010000000oooo
0?ooo`00000A0?ooo`800000403oool00`000000oooo0?ooo`0G0?ooo`04
0000003oool0oooo00000:P0oooo00@000000?ooo`3oool000003@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`040000003oool0
oooo00000180oooo0P00000?0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00/0oooo00@000000?ooo`3oool00000403oool003P0oooo6`00
000:0?ooo`040000003oool00000000000l0oooo00<000000?ooo`3oool0
603oool2000002D0oooo00<000000?ooo`3oool05`3oool2000008<0oooo
6`00000:0?ooo`040000003oool00000000000l0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`020?ooo`D000001@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo0P00000U0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool00P3oool5000000D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`80
00004@3oool005h0oooo00@000000?ooo`3oool000003`3oool00`000000
oooo0?ooo`0G0?ooo`8000009P3oool00`000000oooo0?ooo`0F0?ooo`80
0000Z@3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00/0oooo0P00000V0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00`0oooo0P00000A0?ooo`00L03oool00`000000
oooo0?ooo`0G0?ooo`040000003oool0oooo000002@0oooo00<000000?oo
o`3oool05P3oool010000000oooo0?ooo`00002j0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000903o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`040000003o
ool0oooo00000100oooo00130?ooo`D000009`3oool00`000000oooo0?oo
o`0G0?ooo`8000000P3oool200000080oooo0`0000030?ooo`8000000P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo0P00
00020?ooo`8000000P3oool3000000<0oooo0P0000020?ooo`030000003o
ool0oooo07d0oooo1@00000W0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo0?ooo`8000000P3oool010000000oooo0?ooo`3oool200000080
oooo0P0000020?ooo`<000000`3oool200000080oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool20000
0080oooo00<000000?ooo`3oool00P3oool200000080oooo0P0000020?oo
o`<000000`3oool200000080oooo0@0000010?ooo`40oooo00150?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo000001@0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
00000840oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`00000D0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
0000303oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0000
0080oooo00150?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`080?oo
o`8000005`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
00000840oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool2
000000@0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00
000<0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
4`3oool00`000000oooo0?ooo`080?ooo`8000004`3oool00`000000oooo
0?ooo`090?ooo`800000103oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo000000d0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000020?ooo`00A@3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo00H0oooo00H000000?ooo`3oool000000?ooo`00000G
0?ooo`030000003oool0oooo0080oooo1000000C0?ooo`030000003oool0
oooo00H0oooo00H000000?ooo`3oool000000?ooo`00000F0?ooo`030000
003oool0oooo0080oooo100000220?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool01P3oool01P000000oooo0?ooo`000000oooo0000
02/0oooo1000000=0?ooo`030000003oool0oooo0080oooo1000000C0?oo
o`030000003oool0oooo00H0oooo00H000000?ooo`3oool000000?ooo`00
000Z0?ooo`@000003P3oool00`000000oooo0?ooo`020?ooo`@000000`3o
ool004D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0503oool0
0`000000oooo0000000I0?ooo`030000003oool0oooo00L0oooo00H00000
0?ooo`3oool000000?ooo`00000E0?ooo`030000003oool0000008T0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0000000I0?ooo`030000003oool0oooo00L0oooo00H000000?ooo`3oool0
00000?ooo`00000k0?ooo`030000003oool0000000X0oooo00140?ooo`80
0000903oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080
0000603oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P00000G0?ooo`030000003oool0oooo08L0
oooo0P00000T0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P00000m0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`02000003d0oooo00<000000?ooo`3o
ool02@3oool006X0oooo300000020?ooo`030000003oool0oooo0340oooo
300000020?ooo`030000003oool0oooo0<H0oooo300000020?ooo`030000
003oool0oooo05H0oooo300000020?ooo`030000003oool0oooo04P0oooo
001h0?ooo`<00000@03oool200000=@0oooo0`00001U0?ooo`800000B03o
ool00?l0ooooo`3ooom50?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{579, 23},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Animation",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/TaylorSeriesAnimation.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  ",
  StyleBox[ButtonBox["The Maclaurin series",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/TaylorSeriesAnimation.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\) x\^\(2  n\)\)],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["does not converge uniformly on (-1,1).",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/TaylorSeriesAnimation.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  "Solution.  For ",
  Cell[BoxData[
      \(z \[Element] \(D\_1\) \((0)\)\)]],
  ",\n\n",
  StyleBox["(7-13)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(1\/\(1\  - \ z\)\  = \ \[Sum]\+\(n = 0\)\%\[Infinity] z\^n\)]],
  ". \n\nIf we let ",
  Cell[BoxData[
      \(z\^2\)]],
  " take the role of z in ",
  StyleBox["(7-13)",
    FontColor->RGBColor[0, 0, 1]],
  ", we get that  \n\n\t\t\t",
  Cell[BoxData[
      \(1\/\(1\  - \ z\^2\) = \(1\/\(1\  - \ \((z\^2)\)\)\  = \ \(\[Sum]\+\(n \
= 0\)\%\[Infinity]\((z\^2)\)\^n\  = \ \[Sum]\+\(n = 0\)\%\[Infinity] z\^\(2  \
n\)\)\)\)]],
  ",  \n\nfor  ",
  Cell[BoxData[
      \(z\^2 \[Element] \(D\_1\) \((0)\)\)]],
  ".  But  ",
  Cell[BoxData[
      \(z\^2 \[Element] \(D\_1\) \((0)\)\)]],
  "  iff  ",
  Cell[BoxData[
      \(z \[Element] \(D\_1\) \((0)\)\)]],
  ",  thus we have proven that  ",
  Cell[BoxData[
      \(1\/\(1\  - \ z\^2\) = \[Sum]\+\(n = 0\)\%\[Infinity] z\^\(2  n\)\)]],
  "  for  ",
  Cell[BoxData[
      \(z \[Element] \(D\_1\) \((0)\)\)]],
  ".\n\nNext, let  ",
  Cell[BoxData[
      \(\(-z\^2\)\)]],
  "  take the role of z in Equation ",
  StyleBox["(7-13)",
    FontColor->RGBColor[0, 0, 1]],
  ", we get that  \n\n\t\t\t",
  Cell[BoxData[
      \(1\/\(1\  + \ z\^2\) = \(1\/\(1\  - \ \((\(-z\^2\))\)\)\  = \ \(\[Sum]\
\+\(n = 0\)\%\[Infinity]\((\(-z\^2\))\)\^n\  = \ \[Sum]\+\(n = 0\)\%\
\[Infinity]\(\((\(-1\))\)\^n\) z\^\(2  n\)\)\)\)]],
  "\n\t\t\t\n gives the second part of Equations ",
  StyleBox["(7-12)",
    FontColor->RGBColor[0, 0, 1]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Real Solution 7.4 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[x_] = 1\/\(1 - x\^2\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Rlines = {{Green, Line[{{\(-1\), \(-2\)}, {\(-1\), 8}}]}, {Red, 
            Line[{{0, \(-2\)}, {0, 8}}]}, {Green, 
            Line[{{1, \(-2\)}, {1, 8}}]}};\)\ \), "\[IndentingNewLine]", 
    \(\(Cpoint = {{Red, PointSize[0.025], 
            Point[{0, f[0]}]}};\)\ \ \), "\[IndentingNewLine]", 
    \(\(ydot = Graphics[Cpoint];\)\ \), "\[IndentingNewLine]", 
    \(\(Rends = Graphics[Rlines];\)\ \), "\[IndentingNewLine]", 
    \(For[i = 1, 
      i \[LessEqual] 15, \(i++\), \[IndentingNewLine]m = 
        2  i; \[IndentingNewLine]T[x_]\  = \ 
        Normal[Series[f[x], {x, 0, m}]]; \ \ \[IndentingNewLine]graph = 
        Plot[{f[x], T[x]}, {x, \(-1.5\), 1.5}, 
          PlotStyle \[Rule] {Magenta, Blue}, 
          PlotRange \[Rule] {{\(-1.5\), 1.5}, {\(-2\), 8}}, 
          Ticks \[Rule] {Range[\(-1.5\), 1.5, 0.5], Range[\(-2\), 8, 2]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]figure = 
        Show[graph, ydot, Rends, 
          DisplayFunction \[Rule] $DisplayFunction]; \
\[IndentingNewLine]Print[\*"\"\<Approximation of \!\(1\/\(1 - x\^2\)\) with \
\>\"", "\<\n\>", "\<S\>"\_m, "\<[x] = \>", T[x]];\ \ ]\ \ \)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Complex Solution 7.4 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that ",
  Cell[BoxData[
      \(1\/\(1\  - \ z\^2\) = \[Sum]\+\(n = 0\)\%\[Infinity] z\^\(2  n\)\)]],
  "  is valid for all ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ".  \n",
  "\n",
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = 1\/\(1\  - \ z\^2\)\)]],
  " and find the first few terms of the Maclaurin series."
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, n, S50, S\[Infinity]];\)\ \), "\n", 
    \(\(f[z_]\  = \ 1\/\(1 - z\^2\);\)\ \), "\n", 
    \(\(S50[z_]\  = \ Normal[Series[f[z], {z, 0, 50}]];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_50\)[z] = \>\"", 
        S50[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = \>", 
        S50[z], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Sum up infinitely many terms to verify that we have things right.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(S50[z_]\ \ \  = \ \[Sum]\+\(n = 0\)\%25 z\^\(2  n\);\)\ \), "\n", 
    \(\(S\[Infinity][
          z_]\  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity] z\^\(2  n\);\)\ \), "\n\
", 
    \(\(Print[\*"\"\<\!\(S\_50\)[z] = \>\"", 
        S50[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_\[Infinity]\)[z] = \!\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\)\!\(z\^\(2  n\)\) = \>\"", 
        S\[Infinity][z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some partial sums for  ",
  Cell[BoxData[
      \(f[z] = 1\/\(1\  - \ z\^2\)\)]],
  ".  Since convergence will be more rapid in a smaller disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(r\)\)\)\)]],
  "  we will use the half disk  ",
  Cell[BoxData[
      \(Im[z] > 0\ \ and\ \  | z | \(\(<\)\(\ \)\(0.9\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, j, m, n, s, z];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = \ 1\/\(1 - z\^2\);\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(For\ [j = 3, 
        j \[LessEqual] 5, \(j++\), \[IndentingNewLine]m = 
          4\ j; \ \[IndentingNewLine]s[
            z_] = \[Sum]\+\(n = 0\)\%m z\^\(2  n\); \ \
\[IndentingNewLine]PolarMap[s, {0, 0.9, 0.05}, {0, \[Pi], \[Pi]\/24}, 
          PlotRange \[Rule] {{0, 4}, {\(-2\), 2}}, AspectRatio \[Rule] 1, 
          Ticks \[Rule] {Range[0, 4, 1], Range[\(-2\), 2, 1]}, 
          AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Red, 
              Blue}]; \ \ \[IndentingNewLine]Print["\<w = \>", "\<S\>"\_\(2  \
m\), "\<[z] = \>", s[z]];\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[f, {0, 0.9, 0.05}, {0, \[Pi], \[Pi]\/24}, 
        PlotRange \[Rule] {{0, 4}, {\(-2\), 2}}, AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[0, 4, 1], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\n", 
    \(\(Print["\<  The mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Real Solution 7.4 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[x_] = 1\/\(1 + x\^2\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Rlines = {{Green, Line[{{\(-1\), \(-2\)}, {\(-1\), 8}}]}, {Red, 
            Line[{{0, \(-2\)}, {0, 8}}]}, {Green, 
            Line[{{1, \(-2\)}, {1, 8}}]}};\)\ \), "\[IndentingNewLine]", 
    \(\(Cpoint = {{Red, PointSize[0.025], 
            Point[{0, f[0]}]}};\)\ \ \), "\[IndentingNewLine]", 
    \(\(ydot = Graphics[Cpoint];\)\ \), "\[IndentingNewLine]", 
    \(\(Rends = Graphics[Rlines];\)\ \), "\[IndentingNewLine]", 
    \(For[i = 1, 
      i \[LessEqual] 15, \(i++\), \[IndentingNewLine]m = 
        2  i; \[IndentingNewLine]T[x_]\  = \ 
        Normal[Series[f[x], {x, 0, m}]]; \ \ \[IndentingNewLine]graph = 
        Plot[{f[x], T[x]}, {x, \(-1.5\), 1.5}, 
          PlotStyle \[Rule] {Magenta, Blue}, 
          PlotRange \[Rule] {{\(-1.5\), 1.5}, {\(-2\), 8}}, 
          Ticks \[Rule] {Range[\(-1.5\), 1.5, 0.5], Range[\(-2\), 8, 2]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]figure = 
        Show[graph, ydot, Rends, 
          DisplayFunction \[Rule] $DisplayFunction]; \
\[IndentingNewLine]Print[\*"\"\<Approximation of \!\(1\/\(1 + x\^2\)\) with \
\>\"", "\<\n\>", "\<S\>"\_m, "\<[x] = \>", T[x]];\ \ ]\ \ \)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Complex Solution 7.4 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that ",
  Cell[BoxData[
      \(1\/\(1\  + \ z\^2\) = \[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\
\) z\^\(2  n\)\)]],
  " is valid for all ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ".  \n",
  "\n",
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = 1\/\(1\  + \ z\^2\)\)]],
  " and find the first few terms of the Maclaurin series."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, n, S50, S\[Infinity]];\)\ \), "\n", 
    \(\(f[z_]\  = \ 1\/\(1 + z\^2\);\)\ \), "\n", 
    \(\(S50[z_]\  = \ Normal[Series[f[z], {z, 0, 50}]];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_50\)[z] = \>\"", 
        S50[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = \>", 
        S50[z], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Sum up infinitely many terms to verify that we have things right.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(S50[
          z_]\ \ \  = \ \[Sum]\+\(n = 0\)\%25\(\((\(-1\))\)\^n\) 
            z\^\(2  n\);\)\ \), "\n", 
    \(\(S\[Infinity][
          z_]\  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\) 
            z\^\(2  n\);\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_25\)[z] = \>\"", 
        S50[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_\[Infinity]\)[z] = \!\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\)\!\(\((\(-1\))\)\^n\)\!\(z\^\(2  n\)\) =  \>\"", 
        S\[Infinity][z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some partial sums for  ",
  Cell[BoxData[
      \(f[z] = 1\/\(1\  + \ z\^2\)\)]],
  ".  Since convergence will be more rapid in a smaller disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(r\)\)\)\)]],
  "  we will use the half disk  ",
  Cell[BoxData[
      \(Im[z] > 0\ \ and\ \  | z | \(\(<\)\(\ \)\(0.9\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, j, m, n, s, z];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = \ 1\/\(1 + z\^2\);\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(For\ [j = 3, 
        j \[LessEqual] 5, \(j++\), \[IndentingNewLine]m = 
          4\ j; \ \[IndentingNewLine]s[
            z_] = \[Sum]\+\(n = 0\)\%m\(\((\(-1\))\)\^n\) 
              z\^\(2  n\); \ \[IndentingNewLine]PolarMap[
          s, {0, 0.9, 0.05}, {0, \[Pi], \[Pi]\/24}, 
          PlotRange \[Rule] {{0, 4}, {\(-2\), 2}}, AspectRatio \[Rule] 1, 
          Ticks \[Rule] {Range[0, 4, 1], Range[\(-2\), 2, 1]}, 
          AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Red, 
              Blue}]; \ \ \[IndentingNewLine]Print["\<w = \>", "\<S\>"\_\(2  \
m\), "\<[z] = \>", s[z]];\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[f, {0, 0.9, 0.05}, {0, \[Pi], \[Pi]\/24}, 
        PlotRange \[Rule] {{0, 4}, {\(-2\), 2}}, AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[0, 4, 1], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\n", 
    \(\(Print["\<  The mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Question.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Why do the graph of  ",
  Cell[BoxData[
      \(w = \(f\_1[
            z] = \(1\/\(1\  - \ z\^2\)\ \ \ and\ \ \ w = \(f\_2[z] = 
              1\/\(1\  + \ z\^2\)\)\)\)\)]],
  " \"appear\" to be the same ?"
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark 7.1",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Corollary 7.3 clears up what often seems to be a mystery when series are \
first introduced in calculus.  The calculus analog of Equations ",
  StyleBox["(7-12)",
    FontColor->RGBColor[0, 0, 1]],
  " is  \n\n",
  StyleBox["(7-14)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(1\/\(1\  - \ x\^2\) = \[Sum]\+\(n = 0\)\%\[Infinity] x\^\(2  n\)\)]],
  "    and    ",
  Cell[BoxData[
      \(1\/\(1\  + \ x\^2\) = \[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\
\) x\^\(2  n\)\)]],
  "   for   ",
  Cell[BoxData[
      \(x \[Element] \((\(-1\), 1)\)\)]],
  ".  \n\nFor many students, it makes sense that the first series in \
Equations ",
  StyleBox["(7-14)",
    FontColor->RGBColor[0, 0, 1]],
  " converges only on the interval  ",
  Cell[BoxData[
      \(\((\(-1\), 1)\)\)]],
  "  because ",
  Cell[BoxData[
      \(1\/\(1\  - \ x\^2\)\)]],
  " is undefined at the points  ",
  Cell[BoxData[
      \(x = \(\[PlusMinus]1\)\)]],
  ".  It seems unclear as to why this should also be the case for the series \
representing ",
  Cell[BoxData[
      \(1\/\(1\  + \ x\^2\)\)]],
  ", since the real-valued function ",
  Cell[BoxData[
      \(f \((x)\) = 1\/\(1\  + \ x\^2\)\)]],
  " is defined everywhere.  The explanation, of course, comes from the \
complex domain.  The complex function ",
  Cell[BoxData[
      \(f \((z)\) = 1\/\(1\  + \ z\^2\)\)]],
  " is not defined everywhere.  In fact, the singularities of  ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  "  are at the points  ",
  Cell[BoxData[
      \(z = \(\[PlusMinus]\[ImaginaryI]\)\)]],
  ",  and the distance between them and the point  ",
  Cell[BoxData[
      \(z = \(\[Alpha] = 0\)\)]],
  "  equals ",
  StyleBox["1",
    FontFamily->"Courier New"],
  ".According to Corollary 7.3, therefore, Equations ",
  StyleBox["(7-14)",
    FontColor->RGBColor[0, 0, 1]],
  " are valid only for ",
  Cell[BoxData[
      \(z \[Element] \(D\_1\) \((0)\)\)]],
  ", and thus Equations ",
  StyleBox["(7-14)",
    FontColor->RGBColor[0, 0, 1]],
  " are valid only for the real numbers  ",
  Cell[BoxData[
      \(x \[Element] \((\(-1\), 1)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tAlas, there is a potential fly in this ointment: Corollary 7.3 applies \
to Taylor series.  To form the Taylor series of a function, we must compute \
its derivatives.  We didn't get the series in Equations ",
  StyleBox["(7-12)",
    FontColor->RGBColor[0, 0, 1]],
  " by computing derivatives, so how do we know that they are indeed the \
Taylor series centered at  ",
  Cell[BoxData[
      \(z = \(\[Alpha] = 0\)\)]],
  "?  Perhaps the Taylor series would give completely different expressions \
from those given by Equations ",
  StyleBox["(7-12)",
    FontColor->RGBColor[0, 0, 1]],
  ".  Fortunately, Theorem 7.5 removes this possibility.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 7.5  (Uniqueness of Power Series).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose that in some disk ",
  Cell[BoxData[
      \(\(D\_r\) \((\[Alpha])\)\)]],
  " we have  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ \(\[Sum]\+\(n = 0\)\%\[Infinity]\( 
                  a\_n\) \((z - \[Alpha])\)\^n\ \  = \ \ \[Sum]\+\(n = 0\)\%\
\[Infinity]\( b\_n\) \((z - \[Alpha])\)\^n\)\)]],
  ".  \n\nThen  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(a\_n\), "=", 
          RowBox[{
            RowBox[{\(b\_n\), "   ", 
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "   ", "n"}], "=", "0"}]}], ",", 
        "1", ",", "2", ",", "..."}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.5 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Maclaurin series for ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(sin\^3\) z\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Solution.  Computing derivatives for",
  " ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " ",
  "would be an onerous task. Fortunately, we can make use of the \
trigonometric identity  \n\n\t\t\t",
  Cell[BoxData[
      \(\(sin\^3\) 
          z\ \  = \ \ \(3\/4\) sin\ z\ \ \  - \ \ \(1\/4\) sin\ 3  z\)]],
  ".  \n\nRecall that the series for sin z (valid for all z) is  ",
  Cell[BoxData[
      \(sin\ z\ \  = \ \ \[Sum]\+\(n = \
0\)\%\[Infinity]\((\(-1\))\)\^n\/\(\((2  n + 1)\)!\)\ z\^\(2  n + 1\)\)]],
  ".  Using the identity for  ",
  Cell[BoxData[
      \(\(sin\^3\) z\)]],
  ",  we obtain  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\(sin\^3\) 
          z\ \  = \ \ \(3\/4\) \(\[Sum]\+\(n = \
0\)\%\[Infinity]\((\(-1\))\)\^n\/\(\((2  n + 1)\)!\)\ z\^\(2  n + 1\)\)\ \ \  \
- \ \ \(1\/4\) \(\[Sum]\+\(n = 0\)\%\[Infinity]\((\(-1\))\)\^n\/\(\((2  n + \
1)\)!\)\ \((3  z)\)\^\(2  n + 1\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(3\/4\) \(\[Sum]\+\(n \
= 0\)\%\[Infinity]\((\(-1\))\)\^n\/\(\((2  n + 1)\)!\)\ z\^\(2  n + 1\)\)\ \ \
\  - \ \ \(3\/4\) \(\[Sum]\+\(n = 0\)\%\[Infinity]\(\(\((\(-1\))\)\^n\) \
9\^n\)\/\(\((2  n + 1)\)!\)\ z\^\(2  n + 1\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\(\(\((\(-1\))\)\^n\) \(\(3 \((1 - 
                      9\^n)\)\)\/\(4 \(\((2  n + 1)\)!\)\)\)\(\ \)\(z\^\(2  
                    n + 1\)\)\(\ \)\)\)\)\)}]],
  "\n\nBy the uniqueness of power series, this last expression is the \
Maclaurin series for  ",
  Cell[BoxData[
      \(\(sin\^3\) z\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 7.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "First, we can let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " verify the trigonometric identity  ",
  Cell[BoxData[
      \(\(sin\^3\) 
          z\ \  = \ \ \(3\/4\) sin\ z\ \ \  - \ \ \(1\/4\) sin\ 3  z\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(3\/4\)Sin[z] - \!\(1\/4\)Sin[3z]  =  \>\"", 
        Simplify[\(3\/4\) Sin[z] - \(1\/4\) 
              Sin[3  z]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ \ Simplify[\((Sin[z])\)\^3\ \  \[Equal] \ \ \(3\/4\) 
                Sin[z] - \(1\/4\) 
                Sin[3  z]]\ \ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Then we could let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " calculate the sum of the proposed series."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\< \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\((\(-1\))\)\^n\
\)\!\(\(3 \((1 - 9\^n)\)\)\/\(4 \(\((2  n + 1)\)!\)\)\) \!\(z\^\(2  n + 1\)\) \
 =  \>\"", 
        FullSimplify[\ \[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\) \(3 \
\((1 - 9\^n)\)\)\/\(4 \(\((2  n + 1)\)!\)\)\ z\^\(2  n + 1\)]\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\ 
        FullSimplify[\ \[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\) \(3 \
\((1 - 9\^n)\)\)\/\(4 \(\((2  n + 1)\)!\)\)\ z\^\(2  n + 1\)]\  \[Equal] \ \ \
\((Sin[z])\)\^3\ \ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Or we could supply more details if you prefer. \n\nEnter the function  ",
  Cell[BoxData[
      \(f[z] = Sin[z]\^3\)]],
  "  and find the first few terms of the Maclaurin series."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, f1, f2, n, S27];\)\ \), "\n", 
    \(\(f[z_]\  = \ Sin[z]\^3;\)\ \), "\n", 
    \(\(S27[z_]\  = \ Normal[Series[f[z], {z, 0, 27}]];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_27\)[z] = \>\"", 
        S27[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = \>", 
        S27[z], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The Maclaurin polynomial  ",
  Cell[BoxData[
      \(S\_27[z]\)]],
  " of degree n=27  is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " equal to the cube of  ",
  Cell[BoxData[
      \(S\_9[z]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(S9[z_]\  = \ Normal[Series[f[z], {z, 0, 9}]]\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(S\_9\)[z] = \>\"", 
        S9[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<(\!\(S\_9\)[z]\!\(\()\^3\)\) = \>\"", 
        S9[z]\^3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<(\!\(S\_9\)[z]\!\(\()\^3\)\) = \>\"", 
        Expand[S9[z]\^3]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Warning (\!\(S\_9\)[z]\!\(\()\^3\)\) \[NotEqual] \
\!\(S\_27\)[z].\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(S\_27\)[z] = \>\"", 
        S27[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Sum up infinitely many terms to verify that we have things right.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f1[z_]\  = 
        PowerExpand[\[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\ 3\)\/\(4 \
\(\((2  n + 1)\)!\)\)\ z\^\(2  n + 1\)];\)\ \), "\n", 
    \(\(f2[z_]\  = \ 
        PowerExpand[\[Sum]\+\(n = 0\)\%\[Infinity]\(\(-\ \((\(-1\))\)\^n\)\ 3\
\ 9\^n\)\/\(4 \(\((2  n + 1)\)!\)\)\ z\^\(2  n + 1\)];\)\ \), "\n", 
    \(\(f[z_]\  = \ 
        Factor[f1[z]\  + \ f2[z], \ Trig \[Rule] True];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_1\)[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\
\(\((\(-1\))\)\^n\\\ 3\)\/\(4 \(\((2  n + 1)\)!\)\)\) \!\(z\^\(2  n + 1\)\) = \
 \>\"", f1[z]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_2\)[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\
\(\(-\\\ \((\(-1\))\)\^n\)\\\ 3\\\ 9\^n\)\/\(4 \(\((2  n + 1)\)!\)\)\) \
\!\(z\^\(2  n + 1\)\) =  \>\"", f2[z]];\)\ \), "\n", 
    \(\(Print[\*"\"\< f[z] = \!\(f\_1\)[z] + \!\(f\_2\)[z] = \>\"", \ 
        f1[z]\  + \ f2[z]];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to plot some partial sums for  ",
  Cell[BoxData[
      \(f[z] = \ Sin[z]\^3\)]],
  ".  For illustration we use the portion of the  disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1.2\)\)\)\)]],
  "  that lies in the sector ",
  Cell[BoxData[
      \(0 < Arg[z] < \(23  \[Pi]\)\/36\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, j, m, n, s, z];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_]\  = \ Sin[z]\^3;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(For\ [j = 1, 
        j \[LessEqual] 5, \(j++\), \[IndentingNewLine]m = 
          2  j + 1; \ \[IndentingNewLine]s[z_] = 
          Normal[Series[f[z], {z, 0, m}]]; \ \[IndentingNewLine]PolarMap[
          s, {0, 1.2, 0.1}, {0, \(23  \[Pi]\)\/36, \[Pi]\/36}, 
          PlotRange \[Rule] {{\(-3\), 3}, {\(-3.5\), 2.5}}, 
          AspectRatio \[Rule] 1, 
          Ticks \[Rule] {Range[0, 4, 1], Range[\(-2\), 2, 1]}, 
          AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Red, 
              Blue}]; \ \ \[IndentingNewLine]Print["\<w = \>", "\<S\>"\_m, \
"\<[z] = \>", s[z]];\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[f, {0, 1.2, 0.1}, {0, \(23  \[Pi]\)\/36, \[Pi]\/36}, 
        PlotRange \[Rule] {{\(-3\), 3}, {\(-3.5\), 2.5}}, 
        AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[0, 4, 1], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\n", 
    \(\(Print["\<  The mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell["\<\
\t In the preceding argument we used some obvious results of power series \
representations that we haven't yet formally stated.  The requisite results \
are part of Theorem 7.6.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 7.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " have the power series representations  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\) = \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                  a\_n\) \((z - \[Alpha])\)\^n\ \ \ for\ \ z \[Element] \(D\_\
\(r\_1\)\) \((\[Alpha])\)\)]],
  ", \nand \n\t\t\t",
  Cell[BoxData[
      \(g \((z)\) = \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                  b\_n\) \((z - \[Alpha])\)\^n\ \ \ for\ \ z \[Element] \(D\_\
\(r\_2\)\) \((\[Alpha])\)\)]],
  ".  \n\nIf  ",
  Cell[BoxData[
      \(r = min {r\_1, r\_2}\ \ and\ \ \[Beta]\)]],
  "  is any complex constant, then\n\n",
  StyleBox["(7-15)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\t\t\t",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(\[Beta]f \((z)\)\ \  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\( \
\[Beta]a\_n\) \((z - \[Alpha])\)\^n\ \ \ for\ \ z \[Element] \(D\_\(r\_1\)\) \
\((\[Alpha])\)\)]],
  ",  \n\n",
  StyleBox["(7-16)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\t\t\t",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(f \((z)\) + 
          g \((z)\)\ \  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\((a\_n + 
                  b\_n)\) \((z - \[Alpha])\)\^n\ \ \ for\ \ z \[Element] \
\(D\_r\) \((\[Alpha])\)\)]],
  ",  and  \n\n",
  StyleBox["(7-17)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\t\t\t",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(f \((z)\)*
          g \((z)\)\ \  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                  c\_n\) \((z - \[Alpha])\)\^n\ \ \ for\ \ z \[Element] \
\(D\_r\) \((\[Alpha])\)\)]],
  ",   where \n\n",
  StyleBox["(7-18)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\t\t\t",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(c\_n\  = \ \[Sum]\+\(k = o\)\%n\( a\_n\) b\_\(n - k\)\)]],
  ". \n\nIdentity ",
  StyleBox["(7-17)",
    FontColor->RGBColor[0, 0, 1]],
  " is known as the ",
  ButtonBox["Cauchy",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " product of the series for ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.6 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Cauchy product of series to show that \n\n\t\t\t",
  Cell[BoxData[
      \(1\/\((1\  - \ z)\)\^2\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\((n + 
                1)\)\ z\^n\)]],
  "   for   ",
  Cell[BoxData[
      \(z\ \[Epsilon]\ \(D\_1\) \((0)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Solution.  We let  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(g \((z)\)\  = \ 1\/\(1\  - \ z\)\)\)]],
  ",  for ",
  Cell[BoxData[
      \(z\ \[Epsilon]\ \(D\_1\) \((0)\)\)]],
  ".   In terms of Theorem 7.6, we have  ",
  Cell[BoxData[
      \(a\_n\  = \ \(b\_n\  = \ 1\)\)]],
  ",  for all n, and thus Equation ",
  StyleBox["(7-17)",
    FontColor->RGBColor[0, 0, 1]],
  " gives  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(1\/\((1\  - \ z)\)\^2\ \  = \ \ \(h \((z)\)\ \  = \ \ f \((z)\) 
            g \((z)\)\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\((\[Sum]\+\(k = 0\)\%n\( a\_k\) b\_\(n - k\))\) 
            z\^n\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\((\[Sum]\+\(k = 0\)\%n\ 1)\) 
            z\^n\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\((n + 1)\)\ z\^n\)\)\)}]],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 7.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Use the following fact that ",
  Cell[BoxData[
      \(f \((z)\) = \(g \((z)\) = \(1\/\(1\  - \ z\) = \[Sum]\+\(n = 0\)\%\
\[Infinity] z\^n\ \ \ for\ \ z\ \[Epsilon]\ \(D\_1\) \((0)\)\)\)\)]],
  ". \nEnter the coefficients ",
  Cell[BoxData[
      \(a\_n = \(1\ \ \ and\ \ \ b\_n = 1\)\)]],
  "  and let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " carry out the computations."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(a = \(b = \(c = \(z = 0\)\)\); \ Remove[a, b, c, z];\ \), "\n", 
    \(\(Clear[f, g, h, k, n];\)\ \), "\n", 
    \(\(a\_n_ = 1;\)\ \), "\n", 
    \(\(b\_n_ = 1;\)\ \), "\n", 
    \(\(c\_n_ = 
        FullSimplify[\[Sum]\+\(k = 0\)\%n\( a\_k\) 
              b\_\(n - k\)];\)\ \), "\n", 
    \(\(f[z_] = 
        FullSimplify[\[Sum]\+\(n = 0\)\%\[Infinity]\( a\_n\) 
              z\^n];\)\ \), "\n", 
    \(\(g[z_] = 
        FullSimplify[\[Sum]\+\(n = 0\)\%\[Infinity]\( b\_n\) 
              z\^n];\)\ \), "\n", 
    \(\(h[z_] = 
        FullSimplify[\[Sum]\+\(n = 0\)\%\[Infinity]\( c\_n\) 
              z\^n];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(a\_n\) = \>\"", a\_n];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(b\_n\) = \>\"", b\_n];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<f[z] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\!\(z\^n\) = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)(\>\"", a\_k, \*"\"\<)\!\(z\^n\) = \>\"", 
        f[z]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<g[z] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(b\_n\)\!\(z\^n\) = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)(\>\"", b\_\(n - k\), \*"\"\<)\!\(z\^n\) = \>\"", 
        g[z]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(c\_n\) = \!\(\[Sum]\+\(k = 0\)\%n\)\!\(a\_k\)\!\(b\_\
\(n - k\)\)\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(c\_n\) = \!\(\[Sum]\+\(k = 0\)\%n\)(\>\"", 
        a\_k, "\<)(\>", 
        b\_\(n - k\), "\<) = \>", \*"\"\<\!\(\[Sum]\+\(k = 0\)\%n\)(\>\"", \
\(a\_k\) b\_\(n - k\), "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = 0\)\%n\)(\>\"", \(a\_k\) 
          b\_\(n - k\), "\<) = \>", c\_n];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(c\_n\) = \>\"", c\_n];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<h[z] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(c\_n\)\!\(z\^n\) = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)(\>\"", c\_n, \*"\"\<)\!\(z\^n\) = \>\"", 
        h[z]];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Cauchy product of series to show that \n\n\t\t\t",
  Cell[BoxData[
      \(z\/\((z\  - \ 1)\)\^4 = \[Sum]\+\(n = 0\)\%\[Infinity]\(\( 
                  n\ \((1 + n)\)\ \((2 + n)\)\)\/6\) z\^n\)]],
  "   for   ",
  Cell[BoxData[
      \(z\ \[Epsilon]\ \(D\_1\) \((0)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution for Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Use the following facts ",
  Cell[BoxData[
      \(z\/\((z\  - \ 1)\)\^2 = \[Sum]\+\(n = 0\)\%\[Infinity] 
            n\ z\^n\ \ \ for\ \ z\ \[Epsilon]\ \(D\_1\) \((0)\)\)]],
  " and ",
  Cell[BoxData[
      \(1\/\((z\  - \ 1)\)\^2 = \[Sum]\+\(n = 0\)\%\[Infinity]\((n + 
                1)\)\ z\^n\ \ \ for\ \ z\ \[Epsilon]\ \(D\_1\) \((0)\)\)]],
  ". \nEnter the coefficients ",
  Cell[BoxData[
      \(a\_n = \(n\ \ \ and\ \ \ b\_n = n + 1\)\)]],
  "  and let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " carry out the computations."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Remove[a, b, c, z];\)\ \), "\n", 
    \(\(Clear[f, g, h, k, n];\)\ \), "\n", 
    \(\(a\_n_ = n;\)\ \), "\n", 
    \(\(b\_n_ = n + 1;\)\ \), "\[IndentingNewLine]", 
    \(\(c\_n_ = 
        FullSimplify[\[Sum]\+\(k = 0\)\%n\( a\_k\) 
              b\_\(n - k\)];\)\ \), "\n", 
    \(\(f[z_] = 
        FullSimplify[\[Sum]\+\(n = 0\)\%\[Infinity]\( a\_n\) 
              z\^n];\)\ \), "\n", 
    \(\(g[z_] = 
        FullSimplify[\[Sum]\+\(n = 0\)\%\[Infinity]\( b\_n\) 
              z\^n];\)\ \), "\n", 
    \(\(h[z_] = 
        FullSimplify[\[Sum]\+\(n = 0\)\%\[Infinity]\( c\_n\) 
              z\^n];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(a\_n\) = \>\"", a\_n];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(b\_n\) = \>\"", b\_n];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<f[z] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\!\(z\^n\) = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)(\>\"", a\_k, \*"\"\<)\!\(z\^n\) = \>\"", 
        f[z]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<g[z] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(b\_n\)\!\(z\^n\) = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)(\>\"", b\_\(n - k\), \*"\"\<)\!\(z\^n\) = \>\"", 
        g[z]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(c\_n\) = \!\(\[Sum]\+\(k = 0\)\%n\)\!\(a\_k\)\!\(b\_\
\(n - k\)\)\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(c\_n\) = \!\(\[Sum]\+\(k = 0\)\%n\)(\>\"", 
        a\_k, "\<)(\>", 
        b\_\(n - k\), "\<) = \>", \*"\"\<\!\(\[Sum]\+\(k = 0\)\%n\)(\>\"", \
\(a\_k\) b\_\(n - k\), "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(k = 0\)\%n\)(\>\"", \(a\_k\) 
          b\_\(n - k\), "\<) = \>", c\_n];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(c\_n\) = \>\"", c\_n];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<h[z] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(c\_n\)\!\(z\^n\) = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)(\>\"", c\_n, \*"\"\<)\!\(z\^n\) = \>\"", 
        h[z]];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(z\/\((1\  - \ z)\)\^2\  = \ \[Sum]\+\(n = 1\)\%\[Infinity]\ 
          n\ z\^n\)]],
  "   for   ",
  Cell[BoxData[
      \(z\ \[Epsilon]\ \(D\_1\) \((0)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Solution.  Use the result of Example 7.6 and ",
  StyleBox["(7-16)",
    FontColor->RGBColor[0, 0, 1]],
  " and obtain \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(z\/\((1\  - \ z)\)\^2\  = \ \ \(z - 1\  + \ 1\)\/\((1\  - \ \
z)\)\^2\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(1\/\((1\  - \ z)\)\^2\ \
\  + \ \ \(-1\)\/\((1\  - \ z)\)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\((n + 1)\)\ z\^n\ \ \  - \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\ 
            z\^n\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\ n\ z\^n\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\ n\ z\^n\)\)\)}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution for Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "We could let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " calculate the sum of the proposed series."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\) n \!\(z\^n\)  =  \>\
\"", \[Sum]\+\(n = 1\)\%\[Infinity]\ n\ z\^n\ ];\)\)], "Input"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Taylor Series",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/TaylorSeriesBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Analytic Continuation",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/AnalyticContinuationBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{919, 615},
WindowMargins->{{28, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[6533, 206, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[8908, 289, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[11936, 390, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[136308, 2748, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[148284, 3092, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 160470, 3442}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 124, 2, 33, "Text"],
Cell[2229, 66, 928, 23, 71, "Text"],
Cell[3160, 91, 1424, 45, 161, "Text",
  Evaluatable->False],
Cell[4587, 138, 103, 3, 33, "Text"],
Cell[4693, 143, 1334, 39, 117, "Text"],

Cell[CellGroupData[{
Cell[6052, 186, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[6200, 192, 330, 12, 33, "Text",
  Evaluatable->False],
Cell[6533, 206, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[6893, 218, 79, 2, 30, "Text"],
Cell[6975, 222, 1583, 51, 133, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[8583, 277, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[8731, 283, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[8908, 289, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[9268, 301, 718, 12, 110, "Text"],
Cell[9989, 315, 1595, 59, 138, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[11609, 378, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[11757, 384, 176, 4, 33, "Text",
  Evaluatable->False],
Cell[11936, 390, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[12296, 402, 440, 15, 35, "Text",
  Evaluatable->False],
Cell[12739, 419, 1582, 47, 145, "Text"],

Cell[CellGroupData[{
Cell[14346, 470, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[14509, 476, 219, 7, 38, "Text",
  Evaluatable->False],
Cell[14731, 485, 613, 12, 226, "Input"],
Cell[15347, 499, 118, 2, 33, "Text",
  Evaluatable->False],
Cell[15468, 503, 543, 12, 199, "Input"],
Cell[16014, 517, 435, 14, 57, "Text"],
Cell[16452, 533, 1335, 24, 357, "Input"]
}, Closed]],
Cell[17802, 560, 611, 22, 72, "Text",
  Evaluatable->False],
Cell[18416, 584, 339, 10, 52, "Text"],
Cell[18758, 596, 90267, 1483, 380, 90153, 1479, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[109028, 2081, 9339, 156, 37, 9226, 152, "GraphicsData", "Bitmap", "Text",
  
  Evaluatable->False],
Cell[118370, 2239, 1029, 33, 35, "Text"],
Cell[119402, 2274, 1582, 51, 319, "Text"],

Cell[CellGroupData[{
Cell[121009, 2329, 169, 4, 33, "Text",
  Evaluatable->False],
Cell[121181, 2335, 1322, 22, 297, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[122540, 2362, 172, 4, 30, "Text",
  Evaluatable->False],
Cell[122715, 2368, 464, 16, 77, "Text"],
Cell[123182, 2386, 606, 12, 224, "Input"],
Cell[123791, 2400, 138, 4, 33, "Text",
  Evaluatable->False],
Cell[123932, 2406, 515, 11, 199, "Input"],
Cell[124450, 2419, 446, 14, 55, "Text"],
Cell[124899, 2435, 1304, 23, 355, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[126240, 2463, 169, 4, 30, "Text",
  Evaluatable->False],
Cell[126412, 2469, 1322, 22, 297, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[127771, 2496, 172, 4, 30, "Text",
  Evaluatable->False],
Cell[127946, 2502, 532, 19, 79, "Text",
  Evaluatable->False],
Cell[128481, 2523, 606, 12, 224, "Input"],
Cell[129090, 2537, 138, 4, 33, "Text",
  Evaluatable->False],
Cell[129231, 2543, 610, 13, 199, "Input"],
Cell[129844, 2558, 446, 14, 56, "Text"],
Cell[130293, 2574, 1347, 24, 355, "Input"],
Cell[131643, 2600, 323, 10, 37, "Text"]
}, Closed]],
Cell[131981, 2613, 2242, 70, 198, "Text"],
Cell[134226, 2685, 680, 15, 71, "Text"],
Cell[134909, 2702, 1049, 30, 109, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[135983, 2736, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[136131, 2742, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[136308, 2748, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[136668, 2760, 266, 10, 30, "Text",
  Evaluatable->False],
Cell[136937, 2772, 1733, 40, 292, "Text"],

Cell[CellGroupData[{
Cell[138695, 2816, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[138858, 2822, 311, 11, 36, "Text",
  Evaluatable->False],
Cell[139172, 2835, 375, 7, 97, "Input"],
Cell[139550, 2844, 198, 7, 33, "Text",
  Evaluatable->False],
Cell[139751, 2853, 608, 11, 114, "Input"],
Cell[140362, 2866, 258, 7, 71, "Text",
  Evaluatable->False],
Cell[140623, 2875, 594, 12, 210, "Input"],
Cell[141220, 2889, 330, 14, 33, "Text"],
Cell[141553, 2905, 764, 14, 193, "Input"],
Cell[142320, 2921, 138, 4, 33, "Text",
  Evaluatable->False],
Cell[142461, 2927, 1053, 19, 260, "Input"],
Cell[143517, 2948, 412, 14, 55, "Text"],
Cell[143932, 2964, 1363, 25, 322, "Input"]
}, Closed]],
Cell[145310, 2992, 202, 4, 49, "Text"],
Cell[145515, 2998, 2419, 78, 337, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[147959, 3080, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[148107, 3086, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[148284, 3092, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[148644, 3104, 432, 14, 73, "Text",
  Evaluatable->False],
Cell[149079, 3120, 1164, 29, 194, "Text"],

Cell[CellGroupData[{
Cell[150268, 3153, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[150431, 3159, 471, 14, 55, "Text",
  Evaluatable->False],
Cell[150905, 3175, 2044, 43, 660, "Input"]
}, Closed]],
Cell[152964, 3221, 461, 14, 73, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[153450, 3239, 176, 4, 33, "Text",
  Evaluatable->False],
Cell[153629, 3245, 631, 18, 57, "Text",
  Evaluatable->False],
Cell[154263, 3265, 2036, 43, 660, "Input"]
}, Closed]],
Cell[156314, 3311, 377, 14, 35, "Text",
  Evaluatable->False],
Cell[156694, 3327, 1064, 24, 236, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[157783, 3355, 176, 4, 33, "Text",
  Evaluatable->False],
Cell[157962, 3361, 193, 7, 33, "Text",
  Evaluatable->False],
Cell[158158, 3370, 156, 2, 49, "Input"]
}, Closed]],
Cell[158329, 3375, 290, 7, 30, "Text"],
Cell[158622, 3384, 311, 10, 33, "Text"],
Cell[158936, 3396, 334, 11, 33, "Text"],
Cell[159273, 3409, 257, 5, 33, "Text"],
Cell[159533, 3416, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

