(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    102535,       2919]*)
(*NotebookOutlinePosition[    103695,       2960]*)
(*  CellTagsIndexPosition[    103618,       2954]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["7.3  Laurent Series Representations",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tSuppose ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is not analytic in  ",
  Cell[BoxData[
      \(\(D\_R\) \((\[Alpha])\)\)]],
  ",  but is analytic in  ",
  Cell[BoxData[
      \(\(D\_R\%*\) \((\[Alpha])\) = {z : \ \ \(\(0\)\(\ \)\(<\)\)\  | 
              z - \[Alpha] | \ \(\(<\)\(\ \)\(R\)\)}\)]],
  ".   For example, the function  ",
  Cell[BoxData[
      \(f \((z)\) = \(1\/z\^3\) \[ExponentialE]\^z\)]],
  "  is not analytic when  ",
  Cell[BoxData[
      \(z = \ 0\)]],
  "  but is analytic for ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(\ \)\(0\)\)\)\)]],
  ".  Clearly, this function does not have a ",
  StyleBox[ButtonBox["Maclaurin series",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/MaclaurinSeries.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " representation.  If we use the ",
  StyleBox[ButtonBox["Maclaurin",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Maclaurin.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " series for  ",
  Cell[BoxData[
      \(g \((z)\) = \[ExponentialE]\^z\)]],
  ",  however, and formally divide each term in that series by  ",
  Cell[BoxData[
      \(z\^3\)]],
  ", we obtain the representation  \n\n\t",
  Cell[BoxData[
      RowBox[{\(f \((z)\)\), "  ", "=", "  ", 
        RowBox[{\(\(1\/z\^3\) \[ExponentialE]\^z\), "  ", "=", "  ", 
          RowBox[{
            RowBox[{
              
              InterpretationBox[\(1\/z\^3 + 1\/z\^2 + 1\/\(\(2!\)\ z\) + 
                  1\/\(3!\) + z\/\(4!\) + z\^2\/\(5!\) + z\^3\/\(6!\)\),
                SeriesData[ z, 0, {1, 1, 
                  Rational[ 1, 2], 
                  Rational[ 1, 6], 
                  Rational[ 1, 24], 
                  Rational[ 1, 120], 
                  Rational[ 1, 720], 
                  Rational[ 1, 5040], 
                  Rational[ 1, 40320], 
                  Rational[ 1, 362880]}, -3, 7, 1]], "+"}], "..."}]}]}]]],
  "  \n\nthat is valid for all ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "  such that  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(\ \)\(0\)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find the series for ",
  Cell[BoxData[
      \(f \((z)\) = \[ExponentialE]\^z\/z\^3\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution for Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \[ExponentialE]\^z\/z\^3\)]],
  " and find the first few terms of the series in the punctured plane  ",
  Cell[BoxData[
      \(0 < z\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(z = 0; \ Remove[z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, L, S, S9, S11, S12, S21, S22, S\[Infinity]];\)\ \), "\n", 
    \(\(f[z_]\  = \ \[ExponentialE]\^z\/z\^3;\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        Normal[Series[\[ExponentialE]\^z, {z, 0, 9}]];\)\ \), "\n", 
    \(\(L[z_]\  = \ Normal[Series[f[z], {z, 0, 6}]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<S[z] = (\>", S[z], "\< + ... )/(\>", 
        z\^3, "\<)\>"];\)\ \), "\n", 
    \(\(Print["\<L[z] = \>", 
        L[z], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The latter is a series is valid for 0 < |z|.  Sum up infinitely many terms to \
verify that we have things right.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(S9[z_]\  = \ \[Sum]\+\(n = 0\)\%9 z\^\(n - 3\)\/\(n!\);\)\ \), "\n", 
    \(\(S\[Infinity][
          z_]\  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity] z\^\(n - 3\)\/\(n!\);\)\ \
\), "\n", 
    \(\(Print[\*"\"\<\!\(S\_9\)[z] = \>\"", 
        S9[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_\[Infinity]\)[z] = \!\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\)\!\(z\^\(n - 3\)\/\(n!\)\) =  \>\"", 
        S\[Infinity][z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the series is \"converging\" for real numbers."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], S9[x]}, {x, 0.1, 8}, PlotRange \[Rule] {{0, 8}, {0, 10}}, 
        Ticks \[Rule] {Range[0, 8, 1], Range[0, 10, 1]}, 
        PlotStyle \[Rule] {Blue, Red}, 
        AxesLabel \[Rule] {"\<x\>", "\<s\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<s = \>", 
        f[x], \*"\"\<  and  s = \!\(S\_9\)[x]\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(S\_9\)[x] = \>\"", 
        S9[x]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the complex series is \"converging\" in the \
complex plane.\nBut, we need to stay away from  z=0.  For convenience we use \
the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z - 1\)\(|\)\(\ \)\(\(<\)\(\ \)\(0.999\)\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(F[z_] = f[z + 1];\)\ \), "\n", 
    \(\(G[z_] = S9[z + 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        G\ , {0, 0.999, 
          0.1665}, {\(-\[Pi]\), \ \[Pi], \ \[Pi]\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-5\), 5}, {\(-5\), 5}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-5\), 5, 1], 
            Range[\(-5\), 5, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<w = \!\(S\_9\)[1+z] =  \>\"", 
        S9[1 + z], "\<,  where |z| < 0.999\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(PolarMap[
        F, {0, 0.999, 
          0.1665}, {\(-\[Pi]\), \ \[Pi], \ \[Pi]\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-5\), 5}, {\(-5\), 5}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-5\), 5, 1], 
            Range[\(-5\), 5, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = f[1+z] = \>", 
        f[1 + z], "\<,  where |z| < 0.999\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        S9\ , {0.2, 2.2, 0.1}, {\(-1\), \ 1, \ 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-5\), 5}, {\(-5\), 
              5}}, AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-5\), 5, 1], 
            Range[\(-5\), 5, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<w = \!\(S\_9\)[z] =  \>\"", 
        S9[z], "\<,  where 0.2 \[LessEqual] x \[LessEqual] 2.2, -1 \
\[LessEqual] y \[LessEqual] 1\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        f, {0.2, 2.2, 0.1}, {\(-1\), \ 1, \ 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-5\), 5}, {\(-5\), 
              5}}, AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-5\), 5, 1], 
            Range[\(-5\), 5, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = f[z] = \>", 
        f[z], "\<,  where 0.2 \[LessEqual] x \[LessEqual] 2.2, -1 \
\[LessEqual] y \[LessEqual] 1\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tThis example raises the question as to whether it might be possible to \
generalize the ",
  StyleBox[ButtonBox["Taylor",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Taylor.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " series method to functions analytic in an annulus  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(A \((\[Alpha], r, 
            R)\) = {z : \ \(\(r\)\(\ \)\(\[LessEqual]\)\) \
\[VerticalSeparator] 
            z - \[Alpha] \[VerticalSeparator] \(\(\[LessEqual]\)\(\ \
\)\(R\)\)}\)\)\)]],
  ".   \n\nPerhaps we can represent these functions with a series that \
employs negative powers of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " in some way as we did with ",
  Cell[BoxData[
      \(f \((z)\) = \(1\/z\^3\) \[ExponentialE]\^z\)]],
  ".  As you will see shortly, we can indeed.  We begin by defining a series \
that allows for negative powers of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Definition 7.3 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Laurent Series",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LaurentSeries.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(c\_n\)]],
  "  be a complex number for  ",
  Cell[BoxData[
      \(n = 
        0, \(\[PlusMinus]1\), \(\[PlusMinus]2\), \(\[PlusMinus]3\),  ... \
\)]],
  ".  The doubly infinite series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity]\( 
              c\_n\) \((z - \[Alpha])\)\^n\)]],
  ",  called a ",
  StyleBox[ButtonBox["Laurent",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Laurent_\
Pierre.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " series, is defined by \n\n",
  StyleBox["(7-21)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity]\( 
                c\_n\) \((z - \[Alpha])\)\^n\ \  = \ \ \[Sum]\+\(n = 1\)\%\
\[Infinity]\( 
                  c\_\(-n\)\) \((z - \[Alpha])\)\^\(-n\)\  + \ \[Sum]\+\(n = \
0\)\%\[Infinity]\( c\_n\) \((z - \[Alpha])\)\^n\)]],
  ",  \n\nprovided the series on the right-hand side of this equation \
converge."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Remark 7.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Recall that  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\( c\_n\) \((z - \[Alpha])\)\^n\)]],
  "  is a simplified expression for the sum  ",
  Cell[BoxData[
      \(c\_n0\  + \ \[Sum]\+\(n = 1\)\%\[Infinity]\( 
                c\_n\) \((z - \[Alpha])\)\^n\)]],
  ".  At times it will be convenient to write  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity]\( 
              c\_n\) \((z - \[Alpha])\)\^n\)]],
  "  as  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity]\( 
                c\_n\) \((z - \[Alpha])\)\^n\ \  = \ \ \[Sum]\+\(n = \(-\
\[Infinity]\)\)\%\(-1\)\(c\_n\) \((z - \[Alpha])\)\^n\  + \ \[Sum]\+\(n = 0\)\
\%\[Infinity]\( c\_n\) \((z - \[Alpha])\)\^n\)]],
  ", \n\nrather than using the expression given in Equation ",
  StyleBox["(7-21)",
    FontColor->RGBColor[0, 0, 1]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 7.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Given  ",
  Cell[BoxData[
      \(0\  \[LessEqual] r < \ R\)]],
  ",  we define the annulus centered at  ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  "  with radii ",
  StyleBox["r",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["R",
    FontFamily->"Courier New"],
  " by  \n\n\t\t\t",
  Cell[BoxData[
      \(A \((\[Alpha], r, 
            R)\)\  = \ {z : \ \(\(r\)\(\ \)\(<\)\) \[VerticalSeparator] \(z - \
\[Alpha] \[VerticalSeparator] \(\(<\)\(\ \)\(R\)\)\)}\)]],
  ".  \n\nThe closed annulus centered at  with radii ",
  StyleBox["r",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["R",
    FontFamily->"Courier New"],
  " is denoted by  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(\(\ \)\(A\)\)\&_\) \((\[Alpha], r, 
            R)\) = {z : \ \(\(r\)\(\ \)\(\[LessEqual]\)\) \
\[VerticalSeparator] 
            z - \[Alpha] \[VerticalSeparator] \(\(\[LessEqual]\)\(\ \
\)\(R\)\)}\)]],
  ". \n\t\t\nFigure 7.3 illustrates these terms."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 7.3",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/laurentseries/\
LaurentSeriesFigures/mat0703.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The closed annulus ",
  Cell[BoxData[
      \(\(\(\(\ \)\(A\)\)\&_\) \((\[Alpha], r, R)\)\)]],
  ". The shaded portion is the open annulus ",
  Cell[BoxData[
      \(\(\(\ \)\(A \((\[Alpha], r, R)\)\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 7.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "Suppose that the Laurent series",
  "  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity]\( 
              c\_n\) \((z - \[Alpha])\)\^n\)]],
  "  converges on an annulus  ",
  Cell[BoxData[
      \(A \((\[Alpha], r, 
            R)\) = {z : \ \(\(r\)\(\ \)\(<\)\) \[VerticalSeparator] \(z - \
\[Alpha] \[VerticalSeparator] \(\(<\)\(\ \)\(R\)\)\)}\)]],
  ".  Then the series converges uniformly on any closed subannulus  ",
  Cell[BoxData[
      \(\(\(\(\ \)\(A\)\)\&_\) \((\[Alpha], s, 
            t)\) = {z : \ \(\(s\)\(\ \)\(\[LessEqual]\)\) \
\[VerticalSeparator] \(z - \[Alpha] \[VerticalSeparator] \(\(\[LessEqual]\)\(\
\ \)\(t\)\)\)}\)]],
  " where  ",
  Cell[BoxData[
      \(r\  < s < t < \ R\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.7 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  "\tThe main result of this section specifies how functions analytic in an \
annulus can be expanded in a ",
  StyleBox[ButtonBox["Laurent",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Laurent_\
Pierre.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " series.  In it, we will use symbols of the form  ",
  Cell[BoxData[
      \(\(C\_\[Rho]\%+\) \((\[Alpha])\)\)]],
  ",  which - we remind you - designate the positively oriented circle with \
radius  ",
  Cell[BoxData[
      \(\[Rho]\)]],
  "  and center  ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  ".  That is,  ",
  Cell[BoxData[
      \(\(C\_\[Rho]\%+\) \((\[Alpha])\) = {\(\(z\)\(:\)\)\  \
\[VerticalSeparator] 
            z - \[Alpha] \[VerticalSeparator] \(\(<\)\(\ \)\(\[Rho]\)\)}\)]],
  ",  oriented counterclockwise."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Theorem 7.8  (Laurent's Theorem).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose  ",
  Cell[BoxData[
      \(0 \[LessEqual] r < R\)]],
  ",  and that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic in the annulus ",
  Cell[BoxData[
      \(A = \(A \((\[Alpha], r, 
              R)\) = {z : \ \(\(r\)\(\ \)\(<\)\) \[VerticalSeparator] \(z - \
\[Alpha] \[VerticalSeparator] \(\(<\)\(\ \)\(R\)\)\)}\)\)]],
  "  shown in Figure 7.3.  If  ",
  Cell[BoxData[
      \(\[Rho]\)]],
  "  is any number such that ",
  Cell[BoxData[
      \(r\  < \[Rho] < \ R\)]],
  ", then for all ",
  Cell[BoxData[
      \(z\_0\ \[Epsilon]\ A \((\[Alpha], r, R)\)\)]],
  " the function value ",
  Cell[BoxData[
      \(f \((z\_0)\)\)]],
  " has the Laurent series representation \n\n",
  StyleBox["(7-22)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f \((z\_0)\)\ \  = \ \ \(\[Sum]\+\(n = \
\(-\[Infinity]\)\)\%\[Infinity]\( 
                  c\_n\) \((z\_0 - \[Alpha])\)\^n\ \  = \ \ \[Sum]\+\(n = 1\)\
\%\[Infinity]\( 
                    c\_\(-n\)\) \((z\_0 - \[Alpha])\)\^\(-n\)\  + \ \
\[Sum]\+\(n = 0\)\%\[Infinity]\( c\_n\) \((z\_0 - \[Alpha])\)\^n\)\)]],
  ",  \n\nwhere for ",
  Cell[BoxData[
      RowBox[{\(n = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  ", the coefficients ",
  Cell[BoxData[
      \(c\_\(-n\)\ \ and\ \ c\_n\)]],
  " are given by \n\n",
  StyleBox["(7-23)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(c\_\(-n\) = \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \(\[Integral]\_\(\(C\_\
\[Rho]\^+\) \((\[Alpha])\)\)\(\(f \((z)\)\)\/\((z\  - \ \[Alpha])\)\^\(\(-n\) \
+ 1\)\) \[DifferentialD]z\)\)]],
  "    and    ",
  Cell[BoxData[
      \(c\_n = \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \
\(\[Integral]\_\(\(C\_\[Rho]\^+\) \((\[Alpha])\)\)\(\(f \((z)\)\)\/\((z\  - \ \
\[Alpha])\)\^\(n + 1\)\) \[DifferentialD]z\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.8 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  What happens to the Laurent series if ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic in the disk ",
  Cell[BoxData[
      \(\(D\_R\) \((\[Alpha])\)\)]],
  "?  If we look at equation ",
  StyleBox["(7-23)",
    FontColor->RGBColor[0, 0, 1]],
  ", we see that the coefficient ",
  Cell[BoxData[
      \(c\_n\)]],
  " for the positive power ",
  Cell[BoxData[
      \(\((z\_0 - \[Alpha])\)\^n\)]],
  " equals ",
  Cell[BoxData[
      \(\(\(f\^\((n)\)\) \((z\_0)\)\)\/\(n!\)\)]],
  " by using Cauchy's integral formula for derivatives.  Hence, the series in \
equation ",
  StyleBox["(7-22)",
    FontColor->RGBColor[0, 0, 1]],
  " involving the positive powers of ",
  Cell[BoxData[
      \(\((z\_0 - \[Alpha])\)\)]],
  " is actually the \nTaylor series for ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  ".  The ",
  StyleBox[ButtonBox["Cauchy",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  StyleBox["-",
    FontSize->14,
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[ButtonBox["Goursat",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Goursat.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " theorem shows us that the coefficients for the negative powers of ",
  Cell[BoxData[
      \(\((z\_0 - \[Alpha])\)\)]],
  " equal zero.  In this case, therefore, there are no negative powers \
involved, and the Laurent series reduces to the Taylor series."
}], "Text"],

Cell["\<\
\tTheorem 7.9 delineates two important aspects of the Laurent series.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 7.9 (Uniqueness and differentiation of Laurent Series).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose that  ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  "  is analytic in the annulus  ",
  Cell[BoxData[
      \(A \((\[Alpha], r, R)\)\)]],
  ",  and has the Laurent series representation  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\  = \ \[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity]\( 
                c\_n\) \((z - \[Alpha])\)\^n\)]],
  "  for all  ",
  Cell[BoxData[
      \(z\ \[Epsilon]\ A \((\[Alpha], r, R)\)\)]],
  ".  \n\n",
  StyleBox["(i) ",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\tIf  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity]\( 
                b\_n\) \((z - \[Alpha])\)\^n\)]],
  "  for all  ",
  Cell[BoxData[
      \(z\ \[Epsilon]\ A \((\[Alpha], r, R)\)\)]],
  ",  then ",
  Cell[BoxData[
      \(b\_n = c\_n\)]],
  " for all  ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ".  \n\t\t\t(In other words, the Laurent series for ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  "  in a given annulus is unique.)\n\n",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\t\t\t",
    FontWeight->"Bold"],
  "For all ",
  Cell[BoxData[
      \(z\ \[Epsilon]\ A \((\[Alpha], r, R)\)\)]],
  ", the derivatives for ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  "  may be obtained by termwise differentiation of its Laurent series. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.9 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  "\tThe uniqueness of the Laurent series is an important property because \
the coefficients in the Laurent expansion of a function are seldom found by \
using  Equation ",
  StyleBox["(7-23)",
    FontColor->RGBColor[0, 0, 1]],
  ".  ",
  "The following examples illustrate some methods for finding Laurent series \
coefficients. "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 7.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find three different Laurent series representations for the function  ",
  Cell[BoxData[
      \(f \((z)\) = 3\/\(2\  + \ z\  - \ z\^2\)\)],
    AspectRatioFixed->True],
  "  involving powers of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214133 0.190514 0.15 0.05 [
[.02362 .1375 -6 -9 ]
[.02362 .1375 6 0 ]
[.40465 .1375 -3 -9 ]
[.40465 .1375 3 0 ]
[.59516 .1375 -3 -9 ]
[.59516 .1375 3 0 ]
[.78568 .1375 -3 -9 ]
[.78568 .1375 3 0 ]
[.97619 .1375 -3 -9 ]
[.97619 .1375 3 0 ]
[.20163 0 -12 -4.5 ]
[.20163 0 0 4.5 ]
[.20163 .05 -12 -4.5 ]
[.20163 .05 0 4.5 ]
[.20163 .1 -12 -4.5 ]
[.20163 .1 0 4.5 ]
[.20163 .2 -6 -4.5 ]
[.20163 .2 0 4.5 ]
[.20163 .25 -6 -4.5 ]
[.20163 .25 0 4.5 ]
[.20163 .3 -6 -4.5 ]
[.20163 .3 0 4.5 ]
[.20163 .35 -6 -4.5 ]
[.20163 .35 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .35 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02362 .15 m
.02362 .15625 L
s
[(-1)] .02362 .1375 0 1 Mshowa
.40465 .15 m
.40465 .15625 L
s
[(1)] .40465 .1375 0 1 Mshowa
.59516 .15 m
.59516 .15625 L
s
[(2)] .59516 .1375 0 1 Mshowa
.78568 .15 m
.78568 .15625 L
s
[(3)] .78568 .1375 0 1 Mshowa
.97619 .15 m
.97619 .15625 L
s
[(4)] .97619 .1375 0 1 Mshowa
0 .15 m
1 .15 L
s
.21413 0 m
.22038 0 L
s
[(-3)] .20163 0 1 0 Mshowa
.21413 .05 m
.22038 .05 L
s
[(-2)] .20163 .05 1 0 Mshowa
.21413 .1 m
.22038 .1 L
s
[(-1)] .20163 .1 1 0 Mshowa
.21413 .2 m
.22038 .2 L
s
[(1)] .20163 .2 1 0 Mshowa
.21413 .25 m
.22038 .25 L
s
[(2)] .20163 .25 1 0 Mshowa
.21413 .3 m
.22038 .3 L
s
[(3)] .20163 .3 1 0 Mshowa
.21413 .35 m
.22038 .35 L
s
[(4)] .20163 .35 1 0 Mshowa
.21413 0 m
.21413 .35 L
s
0 0 m
1 0 L
1 .35 L
0 .35 L
closepath
clip
newpath
1 0 0 r
.005 w
.07638 .35 m
.08001 .33742 L
.08743 .31805 L
.09505 .3024 L
.10335 .28884 L
.1111 .27857 L
.11965 .26923 L
.13534 .25598 L
.15141 .24601 L
.16688 .23874 L
.18332 .23278 L
.19915 .22832 L
.21439 .22495 L
.2306 .22215 L
.2462 .22009 L
.25416 .21925 L
.26279 .21849 L
.2704 .21793 L
.27877 .21744 L
.28671 .21709 L
.29106 .21694 L
.29512 .21683 L
.29711 .21679 L
.29928 .21675 L
.3012 .21672 L
.30323 .2167 L
.30427 .21669 L
.30525 .21668 L
.30613 .21668 L
.30658 .21667 L
.30708 .21667 L
.30751 .21667 L
.30798 .21667 L
.30847 .21667 L
.30893 .21667 L
.30939 .21667 L
.30983 .21667 L
.31022 .21667 L
.31064 .21667 L
.31113 .21667 L
.31158 .21667 L
.31258 .21667 L
.31347 .21668 L
.31441 .21669 L
.31639 .21671 L
.31856 .21674 L
.32291 .21682 L
.32696 .21692 L
.33515 .21721 L
.34259 .21758 L
Mistroke
.35027 .21806 L
.35859 .2187 L
.37496 .22037 L
.39073 .22254 L
.40446 .22496 L
Mfstroke
0 0 1 r
.05409 .35 m
.05609 .34599 L
.07191 .31986 L
.08712 .29908 L
.10331 .28098 L
.11889 .26688 L
.13546 .25488 L
.15142 .24572 L
.16677 .23872 L
.1831 .23284 L
.19883 .2284 L
.21395 .22504 L
.23006 .22223 L
.24555 .22017 L
.25343 .21934 L
.26203 .21859 L
.27026 .21802 L
.2779 .21764 L
.28212 .21749 L
.2842 .21743 L
.2861 .21738 L
.28784 .21735 L
.28967 .21733 L
.29063 .21732 L
.29152 .21731 L
.29203 .21731 L
.29249 .21731 L
.29275 .21731 L
.29303 .2173 L
.29354 .2173 L
.29403 .2173 L
.29447 .2173 L
.29496 .21731 L
.29548 .21731 L
.29593 .21731 L
.29635 .21731 L
.2973 .21732 L
.29835 .21733 L
.2993 .21735 L
.30144 .21739 L
.30352 .21745 L
.30576 .21752 L
.30984 .2177 L
.31362 .21792 L
.31778 .21822 L
.32619 .21904 L
.33397 .22007 L
.34232 .22152 L
.35021 .22325 L
.35881 .22558 L
Mistroke
.37471 .23131 L
.39097 .23944 L
.40446 .2483 L
Mfstroke
1 0 0 r
.40484 .22504 m
.41255 .22666 L
.42096 .22866 L
.42886 .23079 L
.43646 .2331 L
.44455 .23588 L
.45233 .23891 L
.46061 .24259 L
.46858 .24666 L
.47625 .25115 L
.48441 .25668 L
.49226 .2629 L
.49982 .26991 L
.50786 .27878 L
.5156 .28909 L
.52383 .30258 L
.53176 .31898 L
.53938 .33924 L
s
.53938 .33924 m
.54241 .35 L
s
0 1 0 r
.40484 .24975 m
.40859 .24632 L
.41255 .24357 L
.41657 .24152 L
.41884 .24064 L
.42096 .23998 L
.42306 .23946 L
.42504 .23907 L
.42682 .23882 L
.42782 .2387 L
.42875 .23862 L
.42968 .23855 L
.43019 .23852 L
.43068 .2385 L
.43113 .23848 L
.43137 .23848 L
.43162 .23847 L
.43186 .23847 L
.43207 .23846 L
.43228 .23846 L
.43249 .23846 L
.43272 .23846 L
.43299 .23846 L
.43312 .23846 L
.43326 .23846 L
.43352 .23846 L
.43377 .23846 L
.43401 .23847 L
.43446 .23848 L
.435 .2385 L
.43549 .23852 L
.4366 .23858 L
.43753 .23864 L
.43853 .23873 L
.44033 .23892 L
.44444 .23953 L
.44844 .24033 L
.45266 .24137 L
.46026 .24371 L
.46836 .24683 L
.47616 .2504 L
.48444 .25481 L
.49242 .2597 L
.5001 .26503 L
.50827 .27144 L
.51614 .27839 L
.5237 .28589 L
.53176 .29483 L
.53951 .30448 L
.54775 .316 L
Mistroke
.55568 .32847 L
.56332 .34188 L
Mfstroke
.56332 .34188 m
.56744 .35 L
s
1 0 0 r
.65298 0 m
.659 .01577 L
.66728 .03271 L
.67493 .04521 L
.69026 .06412 L
.70596 .07799 L
.72106 .08799 L
.73713 .09625 L
.7526 .10256 L
.76906 .108 L
.7849 .11231 L
.80014 .1158 L
.81636 .11895 L
.83197 .12156 L
.84857 .12396 L
.86455 .12597 L
.87994 .12767 L
.8963 .12928 L
.91206 .13066 L
.92721 .13185 L
.94334 .133 L
.95886 .13399 L
.97537 .13495 L
.97619 .135 L
s
0 1 1 r
.62076 0 m
.62765 .01298 L
.64347 .03554 L
.65869 .05249 L
.67489 .06677 L
.69048 .07775 L
.70706 .0872 L
.72302 .09463 L
.73839 .10058 L
.75473 .1059 L
.77046 .11022 L
.78559 .11378 L
.8017 .11706 L
.81721 .11979 L
.83369 .12233 L
.84957 .12447 L
.86484 .12629 L
.8811 .12801 L
.89674 .12949 L
.91337 .1309 L
.92939 .13211 L
.94481 .13317 L
.9612 .1342 L
.97619 .13505 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{546.75, 191.375},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008R0000_b000`400?l00000o`00003oo`3ooooo
0?ooob@0oooo003o0?ooool0oooo903oool00?l0ooooo`3ooolT0?ooo`00LP3oool200000?l0oooo
[`3oool00740oooo00@000000?ooo`3oool00000fP3oool00`00ool0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo0;l0oooo001c0?ooo`030000003oool0oooo00H0oooo1000003?0?ooo`03003oo`3o
ool0oooo00d0oooo0`3o00300?ooo`00J`3oool4000000D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`3@0?ooo`800?oo3`3oool20?l00<00oooo001a0?ooo`040000003oool0oooo
000000L0oooo00<000000?ooo`3oool0d@3oool2003oo`h0oooo0P3o00300?ooo`00LP3oool20000
00P0oooo00<000000?ooo`3oool0dP3oool00`00ool0oooo0?ooo`0=0?ooo`80o`00_`3oool007`0
oooo00<000000?ooo`3oool0dP3oool2003oo`h0oooo0P3o002o0?ooo`00O03oool00`000000oooo
0?ooo`3C0?ooo`800?oo3@3oool30?l00;h0oooo001l0?ooo`030000003oool0oooo0=@0oooo00<0
0?oo0?ooo`3oool0303oool20?l00;h0oooo001l0?ooo`030000003oool0oooo0=@0oooo0P00ool=
0?ooo`80o`00_P3oool007`0oooo00<000000?ooo`3oool0e@3oool2003oo`d0oooo00<0o`000?oo
o`3oool0_03oool007`0oooo00<000000?ooo`3oool0eP3oool00`00ool0oooo0?ooo`0;0?ooo`80
o`00_@3oool007`0oooo00<000000?ooo`3oool0eP3oool2003oo`d0oooo00<0o`000?ooo`3oool0
^`3oool007`0oooo00<000000?ooo`3oool0e`3oool2003oo``0oooo0P3o002l0?ooo`00O03oool0
0`000000oooo0?ooo`3H0?ooo`03003oo`3oool0oooo00/0oooo00<0o`000?ooo`3oool0^P3oool0
07`0oooo00<000000?ooo`3oool0f03oool2003oo``0oooo00<0o`000?ooo`3oool0^P3oool007`0
oooo00<000000?ooo`3oool0f@3oool2003oo`/0oooo0P3o002k0?ooo`00O03oool00`000000oooo
0?ooo`3J0?ooo`03003oo`3oool0oooo00X0oooo00<0o`000?ooo`3oool0^@3oool007`0oooo00<0
00000?ooo`3oool0fP3oool2003oo`/0oooo0P3o002j0?ooo`00O03oool00`000000oooo0?ooo`3K
0?ooo`800?oo2`3oool00`3o0000oooo0?ooo`2h0?ooo`00O03oool00`000000oooo0?ooo`3L0?oo
o`800?oo2P3oool20?l00;T0oooo001l0?ooo`030000003oool0oooo0=`0oooo0`00ool:0?ooo`80
o`00^03oool007`0oooo00<000000?ooo`3oool0g@3oool3003oo`X0oooo00<0o`000?ooo`3oool0
]P3oool007`0oooo00<000000?ooo`3oool0gP3oool3003oo`T0oooo0P3o002g0?ooo`00O03oool0
0`000000oooo0?ooo`3O0?ooo`800?oo2P3oool20?l00;H0oooo001l0?ooo`030000003oool0oooo
0>00oooo0P00ool:0?ooo`80o`00]@3oool00740oooo100000070?ooo`030000003oool0oooo0>00
oooo0`00ool90?ooo`<0o`00]03oool00740oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`3Q0?ooo`<00?oo2@3oool20?l00;@0oooo001b0?ooo`030000003oool0oooo00L0oooo1000
003Q0?ooo`<00?oo2@3oool20?l00;<0oooo001[0?ooo`@00000103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0><0oooo0`00ool80?ooo`<0o`00/P3oool00740oooo00@000000?oo
o`3oool000001`3oool00`000000oooo0?ooo`3T0?ooo`<00?oo203oool30?l00;40oooo001b0?oo
o`800000203oool00`000000oooo0?ooo`3U0?ooo`<00?oo203oool30?l00;00oooo001l0?ooo`03
0000003oool0oooo0>H0oooo1000ool70?ooo`80o`00/03oool007`0oooo00<000000?ooo`3oool0
i`3oool4003oo`L0oooo0P3o002_0?ooo`00O03oool00`000000oooo0?ooo`3Y0?ooo`<00?oo1P3o
ool30?l00:h0oooo001l0?ooo`030000003oool0oooo0>X0oooo0`00ool60?ooo`<0o`00[@3oool0
07`0oooo00<000000?ooo`3oool0j`3oool3003oo`H0oooo0`3o002/0?ooo`00O03oool00`000000
oooo0?ooo`3/0?ooo`@00?oo1@3oool30?l00:/0oooo001l0?ooo`030000003oool0oooo0>d0oooo
1000ool50?ooo`@0o`00Z@3oool007`0oooo00<000000?ooo`3oool0k`3oool3003oo`D0oooo103o
002X0?ooo`00O03oool00`000000oooo0?ooo`3`0?ooo`@00?oo1@3oool30?l00:L0oooo001l0?oo
o`030000003oool0oooo0?40oooo1000ool50?ooo`<0o`00YP3oool007`0oooo00<000000?ooo`3o
ool0l`3oool4003oo`@0oooo103o002T0?ooo`00O03oool00`000000oooo0?ooo`3d0?ooo`D00?oo
0`3oool40?l00:<0oooo001l0?ooo`030000003oool0oooo0?H0oooo1000ool40?ooo`@0o`00X@3o
ool007`0oooo00<000000?ooo`3oool0n03oool4003oo`<0oooo103o002P0?ooo`00O03oool00`00
0000oooo0?ooo`3i0?ooo`D00?oo0`3oool40?l009h0oooo001l0?ooo`030000003oool0oooo0?/0
oooo1@00ool20?ooo`D0o`00W03oool007`0oooo00<000000?ooo`3oool0o@3oool5003oo`80oooo
103o002K0?ooo`00O03oool00`000000oooo0?ooo`3o0?ooo`D00?oo0P3oool40?l009T0oooo001l
0?ooo`030000003oool0oooo0?l0oooo0P3oool5003oo`030?ooo`3o0000o`000080o`00V03oool0
0740oooo1@0000060?ooo`030000003oool0oooo0?l0oooo103oool6003oo`@0o`00UP3oool007<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooo`H0oooo1P00ool50?l009<0
oooo001c0?ooo`030000003oool0oooo00H0oooo1000003o0?ooo`P0oooo1P00ool40?l00940oooo
001[0?ooo`@00000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo2`3o
ool7003oo`@0o`00SP3oool007<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o
0?ooo`h0oooo1P00ool50?l008/0oooo001b0?ooo`800000203oool00`000000oooo0?ooo`3o0?oo
oa40oooo1P00ool50?l008P0oooo001l0?ooo`030000003oool0oooo0?l0oooo4`3oool8003oo`@0
o`00Q@3oool007`0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`T00?oo0`3o00220?ooo`00O03o
ool00`000000oooo0?ooo`3o0?oooa/0oooo2000ool30?l007h0oooo001l0?ooo`030000003oool0
oooo0?l0oooo7`3oool7003oo`@0o`00NP3oool007`0oooo00<000000?ooo`3oool0o`3ooolS0?oo
o``00?ooM@3oool007`0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`d00?oo0`3o001^0?ooo`00
O03oool00`000000oooo0?ooo`3o0?ooobh0oooo00<0o`00003oo`00ool01P00ool30?l006X0oooo
001l0?ooo`030000003oool0oooo0?l0oooo<`3oool<003oofD0oooo000K0?ooo`D00000G03oool0
0`000000oooo0?ooo`1N0?ooo`D00000GP3oool4000005l0oooo0P00000@0?oooa400?oo@@3oool3
000001P0oooo000M0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo05l0oooo00@000000?ooo`3oool000005P3oool0
0`3o00000?oo003oo`0>003ooc/0oooo00<000000?ooo`3oool05`3oool001d0oooo00<000000?oo
o`3oool0G03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`0N0?ooo`030?l00000ool00?oo00h00?oo;`3oool50000
01P0oooo000E0?ooo`@00000103oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo02D0
oooo4@00oolW0?ooo`040000003oool0oooo000001T0oooo000M0?ooo`030000003oool0oooo05`0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1N0?ooo`040000003oool0oooo0000
05h0oooo00@000000?ooo`3oool00000;`3oool00`3o00000?oo003oo`0G003ooaL0oooo00<00000
0?ooo`0000006@3oool001`0oooo0P00001N0?ooo`030000003oool0oooo05l0oooo0P00001Q0?oo
o`800000H03oool2000003T0oooo6@00ool@0?ooo`8000006@3oool007`0oooo00<000000?ooo`3o
ool0o`3ooom`0?ooo`030?l00000ool00?oo01H00?oo6`3oool007`0oooo00<000000?ooo`3oool0
o`3ooomh0?ooo`030?l00000ool00?oo00l00?oo6P3oool007`0oooo00<000000?ooo`3oool0o`3o
oon90?ooo`03003oo`3oool0oooo01P0oooo001l0?ooo`030000003oool0oooo0?l0ooooY03oool0
07`0oooo00<000000?ooo`3oool0o`3ooonT0?ooo`00O03oool00`000000oooo0?ooo`3o0?oooj@0
oooo001l0?ooo`030000003oool0oooo0?l0ooooY03oool007`0oooo00<000000?ooo`3oool0o`3o
oonT0?ooo`003@3ooooo00000?l000002@00000>0?ooo`006P3oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0603oool001X0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01P0oooo000J0?ooo`030000
003oool0oooo05l0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo05l0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0H0?ooo`006P3o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0603o
ool007`0oooo00<000000?ooo`3oool0o`3ooonT0?ooo`00O03oool00`000000oooo0?ooo`3o0?oo
oj@0oooo001l0?ooo`030000003oool0oooo0?l0ooooY03oool007`0oooo00<000000?ooo`3oool0
o`3ooonT0?ooo`00O03oool00`000000oooo0?ooo`3o0?oooj@0oooo001l0?ooo`030000003oool0
oooo0?l0ooooY03oool007`0oooo00<000000?ooo`3oool0o`3ooonT0?ooo`00O03oool00`000000
oooo0?ooo`3o0?oooj@0oooo001l0?ooo`030000003oool0oooo0?l0ooooY03oool007`0oooo00<0
00000?ooo`3oool0o`3ooonT0?ooo`00O03oool00`000000oooo0?ooo`3o0?oooj@0oooo001l0?oo
o`030000003oool0oooo0?l0ooooY03oool007`0oooo00<000000?ooo`3oool0o`3ooonT0?ooo`00
O03oool00`000000oooo0?ooo`3o0?oooj@0oooo001l0?ooo`030000003oool0oooo0?l0ooooY03o
ool007`0oooo00<000000?ooo`3oool0o`3ooonT0?ooo`00O03oool00`000000oooo0?ooo`3o0?oo
oj@0oooo001l0?ooo`030000003oool0oooo0?l0ooooY03oool007`0oooo00<000000?ooo`3oool0
o`3ooonT0?ooo`00L@3oool5000000H0oooo00<000000?ooo`3oool0o`3ooonT0?ooo`00L`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooY03oool007<0oooo00<000000?oo
o`3oool01P3oool400000?l0ooooX`3oool007<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`3o0?oooj@0oooo001c0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
o`3ooonT0?ooo`00LP3oool2000000P0oooo00<000000?ooo`3oool0o`3ooonT0?ooo`00O03oool0
0`000000oooo0?ooo`3o0?oooj@0oooo001l0?ooo`030000003oool0oooo0?l0ooooY03oool007`0
oooo00<000000?ooo`3oool0o`3ooonT0?ooo`00O03oool00`000000oooo0?ooo`3o0?oooj@0oooo
001l0?ooo`030000003oool0oooo03l0oooo00<0o`000?ooo`3oool0o`3ooomR0?ooo`00O03oool0
0`000000oooo0?ooo`0J0?oooaP0003o4P3o003o0?ooof00oooo001l0?ooo`030000003oool0oooo
00h0oooo;@000?lF0?l00?l0ooooD`3oool007`0oooo00<000000?ooo`3oool01@3ooolE0000oaL0
oooo4`000?lE0?l00?l0ooooB`3oool007`0oooo4@000?l]0?ooo``0003o2P3oool@0?l00?l0oooo
@`3oool007P0oooo30000?l00`3o0000oooo0?ooo`0l0?ooo`D0003o403oool;0?l00?l0oooo@03o
ool007@0oooo20000?l00`000000oooo0?ooo`160?ooo`H0003o503oool80?l00?l0oooo?03oool0
0700oooo20000?l40?ooo`030000003oool0oooo04P0oooo20000?lD0?ooo`T0o`00o`3ooolg0?oo
o`00K03oool80000o`P0oooo00<000000?ooo`3oool0C03oool70000oaD0oooo2@3o003o0?oooc<0
oooo001Y0?ooo`L0003o303oool00`000000oooo0?ooo`1@0?ooo`D0003o603oool60?l00?l0oooo
<@3oool006L0oooo1P000?l?0?ooo`030000003oool0oooo0580oooo10000?lJ0?ooo`H0o`00o`3o
ool^0?ooo`00I03oool60000oa80oooo00<000000?ooo`3oool0E03oool40000oaX0oooo1`3o003o
0?ooob/0oooo001R0?ooo`H0003o503oool00`000000oooo0?ooo`1E0?ooo`D0003o403oool<003o
00H0o`00o`3ooolX0?ooo`00H03oool50000oaL0oooo00<000000?ooo`3oool0E`3oool50000o`X0
oooo5000o`040?l00?l0oooo9P3oool005h0oooo1@000?lI0?ooo`030000003oool0oooo05T0oooo
10000?l70?ooo`P00?l02@3oool8003o00<0o`00o`3ooolT0?ooo`00G03oool50000oa/0oooo00<0
00000?ooo`3oool0F`3oool40000o`<0oooo1@00o`0B0?ooo`L00?l00P3o003o0?ooob80oooo001J
0?ooo`D0003o4P3oool4000000L0oooo00<000000?ooo`3oool0G03oool50000o`@00?l0603oool5
003o00030?l0003oool0oooo0?l0oooo7`3oool005P0oooo1@000?lD0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0GP3oool20000o`<00?l0703oool6003o0?l0oooo7`3oool005L0
oooo10000?lG0?ooo`030000003oool0oooo00L0oooo1000001N0?ooo`<00?l07`3oool6003o0?l0
oooo7@3oool005D0oooo10000?lJ0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
H03oool00`00o`00oooo0?ooo`0Q0?ooo`030?l00000o`000?l000800?l0o`3ooolK0?ooo`00D`3o
ool50000oaT0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`250?ooo`030?l0
0000o`000?l000800?l0o`3ooolJ0?ooo`00DP3oool40000oa`0oooo0P0000080?ooo`030000003o
ool0oooo08H0oooo0P3o0004003o0?l0oooo603oool00500oooo10000?lX0?ooo`030000003oool0
oooo08P0oooo00<0o`00003o0000o`000`00o`3o0?oooaH0oooo001?0?ooo`@0003o:@3oool00`00
0000oooo0?ooo`290?ooo`80o`001000o`3o0?oooaD0oooo001>0?ooo`<0003o00<0o`000?ooo`3o
ool0:03oool00`000000oooo0?ooo`2:0?ooo`<0o`001000o`3o0?oooa<0oooo001<0?ooo`@0003o
00<0o`000?ooo`3oool0:@3oool00`000000oooo0?ooo`2<0?ooo`80o`001000o`3o0?oooa80oooo
001;0?ooo`@0003o;@3oool00`000000oooo0?ooo`2=0?ooo`<0o`001000o`3o0?oooa00oooo001:
0?ooo`<0003o00<0o`000?ooo`3oool0;03oool00`000000oooo0?ooo`2>0?ooo`<0o`001000o`3o
0?ooo`l0oooo00190?ooo`<0003o00<0o`000?ooo`3oool0;@3oool00`000000oooo0?ooo`2@0?oo
o`<0o`001000o`3o0?ooo`d0oooo00180?ooo`<0003o00<0o`000?ooo`3oool0;P3oool00`000000
oooo0?ooo`2A0?ooo`<0o`001000o`3o0?ooo``0oooo00160?ooo`@0003o00<0o`000?ooo`3oool0
;`3oool00`000000oooo0?ooo`2B0?ooo`80o`000P3oool3003o0?l0oooo2`3oool004D0oooo1000
0?l00`3o0000oooo0?ooo`0`0?ooo`030000003oool0oooo09<0oooo0P3o00020?ooo`<00?l0o`3o
ool:0?ooo`00A03oool30000o`<0o`00<P3oool00`000000oooo0?ooo`2C0?ooo`<0o`000P3oool3
003o0?l0oooo2@3oool004<0oooo0`000?l30?l003<0oooo00<000000?ooo`3oool0U03oool30?l0
0080oooo0`00o`3o0?ooo`P0oooo00120?ooo`<0003o0`3o000d0?ooo`030000003oool0oooo09D0
oooo0`3o00020?ooo`<00?l0o`3oool70?ooo`00@@3oool30000o`030?ooo`3o0000o`0003D0oooo
00<000000?ooo`3oool0UP3oool20?l000<0oooo0`00o`3o0?ooo`H0oooo00100?ooo`<0003o00<0
oooo0?l0003o0000=P3oool00`000000oooo0?ooo`2G0?ooo`80o`000`3oool3003o0?l0oooo1@3o
ool003l0oooo0`000?l0103oool0o`000?l0003o000f0?ooo`030000003oool0oooo09L0oooo0`3o
00030?ooo`<00?l0o`3oool40?ooo`00?P3oool30000o`80oooo0P3o000g0?ooo`030000003oool0
oooo09P0oooo0P3o00040?ooo`<00?l0o`3oool30?ooo`00?P3oool20000o`80oooo0P3o000h0?oo
o`030000003oool0oooo09T0oooo0P3o00040?ooo`<00?l0o`3oool20?ooo`00?@3oool20000o`<0
oooo00<0o`000?ooo`3oool0=`3oool00`000000oooo0?ooo`2J0?ooo`80o`00103oool3003o0?l0
oooo0@3oool003`0oooo0`000?l20?ooo`80o`00>@3oool00`000000oooo0?ooo`2K0?ooo`030?l0
003oool0oooo00<0oooo0`00o`3o0?ooo`00>`3oool30000o`80oooo0P3o000`0?ooo`800000203o
ool00`000000oooo0?ooo`2K0?ooo`80o`001@3oool3003o0?h0oooo000j0?ooo`<0003o0`3oool0
0`3o0000oooo0?ooo`0^0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0W03o
ool20?l000D0oooo0P00o`3n0?ooo`00>P3oool20000o`<0oooo0P3o000b0?ooo`030000003oool0
oooo00H0oooo1000002L0?ooo`80o`001@3oool2003o0?d0oooo000i0?ooo`80003o103oool00`3o
0000oooo0?ooo`0b0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0WP3oool00`3o
0000oooo0?ooo`030?ooo`<00?l0o03oool003P0oooo0P000?l40?ooo`80o`00<@3oool010000000
oooo0?ooo`0000070?ooo`030000003oool0oooo09h0oooo0P3o00050?ooo`800?l0o03oool003P0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0a0?ooo`800000203oool00`000000
oooo0?ooo`2O0?ooo`030?l0003oool0oooo00@0oooo0P00o`3k0?ooo`00=`3oool20000o`@0oooo
0P3o000m0?ooo`030000003oool0oooo09l0oooo0P3o00060?ooo`800?l0nP3oool003H0oooo0P00
0?l50?ooo`030?l0003oool0oooo03`0oooo00<000000?ooo`3oool0X03oool00`3o0000oooo0?oo
o`050?ooo`03003o003oool0oooo0?P0oooo000e0?ooo`80003o1@3oool20?l003h0oooo00<00000
0?ooo`3oool0X03oool00`3o0000oooo0?ooo`050?ooo`800?l0n@3oool003D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`0m0?ooo`030000003oool0oooo0:00oooo0P3o00070?oo
o`800?l0n03oool003@0oooo0P000?l50?ooo`80o`00?`3oool00`000000oooo0?ooo`2Q0?ooo`03
0?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool0mP3oool003<0oooo0P000?l60?ooo`030?l0
003oool0oooo03h0oooo00<000000?ooo`3oool0X@3oool20?l000L0oooo0P00o`3g0?ooo`00<`3o
ool00`000?l0oooo0?ooo`040?ooo`80o`00@03oool00`000000oooo0?ooo`2R0?ooo`80o`001`3o
ool00`00o`00oooo0?ooo`3e0?ooo`00<P3oool20000o`H0oooo0P3o00100?ooo`030000003oool0
oooo0:80oooo0P3o00070?ooo`800?l0mP3oool00340oooo0P000?l60?ooo`80o`00@@3oool00`00
0000oooo0?ooo`2R0?ooo`80o`00203oool2003o0?D0oooo000a0?ooo`030000o`3oool0oooo00D0
oooo0P3o00110?ooo`030000003oool0oooo0:80oooo0`3o00080?ooo`03003o003oool0oooo0?<0
oooo000`0?ooo`80003o1P3oool30?l00440oooo00<000000?ooo`3oool0X`3oool20?l000P0oooo
0P00o`3d0?ooo`00;`3oool20000o`L0oooo0P3o00120?ooo`030000003oool0oooo0:<0oooo0`3o
00080?ooo`03003o003oool0oooo0?80oooo000_0?ooo`030000o`3oool0oooo00D0oooo0`3o0012
0?ooo`030000003oool0oooo0:@0oooo0P3o00080?ooo`800?l0l`3oool002h0oooo0P000?l70?oo
o`80o`00@`3oool00`000000oooo0?ooo`2T0?ooo`80o`002@3oool00`00o`00oooo0?ooo`3a0?oo
o`00;P3oool00`000?l0oooo0?ooo`060?ooo`80o`00@`3oool00`000000oooo0?ooo`2T0?ooo`<0
o`00203oool2003o0?80oooo000]0?ooo`80003o1`3oool30?l004<0oooo00<000000?ooo`3oool0
Y@3oool20?l000T0oooo0P00o`3a0?ooo`00;03oool20000o`P0oooo0P3o00140?ooo`030000003o
ool0oooo0:D0oooo0`3o00090?ooo`03003o003oool0oooo0>l0oooo000/0?ooo`030000o`3oool0
oooo00L0oooo0P3o00140?ooo`030000003oool0oooo0:H0oooo0P3o00090?ooo`800?l0l03oool0
02/0oooo0P000?l90?ooo`80o`00A03oool00`000000oooo0?ooo`2V0?ooo`80o`002P3oool00`00
o`00oooo0?ooo`3^0?ooo`00:P3oool20000o`T0oooo0`3o00140?ooo`030000003oool0oooo0:H0
oooo0P3o000:0?ooo`800?l0k`3oool002X0oooo00<0003o0?ooo`3oool0203oool20?l003`0oooo
0`0000060?ooo`030000003oool0oooo0:H0oooo0P3o000;0?ooo`03003o003oool0oooo0>d0oooo
000Y0?ooo`80003o2P3oool20?l003d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`2V0?ooo`80o`002`3oool2003o0>h0oooo000Y0?ooo`030000o`3oool0oooo00P0oooo0`3o000j
0?ooo`D000001P3oool400000:H0oooo0P3o000;0?ooo`03003o003oool0oooo0>`0oooo000Y0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0>@3oool010000000oooo0?ooo`00002a
0?ooo`80o`002`3oool00`00o`00oooo0?ooo`3/0?ooo`00LP3oool00`000000oooo0000003o0?oo
ojh0oooo001c0?ooo`800000o`3ooon^0?ooo`00o`3ooooo0?ooob@0oooo0000\
\>"],
    ImageRangeCache->{{{0, 545.75}, {190.375, 0}} -> {-1, -3, 0, 0}}],
  " "
}], "Text"],

Cell[TextData[{
  "Solution.  The function ",
  StyleBox["f(z)",
    FontFamily->"Courier"],
  " has singularities at  ",
  Cell[BoxData[
      \(z = \(-1\), 2\)]],
  "  and is analytic in the disk  ",
  Cell[BoxData[
      \(D : \(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ",  in the annulus  ",
  Cell[BoxData[
      StyleBox[\(A : \(\(1\)\(<\)\) | z | \(\(<\)\(2\)\)\),
        FontWeight->"Plain"]], "Input"],
  ",  and in the region  ",
  Cell[BoxData[
      \(R : \(\(|\)\(z\)\(|\)\(\(>\)\(2\)\)\)\)]],
  ".  We want to find a different Laurent series for ",
  StyleBox["f(z)",
    FontFamily->"Courier"],
  " in each of the three domains ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["A",
    FontFamily->"Courier New"],
  ", and ",
  StyleBox["R",
    FontFamily->"Courier New"],
  ".  We start by writing ",
  StyleBox["f(z)",
    FontFamily->"Courier"],
  " in its partial fraction form:  \n\n",
  StyleBox["(7-30)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ \(3\/\(\((1 + z)\) \((2 - z)\)\)\ \  = \ \ \
\(1\/\(1 + z\)\ \  + 
              1\/\(2 - z\)\ \  = \ \ 1\/\(1 + z\)\ \  + \(1\/2\) 
                1\/\(1 - z\/2\)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "We use Theorem 4.12 and Corollary 4.1 to obtain the following \
representations for the terms on the right side of Equation ",
  StyleBox["(7-30)",
    FontColor->RGBColor[0, 0, 1]],
  ":  \n\n",
  Cell[BoxData[GridBox[{
          {
            StyleBox[\(\((7 - 31)\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \)\),
              FontWeight->"Plain",
              FontColor->RGBColor[0, 0, 1]], 
            
            StyleBox[\(\(\ \ \ \ \ \ \ \ \ \ \)\(1\/\(1 + z\)\ \  = \ \ \
\[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\) z\^n\)\),
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["   ",
                FontWeight->"Plain"], 
              RowBox[{
                RowBox[{
                  StyleBox[\(valid\ for\),
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["   ",
                    FontWeight->"Plain"], 
                  StyleBox["|",
                    FontWeight->"Plain"], 
                  StyleBox["z",
                    FontWeight->"Plain"], 
                  StyleBox["|",
                    FontWeight->"Plain"], 
                  StyleBox[\(\(<\)\(1\)\),
                    FontWeight->"Plain"]}], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontWeight->"Plain"]}]}]},
          {
            StyleBox[\(\((7 - 32)\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \)\),
              FontWeight->"Plain",
              FontColor->RGBColor[0, 0, 1]], 
            
            StyleBox[\(\(\ \ \ \ \ \ \ \ \ \ \)\(1\/\(1 + z\)\ \  = \ \ \(\(\
\[Sum]\+\(n = 1\)\%\[Infinity]\)\(\((\(-1\))\)\^\(n + 1\)\/z\^n\)\(\ \)\)\)\),
              
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["   ",
                FontWeight->"Plain"], 
              RowBox[{
                RowBox[{
                  StyleBox[\(valid\ for\),
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["   ",
                    FontWeight->"Plain"], 
                  StyleBox["|",
                    FontWeight->"Plain"], 
                  StyleBox["z",
                    FontWeight->"Plain"], 
                  StyleBox["|",
                    FontWeight->"Plain"], 
                  StyleBox[\(\(>\)\(1\)\),
                    FontWeight->"Plain"]}], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontWeight->"Plain"]}]}]},
          {
            StyleBox[\(\((7 - 33)\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \)\),
              FontWeight->"Plain",
              FontColor->RGBColor[0, 0, 1]], 
            
            StyleBox[\(\(\ \)\(\(1\/2\) 
                  1\/\(1 - z\/2\)\ \  = \ \ \(\(\[Sum]\+\(n = 
                        0\)\%\[Infinity]\)\(z\^n\/2\^\(n + 1\)\)\(\ \ \ \ \
\)\)\)\),
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["   ",
                FontWeight->"Plain"], 
              RowBox[{
                RowBox[{
                  StyleBox[\(valid\ for\),
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["   ",
                    FontWeight->"Plain"], 
                  StyleBox["|",
                    FontWeight->"Plain"], 
                  StyleBox["z",
                    FontWeight->"Plain"], 
                  StyleBox["|",
                    FontWeight->"Plain"], 
                  StyleBox[\(\(<\)\(2\)\),
                    FontWeight->"Plain"]}], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontWeight->"Plain"]}]}]},
          {
            StyleBox[\(\((7 - 34)\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \)\),
              FontWeight->"Plain",
              FontColor->RGBColor[0, 0, 1]], 
            
            StyleBox[\(\(1\/2\) 
                  1\/\(1 - z\/2\)\ \  = \ \ \[Sum]\+\(n = 1\)\%\[Infinity]\(-\
\ 2\^\(n - 1\)\)\/z\^n\),
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["   ",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox[\(valid\ for\),
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["   ",
                  FontWeight->"Plain"], 
                StyleBox["|",
                  FontWeight->"Plain"], 
                StyleBox["z",
                  FontWeight->"Plain"], 
                StyleBox["|",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox[">",
                    FontWeight->"Plain"], 
                  RowBox[{
                    StyleBox["2",
                      FontWeight->"Plain"], 
                    StyleBox[" ",
                      FontWeight->"Plain"], 
                    StyleBox[".",
                      FontFamily->"Times New Roman",
                      FontWeight->"Plain"]}]}]}]}]}
          }]], "Input"],
  "  "
}], "Text"],

Cell[TextData[{
  "Representations ",
  StyleBox["(7-31)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(7-33)",
    FontColor->RGBColor[0, 0, 1]],
  " are both valid in the disk  ",
  Cell[BoxData[
      \(D : \(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ",  and thus we have  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ \(\[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\
\) z\^n\  + \ \[Sum]\+\(n = 0\)\%\[Infinity] z\^n\/2\^\(n + 1\)\ \  = \ \ \
\[Sum]\+\(n = 0\)\%\[Infinity]\((\((\(-1\))\)\^n + 1\/2\^\(n + 1\))\) 
              z\^n\)\)]],
  "   valid for   ",
  Cell[BoxData[
      StyleBox[\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\(\ \)\)\),
        FontWeight->"Plain"]]],
  ",  \n\nwhich is a Laurent series that reduces to a Maclaurin series. "
}], "Text"],

Cell[TextData[{
  "In the annulus  ",
  Cell[BoxData[
      StyleBox[\(A : \(\(1\)\(<\)\) | z | \(\(<\)\(2\)\)\),
        FontWeight->"Plain"]], "Input"],
  ",  representations ",
  StyleBox["(7-32)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(7-33)",
    FontColor->RGBColor[0, 0, 1]],
  " are valid; hence we get  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ \[Sum]\+\(n = 1\)\%\[Infinity]\((\(-1\))\)\^\(n + \
1\)\/z\^n\ \  + \ \ \[Sum]\+\(n = 0\)\%\[Infinity] z\^n\/2\^\(n + 1\)\)]],
  "   valid for   ",
  Cell[BoxData[
      StyleBox[\(\(\(1\)\(<\)\) | z | \(\(<\)\(2\)\)\),
        FontWeight->"Plain"]], "Input"],
  ".  "
}], "Text"],

Cell[TextData[{
  "Finally, in the region  ",
  Cell[BoxData[
      \(R : \(\(|\)\(z\)\(|\)\(\(>\)\(2\)\)\)\)]],
  "   we use Representations ",
  StyleBox["(7-32)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(7-34)",
    FontColor->RGBColor[0, 0, 1]],
  " to obtain   \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ \(\[Sum]\+\(n = 1\)\%\[Infinity]\((\(-1\))\)\^\(n \
+ 1\)\/z\^n\ \  + \ \ \ \[Sum]\+\(n = 1\)\%\[Infinity]\(-\ 2\^\(n - \
1\)\)\/z\^n\ \  = \ \ \[Sum]\+\(n = 1\)\%\[Infinity]\(\((\(-1\))\)\^\(n + 1\) \
- \ 2\^\(n - 1\)\)\/z\^n\)\)]],
  "   valid for   ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(2\)\)\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 7.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "We could let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " sum up the various series, and note when they are valid. "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(\((\(-1\))\)\^n\)\!\(z\^n\) = \>\"", \ \[Sum]\+\(n = \
0\)\%\[Infinity]\(\((\(-1\))\)\^n\) 
            z\^n\ , "\<  valid for  |z|<1\>"\ ];\)\), "\n", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = \
1\)\%\[Infinity]\)\!\(\((\(-1\))\)\^\(n + 1\)\/z\^n\) = \>\"", \ 
        FullSimplify[\[Sum]\+\(n = 1\)\%\[Infinity]\((\(-1\))\)\^\(n + 1\)\/z\
\^n], "\<  valid for  |z|>1\>"\ ];\)\), "\n", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(z\^n\/2\^\(n + 1\
\)\) = \>\"", \ 
        FullSimplify[\[Sum]\+\(n = 0\)\%\[Infinity] z\^n\/2\^\(n + 1\)], "\<  \
valid for  |z|<2\>"\ ];\)\), "\n", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\(-2\^\(n - \
1\)\)\/z\^n\) = \>\"", \ 
        FullSimplify[\[Sum]\+\(n = 1\)\%\[Infinity]\(-\ 2\^\(n - \
1\)\)\/z\^n], "\<  valid for  |z|>2\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Combining the above representations we get:", "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)(-1\!\(\()\^n\)\)\!\(z\^n\) + \!\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\)\!\(z\^n\/2\^\(n + 1\)\) = \>\"", \ 
        FullSimplify[\[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\) 
                z\^n\  + \ \[Sum]\+\(n = 0\)\%\[Infinity] z\^n\/2\^\(n + \
1\)], "\<  valid for  |z|<1\>"\ ];\)\), "\n", 
    \(\(Print[\*"\"\<    \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)(\!\(\((\(-1\))\)\^n\)+\!\(1\/2\^\(n + 1\)\))\!\(z\^n\) = \
\>\"", \ FullSimplify[\[Sum]\+\(n = 0\)\%\[Infinity]\((\((\(-1\))\)\^n + 
                  1\/2\^\(n + 1\))\) 
              z\^n], "\<  valid for  |z|<1\>"\ ];\)\), "\n", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(\[Sum]\+\(n = \
1\)\%\[Infinity]\)\!\(\((\(-1\))\)\^\(n + 1\)\/z\^n\) + \!\(\[Sum]\+\(n = 0\)\
\%\[Infinity]\)\!\(z\^n\/2\^\(n + 1\)\) = \>\"", \ 
        FullSimplify[\[Sum]\+\(n = 1\)\%\[Infinity]\((\(-1\))\)\^\(n + 1\)\/z\
\^n\ \  + \ \ \[Sum]\+\(n = 0\)\%\[Infinity] z\^n\/2\^\(n + 1\)], "\<  valid \
for  1<|z|<2\>"\ ];\)\), "\n", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Sum]\+\(n = \
1\)\%\[Infinity]\)\!\(\((\(-1\))\)\^\(n + 1\)\/z\^n\) + \!\(\[Sum]\+\(n = 1\)\
\%\[Infinity]\)\!\(\(-2\^\(n - 1\)\)\/z\^n\) = \>\"", \ 
        FullSimplify[\[Sum]\+\(n = 1\)\%\[Infinity]\((\(-1\))\)\^\(n + 1\)\/z\
\^n\  + \ \[Sum]\+\(n = 1\)\%\[Infinity]\(-\ 2\^\(n - 1\)\)\/z\^n], "\<  \
valid for  2<|z|\>"\ ];\)\), "\n", 
    \(\(Print[\*"\"\<     \!\(\[Sum]\+\(n = \
1\)\%\[Infinity]\)\!\(\(\((\(-1\))\)\^\(n + 1\) - 2\^\(n - 1\)\)\/z\^n\) = \>\
\"", \ FullSimplify[\[Sum]\+\(n = 1\)\%\[Infinity]\(\((\(-1\))\)\^\(n + 1\) - \
\ 2\^\(n - 1\)\)\/z\^n], "\<  valid for  2<|z|\>"\ ];\)\), "\
\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "If more details are desired then we can proceed here they are.\n\nEnter \
the function  ",
  Cell[BoxData[
      \(f[z] = 3\/\(2\  + \ z\  - \ z\^2\)\)]],
  " and find the first few terms of the various Laurent series."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(z = 0; \ Remove[z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[A, f, f1, f2, L1, L2, L3, L4, S0, S11, S12, S21, S22, 
        SI];\)\ \), "\n", 
    \(\(f[z_]\  = \ 3\/\(2\  + \ z\  - \ z\^2\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  " easily finds the Maclaurin series involving positive powers of  z."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(S0[z_]\  = \ 
        Normal[Series[f[z], {z, 0, 7}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_0\)[z] = \>\"", 
        S0[z], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The above series converges for  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ",  this requires looking at the sum of the two \"geometric series\" that \
form the parts of  ",
  Cell[BoxData[
      \(S\_0[z]\)],
    AspectRatioFixed->True],
  ".  ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  " can also find \"the other series\" that involves negative powers of  z, \
this involves the mental thinking that you substitute  ",
  Cell[BoxData[
      \(Z = 1\/z\)]],
  "  in the original series to get a new function of  Z, then expand it about \
 Z = 0  and then substitute  ",
  Cell[BoxData[
      \(Z = 1\/z\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(SI[z_]\  = \ 
        Normal[Series[f[z], {z, \[Infinity], 10}]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_\[Infinity]\)[z] = \>\"", "\<... \>", 
        SI[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The above series converges for  ",
  Cell[BoxData[
      \(\(\(2\)\(\ \)\(<\)\)\  | z | \)]],
  ",  this requires looking at the sum of the two \"geometric series that \
form the parts of ",
  Cell[BoxData[
      \(S\_\[Infinity][z]\)]],
  ".\nThis leaves an unresolved question: \"What happens in the annulus  ",
  Cell[BoxData[
      \(\(\(1\)\(\ \)\(<\)\)\  | z | \(\(<\)\(\ \)\(2\)\)\)]],
  " ?  This requires a little work.  First split up the functions up into \
their partial fraction form, and then do expansions about  ",
  Cell[BoxData[
      \(z = \(0\ \ and\ \ z = \[Infinity]\)\)]],
  "  for each part."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(A\  = \ MapAll[Cancel, Apart[f[z]]];\)\ \), "\n", 
    \(\(f1[z_]\  = \ 
        A\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\);\)\ \), \
"\n", 
    \(\(f2[z_]\  = \ 
        A\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\);\)\ \), \
"\n", 
    \(\(Print["\< f[z] = \>", f[z], "\< = \>", 
        A];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_1\)[z] = \>\"", f1[z]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_2\)[z] = \>\"", 
        f2[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The singularity of  ",
  Cell[BoxData[
      \(f\_1[z]\ \ is\ \ z\  = \ \(-1\)\)],
    AspectRatioFixed->True],
  ",  and the singularity of  ",
  Cell[BoxData[
      \(f\_2[z]\ \ is\ \ z\  = \ 2\)],
    AspectRatioFixed->True],
  ".  Next we form Laurent expansions for the two parts  ",
  Cell[BoxData[
      \(f\_1[z]\ \ and\ \ f\_2[z]\)],
    AspectRatioFixed->True],
  ",  there are two expansions for each function. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(S11[z_]\  = \ Normal[Series[f1[z], {z, 0, 12}]];\)\ \), "\n", 
    \(\(S12[z_]\  = \ 
        Normal[Series[f1[z], {z, \[Infinity], 11}]];\)\ \), "\n", 
    \(\(S21[z_]\  = \ Normal[Series[f2[z], {z, 0, 12}]];\)\ \), "\n", 
    \(\(S22[z_]\  = \ 
        Normal[Series[
            f2[z], {z, \[Infinity], 12}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(f\_1\)[z] = \>\"", f1[z]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_11\)[z] = \>\"", 
        S11[z], "\< - ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  for  |z| < 1\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_12\)[z] = \>\"", "\<... + \>", 
        S12[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  for  |z| > 1\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(f\_2\)[z] = \>\"", f2[z]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_21\)[z] = \>\"", 
        S21[z], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  for  |z| < 2\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_22\)[z] = \>\"", "\<... + \>", 
        S22[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  for  |z| > 2\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Laurent Series (i).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  The first Laurent series  ",
  Cell[BoxData[
      \(L\_1[z]\  = S\_11[z] + S\_21[z]\)]],
  "  is valid for  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(L1[z_]\  = \ S11[z]\  + \ S21[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = \>", f[z], "\< = \>", 
        A];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(L\_1\)[z] = \>\"", 
        L1[z], "\< - ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], L1[x]}, {x, \(-0.999999\), 0.999999}, 
        PlotRange \[Rule] {{\(-1\), 1}, {0, 8}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 8, 1]}, 
        PlotStyle \[Rule] {Red, Blue}, 
        AxesLabel \[Rule] {"\<x\>", "\<s\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<s = \>", 
        f[x], \*"\"\<  and  s = \!\(L\_1\)[x]\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(L\_1\)[x] = \>\"", 
        L1[x]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the complex Laurent series is \"converging\" in \
the complex plane.\nFor the first series we need to be close to  ",
  Cell[BoxData[
      \(z = 0\)]],
  ".  For convenience we use the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(0.6\)\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        L1, {0, 0.6, 
          0.1}, {\(-\[Pi]\), \ \[Pi], \ \[Pi]\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{1, 2}, {\(-0.5\), 0.5}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[1, 2, 1], 
            Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\n", 
    \(\(Print[\*"\"\<w = = \!\(L\_1\)[z] = \>\"", 
        L1[z], "\<,  where |z| < 0.6\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        f, {0, 0.6, 
          0.1}, {\(-\[Pi]\), \ \[Pi], \ \[Pi]\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{1, 2}, {\(-0.5\), 0.5}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[1, 2, 1], 
            Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\n", 
    \(\(Print["\<w = f[z] = \>", 
        f[z], "\<,  where |z| < 0.6\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  If ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " chosen close enough to ",
  Cell[BoxData[
      \(z = 0\)]],
  " then the series ",
  Cell[BoxData[
      \(L\_1[z]\)]],
  " will not converge rapidly near the circle.  More terms are needed to get \
convergence near the circle  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ".  We can see what is happening in the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(0.9\)\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        L1, {0, 0.9, 
          0.15}, {\(-\[Pi]\), \ \[Pi], \ \[Pi]\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{1, 2}, {\(-0.5\), 0.5}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[1, 2, 1], 
            Range[\(-1\), 1, 
              1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\n", 
    \(\(Print[\*"\"\<w = = \!\(L\_1\)[z] = \>\"", 
        L1[z], "\<,  where |z| < 0.9\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Laurent Series (ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  The second Laurent series  ",
  Cell[BoxData[
      \(L\_2[z]\  = \ S\_12[z] + S\_21[z]\)]],
  "  is valid for  ",
  Cell[BoxData[
      \(\(\(1\)\(\ \)\(<\)\)\  | z | \(\(<\)\(\ \)\(2\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(L2[z_]\  = \ S12[z]\  + \ S21[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = \>", f[z], "\< = \>", 
        A];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(L\_2\)[z] = ... + \>\"", \ S12[z]\ , "\< + \>", 
        S21[z], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(Plot[{f[x], L2[x]}, {x, 1.0001, 
          1.9999}, \n\ \ PlotRange \[Rule] {{1, 2}, {0, 7}}, 
        Ticks \[Rule] {Range[1, 2, 0.2], Range[0, 7, 1]}, 
        PlotStyle \[Rule] {Red, Green}, 
        AxesLabel \[Rule] {"\<x\>", "\<s\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<s = \>", 
        f[x], \*"\"\<  and  s = \!\(L\_2\)[x]\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(L\_2\)[x] = \>\"", 
        L2[x]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the complex Laurent series is \"converging\" in \
the complex plane.\nFor the second series we need to be in the middle of the \
annulus  ",
  Cell[BoxData[
      \(\(\(1\)\(\ \)\(<\)\)\  | z | \(\(<\)\(\ \)\(2\)\)\)]],
  ".   For convenience we choose  ",
  Cell[BoxData[
      \(\(\(1.3\)\(\ \)\(<\)\)\  | z | \(\(<\)\(\ \)\(1.6\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        L2, {1.3, 1.6, 
          0.05}, {\(-\[Pi]\), \ \[Pi], \ \[Pi]\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{0.63, 2.93}, {\(-1.15\), 1.15}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[1, 3, 1\/2], 
            Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\n", 
    \(\(Print[\*"\"\<w = = \!\(L\_2\)[z] = \>\"", 
        L2[z], "\<,  where 1.3 < |z| < 1.6\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(PolarMap[
        f, {1.3, 1.6, 
          0.05}, {\(-\[Pi]\), \ \[Pi], \ \[Pi]\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{0.63, 2.93}, {\(-1.15\), 1.15}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[1, 3, 1\/2], 
            Range[\(-1\), 1, 
              1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\n", 
    \(\(Print["\<w = f[z] = \>", 
        f[z], "\<,  where 1.3 < |z| < 1.6\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Hence ",
  Cell[BoxData[
      \(L\_2[z]\)]],
  " is an approximation to  ",
  Cell[BoxData[
      \(f[z] = \(3\/\(2\  + \ z\  - \ z\^2\) = 
          1\/\(z\  + \ 1\) - 1\/\(z\  - \ 2\)\)\)]],
  "  valid for  ",
  Cell[BoxData[
      \(\(\(1\)\(\ \)\(<\)\)\  | z | \(\(<\)\(\ \)\(2\)\)\)]],
  ".   \nNotice that the first series  ",
  Cell[BoxData[
      \(L\_1[z]\)]],
  "  is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " a good approximation in  ",
  Cell[BoxData[
      \(\(\(1\)\(\ \)\(<\)\)\  | z | \(\(<\)\(\ \)\(2\)\)\)]],
  ",  for illustration, it is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " accurate at  ",
  Cell[BoxData[
      \(z = 1.5\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Print["\< f[1.5] = \>", f[1.5]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(L\_1\)[1.5] = \>\"", 
        L1[1.5]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[1.5] = \>", f[1.5]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(L\_2\)[1.5] = \>\"", 
        L2[1.5]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Laurent Series (iii).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  The third Laurent series  ",
  Cell[BoxData[
      \(L\_3[z]\  = \ S\_12[z] + S\_22[z]\)]],
  "  is valid for  ",
  Cell[BoxData[
      \(\(\(2\)\(\ \)\(<\)\)\  | z | \)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(L3[z_]\  = \ S12[z]\  + \ S22[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = \>", f[z], "\< = \>", 
        A];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(L\_3\)[z] = ... \>\"", 
        L3[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(Plot[{f[x], L3[x]}, {x, 2.0001, 
          5.0}, \n\ \ PlotRange \[Rule] {{2, 5}, {\(-6\), 0}}, 
        Ticks \[Rule] {Range[2, 5, 0.5], Range[\(-6\), 0, 1]}, 
        PlotStyle \[Rule] {Red, Cyan}, 
        AxesLabel \[Rule] {"\<x\>", "\<s\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<s = \>", 
        f[x], \*"\"\<  and  s = \!\(L\_3\)[x], for 2 < x \[LessEqual] \
5\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(L\_3\)[x] = \>\"", 
        L3[x]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the complex Laurent series is \"converging\" in \
the complex plane.\nFor the third series z must satisfy  ",
  Cell[BoxData[
      \(\(\(2\)\(\ \)\(<\)\)\  | z | \)]],
  ".  For convenience we choose  ",
  Cell[BoxData[
      \(\(\(3\)\(\ \)\(<\)\)\  | z | \)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        L3, {3, 5, 
          0.5}, {\(-\[Pi]\), \ \[Pi], \ \[Pi]\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-0.8\), 0.4}, {\(-0.6\), 0.6}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[1, 2, 0.5], 
            Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\n", 
    \(Print[\*"\"\<w = = \!\(L\_3\)[z] = \>\"", 
      L3[z], "\<,  where 3 < |z| < 5\>"]; \ 
    PolarMap[f, {3, 5, 
        0.5}, {\(-\[Pi]\), \ \[Pi], \ \[Pi]\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-0.8\), 0.4}, {\(-0.6\), 0.6}}, 
      AspectRatio \[Rule] 
        1, \[IndentingNewLine]Ticks \[Rule] {Range[1, 2, 0.5], 
          Range[\(-1\), 1, 
            1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
      PlotStyle \[Rule] {Red, Blue}];\ \), "\n", 
    \(\(Print["\<w = f[z] = \>", 
        f[z], "\<,  where 3 < |z| < 5\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " If z is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " large enough to then the series ",
  Cell[BoxData[
      \(L\_3[z]\)]],
  " will not converge rapidly.  More terms are needed to get convergence near \
 ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = \ 2\)]],
  ".    We can see what is happening in the annulus  ",
  Cell[BoxData[
      \(\(\(2.2\)\(\ \ \)\(<\)\)\  | z | \ \(\(<\)\(\ \ \)\(4\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        L3, {2.2, 4, 
          0.2}, {\(-\[Pi]\), \ \[Pi], \ \[Pi]\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-0.8\), 0.4}, {\(-0.6\), 0.6}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[1, 2, 0.5], 
            Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\n", 
    \(\(Print[\*"\"\<w = = \!\(L\_3\)[z] = \>\"", 
        L3[z], "\<,  where 2.2 < |z| < 4\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "So  ",
  Cell[BoxData[
      \(L\_3[z]\)]],
  "  is an approximation to  ",
  Cell[BoxData[
      \(f[z] = \(3\/\(2\  + \ z\  - \ z\^2\) = 
          1\/\(z\  + \ 1\) - 1\/\(z\  - \ 2\)\)\)]],
  "  valid for  ",
  Cell[BoxData[
      \(\(\(2\)\(\ \)\(<\)\)\  | z | \)]],
  ".  \nNotice that ",
  Cell[BoxData[
      \(L\_1[z]\ \ and\ \ L\_2[z]\)]],
  " are ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " good approximations for  ",
  Cell[BoxData[
      \(\(\(2\)\(\ \)\(<\)\)\  | z | \)]],
  ",  for illustration they are ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " accurate at  z = 4.0"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Print["\< f[4.0] = \>", f[4.0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(L\_1\)[4.0] = \>\"", 
        L1[4.0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[4.0] = \>", f[4.0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(L\_2\)[4.0] = \>\"", 
        L2[4.0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[4.0] = \>", f[4.0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(L\_3\)[4.0] = \>\"", 
        L3[4.0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Divergent Series Combination (iv).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["  ",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The fourth possibility  ",
  Cell[BoxData[
      \(S\_11[z] + S\_22[z]\)]],
  "  does ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " converge for any values of z and should ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " be considered, however you could write down a few terms and think about \
why this series ",
  StyleBox["diverges",
    FontColor->RGBColor[1, 0, 1]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(L4[z_]\  = \ S11[z]\  + \ S22[z];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(L\_4\)[z] = \>\"", "\<... \>", S22[z], "\< + \>", 
        S11[z], "\< - ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "In the above series, when  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\/2\)\)\)\)]],
  "  the portion of the series with positive exponents will converge but the \
portion with negative exponents will diverge. Similarly, when  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(\ \)\(1\)\)\)\)]],
  "  the portion of the series with negative exponents will converge, but the \
portion of the series with positive exponents will diverge.   Hence, the \
series diverges for all  z.  It does ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " approximate  f[z]  at any of the values x = 0.5, 1.5, 4.0"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\< f[0.5] = \>", f[0.5]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(L\_4\)[0.5] = \>\"", 
        L4[0.5]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[1.5] = \>", f[1.5]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(L\_4\)[1.5] = \>\"", 
        L4[1.5]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[4.0] = \>", f[4.0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(L\_4\)[4.0] = \>\"", 
        L4[4.0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Open  ]],

Cell["We can summarize the above findings.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(graph1 = 
        Plot[{f[x], L1[x]}, {x, \(-0.999999\), 0.999999}, 
          PlotRange \[Rule] {{\(-1\), 1}, {0, 8}}, 
          Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 8, 1]}, 
          PlotStyle \[Rule] {Red, Blue}, 
          AxesLabel \[Rule] {"\<x\>", "\<s\>"}];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<s = \>", 
        f[x], \*"\"\<  and  s = \!\(L\_1\)[x]\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(L\_1\)[x] = \>\"", 
        L1[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(graph2 = 
        Plot[{f[x], L2[x]}, {x, 1.0001, 
            1.9999}, \n\ \ PlotRange \[Rule] {{1, 2}, {0, 7}}, 
          Ticks \[Rule] {Range[1, 2, 0.2], Range[0, 7, 1]}, 
          PlotStyle \[Rule] {Red, Green}, 
          AxesLabel \[Rule] {"\<x\>", "\<s\>"}];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<s = \>", 
        f[x], \*"\"\<  and  s = \!\(L\_2\)[x]\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(L\_2\)[x] = \>\"", 
        L2[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(graph3 = 
        Plot[{f[x], L3[x]}, {x, 2.0001, 
            5.0}, \n\ \ PlotRange \[Rule] {{2, 5}, {\(-6\), 0}}, 
          Ticks \[Rule] {Range[2, 5, 0.5], Range[\(-6\), 0, 1]}, 
          PlotStyle \[Rule] {Red, Cyan}, 
          AxesLabel \[Rule] {"\<x\>", "\<s\>"}];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<s = \>", 
        f[x], \*"\"\<  and  s = \!\(L\_3\)[x], for 2 < x \[LessEqual] \
5\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(L\_3\)[x] = \>\"", 
        L3[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, PlotRange \[Rule] {All, {\(-5\), 10}}, 
        Ticks \[Rule] {Range[\(-1\), 5, 1], 
            Range[\(-4\), 10, 2]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<s = \>", 
        f[x], \*"\"\<  and  s = \!\(L\_3\)[x], \!\(L\_2\)[x], \!\(L\_3\)[x]\>\
\""];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Laurent series representation for  ",
  Cell[BoxData[
      \(f \((z)\) = \(cos \((z)\)\  - \ 1\)\/z\^4\)],
    AspectRatioFixed->False],
  "  that involves powers of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Solution.  We know that  ",
  Cell[BoxData[
      \(cos\ z\ \  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\(\(\((\(-1\))\)\^n\) \
z\^\(2  n\)\)\/\(\((2  n)\)!\)\)]],
  ",  and hence the Maclaurin series for  ",
  Cell[BoxData[
      \(cos\ z\  - \ 1\)]],
  "  is\n\n\t\t\t",
  Cell[BoxData[
      \(cos\ z\  - \ 
          1\ \  = \ \ \(\[Sum]\+\(n = 1\)\%\[Infinity]\(\(\((\(-1\))\)\^n\) z\
\^\(2  n\)\)\/\(\((2  n)\)!\)\ \  = \ \ \(-\(z\^2\/\(2!\)\)\) + 
              z\^4\/\(4!\) - z\^6\/\(6!\) + z\^8\/\(8!\) - 
              z\^10\/\(10!\) +  ... \)\)]],
  ",   \nthen we can write \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ \(\(1\/z\^4\) \(\[Sum]\+\(n = \
1\)\%\[Infinity]\(\(\((\(-1\))\)\^n\) z\^\(2  n\)\)\/\(\((2  n)\)!\)\)\ \  = \
\ \ \[Sum]\+\(n = 1\)\%\[Infinity]\(\(\((\(-1\))\)\^n\) z\^\(2  n - 4\)\)\/\(\
\((2  n)\)!\)\)\)]],
  "\n\nor in another way we can write\n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ \(\(cos\ z\ \  - \ \ 1\)\/z\^4\ \  = \ \ \(\(-\ \
\(z\^2\/\(2!\)\)\)\  + \ z\^4\/\(4!\)\  - \ z\^6\/\(6!\)\  + \ z\^8\/\(8!\)\  \
- \ z\^10\/\(10!\)\  + \  ... \)\/z\^4\)\)]],
  "\n\nWe formally divide each term by ",
  Cell[BoxData[
      \(z\^4\)]],
  " to obtain the Laurent series  \n\n\t\t\t",
  Cell[BoxData[{
      \(f \((z)\)\ \  = \ \ \(-\ \(1\/\(2!\)\)\) 1\/z\^2\  + \ 
            1\/\(4!\)\  - \ z\^2\/\(6!\)\  + \ z\^4\/\(8!\)\  - \ 
            z\^6\/\(10!\)\  + \  ... \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(-\(1\/\(2\ z\^2\)\)\) + 
            1\/24 - z\^2\/720 + z\^4\/40320 - z\^6\/3628800 +  ... \)\)\)}]],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 7.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \(Cos[z]\  - \ 1\)\/z\^4\)]],
  " and find the first few terms of the Laurent series in the punctured plane \
 ",
  Cell[BoxData[
      \(0 < z\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, L, S, S10, S\[Infinity]];\)\ \), "\n", 
    \(\(f[z_]\  = \ \(Cos[z]\  - \ 1\)\/z\^4;\)\ \), "\n", 
    \(\(S[z_]\  = \ Normal[Series[Cos[z] - 1, \ {z, 0, 14}]];\)\ \), "\n", 
    \(\(L[z_]\  = \ Normal[Series[f[z], {z, 0, 10}]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<S[z] = (\>", S[z], "\< - ... )/(\>", 
        z\^4, "\<)\>"];\)\ \), "\n", 
    \(\(Print["\<L[z] = \>", 
        L[z], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "The latter Laurent series is valid for  ",
  Cell[BoxData[
      \(\(\(0\)\(\ \)\(<\)\) | z | \)]],
  ".  \n\nSum up an infinite number of terms to verify that we have things \
right."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(S10[
          z_]\  = \ \[Sum]\+\(n = 1\)\%7\(\(\((\(-1\))\)\^n\) z\^\(2  n - 4\)\
\)\/\(\((2  n)\)!\);\)\ \), "\n", 
    \(\(S\[Infinity][
          z_]\  = \ \ \[Sum]\+\(n = 1\)\%\[Infinity]\(\(\((\(-1\))\)\^n\) z\^\
\(2  n - 4\)\)\/\(\((2  n)\)!\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(S\_10\)[z] = \>\"", 
        S10[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_\[Infinity]\)[z] = \!\(\[Sum]\+\(n = 1\)\%\
\[Infinity]\)\!\(\(\(\((\(-1\))\)\^n\) z\^\(2  n - 4\)\)\/\(\((2  n)\)!\)\) = \
 \>\"", S\[Infinity][z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_\[Infinity]\)[z] = \!\(\[Sum]\+\(n = 1\)\%\
\[Infinity]\)\!\(\(\(\((\(-1\))\)\^n\) z\^\(2  n - 4\)\)\/\(\((2  n)\)!\)\) = \
 \>\"", Together[Expand[S\[Infinity][z]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "See how closely the series  ",
  Cell[BoxData[
      \(S\_10[z]\)]],
  "  approximates the function  ",
  Cell[BoxData[
      \(f[z] = \(Cos[z]\  - \ 1\)\/z\^4\)],
    AspectRatioFixed->False],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<f[0.2]= \>", f[0.2]];\)\ \), "\n", 
    \(\(Print["\<L[0.2]= \>", L[0.2]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<f[2.0]= \>", f[2.0]];\)\ \), "\n", 
    \(\(Print["\<L[2.0]= \>", L[2.0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(Plot[{f[x], L[x]}, {x, 0.0001, 
          15}, \[IndentingNewLine]PlotRange \[Rule] {{0, 15}, {\(-10\), 
              0.1}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 15, 2], 
            Range[\(-10\), 0, 2]}, PlotStyle \[Rule] {Red, Blue}, 
        AxesLabel \[Rule] {"\<x\>", "\<s\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<s = \>", 
        f[x], \*"\"\<  and  s = \!\(S\_10\)[x]\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(S\_10\)[x] = \>\"", 
        L[x]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the complex Laurent series is \"converging\" in \
the complex plane."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        S10\ , {0.2, 2.2, 0.1}, {\(-1\), \ 1, \ 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-6\), 2}, {\(-4\), 
              4}}, AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-7\), 3, 1], 
            Range[\(-5\), 5, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<w = \!\(S\_10\)[z] =  \>\"", 
        S10[z], "\<,  where 0.2 \[LessEqual] x \[LessEqual] 2.2, -1 \
\[LessEqual] y \[LessEqual] 1\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        f, {0.2, 2.2, 0.1}, {\(-1\), \ 1, \ 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-6\), 2}, {\(-4\), 
              4}}, AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-7\), 3, 1], 
            Range[\(-5\), 5, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = f[z] = \>", 
        f[z], "\<,  where 0.2 \[LessEqual] x \[LessEqual] 2.2, -1 \
\[LessEqual] y \[LessEqual] 1\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(F[z_] = f[z + 1];\)\ \), "\n", 
    \(\(G[z_] = S10[z + 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        G\ , {0, 0.999, 
          0.1665}, {\(-\[Pi]\), \ \[Pi], \ \[Pi]\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-5\), 2}, {\(-3\), 3}}, 
        AspectRatio \[Rule] 
          6\/7, \[IndentingNewLine]Ticks \[Rule] {Range[\(-5\), 5, 1], 
            Range[\(-5\), 5, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<w = \!\(S\_9\)[1+z] =  \>\"", 
        S9[1 + z], "\<,  where |z| < 0.999\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(PolarMap[
        F, {0, 0.999, 
          0.1665}, {\(-\[Pi]\), \ \[Pi], \ \[Pi]\/12}, \
\[IndentingNewLine]PlotRange \[Rule] {{\(-5\), 2}, {\(-3\), 3}}, 
        AspectRatio \[Rule] 
          6\/7, \[IndentingNewLine]Ticks \[Rule] {Range[\(-5\), 5, 1], 
            Range[\(-5\), 5, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = f[1+z] = \>", 
        f[1 + z], "\<,  where |z| < 0.999\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Laurent series for  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ exp \((\(-1\)\/z\^2)\)\)],
    AspectRatioFixed->False],
  "  centered at  ",
  Cell[BoxData[
      \(\[Alpha] = 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Solution.  The Maclaurin series for  ",
  StyleBox["exp z",
    FontFamily->"Courier New"],
  "  is  ",
  Cell[BoxData[
      \(exp\ z\ \  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\( 1\/\(n!\)\) 
            z\^n\)]],
  ", which is valid for all ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ".  We let  ",
  Cell[BoxData[
      \(\(-1\)\/z\^2\)]],
  "  take the role of z in this equation to get\n\n\t\t\t",
  Cell[BoxData[
      \(exp \((\(-1\)\/z\^2)\)\ \  = \ \ \(\[Sum]\+\(n = 0\)\%\[Infinity]\( 
                  1\/\(n!\)\) \((\(-1\)\/z\^2)\)\^n\ \  = \ \ \(\[Sum]\+\(n = \
0\)\%\[Infinity]\( 
                    1\/\(n!\)\) \((\(-1\))\)\^n\/\((z\^2)\)\^n\ \  = \ \ \
\[Sum]\+\(n = 0\)\%\[Infinity]\((\(-1\))\)\^n\/\(\(n!\) \
\((z\^2)\)\^n\)\)\)\)]],
  ",\n\nwhich is valid for ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(0\)\)\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 7.9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \[ExponentialE]\^\(\(-1\)\/z\^2\)\)]],
  " and find the first few terms of the Laurent series in the punctured plane \
 ",
  Cell[BoxData[
      \(0 < z\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, L, L1, S1];\)\ \), "\n", 
    \(\(f[z_]\  = \ \[ExponentialE]\^\(\(-1\)\/z\^2\);\)\ \), "\n", 
    \(\(L[z_]\  = \ Normal[Series[f[z], {z, \[Infinity], 20}]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<L[z] = ... + \>", L[z] - 1, "\< + \>", 
        1];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Note that we had to expand the function about ",
  Cell[BoxData[
      \(\[Infinity]\)]],
  " in order to get the negative powers of  z. Also, we can get the Laurent \
expansion by series substitution:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(S1[z_]\  = \ 
        Normal[Series[\[ExponentialE]\^z, {z, 0, 10}]];\)\ \), "\n", 
    \(\(L1[z_]\  = \ S1[\(-1\)\/z\^2];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(\[ExponentialE]\^Z\) = \>\"", 
        S1[Z], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Use the change of variable Z = \
\!\(\(-1\)\/z\^2\).\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(L\_1\)[z] = ... + \>\"", L1[z] - 1, "\< + \>", 
        1];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "The above Laurent series is valid for  ",
  Cell[BoxData[
      \(\(\(0\)\(\ \)\(<\)\)\  | z | \)]],
  ".  \n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(Plot[{f[x], L1[x]}, {x, 0.3, 
          2.0}, \n\ \ PlotRange \[Rule] {{0, 2}, {\(-0.1\), 1}}, 
        Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 1, 0.2]}, 
        PlotStyle \[Rule] {Red, Blue}, 
        AxesLabel \[Rule] {"\<x\>", "\<s\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<s = \>", 
        f[x], \*"\"\<  and  s = \!\(S\_1\)[x]\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(S\_1\)[x] = \>\"", 
        L1[x]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the complex Laurent series is \"converging\" in \
the complex plane.\nBut, we need to stay away from  z=0.  For convenience we \
use the disk  ",
  Cell[BoxData[
      \(\(\(0.3\)\(\ \)\(<\)\)\  | z | \(\(<\)\(0.9\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        L1\ , {0.3, 0.9, 
          0.1}, {\(-\ \[Pi]\)\/2, \ \(\(\ \)\(\[Pi]\)\)\/2, \ \(\(\ \)\(\[Pi]\
\)\)\/12}, \[IndentingNewLine]PlotRange \[Rule] {{\(-5\), 5}, {\(-5\), 5}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-5\), 5, 1], 
            Range[\(-5\), 5, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(Print[\*"\"\<w = \!\(S\_1\)[1+z] =  \>\"", 
      S9[1 + z], "\<,  where 0.3 < |z| < 0.9\>"]; \ 
    PolarMap[f, {0.3, 0.9, 
        0.1}, {\(-\ \[Pi]\)\/2, \ \(\(\ \)\(\[Pi]\)\)\/2, \ \(\(\ \)\(\[Pi]\)\
\)\/12}, \[IndentingNewLine]PlotRange \[Rule] {{\(-5\), 5}, {\(-5\), 5}}, 
      AspectRatio \[Rule] 
        1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-5\), 5, 1], 
          Range[\(-5\), 5, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
      PlotStyle \[Rule] {Red, Blue}];\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = f[1+z] = \>", 
        f[1 + z], "\<,  where 0.3 < |z| < 0.9\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Taylor Series",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/TaylorSeriesBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Laurent Series",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/LaurentSeriesBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Poles and Singularity",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/PoleBib.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{930, 638},
WindowMargins->{{28, Automatic}, {Automatic, 4}},
CellLabelAutoDelete->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[17344, 509, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[21800, 651, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[25922, 791, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 103206, 2937}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 125, 2, 33, "Text"],
Cell[2230, 66, 2309, 67, 155, "Text",
  Evaluatable->False],
Cell[4542, 135, 362, 14, 36, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4929, 153, 176, 4, 33, "Text",
  Evaluatable->False],
Cell[5108, 159, 280, 10, 36, "Text",
  Evaluatable->False],
Cell[5391, 171, 696, 14, 226, "Input"],
Cell[6090, 187, 186, 5, 33, "Text",
  Evaluatable->False],
Cell[6279, 194, 561, 12, 224, "Input"],
Cell[6843, 208, 172, 5, 33, "Text"],
Cell[7018, 215, 591, 12, 130, "Input"],
Cell[7612, 229, 353, 10, 52, "Text"],
Cell[7968, 241, 1364, 27, 296, "Input"],
Cell[9335, 270, 1355, 24, 230, "Input"]
}, Closed]],
Cell[10705, 297, 1119, 31, 128, "Text",
  Evaluatable->False],
Cell[11827, 330, 1545, 47, 128, "Text",
  Evaluatable->False],
Cell[13375, 379, 986, 25, 128, "Text"],
Cell[14364, 406, 1122, 37, 185, "Text",
  Evaluatable->False],
Cell[15489, 445, 594, 19, 33, "Text"],
Cell[16086, 466, 908, 27, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[17019, 497, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[17167, 503, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[17344, 509, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[17704, 521, 950, 28, 49, "Text",
  Evaluatable->False],
Cell[18657, 551, 2793, 84, 177, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[21475, 639, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[21623, 645, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[21800, 651, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[22160, 663, 1769, 56, 113, "Text"],
Cell[23932, 721, 93, 2, 33, "Text"],
Cell[24028, 725, 1544, 50, 185, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[25597, 779, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[25745, 785, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[25922, 791, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[26282, 803, 361, 9, 49, "Text"],
Cell[26646, 814, 419, 14, 37, "Text",
  Evaluatable->False],
Cell[27068, 830, 21605, 570, 211, "Text"],
Cell[48676, 1402, 1232, 42, 99, "Text"],
Cell[49911, 1446, 6173, 160, 169, "Text"],
Cell[56087, 1608, 778, 21, 112, "Text"],
Cell[56868, 1631, 669, 20, 76, "Text"],
Cell[57540, 1653, 678, 20, 76, "Text"],

Cell[CellGroupData[{
Cell[58243, 1677, 244, 9, 33, "Text",
  Evaluatable->False],
Cell[58490, 1688, 161, 5, 33, "Text"],
Cell[58654, 1695, 1092, 20, 284, "Input"],
Cell[59749, 1717, 59, 0, 33, "Text"],
Cell[59811, 1719, 1816, 31, 319, "Input"],
Cell[61630, 1752, 299, 8, 75, "Text",
  Evaluatable->False],
Cell[61932, 1762, 342, 7, 124, "Input"],
Cell[62277, 1771, 200, 6, 33, "Text",
  Evaluatable->False],
Cell[62480, 1779, 365, 8, 110, "Input"],
Cell[62848, 1789, 741, 23, 77, "Text",
  Evaluatable->False],
Cell[63592, 1814, 263, 6, 70, "Input"],
Cell[63858, 1822, 695, 18, 71, "Text",
  Evaluatable->False],
Cell[64556, 1842, 624, 15, 170, "Input"],
Cell[65183, 1859, 502, 16, 52, "Text",
  Evaluatable->False],
Cell[65688, 1877, 1270, 24, 330, "Input"],

Cell[CellGroupData[{
Cell[66983, 1905, 363, 13, 33, "Text",
  Evaluatable->False],
Cell[67349, 1920, 368, 8, 110, "Input"],
Cell[67720, 1930, 182, 6, 33, "Text"],
Cell[67905, 1938, 627, 13, 130, "Input"],
Cell[68535, 1953, 398, 12, 52, "Text"],
Cell[68936, 1967, 1166, 23, 256, "Input"],
Cell[70105, 1992, 664, 24, 52, "Text"],
Cell[70772, 2018, 717, 14, 183, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71526, 2037, 328, 11, 33, "Text"],
Cell[71857, 2050, 399, 8, 110, "Input"],
Cell[72259, 2060, 182, 6, 33, "Text"],
Cell[72444, 2068, 600, 13, 150, "Input"],
Cell[73047, 2083, 472, 13, 52, "Text"],
Cell[73522, 2098, 1242, 25, 303, "Input"],
Cell[74767, 2125, 776, 29, 56, "Text",
  Evaluatable->False],
Cell[75546, 2156, 400, 9, 130, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75983, 2170, 308, 11, 33, "Text"],
Cell[76294, 2183, 359, 8, 110, "Input"],
Cell[76656, 2193, 182, 6, 33, "Text"],
Cell[76841, 2201, 632, 13, 150, "Input"],
Cell[77476, 2216, 396, 12, 52, "Text"],
Cell[77875, 2230, 1163, 23, 256, "Input"],
Cell[79041, 2255, 541, 18, 52, "Text"],
Cell[79585, 2275, 697, 13, 163, "Input"],
Cell[80285, 2290, 697, 26, 56, "Text",
  Evaluatable->False],
Cell[80985, 2318, 588, 13, 190, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81610, 2336, 725, 25, 52, "Text",
  Evaluatable->False],
Cell[82338, 2363, 255, 5, 70, "Input"],
Cell[82596, 2370, 705, 16, 74, "Text",
  Evaluatable->False],
Cell[83304, 2388, 562, 12, 190, "Input"]
}, Open  ]],
Cell[83881, 2403, 52, 0, 33, "Text"],
Cell[83936, 2405, 2045, 45, 370, "Input"]
}, Closed]],
Cell[85996, 2453, 402, 14, 33, "Text",
  Evaluatable->False],
Cell[86401, 2469, 1669, 38, 364, "Text"],

Cell[CellGroupData[{
Cell[88095, 2511, 244, 9, 33, "Text",
  Evaluatable->False],
Cell[88342, 2522, 290, 11, 36, "Text",
  Evaluatable->False],
Cell[88635, 2535, 606, 12, 205, "Input"],
Cell[89244, 2549, 263, 8, 71, "Text",
  Evaluatable->False],
Cell[89510, 2559, 1052, 19, 328, "Input"],
Cell[90565, 2580, 232, 9, 36, "Text"],
Cell[90800, 2591, 344, 7, 130, "Input"],
Cell[91147, 2600, 182, 6, 33, "Text"],
Cell[91332, 2608, 651, 13, 150, "Input"],
Cell[91986, 2623, 194, 6, 33, "Text"],
Cell[92183, 2631, 1358, 24, 230, "Input"],
Cell[93544, 2657, 1371, 27, 324, "Input"]
}, Closed]],
Cell[94930, 2687, 367, 14, 33, "Text",
  Evaluatable->False],
Cell[95300, 2703, 893, 26, 122, "Text"],

Cell[CellGroupData[{
Cell[96218, 2733, 244, 9, 33, "Text",
  Evaluatable->False],
Cell[96465, 2744, 299, 11, 39, "Text",
  Evaluatable->False],
Cell[96767, 2757, 506, 10, 180, "Input"],
Cell[97276, 2769, 282, 8, 33, "Text",
  Evaluatable->False],
Cell[97561, 2779, 609, 12, 179, "Input"],
Cell[98173, 2793, 341, 11, 71, "Text",
  Evaluatable->False],
Cell[98517, 2806, 602, 13, 150, "Input"],
Cell[99122, 2821, 355, 10, 52, "Text"],
Cell[99480, 2833, 1284, 24, 256, "Input"]
}, Closed]],
Cell[100779, 2860, 290, 7, 30, "Text"],
Cell[101072, 2869, 311, 10, 33, "Text"],
Cell[101386, 2881, 313, 10, 33, "Text"],
Cell[101702, 2893, 304, 9, 33, "Text"],
Cell[102009, 2904, 257, 5, 33, "Text"],
Cell[102269, 2911, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

