(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    259219,       6056]*)
(*NotebookOutlinePosition[    260851,       6111]*)
(*  CellTagsIndexPosition[    260774,       6105]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["7.4  Singularities, Zeros, and Poles",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tRecall that the point ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  " is called a ",
  StyleBox[ButtonBox["singular point",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/SingularPointFunction.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ", or  ",
  StyleBox[ButtonBox["singularity",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/SingularPointFunction.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " of the complex function ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " if  f  is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " analytic at  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ",  but every neighborhood  ",
  Cell[BoxData[
      \(\(D\_R\) \((\[Alpha])\)\ \ of\ \ \[Alpha]\)]],
  "  contains at least one point at which ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic.  For example, the function  ",
  Cell[BoxData[
      \(f \((z)\) = 1\/\(1\  - \ z\)\)]],
  "  is not analytic at  ",
  Cell[BoxData[
      \(z = 1\)]],
  ",  but is analytic for all other values of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ".  Thus the point  ",
  Cell[BoxData[
      \(z = 1\)]],
  "  is a singular point of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  ".  As another example,  consider  ",
  Cell[BoxData[
      \(g \((z)\)\  = \ Log \((z)\)\)]],
  ".  We saw in Section 5.2 that ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " is  analytic for all ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " except at the origin and at all points on the negative real-axis.  Thus, \
the origin and each point on the negative real axis is a singularity of  ",
  Cell[BoxData[
      \(g \((z)\)\  = \ Log \((z)\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "\tThe point ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  " is called a ",
  StyleBox[ButtonBox["isolated singularity",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/IsolatedSingularity.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " of the complex function ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " if  f  is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " analytic at  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ",  but there exists a real number  ",
  Cell[BoxData[
      \(R > 0\)]],
  "  such that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic everywhere in the punctured disk  ",
  Cell[BoxData[
      \(\(D\_R\%*\) \((\[Alpha])\)\)]],
  ".  The function  ",
  Cell[BoxData[
      \(f \((z)\) = 1\/\(1\  - \ z\)\)]],
  "  has an isolated singularity at  ",
  Cell[BoxData[
      \(z = 1\)]],
  ".  \n\n\tThe function  ",
  Cell[BoxData[
      \(g \((z)\)\  = \ Log \((z)\)\)]],
  ",  however, the singularity at  ",
  Cell[BoxData[
      \(z = 0\)]],
  "  (or at any point of the negative real axis) that is not isolated, \
because any neighborhood of  contains points on the negative real axis, and  \
",
  Cell[BoxData[
      \(g \((z)\)\  = \ Log \((z)\)\)]],
  "  is not analytic at those points.  Functions with isolated singularities \
have a Laurent series because the punctured disk   ",
  Cell[BoxData[
      \(\(D\_R\%*\) \((\[Alpha])\)\)]],
  "  is the same as the annulus  ",
  Cell[BoxData[
      \(A \((\[Alpha], 0, R)\)\)]],
  ".  The logarithm function  ",
  Cell[BoxData[
      \(g \((z)\)\  = \ Log \((z)\)\)]],
  "  does ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " have a ",
  StyleBox[ButtonBox["Laurent",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Laurent_\
Pierre.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " series at any point  ",
  Cell[BoxData[
      \(z = \(-a\)\)]],
  "  on the negative real-axis.  We now look at this special case of \
Laurent's theorem in order to classify three types of isolated singularities. \
"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Definition 7.5 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Removable Singularity",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RemovableSingularity.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[", ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Pole of order k",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Pole.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[", ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Essential Singularity",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/EssentialSingularity.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " Let ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " have an isolated singularity at  ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  "  with Laurent series expansion  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\  = \ \[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity]\( 
                c\_n\) \((z - \[Alpha])\)\^n\)]],
  "    valid for    ",
  Cell[BoxData[
      \(z \[Element] A \((\[Alpha], 0, R)\)\)]],
  ".  \n\nThen we distinguish the following types of singularities at  ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  ".  \n\n",
  StyleBox["(i)",
    FontColor->RGBColor[0, 0, 1]],
  "  \tIf  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(c\_n\), "=", 
          RowBox[{
            RowBox[{"0", "  ", 
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "n"}], "=", \(-1\)}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(-2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(-3\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  ",  then we say that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has a ",
  StyleBox[ButtonBox["removable singularity",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RemovableSingularity.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " at  ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  ".  \n\n",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  "  \tIf ",
  StyleBox["k",
    FontFamily->"Courier"],
  " is a positive integer such that  ",
  Cell[BoxData[
      \(c\_\(-k\) \[NotEqual] 0\)]],
  "  but ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(c\_n\), "=", 
          RowBox[{
            RowBox[{"0", 
              StyleBox[
                RowBox[{"  ", 
                  StyleBox["  ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]], 
              StyleBox["for",
                FontFamily->"Times New Roman"], 
              StyleBox[
                RowBox[{
                  StyleBox["  ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "  "}]], "n"}], 
            "=", \(\(-k\) - 1\)}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\(-k\) - 2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\(-k\) - 3\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  ",  then we say that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has a ",
  StyleBox[ButtonBox["pole of order k",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Pole.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " at ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  ".  \n\n",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  "  \tIf ",
  Cell[BoxData[
      \(c\_n \[NotEqual] 0\)]],
  " for infinitely many negative integers ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ", then we say that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has an",
  StyleBox[" ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["essential singularity",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/EssentialSingularity.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " at  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ".  "
}], "Text"],

Cell["\<\
\tLet's investigate some examples of these three cases.\
\>", "Text"],

Cell[TextData[{
  StyleBox["(i).",
    FontColor->RGBColor[0, 0, 1]],
  "  If ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has a removable singularity at ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ", then it has a Laurent series  \n\n\t\t",
  Cell[BoxData[
      \(f \((z)\)\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                c\_n\) \((z - \[Alpha])\)\^n\)]],
  "    valid for    ",
  Cell[BoxData[
      \(z \[Element] A \((\[Alpha], 0, R)\)\)]],
  ".  \n\n\tTheorem 4.17 implies that the power series for ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " defines an analytic function in the disk  ",
  Cell[BoxData[
      \(\(D\_R\) \((\[Alpha])\)\)]],
  ".  \n\tIf we use this series to define  ",
  Cell[BoxData[
      \(f \((\[Alpha])\) = c\_0\)]],
  ",  then the function ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " becomes analytic at ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ", removing the singularity.  "
}], "Text"],

Cell[TextData[{
  "\tFor example, consider the function  ",
  Cell[BoxData[
      \(f \((z)\) = \(sin \((z)\)\)\/z\)],
    AspectRatioFixed->True],
  ".  It is undefined at ",
  Cell[BoxData[
      \(z = 0\)]],
  " and has an isolated singularity at ",
  Cell[BoxData[
      \(z = 0\)]],
  ", as the Laurent series for ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\ \  = \ \ \(1\/z\) \((z - z\^3\/\(3!\) + z\^5\/\(5!\) - 
                z\^7\/\(7!\) + z\^9\/\(9!\) - 
                z\^11\/\(11!\) +  ... )\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1 - z\^2\/\(3!\) + 
            z\^4\/\(5!\) - z\^6\/\(7!\) + z\^8\/\(9!\) - 
            z\^10\/\(11!\) +  ... \)\)\)}]],
  "  \n\nvalid for ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(0\)\)\)\)]],
  ".  \n\nWe can remove this singularity if we define  ",
  Cell[BoxData[
      \(f \((0)\) = 1\)]],
  ",  for then ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " will be analytic at ",
  Cell[BoxData[
      \(z = 0\)]],
  " in accordance with Theorem 4.17.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = Sin[z]\/z\)]],
  " and find the first few terms of the Laurent series in the punctured plane \
 ",
  Cell[BoxData[
      \(0 < z\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, lim, S];\)\ \), "\n", 
    \(\(f[z_] = Sin[z]\/z;\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        Normal[Series[f[z], {z, 0, 13}]];\)\ \), "\[IndentingNewLine]", 
    \(\(lim = Limit[f[z], z \[Rule] 0];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[0] = \>", f[0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<S[z] = \>", S[z]];\)\ \), "\n", 
    \(\(Print["\<S[0] = \>", S[0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<From calculus we know that\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] 0\)\) \>\"", f[x], "\< = \>", 
        Limit[f[x], x \[Rule] 0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Extending to the complex plane, we have\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", S[z], "\< + ...\>"];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(z \[Rule] 0\)\) \>\"", f[z], "\< = \>", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The Laurent series for f(z) contains only positive powers of z. Hence,  ",
  Cell[BoxData[
      \(f[z] = Sin[z]\/z\)]],
  "  has a removable singularity at the origin.\n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[z], S[z]}, {z, \(-7\), 7}, 
        PlotStyle \[Rule] {Red, 
            Blue}, \[IndentingNewLine]PlotRange \[Rule] {{\(-7\), 
              7}, {\(-0.25\), 
              1.05}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-7\), 7, 1], 
            Range[0, 1, 1\/2]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The function  f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print["\<and series\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[x] = \>", S[x]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate the real and imaginary parts of  ",
  Cell[BoxData[
      \(f[z] = Sin[z]\/z\)]],
  " near the removable singularity."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(u[x_, y_] = 
        Together[
          ComplexExpand[Re[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, Re}]];\)\ \), "\n", 
    \(\(v[x_, y_] = 
        Together[
          ComplexExpand[Im[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, Re}]];\)\ \), "\n", 
    \(\(Plot3D[
        u[x, y], {x, \(-0.1\), 0.1}, {y, \(-0.1\), 
          0.1}, \[IndentingNewLine]PlotPoints \[Rule] 40, 
        BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<s\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        v[x, y], {x, \(-0.1\), 0.1}, {y, \(-0.1\), 
          0.1}, \[IndentingNewLine]PlotPoints \[Rule] 40, 
        BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<s\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[u[x, y], {x, \(-5\), 5}, {y, \(-5\), 5}, 
        PlotPoints \[Rule] {31, 
            31}, \[IndentingNewLine]PlotRange \[Rule] {{\(-5\), 5}, {\(-5\), 
              5}, {\(-12\), 
              15}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", "\
\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[v[x, y], {x, \(-5\), 5}, {y, \(-5\), 5}, 
        PlotPoints \[Rule] {31, 
            31}, \[IndentingNewLine]PlotRange \[Rule] {{\(-5\), 5}, {\(-5\), 
              5}, {\(-12\), 
              15}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", "\
\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        u[x, y], {x, \(-4\), 4}, {y, \(-4\), 
          4}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
        AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        v[x, y], {x, \(-4\), 4}, {y, \(-4\), 
          4}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
        AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tAnother example is  ",
  Cell[BoxData[
      \(g \((z)\) = \(cos \((z)\)\  - \ \ 1\)\/z\^2\)],
    AspectRatioFixed->True],
  ",  which has an isolated singularity at the point ",
  Cell[BoxData[
      \(z = 0\)]],
  ", as the Laurent series for ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " is \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(g \((z)\)\ \  = \ \ \(1\/z\^2\) \((\(-\(z\^2\/\(2!\)\)\) + 
                z\^4\/\(4!\) - z\^6\/\(6!\) + z\^8\/\(8!\) - 
                z\^10\/\(10!\) +  ... )\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(-\(1\/\(2!\)\)\) + 
            z\^2\/\(4!\) - z\^4\/\(6!\) + z\^6\/\(8!\) - 
            z\^8\/\(10!\) +  ... \)\)\)}]],
  " \n\nvalid for ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(0\)\)\)\)]],
  ".  If we define  ",
  Cell[BoxData[
      \(f \((0)\)\  = \ \(-\(1\/2\)\)\)]],
  ",  then ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " will be analytic for all ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \(Cos[z]\  - \ 1\)\/z\^2\)]],
  " and find the first few terms of the Laurent series in the punctured plane \
 ",
  Cell[BoxData[
      \(0 < z\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, S];\)\ \), "\n", 
    \(\(f[z_]\  = \ \(Cos[z]\  - 1\)\/z\^2;\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        Normal[Series[f[z], {z, 0, 11}]];\)\ \), "\[IndentingNewLine]", 
    \(\(lim = Limit[f[z], z \[Rule] 0];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[0] = \>", f[0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<S[z] = \>", S[z]];\)\ \), "\n", 
    \(\(Print["\<S[0] = \>", S[0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<From calculus we know that\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] 0\)\) \>\"", f[x], "\< = \>", 
        Limit[f[x], x \[Rule] 0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Extending to the complex plane, we have\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", S[z], "\< + ...\>"];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(z \[Rule] 0\)\) \>\"", f[z], "\< = \>", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The Laurent series for f(z) contains only positive powers of z. Hence,  ",
  Cell[BoxData[
      \(f[z] = \(Cos[z]\  - \ 1\)\/z\^2\)]],
  "  has a removable singularity at the origin.\n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[z], S[z]}, {z, \(-8\), 8}, 
        PlotStyle \[Rule] {Red, 
            Blue}, \[IndentingNewLine]PlotRange \[Rule] {{\(-8\), 
              8}, {\(-0.55\), 
              0.15}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-8\), 8, 2], 
            Range[\(-0.5\), 0, 0.25]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The function  f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print["\<and series\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[x] = \>", S[x]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate the real and imaginary parts of  ",
  Cell[BoxData[
      \(f[z] = \(Cos[z]\  - \ 1\)\/z\^2\)]],
  " near the removable singularity."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(u[x_, y_] = 
        FullSimplify[
          ComplexExpand[Re[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, Re}]];\)\ \), "\n", 
    \(\(v[x_, y_] = 
        FullSimplify[
          ComplexExpand[Im[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, Re}]];\)\ \), "\n", 
    \(\(Plot3D[
        u[x, y], {x, \(-0.1\), 0.1}, {y, \(-0.1\), 
          0.1}, \[IndentingNewLine]PlotPoints \[Rule] 40, 
        BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<s\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        v[x, y], {x, \(-0.1\), 0.1}, {y, \(-0.1\), 
          0.1}, \[IndentingNewLine]PlotPoints \[Rule] 40, 
        BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<s\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[u[x, y], {x, \(-5\), 5}, {y, \(-5\), 5}, 
        PlotPoints \[Rule] {31, 
            31}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[v[x, y], {x, \(-5\), 5}, {y, \(-5\), 5}, 
        PlotPoints \[Rule] {31, 
            31}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        u[x, y], {x, \(-5\), 5}, {y, \(-5\), 
          5}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
        AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        v[x, y], {x, \(-5\), 5}, {y, \(-5\), 
          5}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
        AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["(ii).",
    FontColor->RGBColor[0, 0, 1]],
  "  If ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has a pole of order",
  " ",
  StyleBox["k",
    FontFamily->"Courier"],
  " ",
  "at ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ", the Laurent series for ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is \n\n\t\t",
  Cell[BoxData[
      \(f \((z)\)\  = \ \[Sum]\+\(n = \(-k\)\)\%\[Infinity]\( 
                c\_n\) \((z - \[Alpha])\)\^n\)]],
  "    valid for    ",
  Cell[BoxData[
      \(z \[Element] A \((\[Alpha], 0, R)\)\)]],
  ".  \n\nwhere  ",
  Cell[BoxData[
      \(c\_\(-k\) \[NotEqual] 0\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " The following example will help this concept.  Consider the function  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ cot\ z\)]],
  ".  The leading term in the Laurent series expansion  ",
  StyleBox["S(z)",
    FontFamily->"Courier New"],
  "  is  ",
  Cell[BoxData[
      \(1\/z\)]],
  "  and  ",
  StyleBox["S(z)",
    FontFamily->"Courier New"],
  "  goes to ",
  Cell[BoxData[
      \(\[Infinity]\ \ as\ \ z \[Rule] 0\)]],
  " in the same manner as  ",
  Cell[BoxData[
      \(cot\ z\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15625 0.309017 0.0309017 [
[.00913 .29652 -8.3125 -12.5625 ]
[.00913 .29652 8.3125 0 ]
[.25456 .29652 -11.4063 -18.1875 ]
[.25456 .29652 11.4063 0 ]
[.74544 .29652 -8.09375 -18.1875 ]
[.74544 .29652 8.09375 0 ]
[.99087 .29652 -5 -12.5625 ]
[.99087 .29652 5 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .46353 -6 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .61803 -12 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00913 .30902 m
.00913 .31527 L
s
gsave
.00913 .29652 -69.3125 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.625 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.25456 .30902 m
.25456 .31527 L
s
gsave
.25456 .29652 -72.4063 -22.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.1875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 15.125 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.688 9.313 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
71.375 15.125 moveto
(\\200\\200) show
75.625 15.125 moveto
(\\200) show
77.688 15.125 moveto
(\\200) show
72.688 21.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.74544 .30902 m
.74544 .31527 L
s
gsave
.74544 .29652 -69.0938 -22.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.1875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 9.313 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.750 15.125 moveto
(\\200\\200) show
69.000 15.125 moveto
(\\200) show
71.063 15.125 moveto
(\\200) show
66.063 21.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.99087 .30902 m
.99087 .31527 L
s
gsave
.99087 .29652 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-5)] .4875 .15451 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(5)] .4875 .46353 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(10)] .4875 .61803 1 0 Mshowa
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.51566 .61803 m
.51635 .60332 L
.51884 .5641 L
.52115 .53593 L
.52394 .50912 L
.52657 .48898 L
.53149 .46028 L
.53678 .43785 L
.54251 .41979 L
.55262 .39729 L
.55771 .38885 L
.5633 .38108 L
.57402 .3693 L
.58379 .36101 L
.60351 .34863 L
.62371 .33953 L
.64314 .33274 L
.66382 .32681 L
.68373 .3219 L
.70286 .31765 L
.72324 .31344 L
.74286 .30953 L
.76371 .30539 L
.7838 .30127 L
.80312 .29706 L
.82368 .2921 L
.84348 .28661 L
.86451 .27952 L
.88478 .27072 L
.90428 .25908 L
.91436 .25104 L
.92503 .24008 L
.93495 .2264 L
.94423 .20858 L
.94951 .19502 L
.95452 .17861 L
.95902 .15956 L
.96392 .13168 L
.9666 .11174 L
.96912 .08853 L
.97141 .06226 L
.97383 .02692 L
.97509 .00422 L
s
.97509 .00422 m
.97528 0 L
s
0 0 1 r
.51566 .61803 m
.51635 .60332 L
.51884 .5641 L
.52115 .53593 L
.52394 .50912 L
.52657 .48898 L
.53149 .46028 L
.53678 .43785 L
.54251 .41979 L
.55262 .39729 L
.55771 .38885 L
.5633 .38108 L
.57402 .3693 L
.58379 .36101 L
.60351 .34863 L
.62371 .33953 L
.64314 .33274 L
.66382 .32681 L
.68373 .3219 L
.70286 .31765 L
.72324 .31344 L
.74286 .30953 L
.76371 .30539 L
.7838 .30128 L
.80312 .29708 L
.82368 .29217 L
.84348 .28679 L
.86451 .28003 L
.88478 .27205 L
.90428 .26241 L
.92503 .24914 L
.945 .23215 L
.96421 .21023 L
.98437 .17887 L
s
1 0 0 r
.02476 .61803 m
.02516 .6091 L
.0277 .5678 L
.03039 .53473 L
.03521 .4924 L
.03774 .47587 L
.04046 .46104 L
.04538 .43982 L
.05122 .42093 L
.05657 .40764 L
.0662 .38983 L
.0767 .37596 L
.08668 .36608 L
.09731 .35783 L
.11839 .34576 L
.1387 .33732 L
.15824 .33091 L
.17903 .32524 L
.19905 .32048 L
.2183 .31632 L
.23879 .31215 L
.25852 .30824 L
.27948 .30405 L
.29968 .29984 L
.31912 .29547 L
.33979 .29026 L
.3597 .28439 L
.37883 .2775 L
.39921 .26795 L
.41883 .25498 L
.42899 .24577 L
.43968 .23298 L
.44452 .22567 L
.44969 .21638 L
.459 .19396 L
.4642 .17653 L
.46693 .1652 L
.46982 .151 L
.47236 .13619 L
.47514 .11644 L
.47765 .09442 L
.48004 .06843 L
.48226 .03805 L
s
.48226 .03805 m
.48439 0 L
s
0 0 1 r
.01563 .43916 m
.03521 .40857 L
.05657 .38436 L
.07663 .36769 L
.09593 .35551 L
.11646 .34544 L
.13623 .33774 L
.15724 .33104 L
.17748 .32557 L
.19696 .32093 L
.21767 .31644 L
.23762 .31238 L
.2568 .30857 L
.27723 .3045 L
.29688 .30044 L
.31778 .29578 L
.33791 .29077 L
.35727 .28516 L
.37788 .27788 L
.39772 .26875 L
.40784 .26284 L
.4188 .25501 L
.42938 .24537 L
.43911 .23378 L
.44865 .21839 L
.45407 .20694 L
.45913 .19359 L
.46443 .17564 L
.46944 .15301 L
.47395 .12538 L
.4765 .10514 L
.47885 .0821 L
.48116 .05394 L
.48365 .01471 L
s
.48365 .01471 m
.48435 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00PP3oool500000080oooo0P00002E0?ooo`00Q03oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0TP3oool008@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`03000000000?l0oooo00<0oooo0P00001o0?ooo`030?l0003oool0oooo00/0
oooo001l0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000000o`3o
ool00`3oool00`000000oooo0?ooo`1n0?ooo`030?l0003oool0oooo00/0oooo00240?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000003o0?ooo`030?ooo`030000003oool0oooo07h0
oooo00<0o`000?ooo`3oool02`3oool008<0oooo0P0000040?ooo`80000000<0oooo0000o`3oool0
0`3oool00`000000oooo0?ooo`1n0?ooo`030?l0003oool0oooo00/0oooo002<0?ooo`030000o`3o
ool0oooo0080oooo00<000000?ooo`3oool0O@3oool00`3o0000oooo0?ooo`0<0?ooo`00S03oool0
0`000?l0oooo0?ooo`020?ooo`030000003oool0oooo07d0oooo00<0o`000?ooo`3oool0303oool0
08`0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`1m0?ooo`030?l0003oool0oooo
00`0oooo002<0?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`3oool0O@3oool00`3o0000
oooo0?ooo`0<0?ooo`00S03oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo07d0oooo
00<0o`000?ooo`3oool0303oool008`0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?oo
o`1m0?ooo`030?l0003oool0oooo00`0oooo002<0?ooo`030000o`3oool0oooo0080oooo00<00000
0?ooo`3oool0O@3oool00`3o0000oooo0?ooo`0<0?ooo`00S03oool00`000?l0oooo0?ooo`020?oo
o`030000003oool0oooo07d0oooo00<0o`000?ooo`3oool0303oool008`0oooo00<0003o0?ooo`3o
ool00P3oool00`000000oooo0?ooo`1m0?ooo`030?l0003oool0oooo00`0oooo002<0?ooo`030000
o`3oool0oooo0080oooo00<000000?ooo`3oool0O@3oool00`3o0000oooo0?ooo`0<0?ooo`00S03o
ool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo07d0oooo00<0o`000?ooo`3oool0303o
ool008/0oooo00<0o`000000o`3oool00`3oool00`000000oooo0?ooo`1m0?ooo`030?l0003oool0
oooo00`0oooo002;0?ooo`030?l000000?l0oooo00<0oooo00<000000?ooo`3oool0O@3oool00`3o
0000oooo0?ooo`0<0?ooo`00R`3oool00`3o0000003o0?ooo`030?ooo`030000003oool0oooo07d0
oooo00<0o`000?ooo`3oool0303oool008/0oooo00<0o`000000o`3oool00`3oool00`000000oooo
0?ooo`1m0?ooo`030?l0003oool0oooo00`0oooo002;0?ooo`030000o`3oool0oooo00<0oooo00<0
00000?ooo`3oool0O@3oool00`3o0000oooo0?ooo`0<0?ooo`00R`3oool00`000?l0oooo0?ooo`03
0?ooo`030000003oool0oooo07d0oooo00<0o`000?ooo`3oool0303oool008/0oooo00<0003o0?oo
o`3oool00`3oool00`000000oooo0?ooo`1l0?ooo`030?l0003oool0oooo00d0oooo002;0?ooo`03
0000o`3oool0oooo00<0oooo00<000000?ooo`3oool0O03oool00`3o0000oooo0?ooo`0=0?ooo`00
R`3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo07`0oooo00<0o`000?ooo`3oool0
3@3oool008/0oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`1l0?ooo`030?l0003o
ool0oooo00d0oooo002;0?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool0O03oool0
0`3o0000oooo0?ooo`0=0?ooo`00RP3oool00`000?l0o`000?ooo`040?ooo`030000003oool0oooo
07`0oooo00<0o`000?ooo`3oool03@3oool008X0oooo00<0003o0?l0003oool0103oool00`000000
oooo0?ooo`1k0?ooo`030?l0003oool0oooo00h0oooo002:0?ooo`030000o`3o0000oooo00@0oooo
00<000000?ooo`3oool0N`3oool00`3o0000oooo0?ooo`0>0?ooo`00RP3oool00`000?l0oooo0?oo
o`040?ooo`030000003oool0oooo07/0oooo00<0o`000?ooo`3oool03P3oool008X0oooo00<0003o
0?ooo`3oool0103oool00`000000oooo0?ooo`1k0?ooo`030?l0003oool0oooo00h0oooo002:0?oo
o`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool0N`3oool00`3o0000oooo0?ooo`0>0?oo
o`00RP3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo07/0oooo00<0o`000?ooo`3o
ool03P3oool008X0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`1k0?ooo`030?l0
003oool0oooo00h0oooo002:0?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool0N`3o
ool00`3o0000oooo0?ooo`0>0?ooo`00R@3oool00`3o0000003o0?ooo`050?ooo`030000003oool0
oooo07/0oooo00<0o`000?ooo`3oool03P3oool008T0oooo00<0003o0?ooo`3oool01@3oool00`00
0000oooo0?ooo`1k0?ooo`030?l0003oool0oooo00h0oooo00290?ooo`030000o`3oool0oooo00D0
oooo00<000000?ooo`3oool0N`3oool00`3o0000oooo0?ooo`0>0?ooo`00R@3oool00`000?l0oooo
0?ooo`050?ooo`030000003oool0oooo07X0oooo00<0o`000?ooo`3oool03`3oool008P0oooo00<0
o`000000o`3oool01P3oool00`000000oooo0?ooo`1j0?ooo`030?l0003oool0oooo00l0oooo0028
0?ooo`030000o`000000000000H0oooo00<000000?ooo`3oool0NP3oool00`3o0000oooo0?ooo`0?
0?ooo`00R03oool010000?l0oooo0?ooo`0000050?ooo`030000003oool0oooo07X0oooo00<0o`00
0?ooo`3oool03`3oool008P0oooo00@0003o0?ooo`3oool000001@3oool2000007X0oooo00<0o`00
0?ooo`3oool0403oool00880oooo100000020?ooo`030000o`000000000000H0oooo00<000000?oo
o`3oool0N@3oool00`3o0000oooo0?ooo`0@0?ooo`00R03oool00`000?l000000?ooo`060?ooo`03
0000003oool0oooo07T0oooo00<0o`000?ooo`3oool0403oool008L0oooo00<0003o0?l000000000
0P0000050?ooo`030000003oool0oooo07T0oooo00<0o`000?ooo`3oool0403oool008L0oooo00<0
003o0?l0003oool01`3oool00`000000oooo0?ooo`1h0?ooo`030?l0003oool0oooo0140oooo0027
0?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3oool0N03oool00`3o0000oooo0?ooo`0A
0?ooo`00Q`3oool00`000?l0oooo0?ooo`070?ooo`030000003oool0oooo07P0oooo00<0o`000?oo
o`3oool04@3oool008L0oooo00<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`1h0?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool02@3oool008L0oooo00<0003o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`1h0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
2P3oool008H0oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`1g0?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool02P3oool008H0oooo00<0003o0?ooo`3oool0203oool0
0`000000oooo0?ooo`1g0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool0
08H0oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`1g0?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool0303oool008D0oooo00<0003o0?ooo`3oool02@3oool00`000000
oooo0?ooo`1f0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0303oool008D0oooo
00<0003o0?ooo`3oool02@3oool00`000000oooo0?ooo`1f0?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool03@3oool008@0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?oo
o`1e0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool03@3oool008@0oooo00<0003o
0?ooo`3oool02P3oool00`000000oooo0?ooo`1e0?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool03P3oool008<0oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`1e0?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool03`3oool008<0oooo00<0003o0?ooo`3o
ool02`3oool00`000000oooo0?ooo`1d0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool0403oool00880oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`1d0?ooo`050?l0
003oool0oooo0?ooo`000?l04`3oool00880oooo00<0003o0?ooo`3oool0303oool00`000000oooo
0?ooo`1c0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool04@3oool00840oooo00<0
003o0?ooo`3oool03@3oool00`000000oooo0?ooo`1c0?ooo`050?l0003oool0oooo0?ooo`000?l0
503oool00800oooo00<0o`000000o`3oool03P3oool00`000000oooo0?ooo`1b0?ooo`050?l0003o
ool0oooo0?ooo`000?l05@3oool004l0oooo1000000/0?ooo`030?l000000?l0oooo00l0oooo00<0
00000?ooo`3oool0?@3oool400000300oooo00D0o`000?ooo`3oool0oooo0000o`0F0?ooo`00C`3o
ool00`000000oooo0?ooo`0/0?ooo`030?l000000?l0oooo0100oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0`0?ooo`050?l0003oool0oooo0?ooo`000?l05`3oool00500oooo00<0
00000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`020000oaP0oooo001A0?ooo`030000003oool0
oooo02T0oooo00<0003o0?ooo`3oool04@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo02`0oooo00@0o`000?ooo`3oool0003o6P3oool004l0oooo00@000000?ooo`3oool00000:@3o
ool00`000?l0oooo0?ooo`0B0?ooo`030000003oool0oooo03d0oooo00@000000?ooo`3oool00000
;03oool0103o0000oooo0?ooo`000?lK0?ooo`00D03oool2000002T0oooo00<0003o0?ooo`3oool0
4`3oool00`000000oooo0?ooo`0n0?ooo`800000;03oool0103o0000oooo0000o`000?lL0?ooo`00
N@3oool20000oaH0oooo00<000000?ooo`3oool0J`3oool00`3o0000003o0000o`0N0?ooo`00N03o
ool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo06T0oooo0P3o00000`000?l0oooo0?oo
o`0N0?ooo`00AP3oool4000000<0oooo2000000Q0?ooo`80003o6@3oool00`000000oooo0?ooo`0k
0?ooo`P000009@3oool00`3o0000003o0000o`0Q0?ooo`00303oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0600oooo00<0o`000000o`3oool06P3oool00`000000oooo0?ooo`1V0?oo
o`030?l000000?l0003o01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`001P3oool4000000<0oooo00@000000?ooo`3oool00000H@3oool00`3o0000003o0000o`0L0?oo
o`030000003oool0oooo06@0oooo0`000?lI0?ooo`040000003oool0oooo000000P0oooo000>0?oo
o`030000003oool0000005h0oooo0P3o00020000oah0oooo00<000000?ooo`3oool0HP3oool20000
oad0oooo00<000000?ooo`000000203oool000h0oooo00<000000?ooo`000000?@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00@0o`000000o`000?l0003o803oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool30000
oal0oooo00<000000?ooo`000000203oool000d0oooo1@00000m0?ooo`040000003oool0oooo0000
01L0oooo0P3o00020000ob<0oooo00<000000?ooo`3oool0?@3oool010000000oooo0?ooo`00000K
0?ooo`<0003o8@3oool5000000L0oooo001@0?ooo`030000003oool0000001@0oooo00<0o`000000
o`000?l00P000?lU0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`0000005`3oool40000
oc00oooo001@0?ooo`030000003oool000000100oooo1@000?lY0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`0000004`3oool40000oc@0oooo001?0?ooo`D000002P3oool50000obh0oooo
00<000000?ooo`3oool0?@3oool5000000l0oooo0`000?lh0?ooo`00F`3oool30000o`030?l0003o
ool0oooo0300oooo00<000000?ooo`3oool0C@3oool40000oc/0oooo001G0?ooo`@0003o00<0o`00
0?ooo`3oool0<`3oool00`000000oooo0?ooo`180?ooo`D0003o?`3oool00580oooo1@000?l00`3o
0000oooo0?ooo`0g0?ooo`030000003oool0oooo0480oooo1P000?m40?ooo`002@3ooom4000000D0
003o00<0o`00000000000000O00000050000od@000001P3oool000/0oooo00<000000?ooo`3oool0
>@3oool60000o`030?ooo`000000oooo0440oooo00<000000?ooo`3oool0=`3oool60000o`80oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`070?ooo`002`3oool00`000000oooo0?oo
o`0d0?ooo`D0003o00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo03<0oooo10000?l80?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool01`3o
ool003d0oooo1@000?m?0?ooo`030000003oool0oooo0340oooo0P000?mI0?ooo`00>03oool30?l0
0080003oE03oool00`000000oooo0?ooo`0]0?ooo`@0003oF`3oool003H0oooo00<0o`000000o`00
0?l00P000?mF0?ooo`030000003oool0oooo02L0oooo1P000?mO0?ooo`00<`3oool40000oeX0oooo
00<000000?ooo`3oool08`3oool40000ofD0oooo000`0?ooo`<0003oGP3oool00`000000oooo0?oo
o`0P0?ooo`<0003oJ@3oool002d0oooo0`000?mQ0?ooo`030000003oool0oooo01h0oooo0P000?m/
0?ooo`00:P3oool30000of@0oooo00<000000?ooo`3oool0703oool20000ofh0oooo000X0?ooo`80
003o00<0o`000?ooo`3oool0I03oool00`000000oooo0?ooo`0J0?ooo`80003oL03oool002H0oooo
0P000?l00`3o0000oooo0?ooo`1V0?ooo`030000003oool0oooo01T0oooo00<0003o0?ooo`3oool0
L03oool002@0oooo0P000?l00`3o0000oooo0?ooo`1X0?ooo`030000003oool0oooo01L0oooo0P00
0?mc0?ooo`008`3oool00`000?l0o`000?ooo`1[0?ooo`030000003oool0oooo01D0oooo0P000?me
0?ooo`008@3oool20000ofh0oooo00<000000?ooo`3oool04`3oool20000ogL0oooo000O0?ooo`80
003o00<0o`000?ooo`3oool0K@3oool00`000000oooo0?ooo`0B0?ooo`030000o`3oool0oooo07L0
oooo000N0?ooo`030000o`3oool0o`000700oooo00<000000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`1h0?ooo`007@3oool00`000?l0oooo0?l0001a0?ooo`030000003oool0oooo0100oooo00<0
003o0?ooo`3oool0N@3oool001`0oooo00<0003o0?ooo`3o0000LP3oool00`000000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo07X0oooo000J0?ooo`80003o00<0oooo0?l0003oool0LP3oool00`00
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo07X0oooo000I0?ooo`040000o`3oool0oooo0?l0
07@0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`1k0?ooo`00603oool01@000?l0
oooo0?ooo`3oool0o`0007@0oooo00<000000?ooo`3oool03@3oool00`000?l0oooo0?ooo`1l0?oo
o`005`3oool01@000?l0oooo0?ooo`3oool0o`0007D0oooo00<000000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`1m0?ooo`005P3oool01@000?l0oooo0?ooo`3oool0o`0007H0oooo00<000000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`1n0?ooo`005@3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo07@0oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1n0?ooo`00
503oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo07D0oooo00<000000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`1o0?ooo`004`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo07D0oooo00<000000?ooo`3oool02P3oool00`000?l0oooo0?ooo`1o0?ooo`004P3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo07H0oooo00<000000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`200?ooo`004@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
07H0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo0?ooo`200?ooo`004@3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo07L0oooo00<000000?ooo`3oool0203oool00`000?l0
oooo0?ooo`210?ooo`00403oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo07L0oooo
00<000000?ooo`3oool0203oool00`000?l0oooo0?ooo`210?ooo`003`3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo07L0oooo00<000000?ooo`3oool0203oool00`000?l0oooo0?oo
o`210?ooo`003`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo07P0oooo00<00000
0?ooo`3oool0203oool00`000?l0oooo0?ooo`210?ooo`003P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo07P0oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`220?oo
o`003P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo07P0oooo00<000000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`220?ooo`003@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo07T0oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`220?ooo`005@3o
ool00`3o0000oooo0?ooo`1i0?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool0PP3o
ool001D0oooo00<0o`000?ooo`3oool0N@3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0
oooo08<0oooo000E0?ooo`030?l0003oool0oooo07T0oooo00<000000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`230?ooo`00503oool00`3o0000oooo0?ooo`1j0?ooo`030000003oool0oooo00H0
oooo00<0003o0?ooo`3oool0P`3oool001@0oooo00<0o`000?ooo`3oool0LP3oool2000000H0oooo
00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`240?ooo`00503oool00`3o0000oooo0?oo
o`1a0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`240?ooo`00503oool00`3o0000oooo0?ooo`1d0?ooo`030000003oool0oooo00<0oooo0P00
00060?ooo`030000o`3oool0oooo08@0oooo000C0?ooo`030?l0003oool0oooo07<0oooo0P000006
0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool0Q03oool001<0oooo00<0o`000?oo
o`3oool0L`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0003o0?oo
o`3oool0Q03oool001<0oooo00<0o`000?ooo`3oool0L`3oool3000000D0oooo00<000000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`250?ooo`004`3oool00`3o0000oooo0?ooo`1k0?ooo`030000
003oool0oooo00@0oooo00<0003o0?ooo`3oool0Q@3oool001<0oooo00<0o`000?ooo`3oool0N`3o
ool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo08D0oooo000B0?ooo`030?l0003oool0
oooo07`0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`250?ooo`004P3oool00`3o
0000oooo0?ooo`1l0?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool0Q@3oool00180
oooo00<0o`000?ooo`3oool0O03oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo08D0
oooo000B0?ooo`030?l0003oool0oooo07`0oooo00<000000?ooo`3oool0103oool00`000?l0oooo
0?ooo`250?ooo`004P3oool00`3o0000oooo0?ooo`1l0?ooo`030000003oool0oooo00<0oooo00<0
003o0?ooo`3oool0QP3oool00180oooo00<0o`000?ooo`3oool0O03oool00`000000oooo0?ooo`03
0?ooo`030000o`3oool0oooo08H0oooo000B0?ooo`030?l0003oool0oooo07`0oooo00<000000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`260?ooo`004P3oool00`3o0000oooo0?ooo`1l0?ooo`03
0000003oool0oooo00<0oooo00<0003o0?ooo`3oool0QP3oool00140oooo00<0o`000?ooo`3oool0
O@3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo08H0oooo000A0?ooo`030?l0003o
ool0oooo07d0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`260?ooo`004@3oool0
0`3o0000oooo0?ooo`1m0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0Q`3oool0
0140oooo00<0o`000?ooo`3oool0O@3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo
08L0oooo000A0?ooo`030?l0003oool0oooo07d0oooo00<000000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`270?ooo`004@3oool00`3o0000oooo0?ooo`1m0?ooo`030000003oool0oooo0080oooo
00<0003o0?ooo`3oool0Q`3oool00140oooo00<0o`000?ooo`3oool0O@3oool00`000000oooo0?oo
o`020?ooo`030000o`3oool0oooo08L0oooo000A0?ooo`030?l0003oool0oooo07d0oooo00<00000
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`270?ooo`004@3oool00`3o0000oooo0?ooo`1m0?oo
o`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0Q`3oool00140oooo00<0o`000?ooo`3o
ool0O@3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo08L0oooo000@0?ooo`030?l0
003oool0oooo07h0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`270?ooo`00403o
ool00`3o0000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0Q`3o
ool00100oooo00<0o`000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0
oooo08L0oooo000@0?ooo`030?l0003oool0oooo07h0oooo00<000000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`270?ooo`00403oool00`3o0000oooo0?ooo`1n0?ooo`030000003oool0oooo0080
oooo00<0003o0?ooo`3oool0Q`3oool00100oooo00<0o`000?ooo`3oool0OP3oool00`000000oooo
0?ooo`020?ooo`030000o`3oool0oooo08L0oooo000@0?ooo`030?l0003oool0oooo07h0oooo00<0
00000?ooo`3oool00P3oool00`000?l0oooo0?ooo`270?ooo`00403oool00`3o0000oooo0?ooo`1n
0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0Q`3oool00100oooo00<0o`000?oo
o`3oool0OP3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo08L0oooo000@0?ooo`03
0?l0003oool0oooo07h0oooo00D000000?ooo`3oool0oooo0000o`2:0?ooo`00403oool00`3o0000
oooo0?ooo`1n0?ooo`050000003oool0oooo0?ooo`000?l0RP3oool00100oooo00<0o`000?ooo`3o
ool0OP3oool01@000000oooo0?ooo`3oool0003o08X0oooo000@0?ooo`030?l0003oool0oooo07h0
oooo00D000000?ooo`3oool0oooo0000o`2:0?ooo`00403oool00`3o0000oooo0?ooo`1n0?ooo`05
0000003oool0oooo0?ooo`000?l0RP3oool00100oooo00<0o`000?ooo`3oool0OP3oool01@000000
oooo0?ooo`3oool0003o08X0oooo000@0?ooo`030?l0003oool0oooo07h0oooo00D000000?ooo`3o
ool0oooo0000o`2:0?ooo`00403oool00`3o0000oooo0?ooo`1_0?ooo`D000000P3oool2000000H0
oooo00D000000?ooo`3oool0oooo0000o`2:0?ooo`00403oool00`3o0000oooo0?ooo`1a0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`000?l0RP3oool00100oooo00<0o`000?ooo`3oool0L@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00`3oool200000080oooo00<0003o0?ooo`3oool0R03oool0
08@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0980oooo00240?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`2B0?ooo`00P`3oool20000
00@0oooo0P00002E0?ooo`00o`3ooolQ0?ooo`00\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3, -10, 0, 0}}],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, lim, S, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ Cot[z];\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        Normal[Series[f[z], {z, 0, 13}]];\)\ \), "\[IndentingNewLine]", 
    \(\(lim = Limit[f[z], z \[Rule] 0];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<S[z] = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", 
        S[z], "\< - ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(z \[Rule] 0\)\) \>\"", f[z], "\< = \>", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The Laurent series for f(z) involves only ",
  Cell[BoxData[
      \(1\/z\)]],
  " for negative powers of z. Hence, ",
  Cell[BoxData[
      \(\(\(\ \)\(f[z] = Cot[z]\)\)\)]],
  "  has a simple pole at the origin.\n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(graph1\  = \ 
        Plot[{f[z], S[z]}, {z, 0.01, 3.1}, PlotStyle \[Rule] {Red, Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(graph2\  = \ 
        Plot[{f[z], S[z]}, {z, \(-3.1\), \(-0.01\)}, 
          PlotStyle \[Rule] {Red, Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[graph1, graph2, 
        PlotRange \[Rule] {{\(-3.2\), 3.2}, {\(-10\), 10}}, 
        Ticks \[Rule] {Range[\(-\[Pi]\), \[Pi], \[Pi]\/2], 
            Range[\(-10\), 10, 5]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The function  f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print["\<and series\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[x] = \>", S[x]];\)\ \)}], "Input"],

Cell[TextData[{
  "\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate the real and imaginary parts of  f[z] = Cot[z]  near the \
pole."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(u[x_, y_] = ComplexExpand[Re[f[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(v[x_, y_] = ComplexExpand[Im[f[x + \[ImaginaryI]\ y]]];\)\ \), "\n", 
    \(\(Plot3D[u[x, y], {x, \(-0.1\), 0.1}, {y, \(-0.1\), 0.1}, 
        PlotRange \[Rule] {{\(-0.1\), 0.1}, {\(-0.1\), 0.1}, {\(-30\), 
              60}}, \[IndentingNewLine]PlotPoints \[Rule] 40, 
        BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, 
              Blue}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[v[x, y], {x, \(-0.1\), 0.1}, {y, \(-0.1\), 0.1}, 
        PlotRange \[Rule] {{\(-0.1\), 0.1}, {\(-0.1\), 0.1}, {\(-30\), 
              60}}, \[IndentingNewLine]PlotPoints \[Rule] 40, 
        BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        Re[f[x\  + \ \[ImaginaryI]\ y]], {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] {31, 
            31}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
              1}, {\(-3\), 
              5}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        Im[f[x\  + \ \[ImaginaryI]\ y]], {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] {31, 
            31}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
              1}, {\(-3\), 
              5}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(g1 = 
        ContourPlot[
          u[x, y], {x, \(-1\), \(-0.00001\)}, {y, \(-1\), 
            1}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g2 = 
        ContourPlot[
          u[x, y], {x, 0.00001, 1}, {y, \(-1\), 
            1}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[g1, g2, AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(g1 = 
        ContourPlot[
          v[x, y], {x, \(-1\), 
            1}, {y, \(-1\), \(-0.00001\)}, \[IndentingNewLine]PlotPoints \
\[Rule] 35, ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g2 = 
        ContourPlot[
          v[x, y], {x, \(-1\), 1}, {y, 0.00001, 
            1}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[g1, g2, AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tFor example,  \n\n\t\t\t",
  Cell[BoxData[{
      \(f \((z)\)\ \  = \ \ \(sin \((z)\)\)\/z\^3\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(1\/z\^3\) \((z - 
                z\^3\/\(3!\) + z\^5\/\(5!\) - z\^7\/\(7!\) + z\^9\/\(9!\) - 
                z\^11\/\(11!\) +  ... )\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1\/z\^2 - 1\/\(3!\) + 
            z\^2\/\(5!\) - z\^4\/\(7!\) + z\^6\/\(9!\) - 
            z\^10\/\(11!\) +  ... \)\)\)}],
    AspectRatioFixed->True],
  "  \n\nhas a pole of order  ",
  Cell[BoxData[
      \(k = 2\)]],
  "  at  ",
  Cell[BoxData[
      \(z = 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = Sin[z]\/z\^3\)]],
  " and find the first few terms of the Laurent series in the punctured plane \
 ",
  Cell[BoxData[
      \(0 < z\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, lim, S];\)\ \), "\n", 
    \(\(f[z_] = Sin[z]\/z\^3;\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        Normal[Series[f[z], {z, 0, 11}]];\)\ \), "\[IndentingNewLine]", 
    \(\(lim = Limit[f[z], z \[Rule] 0];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<S[z] = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", 1\/z\^2, 
        S[z] - 1\/z\^2, "\< - ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(z \[Rule] 0\)\) \>\"", f[z], "\< = \>", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The Laurent series for f(z) contains terms down to  ",
  Cell[BoxData[
      \(1\/z\^2\)]],
  "  for negative powers of z. Hence, ",
  Cell[BoxData[
      \(\(\(\ \)\(f[z] = Sin[z]\/z\^3\)\)\)]],
  " has a pole of order 2 at the origin.\n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], S[x]}, {x, \(-10\), 10}, 
        PlotStyle \[Rule] {Red, 
            Blue}, \[IndentingNewLine]PlotRange \[Rule] {{\(-10\), 10}, {0, 
              10}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-10\), 10, 2], 
            Range[0, 10, 5]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The function  f[x] = \>", 
        f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and series\>"];\)\ \), "\n", 
    \(\(Print["\<S[x] = \>", S[x]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate the real and imaginary parts of  ",
  Cell[BoxData[
      \(f[z] = Sin[z]\/z\^3\)]],
  " near the removable singularity."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(u[x_, y_] = 
        FullSimplify[
          ComplexExpand[Re[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, Re}]];\)\ \), "\n", 
    \(\(v[x_, y_] = 
        FullSimplify[
          ComplexExpand[Im[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, Re}]];\)\ \), "\n", 
    \(\(Plot3D[
        u[x, y], {x, \(-0.1\), 0.1}, {y, \(-0.1\), 
          0.1}, \[IndentingNewLine]PlotPoints \[Rule] 40, 
        BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        v[x, y], {x, \(-0.1\), 0.1}, {y, \(-0.1\), 
          0.1}, \[IndentingNewLine]PlotPoints \[Rule] 40, 
        BoxRatios \[Rule] {1, 1, 1}, 
        Mesh \[Rule] 
          False, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[u[x, y], {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] {31, 31}, 
        PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}, {\(-15\), 
              20}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", "\
\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[v[x, y], {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] {31, 31}, 
        PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}, {\(-15\), 
              20}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", "\
\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        u[x, y], {x, \(-1\), 1}, {y, \(-1\), 
          1}, \[IndentingNewLine]PlotPoints \[Rule] 55, 
        AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        v[x, y], {x, \(-1\), 1}, {y, \(-1\), 
          1}, \[IndentingNewLine]PlotPoints \[Rule] 54, 
        AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tIf",
  " ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " ",
  "has a pole of order 1 at ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ", we say that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has a simple pole at ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ".   "
}], "Text"],

Cell[TextData[{
  "\tFor example,  \n\n\t\t\t",
  Cell[BoxData[{
      \(g \((z)\)\ \  = \ \ \(\(1\/z\) \[ExponentialE]\^z\ \  = \ \ 1\/z\ \(\
\[Sum]\+\(n = 0\)\%\[Infinity]\( 1\/\(n!\)\) z\^n\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\( 1\/\(n!\)\) z\^\(n - 1\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(1\/z + 1 + z\/\(2!\) + 
            z\^2\/\(3!\) + z\^3\/\(4!\) + z\^4\/\(5!\) + 
            z\^5\/\(6!\) +  ... \)\)\)}]],
  "  \n\nhas a simple pole at  ",
  Cell[BoxData[
      \(z = 0\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \[ExponentialE]\^z\/z\)]],
  " and find the first few terms of the Laurent series in the punctured plane \
 ",
  Cell[BoxData[
      \(0 < z\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, lim, S];\)\ \), "\n", 
    \(\(f[z_]\  = \ \[ExponentialE]\^z\/z;\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        Normal[Series[f[z], {z, 0, 8}]];\)\ \), "\[IndentingNewLine]", 
    \(\(lim = Limit[f[z], z \[Rule] 0];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<S[z] = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", 
        S[z], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(z \[Rule] 0\)\) \>\"", f[z], "\< = \>", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The Laurent series for f(z) involves only ",
  Cell[BoxData[
      \(1\/z\)]],
  " for negative powers of z. Hence, ",
  Cell[BoxData[
      \(\(\(\ \)\(f[z] = \[ExponentialE]\^z\/z\)\)\)]],
  " has a simple pole at the origin.\n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(graph1\  = \ 
        Plot[{f[z], S[z]}, {z, 0.01, 6.1}, PlotStyle \[Rule] {Red, Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(graph2\  = \ 
        Plot[{f[z], S[z]}, {z, \(-6.1\), \(-0.01\)}, 
          PlotStyle \[Rule] {Red, Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[graph1, graph2, 
        PlotRange \[Rule] {{\(-6.1\), 6.1}, {\(-20\), 50}}, 
        Ticks \[Rule] {Range[\(-6\), 6, 1], Range[\(-20\), 50, 10]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The function  f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print["\<and series\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[x] = \>", S[x]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate the real and imaginary parts of  ",
  Cell[BoxData[
      \(f[z] = \[ExponentialE]\^z\/z\)],
    AspectRatioFixed->True],
  "  near the pole."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(u[x_, y_] = 
        FullSimplify[
          ComplexExpand[Re[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, Re}]];\)\ \), "\n", 
    \(\(v[x_, y_] = 
        FullSimplify[
          ComplexExpand[Im[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, Re}]];\)\ \), "\n", 
    \(\(Plot3D[
        u[x, y], {x, \(-0.1\), 0.1}, {y, \(-0.1\), 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.1\), 
              0.1}, {\(-0.1\), 0.1}, {\(-30\), 
              60}}, \[IndentingNewLine]PlotPoints \[Rule] 40, 
        BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[v[x, y], {x, \(-0.1\), 0.1}, {y, \(-0.1\), 0.1}, 
        PlotRange \[Rule] {{\(-0.1\), 0.1}, {\(-0.1\), 0.1}, {\(-30\), 
              60}}, \[IndentingNewLine]PlotPoints \[Rule] 40, 
        BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[u[x, y], {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] {31, 
            31}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
              1}, {\(-3\), 
              5}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[v[x, y], {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] {31, 
            31}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
              1}, {\(-3\), 
              5}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(g1 = 
        ContourPlot[
          u[x, y], {x, \(-1\), \(-0.00001\)}, {y, \(-1\), 
            1}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g2 = 
        ContourPlot[
          u[x, y], {x, 0.00001, 1}, {y, \(-1\), 
            1}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[g1, g2, AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(g1 = 
        ContourPlot[
          v[x, y], {x, \(-1\), 
            1}, {y, \(-1\), \(-0.00001\)}, \[IndentingNewLine]PlotPoints \
\[Rule] 35, ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g2 = 
        ContourPlot[
          v[x, y], {x, \(-1\), 1}, {y, 0.00001, 
            1}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[g1, g2, AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["(iii).",
    FontColor->RGBColor[0, 0, 1]],
  "  If infinitely many negative powers of ",
  Cell[BoxData[
      \(\((z - \[Alpha])\)\)]],
  " occur in the Laurent series, then",
  " ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " ",
  "has an essential singularity at ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ".  For example,  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\ \  = \ \ \(z\^2\) sin \((1\/z)\)\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(z\^2\) \((1\/z - \
\((1\/z)\)\^3\/\(3!\) + \((1\/z)\)\^5\/\(5!\) - \((1\/z)\)\^7\/\(7!\) + \
\((1\/z)\)\^9\/\(9!\) - \((1\/z)\)\^11\/\(11!\) +  ... )\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(z - \(1\/\(3!\)\) 
              z\^\(-1\) + \(1\/\(5!\)\) z\^3 - \(1\/\(7!\)\) 
              z\^\(-5\) + \(1\/\(9!\)\) z\^\(-7\) - \(1\/\(11!\)\) 
              z\^\(-9\) +  ... \)\)\)}],
    AspectRatioFixed->True],
  "  \n\nhas an essential singularity at the origin.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = z\^2\ Sin[1\/z]\)]],
  " and find the first few terms of the Laurent series in the punctured plane \
 ",
  Cell[BoxData[
      \(\(\(0\)\(<\)\) | z | \)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[g, h, p, S];\)\ \), "\n", 
    \(\(g[z_]\  = \ Sin[z];\)\ \), "\n", 
    \(\(S[z_]\  = \ Normal[Series[Sin[z], {z, 0, 17}]];\)\ \), "\n", 
    \(\(h[z_]\  = \ S[1\/z];\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^2\ g[1\/z];\)\ \), "\n", 
    \(\(p[z_]\  = \ Simplify[z\^2\ h[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(lim0 = 
        Limit[f[z], z \[Rule] 0, 
          Direction \[Rule] \(-1\)];\)\ \), "\[IndentingNewLine]", 
    \(\(lim1 = 
        Limit[f[z], z \[Rule] 0, 
          Direction \[Rule] \(-\[ImaginaryI]\)];\)\ \), \
"\[IndentingNewLine]", 
    \(\(lim2 = 
        Limit[f[z], z \[Rule] 0, 
          Direction \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(lim3 = 
        Limit[f[z], z \[Rule] 0, 
          Direction \[Rule] \[ImaginaryI]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<p[z] = \>", p[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = ... + \>", p[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(z \[Rule] \(0\^+\)\)\) \>\"", 
        f[z], "\< = \>", lim0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(z \[Rule] \(\[ImaginaryI]0\^+\)\)\) \>\"", 
        f[z], "\< = \>", lim1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(z \[Rule] \(0\^-\)\)\) \>\"", 
        f[z], "\< = \>", lim2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(z \[Rule] \(\[ImaginaryI]0\^-\)\)\) \>\"", 
        f[z], "\< = \>", lim3];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The Laurent series for f(z) has \"infinitely many\" negative powers of z. \
Hence, ",
  Cell[BoxData[
      \(f \((z)\) = z\^2\ sin \((1\/z)\)\)]],
  " has an essential singularity at the origin. \n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(graph1\  = \ 
        Plot[{f[z], p[z]}, {z, 0.0001, 0.5}, PlotStyle \[Rule] {Red, Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(graph2\  = \ 
        Plot[{f[z], p[z]}, {z, \(-0.5\), \(-0.0001\)}, 
          PlotStyle \[Rule] {Red, Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[graph1, graph2, 
        PlotRange \[Rule] {{\(-0.5\), 0.5}, {\(-0.1\), 0.1}}, 
        Ticks \[Rule] {Range[\(-0.5\), 0.5, 0.5], Range[\(-0.1\), 0.1, 0.1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The function  f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print["\<and series\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[x] = \>", p[x]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate the real and imaginary parts of  ",
  Cell[BoxData[
      \(f[z] = \[ExponentialE]\^z\/z\)],
    AspectRatioFixed->True],
  "  near the pole."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(u[x_, y_] = 
        FullSimplify[
          ComplexExpand[Re[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, Re}]];\)\ \), "\n", 
    \(\(v[x_, y_] = 
        FullSimplify[
          ComplexExpand[Im[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, Re}]];\)\ \), "\n", 
    \(\(Plot3D[
        u[x, y], {x, \(-0.1\), 0.1}, {y, \(-0.1\), 
          0.1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.1\), 
              0.1}, {\(-0.1\), 0.1}, {\(-30\), 
              60}}, \[IndentingNewLine]PlotPoints \[Rule] 40, 
        BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[v[x, y], {x, \(-0.1\), 0.1}, {y, \(-0.1\), 0.1}, 
        PlotRange \[Rule] {{\(-0.1\), 0.1}, {\(-0.1\), 0.1}, {\(-30\), 
              60}}, \[IndentingNewLine]PlotPoints \[Rule] 40, 
        BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        Re[f[x\  + \ \[ImaginaryI]\ y]], {x, \(-0.1\), 
          0.099999}, {y, \(-0.1\), 
          0.099999}, \[IndentingNewLine]PlotPoints \[Rule] {41, 41}, 
        PlotRange \[Rule] {{\(-0.1\), 0.1}, {\(-0.1\), 0.1}, {\(-5\), 
              5}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        Im[f[x\  + \ \[ImaginaryI]\ y]], {x, \(-0.1\), 
          0.099999}, {y, \(-0.1\), 
          0.099999}, \[IndentingNewLine]PlotPoints \[Rule] {41, 
            41}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.1\), 
              0.1}, {\(-0.1\), 0.1}, {\(-5\), 
              5}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(g1 = 
        ContourPlot[
          u[x, y], {x, \(-0.5\), \(-0.00001\)}, {y, \(-0.5\), 
            0.5}, \[IndentingNewLine]PlotPoints \[Rule] 55, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g2 = 
        ContourPlot[
          Re[f[x\  + \ \[ImaginaryI]\ y]], {x, 0.00001, 0.5}, {y, \(-0.5\), 
            0.5}, \[IndentingNewLine]PlotPoints \[Rule] 55, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[g1, g2, 
        PlotRange \[Rule] {{\(-0.52\), 0.52}, {\(-0.52\), 0.52}}, 
        AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(g1 = 
        ContourPlot[
          v[x, y], {x, \(-0.5\), \(-0.00001\)}, {y, \(-0.5\), 
            0.5}, \[IndentingNewLine]PlotPoints \[Rule] 55, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g2 = 
        ContourPlot[
          Im[f[x\  + \ \[ImaginaryI]\ y]], {x, 0.00001, 0.5}, {y, \(-0.5\), 
            0.5}, \[IndentingNewLine]PlotPoints \[Rule] 55, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[g1, g2, 
        PlotRange \[Rule] {{\(-0.52\), 0.52}, {\(-0.52\), 0.52}}, 
        AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Definition 7.6 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Zero of order k",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Multiplicity.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  A function",
  " ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " ",
  "analytic in  ",
  Cell[BoxData[
      \(\(D\_r\) \((\[Alpha])\)\)]],
  "  has a ",
  ButtonBox["zero of order k",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Multiplicity.html"], None},
    ButtonStyle->"Hyperlink"],
  " at the point  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  "  if and only if  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(\(f\^\((n)\)\) \((\[Alpha])\) = \(0\ \ for\ \ n = 0\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(k - 1\)}]]],
  ",  and  ",
  Cell[BoxData[
      \(\(f\^\((k)\)\) \((\[Alpha])\) \[NotEqual] 0\)]],
  ".\n\nA zero of order one is sometimes called a simple zero.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 7.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  A function ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " analytic in ",
  Cell[BoxData[
      \(\(D\_R\) \((\[Alpha])\)\)]],
  " has a zero of order ",
  StyleBox["k",
    FontFamily->"Courier"],
  " at the point ",
  Cell[BoxData[
      \(\(\(\ \)\(z = \[Alpha]\)\)\)]],
  "  iff its Taylor series given by ",
  Cell[BoxData[
      \(f \((z)\) = \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                c\_n\) \((z - \[Alpha])\)\^n\)]],
  " has \n\n\t\t\t",
  Cell[BoxData[
      \(c\_0\  = \ \(c\_1\  = \ \(\(...\)\(=\)\(\ \)\(c\_\(k - 1\)\  = \ 
              0\ \ \ and\ \ \ c\_k \[NotEqual] 0\)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.10 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  From Theorem 7.10 we see that the function\n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ \(z\ sin \((z\^2)\)\ \  = \ \ \ \ z\^3 - 
              z\^7\/\(3!\) + z\^11\/\(5!\) - z\^15\/\(7!\) +  ... \)\)],
    AspectRatioFixed->True],
  "   \n\nhas a zero of order ",
  Cell[BoxData[
      \(k = 3\)]],
  " at ",
  Cell[BoxData[
      \(z = 0\)]],
  ".  Definition 7.6 confirms this fact because   \n\n\t\t\t",
  Cell[BoxData[{
      \(\ \ \ \ \(\(f' \((z)\)\ \  = \ \ 2\ z\^2\ Cos\ z\^2\  + \ 
          Sin\ z\^2\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \(\(f'' \((z)\)\ \  = \ \ 6\ z\ Cos\ z\^2\  - \ 
          4\ z\^3\ Sin\ z\^2\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(f''' \((z)\)\ \  = \ \ 6\ Cos\ z\^2\  - \ 8\ z\^4\ Cos\ z\^2\  - \ 
          24\ z\^2\ Sin\ z\^2\)}]],
  "  \n\nThen,  ",
  Cell[BoxData[
      \(f \((0)\)\  = \ \(f'' \((0)\)\  = \ \(f'' \((0)\)\  = \ 0\)\)\)]],
  ",  but  ",
  Cell[BoxData[
      \(f''' \((0)\)\ \  = \ \ 6\ \  \[NotEqual] \ 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 7.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = z\ sin \((z\^2)\)\)]],
  "  and find the first few terms of the Maclaurin series.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, i, L, m, p, S];\)\ \), "\n", 
    \(\(f[z_]\  = \ z\ Sin[z\^2];\)\ \), "\n", 
    \(\(S[z_]\  = \ Normal[Series[f[z], {z, 0, 23}]];\)\ \), "\n", 
    \(\(L\  = \ CoefficientList[S[z], z];\)\ \), "\n", 
    \(i = 1; \ \ m\  = \ Length[L];\ \), "\n", 
    \(\(While[
        L[\([i]\)] == 0\  && \ i < m, \n\ \ term\  = \ z\^i; \ \ i = 
          i + 1];\)\ \ \), "\n", 
    \(\(fact\  = \ Simplify[S[z]\/term];\)\ \), "\n", 
    \(\(p[z_]\  = \ term\ fact;\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<S[z] = \>", 
        S[z], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<p[z] = \>", term\ , "\<(\>", 
        fact, "\< + ...)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Thus, ",
  Cell[BoxData[
      \(f \((z)\) = z\ sin \((z\^2)\)\)],
    AspectRatioFixed->True],
  " has a zero of order k = 3 at z = 0."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Investigate the graph for real variables.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(Plot[{f[x], S[x]}, {x, \(-3\), 3}, 
        PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 3}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[\(-4\), 4, 1]}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[z] = \>", S[z]];\)\ \)}], "Input"],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate the real and imaginary parts and the absolute value of ",
  Cell[BoxData[
      \(f[z] = z\ sin \((z\^2)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(u[x_, y_] = 
        FullSimplify[
          ComplexExpand[Re[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, Re}]];\)\ \), "\n", 
    \(\(v[x_, y_] = 
        FullSimplify[
          ComplexExpand[Im[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, 
                Re}]];\)\ \), "\[IndentingNewLine]", 
    \(\(w[x_, y_] = 
        FullSimplify[
          ComplexExpand[Abs[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, 
                Re}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[u[x, y], {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] {21, 
            21}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
              1}, {\(-4\), 
              4}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[v[x, y], {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] {21, 
            21}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
              1}, {\(-4\), 
              4}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[w[x, y], {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] {21, 
            21}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
              1}, {0, 5}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", \
"\<y\>", "\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[x,y] = \>", 
        Abs[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", w[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        Re[f[x\  + \ \[ImaginaryI]\ y]], {x, \(-1\), 1}, {y, \(-1\), 
          1}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        Im[f[x\  + \ \[ImaginaryI]\ y]], {x, \(-1\), 1}, {y, \(-1\), 
          1}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        Abs[f[x\  + \ \[ImaginaryI]\ y]], {x, \(-1\), 1}, {y, \(-1\), 
          1}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[x,y] = \>", 
        Abs[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", w[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 7.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic in ",
  Cell[BoxData[
      \(\(D\_R\) \((\[Alpha])\)\)]],
  ".  Then ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has a zero of order ",
  StyleBox["k",
    FontFamily->"Courier New"],
  " at the point ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  " if and only if it can be expressed in the form \n\n",
  StyleBox["(7-35)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f \((z)\) = \(\((z - \[Alpha])\)\^k\) g \((z)\)\)]],
  ", \n\nwhere ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " is analytic at ",
  Cell[BoxData[
      \(z = \[Alpha]\ \ and\ \ g \((\[Alpha])\) \[NotEqual] 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.11 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\<\
\tAn immediate consequence of Theorem 7.11 is Corollary 7.4.  The proof is \
left as an exercise. \
\>", "Text"],

Cell[TextData[{
  StyleBox["Corollary 7.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " are analytic at  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ",  and have zeros of orders  ",
  StyleBox["m",
    FontFamily->"Courier New"],
  "  and  ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ",  respectively at  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ",  then their product  ",
  Cell[BoxData[
      \(h \((z)\) = f \((z)\) g \((z)\)\)]],
  "  has a zero of order  ",
  Cell[BoxData[
      \(m + n\ \ at\ \ z = \[Alpha]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Corollary 7.4 is an exercise in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let ",
  Cell[BoxData[
      \(f \((z)\) = z\^3\ sin\ z\)],
    AspectRatioFixed->True],
  ".  Then ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " can be factored as the product of  ",
  Cell[BoxData[
      \(z\^3\)],
    AspectRatioFixed->True],
  "  and  ",
  Cell[BoxData[
      \(sin\ z\)],
    AspectRatioFixed->True],
  ",  which have zeros of orders ",
  Cell[BoxData[
      \(m = 3\)]],
  " and ",
  Cell[BoxData[
      \(n = 1\)]],
  ", respectively, at ",
  Cell[BoxData[
      \(z = 0\)]],
  ".  \nHence  ",
  Cell[BoxData[
      \(z = 0\)]],
  " is a zero of order 4 of  ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 7.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = z\^3\ Sin[z]\)]],
  " and find the first few terms of the Maclaurin series.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, i, L, m, p, S];\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^3\ Sin[z];\)\ \), "\n", 
    \(\(S[z_]\  = \ Normal[Series[f[z], {z, 0, 16}]];\)\ \), "\n", 
    \(\(L\  = \ CoefficientList[S[z], z];\)\ \), "\n", 
    \(i = 1; \ \ m\  = \ Length[L];\ \), "\n", 
    \(\(While[
        L\[LeftDoubleBracket]i\[RightDoubleBracket] == 0\  && \ 
          i < m, \n\ \ \ term\  = \ z\^i; \ \ i = i + 1];\)\ \ \), "\n", 
    \(\(fact\  = \ Simplify[S[z]\/term\ ];\)\ \), "\n", 
    \(\(p[z_]\  = \ term\ fact;\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<S[z] = \>", 
        S[z], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<p[z] = \>", term\ , "\<(\>", 
        fact, "\< + ...)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Thus, ",
  Cell[BoxData[
      \(f \((z)\) = z\^3\ sin \((z)\)\)],
    AspectRatioFixed->True],
  " has a zero of order k = 4 at z = 0.\n\nInvestigate the graph for real \
variables."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(Plot[{f[x], S[x]}, {x, \(-3.3\), 3.3}, 
        PlotRange \[Rule] {{\(-3.3\), 3.3}, {\(-10\), 10}}, 
        Ticks \[Rule] {Range[\(-\[Pi]\), \[Pi], \[Pi]\/2], 
            Range[\(-10\), 10, 5]}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[z] = \>", S[z]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(Plot[{f[x]}, {x, \(-3.3\), 3.3}, 
        PlotRange \[Rule] {{\(-3.3\), 3.3}, {\(-10\), 10}}, 
        Ticks \[Rule] {Range[\(-\[Pi]\), \[Pi], \[Pi]\/2], 
            Range[\(-10\), 10, 5]}, 
        PlotStyle \[Rule] {Red}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{S[x]}, {x, \(-3.3\), 3.3}, 
        PlotRange \[Rule] {{\(-3.3\), 3.3}, {\(-10\), 10}}, 
        Ticks \[Rule] {Range[\(-\[Pi]\), \[Pi], \[Pi]\/2], 
            Range[\(-10\), 10, 5]}, 
        PlotStyle \[Rule] {Blue}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[z] = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate the real and imaginary parts and the absolute value of ",
  Cell[BoxData[
      \(f \((z)\) = z\^3\ sin \((z)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(u[x_, y_] = 
        FullSimplify[
          ComplexExpand[Re[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, Re}]];\)\ \), "\n", 
    \(\(v[x_, y_] = 
        FullSimplify[
          ComplexExpand[Im[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, 
                Re}]];\)\ \), "\[IndentingNewLine]", 
    \(\(w[x_, y_] = 
        FullSimplify[
          ComplexExpand[Abs[f[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, 
                Re}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        Re[f[x\  + \ \[ImaginaryI]\ y]], {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] {21, 
            21}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
              1}, {\(-4\), 
              1}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        Im[f[x\  + \ \[ImaginaryI]\ y]], {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] {21, 
            21}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
              1}, {\(-2\), 
              2}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        Abs[f[x\  + \ \[ImaginaryI]\ y]], {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] {21, 
            21}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
              1}, {0, 5}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", \
"\<y\>", "\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[x,y] = \>", 
        Abs[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", w[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        Re[f[x\  + \ \[ImaginaryI]\ y]], {x, \(-1\), 1}, {y, \(-1\), 
          1}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        Im[f[x\  + \ \[ImaginaryI]\ y]], {x, \(-1\), 1}, {y, \(-1\), 
          1}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        Abs[f[x\  + \ \[ImaginaryI]\ y]], {x, \(-1\), 1}, {y, \(-1\), 
          1}, \[IndentingNewLine]PlotPoints \[Rule] 35, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[x,y] = \>", 
        Abs[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", w[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell["\<\
\tTheorem 7.12 gives a useful way to characterize a pole.  \
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 7.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  A function ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " analytic in the punctured disk ",
  Cell[BoxData[
      \(\(D\_R\^*\) \((\[Alpha])\)\)]],
  " has a pole of order k at ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  " if and only if it can be expressed in the form \n\t\t\t\n",
  StyleBox["(7-37)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f \((z)\) = \(h \((z)\)\)\/\((z\  - \ \[Alpha])\)\^k\)]],
  ", \n\nwhere the function ",
  StyleBox["h(z)",
    FontFamily->"Courier New"],
  " is analytic at the point ",
  Cell[BoxData[
      \(z = \[Alpha]\ \ and\ \ h \((\[Alpha])\) \[NotEqual] 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.12 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\<\
\tCorollaries 7.5-7.8 are useful in determining the order of a zero or a \
pole.  The proofs follow easily from Theorems 7.10 and 7.12 and are left as \
exercises.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Corollary 7.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "If ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic and has a zero of order ",
  StyleBox["k",
    FontFamily->"Courier"],
  " at the point  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ",  then  ",
  Cell[BoxData[
      \(g \((z)\) = 1\/\(f \((z)\)\)\)]],
  "  has a pole of order ",
  StyleBox["k",
    FontFamily->"Courier"],
  " at  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 7.5 is an exercise in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Corollary 7.6. ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "If  ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has a pole of order ",
  StyleBox["k",
    FontFamily->"Courier"],
  " at the point ",
  Cell[BoxData[
      \(\(\(\ \)\(z = \[Alpha]\)\)\)]],
  ", then ",
  Cell[BoxData[
      \(g \((z)\) = 1\/\(f \((z)\)\)\)]],
  " has a removable singularity at ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ".  If we define ",
  Cell[BoxData[
      \(g \((\[Alpha])\) = 0\)]],
  ",  then ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  "  has a zero of order ",
  StyleBox["k",
    FontFamily->"Courier"],
  " at ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 7.6 is an exercise in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Corollary 7.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " have poles of orders  ",
  StyleBox["m",
    FontFamily->"Courier New"],
  "  and  ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ",  respectively at the point  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ", then their product  ",
  Cell[BoxData[
      \(h \((z)\) = f \((z)\) g \((z)\)\)]],
  "  has a pole of order  ",
  Cell[BoxData[
      \(m + n\ \ at\ \ z = \[Alpha]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 7.7 is an exercise in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Corollary 7.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " be analytic with  zeros of orders  ",
  StyleBox["m",
    FontFamily->"Courier New"],
  "  and  ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ",  respectively at  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ".  Then their quotient ",
  Cell[BoxData[
      \(h \((z)\) = \(f \((z)\)\)\/\(g \((z)\)\)\)]],
  "  has the following behavior:\n\n",
  StyleBox["(i)",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(m > n\)]],
  ",  then ",
  StyleBox["h(z)",
    FontFamily->"Courier New"],
  " has a removable singularity at  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ".   If we define  ",
  Cell[BoxData[
      \(h \((\[Alpha])\) = 0\)]],
  ",  then ",
  StyleBox["h(z)",
    FontFamily->"Courier New"],
  " has a zero of order  ",
  Cell[BoxData[
      \(m - n\ \ at\ \ z = \[Alpha]\)]],
  ". \n\n",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(m < n\)]],
  ",  then ",
  StyleBox["h(z)",
    FontFamily->"Courier New"],
  " has a pole of order  ",
  Cell[BoxData[
      \(n - m\ \ at\ \ z = \[Alpha]\)]],
  ". \n\n",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(m = n\)]],
  ",  then ",
  StyleBox["h(z)",
    FontFamily->"Courier New"],
  " has a removable singularity  at  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ",  and can be defined so that ",
  StyleBox["h(z)",
    FontFamily->"Courier New"],
  " is analytic at  ",
  Cell[BoxData[
      \(z = \[Alpha]\)]],
  ",  by  ",
  Cell[BoxData[
      \(h \((\[Alpha])\) = lim\+\(z\  \[Rule] \ \[Alpha]\)\ \ h \((z)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 7.8 is an exercise in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Locate the zeros and poles of  ",
  Cell[BoxData[
      \(h \((z)\) = \(tan\ z\)\/z\)],
    AspectRatioFixed->True],
  ",  and determine their order. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  In Section 5.4 we saw that the zeros of  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ sin\ z\)],
    AspectRatioFixed->True],
  "  occur at the points  ",
  Cell[BoxData[
      \(z = n\ \[Pi]\)]],
  ",  where ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is an integer.  Because  ",
  Cell[BoxData[
      \(f' \((n\ \[Pi])\)\ \  = \ \ cos\ n\ \[Pi]\ \  \[NotEqual] \ \ 0\)]],
  ",  the zeros of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " are simple.  Similarly, the function  ",
  Cell[BoxData[
      \(g \((z)\)\  = \ z\ cos\ z\)],
    AspectRatioFixed->True],
  "  has simple zeros at the points ",
  Cell[BoxData[
      \(z = 0\)]],
  " and  ",
  Cell[BoxData[
      \(z = \((n + 1\/2)\) \[Pi]\)]],
  ",  where ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is an integer.  From the information given, we find that  ",
  Cell[BoxData[
      \(h \((z)\)\  = \ \(f \((z)\)\)\/\(g \((z)\)\)\)]],
  "  behaves as follows:\n\n\t\t i.    ",
  StyleBox["h(z)",
    FontFamily->"Courier New"],
  "  has simple zeros at  ",
  Cell[BoxData[
      \(z = n\ \[Pi]\)]],
  ",  where  ",
  Cell[BoxData[
      \(n = \(\[PlusMinus]1\), \(\[PlusMinus]2\),  ... \)]],
  ";\n\n\t\t ii.   ",
  StyleBox["h(z)",
    FontFamily->"Courier New"],
  "  has simple poles at  ",
  Cell[BoxData[
      \(z = \((n + 1\/2)\) \[Pi]\)]],
  ",  where ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is an integer;  and\n\n\t\t iii.  ",
  StyleBox["h(z)",
    FontFamily->"Courier New"],
  "  is analytic at ",
  Cell[BoxData[
      \(z = 0\)]],
  " if we define  ",
  Cell[BoxData[
      \(h \((0)\)\  = \ \(lim\+\(z \[Rule] 0\)h \((z)\)\  = \ 1\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 7.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(h[z] = Tan[z]\/z\)]],
  " and find the first few terms of the Maclaurin series.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[h, i, S];\)\ \), "\n", 
    \(\(h[z_]\  = \ Tan[z]\/z;\)\ \), "\n", 
    \(\(S[z_]\  = \ Normal[Series[h[z], {z, 0, 13}]];\)\ \), "\n", 
    \(\(Print["\<h[z] = \>", h[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<S[z] = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<h[z] = \>", 
        S[z], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Thus, ",
  Cell[BoxData[
      \(h \((z)\) = Tan[z]\/z\)],
    AspectRatioFixed->True],
  " has a removable singularity at z = 0.\n\nNow look for the zeros of  \
h[x]."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<  h[z] = \>", h[z]];\)\ \), "\n", 
    \(\(For[k = \(-5\), 
        k \[LessEqual] \(-1\), \(k++\), \n\ \ \ Print["\<h[\>", 
          k, "\< \[Pi]] = \>", 
          h[k\ \[Pi]]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(For[k = 1, 
        k \[LessEqual] 5, \(k++\), \n\ \ \ Print["\<h[\>", 
          k, "\< \[Pi]] = \>", 
          h[k\ \[Pi]]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Or we could consider the following method of investigation.", "Text"],

Cell[BoxData[{
    \(\(Print["\<h[x] = \>", h[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<h[n \[Pi]] = \>", 
        h[n\ \[Pi]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<h[n \[Pi]] = \>", 
        Simplify[h[n\ \[Pi]], Element[n, Integers]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "\nThus, ",
  Cell[BoxData[
      \(h \((z)\) = Tan[z]\/z\)],
    AspectRatioFixed->True],
  " has simple zeros at  ",
  Cell[BoxData[
      \(z = \(n\ \[Pi]\ \ for\ \ n = \(\[PlusMinus]1\)\), \(\[PlusMinus]2\),  \
... \)]],
  ".  \n\nNow consider the other singular points."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<    h[z] = \>", h[z]];\)\ \), "\n", 
    \(\(For[i = \(-4\), 
        i <= 5, \(i++\), \[IndentingNewLine]Print["\<h[\>", \(2  i - 1\)\/2, \
"\< \[Pi]] = \>", \[IndentingNewLine]Limit[h[z], 
            z \[Rule] \(\((2  i - 1)\) \[Pi]\)\/2]\ ]\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Or we could consider the following method of investigation.", "Text"],

Cell[BoxData[{
    \(\(Print["\<h[x] = \>", h[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<h[(2n+1) \!\(\[Pi]\/2\)] = \>\"", 
        h[\((2  n + 1)\)\ \[Pi]\/2]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<h[(2n+1) \!\(\[Pi]\/2\)] = \>\"", 
        Simplify[h[\((2  n + 1)\)\ \[Pi]\/2], 
          Element[n, Integers]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Hence,  ",
  Cell[BoxData[
      \(h \((z)\) = Tan[z]\/z\)],
    AspectRatioFixed->True],
  " has simple poles at  ",
  Cell[BoxData[
      \(z = \(\((2  n - 1)\) \[Pi]\)\/2\)]],
  "  where n is an integer."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Investigate the graph for real variables.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(Plot[h[x], {x, \(-3\) \[Pi], 3  \[Pi]}, 
        PlotRange \[Rule] {{\(-3\) \[Pi], 3  \[Pi]}, {\(-10\), 10}}, 
        Ticks \[Rule] {Range[\(\(-7\) \[Pi]\)\/2, \(7  \[Pi]\)\/2, \[Pi]], 
            Range[\(-10\), 10, 5]}, 
        PlotStyle \[Rule] Red];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<h[x] = \>", h[x]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate the real part, imaginary part and absolute value of  ",
  Cell[BoxData[
      \(h \((z)\) = Tan[z]\/z\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(u[x_, y_] = 
        FullSimplify[
          ComplexExpand[Re[h[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, 
                Re}]];\)\ \), "\[IndentingNewLine]", 
    \(\(v[x_, y_] = 
        FullSimplify[
          ComplexExpand[Im[h[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, 
                Re}]];\)\ \), "\[IndentingNewLine]", 
    \(\(w[x_, y_] = 
        FullSimplify[
          ComplexExpand[Abs[h[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, 
                Re}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        u[x, y], {x, \(-6\), 6}, {y, \(-6\), 
          6}, \[IndentingNewLine]PlotPoints \[Rule] {41, 41}, 
        PlotRange \[Rule] {{\(-6\), 6}, {\(-6\), 6}, {0, 
              0.15}}, \[IndentingNewLine]ViewPoint \[Rule] {4, 4, 1}, 
        ClipFill \[Rule] 
          None, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Re[\>", h[z], "\<] = \>", 
        u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        u[x, y], {x, \(-6\), 6}, {y, \(-6\), 
          6}, \[IndentingNewLine]PlotPoints \[Rule] {41, 41}, 
        PlotRange \[Rule] {{\(-6\), 6}, {\(-6\), 6}, {0, 
              2}}, \[IndentingNewLine]ViewPoint \[Rule] {4, 4, 1}, 
        ClipFill \[Rule] 
          None, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Re[\>", h[z], "\<] = \>", 
        u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        v[x, y], {x, \(-6\), 6}, {y, \(-6\), 
          6}, \[IndentingNewLine]PlotPoints \[Rule] {41, 41}, 
        PlotRange \[Rule] {{\(-6\), 6}, {\(-6\), 6}, {\(-0.15\), 
              0.15}}, \[IndentingNewLine]ViewPoint \[Rule] {4, 2, 2}, 
        ClipFill \[Rule] 
          None, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Im[\>", h[z], "\<] = \>", 
        v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        v[x, y], {x, \(-6\), 6}, {y, \(-6\), 
          6}, \[IndentingNewLine]PlotPoints \[Rule] {41, 41}, 
        PlotRange \[Rule] {{\(-6\), 6}, {\(-6\), 6}, {\(-1\), 
              1}}, \[IndentingNewLine]ViewPoint \[Rule] {4, 2, 2}, 
        ClipFill \[Rule] 
          None, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Im[\>", h[z], "\<] = \>", 
        v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        w[x, y], {x, \(-6\), 6}, {y, \(-6\), 
          6}, \[IndentingNewLine]PlotPoints \[Rule] {41, 41}, 
        PlotRange \[Rule] {{\(-6\), 6}, {\(-6\), 6}, {0, 
              0.2}}, \[IndentingNewLine]ViewPoint \[Rule] {4, 4, 1}, 
        ClipFill \[Rule] 
          None, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Abs[\>", h[z], "\<] = \>", 
        w[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        w[x, y], {x, \(-6\), 6}, {y, \(-6\), 
          6}, \[IndentingNewLine]PlotPoints \[Rule] {41, 41}, 
        PlotRange \[Rule] {{\(-6\), 6}, {\(-6\), 6}, {0, 
              2}}, \[IndentingNewLine]ViewPoint \[Rule] {4, 4, 1}, 
        ClipFill \[Rule] 
          None, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>", \
"\<\>"}, ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Abs[\>", h[z], "\<] = \>", 
        w[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.13.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Locate the poles of ",
  Cell[BoxData[
      \(g \((z)\) = 1\/\(5  z\^4\  + \ 26  z\^2\  + \ 5\)\)],
    AspectRatioFixed->True],
  ", and specify their order. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000kb000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD
0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3o
oolh0?ooo`800000FP3oool00?l0oooo=P3oool2000000030?ooo`000000
000005T0oooo003o0?oooa<0oooo1000000L0?ooo`<000000`3oool20000
05T0oooo003o0?oooa<0oooo00<000000?ooo`3oool06`3oool2000000H0
oooo00<000000?ooo`000000F03oool00?l0oooo503oool00`000000oooo
0?ooo`0G0?ooo`<00000203oool010000000oooo0?ooo`00001G0?ooo`00
o`3ooolE0?ooo`030000003oool0oooo01@0oooo0P00000;0?ooo`040000
003oool0oooo000005L0oooo003o0?oooa<0oooo00@000000?ooo`3oool0
00004P3oool3000000d0oooo00D000000?ooo`3oool0oooo0000001F0?oo
o`00o`3ooolD0?ooo`800000403oool4000000h0oooo0P0000040?ooo`03
0000003oool0oooo05<0oooo003o0?ooob@0oooo0P0000030?ooo`030000
003oool0oooo00X0oooo0P0000000`3oZ00000000?ooo`030?ooo`030000
003oool0oooo05<0oooo003o0?ooob40oooo0`00000?0?ooo`<00000103o
Z0000`000000oooo0?ooo`020?ooo`030000003oool0oooo0580oooo003o
0?oooal0oooo0P00000@0?ooo`8000000P3oZ0000`000000ojP00?nX0002
0?nX00030000003oool0oooo0080oooo00<000000?ooo`3oool0DP3oool0
0?l0oooo703oool300000100oooo0P0000050?nX00040000003oZ000ojP0
0?nX00800000103oool00`000000oooo0?ooo`1A0?ooo`00o`3ooolJ0?oo
o`8000004@3oool2000000030?nW00000000ojP000@0ojP01@000000103o
Z00000000?ooo`3oool300000580oooo00370?ooo`80000000<0oooo0000
00000000BP3oool300000100oooo0`0000040?nW00030000003oZ000ojP0
0080000000D0ojP00000003oZ000ojP0000000020?nX00050000003oool0
oooo0?ooo`000000DP3oool00<P0oooo00<000000?ooo`000000B@3oool2
000000<0oooo00<000000?ooo`3oool02`3oool200000080ojL000<00000
0?nW003oY`000P3oY`03000000@0ojP000<000000?nX000000000P3oZ002
000000<0oooo00<000000?ooo`3oool0C`3oool00<T0oooo00<000000?oo
o`3oool0A@3oool3000000l0oooo100000040?nW00030000003oY`00ojL0
0080000000<0ojL00000003oZ000103oZ0000`000000ojP0000000020000
0080ojP000D000000?ooo`3oool0oooo0000001@0?ooo`00a`3oool20000
00030?ooo`000000000004<0oooo0P00000>0?ooo`@000000`3oY`000`00
0000ojL00?nW00020?nW00<00000103oY`000`000000ojP00?nX00020?nX
00<00000103oZ0001@000000oooo0?ooo`3oool000000500oooo003o0?oo
o`d0oooo0`00000>0?ooo`80000000<0ojH00000003oY`00103oY`000`00
0000ojL00?nW0002000000030?nW00000000ojL000@0ojL000<000000?nX
003oZ0000P0000020?nW00030000003oZ000ojP00080ojP00P0000030?oo
o`030000003oool0oooo04d0oooo003o0?ooo`X0oooo0`00000>0?ooo`<0
0000103oYP000`000000ojL00?nW00020?nW00<00000103oY`000`000000
ojL00?nW00020?nW00<00000103oY`000`000000ojP00?nX000200000003
0?nX00000000oooo00<0oooo00<000000?ooo`3oool02P3oool4000003h0
oooo003o0?ooo`P0oooo0P00000?0?ooo`8000000P3oYP000`000000ojH0
0?nV00020?nV00030000003oY`00ojL0008000000P3oYP000`000000ojL0
0?nW00020?nW00030000003oY`00ojL0008000000P3oY`000`000000ojL0
0?nW00020?nW00<00000103oZ0001@000000oooo0?ooo`3oool0000000`0
oooo00<000000?ooo`3oool0?`3oool00?l0oooo1@3oool300000080oooo
00<000000?ooo`3oool02P3oool2000000@0ojH000<000000?nV003oYP00
0`3oYP02000000@0ojH000@000000?nW003oY`00ojL0100000040?nW0003
0000003oY`00ojL000@000001@3oZ0000`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0?P3oool00?l0oooo
0`3oool200000100oooo0P0000000`3oY@0000000?nV00040?nV00030000
003oYP00ojH00080000000<0ojH00000003oYP00103oYP03000000<0ojH0
00<000000?nW003oY`000`3oY`0200000080ojL000<000000?nW00000000
103oZ002000000@0oooo00<000000?ooo`3oool00P3oool4000000@0oooo
00<000000?ooo`3oool0?@3oool00?l0oooo0`00000?0?ooo`<00000103o
Y@0010000000ojH00?nV003oYP04000000@0ojH000<000000?nV003oYP00
0P0000000`3oYP0000000?nV00040?nV00030000003oY`00ojL000800000
00L0ojL00000003oY`00ojL00000003oY`0000000080ojP00P0000020?nX
00050000003oool0oooo0?ooo`0000002P3oool010000000oooo0?ooo`00
000n0?ooo`00o@3oool200000100oooo0P0000020?nU00030000003oY@00
ojD00080ojD0100000030?nU00030000003oYP00ojH00080ojH00`000003
0?nV00030000003oYP00ojH000<0ojH00`0000040?nW00040000003oY`00
00000?nW00<00000103oZ0000`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo0P00000o0?ooo`00nP3oool3000000h0oooo10000004
0?nU00030000003oY@00ojD00080000000<0ojD00000003oY@00103oY@00
0`000000ojH00?nV000200000080ojD000<000000?nV003oYP000P3oYP00
0`000000ojH00?nV000200000080ojH000<000000?nW003oY`000P3oY`04
00000080ojL000<000000?nX003oZ0000`3oZ0000`000000oooo00000002
000004/0oooo003h0?ooo`8000003P3oool3000000<0ojD000<000000?nU
003oY@000`3oY@02000000@0ojD000<000000?nU003oY@000P3oY@030000
00@0ojD000@000000?nV003oYP00ojH0100000040?nV00030000003oY`00
ojL00080000000@0ojL00000003oY`0000000`3oY`000`000000ojP00?nX
0002000000030?nX00000000oooo0080oooo00<000000?ooo`3oool0B03o
ool00=H0oooo0P00000M0?ooo`<000000P3oool00`000000oooo0?ooo`09
0?ooo`80000000<0ojD00000003oY@00103oY@000`000000ojD00?nU0002
000000030?nT00000000ojD000<0ojD000<000000?nU003oY@000P000002
0?nT00030000003oY@00ojD00080ojD0100000030?nV00030000003oYP00
ojH00080ojH00`0000040?nW008000000`3oY`03000000<0ojP000<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`170?ooo`00e@3oool01000
0000oooo0?ooo`00000J0?ooo`8000003P3oool3000000<0ojD000<00000
0?nU003oY@000`3oY@03000000@0oj@000@000000?nU003oY@00ojD00`00
00040?nT00030000003oY@00ojD00080000000<0ojD00000003oYP00103o
YP000`000000ojH00?nV0002000000030?nV00000000ojL000@0ojL00P00
00000`3oY`000000000000020?nX00030000003oZ000ojP00080ojP000D0
00000?ooo`3oool0oooo000000190?ooo`00e@3oool010000000oooo0?oo
o`00000G0?ooo`<000003P3oool200000080ojD000<000000?nU003oY@00
0P3oY@000`000000ojD00?nU000200000080oj@000<000000?nT003oY000
0P3oY00400000080oj@000<000000?nT003oY0000`3oY002000000@0ojD0
00<000000?nV003oYP000P3oYP03000000@0ojH000<000000?nW003oY`00
0P3oY`03000000@0ojP000@000000?nX003oZ000ojP00`0000030?ooo`03
0000003oool0oooo04H0oooo003E0?ooo`040000003oool0oooo000001@0
oooo0`00000?0?ooo`800000103oY@0010000000ojD00?nU003oY@040000
00@0oj@000<000000?nT003oY0000P0000000`3oX`0000000?nT00040?nT
00030000003oY000oj@00080000000<0oj@00000003oY@000`3oY@000`00
0000ojH00?nV000200000080ojD000<000000?nV003oYP000P3oYP000`00
0000ojL00?nW0002000000030?nW00000000000000@0ojP0100000030?nX
00050000003oool0oooo0?ooo`000000A`3oool00=D0oooo00@000000?oo
o`3oool000004P3oool200000100oooo0P0000000`3oYP0000000?nU0004
0?nU00<000000`3oX`000`000000oj@00?nT00020?nT00<00000103oX`00
0`000000oj@00?nT00020?nT00<00000103oY00010000000ojD00?nU003o
Y@03000000@0ojD000@000000?nV003oYP00ojH0100000030?nW00800000
0P3oZ002000000030?nX00000000ojP000@0ojP000D000000?ooo`3oool0
oooo000000170?ooo`00eP3oool200000100oooo0`00000?0?ooo`<00000
103oYP000`000000ojD00?nU0002000000030?nS00000000oj<000<0oj<0
00<000000?nT003oY0000P0000020?nR00030000003oX`00oj<00080oj<0
00<000000?nT003oY0000P0000020?nS00030000003oY000oj@00080oj@0
100000020?nT00030000003oY@00ojD000<0ojD00`0000030?nV00040000
003oY`00ojL00?nW00@00000103oZ0000`000000ojP00?nX00020?nX0080
00000`3oool00`000000oooo0?ooo`140?ooo`00iP3oool2000000<0oooo
00<000000?ooo`3oool02P3oool200000080ojL000<000000?nV003oYP00
0P3oYP03000000<0oj<000<000000?nS003oX`000`3oX`02000000@0oj80
00@000000?nS003oX`00oj<0100000040?nS00030000003oY000oj@00080
000000<0oj<00000003oY000103oY0000`000000ojD00?nU000200000003
0?nU00000000ojH000<0ojH000<000000?nW003oY`000P0000020?nW0003
0000003oZ000ojP00080ojP000<000000?nX003oZ0000P0000020?nY0005
0000003oool0oooo0?ooo`000000A@3oool00><0oooo0`00000@0?ooo`80
0000103oY`000`000000ojH00?nV000200000080oj@000<000000?nS003o
X`000P3oX`000`000000oj<00?nS0002000000030?nQ00000000oj8000@0
oj800`0000030?nR00030000003oX`00oj<00080oj<00`0000040?nS0003
0000003oY000oj@00080oj@00`0000040?nU00040000003oYP00ojH00?nV
00<0000000D0ojL00000003oY`00ojL0000000030?nX00@00000103oZ@00
1@000000oooo0?ooo`3oool0000004D0oooo003Q0?ooo`8000004@3oool2
000000030?nZ00000000ojL000@0ojL00P0000040?nT00040000003oX`00
oj<00?nS00@00000103oX@000`000000oj800?nR0002000000030?nP0000
0000oj8000<0oj8000<000000?nS003oX`000P0000020?nR00030000003o
X`00oj<00080oj<000<000000?nT003oY0000P0000020?nT00030000003o
Y@00ojD00080ojD0100000020?nV00030000003oY`00000000<0ojL00`00
00030?nX00030000003oZ@00ojT00080ojT00P0000020?ooo`800000A03o
ool00=h0oooo0`00000?0?ooo`@00000103oZP000`000000ojL00?nW0002
000000030?nU00000000oj@000@0oj@00`0000030?nQ00030000003oX@00
oj400080oj400`0000040?nP00040000003oXP00oj800?nR00<00000103o
XP0010000000oj<00?nS003oX`04000000@0oj@000<000000?nU003oY@00
0P0000000`3oYP0000000?nV00040?nV0080000000D0ojL0000000000000
ojP0000000040?nX00030000003oZ@00ojT0008000000P3oZ@001@000000
oooo0?ooo`3oool0000004<0oooo003L0?ooo`8000003`3oool3000000<0
ojd000<000000?nZ003oZP000P3oZP03000000@0ojD000<000000?nT003o
Y0000P0000000`3oX@0000000?nQ00030?nQ00030000003oX@00oj400080
00000P3oW`000`000000oj000?nP00020?nP00@000000P3oX@000`000000
oj800?nR00030?nR00<000000`3oX`000`000000oj@00?nT00020?nT00<0
0000103oYP000`000000ojH00?nV00020?nV00<000000`3oZ00010000000
ojP00?nX003oZ004000000@0ojT000D000000?ooo`3oool0oooo00000013
0?ooo`00f@3oool4000000h0oooo0P0000000`3o/P0000000?n]00030?n]
00030000003oZP00ojX0008000000P3oY`000`000000ojD00?nU00020?nU
00<00000103oX@0010000000oj400?nQ003oX@03000000@0oil000<00000
0?nP003oX0000P0000000`3oW`0000000?nQ00040?nQ00030000003oXP00
oj800080000000<0oj400000003oX`000`3oX`000`000000oj@00?nT0002
00000080oj@000<000000?nV003oYP000P3oYP000`000000ojH00?nV0002
000000030?nW00000000000000@0ojP00`0000030?nY00030000003oZ@00
ojT00080ojT00P0000030?ooo`030000003oool0oooo0400oooo003G0?oo
o`800000103oool00`000000oooo0?ooo`080?ooo`<000000`3o/P000`00
0000ojd00?n]00030?n]00800000103oY`000`000000ojD00?nU00020000
0080oj4000<000000?nQ003oX@000P3oX@0400000080oih000<000000?nO
003oW`000`3oW`02000000@0oil000<000000?nQ003oX@000P3oX@030000
00@0oj4000@000000?nS003oX`00oj<00`0000040?nT00040000003oYP00
ojH00?nV00@000000`3oY`0200000080ojP00P0000000`3oZ00000000?nY
00030?nY00030000003oZ@00ojT0008000000P3oZP0010000000oooo0?oo
o`0000120?ooo`00e03oool3000000l0oooo0P0000000`3o^00000000?nb
00040?nb00030000003o[@00ojd00080000000<0oj/00000003oY`00103o
Y`02000000@0oj4000<000000?nQ003oX@000P0000020?nM00030000003o
WP00oih00080oih000<000000?nO003oW`000P0000000`3oW@0000000?nO
00030?nO00030000003oX@00oj40008000000P3oW`000`000000oj400?nQ
00020?nQ00@000000P3oX`000`000000oj@00?nT00030?nT00<000000`3o
YP0010000000ojL00?nW003oY`04000000<0ojP000<000000?nY003oZ@00
0`3oZ@02000000@0ojX000D000000?ooo`3oool0oooo000000110?ooo`00
d@3oool300000100oooo0P0000040?nh00030000003o/P00ok800080ok80
0`0000040?n[00030000003oY`00ojL00080000000<0oj<00000003oX@00
103oX@02000000@0oid000@000000?nN003oWP00oih0100000040?nM0004
0000003oW`00oil00?nO00<00000103oW`000`000000oj400?nQ00020000
00030?nQ00000000oj<000@0oj<000<000000?nT003oY0000P0000000`3o
Y@0000000?nV00030?nV00030000003oY`00ojL0008000000P3oY`000`00
0000ojP00?nX00020?nX00030000003oZ@00ojT00080000000<0ojT00000
003oZP000`3oZP02000000<0oooo00<000000?ooo`3oool0?P3oool00<l0
oooo0P00000A0?ooo`80000000<0okd00000003o^0000`3o^0000`000000
ok800?nb000200000080ok4000<000000?n[003oZ`000P3oZ`03000000@0
oj<000<000000?nQ003oX@000P0000000`3oW00000000?nM00040?nM00<0
00000`3oV`000`000000oid00?nM00020?nM00@000000P3oW@000`000000
oil00?nO00030?nO00800000103oX@000`000000oj<00?nS00020?nS00<0
0000103oY@0010000000ojH00?nV003oYP03000000050?nW00000000ojL0
0?nW000000000`3oZ004000000<0ojT000<000000?nZ003oZP000P000000
0`3oZ`0000000?ooo`020?ooo`030000003oool0oooo03h0oooo003<0?oo
o`<00000403oool3000000@0okd000@000000?nh003o^000okP00`000004
0?na00030000003oZ`00oj/0008000000P3oY`000`000000oj<00?nS0002
0?nS00<00000103oW0000`000000oid00?nM0002000000030?nI00000000
oi/000<0oi/000<000000?nM003oW@000P0000020?nK00030000003oW@00
oid00080oid000<000000?nO003oW`000P0000000`3oW`0000000?nQ0003
0?nQ00030000003oX`00oj<0008000000P3oX`000`000000ojD00?nU0002
0?nU00@000000P3oY`001@000000ojL00?nW00000000ojL000@000000`3o
Z@000`000000ojT00?nY00020?nY00800000103oZ`001@000000oooo0?oo
o`3oool0000003l0oooo003:0?ooo`8000000P3oool00`000000oooo0?oo
o`0<0?ooo`8000000P3o`@000`000000okd00?nm00030?nm00<000000P3o
^P000`000000ok400?na00030?na00800000103oY`000`000000oj<00?nS
000200000080oid000<000000?nL003oW0000P3oW003000000@0oiT000@0
00000?nK003oV`00oi/00`0000040?nK00040000003oW@00oid00?nM00@0
00000`3oW`0010000000oj400?nQ003oX@04000000@0oj<000<000000?nU
003oY@000P0000000`3oY@0000000?nW00030?nW00030000003oY`00ojL0
008000000P3oZ0000`000000ojT00?nY00020?nY00030000003oZ@00ojT0
0080000000<0ojX00000003oZ`000`3oZ`000`000000oooo0?ooo`020?oo
o`030000003oool0oooo03`0oooo00370?ooo`<00000403oool3000000D0
ol4000<000000?nm003o_@000P0000000`3oa00000000?nj00030?nj0003
0000003o/@00ok400080000000<0ojh00000000000000`3oY`03000000@0
oid000<000000?nL003oW0000P0000020?nG00030000003oV@00oiT00080
oiT0100000020?nH00030000003oV`00oi/000<0oi/00`0000030?nL0003
0000003oW`00oil00080oil00`0000030?nQ00030000003oX`00oj<00080
oj<00`0000040?nU00030000003oY`00ojL00080ojL00`0000030?nX0004
0000003oZ@00ojT00?nY00@00000103oZP0010000000oj/00?n[003oZ`02
00000080oooo0P00000n0?ooo`00a@3oool200000100oooo0`0000020?o1
00030000003o`@00ol4000<0ol400`0000030?o400030000003o^P00okX0
00<0okX00P0000050?n^00<000000P3oW`02000000<0oid00`0000040?nG
00030000003oV@00oiT0008000000P3oU0000`000000oiP00?nH00020?nH
00030000003oV`00oi/00080000000<0oiT00000003oW0000`3oW0000`00
0000oil00?nO0002000000030?nO00000000oj4000<0oj4000<000000?nS
003oX`000P0000020?nT00030000003oY@00ojD00080ojD000<000000?nW
003oY`000P0000000`3oY`000000000000030?nX00@000000`3oZP000`00
0000ojX00?nZ00020?nZ00@000000P3oZ`001@000000oooo0?ooo`3oool0
000003d0oooo00320?ooo`<00000403oool2000000030?nm00000000ol40
00<0ol4000<000000?o1003o`@000P0000000`3ob`0000000?o400040?o4
00030000003o^P00okX00080000000<0okX00000003o[P000`3o[P000`00
0000ojD0000000050?nO00<000000P3oU@02000000<0oiL00`0000040?nD
00040000003oV000oiP00?nH00@000000`3oV@0010000000oi`00?nL003o
W004000000@0oil000@000000?nQ003oX@00oj400`0000040?nT00040000
003oY@00ojD00?nU00@000000`3oY`02000000050?nX0000000000000?nY
000000001@3oZP000`000000ojX00?nZ000200000080oj/000D000000?n[
003oZ`00oj/0000000040?ooo`030000003oool0oooo03X0oooo00300?oo
o`800000403oool3000000<0okd000<000000?o1003o`@000`3o`@020000
00@0ol/000<000000?o4003oa0000P3oa003000000@0okX000@000000?n^
0000000000000`3oY@000`000000oil00?nO0002000000030?nD00000000
oiD000<0oiD0100000020?nA00030000003oU000oi@000<0oi@00`000003
0?nE00030000003oV@00oiT00080oiT00`0000030?nL00030000003oW`00
oil00080oil0100000020?nR00030000003oY000oj@000<0oj@00`000003
0?nV00030000003oY`00ojL00080ojL00P0000040?nY00030000003oZP00
ojX00080ojX00`0000040?n[00040000003oZ`00oj/00?n[008000000`3o
ool00`000000oooo0?ooo`0j0?ooo`00W@3oool4000001`0oooo1000000=
0?ooo`@000000P3o^0000`000000okd00?nm00020?nm00030000003o`@00
ol400080000000<0ol/00000003ob`000`3ob`000`000000ol@00?o40002
00000080ol`000<000000?nj003o^P000P3o^P02000000D0ojD00`000003
0?nD00030000003oU@00oiD0008000000P3oS@000`000000oi400?nA0002
0?nA00030000003oU000oi@00080000000<0oi400000003oU@000`3oU@00
0`000000oiT00?nI0002000000030?nH00000000oi`000<0oi`000<00000
0?nO003oW`000P0000020?nO00030000003oXP00oj800080oj8000<00000
0?nT003oY0000P0000000`3oY@0000000?nV00030?nV00030000003oY`00
ojL000@00000103oZ@000`000000ojX00?nZ000200000080oj/000<00000
0?n[003oZ`000P3oZ`0400000080oj`000D000000?ooo`3oool0oooo0000
000k0?ooo`00W@3oool00`000000oooo0?ooo`0K0?ooo`8000003`3oool2
00000080ok8000<000000?nh003o^0000P3o^00010000000okd00?nm003o
_@03000000<0ol/000<000000?o;003ob`000`3ob`02000000@0ol`000<0
00000?nj003o^P000P0000020?nc00030000003oY@00ojD0008000000P3o
UP000`000000oi@00?nD00020?nD00800000103oS@0010000000oi400?nA
003oT@04000000@0oi4000@000000?nE003oU@00oiD00`0000040?nH0004
0000003oW000oi`00?nL00<00000103oW`0010000000oj800?nR003oXP04
000000<0ojD000@000000?nV003oYP00ojH0100000020?nY00030000003o
Z@00000000<0ojT00`0000040?n[00030000003oZ`00oj/0008000000P3o
[0001@000000oj`00?n/003o[000000000@0oooo00<000000?ooo`3oool0
>03oool009h0oooo00<000000?ooo`3oool05`3oool3000000h0oooo0`00
00040?nb00040000003o^000okP00?nh00D000000P3oa0000`000000ol/0
0?o;00020?o;00030000003ob`00ol/00080000000<0omd00000003oc000
103oc002000000D0ok<00P0000040?nF00030000003oU000oi@000800000
00<0ohP00000003oS@00103oS@03000000<0oh/000<000000?nA003oT@00
0P3oT@0400000080oi<000<000000?nH003oV0000P3oV00400000080oi`0
00<000000?nO003oW`000`3oW`03000000<0oj<000<000000?nU003oY@00
0P3oY@03000000<0ojP000D000000?nY003oZ@0000000?nY000400000080
oj/000<000000?n[003oZ`000P3oZ`03000000@0oj`000@000000?n/003o
[000oj`00P0000030?ooo`030000003oool0oooo03P0oooo002G0?ooo`@0
0000103oool00`000000oooo0?ooo`0C0?ooo`<000003P3oool300000080
ojd000<000000?nb003o/P000`3o/P03000000<0okX000<000000?o4003o
a0000P3oa00010000000ol/00?o;003ob`03000000<0omd000<000000?o<
003oc0000P3oc00010000000om<00000000000020?nc0080000000<0oid0
0000000000000`3oUP03000000@0ohP000<000000?n=003oS@000P000000
0`3oQ00000000?n;00030?n;00030000003oT@00oi40008000000P3oSP00
1@000000oi<00?nC003oT`0000000080oiP00P0000020?nH00030000003o
W000oi`00080oi`000<000000?nO003oW`000P0000000`3oX00000000?nS
00030?nS00030000003oY@00ojD00080000000<0ojH00000003oZ0000`3o
Z0000`000000ojT00?nY000200000080ojX000D000000?n[003oZ`00oj/0
000000020?n[008000000P3o[0000`000000oj`00?n/00020?n/00@00000
0P3o[@001@000000oooo0?ooo`3oool0000001h0oooo0P00000I0?ooo`00
W@3oool010000000oooo0?ooo`00000B0?ooo`8000003`3oool200000003
0?nZ00000000ojd000<0ojd000<000000?nb003o/P000P0000000`3o/@00
00000?nj00030?nj00040000003oa000ol@00?o400D0000000<0omd00000
003og@00103og@0010000000ol`00000000000040?oC00800000103oW@04
00000080oh800P0000030?n800<00000103oQ00010000000oh/00?n;003o
R`03000000@0ohh000@000000?nC003oT`00oi<00`0000040?nH00040000
003oW000oi`00?nL00@000000`3oX00010000000oj<00?nS003oX`040000
00@0ojH000@000000?nX003oZ000ojP0100000030?nZ00040000003oZ`00
oj/00?n[00<00000103o[0000`000000oj`00?n/000200000080ojd000D0
00000?n]003o[@00ojd0000000030?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool05`3oool009h0oooo0P00000@0?ooo`<000003P3o
ool3000000@0ojX000@000000?n]003o[@00ojd00`0000040?na00040000
003o^P00okX00?nj00@000000P3oc0000`000000omd00?oM00020?oM0003
0000003og@00omd00080omd00P0000050?oC00030000003o]00000000080
oid00P0000020?mi00040000003oPP00oh800?n200D000000P3oO0001000
0000oh@00?n4003oQ00500000080ohH000<000000?n>003oSP000P3oSP04
00000080oi8000<000000?nH003oV0000`3oV003000000<0oid000<00000
0?nP003oX0000P3oX003000000<0ojD000<000000?nV003oYP000P3oYP04
00000080ojT00P0000030?nZ00@000000P3o[0000`000000oj`00?n/0002
0?n/00<00000103o[@0010000000ojd00?n]003o[@02000000<0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0F0?ooo`00[P3oool2
000000<0oooo00<000000?ooo`3oool0203oool300000080ojL000<00000
0?nZ003oZP000`3oZP0300000080oj/000<000000?na003o/@000`3o/@03
00000080okX000<000000?o<003oc0000P3oc0001@000000omd00?oM003o
g@0000000080omd00P0000020?_o00030000003od`00om<0008000000`3o
]002000000@0ogT0100000030?ma00040000003oO000og`00?ml00@00000
0`3oOP001@000000ohH00?n6003oQP0000000080ohh00P0000020?n<0003
0000003oTP00oi800080oi8000<000000?nH003oV0000P0000000`3oV@00
00000?nM00030?nM00030000003oX000oj000080000000<0oj800000003o
Y@000`3oY@000`000000ojH00?nV000200000080ojP000@000000?nY003o
Z@00ojT00P0000000`3oZP000000000000020?n/00050000003o[000oj`0
0?n/000000000P3o[00200000080ojd000<000000?n]003o[@000P3o[@04
00000080ojh000<000000?ooo`3oool00P00000M0?ooo`030000003oool0
000001L0oooo002[0?ooo`<000003P3oool2000000030?nV00000000ojL0
00<0ojL000<000000?nZ003oZP000P0000000`3oY`0000000?n[00030?n[
00030000003o/@00ok400080000000<0ojh00000003o^P000`3o^P001@00
0000ol`00?o<003oc000000000<0omd00`0000040?_o00030000003od`00
000000<0ok@0200000020?mN008000000`3oL@0400000080og<000<00000
0?mn003oOP000P3oOP0010000000ohH00?n6003oQP03000000@0oh`000@0
00000?nB003oTP00oi80100000030?nI00040000003oW@00oid00?nM00@0
00000`3oXP0010000000ojD00?nU003oY@04000000@0ojP000@000000?nY
003oZ@00ojT00`0000040?n/00040000003o[000oj`00?n/00<00000103o
[@000`000000ojd00?n]000200000080ojh000D000000?n^003o[P00ojh0
000000030?ooo`030000003oool0oooo01X0oooo00@000000?ooo`3oool0
00005`3oool00:T0oooo0P00000>0?ooo`<00000103oYP0010000000ojL0
0?nW003oY`03000000@0ojL000@000000?n[003oZ`00oj/00`0000040?n^
00040000003o^P00okX00?nj00P0000000<0nol00000003ko`001@3ko`05
00000080oa8000D000000?lh003o>000ocP0000000030?mN00D000000P3o
I@000`000000og<00?mc00020?mc00040000003oOP00ogh00?mn00@00000
0P3oP`02000000<0oh`0100000030?nC00030000003oV@00oiT00080oiT0
0`0000030?nO00030000003oXP00oj800080oj800`0000030?nW00030000
003oZ000ojP00080ojP0100000000`3o[0000000000000040?n/00@00000
0P3o[@000`000000ojd00?n]00020?n]00<00000103o[P0010000000ojh0
0?n^003o[P02000000<0oooo00<000000?ooo`3oool0603oool300000003
0?ooo`000000000001H0oooo002V0?ooo`<000003P3oool200000080ojD0
00<000000?nV003oYP000P3oYP0400000080ojD000<000000?nW003oY`00
0`3oY`0300000080ojL00P0000030?n^00@000000P3o/`001@000000om<0
0?oC003od`00000000<0nol000<000000?_o003ko`000P3ko`001@000000
0?lf003o=P00ocH0000000<0oa80200000030?mC00050000003oI@00ofD0
0?mU000000000`3oL`0500000080ogT000<000000?n3003oP`000P3oP`04
00000080oh`000<000000?nC003oT`000P3oT`000`000000oiT00?nI0002
000000030?nK00000000oil000<0oil000<000000?nR003oXP000P000000
0`3oY@0000000?nW00030?nW00030000003oZ000ojP0008000000P3oZ`00
0`000000oj`00?n/000200000080oj`00P0000020?n^00050000003o[@00
ojd00?n]000000000P3o[@0200000080ojh000<000000?n^003o[P000P3o
[P0400000080ojh000D000000?ooo`3oool0oooo0000000e0?ooo`00Y03o
ool2000000h0oooo0`0000040?nU00030000003oYP00ojH0008000000P3o
Y0000`000000ojD00?nU00020?nU00030000003oY`00ojL00080000000<0
oj<00000003oY`000`3oY`0400000080ojD000<000000?nc003o/`000P3o
/`0010000000om<00?oC000000030?_o00030000003ko`00nol00080nol0
00@00000003o=P00ocH00?lf100000020?lT00050000003o>P00ocX00?lj
00000000103oD`0010000000ofD00?mU003oI@04000000<0ofd000D00000
0?mi003oN@00ogT0000000020?n3008000000P3oPP000`000000oh`00?n<
00020?n<00040000003oT`00oi<00?nC00<00000103oV`0010000000oil0
0?nO003oW`03000000<0ojD000<000000?nW003oY`000`3oY`02000000@0
oj/000@000000?n/003o[000oj`00`0000040?n^00040000003o[@00ojd0
0?n]00<00000103o[P000`000000ojh00?n^000200000080ojl000D00000
0?n^003o[P00ojh0000000030?ooo`030000003oool0oooo00H0oooo0P00
000[0?ooo`00X@3oool300000080oooo00<000000?ooo`3oool0203oool3
00000080ojD00P0000030?nU00<00000103oY00010000000ojD00?nU003o
Y@04000000<0oj<000<000000?nW003oY`000P0000020?nO00050000003o
Y@00ojD00?nU000000000`3o/`04000000030?oC00000000nol00080nol0
00@000000?_o003ko`0000001000ocH2000000@0ob@000<000000?lj003o
>P000P3o>P0010000000oe<00?mC003oD`0400000080oel000<000000?m]
003oK@000P3oK@0010000000ogT00?mi003oN@03000000@0oh8000@00000
0?n<003oS000oh`01@0000020?nE00030000003oV`00oi/00080oi/01000
00020?nR00030000003oY@00ojD00080ojD000<000000?nW003oY`000P00
00000`3oZP0000000?n[00030?n[00D0000000<0ojh00000003o[P000`3o
[P0400000080ojl000<000000?n^003o[P000P3o[P03000000@0ojl000@0
00000?n^003o[P00ojh00P0000030?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool00000:P3oool009l0oooo0P00000>0?ooo`800000
00<0ojD00000003oY@00103oY@0300000080oj<000<000000?nT003oY000
0`3oY003000000<0oj4000@000000?nS003oX`00oj<00`0000040?nO0004
0000003oY@00ojD00?nU00@000000`3oW@0400000080nol000<000000?_o
000000001@00ocH00`000000ob@0000000040?lT00040000003o>P00ocX0
0?lj00@000000P3oCP000`000000oel00?mO00020?mO00040000003oK@00
ofd00?m]00@000000P3oM`02000000<0oh80100000030?n=00050000003o
U@00oiD00?nE000000000P3oV`0200000080oih000D000000?nR003oXP00
oj80000000030?nU00@000000`3oZP000`000000oj/00?n[000200000080
ojh000D000000?n^00000000ojh0000000020?n^008000000P3o[`001@00
0000ojl00?n_003o[`0000000080ojh00P0000020?n_00030000003o[`00
ojl00080ojl0100000020?n_00050000003oool0oooo0?ooo`0000001@3o
ool010000000oooo0?ooo`00000Z0?ooo`00W03oool3000000d0oooo0`00
00040?nU00030000003oY@00ojD00080000000<0oj<00000003oX`000`3o
X`000`000000oj@00?nT0002000000030?nQ00000000oj4000@0oj400`00
00020?nM008000000`3oW`0400000080oiH00P0000020?nM008000000P3o
N@03000000030?_o00000000000000@00?lf00@000000?lT003o90000000
0`3o900500000080och000<000000?m>003oCP000P3oCP0010000000oel0
0?mO003oG`0400000080ofT000<000000?mg003oM`000P3oM`0400000080
oh<000<000000?n=003oS@000P3oS@0010000000oiD00?nE003oU@030000
00@0oih000@000000?nR003oXP00oj80100000030?nY00030000003oZP00
ojX00080ojX00P0000040?n^00040000003o[P0000000?n^00<00000103o
[`0010000000ojl00?n_003o[`03000000@0ojl000<000000?n_003o[`00
0P0000020?n`00050000003o[`00ojl00?n_000000000`3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000002X0oooo002I0?ooo`<0
00003@3oool300000080ojD000<000000?nU003oY@000`3oY@02000000@0
oj<000@000000?nS003oX`00oj<00`0000040?nQ00030000003oX@00oj40
0080000000<0oi`00000003oW@00103oW@0300000080oi@00P0000030?nF
00<00000103oN@000`000000oeh000000002000000D00?lf00@000000?lT
003o9000ob@00`0000030?lb00050000003o?P00och00?ln000000000`3o
CP0500000080oeX000D000000?mY003oJ@00ofT0000000020?mg00800000
0P3oM`001@000000oh<00?n3003oP`00000000<0ohd01@0000020?nI0003
0000003oWP00oih00080oih0100000020?nW00030000003oZ@00ojT00080
ojT000<000000?nZ003oZP000P0000000`3o[P0000000?n^00030?n^00@0
00000P3o/0000`000000ojl00?n_00020?n_00@000000P3o/0000`000000
ojl00?n_00030?n_00800000103o/00010000000ojl00?n_003o[`020000
00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000Z
0?ooo`00U`3oool2000000h0oooo0P0000000`3oY@0000000?nU00030?nU
00030000003oY@00ojD00080000000<0oj@00000003oX`00103oX`030000
0080oj400P0000030?nQ00<00000103oW0000`000000oid00?nM00020000
00030?nE00000000oi@000@0oi@00`0000020?n20080000000<0ogT00000
000000000`3oGP02000000D00?lf00H000000?lT0000000000000?lb0000
00040?lb00040000003o?P00och00?ln00@000000`3oB`0010000000oeX0
0?mJ003oFP07000000@0ogL000@000000?n3003oP`00oh<0100000030?nA
00050000003oV@00oiT00?nI000000000P3oWP02000000030?nT00000000
ojL000<0ojL000@000000?nY003oZ@00ojT0100000030?n^00030000003o
[P00ojh0008000000P3o/@001@000000ok000?n`003o/00000000080ojl0
0P0000020?na00030000003o/000ok000080ok0000<000000?n_003o[`00
0P0000000`3o/00000000?n`00030?n`00@000000P3o[`001@000000oooo
0?ooo`3oool0000000@0oooo0P00000[0?ooo`00U03oool3000000030?oo
o`000000oooo00X0oooo0`0000040?nU00040000003oY@00ojD00?nU00<0
0000103oY0000`000000oj<00?nS0002000000030?nQ00000000oj4000@0
oj400`0000020?nM00030000003oW000oi`000<0oi`00P0000040?nE0003
0000003oU000oi@00080000000<0ohP00000003oPP00103oPP000`000000
oeh00?mN00020?mN00<000001@00ocH2000000@0oc8000@000000?lb003o
<P00oc80100000020?lm008000000`3oB`0400000080oeL000@000000?mX
003oJ000ofP00P0000030?mg00@000000P3oQ`000`000000oi400?nA0002
0?nA00040000003oV@00oiT00?nI00<00000103oY0000`000000ojL00?nW
00020?nW00<000000`3o[@000`000000ojh00?n^00020?n^00800000103o
/@0010000000ok000?n`003o/003000000@0ok4000@000000?n`003o/000
ok00100000030?n`00030000003o/000ok000080000000<0ok000000003o
[`000`3o[`000`000000oooo0000000200000340oooo002B0?ooo`800000
3@3oool300000080ojH000<000000?nU003oY@000`3oY@0300000080oj@0
0P0000030?nT00<00000103oX@000`000000oj400?nQ0002000000030?nN
00000000oid000<0oid000<000000?nL003oW0000P0000000`3oU`000000
0?nE00040?nE00800000103oR0000`000000oh800?n20002000000030?ma
00000000oeh00080000000<0oe<00000000000001@00ocH2000000D0oc80
0`0000020?ld008000000`3o?@0400000080odD000<000000?mG003oE`00
0P3oE`0010000000ofP00?mX003oJ00400000080ogT000<000000?n7003o
Q`000P3oQ`0010000000oi400?nA003oT@0400000080oil000<000000?nT
003oY0000P3oY0000`000000ojL00?nW0002000000030?n/00000000ojd0
00<0ojd000<000000?n^003o[P000P0000000`3o/@0000000?na00030?na
00@000000P3o/P000`000000ok400?na00030?na00<000000P3o/P001000
0000ok000?n`003o/004000000@0ok0000<000000?n_003o[`000`000003
0?ooo`030000003oool0oooo02h0oooo002?0?ooo`<000003@3oool20000
00030?nV00000000ojH000<0ojH000<000000?nU003oY@000P0000000`3o
Y@0000000?nT00040?nT00<000000P3oXP000`000000oj400?nQ00030?nQ
00800000103oWP0010000000oid00?nM003oW@03000000@0oiL000<00000
0?nE003oU@000P0000000`3oS@0000000?n800020?n800@00000103oL@00
10000000oe<00?mC003oD`02000000D00?lf00<000000?ln000000000P3o
<P02000000030?ld00000000oc@000<0oc@0100000020?lf00050000003o
A@00odD00?m5000000000`3oE`0500000080ofP000D000000?mi003oN@00
ogT0000000030?n700D000000P3oV0000`000000oil00?nO00020?nO0004
0000003oY000oj@00?nT00<00000103o[00010000000ojd00?n]003o[@03
000000@0ok4000<000000?na003o/@000P0000000`3o]00000000?nb0003
0?nb00030000003o/@00ok400080000000<0ok<00000003o/P000`3o/P03
000000<0ok4000<000000?n`003o/0000P3o/003000000<0ok0000@00000
0?ooo`3oool00000<03oool008d0oooo0P00000>0?ooo`800000103oYP00
10000000ojH00?nV003oYP03000000@0ojD000<000000?nT003oY0000P00
00000`3oX`0000000?nR00030?nR00030000003oX@00oj400080000000<0
oil00000003oWP00103oWP0300000080oiT00P0000030?nG00<00000103o
S@03000000<0og`000<000000?ma003oL@000P000000103oI@0000000000
003oD`02000000D00?lf00<000000?ln003o?P000P0000030?ld00030000
003o=000oc@0008000000P3o;P001@000000ocH00?lf003o=P00000000<0
odD0100000030?mC00050000003oJ000ofP00?mX000000000`3oN@040000
0080ohh000<000000?nH003oV0000P3oV00010000000oil00?nO003oW`05
00000080ojX000<000000?n/003o[0000P3o[00400000080ok8000<00000
0?na003o/@000P3o/@0300000080ok@00P0000030?nb00@000000`3o/`00
0`000000ok800?nb0002000000030?nc00000000ok4000<0ok4000<00000
0?n`003o/0000P0000000`3o/@0000000?n`00030?n`008000000P3oool0
0`000000oooo0?ooo`0]0?ooo`00R`3oool2000000h0oooo0P0000000`3o
Y`0000000?nV00040?nV00<000000P3oY@000`000000ojD00?nU00030?nU
00800000103oX`0010000000oj800?nR003oXP03000000@0oil000<00000
0?nN003oWP000P0000000`3oV`0000000?nI00030?nI00@000000P3oT@00
0`000000ohd00?n=0002000000030?n400000000og`000@0og`00P000005
0?mU00<000001@00ocH3000000030?lm00000000oc@00080oc@00`000004
0?l^00040000003o=P00ocH00?lf00@000000P3o?@000`000000oe<00?mC
00020?mC00040000003oJ000ofP00?mX00@000000P3oO`000`000000ohh0
0?n>00020?n>00030000003oV000oiP00080oiP00`0000030?nW00050000
003oZP00ojX00?nZ000000000P3o[00200000080ok8000H000000?nb003o
/P00ok800000003o/@0300000080okD000D000000?nd003o]00000000?nd
0003000000<0ok@000<000000?nc003o/`000P3o/`02000000<0ok<000@0
00000?na003o/@00ok40100000030?na00030000003o/000ok0000800000
0P3o/00010000000oooo0?ooo`00000^0?ooo`00R`3oool2000000/0oooo
0`0000040?nW00030000003oYP00ojH00080000000<0ojH00000003oY@00
0`3oY@000`000000ojD00?nU0002000000030?nT00000000oj<000@0oj<0
0`0000020?nP008000000`3oW`03000000<0oi/000<000000?nI003oV@00
0P0000020?nD00030000003oT@00oi400080oi400P0000040?n400030000
003oO000og`00080000000<0og<00000000000000P3oI@02000000030?mO
00000000000000@00?lf0P0000040?lm00<000000P3o;P02000000<0obh0
100000020?lZ00030000003o?@00ocd00080ocd000@000000?mC003oD`00
oe<0100000020?m/00050000003oO`00ogl00?mo00000000103oSP000`00
0000oiP00?nH0002000000030?nR00000000ojL000<0ojL000@000000?nZ
003oZP00ojX00`0000040?nb00030000003o/P00ok8000@00000103o]@00
0`000000ok@00?nd0002000000030?ng00000000ok@000<0ok@000<00000
0?nc003o/`000P0000000`3o]00000000?nc00030?nc00<000000`3o/P00
0`000000ok400?na00020?na00800000103o/00010000000oooo0?ooo`00
000^0?ooo`00RP3oool2000000030?ooo`000000oooo00H0oooo0`000002
0?nW008000000`3oY`03000000@0ojH000@000000?nU003oY@00ojD00`00
00040?nT00030000003oX`00oj<00080000000<0oj800000003oX000103o
X00300000080oid000@000000?nK003oV`00oi/00`0000040?nD00030000
003oT@00oi400080000000<0oh/00000003oQ000103oQ002000000D0og<0
0P0000030?mO008000001000ocH200000080ocd00P0000000`3o=P000000
0?l^00040?l^00<000000P3o7P0010000000obX00?lZ003o:P0900000080
oe8000D000000?m/003oK000of`0000000040?mo00040000003oSP00ohh0
0?n>00<00000103oXP0010000000ojL00?nW003oY`0400000080ok8000<0
00000?nb003o/P000P3o/P0400000080okL000<000000?ne003o]@000P3o
]@0300000080okL00P0000030?nd00@000000`3o]0000`000000ok<00?nc
0002000000030?nc00000000ok8000<0ok8000<000000?na003o/@000P00
00000`3o/@0000000?n`00030?n`008000000P3oool00`000000oooo0?oo
o`0[0?ooo`00R`3oool010000000oooo0?ooo`0000040?ooo`80000000<0
ojL00000003oY`00103oY`0300000080ojH000<000000?nV003oYP000`3o
YP0300000080oj@00P0000030?nT00<00000103oXP000`000000oj000?nP
0002000000030?nO00000000oid000<0oid00`0000020?nH00030000003o
U000oi@000<0oi@00P0000040?n;00030000003oQ000oh@00080000000<0
ogh00000000000000P3oL`02000000030?m]00000000oel00080oel00P00
0004003o=P040000003oB`000000000000@0ocH000<000000?l^003o;P00
0P0000000`3o7P0000000?lN00020?lN00@000000P3o5`02000000<0oc<0
00D000000?mB003oDP00oe80000000030?m/00T000000P3oV@000`000000
oj800?nR00020?nR00@000000P3o/@001@000000ok800?nb003o/P000000
0080ok800`0000000`3o^@0000000?ng00020?ng00030000003o]@00okD0
008000000P3o^@0010000000okL00?ng003o]`04000000<0okH000<00000
0?nd003o]0000P3o]002000000<0ok<000@000000?nb003o/P00ok801000
00030?na00030000003o/000ok00008000000P3o/00010000000oooo0?oo
o`00000/0?ooo`00RP3oool2000000<0oooo100000040?nW00030000003o
Y`00ojL00080000000<0ojL00000003oYP000`3oYP000`000000ojH00?nV
0002000000030?nU00000000oj@000@0oj@00`0000020?nS008000000`3o
XP03000000<0oil000<000000?nM003oW@000P0000000`3oV`0000000?nH
00030?nH00030000003oU000oi@00080000000<0oi400000000000000`3o
R`03000000D0ogh00P0000030?m]00030000003oG`00oel000<000001000
ocH2000000030?m500000000ocH000<0ocH00`0000040?lN00<000000P3o
2@02000000<0oaL0300000020?mf00030000003oR`00oh/00080oh/000D0
00000?nI003oV@00oiT0000000020?nR0080000000<0ojl00000003o/@00
0`3o/@0010000000ok800?nb003o/P03000000@0okT000@000000?ng003o
]`00okL00`0000040?ni00030000003o]`00okL00080000000<0okT00000
003o]P000`3o]P000`000000ok@00?nd0002000000030?ne00000000ok<0
00<0ok<00`0000030?nb00040000003o/@00ok400?na00<00000103o/000
10000000oooo0?ooo`00000/0?ooo`00RP3oool010000000oooo0?ooo`3o
ool200000080ojP00P0000030?nW00<00000103oY`0010000000ojH00?nV
003oYP03000000@0ojD000<000000?nT003oY0000P0000000`3oY0000000
0?nS00040?nS00<000000P3oX@000`000000oil00?nO00020?nO00800000
103oV`0010000000oiP00?nH003oV003000000D0oi400`0000020?n60080
00000P3oOP02000000030?mi00000000ofd000<0ofd00P0000000`3oFP00
000000000004003o=P040000003oA@00odD000000080ocH00P0000020?lZ
00030000003o7P00oah00080000000<0o`T00000000000000`3o2@040000
0080o`P000D000000?lY003o:@00obT0000000030?mF00050000003oMP00
ogH00?mf00000000103oR`0010000000oiT00?nI003oV@03000000@0ojl0
00<000000?na003o/@000P3o/@0300000080ok/000<000000?ni003o^@00
0`3o^@0300000080ok`000<000000?ni003o^@000P3o^@0300000080okT0
0P0000030?nf00@000000`3o]@000`000000ok<00?nc0002000000030?nd
00000000ok8000<0ok80100000020?na00030000003o/000ok000080ok00
0P0000000`3oool000000000000[0?ooo`00RP3oool4000000030?nX0000
0000ojP000<0ojP00`0000020?nW00030000003oY`00ojL000<0ojL00`00
00020?nV008000000`3oY@03000000@0oj@000<000000?nS003oX`000P00
00000`3oXP0000000?nQ00020?nQ00030000003oW`00oil00080000000<0
oid00000003oV`00103oV`0300000080oiD00P0000020?nA0080000000<0
ohh00000003oQP000`3oQP03000000<0ogT000<000000?m]003oK@000P00
00000`3oJ@0000000?mJ0002000000@00?lf00@000000?m5003oA@00odD0
0P0000050?lZ00800000103o2@0400000080oooo00@000000?l8003o2000
o`P00`0000000`3o:@0000000?mF00020?mF00030000003oMP00ogH00080
ogH000@000000?n;003oR`00oh/0100000020?nY00030000003o[`00ojl0
0080ojl000<000000?na000000000P0000000`3o_@0000000?nk00030?nk
00030000003o^@00okT00080000000<0okl00000003o_0000P3o_0000`00
0000okT00?ni000200000080ok`000@000000?ni003o^@00okT010000003
0?nh00040000003o]@00okD00?ne00<000000`3o]0000`000000ok800?nb
000200000080ok8000D000000?na003o/@00ok40000000020?n`00800000
00<0ok000000003oool00P3oool00`000000oooo0?ooo`0X0?ooo`00RP3o
ool2000000<0ojP000<000000?nX003oZ0000P0000000`3oZ00000000?nW
00030?nW00030000003oY`00ojL00080000000<0ojH00000003oYP00103o
YP0300000080ojD000<000000?nT003oY0000`3oY002000000<0oj8000@0
00000?nQ003oX@00oj400`0000040?nM00030000003oV`00oi/000800000
00<0oiT00000003oU@00103oU@02000000<0ohh000<000000?n6003oQP00
0P0000020?n300030000003oN@00ogT00080ogT00P0000040?mY00<00000
1000ocH01@000000odD0000000000000ocd0008000000P3o:P0200000004
0?lG00000000o`T00?l9008000001`3oool300000080o`403`0000020?nO
00050000003oZ@00ojT00?nY000000000`3o[`04000000<0okd000@00000
0?nk003o^`00ok/0100000030?no00040000003o_000ok`00?nl00<00000
103o_0000`000000okT00?ni0004000000@0okP0100000020?nf00030000
003o]000ok@00080ok@00P0000040?nb00040000003o/@00ok400?na00<0
0000103o/00010000000oooo0?ooo`00000Z0?ooo`00PP3oool2000000H0
oooo0`0000020?nX00<00000103oZ00010000000ojL00?nW003oY`030000
00@0ojH000<000000?nV003oYP000P0000000`3oYP0000000?nU00030?nU
00030000003oY000oj@00080000000<0oj<00000003oXP000`3oXP030000
0080oil00P0000030?nM00<00000103oV@000`000000oiD00?nE00020000
00030?nC00000000ohh000<0ohh00P0000040?n300030000003oN@00ogT0
0080000000<0ogL00000003oJ@00103oJ@02000000@00?lf0P0000050?lm
00800000103o5`02000000X0oooo00D000000?l1003o0@00o`4000000002
0?lZ00030000003oI`00ofL00080ofL000D000000?n;003oR`00oh/00000
00040?nO00040000003oZ@00ojT00?nY00@000000`3o_P000`000000okd0
0?nm00020?nm00<000000`3oa0000`000000okl00?no00020?no00<00000
0P3o`00010000000ok`00?nl003o_00400000080ok/00P0000020?nh0080
000000<0okP00000003o]P000`3o]P000`000000ok@00?nd000200000003
0?nd00000000ok8000<0ok80100000020?na00040000003o/000ok000?n`
008000000`3oool00`000000oooo0?ooo`0W0?ooo`00P@3oool010000000
oooo0?ooo`0000040?ooo`8000000P3oool200000080ojP000<000000?nX
003oZ0000`3oZ00300000080ojL00P0000030?nV00<00000103oYP001000
0000ojD00?nU003oY@03000000<0oj<000<000000?nR003oXP000P000000
0`3oX@0000000?nO00040?nO00<000000P3oW002000000<0oiT00`000003
0?nC00030000003oSP00ohh00080000000<0oh`00000003oP`00103oP`02
000000@0ogL000<000000?mY003oJ@0010000004003o=P<000000P3o?@02
000000040?lc00000000oaL00?lG0080000000<0o`P00000000000002@3o
ool010000000o`400?l1003o0@0200000080obX000D000000?mW003oI`00
ofL0000000040?n;00030000003oW`00oil00080oil0100000000`3o_P00
00000?nn00030?nn00030000003o_@00okd000<000001@3oa0000`000000
okl00?no0002000000030?o500000000ol0000<0ol000`0000030?nn0004
0000003o^`00ok/00?nk00<00000103o^0000`000000okH00?nf00040000
00<0ok@000<000000?nb003o/P000P0000020?nb00030000003o/@00ok40
0080ok400`0000020?n_00050000003oool0oooo0?ooo`000000:03oool0
0840oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`02
0?ooo`050000003oZ000ojP00?nX000000000P3oZ002000000030?nW0000
0000ojL000@0ojL00`0000020?nV00030000003oYP00ojH000<0ojH00`00
00020?nT00040000003oX`00oj<00?nS00<00000103oX@000`000000oil0
0?nO0002000000030?nO00000000oi`000@0oi`00`0000020?nH00030000
003oT`00oi<00080oi<00P0000040?n<00030000003oP`00oh<000800000
00<0oh800000003oM`00103oM`0200000080ofP00P000003003o=P040000
003oD`00oe<00?mC00800000103o<`02000000D0o`P000<000000?ooo`3o
ool01`3oool300000080oa000`0000040?mW00050000003oR`00oh/00?n;
000000000P3oW`03000000@0okh000<000000?nn003o_P000`3o_P020000
00<0olT000<000000?o4003oa0000P3oa003000000<0olD000<000000?o0
003o`0000P0000000`3o``0000000?nn00030?nn00030000003o^`00ok/0
00@00000103o^003000000<0okH000@000000?nd003o]000ok@00`000004
0?nb00030000003o/@00ok400080000000<0ok000000003o[`000P3o[`00
1@000000oooo0?ooo`3oool0000002P0oooo00210?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000ojP00?nX
0003000000@0ojL000<000000?nW003oY`000P0000000`3oY`0000000?nV
00030?nV00030000003oYP00ojH00080000000<0ojD00000003oY0000`3o
Y00300000080oj<00P0000030?nQ00<00000103oW`000`000000oi`00?nL
0002000000030?nL00000000oiP00080oiP000<000000?nC003oT`000P00
00000`3oTP000000000000030?n<00<00000103oPP000`000000ogL00?mg
0002000000040?mg00000000ofP00?mX008000000`00ocH01P000000oe<0
0?mC00000000oe80000000<0oc<000@000000?lY0000000000000P3o2002
000000030?l100000000oooo00P0oooo00H000000?l@003o4000oa000000
003oD00=00000080ok/000<000000?nn003o_P000P3o_P000`000000okh0
0?nn0002000000030?o@00000000olT00080olT000<000000?o4003oa000
0P0000020?o<00030000003oa@00olD00080olD00P0000030?o300040000
003o_P00okh00?nn00@000000`3o^`000`000000okP00?nh000200000003
0?nh00000000okH000<0okH0100000020?nc00040000003o/P00ok800?nb
00@000000`3o/00010000000ojl00?n_003o[`02000000<0oooo00<00000
0?ooo`3oool09@3oool00840oooo00@000000?ooo`3oool00000103oool2
000000D0oooo0P0000020?nX008000000`3oY`03000000@0ojL000@00000
0?nV003oYP00ojH00`0000040?nU00060000003oY00000000000003oY000
00001@3oX`0300000080oj4000<000000?nO003oW`000`3oW`02000000<0
oi`000@000000?nH003oV000oiP00`0000050?nB00<000000P3oS0020000
00<0oh800`0000040?mg00@000000`00ocH300000080oe8000@000000?lc
000000000000103o:@02000000<0o`4000<000000?ooo`3oool01`3oool0
0`000000oa000?l@00020?l@00040000003oD000oe00000000<0oi<01@00
00040?nk00040000003o_P00okh00?nn00@000000`3od00010000000olT0
0?o9003ob@03000000@0ol`000<000000?o5003oa@000P0000000`3ob@00
00000?o300030?o300<000000`3o_`0010000000ok/00?nk003o^`030000
00<0okP000<000000?nf003o]P000P0000020?ne00030000003o/`00ok<0
0080ok<00`0000020?na00030000003o/000ok000080ok00100000020?n_
00040000003oool0oooo000002L0oooo00220?ooo`8000001@3oool00`00
0000oooo0?ooo`050?ooo`030000003oZ000ojP00080ojP00`0000020?nW
00030000003oY`00ojL000<0ojL00`0000020?nV008000000`3oY@020000
00@0oj@000<000000?nS003oX`000P0000000`3oX`0000000?nQ00030?nQ
00030000003oW`00oil00080000000<0oil00000003oW0000`3oW0030000
0080oiP00P0000020?nB0080000000<0oi<00000003oS000103oS0030000
0080oh<000<000000?mg003oM`000P000000103oN@000000000000000003
003o=P030000003oDP00oe8000<0oe8000<000000?lY003o:@000`3o:@00
0`000000obX0000000030?l100800000203oool4000000060?l@00000000
oe000?m@00000000oi<0100000030?n_00030000003o^`00ok/00080ok/0
0`0000030?oG00030000003od000om000080om000`0000020?oD00030000
003oc000ol`00080ol`00`0000030?o900030000003o``00ol<000800000
00<0olD00000003o_`000`3o_`04000000030?nk00000000000000<0okP0
0`0000040?ne00030000003o/`00ok<00080000000<0ok<00000003o/@00
0`3o/@0010000000ok000000000000020?n`00030000003o[`00ojl00080
ojl000@000000?ooo`3oool000009P3oool008T0oooo00<000000?ooo`3o
ool01@3oool00`000000ojP00?nX0002000000030?nX00000000ojL000<0
ojL000<000000?nW003oY`000P0000000`3oY`0000000?nV00040?nV00<0
00000P3oY@0010000000oj@00?nT003oY003000000@0oj<000@000000?nQ
003oX@00oj400`0000030?nO00030000003oW000oi`00080000000<0oi`0
0000003oV000103oV002000000@0oi<000<000000?n<003oS0000P000000
0`3oS@0000000?n300030?n300800000103oN@02000000<00?lf0P000003
0?mB00030000003oEP00000000<0obT000@000000?lZ003o:P00obX00`00
00020?l@00030000003oool0oooo0080oooo0`000000103oB@0000000?nT
003oY006000000<0oi<000D000000?n_003o[`00ojl0000000020?nk0080
000000<0omh00000003oe`000`3oe`000`000000om000?o@000200000003
0?oP00000000om@00080om@000<000000?o<003oc0000P0000020?oB0003
0000003ob@00olT00080olT00P0000030?o500030000003o_`00okl00080
00000P3o_`0010000000ok/00?nk003o^`0400000080okP000@000000?ne
003o]@00okD0100000030?nc00040000003o/@00ok400?na00<00000103o
/0000`000000ojl00?n_0002000000030?n^00000000oooo008000009@3o
ool008P0oooo0P0000080?ooo`800000103oZ00010000000ojL00?nW003o
Y`03000000@0ojL000<000000?nV003oYP000P0000000`3oYP0000000?nU
00030?nU00<000000P3oY0000`000000oj<00?nS00030?nS00<000000P3o
X@0010000000oil00?nO003oW`03000000@0oi`000<000000?nH003oV000
0P0000000`3oV@0000000?nC00040?nC008000000`3oS@000`000000oh<0
0?n30002000000030?n700000000ogT000<0ogT00P000003003o=P800000
00<0oe800000000000000`3oEP000`000000obT0000000030?lZ00800000
103o40000`000000oooo0?ooo`02000000050?m900000000odT00?m90000
00000P3oY006000000@0oi<000<000000?n_003o[`000`0000030?oN0003
0000003oe`00omL000<0omL00P0000030?oP00040000003oe000om@00?oD
00<00000103odP000`000000olT00?o90002000000030?o<00000000olD0
00<0olD00P0000040?no00030000003o^`00ok/00080000000<0ok/00000
003o^0000`3o^003000000<0ok@000<000000?nc003o/`000P3o/`030000
0080ok0000@000000?n`003o/000ok00100000030?n^00040000003oool0
oooo000002D0oooo00280?ooo`030000003oool0oooo00P0oooo0P000003
0?nX00@000000P3oY`02000000<0ojL00`0000030?nV00030000003oY@00
ojD00080000000<0ojH00000003oY0000`3oY0000`000000oj<00?nS0002
000000030?nS00000000oj4000<0oj400`0000020?nO008000000`3oW003
000000@0oiT000<000000?nC003oT`000P0000000`3oU@0000000?n=0003
0?n=00800000103oQ`000`000000ogT00?mi0003000000<00?lf00<00000
0?m/000000001P3oEP001@000000obX00?lZ003o:P0000000080oe0000<0
00000?l@003o40000P3o4002000000@0odT000<000000?m9000000000P00
00020?nT00030000003ob@00olT000P0000000<0on<00000003ogP00103o
gP000`000000omL00?oG0002000000030?o^00000000on0000<0on000`00
00020?oM008000000`3odP03000000<0ol`000<000000?o5003oa@000P00
00000`3oa@0000000?no00030?no00<000000P3o^`0200000080okP00P00
00000`3o]P0000000?nd00030?nd00030000003o/`00ok<00080000000<0
ok800000003o/0000`3o/00300000080ojl000@000000?n^003o[P00ojh0
0`0000020?ooo`030000003oool0oooo0280oooo00280?ooo`8000002`3o
ool300000080ojP000<000000?nW003oY`000`3oY`0300000080ojL00P00
00020?nV00<00000103oYP0010000000oj@00?nT003oY003000000@0oj<0
00H000000?nQ0000000000000?nR000000050?nO00<000000P3oW@000`00
0000oiT00?nI00030?nI008000000`3oU@000`000000ohd00?n=00020000
00030?nA00000000ohL000@0ohL00P0000000`3oO`00000000000003003o
=P80000000<0ogH00000003oEP000P3oEP02000000050?mW00000000obX0
0?lZ000000000P3oD00010000000oa000?l@003o4002000000@0odT00`00
00000`3oB@0000000?nT00030?nT00040000003ob@00olT0000000<0on40
00<000000?oS003oh`000P3oh`000`000000omh00?oN00020?oN00<00000
0`3okP000`000000on000?oP0002000000030?o]00000000omd000<0omd0
100000020?oE00040000003oc000ol`00?o<00<000000`3oa@000`000000
okl00?no000200000080okh000@000000?nk003o^`00ok/00`0000030?nf
00040000003o]000ok@00?nd00@000000`3o/P000`000000ok000?n`0002
000000030?n_00000000ojl000<0ojl00`0000030?n^00040000003oool0
oooo000002<0oooo00280?ooo`030000003oool0oooo00/0oooo00<00000
0?nX003oZ0000P3oZ0000`000000ojL00?nW0002000000030?nX00000000
ojL000@0ojL00P0000020?nV00030000003oYP00ojH000<0ojH00`000002
0?nU008000000`3oX`02000000@0oj8000<000000?nO003oW`000P000000
0`3oX00000000?nM00030?nM00030000003oV@00oiT00080000000<0oi/0
0000003oU@000`3oU@02000000@0oi4000<000000?n7003oQ`000P000000
0`3oSP0000000?mo0002000000800?lf00H000000?mf003oMP00ogH00000
003oEP02000000<0ofL000<000000?lZ00000000103oD003000000040?nT
00000000odT00?m9008000000P3oB@000`000000odT0000000040?nT0005
0000003ob@00olT00?o9000000000`3oh@001@000000on<00?oS003oh`00
00000080omh00P0000000`3mo`0000000?o^00040?o^008000000`3ok@00
0`000000omd00?oM000200000080on8000<000000?oE003oe@000P3oe@03
00000080ol`000@000000?o5003oa@00olD00`0000040?nn00030000003o
^`00ok/000@00000103o]P0300000080ok<000@000000?nb003o/P00ok80
100000030?n_00030000003o[`00ojl00080000000<0ojh00000003o[P00
0`3o[P0010000000oooo0?ooo`00000S0?ooo`00R03oool2000000d0oooo
00@000000?nX003oZ000ojP00`0000040?nX00030000003oY`00ojL00080
000000<0ojL00000003oYP000P3oYP000`000000ojH00?nV000200000003
0?nV00000000ojD000@0ojD00`0000020?nT00040000003oXP00oj800?nR
00<00000103oX00010000000oid00?nM003oW@03000000<0oi/000<00000
0?nE003oU@000P0000000`3oV@0000000?nA00040?nA008000000`3oSP00
10000000ogl0000000000002003o=P030000003oMP00ogH00080ogH000<0
00000?mW003oI`00103oI`000`000000oe000?m@00030?m@00040000003o
Y000oj@00?nT00<000000`3oB@04000000@0oj@000D000000?o9003ob@00
olT0000000030?oQ00030000003oh`00on<00080on<00P0000040?go0004
0000003okP00onh00?o^008000001@3ok@02000000@0on8000<000000?oE
003oe@000P0000000`3oe@0000000?o<00030?o<00<000000P3o``001000
0000okh00?nn003o_P0400000080okT00P0000020?nf0080000000<0ok@0
0000003o/`000`3o/`03000000<0ok0000@000000?n_003o[`00ojl00`00
00030?n^00040000003o[P00ojh00?n^00<000000P3oool00`000000oooo
0?ooo`0P0?ooo`00R03oool00`000000oooo0?ooo`0=0?ooo`<000000P3o
Z002000000<0ojP00`0000030?nW00040000003oYP00ojH00?nV00<00000
103oYP000`000000ojD00?nU0002000000030?nU00000000oj@000<0oj@0
0`0000020?nS00030000003oX000oj0000<0oj000`0000020?nO00040000
003oV`00oi/00?nK00<00000103oV@000`000000oi400?nA000200000003
0?nH00000000ohh000<0ohh00`000002003o=P030000003oMP00ogH00080
000000<0oh/00000003oI`000`3oI`02000000@0oe001@0000000`3oY000
00000?m900030?m900<0000000<0odT00000003oY0000P3oY0001@000000
olT00?o9003ob@00000000@0on4000H000000?oS0000000000000>?o0000
00040?go00040000003okP00000000000080oOl000L000000?o]003ok@00
ond00000003ol`00000000@0on800`0000030?oE00030000003oc000ol`0
0080000000<0olT00000003o``000`3o``03000000<0ok`000@000000?ni
003o^@00okT00`0000030?nd00030000003o/`00ok<00080000000<0ok40
0000003o/0000`3o/00400000080ojh000@000000?n^003o[P00ojh01000
00020?n]00050000003oool0oooo0?ooo`0000008@3oool008P0oooo00<0
00000?ooo`3oool03P3oool00`000000ojP00?nX00030?nX00<000000P3o
Z00010000000ojL00?nW003oY`0400000080ojL00P0000030?nV00<00000
0`3oY@000`000000oj@00?nT0002000000030?nU00000000oj<000<0oj<0
00<000000?nP003oX0000P0000000`3oXP0000000?nO00030?nO00<00000
0P3oWP02000000<0oiT00`0000030?nH00030000003oSP00ohh000800000
00<0oiT00000000000000P00ocH3000000<0oh/000D000000?mW003oI`00
ofL0000000020?nC00030000003oD000oe0000<00000103oY00020000000
odT00?m9003oB@000000003oR`0000000?n;0P0000030?nT00050000003o
b@00olT00?o900000000103oh@02000000<0hol000<000000?go003mo`00
0`3mo`000`000000oOl00?go00020?go00040000003ok@00000000000080
oo<000<000000?oR003ohP000P0000020?oR00030000003oe@00omD00080
omD00P0000030?o900030000003o``00ol<00080000000<0ol000000003o
_0000`3o_004000000030?ng00000000000000<0ok@00`0000030?na0003
0000003o/000ok000080000000<0ojl00000003o[P000`3o[P0400000080
ojd000<000000?n]003o[@000P3o[@0010000000oooo0?ooo`00000Q0?oo
o`00M03oool2000000@0oooo0P0000030?ooo`D00000103oool00`000000
oooo0?ooo`0?0?ooo`030000003oZ000ojP00080000000<0ojP00000003o
Z0000`3oZ00300000080ojP000<000000?nW003oY`000`3oY`0300000080
ojL000@000000?nU003oY@00ojD00`0000040?nU00040000003oX`00oj<0
0?nS00<000000`3oXP000`000000oil00?nO0002000000030?nR00000000
oih000@0oih00`0000020?nO00030000003oV000oiP00080oiP00P000003
0?nI008000000P00ocH00`000000oil0000000040?n;00030000003oI`00
000000<0oi<0100000000`3ob@0000000?nT00030?nT00080000003oB@00
odT00?m9000000000?n;00000000oh/2000000<0oj@000<000000?o9003o
b@000P3ob@000`000000on4000000002000000D0hol000<000000?go003m
o`000P0000000`3Oo`0000000?go00030?go00030000003ol`00oo<000<0
oo<00P0000040?oR00030000003oe@00omD00080000000<0om800000003o
b@000P3ob@03000000<0ol0000<000000?nl003o_0000P0000020?ni0004
0000003o]`00okL00?ng00@000000P3o/P0010000000ok400?na003o/@03
000000@0ojl000@000000?n^0000000000000P3o[@001@000000ojd00?n]
003o[@0000000080ojd00P000000103o[00000000?ooo`3oool2000001l0
oooo001c0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0A0?ooo`800000103oZ0001P000000
ojP0000000000000ojP0000000@0ojP000<000000?nW003oY`000P000000
0`3oY`0000000?nW00030?nW00<000000P3oYP000`000000ojD00?nU0003
0?nU00<000000P3oY@0010000000oj800?nR003oXP03000000@0oj8000<0
00000?nN003oWP000P0000000`3oY00000000?nO00020?nO00030000003o
V000oiP00080000000<0oj800000003oV@000`3oV@001P0000000?lf003o
=P000000oil0000000D0oh/000<000000?nC000000000P0000000`3oT`00
0000000000030?o900050000003oY000oj@00?nT000000000P3oB@001000
00000?n;003oR`000002003oR`030000003oY000oj@00080oj@000@00000
0?o9003ob@00olT00P0000030;ko00030000003So`00hol000<0hol00P00
00030=oo00030000003mo`00oOl00080000000@0l_l00000003ol`00oo<0
0P0000000`3ol`0000000?oR00030?oR00<00000103odP0300000080olD0
00@000000?o0003o`000ol000`0000040?ni00030000003o]`00okL00080
000000<0ok@00000003o/P000`3o/P0300000080ojl000@000000?n_003o
[`00ojl00`0000040?n]00040000003o[@00ojd00?n]00<000000`3o[000
0`000000oooo0?ooo`02000001l0oooo001c0?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B
0?ooo`8000000`3oZ002000000@0ojP000@000000?nX003oZ000ojP00`00
00040?nW00060000003oY`0000000000003oY`000000103oYP000`000000
ojD00?nU0002000000030?nV00000000ojD000<0ojD00`0000020?nU0080
00000`3oXP03000000<0oj@000@000000?nO003oW`00oil00`0000030?nR
00030000003oV@00oiT000<000000P00ocH010000000oil00?nO00000002
0?n;00@00000103oT`000`000000olT00?o900020?o900050000003oY000
oj@00?nT000000000P3oB@00100000000?n;003oR`000002003oR`800000
0`3oY0000`000000olT000000002000000@0__l000@000000>?o003So`00
hol00`0000050=oo00800000103bo`02000000<0oo<000<000000?oR003o
hP000P0000020?oM00030000003odP00om800080000000<0ol`00000003o
a@000`3oa@0300000080ok`000@000000?ni003o^@00okT0100000020?nd
008000000P3o/P02000000030?n`00000000ojl000<0ojl00`0000020?n]
00040000003o[@00ojd00?n]00D000000P3o[00010000000oj`00?n/003o
[00200000080oooo00<000000?ooo`3oool07@3oool007<0oooo00@00000
0?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`8000005@3o
ool300000080ojT000@000000?nX003oZ000ojP0100000020?nX00800000
0`3oY`02000000@0ojL000@000000?nV003oYP00ojH00`0000030?nV0003
0000003oY@00ojD00080000000<0ojL00000003oY@00103oY@0300000080
ojL000<000000?nT003oY0000P3oY00300000080ojL000<000000?nR003o
XP000P3oXP0200000080ojT000@00000003o=P00ocH000000`3oW`030000
0080ojl000@000000?nC003oT`00oi<00P0000040?o900050000003oY000
oj@00?nT000000000P3oB@00100000000?n;003oR`000003003oR`030000
003oY000oj@000<000000`24o`000`000000__l00;ko00020;ko00<00000
0`2co`001`000000gol00=oo003Oo`0000000<oo000000000`3bo`000`00
0000l_l0000000040?oc00800000103og@03000000<0ol`000<000000?o5
003oa@000P0000000`3o_`0000000?nl00020?nl00@000000P3o]@001000
0000ok@00?nd003o]004000000<0ok0000<000000?n_003o[`000P000000
0`3o[P0000000?n]00030?n]00<000000P3o[00010000000oj`00?n/003o
[00500000080oj/000@000000?ooo`3oool000007P3oool007<0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01D0oooo00<000000?nY003oZ@000P3oZ@0300000080ojT0
00<000000?nX003oZ0000`3oZ00300000080ojP000@000000?nW003oY`00
ojL0100000020?nX00040000003oYP00ojH00?nV00<00000103oY`000`00
0000ojD00?nU0002000000030?nY00000000ojL00080ojL000<000000?nT
003oY0000P0000000`3oZP0000000?nW00020?nW00030000003oXP00oj80
0080000000L0ojl00000003oZ@00ojT000000000ocH000000080oil00`00
00040?n_00060000003oT`0000000000003oh@000000103ob@000`000000
oj@00?nT00020?nT008000000`00oh/0100000000?n;003oR`00oh/30000
000300_o00000000Q?l000<0Q?l000<000000;ko002no`000P2no`000`00
0000/ol00;?o00030;?o00040000003Oo`00000000000080col000@00000
0?;o0000000000000P3bo`000`000000oo<00?oc0002000000040?o]0000
0000omd00?oM008000000P3oe00010000000ol`00?o<003oc003000000@0
okl00`0000020?ng00040000003o]@00okD00?ne00@0000000@0ok400000
003o/@0000000`3o/003000000<0ojh000<000000?n]003o[@000P000000
0`3o[00000000?n/00030?n/00<000000P3oZ`000`000000oj/00?n[0002
0?n[0080000000<0oooo0000003oool01P3oool4000001<0oooo001d0?oo
o`8000002P3oool2000000D0oooo00<000000?ooo`3oool05P3oool01P00
0000ojT0000000000000ojT0000000@0ojT000<000000?nX003oZ0000P00
00000`3oZ@0000000?nX00030?nX00<000000P3oZ@000`000000ojP00?nX
00020?nX00<000000P3oZ002000000<0ojL00`0000030?nY00040000003o
Y`00ojL00?nW00<00000103oZP000`000000ojL00?nW0003000000@0ojl0
00@000000?nY000000000?lf0`0000030?nk00030000003o[`00ojl00080
ojl000<000000?oQ003oh@000P3oh@001@000000olT00?o9003ob@000000
00@0oj@00P000003003oR`0500000000oh/00?n;003oR`0000000`0;o`00
0`000000Q?l008Co000208Co00070000002no`00__l00;ko00000000LOl0
000000050;?o00030000003?o`00col000<0col000<000000?;o003bo`00
0`3bo`02000000@0ond00P0000040?oD00@000000P3oa0000`000000okl0
0?no0002000000030?ni00000000okL000<0okL00`0000020?na00040000
003o/@00ok400?na00D000000P3o[P0010000000ojh00?n^003o[P030000
00<0oj`000<000000?n/003o[0000P0000000`3oZ`0000000?n[00030?n[
00060000003oZ`0000000000003oZ`0000000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01@0oooo00260?ooo`8000006@3oool0
0`000000ojT00?nY00020?nY00040000003oZ@00ojT00?nY00<000000`3o
Z@000`000000ojP00?nX0002000000030?nY00000000ojT000<0ojT000H0
00000?nX0000000000000?nY000000050?nX00<000000P3oZP000`000000
ojT00?nY00020?nY00<000000P3o[0000`000000ojX00?nZ00030?nZ0080
00000P3o/@000`000000ojl00?n_00030?n_00@0000000<0okh00000003o
^`000P3o^`000`000000ojl00?n_0003000000@0on4000D000000?o9003o
b@00olT0000000040?nT000300000000oh/00?n;00800?n;00D00000003o
R`00oh/00?n;0000000300_o000300000024o`00Q?l00080Q?l000@00000
0;ko002no`0000000P1ao`000`000000/ol00;?o00020;?o00030000002I
o`00000000<0col000<000000<oo000000000P3bo`02000000040?go0000
0000ond00?o]0080000000@0on000000003oe000om@00P0000020?o90004
0000003oa000ol@00?o400<000000`3o^@000`000000okL00?ng00020000
00030?nb00000000ok4000<0ok400`0000000`3o[P000000000000030?n^
00D000000P3o[00010000000oj`00?n/003o[003000000<0oj/000@00000
0?n[003oZ`00oj/00`0000040?n[00040000003oool0oooo000000H0oooo
00<000000?ooo`3oool04`3oool008H0oooo00<000000?ooo`3oool06@3o
ool010000000ojT00?nY003oZ@0400000080ojT00P0000020?nY00<00000
103oZ@0010000000ojT00?nY003oZ@02000000@0ojT000<000000?nX003o
Z0000P0000000`3oZ`0000000?nZ00020?nZ00030000003oZ@00ojT00080
000000<0ojd00000003o[0000`3o[0000`000000ojX00?nZ000200000003
0?nb00000000ok400080ok4000<000000?n_000000000P0000001P3o_P00
0000003o=P000000okh0000000<0ok/00`0000030?oS00050000003oh@00
on400?oQ00000000103ob@001@000000oj@00?nT003oY000000000@00?n;
00D00000003oR`00oh/00?n;0000000400_o000300000024o`00Q?l00080
Q?l00P000004077o00040000002co`00/ol000000080VOl000@000000<oo
0000000000000`3?o`02000000@0oOl00P0000040?oP00800000103ob@04
00000080ok/000@000000?ni003o^@00okT00`0000030?nb00030000003o
/@00ok400080000000<0ojh00000003o[P000P3o[P0400000080oj`000<0
00000?n/003o[0000P3o[00400000080oj/000@000000?n[003oZ`00oj/0
100000020?nZ00040000003oZ`00oj/00?n[008000000P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0180oooo00260?ooo`030000
003oool0oooo01X0oooo0`0000020?nZ00030000003oZ@00ojT000<0ojT0
0P0000020?nZ008000000`3oZ@0400000080ojX000@000000?nY003oZ@00
ojT00`0000030?n[00040000003oZP00ojX00?nZ00<00000103o[@001000
0000oj`00?n/003o[003000000<0ok8000<000000?na003o/@0010000003
0?nn000400000000ocH000000?nn00@0000000<0omh00000003oh`000`3o
h`001@000000on400?oQ003oh@00000000@0olT000<000000?nT00000000
0P000004003oR`0500000000oh/00?n;003oR`000000100;o`000`000000
Q?l008Co000208Co00030000001ao`00LOl000<0LOl000<000000;?o0000
0000102Io`000`000000col00<oo00020<oo00030000003Oo`0000000080
oOl00P000000103okP0000000?oP003oh002000000040?o@00000000olT0
0?o9008000000P3o_@000`000000ok/00?nk00020?nk00<000000P3o/P00
10000000ok800?nb003o/P03000000<0ojh000<000000?n^003o[P000P00
00000`3oZ`0000000?n/00030?n/00060000003o[00000000000003oZP00
0000103oZ`0400000080ojX000@000000?nZ003oZP00ojX0100000020?nZ
00040000003oool0oooo000000@0oooo00@000000?ooo`3oool000004`3o
ool008H0oooo0P00000L0?ooo`030000003oZP00ojX00080ojX000<00000
0?nY003oZ@000P0000000`3oZP0000000?nZ00030?nZ00<000000P3oZ`00
0`000000ojX00?nZ00020?nZ00<000000P3o[00200000080oj/010000002
0?n^008000000`3o[@0400000080ok8000@000000?nb003o/P00ok801000
00020?nm00060000003o_P00okh00?nn000000000?lf0P0000000`3oe`00
00000?oN00030?oN00030000003oh`00on<00080on<000D000000?oQ003o
h@00on40000000020?o900<000000P0;o`000`0000000?n;003oR`02003o
R`0500000000oh/00?n;003oR`000000100;o`0010000000Q?l008Co0024
o`02000000H0LOl000<0000009Wo002Io`000P2Io`0010000000VOl00000
003?o`02000000<0gol00P0000040?o^008000000`3od003000000@0okd0
00<000000?nk003o^`000P0000000`3o/P0000000?nb00020?nb00@00000
0P3o[@0010000000ojh00?n^003o[P0300000080oj/00P0000030?n/00<0
0000103oZP001P000000oj/0000000000000ojT0000000@0ojX010000002
0?nY00030000003oZP00ojX00080ojX0100000040?ooo`800000503oool0
08H0oooo00<000000?ooo`3oool0703oool010000000ojX00?nZ003oZP03
000000<0ojX000<000000?nZ003oZP000P0000000`3oZ`0000000?n[0002
0?n[00030000003oZP00ojX00080000000<0oj`00000003o[000103o[002
00000080ojh000<000000?n^003o[P000`3o[P0300000080ok8000<00000
0?nb003o/P000P3o/P0300000080ok/000D000000?nm003o_@00okd00000
00020?nn0080000000<00?lf0000003oe`000P3oe`001@000000omh00?oN
003ogP00000000<0on<0200000000`24o`00000000_o000200_o00030000
0000oh/00?n;00<00?n;00@00000003oR`00oh/00000100;o`001`000000
Q?l008Co0024o`00000000?o00000000101ao`000`000000BOl000000002
09Wo00050000002Io`00VOl009Wo00000000103Oo`000`000000oOl00000
00020?o^0080000000<0omL00000000000000P0000020?nn00040000003o
_@00okd00?nm00@000000`3o/P0400000080oj`000@000000?n]003o[@00
ojd0100000020?nZ00040000003oZ`00oj/00?n[00@000000P3oZ@001000
0000ojX00?nZ003oZP03000000@0ojT000H000000?nZ0000000000000?nY
000000040?nY00030000003oZP00ojX00080000000@0ojT00000003oool0
00006P3oool008H0oooo0P00000N0?ooo`<000000P3oZ`0010000000ojX0
0?nZ003oZP03000000@0oj/000<000000?n[003oZ`000`0000040?n/0003
0000003o[000oj`00080000000<0ojh00000003o[P000P3o[P000`000000
ojh00?n^0002000000030?na00000000ok800080ok8000<000000?nb0000
00000P0000000`3o^@0000000?nk00020?nk00040000003o_@00okd00?nm
00<0000000@0om0000000000ocH000000`3oe`0010000000omh00?oN003o
gP0400000080hol000@000000;ko002no`0000001024o`00100000002ol0
00_o00000005003oR`0500000000oh/00?n;003oR`0000000`0;o`001000
0000Q?l008Co0000000200?o00050000001ao`00LOl0077o000000000P19
o`000`000000VOl00000000309Wo00040000002co`0000000=oo00800000
0P3mo`0300000080omL00P0000000`3o_P0000000?nn00020?nn00@00000
0P3o/@000`000000ok800?nb000200000080ojX000<000000?n/003o[000
0P3o[00300000080ojT000@000000?nZ003oZP00ojX0100000000`3oZ000
0000000000030?nY00@000000P3oZ@0010000000ojT00?nY003oZ@030000
00@0ojT000<000000?nY003oZ@00100000030?nY00040000003oool0oooo
000001T0oooo00250?ooo`800000803oool200000080oj/0100000020?n[
008000000`3oZ`0300000080oj`00P0000030?n/00<000000`3o[P001000
0000ojh00?n^003o[P03000000<0ok4000<000000?nb003o/P0010000003
0?ni00040000003o^`00ok/00?nk00@000000P3ob@001@000000om000000
0000ocH0000000<0omL0100000020?go00050000003So`00hol00>?o0000
00000`2no`001@000000Q?l008Co0024o`00000000<02ol000<00000003o
R`00oh/00P00oh/01@0000000?n;003oR`00oh/0000000<02ol000@00000
08Co0024o`0000000P03o`0010000000LOl0077o0000000404Wo00050000
002Io`00VOl009Wo000000000`2co`0500000080omh00`0000030?nn00@0
00000P3o[`0010000000ok400?na003o/@03000000@0ojX000<000000?n/
003o[0000P0000000`3oY`0000000?nY00030?nY00<000000P3oY`001@00
0000ojP00?nX00000000ojP000<000000P3oZ00010000000ojT00?nY003o
Z@0400000080ojP000@000000?nY003oZ@00ojT0100000020?nY00040000
003oZ@00ojT00?nY00<000000P3oool00`000000oooo0?ooo`0F0?ooo`00
LP3oool2000000@0oooo0P0000030?ooo`@00000103oool00`000000oooo
0?ooo`0Q0?ooo`8000000P3oZ`000`000000oj/00?n[00030?n[00<00000
0P3o[00010000000oj`00?n/003o[00400000080ojh000@000000?n^003o
[P00ojh0100000020?na00040000003o/@00ok400?na00@000000P3o]`02
00000080okT0100000020?o400030000003ob@00olT00080olT01`000002
0?o^00050000003mo`00oOl00?go00000000103So`0010000000__l00;ko
0000000308Co00050000000;o`002ol000_o000000001000oh/01@000000
0?n;003oR`00oh/0000000@02ol00P00000400?o008000001019o`001@00
0000BOl00000002Io`00000000<0/ol00`0000000`3oh`00000000000002
00000080ok/0100000020?nY00040000003o[`00ojl00?n_00@000000P3o
Y`0010000000ojX00?nZ003oZP04000000<0ojL000<000000?nY003oZ@00
0P0000000`3oY@0000000?nW00020?nW00030000003oZ000ojP000800000
00<0ojH00000003oZ0000`3oZ00300000080ojL000@000000?nX003oZ000
ojP0100000020?nX00040000003oZ@00ojT00?nY00@000000P3oZ@001000
0000oooo0?ooo`00000H0?ooo`00L@3oool010000000oooo0?ooo`000008
0?ooo`030000003oool0oooo00D0oooo0P00000S0?ooo`050000003oZ`00
oj/00?n[000000000P3oZ`02000000030?n/00000000oj`000<0oj`00`00
00020?n]00030000003o[P00ojh00080ojh00`0000020?n`008000000P3o
/@05000000030?ne00000000okL000@0okL00P0000020?no00030000003o
a000ol@00080ol@000@000000?o9003ob@00olT00`0000020?oP00030000
003okP00onh00080onh000D000000?go003mo`00oOl0000000030>?o0005
0000002no`00__l00;ko000000000P24o`001@0000002ol000_o000;o`00
000000@00?n;00D00000003oR`00oh/00?n;0000000400_o008000001003
o`000`000000BOl004Wo000204Wo000500000019o`00BOl004Wo00000000
0P2co`0600000080ojl0100000020?nO00040000003oZ@00ojT00?nY00@0
00000P3oXP0010000000ojL00?nW003oY`0400000080oj@000@000000?nW
003oY`00ojL0100000030?nU00040000003oY`00ojL00?nW00<000000P3o
YP0200000080ojP00P0000000`3oYP0000000?nW00030?nW00<000000P3o
Y`000`000000ojP00?nX00020?nX00<000000P3oZ00010000000ojT00?nY
003oZ@0200000080oooo00<000000?ooo`3oool05@3oool00740oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0280oooo00@000000?n[003oZ`00oj/00`0000030?n/0003
0000003o[000oj`00080000000<0ojd00000003o[@000`3o[@001P000000
ojh0000000000000ojl0000000D0ok001@0000040?ne00030000003o]`00
okL00080000000<0ok`00000003o_`000P3o_`0010000000ol@00?o4003o
a004000000030?oD00000000000000<0on0000@000000?o^003okP00onh0
2P0000020;ko000500000024o`00Q?l008Co000000000P0;o`000`000000
0?n;003oR`02003oR`0500000000oh/00?n;003oR`000000100;o`000`00
00000ol000?o000200?o000300000000ob`0000000<0BOl000D0000004Wo
0019o`000000077o0003000000030?lZ00000000000000@000000P3oR`00
10000000oil00?nO003oW`0400000080oiT000@000000?nR003oXP00oj80
100000020?nO00040000003oY000oj@00?nT00@000000P3oXP0010000000
ojD00?nU003oY@0500000080ojD000@000000?nV003oYP00ojH00`000003
0?nV00030000003oY`00ojL00080000000<0ojL00000003oY`000P3oY`00
0`000000ojP00?nX0002000000030?nX00000000ojP000<0ojP00`000002
0?nX00040000003oool0oooo000001H0oooo001a0?ooo`040000003oool0
oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0S0?ooo`<000000P3o[00200000080oj`00`0000040?n]00040000003o
[@00ojd00?n]00800000103o[`000`000000ok000?n`0004000000<0ok@0
00@000000?ne003o]@00okD00`0000030?nl00040000003o_`00okl00?no
00@000000P3oc0000`000000om@00?oD0002000000<0on00100000020?go
00040000003Oo`00gol0000000<0/ol00`0000001@2no`00000008Co0024
o`00000000802ol000<00000003oR`00oh/00P00oh/01@0000000?n;003o
R`00oh/0000000@02ol000<0000000?o0003o`000P03o`001P0000000?l/
003o;0000000BOl000000080BOl000D00000077o001ao`0000000?l8000>
00000080oh/000@000000?nI003oV@00oiT0100000020?nH00040000003o
W`00oil00?nO00@000000P3oWP0010000000oj800?nR003oXP0400000080
oj8000@000000?nU003oY@00ojD01`0000030?nV00@000000`3oY`001000
0000ojL00?nW003oY`03000000<0ojP000<000000?nX003oZ0000P000000
0`3oZ00000000?nX00020?nX00040000003oool0oooo000001H0oooo001a
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0`3oool2000002H0oooo0P0000030?n/00<000000P3o[@02000000<0ojd0
100000020?n_00040000003o[`00ojl00?n_00<000000`3o/P0010000000
ok@00?nd003o]00400000080okT000@000000?nl003o_000ok`010000002
0?o500040000003oc000ol`00?o<00P000000P3ok@001@000000oOl00?go
003mo`00000000<0gol000H000000;?o002co`00/ol00000001ao`020000
0080Q?l000@0000000_o000;o`0000001000oh/01@0000000?n;003oR`00
oh/0000000<02ol000<00000003ob00000000P03o`000`0000000?l/003o
;002003o;00700000019o`00BOl004Wo00000000LOl0000000020?l80005
0000003o:@00obT00?lY000000000`3oEP001@000000ogH00?mf003oMP00
000000<0oh/0100000020?n>00040000003oV000oiP00?nH00@000000P3o
V@0010000000oih00?nN003oWP0400000080oil000@000000?nR003oXP00
oj80100000020?nS00040000003oY@00ojD00?nU00@000000P3oY@001000
0000ojL00?nW003oY`05000000030?nW00000000ojP00080ojP010000003
0?nX00040000003oZ000ojP00?nX0080000000<0oooo0000000000005@3o
ool00780oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`0V
0?ooo`<000000P3o[@0010000000ojd00?n]003o[@0400000080ojh000@0
00000?n_003o[`00ojl0100000020?na00040000003o/P00ok800?nb00@0
00000P3o]`0010000000okT00?ni003o^@0400000080ol0000<000000?o5
003oa@000P3oa@0300000080om800`0000000`3og@0000000?o]00020?o]
00040000003mo`00oOl00?go00<0000000<0gol00000002co`000P2co`00
0`000000LOl0077o00020000000508Co000000002ol000_o000000001000
oh/01@0000000?n;003oR`00oh/0000000<02ol000<00000003ob0000000
0P03o`002P0000000?l/003o;000ob`00000003o;0000000BOl00000001a
o`0D00000080ogl000@000000?n>003oSP00ohh0100000020?nA00040000
003oV@00oiT00?nI00@000000P3oV`0010000000oil00?nO003oW`040000
0080oj0000@000000?nS003oX`00oj<0100000000`3oY000000000000003
0?nU00@000000P3oYP0010000000ojL00?nW003oY`0400000080ojL000@0
00000?nX003oZ000ojP01@0000001@3oZ00000000?ooo`3oool0000001D0
oooo00240?ooo`030000003oool0oooo02P0oooo00<000000?n]003o[@00
0P3o[@0300000080ojh000<000000?n^003o[P000P3o[P04000000030?n`
00000000ok4000<0ok400`0000020?nd008000000P3o]`0400000080ok`0
00D000000?o0003o`000ol00000000020?o50080000000<0olT00000003o
dP000P3odP03000000030?oM00000000000000H000000P3bo`0500000080
/ol000<00000077o001ao`00100000000`0;o`000000003oR`03003oR`05
00000000oh/00?n;003oR`0000000`0;o`001@0000000?o800000003o`00
000000@00?l/00<00000003o;000ob`00`0000020?l900050000003o5`00
oaL00?lG000000000`3o<`001@000000oe800?mB003oDP00000000<0of`0
00@000000?mo003oO`00ogl0100000020?n700040000003oT@00oi400?nA
00@000000P3oU@000`000000oi/00?nK00020?nK00<000000P3oW@000`00
0000oj000?nP00020?nP00<000000P3oXP001@000000oj@00?nT00000000
oj@000<000000P3oY@000`000000ojH00?nV00020?nV00<000000P3oYP00
10000000ojL00?nW003oY`0400000080ojP000@000000?nX003oZ000ojP0
0P0000020?ooo`030000003oool0oooo0180oooo00240?ooo`800000:P3o
ool01P000000ojd0000000000000ojh0000000@0ojh000<000000?n^0000
00000`0000040?n`00060000003o/@0000000000003o/`0000001@3o]002
00000080okT000<000000?nl003o_0000P3o_0000`000000ol000?o00003
000000@0olT000<000000?oB003odP00100000020?oR00050000003ol`00
oo<00?oc000000000`3bo`0010000000col00<oo003?o`0400000080LOl0
00H0000000?o0003o`00000000_o00000004003oR`0500000000oh/00?n;
003oR`0000000`0;o`000`0000000?o8003ob002000000<00?l/00H00000
003o;000ob`0000000?o000000030?l900050000003o5`00oaL00?lG0000
00000`3o<`0010000000oe800?mB003oDP0800000080ogT000@000000?n7
003oQ`00ohL0100000020?n=00050000003oU@00oiD00?nE000000000P3o
V`02000000030?nI00000000oid00080oid000<000000?nP003oX0000P00
00000`3oW`0000000?nR00020?nR00030000003oY000oj@00080000000<0
oj<00000003oY@000P3oY@000`000000ojH00?nV0002000000030?nV0000
0000ojH000<0ojH00`0000020?nW00030000003oZ000ojP00080ojP00`00
00020?nX00040000003oool0oooo000001<0oooo00240?ooo`030000003o
ool0oooo02X0oooo00<000000?n^003o[P000P3o[P0010000000ojh00?n^
003o[P02000000@0ojl000@000000?n`003o/000ok000P0000040?nc0003
0000003o]000ok@00080000000<0okH00000003o^@000P3o^@0010000000
ok`00?nl003o_00300000080ol<00P0000030?o900<0000000<0omD00000
00000000103ohP000`000000oo<00?oc0007000000030<oo00000000VOl0
0080VOl00P000000101ao`00000000?o0000000200_o000500000000oh/0
0?n;003oR`0000000`00oh/0100000002ol000_o00000003003ob0030000
0000ob`00?l/00800?l/00H00000003o;000ob`0000000?o000000030?l9
00`000000P3oD`001@000000ofP00?mX003oJ000000000<0ogT010000002
0?n300050000003oS@00ohd00?n=000000000`3oU@03000000<0oiT000@0
00000?nM003oW@00oid00`0000030?nO00040000003oXP00oj800?nR00<0
00000P3oX`02000000<0ojD00`0000030?nV00030000003oYP00ojH00080
000000<0ojH00000003oY`000P3oY`000`000000ojP00?nX000200000003
0?nW00000000ojP000<0ojP000<000000?ooo`0000004`3oool008@0oooo
00<000000?ooo`3oool0:`3oool010000000ojh00?n^003o[P0400000080
ojl000@000000?n_003o[`00ojl0100000020?nb00040000003o/`00ok<0
0?nc00<000000`3o]P0010000000okT00?ni003o^@0400000080okh000@0
00000?o3003o``00ol<0100000020?o<00050000003oe@0000000?oE0000
00000`3ohP0300000080oo<000@000000?;o003bo`00l_l01@0000000`2I
o`00000004Wo0002000000800ol000<0000000_o000000000`00oh/01@00
00000?n;003oR`00oh/0000000802ol000@00000003ob000olP00?o80P00
0002003o;00700000000ob`00?l/00000003o`0000000?l9000300000080
oah000D000000?lZ003o:P00obX0000000030?lm00050000003oD`00oe<0
0?mC000000000`3oJ00400000080ogL000D000000?n3003oP`00oh<00000
00030?n=00@000000P3oT`0010000000oiT00?nI003oV@0400000080oi`0
00@000000?nO003oW`00oil0100000020?nQ00040000003oX`00oj<00?nS
00@000000P3oY00010000000ojH00?nV003oYP03000000<0ojH000@00000
0?nW003oY`00ojL00`0000030?nW00030000003oZ000ojP00080000000@0
ojP00000003oool000004P3oool008@0oooo0P00000]0?ooo`@0000000<0
ojh00000003o[`000P3o[`0400000080ok0000@000000?nb003o/P00ok80
100000020?nd00040000003o]P00okH00?nf00@000000P3o^`0010000000
okh00?nn003o_P0400000080olD000@000000?o<003oc000ol`020000002
0?oR00050000003ol`00oo<00?oc000000000`3bo`0700000080BOl000D0
000000?o000000002ol000000003003oR`0500000000oh/00?n;003oR`00
00000P0;o`00100000000?o8003ob0000002003ob@0300000000ob`00000
00800?l/1@0000040?lN00050000003o:P00obX00?lZ000000000`3o?@08
00000080ofP000@000000?mg003oM`00ogL0200000020?n<00040000003o
T`00oi<00?nC00@000000P3oV00010000000oi`00?nL003oW00400000080
oil000@000000?nQ003oX@00oj401@0000000`3oX`0000000?nT00020?nT
00@000000P3oY@0010000000ojH00?nV003oYP0400000080ojL000@00000
0?nW003oY`00ojL00`0000030?nX00040000003oool0oooo00000140oooo
00240?ooo`030000003oool0oooo02X0oooo1@0000020?n^00@000000P3o
/00200000080ok00100000020?nc008000000P3o]00400000080okP000@0
00000?nk003o^`00ok/0100000020?no00040000003oa@00olD00?o500@0
00000P3oc0001@000000omD00?oE003oe@00000000<0on80200000020?go
00@0000000<0VOl00000000000000`0000000`0;o`000000003oR`02003o
R`0300000000oh/00?n;00800?n;00<0000000_o000000000P00olP01@00
00000?o9003ob@00olT0000000800?l/00<0000000?o000000000`3o7P00
0`000000oah00?lN00020?lN00L000000P3oA@001@000000oeL00?mG003o
E`00000000<0ofP0100000020?mg00050000003oPP00oh800?n200000000
0`3oS00400000080oi8000@000000?nH003oV000oiP0100000020?nL0004
0000003oW`00oil00?nO00@000000P3oX@000`000000oj<00?nS00050000
00030?nT00000000ojD00080ojD01@0000000`3oYP0000000?nW00020?nW
00D0000000<0ojL00000003oZ0000P3oZ003000000030?ooo`000000oooo
0100oooo00240?ooo`800000:03oool3000000D0oooo0P0000020?n_0003
0000003o/000ok0000<0ok000P0000020?na00030000003o/`00ok<000<0
ok<00P0000020?ne008000000P3o^00400000080ok/000<000000?no003o
_`000P3o_`0300000080olD000D000000?o<003oc000ol`0000000030?oE
00@000000P3og@0010000000ond00?o]003ok@0@000000<00?n;00<00000
003oR`00oh/00P00oh/2000000800?o800P00000003ob@00olT00?o90000
0000olT00000003o;0<000000`3o7P000`000000oah00?lN000200000003
0?l^00000000ocH00080ocH000D000000?m5003oA@00odD0000000030?mG
00@000000P3oJ@001@000000ogL00?mg003oM`00000000<0oh8010000002
0?n<00040000003oTP00oi800?nB00@0000000<0oiP00000003oW0000`3o
W004000000030?nO00000000oj4000<0oj401P0000030?nT00@000000P3o
Y@0010000000ojH00?nV003oYP0400000080ojL000@000000?nW003oY`00
ojL0100000020?nX00040000003oool0000000000100oooo00230?ooo`80
00009P3oool3000000T0oooo00D000000?n_003o[`00ojl0000000020?n`
0080000000<0ok000000003o/@000P3o/@000`000000ok<00?nc00020000
00030?nc00000000okD000<0okD00P0000020?nh00030000003o^`00ok/0
0080ok/000H000000?no0000000000000?no000000030?o500040000003o
c000ol`00?o<00@000000P3odP0010000000omd00?oM003og@0400000080
on0000@000000?o^003okP00onh02P000003003oR`0300000000oh/00?n;
00800?n;0P000002003ob00500000000olT00?o9003ob@0000000P00olT4
000000<0oah00`0000030?l^00040000003o=P00ocH00?lf00P000000P3o
FP001@000000ofT00?mY003oJ@00000000<0ogL0100000020?n300040000
003oS000oh`00?n<00@0000000<0oi<00000003oV0000`3oV0001P000000
oi`0000000000000oi`0000000@0oil000H000000?nQ0000000000000?nQ
000000030?nS00@000000P3oY0000`000000ojD00?nU00020?nU00<00000
0P3oYP0010000000ojL00?nW003oY`0400000080ojL000@000000?nX003o
Z000ojP00P0000000`3oool000000?ooo`0?0?ooo`00L03oool2000000@0
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0R0?ooo`<0
0000303oool010000000ojl00?n_003o[`03000000<0ok0000@000000?na
003o/@00ok400`0000030?nc00030000003o]@00okD00080000000<0okH0
0000003o^0000P3o^00010000000ok/00?nk003o^`02000000@0okl000<0
00000?o5003oa@00100000020?o9008000000P3odP0400000080om@000@0
00000?oP003oh000on00100000020?oG00030000003ogP00omh000D00000
0`00oh/00`0000000?n;003oR`02003oR`80000000<00?o800000000olT0
0P00olT0100000000?o9003ob@00olT200000080obX00`0000020?l^0004
0000003o;P00obh00?l^00@000000P3o?@001@000000od/00?m;003oB`00
000000<0oeX0200000000`3oN@0000000?n300020?n300D0000000<0ohh0
0000003oT`000`3oT`000`000000oiP00?nH0003000000@0oi`000<00000
0?nO003oW`000`0000040?nQ00060000003oX`0000000000003oX`000000
0`3oY0000`000000ojD00?nU0002000000030?nV00000000ojH000<0ojH0
0`0000020?nW00030000003oY`00ojL00080ojL00`0000020?nX00800000
403oool006l0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000040?ooo`800000803oool300000100oooo0`0000020?n_0004
0000003o/000ok000?n`00@000000P3o/P0010000000ok<00?nc003o/`03
000000<0okH000@000000?nh003o^000okP0100000020?nk00040000003o
_`00okl00?no00<000000P3o``02000000<0olT00`0000020?o<00800000
0P3oe00400000080om0000@000000?oG003oe`00omL00`0000020?nk00<0
00000`00oh/00`0000000?n;003oR`02003oR`80000000D00?o800000000
olT00?o900000003003ob@0300000000olP000000080000000<0ocH00000
003o;P000`3o;P0300000080oc@000D000000?lm003o?@00ocd000000003
0?m;00@000000P3oG`001@000000ofd00?m]003oK@0000000080ogT01000
00020?n600030000003oSP00ohh00080ohh000<000000?nC003oT`001000
00020?nI00040000003oW000oi`00?nL00@000000P3oW`0010000000oj40
0?nQ003oX@0300000080oj<00P0000030?nT00<000000`3oYP000`000000
ojH00?nV0002000000030?nV00000000ojL00080ojL000<000000?nW003o
Y`000P0000000`3oZ00000000?nX00030?nX00030000003oool0oooo00h0
oooo001_0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0M0?ooo`800000503oool200000080
ojl0100000020?na008000000P3o/P0400000080ok@000@000000?nf003o
]P00okH0100000020?nh00040000003o^`00ok/00?nk00@000000P3o_P00
10000000ol<00?o3003o``0400000080olD000@000000?o<003oc000ol`0
0`0000020?o9008000000P3od004000000<0okh00P0000020?nO00800000
0P00oh/00`0000000?n;003oR`02003oR`0300000000olP0000000800?o9
00<00000003ob@00olT00P00olT00`0000000?o8000000030?lf00030000
003o;P00obh00080000000<0oc@00000003o=0000P3o=00010000000ocd0
0?lm003o?@0400000080odh000D000000?mO003oG`00oel0000000030?m]
00<000000P3oOP000`000000ohH00?n600020?n600030000003oSP00ohh0
00@000000P3oU@0010000000oiT00?nI003oV@0400000080oid000@00000
0?nO003oW`00oil0100000020?nR00040000003oX`00oj<00?nS00@00000
0P3oY@0010000000ojH00?nV003oYP03000000<0ojH000@000000?nW003o
Y`00ojL00`0000030?nX00030000003oZ000ojP000@000003`3oool006l0
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01X0oooo0`00000H0?ooo`8000000P3o/0020000
00<0ok400`0000020?nb008000000P3o]00400000080okH000@000000?nh
003o^000okP0100000020?nk00040000003o_P00okh00?nn00@000000P3o
`00010000000olD00?o5003oa@0400000080ol@000@000000?o9003ob@00
olT00`0000030?nn00@000000P3oZ@04000000800?n;00<00000003oR`00
oh/00P00oh/3000000800?o900D00000003ob@00olT00?o900000002003o
b0040000003o=P00ocH00?lf00<000000`3o=00010000000oc@00?ld003o
=00400000080och000D000000?m>003oCP00odh0000000030?mO00@00000
00<0og<00000003oOP000P3oOP0010000000ohH00?n6003oQP0400000080
oi4000@000000?nE003oU@00oiD0100000020?nK00040000003oW@00oid0
0?nM00@000000P3oX@0010000000oj800?nR003oXP05000000030?nT0000
0000ojD00080ojD0100000020?nV00040000003oYP00ojH00?nV00@00000
00<0ojL00000003oZ0000P3oZ004000000<0ojP000<000000?ooo`3oool0
3@3oool006l0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo01L0oooo0`00000L0?ooo`04
0000003o/000ok000?n`00@000000P3o/@0010000000ok800?nb003o/P03
00000080ok@00P0000020?nf00@000000P3o^00200000080ok/010000002
0?nl00040000003o`000ol000?o000@000000P3o_`0010000000ol@00?o4
003oa00400000080okd000<000000?nn003o_P000P000000103o[`000000
0?nY003oZ@02000000030?nI00000000000000800?n;00<00000003oR`00
oh/00P00oh/200000003002^o`000000000000@00?o900@00000003ob000
0000odD00`0000020?lm00040000003o=000oc@00?ld00@000000P3o<P00
10000000och00?ln003o?P08000000030?mU00000000og<000<0og<000<0
00000?mn003oOP00100000020?n;00040000003oT@00oi400?nA00@00000
0P3oV00010000000oi/00?nK003oV`0400000080oil000@000000?nQ003o
X@00oj40100000020?nS00030000003oY000oj@000D0000000<0ojD00000
003oYP000P3oYP05000000030?nW00000000ojL00080ojL0100000020?nX
00040000003oZ000ojP00?nX008000003`3oool00700oooo0P00000:0?oo
o`800000103oool00`000000oooo0?ooo`0E0?ooo`<00000803oool30000
0080ok0000<000000?na003o/@000P3o/@0300000080ok8000@000000?nd
003o]000ok@00`0000020?ne008000000`3o^00300000080okT00P000002
0?nl00@000000P3o_00010000000okl00?no003o_`0400000080ok/000@0
00000?nm003o_@00okd00`0000030?n_00<00000103oV@00100000000?n;
003oR`000004003oR`80000000@00:ko00000000[_l000000P00olT00`00
00000?o8003ob002000000030?m;00000000ocd000<0ocd00`0000020?lb
00P000000P3o>P0010000000oe<00?mC000000030?mU00P000000P3oQ000
10000000oh/00?n;003oR`0400000080oi@000@000000?nH003oV000oiP0
100000020?nM00030000003oW`00oil00080oil00`0000020?nR00040000
003oX`00oj<00?nS00H000000`3oY@0400000080ojH000@000000?nW003o
Y`00ojL0100000020?nW00040000003oZ000ojP00?nX00@0000000<0oooo
0000003oool03P3oool00880oooo00<000000?ooo`3oool04P3oool30000
02@0oooo00D000000?n`003o/000ok00000000020?na0080000000<0ok40
0000003o/P000`3o/P0300000080ok<000<000000?ne003o]@000P3o]@03
00000080okH000@000000?ni003o^@00okT00`0000020?ni008000000P3o
_00400000080okT000@000000?nk003o^`00ok/0100000020?na00@00000
0P3oXP000`000000oiT00?nI0003000000800?n;00@00000003oR`00oh/0
0?n;0P0000001@00[_l00000002^o`00[_l0000000800?o900@00000003o
b000olP000000P3oB`000`000000ocd00?lm0002000000040?ln00000000
oc800?lb0080000000<0ob@00000003o90000P3o900;00000080og4000D0
00000?ml003oO000og`0000000030?n400@000000P3oT@000`000000oi@0
0?nD00020?nD00<000000P3oV`001@000000oid00?nM003oW@0000000080
oil00`0000040?nR00@0000000<0oj@00000003oY0000P3oY00400000080
ojH000@000000?nV003oYP00ojH0100000020?nW00040000003oY`00ojL0
0?nW00@000001@3oool00`000000oooo0?ooo`0=0?ooo`00PP3oool20000
0100oooo0`00000X0?ooo`030000003o/000ok0000<000000`3o/@000`00
0000ok800?nb0002000000030?nb00000000ok<00080ok<000<000000?ne
003o]@000P0000000`3o]00000000?nf00030?nf00<000000P3o]`001000
0000okT00?ni003o^@0300000080okL00P0000020?ni00@000000P3o/P00
0`000000ok400?na0002000000030?nW00000000oj800080oj800`000002
0?n>000400000000oh/00?n;000000<00?n;00<00000002^o`0000001000
[_l2000000<00?o800<000000?m;003oB`000`0000040?ln00800000103o
900300000080oa8000@000000?lh003o>00000000`3oGP001@000000og40
0?ma003oL@00000000<0og`0100000020?n=00050000003oT@00oi400?nA
000000000P3oU002000000030?nI00000000oi/00080oi/000@000000?nM
003oW@00oid00`0000030?nP00060000003oXP0000000000003oX`000000
103oY0001P000000oj@0000000000000ojD0000000@0ojH00`0000020?nW
00030000003oY`00ojL00080ojL00`0000090?ooo`030000003oool0oooo
00d0oooo00220?ooo`030000003oool0oooo00`0oooo0`00000/0?ooo`80
00000P3o/00200000080ok400`0000030?nb00040000003o/`00ok<00?nc
00<000000`3o]0000`000000okH00?nf0002000000030?nd00000000okL0
00<0okL00`0000020?ne00040000003o]`00okL00?ng00<000000P3o/P02
00000080ok800`0000040?nW00<000000P3oV00010000000ohh00?n>0000
0002003oR`0400000000oh/00?n;003oR`8000001P00[_l00`0000000?o8
003ob00400000080odh000<000000?ln003o?P000P000000103o>P000000
0?lT003o9002000000030?lB00000000000000D0000000D0ocP00000003o
GP00oeh0000000030?ma00@000000P3oR0001@000000ohd00?n=003oS@00
000000<0oi400`0000030?nI00040000003oV`00oi/00?nK00@0000000<0
oil00000003oX0000P3oX003000000@0oj<000<000000?nT003oY0000`00
00020?nU008000000P3oYP02000000030?nV00000000ojL00080ojL000<0
00000?nW003oY`000P00000=0?ooo`030000003oool0oooo00`0oooo0022
0?ooo`030000003oool0oooo00T0oooo0`00000`0?ooo`040000003o/000
ok000?n`00<000000P3o/@0200000080ok80100000020?nc00040000003o
]000ok@00?nd00<000000`3o]0000`000000okL00?ng0002000000030?nd
00000000okD000<0okD00`0000020?nb00040000003o/P00ok800?nb00<0
00000P3oZP000`000000ojL00?nW0002000000030?nO00000000oiP00080
oiP00`000000103oQ`000000003oR`000003003oR`8000001@00[_l20000
00800?o800<000000?mO00000000103oCP02000000@0ocX00P0000020?lB
00<000000`1Co`000`000000ofH00000000700000080oh8000D000000?n8
003oR000ohP0000000030?n=00@000000P3oU`0010000000oiT00?nI003o
V@04000000030?nN00000000oil00080oil0100000020?nR00040000003o
X`00oj<00?nS00@000000P3oY@0010000000ojD00?nU003oY@03000000<0
ojH000@000000?nW003oY`00ojL00`00000?0?ooo`030000003oool0oooo
00`0oooo00220?ooo`030000003oool0oooo00L0oooo0P00000d0?ooo`<0
00000P3o/00010000000ok400?na003o/@0300000080ok400P0000020?nc
00@000000P3o/`0010000000ok@00?nd003o]003000000<0ok@000<00000
0?ne003o]@000P0000000`3o/@0000000?nb00020?nb00@000000P3o[000
0`000000ojX00?nZ0003000000@0oil00`0000020?nA00050000003oQ`00
0000003oR`0000000`00oh/00`0000000:ko00000004002^o`0700000000
1Ol00000003ob0000000oel0000000020?m>0080000000@0oe<00000003o
>P00ocX00P000000103o>000000000000000000205?o00030000001Co`00
Dol00080Dol000<000000?mV00000000103oN@001@000000oh800?n2003o
PP00000000<0ohP0100000020?nE00040000003oU`00oiL00?nG00@00000
0P3oW@000`000000oih00?nN000400000080oj4000@000000?nR003oXP00
oj80100000020?nT00040000003oY@00ojD00?nU00@0000000<0ojH00000
000000000`3oYP0400000180oooo00<000000?ooo`3oool0303oool00840
oooo00<000000?ooo`3oool01@3oool3000003L0oooo0P0000020?n`00@0
00000P3o/00010000000ok400?na003o/@0300000080ok800P0000020?nc
00@000000P3o/P0010000000ok@00?nd003o]003000000@0ok400`000002
0?n]00040000003o[000oj`00?n/00<000000P3oY002000000050?nO0000
000000000?nI000000000`3oT@0300000003003oR`0000000?n;00800?n;
00<00000002^o`0000000`00[_l01P00000000Go0005o`0000000?o80000
0080oel00P0000040?mC008000000`3o>002000000<0Dol000<0000005?o
001Co`000P1Co`0010000000ofH00?mV000000030?mi00040000003oPP00
oh800?n200@000000P3oU00010000000oiD00?nE003oU@0400000080oi`0
00@000000?nM003oW@00oid00`0000020?nQ00040000003oX@00oj400?nQ
00@000000P3oY00010000000oj@00?nT003oY00400000080ojD000<00000
0?nV003oYP001@00000F0?ooo`030000003oool0oooo00`0oooo00210?oo
o`030000003oool0oooo0080oooo0`00000l0?ooo`8000000P3o[`020000
0080ok00100000020?n`00040000003o/P00ok800?nb00<000000P3o/@02
00000080ok80100000020?na00030000003o/@00ok400080000000<0ojh0
0000003o[@000P3o[@0400000080ojL000@000000?nT003oY000oj@00P00
00040?nI00<000000P3oS@000`0000000?n;00000002003oR`<0000000@0
0:ko00000000[_l0000010001Ol01P000000oel0000000000000ofD00000
0080oe<00P0000001@3oGP0000000?lh003o>00000000080ofH000@00000
05?o001Co`000000101Co`0010000000ofH00?mV000000030?mi00@00000
0P3oUP000`000000oi@00?nD00020?nD00<000000P3oW@000`000000oi`0
0?nL00020?nL00<0000000<0oj400000003oX@000`3oX@0300000080oj<0
00@000000?nT003oY000oj@0100000020?nU00040000003oY@00ojD00?nU
00D000006@3oool00`000000oooo0?ooo`0<0?ooo`00P@3oool500000400
oooo00@000000?n_003o[`00ojl00`0000020?n`008000000P3o/0040000
0080ok0000@000000?na003o/@00ok400`0000020?n`008000000P3o/@03
000000@0ojh00`0000020?nY00040000003oY`00ojL00?nW00@000000P3o
WP001@000000oiT0000000000000oiD0008000000P3oS@001@0000000?n;
003oR`0000000?n;0080000000D000Go0000000000000:ko000000040005
o`800000103oI@02000000<0oeh000<000000?lh000000000`3oIP001000
0000Dol005?o0000000405?o00040000003oIP00ofH00?mV00<000000P3o
W@001@000000oiH00?nF003oUP0000000080oi@00P0000000`3oW`000000
0?nM00020?nM00030000003oW000oi`000<00000103oX@001P000000oj40
000000000000oj<0000000@0oj<00`0000020?nU00040000003oY@00ojD0
0?nU00@000001@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00`0oooo00210?ooo`800000A03oool300000080ojl000@000000?n`
003o/000ok000`0000020?n_00040000003o/000ok000?n`00@000000P3o
[`0010000000ok000?n`003o/00300000080ojh00P0000001@3o[P000000
0000003oZP00000000@0ojT00`0000020?nR00040000003oWP00oih00?nN
008000001@3oU@02000000050?n<000000000?n;00000000oh/00`000002
0005o`03000000001Ol000Go00<000Go00@000000?mc00000000ofD00P00
00000`3oL@0000000?mN00030?mN00030000003oIP00ofH00080ofH000@0
000005?o001Co`0000001@1Co`04000000@0oid000@000000?nF003oUP00
oiH00`0000030?nO00040000003oW@00oid00?nM00<000000`3oX@000`00
0000oj400?nQ0003000000<0oj<000<000000?nS003oX`000P0000000`3o
Y@0000000?nU00030?nU00<000002P3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00`0oooo001^0?ooo`800000103oool2000000D0
oooo0`0000040?ooo`030000003oool0oooo04<0oooo00@000000?n_003o
[`00ojl0100000020?n_00030000003o[`00ojl000@000000P3o[`001000
0000ojl00?n_003o[`0400000080ojh000@000000?n^003o[P00ojh00P00
00030?nZ00030000003oZ@00ojT00080000000<0ojD00000003oXP000P3o
XP0400000080oi/000<000000?nE003oU@000P000000203oT`0000000?n<
000000000?n;00000000oh/000000P3oP`000`00000000Go000000050005
o`040000003oL`00og<0000000<0og4000<000000?mN003oGP000`000004
0?mV00040000001Co`00Dol0000000D0Dol000D000000?nd003o]000ok@0
000000040?nM00<000000P3oY@0010000000oil00?nO003oW`0400000003
0?nS00000000oj400080oj40100000020?nT00040000003oX`00oj<00?nS
00<000000`3oY@000`000000ojD00?nU0002000000d0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0;0?ooo`00K@3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo00@0oooo0P0000140?oo
o`<000000P3o[P0010000000ojl00?n_003o[`0300000080ojh00P000002
0?n_00@000000P3o[P0010000000ojh00?n^003o[P0400000080oj/000<0
00000?nZ003oZP000`0000040?nU00<000000P3oW`0010000000oi/00?nK
003oV`03000000@0oi<00P0000001000oh/00000003oR`0000020?n30003
000000001Ol0000000@000Go00H000000?mc0000000000000?ml00000003
0?ma008000000`3oN@000`000000ofH00?mV00020?mV00040000001Co`00
Dol0000000@0Dol000D000000?nd003o]000ok@0000000020?nM00800000
00<0ok<00000003oY@000`3oY@0300000080ojL000<000000?nS003oX`00
100000020?nU00040000003oY000oj@00?nT00@000000P3oY@0010000000
ojD00?nU003oY@0300000100oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0;0?ooo`00K@3oool010000000oooo0?ooo`0000080?oo
o`D000001`3oool00`000000oooo0?ooo`120?ooo`030000003o[P00ojh0
0080ojh00`0000020?n^00040000003o[P00ojh00?n^00<000000P3o[@02
00000080ojh0100000020?n/00040000003oZ`00oj/00?n[00<000000P3o
Y`02000000050?nU0000000000000?nR000000000`3oW`0400000080oiT0
00<000000?nC003oT`000P0000001@3oTP000000003oR`0000000?n;00@0
000000<000Go000000001Ol00`001Ol2000000<0og`000H000000?ma0000
000000000?n2000000030?mi00040000003oIP00ofH00?mV008000000P1C
o`000`000000Dol005?o000205?o008000000`3o]002000000<0ok<000<0
00000?nU003oY@000P0000000`3o[P0000000?nW00030?nW008000000P3o
Y`0010000000ojD00?nU003oY@0400000080ojH000@000000?nU003oY@00
ojD01000000D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool02`3oool006d0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo0480oooo00H000000?n^
0000000000000?n^000000040?n^00<000000P3o[@0010000000ojd00?n]
003o[@0300000080oj`000@000000?n/003o[000oj`0100000020?nX0004
0000003oY`00ojL00?nW00800000103oXP0300000080oid000@000000?nI
003oV@00oiT00`0000030?nB000600000000oh/000000000003oSP000000
0P3oQP02000000@000Go0P0000030?ml008000000`3oPP0010000000ogT0
0?mi003oN@04000000050?nd00000000Dol005?o00000000101Co`020000
0080ok@000<000000?oC00000000103o/`02000000<0ojh000<000000?nW
003oY`000`0000030?nW00@000000P3oY`0010000000ojH00?nV003oYP04
000001P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0;
0?ooo`00K@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
000000X0oooo00<000000?ooo`3oool0@P3oool00`000000ojh00?n^0002
0?n^00060000003o[P0000000000003o[@000000103o[@0300000080oj`0
00<000000?n/003o[000100000020?nY00040000003oZ000ojP00?nX00@0
00000P3oY@001@000000oj80000000000000oj00008000000P3oW@040000
0080oiP000H000000?nB003oTP00oi8000000000oh/200000080ohh01000
00040005o`D000000P3oR0000`000000oh800?n20004000000030?nM0000
0000ok@00080ok@000@0000005?o001Co`000000101Co`00100000000?lf
0000000000020?oC00030000003o/`00ok<00080000000<0okX00000003o
[P000P3o[P03000000<0oj/00`0000020?nZ00040000003oY`00ojL00?nW
00@000007@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00/0oooo001^0?ooo`8000002`3oool2000000/0oooo0P0000130?ooo`04
0000003o[P00ojh00?n^008000000`3o[@000`000000ojd00?n]00020000
00030?n/00000000oj`00080oj`00`0000020?nZ008000000P3oZ@040000
0080ojH000@000000?nU003oY@00ojD00P0000050?nP008000000P3oW000
10000000oiP00?nH003oV004000000030?nC00000000000000<0000000D0
oi4000000000000000Go000000030005o`040000003oS@00ohd0000000@0
ohP00P0000020?nF00050000003oW@00oid00?nM000000000P3o]0001000
0000Dol005?o0000000405?o000300000000ocH0000000@0om<00P000004
0?nj00<0000000@0ok400000003oZ`00oj/00P0000000`3o[@0000000?nZ
00030?nZ00<000008P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00/0oooo002:0?ooo`030000003oool0oooo0440oooo0`000002
0?n]00030000003o[@00ojd000<00000103o[00300000080oj/000@00000
0?nZ003oZP00ojX00`0000020?nX00040000003oYP00ojH00?nV00@00000
0P3oX`000`000000oj000?nP0002000000030?nO00000000oi`00080oi`0
0`0000020?nH00030000003oT`00oi<000<000000`3oT@02000000030005
o`00000000Go008000Go00@000000?n=003oS@0000000P3oR003000000<0
oiH000D000000?nM003oW@00oid0000000020?nd00040000001Co`00Dol0
000000@0Dol00`0000020?oC0080000000@0ol`00000003o^P00okX00P00
0000103o^P0000000?na003o/@03000000<0ojd000<000000?nZ003oZP00
0P00000V0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
2P3oool008/0oooo00<000000?ooo`3oool0@@3oool010000000ojd00?n]
003o[@0300000080oj`00P0000001@3o[00000000000003oZ`00000000@0
oj/00`0000020?nY00030000003oZ000ojP000@000000P3oY@0010000000
oj<00?nS003oX`03000000<0oil000H000000?nL0000000000000?nL0000
00030?nH00L000000P3oT@02000000050005o`00000000Go0005o`000000
0`3oS@03000000<0oi@000<000000?nF003oUP001`000000103o]0000000
05?o0000000405?o00030000003ko`00nol0008000000`3oc003000000@0
okX00P0000020?nb00040000003o[@00ojd00?n]00<00000:03oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo002<0?ooo`03
0000003oool0oooo0440oooo0`0000020?n/00040000003o[000oj`00?n/
008000000`3oZ`000`000000oj/00?n[0002000000030?nY00000000ojT0
0080ojT00`0000020?nV008000000P3oY@0400000080oj8000@000000?nO
003oW`00oil00P0000040?nL00<000000P3oV@07000000040?nD00000000
00Go0000008000Go100000020?nE00030000003oU000oi@000@000000P3o
Y@0010000000ok<00?nc003o/`030000000305?o00000000Dol000<0Dol0
0`0000000`3og@0000000000000200000080ol@000<000000?nj003o^P00
0`0000030?nb00@00000;03oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00X0oooo002=0?ooo`800000@P3oool200000080oj`01000
00020?n[00030000003oZ`00oj/000<00000103oZ@0300000080ojL000@0
00000?nV003oYP00ojH00`0000020?nT00040000003oXP00oj800?nR00@0
00000P3oW`001P000000oi`0000000000000oi`0000000@0oiT00`000002
0?nH00030000003oU000oi@0008000000P001Ol00`000000oiL000000003
0?nE00<000000P3oW`001@000000ojD00?nU003oY@00000000<0ok<00`00
00000`1Co`00000005?o000305?o00030000003og@00omd00080000000<0
ol/00000003oa0000P3oa003000000<0okP00`00000a0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool02P3oool008l0oooo00<00000
0?ooo`3oool0@@3oool200000080oj/000@000000?n[003oZ`00oj/00`00
00020?nZ0080000000D0ojT0000000000000ojP0000000030?nW00@00000
0P3oY@000`000000oj@00?nT000400000080oj4000@000000?nO003oW`00
oil00P0000030?nL00030000003oV@00oiT00080000000<0oi/00000003o
V0000P3oV0050000008000Go00<000000?nG000000000`0000020?nM0003
0000003oW`00oil000P000000P3o^P000`000000Dol00000000405?o00<0
00000`3ob`0400000080okd000@000000?nh000000000000=@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo002@0?ooo`03
0000003oool0oooo0440oooo00<000000?n[003oZ`00100000020?nZ0004
0000003oZP00ojX00?nZ00800000103oZ00300000080ojL000@000000?nU
003oY@00ojD00`0000020?nS00040000003oX@00oj400?nQ00@000000P3o
W`000`000000oi`00?nL0003000000<0oi/0100000020?nK00<000000P00
1Ol200000080oi`000@000000?nM003oW@00oid00`0000020?nW00050000
003o[P00ojh00?n^000000000`3o^P000`000000Dol00000000405?o0003
0000003ob`00000000<000000P3o`@0010000000okd00?nm003o_@020000
03L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?oo
o`00T@3oool00`000000oooo0?ooo`110?ooo`8000000P3oZ`0200000080
ojX0100000020?nY00060000003oZ00000000000003oY`000000103oY`03
00000080ojD000<000000?nS003oX`00100000020?nQ00040000003oW`00
oil00?nO00<000000P3oW@000`000000oi/00?nK0002000000030?nM0000
0000oi/000<0oi/00P0000020005o`040000003oW000oi`00?nL00@00000
0P3oX`0010000000ojL00?nW000000030?n^00D0000000<0Dol00000001C
o`000`1Co`0200000080ol4000@000000?o1003o`@00ol401000000j0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool00980
oooo0P0000120?ooo`040000003oZ`00oj/00?n[00<000000P3oZ@001000
0000ojT00?nY003oZ@02000000@0ojL000H000000?nW0000000000000?nV
000000030?nU00<000000P3oX`0200000080oj40100000020?nO00030000
003oW@00oid000<000000`3oW@000`000000oi/00?nK0004000000030005
o`000000oid000<000000P3oX@001@000000oj<00?nS003oX`0000000080
ojL0100000020?na00050000003o^P00000005?o00000000101Co`001000
0000ol400?o1003o`@04000003l0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`090?ooo`00U03oool00`000000oooo0?ooo`100?oo
o`<000000P3oZP000`000000ojT00?nY000400000080ojP000@000000?nW
003oY`00ojL00P0000040?nV00<000000P3oY00010000000oj<00?nS003o
X`0300000080oj4000@000000?nO003oW`00oil00`0000020?nO00040000
003oW@00oid00?nM00<000000`3oWP001P00000000Go000000000000oj40
000000<0oj4000@000000?nS003oX`00oj<00`0000020?n[00040000003o
/@00ok400?na00<0000000<0Dol00000001Co`000P1Co`05000004@0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`00U@3o
ool00`000000oooo0?ooo`100?ooo`040000003oZP00ojX00?nZ00<00000
0P3oZ@0010000000ojP00?nX003oZ00400000080ojL000H000000?nV0000
000000000?nV000000030?nT00@000000P3oX`000`000000oj400?nQ0004
00000080oj4000<000000?nO003oW`00100000020?nO00070000003oWP00
oih00?nN0000000000Go000000020?nQ00040000003oX@00oj400?nQ00@0
000000<0ojL00000003oZ`000P3oZ`0400000080ok8000<0000005?o0000
00000`1Co`000`000000oooo0?ooo`160?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool02@3oool009H0oooo00<000000?ooo`3oool0
@03oool300000080ojT000<000000?nY003oZ@00100000020?nX00040000
003oY`00ojL00?nW00800000103oYP0300000080oj@000@000000?nS003o
X`00oj<00`0000020?nR00040000003oX@00oj400?nQ00<000000P3oX000
10000000oil00?nO003oW`05000000040005o`000000oj400?nQ00@00000
0P3oY@000`000000ojL00?nW000400000080ojd000@000000?nb003o/P00
ok800P0000001@1Co`00000005?o001Co`00000004T0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`090?ooo`00U`3oool200000440
oooo00@000000?nY003oZ@00ojT00`0000020?nX008000000P3oZ0040000
0080ojH000H000000?nV0000000000000?nU000000030?nT00@000000P3o
X`000`000000oj800?nR000400000080oj8000<000000?nP003oX0001000
00020?nQ00030000003oX@00000000@000000P3oY00010000000ojD00?nU
003oY@0300000080ojX000@000000?n]003o[@00ojd010000000103oool0
000005?o0000000205?o00030000003oool0oooo04P0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`090?ooo`00V@3oool00`000000
oooo0?ooo`0o0?ooo`<000000P3oZ@0010000000ojP00?nX003oZ0030000
0080ojL000@000000?nV003oYP00ojH00P0000040?nU00<000000P3oY000
10000000oj<00?nS003oX`0300000080oj<000@000000?nR003oXP00oj80
0`0000020?nR00040000003oX@00oj400?nQ00D0000000@0oj<00000003o
Y000oj@0100000020?nW00030000003oZP00ojX000@000001@3oool00`00
0000Dol00000000205?o00030000003oool0oooo04P0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`090?ooo`00VP3oool00`000000
oooo0?ooo`0o0?ooo`8000000P3oZ@0400000080ojP000<000000?nW003o
Y`00100000020?nV00060000003oY@0000000000003oY@0000000`3oY004
00000080oj@000<000000?nS003oX`00100000020?nS00030000003oXP00
oj8000@000000P3oX`0200000080oj<00`0000020?nV00040000003oY`00
ojL00?nW00<000002@3oool00`000000Dol00000000205?o00030000003o
ool0oooo04T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`00V`3oool00`000000oooo0?ooo`100?ooo`8000000P3oZ000
10000000ojP00?nX003oZ00300000080ojL000@000000?nV003oYP00ojH0
0P0000040?nU00<000000P3oY@0010000000oj@00?nT003oY00300000080
oj@000@000000?nS003oX`00oj<00`0000020?nT00040000003oX`00oj<0
0?nS00@0000000<0ojD00000003oYP000P3oYP04000000`0oooo00<00000
05?o000000000P1Co`000`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0203oool009`0oooo0P0000110?oo
o`030000003oZ000ojP000@000000P3oZ0000`000000ojL00?nW00040000
0080ojH000D000000?nU0000000000000?nV000200000080ojD010000002
0?nT00030000003oY000oj@000@000000P3oY0000`000000oj@00?nT0004
000000030?nU0000000000000080ojD01000000@0?ooo`030000001Co`00
00000080Dol000<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo002N0?ooo`030000003oool0oooo
03l0oooo0P0000020?nX00040000003oZ000ojP00?nX00<000000P3oY`00
10000000ojH00?nV003oYP02000000D0ojH00P0000020?nU00040000003o
Y000oj@00?nT00<000000P3oY@0010000000oj@00?nT003oY00300000080
ojD000<000000?nU003oY@001000000D0?ooo`030000001Co`0000000080
Dol000<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo002O0?ooo`030000003oool0oooo03l0oooo
00<000000?nX003oZ000100000020?nW00030000003oY`00ojL000@00000
0P3oYP000`000000ojH00?nV0002000000040?nV00000000ojD00?nU00@0
00000P3oY@000`000000ojD00?nU000400000080ojD000<000000?nU003o
Y@001000000G0?ooo`030000001Co`0000000080Dol000<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo002P0?ooo`030000003oool0oooo03l0oooo0P0000020?nX00040000
003oY`00ojL00?nW00<000000P3oY`0200000080ojH00`0000030?nV00<0
00000P3oYP0010000000ojD00?nU003oY@0300000080ojD000@000000?nU
003oY@00ojD00`00000L0?ooo`8000000P1Co`000`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0:40oooo0P0000100?ooo`030000003oZ000ojP000@000000P3oY`001000
0000ojL00?nW003oY`0300000080ojH0100000020?nV00030000003oYP00
ojH000@000000P3oYP000`000000ojD00?nU0004000001l0oooo0P000002
05?o00030000003oool0oooo04h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`080?ooo`00X`3oool00`000000oooo0?ooo`0n0?oo
o`8000000P3oZ00200000080ojL0100000020?nW00060000003oYP000000
0000003oY`0000000`3oYP0300000080ojH000@000000?nV003oYP00ojH0
0`00000S0?ooo`8000000P1Co`000`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00:@0oooo00<0
00000?ooo`3oool0?P3oool010000000ojP00?nX003oZ00300000080ojL0
00@000000?nW003oY`00ojL00P0000030?nW00@000000P3oY`000`000000
ojH00?nV0004000002H0oooo0P00000205?o00030000003oool0oooo04l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`00
Y@3oool00`000000oooo0?ooo`0n0?ooo`<000000P3oZ0000`000000ojL0
0?nW000400000080ojL00`0000020?nW00040000003oY`00ojL00?nW00<0
0000:P3oool200000080Dol000<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo002V0?ooo`800000
?`3oool010000000ojP00?nX003oZ00300000080ojP000<000000?nW003o
Y`000P000000103oY`0000000?nW003oY`04000002d0oooo0P00000205?o
00030000003oool0oooo0500oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`00Z03oool00`000000oooo0?ooo`0m0?ooo`<0
00000P3oZ0000`000000ojP00?nX0003000000<0ojL00`00000a0?ooo`80
00000P1Co`000`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01`3oool00:T0oooo00<000000?ooo`3oool0
?@3oool010000000ojP00?nX003oZ00300000080ojP01000000d0?ooo`80
00000P1Co`000`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool00:X0oooo00<000000?ooo`3oool0
?@3oool300000080ojP00`00000h0?ooo`050000001Co`00000005?o0000
0000E@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo002[0?ooo`800000?P3oool4000003`0oooo0P0000000`1Co`000000
0?ooo`1D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00:d0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0l0?ooo`80000000<0Dol00000003oool0E@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo002^0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0?03oool20000000305?o00000000
oooo05H0oooo00D000000?ooo`3oool0oooo000000080?ooo`00[`3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03`0oooo0P000000
0`1Co`0000000?ooo`1G0?ooo`040000003oool0oooo000000P0oooo002`
0?ooo`800000>P3oool00`000000oooo0?ooo`0l0?ooo`80000000<0Dol0
0000003oool0E`3oool010000000oooo0?ooo`0000080?ooo`00/P3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03`0oooo0P000000
0`1Co`0000000?ooo`1H0?ooo`030000003oool0000000P0oooo002c0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0?03oool20000
000305?o00000000oooo05T0oooo00<000000?ooo`0000001`3oool00;@0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0l0?ooo`80
000000<0Dol00000003oool0FP3oool2000000L0oooo002e0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?03oool3000005`0oooo
0P0000070?ooo`00]P3oool2000003@0oooo00<000000?ooo`3oool0?@3o
ool2000005`0oooo0P0000070?ooo`00^03oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo03d0oooo0P00001H0?ooo`@000002@3oool0
0;T0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0m0?oo
o`800000E03oool4000000d0oooo002j0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0?@3oool200000500oooo1000000A0?ooo`00
^`3oool2000002l0oooo00<000000?ooo`3oool0?@3oool2000004`0oooo
1000000E0?ooo`00_@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo03d0oooo0P0000190?ooo`<000006@3oool00;h0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0m0?ooo`800000A@3oool4
000001`0oooo002o0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0?@3oool200000440oooo1000000P0?ooo`00`03oool2000002X0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0k0?ooo`@0
0000903oool00<80oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo03L0oooo1000000X0?ooo`00``3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0=03oool3000002`0oooo00340?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0`
0?ooo`@00000;`3oool00<D0oooo0P00000U0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0;03oool4000003<0oooo00370?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0J@3oool4000003L0
oooo00380?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
IP3oool4000003/0oooo00390?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0HP3oool4000003l0oooo003:0?ooo`8000007`3oool0
0`000000oooo0?ooo`1O0?ooo`<00000@`3oool00<`0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`1K0?ooo`@00000AP3oool00<d0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1G0?ooo`@0
0000BP3oool00<h0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1C0?ooo`@00000CP3oool00<l0oooo0P00000J0?ooo`030000003o
ool0oooo04l0oooo1000001B0?ooo`00d@3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo04`0oooo0`00001F0?ooo`00dP3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo1000001I0?oo
o`00d`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04@0
oooo1000001M0?ooo`00e03oool2000001D0oooo00<000000?ooo`3oool0
@03oool400000640oooo003F0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0?03oool4000006D0oooo003G0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0>@3oool3000006T0oooo003H0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0=@3oool40000
06`0oooo003I0?ooo`800000403oool00`000000oooo0?ooo`0a0?ooo`@0
0000L03oool00=/0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0]0?ooo`@00000M03oool00=`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0Y0?ooo`@00000N03oool00=d0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?ooo`<00000O03oool0
0=h0oooo0P00000;0?ooo`030000003oool0oooo0280oooo1000001o0?oo
o`00h03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0
oooo100000230?ooo`00h@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01X0oooo100000270?ooo`00hP3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01H0oooo1000002;0?ooo`00h`3oool2
000000H0oooo00<000000?ooo`3oool04P3oool4000008l0oooo003U0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool30000
09<0oooo003V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool4000009H0oooo003W0?ooo`050000003oool0oooo0?ooo`00
00002@3oool4000009X0oooo003X0?ooo`80000000<0oooo0000003oool0
103oool4000009h0oooo003Z0?ooo`80000000<0oooo0000000000000P00
002R0?ooo`00j`3oool200000:H0oooo003o0?oooi@0oooo003o0?oooi@0
oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oo
oi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 239},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The roots of the quadratic equation  ",
  Cell[BoxData[
      \(5  z\^2\  + \ 26  z\  + \ 5\  = \ 0\)],
    AspectRatioFixed->True],
  "  occur at the points ",
  Cell[BoxData[
      RowBox[{"z", "=", 
        RowBox[{
          RowBox[{\(-5\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "z"}], 
          "=", \(-\(1\/5\)\)}]}]]],
  ".  If we replace ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " with ",
  Cell[BoxData[
      \(z\^2\)],
    AspectRatioFixed->True],
  " in this equation, the function  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ 5  z\^4\  + \ 26  z\^2\  + \ 5\)],
    AspectRatioFixed->True],
  "  has simple zeros at the points  ",
  Cell[BoxData[
      RowBox[{"z", "=", 
        RowBox[{
          RowBox[{\(\[PlusMinus]\[ImaginaryI]\), \(\@5\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "z"}], 
          "=", \(\[PlusMinus]\(\[ImaginaryI]\/\@5\)\)}]}]]],
  ".  Corollary 7.5 implies that ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  "  has simple poles at  ",
  Cell[BoxData[
      RowBox[{"z", "=", 
        RowBox[{
          RowBox[{\(\[PlusMinus]\[ImaginaryI]\), \(\@5\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "z"}], 
          "=", \(\[PlusMinus]\(\[ImaginaryI]\/\@5\)\)}]}]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 7.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(g[z] = 1\/\(5  z\^4\  + \ 26  z\^2\  + \ 5\)\)]],
  " and find roots of the polynomial in the denominator.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Remove[z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[g, solset];\)\ \), "\n", 
    \(\(g[z_]\  = \ 1\/\(5  z\^4\  + \ 26  z\^2\  + \ 5\);\)\ \), "\n", 
    \(\(solset\  = \ Solve[Denominator[g[z]] == 0, z];\)\ \), "\n", 
    \(\(Print["\<g[z] = \>", g[z]];\)\ \), "\n", 
    \(\(Print["\<The poles are located at:\>"];\)\ \), "\n", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Evaluate g[z] at the poles.  ", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Z\_1\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Z\_3\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(3, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Z\_4\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(4, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<g[z] = \>", g[z]];\)\ \), "\n", 
    \(\(Print["\<g[\>", Z\_1, "\<] = \>", 
        Limit[g[z], z \[Rule] Z\_1]];\)\ \), "\n", 
    \(\(Print["\<g[\>", Z\_2, "\<] = \>", 
        Limit[g[z], z \[Rule] Z\_2]];\)\ \), "\n", 
    \(\(Print["\<g[\>", Z\_3, "\<] = \>", 
        Limit[g[z], z \[Rule] Z\_3]];\)\ \), "\n", 
    \(\(Print["\<g[\>", Z\_4, "\<] = \>", 
        Limit[g[z], z \[Rule] Z\_4]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Thus ",
  Cell[BoxData[
      \(g \((z)\) = 1\/\(5  z\^4\  + \ 26  z\^2\  + \ 5\)\)],
    AspectRatioFixed->True],
  " has four simple poles.\n\nWe can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate the absolute value of  ",
  Cell[BoxData[
      \(g \((z)\) = 1\/\(5  z\^4\  + \ 26  z\^2\  + \ 5\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(u[x_, y_] = 
        FullSimplify[
          ComplexExpand[Re[g[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, 
                Re}]];\)\ \), "\[IndentingNewLine]", 
    \(\(v[x_, y_] = 
        FullSimplify[
          ComplexExpand[Im[g[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, 
                Re}]];\)\ \), "\[IndentingNewLine]", 
    \(\(w[x_, y_] = 
        FullSimplify[
          ComplexExpand[Abs[g[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, 
                Re}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        u[x, y], {x, \(-3\), 3}, {y, \(-3\), 
          3}, \[IndentingNewLine]PlotPoints \[Rule] {41, 41}, 
        PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 3}, {\(-0.05\), 
              0.4}}, \[IndentingNewLine]ClipFill \[Rule] None, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        u[x, y], {x, \(-3\), 3}, {y, \(-3\), 
          3}, \[IndentingNewLine]PlotPoints \[Rule] 75, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[u[x, y], {x, \(-3\), 3}, {y, \(-3\), 3}, 
        PlotPoints \[Rule] 
          55, \[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 
              3}, {0, 0.4}}, BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<u[x,y] = \>", 
        Re[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        v[x, y], {x, \(-3\), 3}, {y, \(-3\), 
          3}, \[IndentingNewLine]PlotPoints \[Rule] {41, 41}, 
        PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 3}, {\(-0.05\), 
              0.4}}, \[IndentingNewLine]ClipFill \[Rule] None, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        v[x, y], {x, \(-3\), 3}, {y, \(-3\), 
          3}, \[IndentingNewLine]PlotPoints \[Rule] 75, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[v[x, y], {x, \(-3\), 3}, {y, \(-3\), 3}, 
        PlotPoints \[Rule] 
          55, \[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 
              3}, {0, 0.4}}, BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<v[x,y] = \>", 
        Im[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        w[x, y], {x, \(-3\), 3}, {y, \(-3\), 
          3}, \[IndentingNewLine]PlotPoints \[Rule] {41, 41}, 
        PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 3}, {0, 
              0.4}}, \[IndentingNewLine]ClipFill \[Rule] None, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[x,y] = \>", 
        Abs[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", w[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        w[x, y], {x, \(-3\), 3}, {y, \(-3\), 
          3}, \[IndentingNewLine]PlotPoints \[Rule] 75, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[x,y] = \>", 
        Abs[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", w[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[w[x, y], {x, \(-3\), 3}, {y, \(-3\), 3}, 
        PlotPoints \[Rule] 
          55, \[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 
              3}, {0, 0.4}}, BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<w[x,y] = \>", 
        Abs[f[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", w[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.14.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Locate the zeros and poles of ",
  Cell[BoxData[
      \(g \((z)\) = \(\[Pi]\ cot \((\[Pi]\ z)\)\)\/z\^2\)],
    AspectRatioFixed->True],
  ", and determine their order."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution. The function  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ z\^2\ sin\ \[Pi]\ z\)],
    AspectRatioFixed->True],
  "  has a zero of order  ",
  Cell[BoxData[
      \(k = 3\)]],
  "  at  ",
  Cell[BoxData[
      \(z = 0\)]],
  "  and simple zeros at the points  ",
  Cell[BoxData[
      \(z = \(\[PlusMinus]1\), \(\[PlusMinus]2\),  ... \)]],
  ".  Corollary 7.5 implies that ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " has a pole of order 3 at the point  ",
  Cell[BoxData[
      \(z = 0\)]],
  "  and simple poles at the points  ",
  Cell[BoxData[
      \(z = \(\[PlusMinus]1\), \(\[PlusMinus]2\),  ... \)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 7.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(g[z] = \(\[Pi]\ Cot[\[Pi]\ z]\)\/z\^2\)]],
  " and find roots of the polynomial in the denominator.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[g, S];\)\ \), "\n", 
    \(\(g[z_]\  = \ \(\[Pi]\ Cot[\[Pi]\ z]\)\/z\^2;\)\ \), "\n", 
    \(\(S[z_]\  = \ Normal[Series[g[z], {z, 0, 9}]];\)\ \), "\n", 
    \(\(Print["\<g[z] = \>", g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[z] = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[z] = \>", 
        S[z], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Thus ",
  Cell[BoxData[
      \(g \((z)\) = \(\[Pi]\ cot \((\[Pi]\ z)\)\)\/z\^2\)],
    AspectRatioFixed->True],
  ", has a pole of order  n = 3  at  z = 0.\n\nNow consider the other \
singularities."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<g[z] = \>", g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(For[k = \(-5\), 
        k \[LessEqual] \(-1\), \(k++\), \[IndentingNewLine]\(Print["\<g[\>", 
            k, "\<] = \>", 
            Limit[g[z], z \[Rule] k]];\)\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\(For[k = 1, 
        k \[LessEqual] 
          5, \(k++\), \[IndentingNewLine]\(Print["\<g[\>", k, "\<] = \>", 
            Limit[g[z], z \[Rule] k]];\)\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Or we could consider the following method of investigation.", "Text"],

Cell[BoxData[{
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[n] = \>", g[n]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[n] = \>", 
        Simplify[g[n], Element[n, Integers]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "\nThus ",
  Cell[BoxData[
      \(g \((z)\) = \(\[Pi]\ cot \((\[Pi]\ z)\)\)\/z\^2\)],
    AspectRatioFixed->True],
  " has simple poles at ",
  Cell[BoxData[
      \(z = \(\[PlusMinus]1\), \(\[PlusMinus]2\), \  ... \)]],
  ".  ",
  "\n",
  "\nInvestigate the graph for real variables."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(Plot[g[x], {x, \(-3\), 3}, 
        PlotRange \[Rule] {{\(-3\), 3}, {\(-10\), 10}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[\(-10\), 10, 5]}, 
        PlotStyle \[Rule] Red];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The function y = g[x] = \>", 
        g[x]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to investigate the real part, imaginary part, and absolute value of  ",
  Cell[BoxData[
      \(g \((z)\) = \(\[Pi]\ cot \((\[Pi]\ z)\)\)\/z\^2\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(u[x_, y_] = 
        FullSimplify[
          ComplexExpand[Re[g[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, 
                Re}]];\)\ \), "\[IndentingNewLine]", 
    \(\(v[x_, y_] = 
        FullSimplify[
          ComplexExpand[Im[g[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, 
                Re}]];\)\ \), "\[IndentingNewLine]", 
    \(\(w[x_, y_] = 
        FullSimplify[
          ComplexExpand[Abs[g[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Im, 
                Re}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        Re[g[x\  + \ \[ImaginaryI]\ y]], {x, \(-3\), 3}, {y, \(-3\), 
          3}, \[IndentingNewLine]PlotPoints \[Rule] {41, 41}, 
        PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 3}, {\(-0.5\), 
              0.5}}, \[IndentingNewLine]ClipFill \[Rule] None, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[g[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        u[x, y], {x, \(-3\), 3}, {y, \(-3\), 
          3.01}, \[IndentingNewLine]PlotPoints \[Rule] 75, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", 
        Re[g[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        Re[g[x\  + \ \[ImaginaryI]\ y]], {x, \(-3\), 3}, {y, \(-3\), 3}, 
        PlotPoints \[Rule] 
          55, \[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 
              3}, {0, 5}}, BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<u[x,y] = \>", 
        Re[g[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        Im[g[x\  + \ \[ImaginaryI]\ y]], {x, \(-3\), 3}, {y, \(-3\), 
          3}, \[IndentingNewLine]PlotPoints \[Rule] {41, 41}, 
        PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 3}, {\(-0.5\), 
              0.5}}, \[IndentingNewLine]ClipFill \[Rule] None, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[g[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        v[x, y], {x, \(-3\), 3}, {y, \(-3\), 
          3.01}, \[IndentingNewLine]PlotPoints \[Rule] 75, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", 
        Im[g[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        Im[g[x\  + \ \[ImaginaryI]\ y]], {x, \(-3\), 3}, {y, \(-3\), 3}, 
        PlotPoints \[Rule] 
          55, \[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 
              3}, {0, 5}}, BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<v[x,y] = \>", 
        Im[g[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        Abs[g[x\  + \ \[ImaginaryI]\ y]], {x, \(-3\), 3}, {y, \(-3\), 
          3}, \[IndentingNewLine]PlotPoints \[Rule] {41, 41}, 
        PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 3}, {0, 
              5}}, \[IndentingNewLine]ViewPoint \[Rule] {4, 4, 1}, 
        ClipFill \[Rule] None, AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[x,y] = \>", 
        Abs[g[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", w[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[
        w[x, y], {x, \(-3\), 3}, {y, \(-3\), 
          3.01}, \[IndentingNewLine]PlotPoints \[Rule] 75, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w[x,y] = \>", 
        Abs[g[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", w[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[
        Abs[g[x\  + \ \[ImaginaryI]\ y]], {x, \(-3\), 3}, {y, \(-3\), 3}, 
        PlotPoints \[Rule] 
          55, \[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 3}, {\(-3\), 
              3}, {0, 5}}, BoxRatios \[Rule] {1, 1, 1}, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        ViewPoint \[Rule] {\(-3\), 3, 2}, Boxed \[Rule] False, 
        LightSources \[Rule] {{{4, 7, 20}, Red}, {{7, 10, 10}, 
              Green}, {{\(-13\), \(-8\), 15}, Blue}}];\)\ \), "\n", 
    \(\(Print["\<w[x,y] = \>", 
        Abs[g[x\  + \ \[ImaginaryI]\ y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", w[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Laurent Series",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/LaurentSeriesBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Poles and Singularity",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/PoleBib.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{932, 638},
WindowMargins->{{28, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[94536, 2545, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[103546, 2801, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[105136, 2865, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[114700, 3140, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[116236, 3201, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[117753, 3263, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[119164, 3319, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[121794, 3426, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 259862, 6073}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 126, 2, 33, "Text"],
Cell[2231, 66, 1892, 62, 94, "Text",
  Evaluatable->False],
Cell[4126, 130, 2259, 74, 151, "Text",
  Evaluatable->False],
Cell[6388, 206, 6393, 199, 223, "Text"],
Cell[12784, 407, 79, 2, 33, "Text"],
Cell[12866, 411, 976, 32, 128, "Text"],
Cell[13845, 445, 1182, 36, 200, "Text"],

Cell[CellGroupData[{
Cell[15052, 485, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[15208, 491, 275, 11, 36, "Text",
  Evaluatable->False],
Cell[15486, 504, 1254, 25, 420, "Input"],
Cell[16743, 531, 402, 11, 74, "Text",
  Evaluatable->False],
Cell[17148, 544, 617, 11, 185, "Input"],
Cell[17768, 557, 234, 8, 36, "Text"],
Cell[18005, 567, 1030, 21, 190, "Input"],
Cell[19038, 590, 720, 13, 150, "Input"],
Cell[19761, 605, 625, 11, 150, "Input"],
Cell[20389, 618, 625, 11, 150, "Input"],
Cell[21017, 631, 505, 10, 130, "Input"],
Cell[21525, 643, 505, 10, 130, "Input"]
}, Closed]],
Cell[22045, 656, 1096, 33, 162, "Text"],

Cell[CellGroupData[{
Cell[23166, 693, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[23322, 699, 290, 11, 36, "Text",
  Evaluatable->False],
Cell[23615, 712, 1249, 25, 420, "Input"],
Cell[24867, 739, 417, 11, 74, "Text",
  Evaluatable->False],
Cell[25287, 752, 624, 11, 170, "Input"],
Cell[25914, 765, 249, 8, 36, "Text"],
Cell[26166, 775, 1031, 21, 190, "Input"],
Cell[27200, 798, 713, 13, 150, "Input"],
Cell[27916, 813, 508, 9, 130, "Input"],
Cell[28427, 824, 508, 9, 130, "Input"],
Cell[28938, 835, 498, 10, 130, "Input"],
Cell[29439, 847, 498, 10, 130, "Input"]
}, Closed]],
Cell[29952, 860, 677, 28, 106, "Text"],
Cell[30632, 890, 666, 25, 55, "Text",
  Evaluatable->False],
Cell[31301, 917, 25525, 653, 197, "Text"],

Cell[CellGroupData[{
Cell[56851, 1574, 256, 9, 33, "Text",
  Evaluatable->False],
Cell[57110, 1585, 814, 17, 278, "Input"],
Cell[57927, 1604, 447, 14, 74, "Text",
  Evaluatable->False],
Cell[58377, 1620, 858, 17, 183, "Input"],
Cell[59238, 1639, 183, 6, 52, "Text"],
Cell[59424, 1647, 980, 16, 190, "Input"],
Cell[60407, 1665, 792, 13, 150, "Input"],
Cell[61202, 1680, 656, 12, 150, "Input"],
Cell[61861, 1694, 656, 12, 150, "Input"],
Cell[62520, 1708, 935, 20, 190, "Input"],
Cell[63458, 1730, 926, 20, 190, "Input"]
}, Closed]],
Cell[64399, 1753, 744, 20, 201, "Text"],

Cell[CellGroupData[{
Cell[65168, 1777, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[65324, 1783, 278, 11, 36, "Text",
  Evaluatable->False],
Cell[65605, 1796, 832, 17, 306, "Input"],
Cell[66440, 1815, 470, 14, 74, "Text",
  Evaluatable->False],
Cell[66913, 1831, 605, 11, 170, "Input"],
Cell[67521, 1844, 239, 8, 55, "Text"],
Cell[67763, 1854, 1030, 21, 190, "Input"],
Cell[68796, 1877, 735, 14, 170, "Input"],
Cell[69534, 1893, 580, 10, 130, "Input"],
Cell[70117, 1905, 580, 10, 130, "Input"],
Cell[70700, 1917, 498, 10, 130, "Input"],
Cell[71201, 1929, 498, 10, 130, "Input"]
}, Closed]],
Cell[71714, 1942, 325, 16, 30, "Text"],
Cell[72042, 1960, 672, 16, 201, "Text"],

Cell[CellGroupData[{
Cell[72739, 1980, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[72895, 1986, 287, 11, 36, "Text",
  Evaluatable->False],
Cell[73185, 1999, 825, 17, 293, "Input"],
Cell[74013, 2018, 461, 14, 74, "Text",
  Evaluatable->False],
Cell[74477, 2034, 891, 18, 190, "Input"],
Cell[75371, 2054, 258, 9, 36, "Text"],
Cell[75632, 2065, 1155, 23, 210, "Input"],
Cell[76790, 2090, 792, 13, 150, "Input"],
Cell[77585, 2105, 623, 11, 150, "Input"],
Cell[78211, 2118, 623, 11, 150, "Input"],
Cell[78837, 2131, 935, 20, 190, "Input"],
Cell[79775, 2153, 926, 20, 190, "Input"]
}, Closed]],
Cell[80716, 2176, 1081, 29, 218, "Text"],

Cell[CellGroupData[{
Cell[81822, 2209, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[81978, 2215, 297, 11, 36, "Text",
  Evaluatable->False],
Cell[82278, 2228, 1927, 39, 573, "Input"],
Cell[84208, 2269, 430, 12, 74, "Text",
  Evaluatable->False],
Cell[84641, 2283, 906, 18, 190, "Input"],
Cell[85550, 2303, 258, 9, 36, "Text"],
Cell[85811, 2314, 1148, 23, 210, "Input"],
Cell[86962, 2339, 785, 13, 150, "Input"],
Cell[87750, 2354, 669, 12, 150, "Input"],
Cell[88422, 2368, 707, 13, 170, "Input"],
Cell[89132, 2383, 1040, 22, 190, "Input"],
Cell[90175, 2407, 1040, 22, 190, "Input"]
}, Closed]],
Cell[91230, 2432, 2174, 68, 106, "Text"],
Cell[93407, 2502, 778, 27, 71, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[94210, 2533, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[94358, 2539, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[94536, 2545, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[94896, 2557, 1186, 34, 260, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[96107, 2595, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[96271, 2601, 218, 7, 33, "Text",
  Evaluatable->False],
Cell[96492, 2610, 937, 20, 347, "Input"],
Cell[97432, 2632, 215, 8, 33, "Text",
  Evaluatable->False],
Cell[97650, 2642, 105, 2, 33, "Text",
  Evaluatable->False],
Cell[97758, 2646, 427, 7, 110, "Input"],
Cell[98188, 2655, 235, 8, 33, "Text"],
Cell[98426, 2665, 1162, 25, 210, "Input"],
Cell[99591, 2692, 616, 11, 150, "Input"],
Cell[100210, 2705, 597, 10, 150, "Input"],
Cell[100810, 2717, 490, 9, 130, "Input"],
Cell[101303, 2728, 490, 9, 130, "Input"],
Cell[101796, 2739, 492, 9, 130, "Input"]
}, Closed]],
Cell[102303, 2751, 892, 34, 106, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[103220, 2789, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[103368, 2795, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[103546, 2801, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[103906, 2813, 122, 3, 30, "Text"],
Cell[104031, 2818, 750, 31, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[104806, 2853, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[104954, 2859, 179, 4, 33, "Text",
  Evaluatable->False],
Cell[105136, 2865, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[105496, 2877, 821, 37, 49, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[106342, 2918, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[106506, 2924, 212, 7, 33, "Text",
  Evaluatable->False],
Cell[106721, 2933, 974, 20, 346, "Input"],
Cell[107698, 2955, 262, 9, 71, "Text",
  Evaluatable->False],
Cell[107963, 2966, 467, 8, 123, "Input"],
Cell[108433, 2976, 787, 15, 196, "Input"],
Cell[109223, 2993, 240, 8, 33, "Text"],
Cell[109466, 3003, 1195, 26, 210, "Input"],
Cell[110664, 3031, 649, 12, 150, "Input"],
Cell[111316, 3045, 631, 11, 150, "Input"],
Cell[111950, 3058, 490, 9, 130, "Input"],
Cell[112443, 3069, 490, 9, 130, "Input"],
Cell[112936, 3080, 492, 9, 130, "Input"]
}, Closed]],
Cell[113443, 3092, 83, 2, 30, "Text"],
Cell[113529, 3096, 820, 28, 114, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[114374, 3128, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[114522, 3134, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[114700, 3140, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[115060, 3152, 187, 4, 30, "Text"],
Cell[115250, 3158, 622, 27, 38, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[115897, 3189, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[116045, 3195, 188, 4, 33, "Text",
  Evaluatable->False],
Cell[116236, 3201, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[116596, 3213, 793, 34, 54, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[117414, 3251, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[117562, 3257, 188, 4, 33, "Text",
  Evaluatable->False],
Cell[117753, 3263, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[118113, 3275, 687, 28, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[118825, 3307, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[118973, 3313, 188, 4, 33, "Text",
  Evaluatable->False],
Cell[119164, 3319, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[119524, 3331, 1906, 79, 149, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[121455, 3414, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[121603, 3420, 188, 4, 33, "Text",
  Evaluatable->False],
Cell[121794, 3426, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[122154, 3438, 319, 11, 33, "Text",
  Evaluatable->False],
Cell[122476, 3451, 1707, 61, 196, "Text"],

Cell[CellGroupData[{
Cell[124208, 3516, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[124372, 3522, 209, 7, 36, "Text",
  Evaluatable->False],
Cell[124584, 3531, 560, 12, 224, "Input"],
Cell[125147, 3545, 247, 9, 74, "Text",
  Evaluatable->False],
Cell[125397, 3556, 463, 11, 130, "Input"],
Cell[125863, 3569, 75, 0, 33, "Text"],
Cell[125941, 3571, 284, 5, 70, "Input"],
Cell[126228, 3578, 353, 12, 93, "Text",
  Evaluatable->False],
Cell[126584, 3592, 334, 7, 139, "Input"],
Cell[126921, 3601, 75, 0, 33, "Text"],
Cell[126999, 3603, 367, 6, 92, "Input"],
Cell[127369, 3611, 286, 11, 36, "Text",
  Evaluatable->False],
Cell[127658, 3624, 105, 2, 33, "Text",
  Evaluatable->False],
Cell[127766, 3628, 478, 9, 125, "Input"],
Cell[128247, 3639, 276, 10, 36, "Text",
  Evaluatable->False],
Cell[128526, 3651, 1200, 27, 210, "Input"],
Cell[129729, 3680, 617, 12, 150, "Input"],
Cell[130349, 3694, 628, 12, 150, "Input"],
Cell[130980, 3708, 622, 12, 150, "Input"],
Cell[131605, 3722, 620, 12, 150, "Input"],
Cell[132228, 3736, 618, 12, 150, "Input"]
}, Closed]],
Cell[132861, 3751, 329, 11, 34, "Text",
  Evaluatable->False],
Cell[133193, 3764, 103113, 1693, 253, 102999, 1689, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[236309, 5459, 2089, 62, 65, "Text"],

Cell[CellGroupData[{
Cell[238423, 5525, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[238587, 5531, 236, 7, 37, "Text",
  Evaluatable->False],
Cell[238826, 5540, 462, 9, 184, "Input"],
Cell[239291, 5551, 94, 2, 33, "Text",
  Evaluatable->False],
Cell[239388, 5555, 954, 22, 210, "Input"],
Cell[240345, 5579, 419, 14, 79, "Text",
  Evaluatable->False],
Cell[240767, 5595, 1232, 27, 210, "Input"],
Cell[242002, 5624, 466, 9, 130, "Input"],
Cell[242471, 5635, 766, 13, 150, "Input"],
Cell[243240, 5650, 652, 12, 150, "Input"],
Cell[243895, 5664, 466, 9, 130, "Input"],
Cell[244364, 5675, 766, 13, 150, "Input"],
Cell[245133, 5690, 645, 12, 150, "Input"],
Cell[245781, 5704, 467, 9, 130, "Input"],
Cell[246251, 5715, 767, 13, 150, "Input"]
}, Closed]],
Cell[247033, 5731, 338, 11, 33, "Text",
  Evaluatable->False],
Cell[247374, 5744, 668, 24, 52, "Text"],

Cell[CellGroupData[{
Cell[248067, 5772, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[248231, 5778, 229, 7, 36, "Text",
  Evaluatable->False],
Cell[248463, 5787, 611, 12, 224, "Input"],
Cell[249077, 5801, 279, 9, 74, "Text",
  Evaluatable->False],
Cell[249359, 5812, 508, 10, 130, "Input"],
Cell[249870, 5824, 75, 0, 33, "Text"],
Cell[249948, 5826, 249, 4, 70, "Input"],
Cell[250200, 5832, 364, 13, 93, "Text",
  Evaluatable->False],
Cell[250567, 5847, 434, 9, 90, "Input"],
Cell[251004, 5858, 303, 10, 36, "Text",
  Evaluatable->False],
Cell[251310, 5870, 1255, 27, 210, "Input"],
Cell[252568, 5899, 469, 9, 130, "Input"],
Cell[253040, 5910, 797, 14, 150, "Input"],
Cell[253840, 5926, 675, 12, 150, "Input"],
Cell[254518, 5940, 469, 9, 130, "Input"],
Cell[254990, 5951, 797, 14, 150, "Input"],
Cell[255790, 5967, 697, 12, 150, "Input"],
Cell[256490, 5981, 470, 9, 130, "Input"],
Cell[256963, 5992, 799, 14, 150, "Input"]
}, Closed]],
Cell[257777, 6009, 290, 7, 30, "Text"],
Cell[258070, 6018, 313, 10, 33, "Text"],
Cell[258386, 6030, 304, 9, 33, "Text"],
Cell[258693, 6041, 257, 5, 33, "Text"],
Cell[258953, 6048, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

