(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    144330,       3448]*)
(*NotebookOutlinePosition[    145385,       3486]*)
(*  CellTagsIndexPosition[    145308,       3480]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 8  Residue Theory",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[StyleBox["8.1  The Residue Theorem",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Overview",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tWe now have the necessary machinery to see some amazing applications \
of the tools we developed in the last few chapters.  You will learn how \
Laurent expansions can give useful information concerning seemingly unrelated \
properties of complex functions.  You will also learn how the ideas of \
complex analysis make the solution of very complicated integrals of \
real-valued functions as easy - literally - as the computation of residues.  \
We begin with a theorem relating residues to the evaluation of complex \
integrals. "
}], "Text"],

Cell[TextData[{
  "\tThe ",
  StyleBox[ButtonBox["Cauchy",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " ",
  StyleBox[ButtonBox["integral formulae",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CauchyIntegralFormula.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " in Section 6.5 are useful in evaluating contour integrals over a simple \
closed contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " where the integrand has the form  ",
  Cell[BoxData[
      \(\(f \((z)\)\)\/\((z\  - \ z\_0)\)\^k\)]],
  "  and  f  is an analytic function.  In this case, the singularity of the \
integrand is at worst a pole of order ",
  StyleBox["k",
    FontFamily->"Courier New"],
  " at ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  We begin this section by extending this result to integrals that have a \
finite number of isolated singularities inside the contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".  This new method can be used in cases where the integrand has an \
essential singularity at ",
  Cell[BoxData[
      \(z\_0\)]],
  " and is an important extension of the previous method."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Definition 8.1 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Residue",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ResidueComplexAnalysis.html"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " have a nonremovable isolated singularity at the point ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  Then ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has the Laurent series representation for all z in some disk ",
  Cell[BoxData[
      \(\(D\_R\%*\) \((z\_0)\)\)]],
  "given by  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\) = \[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity]\( 
                a\_n\) \((z - z\_0)\)\^n\)]],
  ".  \n\nThe coefficient  ",
  Cell[BoxData[
      \(a\_\(-1\)\)]],
  "  of  ",
  Cell[BoxData[
      \(1\/\(z\  - \ z\_0\)\)]],
  "  is called the residue of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " at ",
  Cell[BoxData[
      \(z\_0\)]],
  " and we use the notation  \n\n\t\t\t",
  Cell[BoxData[
      \(Res[f, z\_0] = a\_\(-1\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 8.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  If  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \[ExponentialE]\^\(2\/z\)\)],
    AspectRatioFixed->False],
  ",  then the Laurent series of f about the point ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  " has the form   \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ 1\  + \ 2  1\/z\  + \ 2\^2\/\(\(2!\) z\^2\)\  + \ 
            2\^3\/\(\(3!\)\ z\^3\)\  + \ 2\^4\/\(\(4!\)\ z\^4\)\  + \ 
            2\^5\/\(\(5!\)\ z\^5\)\  +  ... \)]],
  ",  and\n\n\t\t\t",
  Cell[BoxData[
      \(Res[f, 0]\ \  = \ \ \(a\_\(-1\)\ \  = \ \ 2\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 8.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \[ExponentialE]\^\(2\/z\)\)],
    AspectRatioFixed->False],
  "  and construct the Laurent series about ",
  " z = 0. "
}], "Text"],

Cell[BoxData[{
    \(z = 0; \ Remove[z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, Res, S];\)\ \), "\n", 
    \(\(f[z_]\  = \ \[ExponentialE]\^\(2\/z\);\)\ \), "\n", 
    \(\(S[z_]\  = \ Series[f[z], {z, \[Infinity], 5}];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<S[z] = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "The coefficient of  ",
  Cell[BoxData[
      \(1\/z\)]],
  "  is  2  so the residue is Res[f, 0] = 2."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Res\  = \ \(S[z]\)\_\(\(\[LeftDoubleBracket]\)\(3, 2\)\(\
\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<Res[f,0] = Res[\>", f[z], "\<,0] = \>", 
        Res];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can verify this computation with ",
  StyleBox["Mathematica'",
    FontSlant->"Italic"],
  "s built in \"Residue\" procedure. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Res = Residue[\[ExponentialE]\^\(2\/z\), {z, 0}];\)\ \), "\n", 
    \(\(Print["\<Res[f,0] = Res[\>", f[z], "\<,0] = \>", 
        Res];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find  ",
  Cell[BoxData[
      \(Res[g, z\_0]\)]],
  "  if  ",
  Cell[BoxData[
      \(g \((z)\) = 3\/\(2  z\  + \ z\^2\  - \ z\^3\)\)],
    AspectRatioFixed->False],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Solution.  Using Example 7.7, we find that ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " has three Laurent series representations involving powers of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ".  The Laurent series valid in the punctured disk  ",
  Cell[BoxData[
      \(\(D\_1\%*\) \((0)\) = {z : \(\(0\)\(<\)\) | z | \(\(<\)\(1\)\)}\)]],
  "  is  \n\n\t\t\t",
  Cell[BoxData[
      \(g \((z)\)\ \  = \ \ \(\[Sum]\+\(n = \
0\)\%\[Infinity]\((\((\(-1\))\)\^n + 1\/2\^\(n + 1\))\) 
              z\^\(n - 1\)\ \  = \ \ \[Sum]\+\(n = \
0\)\%\[Infinity]\(\(\(\((\(-1\))\)\^n\) 2\^\(n + 1\)\  + \ 
                    1\)\/2\^\(n + 1\)\) z\^\(n - 1\)\)\)]],
  ".  \n\nComputing the first few coefficients, we obtain  \n\n\t\t\t",
  Cell[BoxData[{
      \(g \((z)\)\ \  = \ \ \(\(\(\((\(-1\))\)\^0\) 2\^1 + 1\)\/2\) 
            1\/z\  + \ \(\(\((\(-1\))\)\^1\) 2\^2 + 1\)\/2\^2\  + \ \(\(\(\((\
\(-1\))\)\^2\) 2\^3 + 1\)\/2\^3\) 
            z\  + \ \(\(\(\((\(-1\))\)\^3\) 2\^4 + 1\)\/2\^4\) 
            z\^\(\(2\)\(\ \)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(+\ \
\(\(\(\((\(-1\))\)\^4\) 2\^5 + 1\)\/2\^5\)\) 
            z\^3 + \ \(\(\(\((\(-1\))\)\^5\) 2\^6 + 1\)\/2\^6\) 
            z\^4\  + \ \(\(\(\((\(-1\))\)\^n\) 2\^\(n + 1\)\  + \ 
                  1\)\/2\^\(n + 1\)\) 
            z\^\(n - 1\)\  + \  ... \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(3\/2\) 1\/z\  - \ 
            3\/2\^2\  + \ \(9\/2\^3\) z\  - \ \(15\/2\^4\) 
              z\^2\  + \ \(33\/2\^5\) z\^3\  - \ \(63\/2\^6\) 
              z\^4\ \  + \  ... \)\)\)}]],
  "\n\nTherefore,   ",
  Cell[BoxData[
      \(Res[f, 0]\ \  = \ \ \(a\_\(-1\)\ \  = \ \ 3\/2\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 8.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(z = 0; \ Remove[z];\ \), "\[IndentingNewLine]", 
    \(\(g[
          z_]\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\((\((\(-1\))\)\^n + 
                1\/2\^\(n + 1\))\) z\^\(n - 1\);\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)(\!\(\((\(-1\))\)\^n\)+\!\(1\/2\^\(n + 1\)\))\!\(z\^\(n - 1\
\)\)  = \>\"", \ g[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(g[z_]\  = FullSimplify[g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)(\!\(\((\(-1\))\)\^n\)+\!\(1\/2\^\(n + 1\)\))\!\(z\^\(n - 1\
\)\)  = \>\"", \ g[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(g[z_]\  = 
        Numerator[g[z]]/
          Expand[Denominator[
              FullSimplify[g[z]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)(\!\(\((\(-1\))\)\^n\)+\!\(1\/2\^\(n + 1\)\))\!\(z\^\(n - 1\
\)\)  = \>\"", g[z]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(g[z] = 3\/\(2  z\  + \ z\^2\  - \ z\^3\)\)],
    AspectRatioFixed->False],
  "  and construct the Laurent series about  z = 0. "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[g, Res, S, z];\)\ \), "\n", 
    \(\(g[z_]\  = \ 3\/\(2  z\  + \ z\^2\  - \ z\^3\);\)\ \), "\n", 
    \(\(S[z_]\  = \ Series[g[z], {z, 0, 6}];\)\ \), "\n", 
    \(\(Print["\<g[z] = \>", g[z]];\)\ \), "\n", 
    \(\(Print["\<S[z] = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "The coefficient of  ",
  Cell[BoxData[
      \(1\/z\ \ is\ \ 3\/2\)]],
  "  so the residue is  ",
  Cell[BoxData[
      \(Res[g, 0] = 3\/2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Res\  = \ \(S[z]\)\_\(\(\[LeftDoubleBracket]\)\(3, 1\)\(\
\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<Res[g,0] = Res[\>", g[z], "\<,0] = \>", 
        Res];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can verify this computation with ",
  StyleBox["Mathematica'",
    FontSlant->"Italic"],
  "s built in \"Residue\" procedure. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Res\  = \ Residue[g[z], {z, 0}];\)\ \), "\n", 
    \(\(Print["\<Res[g,0] = Res[\>", g[z], "\<,0] = \>", 
        Res];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tRecall that, for a function ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " analytic in ",
  Cell[BoxData[
      \(\(D\_R\%*\) \((z\_0)\)\)]],
  " and for any r with ",
  Cell[BoxData[
      \(0 < r < R\)]],
  ", the Laurent series coefficients of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " are given by  \n\n",
  StyleBox["(8-1)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t  ",
  Cell[BoxData[
      \(a\_n = \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \
\(\[Integral]\_\(\(C\_r\%+\) \((z\_0)\)\)\(\(f \((\[Xi])\)\)\/\((\[Xi]\  - \ \
z\_0)\)\^\(n + 1\)\) \[DifferentialD]\[Xi]\)\)]],
  "    for    ",
  Cell[BoxData[
      RowBox[{\(n = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\[PlusMinus]1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\[PlusMinus]2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  ",  \n  \n  where ",
  Cell[BoxData[
      \(\(C\_r\%+\) \((z\_0)\)\)]],
  " denotes the circle ",
  Cell[BoxData[
      \(\(C\_r\%+\) \((z\_0)\) = {z : \ \(\(|\)\(z - z\_0\)\(|\)\) = r}\)]],
  " with positive orientation.  This gives us an important fact concerning  \
",
  Cell[BoxData[
      \(Res[f, z\_0]\)]],
  ".  If we set  ",
  Cell[BoxData[
      \(n = \(-1\)\)]],
  "  in Equation ",
  StyleBox["(8-1)",
    FontColor->RGBColor[0, 0, 1]],
  " and replace ",
  Cell[BoxData[
      \(\(C\_r\%+\) \((z\_0)\)\)]],
  " with any positively oriented simple closed contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " containing ",
  Cell[BoxData[
      \(z\_0\)]],
  ", provided ",
  Cell[BoxData[
      \(z\_0\)]],
  " is the still only singularity of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " that lies inside ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", then we obtain  \n\n",
  StyleBox["(8-2)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\ 
          f \((z)\) \[DifferentialD]z\ \  = \ \ \(2  \[Pi]\ \[ImaginaryI]\ \
a\_\(-1\)\ \  = \ \ 2  \[Pi]\ \[ImaginaryI]\ Res[f, z\_0]\)\)]],
  ".  \n\nIf we are able to find the Laurent series expansion for ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  ", then above equation gives us an important tool for evaluating contour \
integrals.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 8.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Evaluate  ",
  Cell[BoxData[
      \(\[Integral]\_\(\(\ \)\(\(C\_1\%+\) \((0)\)\)\)\ 
        exp \((2\/z)\) \[DifferentialD]z\)]],
  "  where ",
  Cell[BoxData[
      \(\(C\_1\%+\) \((0)\)\)]],
  " denotes the circle ",
  Cell[BoxData[
      \(\(C\_1\%+\) \((0)\) = {z : \ \(\(|\)\(z\)\(|\)\) = 1}\)]],
  " with positive orientation.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004a0000`b000`400?l0
0000o`00003oo`3ooolb0?ooo`00o`3ooolb0?ooo`00o`3ooolb0?ooo`00
o`3ooolb0?ooo`00o`3ooolb0?ooo`00``3oool00`000000oooo0?ooo`1[
0?ooo`00``3oool00`000000oooo0?ooo`1[0?ooo`00``3oool00`000000
oooo0?ooo`1[0?ooo`00``3oool00`000000oooo0?ooo`1[0?ooo`00``3o
ool00`000000oooo0?ooo`1[0?ooo`00``3oool00`000000oooo0?ooo`1[
0?ooo`00_03oool500000080oooo00<000000?ooo`3oool0J`3oool00;h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1[0?ooo`00
_P3oool00`000000003o0000o`070000ofT0oooo002f0?ooo`0300000000
0?l0003o00H0003o103oool00`000000oooo0?ooo`020?ooo`P0003oH@3o
ool00;40oooo1P000?l70?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool50000oe`0oooo002^0?ooo`<0003o303oool20000
00@0oooo00<000000?ooo`3oool03`3oool40000oeP0oooo002Z0?ooo`@0
003o5@3oool00`000000oooo0?ooo`0C0?ooo`@0003oE03oool00:P0oooo
0P000?lI0?ooo`030000003oool0oooo01L0oooo0P000?mB0?ooo`00Y03o
ool40000oa/0oooo00<000000?ooo`3oool06@3oool30000odl0oooo002S
0?ooo`030000o`3oool0oooo01d0oooo00<000000?ooo`3oool0703oool2
0000odd0oooo002Q0?ooo`80003o803oool00`000000oooo0?ooo`0N0?oo
o`80003oB`3oool009l0oooo0P000?lR0?ooo`030000003oool0oooo0200
oooo0P000?m90?ooo`00W@3oool20000ob@0oooo00<000000?ooo`3oool0
8P3oool00`000?l0oooo0?ooo`160?ooo`00W03oool00`000?l0oooo0?oo
o`0T0?ooo`030000003oool0oooo02<0oooo0P000?m60?ooo`00VP3oool2
0000obL0oooo00<000000?ooo`3oool09@3oool20000od@0oooo002H0?oo
o`80003o:@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo
0440oooo002G0?ooo`030000o`3oool0oooo02T0oooo00<000000?ooo`3o
ool0:03oool20000od40oooo002E0?ooo`80003o;03oool00`000000oooo
0?ooo`0Z0?ooo`80003o?`3oool009@0oooo00<0003o0?ooo`3oool0;03o
ool00`000000oooo0?ooo`0/0?ooo`030000o`3oool0oooo03`0oooo002B
0?ooo`80003o;`3oool00`000000oooo0?ooo`0]0?ooo`80003o?03oool0
0940oooo00<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0_0?oo
o`030000o`3oool0oooo03T0oooo002@0?ooo`030000o`3oool0oooo0300
oooo00<000000?ooo`3oool0<03oool00`000?l0oooo0?ooo`0h0?ooo`00
S`3oool00`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo
00<0003o0?ooo`3oool0=`3oool008h0oooo00<0003o0?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo03H0oooo002=
0?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool0
0`000?l0oooo0?ooo`0f0?ooo`00S03oool00`000?l0oooo0?ooo`0d0?oo
o`030000003oool0oooo03<0oooo00<0003o0?ooo`3oool0=@3oool008/0
oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0d0?ooo`80
003o=@3oool008X0oooo00<0003o0?ooo`3oool0=P3oool00`000000oooo
0?ooo`0f0?ooo`030000o`3oool0oooo0380oooo00290?ooo`030000o`3o
ool0oooo03L0oooo00<000000?ooo`3oool0=`3oool00`000?l0oooo0?oo
o`0a0?ooo`00R03oool00`000?l0oooo0?ooo`0h0?ooo`030000003oool0
oooo03P0oooo00<0003o0?ooo`3oool0<03oool008L0oooo00<0003o0?oo
o`3oool0>@3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo
02l0oooo00260?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3o
ool0>@3oool00`000?l0oooo0?ooo`0_0?ooo`00Q@3oool00`000?l0oooo
0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0003o0?ooo`3oool0
;P3oool008@0oooo00<0003o0?ooo`3oool0<03oool4000000P0oooo00<0
00000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`0]0?ooo`00P`3oool0
0`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`0]0?ooo`00P`3oool00`00
0?l0oooo0?ooo`0b0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0?03oool00`000?l0oooo0?ooo`0/0?ooo`00PP3oool00`000?l0
oooo0?ooo`0d0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0?@3oool00`000?l0oooo0?ooo`0[0?ooo`00P@3oool00`000?l0oooo
0?ooo`0c0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3o
ool0?P3oool00`000?l0oooo0?ooo`0Z0?ooo`00P@3oool00`000?l0oooo
0?ooo`0d0?ooo`8000002@3oool00`000000oooo0?ooo`0o0?ooo`030000
o`3oool0oooo02T0oooo00200?ooo`030000o`3oool0oooo0400oooo00<0
00000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0Y0?ooo`00P03oool0
0`000?l0oooo0?ooo`0Z0?ooo`@000000`3oool4000000030?ooo`000000
0000008000001P3oool00`000000oooo0?ooo`100?ooo`030000o`3oool0
oooo02P0oooo001o0?ooo`030000o`3oool0oooo0440oooo0P0000120?oo
o`030000o`3oool0oooo02L0oooo001n0?ooo`030000o`3oool0oooo0480
oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo0?ooo`0W0?ooo`00
OP3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo0480oooo
00<0003o0?ooo`3oool09P3oool007d0oooo00<0003o0?ooo`3oool0@`3o
ool00`000000oooo0?ooo`120?ooo`030000o`3oool0oooo02H0oooo001m
0?ooo`030000o`3oool0oooo03L0oooo1@0000070?ooo`030000003oool0
oooo0480oooo00<0003o0?ooo`3oool09P3oool007`0oooo00<0003o0?oo
o`3oool0>P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0480oooo00<0003o0?ooo`3oool09P3oool007`0oooo00<0003o0?ooo`3o
ool0>P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04<0
oooo00<0003o0?ooo`3oool09@3oool007`0oooo00<0003o0?ooo`3oool0
>P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04@0oooo
00<0003o0?ooo`3oool0903oool007/0oooo00<0003o0?ooo`3oool0>`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04@0oooo00<0
003o0?ooo`3oool0903oool007/0oooo00<0003o0?ooo`3oool0>P3oool2
000000T0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`0S
0?ooo`00NP3oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo
04D0oooo00<0003o0?ooo`3oool08`3oool007X0oooo00<0003o0?ooo`3o
ool0AP3oool00`000000oooo0?ooo`160?ooo`030000o`3oool0oooo0280
oooo001i0?ooo`030000o`3oool0oooo04L0oooo00<000000?ooo`3oool0
AP3oool00`000?l0oooo0?ooo`0R0?ooo`00N@3oool00`000?l0oooo0?oo
o`170?ooo`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool08P3o
ool007T0oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`16
0?ooo`030000o`3oool0oooo0280oooo001i0?ooo`030000o`3oool0oooo
04L0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0Q0?oo
o`00N03oool00`000?l0oooo0?ooo`180?ooo`030000003oool0oooo04L0
oooo00<0003o0?ooo`3oool08@3oool007P0oooo00<0003o0?ooo`3oool0
B03oool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo0200oooo
001h0?ooo`030000o`3oool0oooo04P0oooo00<000000?ooo`3oool0B03o
ool00`000?l0oooo0?ooo`0P0?ooo`00M`3oool00`000?l0oooo0?ooo`0S
0?ooo`@000008P3oool00`000000oooo0?ooo`0R0?ooo`@000008P3oool0
0`000?l0oooo0?ooo`0P0?ooo`00M`3oool00`000?l0oooo0?ooo`0S0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo01l0oooo001g0?ooo`03
0000o`3oool0oooo02@0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3o
ool07`3oool007L0oooo00<0003o0?ooo`3oool09@3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
8P3oool00`000?l0oooo0?ooo`0O0?ooo`00MP3oool00`000?l0oooo0?oo
o`0T0?ooo`040000003oool0oooo00000280oooo00<000000?ooo`3oool0
8P3oool010000000oooo0?ooo`00000S0?ooo`030000o`3oool0oooo01l0
oooo001f0?ooo`030000o`3oool0oooo02D0oooo0P00000S0?ooo`030000
003oool0oooo02<0oooo0P00000U0?ooo`030000o`3oool0oooo01h0oooo
001f0?ooo`030000o`3oool0oooo04X0oooo00<000000?ooo`3oool0BP3o
ool00`000?l0oooo0?ooo`0N0?ooo`00MP3oool00`000?l0oooo0?ooo`0J
0?ooo`@00000103oool800000200oooo00<000000?ooo`3oool0803oool8
00000280oooo00<0003o0?ooo`3oool07P3oool007D0oooo00<0003o0?oo
o`3oool0B`3oool00`000000oooo0?ooo`1:0?ooo`030000o`3oool0oooo
01h0oooo001e0?ooo`030000o`3oool0oooo04/0oooo00<000000?ooo`3o
ool0BP3oool00`000?l0oooo0?ooo`0N0?ooo`00M@3oool00`000?l00000
00000003000004P0oooo00<000000?ooo`3oool0B@3oool00`000000003o
00000002000001d0oooo001e0?ooo`040000o`3oool0oooo000004X0oooo
00<000000?ooo`3oool0BP3oool00`000?l000000?ooo`0N0?ooo`00M@3o
ool010000?l0oooo0?ooo`00000T0?ooo`D000008@3oool00`000000oooo
0?ooo`0R0?ooo`D000008`3oool00`000?l000000?ooo`0N0?ooo`00L03o
ool4000000050?ooo`000?l0oooo0?ooo`0000009P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
903oool00`000?l0oooo0?ooo`0M0?ooo`00M@3oool010000?l0oooo0?oo
o`00000V0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo01d0oooo
001e0?ooo`040000o`3oool00000000002H0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo
00<000000000o`3oool07P3oool007D0oooo00<0003o0?ooo`3oool09`3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0903oool00`000?l0oooo0?ooo`0M0?ooo`00M@3oool0
0`000?l0oooo0?ooo`0V0?ooo`8000008`3oool00`000000oooo0?ooo`0S
0?ooo`8000009P3oool00`000?l0oooo0?ooo`0M0?ooo`00M@3oool00`00
0?l0oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<0003o0?oo
o`3oool07@3oool007D0oooo00<0003o0?ooo`3oool0BP3oool30?l004`0
oooo00<0003o0?ooo`3oool02`3oool2000000030?ooo`000000000000d0
oooo001e0?ooo`030000o`3oool0oooo04T0oooo1@3o001;0?ooo`030000
o`3oool0oooo00`0oooo00<000000?ooo`0000003P3oool006d0oooo2000
00000`000?l0000000000019000000D0o`00B`0000000`000?l000000000
0006000000L0oooo00<000000?ooo`3oool03@3oool007D0oooo00<0003o
0?ooo`3oool0903oool00`000000oooo0?ooo`0R0?ooo`D0o`00903oool0
0`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo00/0oooo0P000000
0`3oool000000000000=0?ooo`00M@3oool00`000?l0oooo0?ooo`1:0?oo
o`<0o`00C03oool00`000?l0oooo0?ooo`0M0?ooo`00M@3oool00`000?l0
oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<0003o0?ooo`3o
ool07@3oool007D0oooo00<0003o0?ooo`3oool0B`3oool00`000000oooo
0?ooo`060?ooo`D00000@03oool00`000?l0oooo0?ooo`0M0?ooo`00M@3o
ool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0M0?ooo`00M@3oool0
0`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo00D000000`3oool0
0`000000oooo0?ooo`100?ooo`030000o`3oool0oooo01d0oooo001e0?oo
o`030000o`3oool0oooo04/0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`000000@P3oool00`000?l0oooo0?oo
o`0M0?ooo`00M@3oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0o
0?ooo`030000o`3oool0oooo01h0oooo001e0?ooo`030000o`3oool0oooo
04/0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool2
00000440oooo00<0003o0?ooo`3oool07P3oool007D0oooo00<0003o0?oo
o`3oool0B`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0N0?ooo`00M@3oool00`00
0?l0oooo0?ooo`1;0?ooo`040000003oool0oooo0?ooo`D00000A03oool0
0`000?l0oooo0?ooo`0N0?ooo`00M@3oool00`000?l0oooo0?ooo`1;0?oo
o`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool07P3oool007H0
oooo00<0003o0?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?ooo`03
0000o`3oool0oooo01h0oooo001f0?ooo`030000o`3oool0oooo04X0oooo
00<000000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`0N0?ooo`00MP3o
ool00`000?l0oooo0?ooo`1:0?ooo`030000003oool0oooo04X0oooo00<0
003o0?ooo`3oool07P3oool007H0oooo00<0003o0?ooo`3oool0BP3oool0
0`000000oooo0?ooo`190?ooo`030000o`3oool0oooo01l0oooo001g0?oo
o`030000o`3oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`00
0?l0oooo0?ooo`0O0?ooo`00M`3oool00`000?l0oooo0?ooo`190?ooo`03
0000003oool0oooo04T0oooo00<0003o0?ooo`3oool07`3oool007L0oooo
00<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000
o`3oool0oooo01l0oooo001g0?ooo`030000o`3oool0oooo04T0oooo00<0
00000?ooo`3oool0B03oool00`000?l0oooo0?ooo`0P0?ooo`00N03oool0
0`000?l0oooo0?ooo`180?ooo`030000003oool0oooo04P0oooo00<0003o
0?ooo`3oool0803oool007P0oooo00<0003o0?ooo`3oool0B03oool00`00
0000oooo0?ooo`180?ooo`030000o`3oool0oooo0200oooo001h0?ooo`03
0000o`3oool0oooo04P0oooo00<000000?ooo`3oool0B03oool00`000?l0
oooo0?ooo`0P0?ooo`00N@3oool00`000?l0oooo0?ooo`170?ooo`030000
003oool0oooo04L0oooo00<0003o0?ooo`3oool08@3oool007T0oooo00<0
003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`160?ooo`030000o`3o
ool0oooo0280oooo001i0?ooo`030000o`3oool0oooo04L0oooo00<00000
0?ooo`3oool0AP3oool00`000?l0oooo0?ooo`0R0?ooo`00N@3oool00`00
0?l0oooo0?ooo`170?ooo`030000003oool0oooo04H0oooo00<0003o0?oo
o`3oool08P3oool007X0oooo00<0003o0?ooo`3oool0AP3oool00`000000
oooo0?ooo`160?ooo`030000o`3oool0oooo0280oooo001j0?ooo`030000
o`3oool0oooo04H0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo
0?ooo`0S0?ooo`00N`3oool00`000?l0oooo0?ooo`150?ooo`030000003o
ool0oooo04D0oooo00<0003o0?ooo`3oool08`3oool007/0oooo00<0003o
0?ooo`3oool0>@3oool4000000P0oooo00<000000?ooo`3oool0A03oool0
0`000?l0oooo0?ooo`0T0?ooo`00O03oool00`000?l0oooo0?ooo`0h0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A03oool00`00
0?l0oooo0?ooo`0T0?ooo`00O03oool00`000?l0oooo0?ooo`0i0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0@`3oool00`000?l0
oooo0?ooo`0U0?ooo`00O03oool00`000?l0oooo0?ooo`0j0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo
0?ooo`0U0?ooo`00O@3oool00`000?l0oooo0?ooo`0g0?ooo`040000003o
ool0oooo000000P0oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo
0?ooo`0V0?ooo`00O@3oool00`000?l0oooo0?ooo`0h0?ooo`8000002@3o
ool00`000000oooo0?ooo`120?ooo`030000o`3oool0oooo02H0oooo001n
0?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0@P3oool0
0`000?l0oooo0?ooo`0V0?ooo`00OP3oool00`000?l0oooo0?ooo`0c0?oo
o`@0000000<0oooo0000000000000P0000060?ooo`030000003oool0oooo
0440oooo00<0003o0?ooo`3oool09`3oool007l0oooo00<0003o0?ooo`3o
ool0@@3oool200000480oooo00<0003o0?ooo`3oool09`3oool00800oooo
00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`100?ooo`030000
o`3oool0oooo02P0oooo00200?ooo`030000o`3oool0oooo0400oooo00<0
00000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0Y0?ooo`00P@3oool0
0`000?l0oooo0?ooo`0c0?ooo`D000001`3oool00`000000oooo0?ooo`0o
0?ooo`030000o`3oool0oooo02T0oooo00210?ooo`030000o`3oool0oooo
03D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0n0?oo
o`030000o`3oool0oooo02X0oooo00220?ooo`030000o`3oool0oooo03@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0m0?ooo`03
0000o`3oool0oooo02/0oooo00230?ooo`030000o`3oool0oooo03<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0l0?ooo`030000
o`3oool0oooo02`0oooo00230?ooo`030000o`3oool0oooo03<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0k0?ooo`030000o`3o
ool0oooo02d0oooo00240?ooo`030000o`3oool0oooo0340oooo0P000009
0?ooo`030000003oool0oooo03/0oooo00<0003o0?ooo`3oool0;@3oool0
08D0oooo0P000?ll0?ooo`030000003oool0oooo03X0oooo00<0003o0?oo
o`3oool0;P3oool008H0oooo00<0003o0?ooo`3oool0>P3oool00`000000
oooo0?ooo`0i0?ooo`030000o`3oool0oooo02l0oooo00270?ooo`030000
o`3oool0oooo03T0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo
0?ooo`0_0?ooo`00R03oool00`000?l0oooo0?ooo`0h0?ooo`030000003o
ool0oooo03P0oooo00<0003o0?ooo`3oool0<03oool008P0oooo00<0003o
0?ooo`3oool0>03oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0
oooo0340oooo00290?ooo`030000o`3oool0oooo03L0oooo00<000000?oo
o`3oool0=P3oool00`000?l0oooo0?ooo`0b0?ooo`00RP3oool00`000?l0
oooo0?ooo`0f0?ooo`030000003oool0oooo03D0oooo00<0003o0?ooo`3o
ool0<`3oool008/0oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo
0?ooo`0d0?ooo`030000o`3oool0oooo03@0oooo002<0?ooo`030000o`3o
ool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0?oo
o`0e0?ooo`00S@3oool20000oc@0oooo00<000000?ooo`3oool0<P3oool0
0`000?l0oooo0?ooo`0f0?ooo`00S`3oool00`000?l0oooo0?ooo`0a0?oo
o`030000003oool0oooo0340oooo00<0003o0?ooo`3oool0=`3oool00900
oooo00<0003o0?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?ooo`03
0000o`3oool0oooo03P0oooo002A0?ooo`030000o`3oool0oooo02l0oooo
00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0i0?ooo`00TP3o
ool00`000?l0oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo00<0
003o0?ooo`3oool0>P3oool009<0oooo0P000?l^0?ooo`030000003oool0
oooo02`0oooo0P000?lm0?ooo`00U@3oool00`000?l0oooo0?ooo`0[0?oo
o`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool0?@3oool009H0
oooo0P000?l[0?ooo`030000003oool0oooo02T0oooo0P000?m00?ooo`00
V03oool00`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo
0P000?m20?ooo`00V@3oool20000obP0oooo00<000000?ooo`3oool09P3o
ool00`000?l0oooo0?ooo`120?ooo`00V`3oool20000obH0oooo00<00000
0?ooo`3oool0903oool20000odD0oooo002M0?ooo`030000o`3oool0oooo
02<0oooo00<000000?ooo`3oool08P3oool20000odL0oooo002N0?ooo`80
003o8`3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo04L0
oooo002P0?ooo`80003o8@3oool00`000000oooo0?ooo`0O0?ooo`80003o
BP3oool00:80oooo0P000?lO0?ooo`030000003oool0oooo01d0oooo0P00
0?m<0?ooo`00Y03oool30000oa`0oooo00<000000?ooo`3oool06@3oool4
0000odh0oooo002W0?ooo`80003o6P3oool00`000000oooo0?ooo`0H0?oo
o`030000o`3oool0oooo0500oooo002Y0?ooo`@0003o5P3oool00`000000
oooo0?ooo`0D0?ooo`@0003oD`3oool00:d0oooo10000?lB0?ooo`030000
003oool0oooo0100oooo10000?mG0?ooo`00/@3oool30000o`P0oooo1@00
00020?ooo`030000003oool0oooo00`0oooo10000?mK0?ooo`00]03oool8
0000o`80oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`L0003oG`3oool00;`0oooo3`000?mV0?ooo`00_P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo06/0oooo002n0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0J`3oool00;d0oooo0P00
00040?ooo`030000003oool0oooo06/0oooo00330?ooo`030000003oool0
oooo06/0oooo00330?ooo`030000003oool0oooo06/0oooo00330?ooo`03
0000003oool0oooo06/0oooo00330?ooo`030000003oool0oooo06/0oooo
00330?ooo`030000003oool0oooo06/0oooo003o0?oooc80oooo003o0?oo
oc80oooo003o0?oooc80oooo003o0?oooc80oooo003o0?oooc80oooo003o
0?oooc80oooo00310?ooo`800000KP3oool00<80oooo00<000000?ooo`3o
ool0K03oool00<<0oooo00<000000?ooo`3oool0J`3oool00<80oooo00<0
00000?ooo`000000K03oool00<40oooo00@000000?ooo`3oool00000K03o
ool00<00oooo0`0000000`3oool000000000001[0?ooo`00o`3ooolb0?oo
o`00o`3ooolb0?ooo`00o`3ooolb0?ooo`00o`3ooolb0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{305, 195},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  In Example 8.1 we showed that the residue of  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \[ExponentialE]\^\(2\/z\)\)],
    AspectRatioFixed->False],
  "  at  ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  "  is  ",
  Cell[BoxData[
      \(Res[f, 0]\  = \ 2\)]],
  ".  Using Equation ",
  StyleBox["(8-2)",
    FontColor->RGBColor[0, 0, 1]],
  ", we get  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_\(\(\ \)\(\(C\_1\%+\) \((0)\)\)\)\ 
          exp \((2\/z)\) \[DifferentialD]z\ \  = \ \ \(2  \[Pi]\ \
\[ImaginaryI]\ Res[f, 0]\ \  = \ \ 4  \[Pi]\ \[ImaginaryI]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 8.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["From Example 8.1  we have  Res[f,0]  =  2.", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(z = 0; \ Remove[z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, Res, val];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_]\  = \ \[ExponentialE]\^\(2\/z\);\)\ \), "\n", 
    \(\(Res\  = \ Residue[f[z], {z, 0}];\)\ \), "\n", 
    \(\(Print["\<Res[f,0] = Res[\>", f[z], "\<,0] = \>", 
        Res];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Thus the value of the contour integral is given by the following computation.\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(val\  = \ 
        2  \[Pi]\ \[ImaginaryI]\ Res;\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_1 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,0] = Res[\>", f[z], "\<,0] = \>", 
        Res];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{{Red, PointSize[0.03], 
              Point[{Re[Z\_1], Im[Z\_1]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(center = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] + 0.05}, {\(-1\), 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 1]}];\)\ \), "\n", 
    \(\(Show[dot, center, contour, 
        PlotRange \[Rule] {{\(-1.1\), 1.1}, {\(-1.1\), 1.1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1\/2], 
            Range[\(-1\), 1, 1\/2]}, \[IndentingNewLine]AspectRatio \[Rule] 
          1, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) \>\"", 
      f[z], "\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI] Res[\>", 
      f[z], "\<,0] = \>", val]\), "\[IndentingNewLine]", 
    \(\(Print["\<The contour is the unit circle  C:|z| = 1,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<with positive orientation.\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 8.1 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Cauchy's Residue Theorem",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ResidueTheorem.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " be a simply connected domain, and let ",
  StyleBox["C",
    FontFamily->"Courier New"],
  "  be a simple closed positively oriented contour that lies in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  If ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic \ninside ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " and on ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ",  except at the points  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_n\)}]]],
  "  that lie inside ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", then  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_C\ 
          f \((z)\) \[DifferentialD]z\ \  = \ \ 2  \[Pi]\ \[ImaginaryI]\ \(\
\[Sum]\+\(k = 1\)\%n Res[f, z\_k]\)\)]],
  ".  \n\nThe situation is illustrated in Figure 8.1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 8.1 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 8.1",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/residuecalculus/\
ResidueCalcFigures/mat0801.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  " The domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " and contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " and the singular points ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_n\)}]]],
  " in the statement of Cauchy's residue theorem."
}], "Text"],

Cell[TextData[{
  "\tThe calculation of a ",
  StyleBox[ButtonBox["Laurent",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Laurent_\
Pierre.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " ",
  StyleBox[ButtonBox["series",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LaurentSeries.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " expansion is tedious in most circumstances.  Since the residue at ",
  Cell[BoxData[
      \(z\_0\)]],
  " involves only the coefficient ",
  Cell[BoxData[
      \(a\_\(-1\)\)]],
  " in the Laurent expansion, we seek a method to calculate the residue from \
special information about the nature of the singularity at ",
  Cell[BoxData[
      \(z\_0\)]],
  ".\n\n\tIf ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has a removable singularity at ",
  Cell[BoxData[
      \(z\_0\)]],
  ", then  ",
  Cell[BoxData[
      \(a\_\(-1\) = 0\)]],
  "  for  ",
  Cell[BoxData[
      RowBox[{\(n = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  ".  Therefore,  ",
  Cell[BoxData[
      \(Res[f, z\_0] = 0\)]],
  ".  Theorem 8.2 gives methods for evaluating residues at poles."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Theorem 8.2 (Residues at Poles).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 1]],
  "\n",
  StyleBox["(i)  ",
    FontColor->RGBColor[0, 0, 1]],
  "\tIf ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has a simple pole at  ",
  Cell[BoxData[
      \(z\_0\)]],
  ",  then  ",
  Cell[BoxData[
      \(Res[f, z\_0]\  = \ 
        lim\+\(z\  \[Rule] \ z\_0\)\ \((z - z\_0)\) f \((z)\)\)]],
  ".  \n\n",
  StyleBox["(ii) ",
    FontColor->RGBColor[0, 0, 1]],
  "\tIf ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has a pole of order ",
  StyleBox["2",
    FontFamily->"Courier New"],
  " at  ",
  Cell[BoxData[
      \(z\_0\)]],
  ",  then  ",
  Cell[BoxData[
      \(Res[f, z\_0]\  = \ 
        lim\+\(z\  \[Rule] \ z\_0\)\ \(d\/dz\) \((\(\((z - z\_0)\)\^2\) 
                f \((z)\))\)\)]],
  ".  \n\n",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  " \tIf ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has a pole of order ",
  StyleBox["3",
    FontFamily->"Courier New"],
  " at  ",
  Cell[BoxData[
      \(z\_0\)]],
  ",  then  ",
  Cell[BoxData[
      \(Res[f, 
          z\_0]\  = \ \(1\/\(2!\)\) \(lim\+\(z\  \[Rule] \ z\_0\)\ \(d\^2\/dz\
\^2\) \((\(\((z - z\_0)\)\^3\) f \((z)\))\)\)\)]],
  ".  \n\n",
  StyleBox["(v) ",
    FontColor->RGBColor[0, 0, 1]],
  "\tIf ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has a pole of order ",
  StyleBox["k",
    FontFamily->"Courier New"],
  " at  ",
  Cell[BoxData[
      \(z\_0\)]],
  ",  then  ",
  Cell[BoxData[
      \(Res[f, 
          z\_0]\  = \ \(1\/\(\((k - 
                    1)\)!\)\) \(lim\+\(z\  \[Rule] \ z\_0\)\ \(d\^\(k - \
1\)\/dz\^\(k - 1\)\) \((\(\((z - z\_0)\)\^k\) f \((z)\))\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Proof of Theorem 8.2",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[" is in the book.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the residue of  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(\[Pi]\ cot\ \((\[Pi]\ z)\)\)\/z\^2\)]],
  "  at  ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Solution.  We write  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(\(\[Pi]\ cot\ \((\[Pi]\ z)\)\)\/z\^2\  = \ \(\[Pi]\ \
cos\ \((\[Pi]\ z)\)\)\/\(\(z\^2\) sin\ \((\[Pi]\ z)\)\)\)\)]],
  ".  Because  ",
  Cell[BoxData[
      \(\(z\^2\) sin\ \((\[Pi]\ z)\)\)]],
  "  has a zero of order ",
  StyleBox["3",
    FontFamily->"Courier New"],
  " at ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  " and  ",
  Cell[BoxData[
      \(\[Pi]\ cot\ \((\[Pi]\ z)\) \[NotEqual] 0\)]],
  ".  Thus ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has a pole of order ",
  StyleBox["3",
    FontFamily->"Courier New"],
  " at ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  ".  By part ",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  " of Theorem 8.2, we have  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, 
          0]\  = \ \(\(1\/\(2!\)\) \(lim\+\(z\  \[Rule] 0\)\ \(d\^2\/dz\^2\) \
\((\(z\^3\) 
                    f \((z)\))\)\)\  = \ \(1\/\(2!\)\) \(lim\+\(z\  \[Rule] 0\
\)\ \(d\^2\/dz\^2\) \((\(z\^3\) \(\[Pi]\ cot\ \((\[Pi]\ z)\)\)\/z\^2)\)\)\)\)\
\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \
\)\(\(1\/\(2!\)\) \(lim\+\(z\  \[Rule] 0\)\ \(d\^2\/dz\^2\) \((\[Pi]\ z\ cot\ \
\((\[Pi]\ z)\))\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \
\)\(\(1\/\(2!\)\) \(lim\+\(z\  \[Rule] 0\)\ \(d\/dz\) \((\[Pi]\ cot \((\[Pi]\ \
z)\)\  - \ \[Pi]\^2\ z\ \(csc\^2\) \((\[Pi]\ z)\))\)\)\)\)\(\ \ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \
\)\(\(1\/\(2!\)\) \(lim\+\(z\  \[Rule] 0\)\ \((\(-\[Pi]\^2\)\ \(csc\^2\) \((\
\[Pi]\ z)\) - \(\[Pi]\^2\) \((\(csc\^2\) \((\[Pi]\ z)\) - 
                      2  \[Pi]\ z\ \(csc\^2\) \((\[Pi]\ z)\) 
                        cot \((\[Pi]\ z)\))\))\)\)\)\)\(\ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \
\)\(\(1\/\(2!\)\) \(lim\+\(z\  \[Rule] 0\)\ \((2\ \[Pi]\^3\ z\ cot \((\[Pi]\ \
z)\)\ \(csc\^2\) \((\[Pi]\ z)\) - 
                2\ \[Pi]\^2\ \(csc\^2\) \((\[Pi]\ z)\))\)\)\)\)\(\ \ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(\(\[Pi]\^2\
\) \(lim\+\(z\  \[Rule] 0\)\ \((\[Pi]\ z\ cot \((\[Pi]\ z)\)\ \(csc\^2\) \((\
\[Pi]\ z)\) - \ \(csc\^2\) \((\[Pi]\ z)\))\)\)\)\)\(\ \ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(\(\[Pi]\^2\
\) \(lim\+\(z\  \[Rule] 0\)\ \((\[Pi]\ z\ cot \((\[Pi]\ z)\) - 
                  1)\)\ \(csc\^2\) \((\[Pi]\ z)\)\)\)\)\(\ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(\(\[Pi]\^2\
\) \(lim\+\(z\  \[Rule] 0\)\ \(\((\[Pi]\ z\ cot \((\[Pi]\ z)\) - 1)\)\ sin \
\((\[Pi]\ z)\)\)\/\(\(\ \)\(\(sin\^3\) \((\[Pi]\ z)\)\)\)\)\)\)\(\ \ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(\(\[Pi]\^2\) \
\(\(lim\+\(z\  \[Rule] 
                  0\)\)\(\ \)\(\(\[Pi]\ z\ cos \((\[Pi]\ z)\) - \(\(sin\) \((\
\[Pi]\ z)\)\(\ \)\)\)\/\(\(\ \)\(\(sin\^3\) \((\[Pi]\ z)\)\)\)\)\(\ \ \
\)\)\)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "This last limit involves an indeterminate form, which we evaluate by using \
L'H\[OHat]pital's rule:  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, 
          0]\ \  = \ \ \(\[Pi]\^2\) \(lim\+\(z\  \[Rule] 0\)\ \(\[Pi]\ z\ cos \
\((\[Pi]\ z)\)\  - \ \(\(sin\) \((\[Pi]\ z)\)\(\ \)\)\)\/\(\(\ \)\(\(sin\^3\) \
\((\[Pi]\ z)\)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \(\(\(=\)\(\ \ \)\(\(\[Pi]\^2\) \(lim\+\(z\  \[Rule] 0\)\ \(\(-\
\[Pi]\^2\)\ z\ sin \((\[Pi]\ z)\)\  + \ \[Pi]\ cos \((\[Pi]\ z)\)\  - \ \[Pi]\
\ cos \((\[Pi]\ z)\)\)\/\(3\ \[Pi]\ cos \((\[Pi]\ z)\)\ \(sin\^2\) \((\[Pi]\ \
z)\)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \(\(\(=\)\(\ \ \)\(\(\[Pi]\^2\) \(lim\+\(z\  \[Rule] 0\)\ \(\(-\
\[Pi]\^2\)\ z\ sin \((\[Pi]\ z)\)\)\/\(3\ \[Pi]\ cos \((\[Pi]\ z)\)\ \(sin\^2\
\) \((\[Pi]\ z)\)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \(\(\(=\)\(\ \ \)\(\(\[Pi]\^2\) \(lim\+\(z\  \[Rule] 0\)\ \(\(-\
\[Pi]\)\ z\)\/\(3\ cos \((\[Pi]\ z)\)\ sin \((\[Pi]\ z)\)\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \(\(=\)\(\ \ \)\(\(\(-\[Pi]\^2\)\/3\) \(lim\+\(z\  \[Rule] 0\)\ \
\(\[Pi]\ z\)\/\(cos \((\[Pi]\ z)\)\ sin \((\[Pi]\ z)\)\)\)\)\)\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \(\(=\)\(\ \ \)\(\(\(-\[Pi]\^2\)\/3\) \(lim\+\(z\  \[Rule] 0\)\ \
\(\(\[Pi]\ z\)\/\(sin \((\[Pi]\ z)\)\)\) \(lim\+\(z\  \[Rule] 0\)\ 
                1\/\(cos \((\[Pi]\ z)\)\)\)\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \(\(=\)\(\ \ \)\(\(\(-\[Pi]\^2\)\/3\) \((1)\) \((1)\)\ \  = \ \ \
\(-\(\[Pi]\^2\/3\)\)\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \(\[Pi]\ Cot[\[Pi]\ z]\)\/z\^2\)],
    AspectRatioFixed->False],
  ".   "
}], "Text"],

Cell[BoxData[{
    \(z = 0; \ Remove[z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, Res, S];\)\ \), "\n", 
    \(\(f[z_]\  = \ \(\[Pi]\ Cot[\[Pi]\ z]\)\/z\^2;\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "The function  f[z]  has a pole of order  3  at  ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  ".  The residue is computed using Theorem 8.2 (c)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(ResLim = 
        1\/\(2!\)\ Limit[\[PartialD]\_\(z, z\)\ \((z\^3\ f[z])\), 
            z \[Rule] 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<      \!\(z\^3\)f[z] = \>\"", z\^3\ f[z]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(\[PartialD]\_z\) (\!\(z\^3\)f[z]) = \>\"", \
\[PartialD]\_z\ \((\(z\^3\) f[z])\)];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[PartialD]\_\(z, z\)\) (\!\(z\^3\)f[z]) = \>\"", \
\[PartialD]\_\(z, z\)\ \((z\^3\ f[z])\)];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Res[f,0] = \!\(1\/\(2!\)\) \!\(lim\+\(z \[Rule] 0\)\) \>\
\"", \*"\"\<\!\(\[PartialD]\_\(z, z\)\)(\!\(z\^3\)f[z])) = \>\"", 
        ResLim];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Res[f,0] = Res[\>", f[z], "\<,0] = \>", 
        ResLim];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can verify this computation with ",
  StyleBox["Mathematica'",
    FontSlant->"Italic"],
  "s built in \"Residue\" procedure. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Res = Residue[f[z], {z, 0}];\)\ \), "\n", 
    \(\(Print["\<Res[f,0] = Res[\>", f[z], "\<,0] = \>", 
        Res];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Which is the coefficient of  ",
  Cell[BoxData[
      \(1\/z\)]],
  " in the Laurent series expansion for  f[z]."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(S[z_]\  = \ Series[f[z], {z, 0, 7}];\)\ \), "\n", 
    \(\(Res\  = \ \(S[z]\)\_\(\(\[LeftDoubleBracket]\)\(3, 3\)\(\
\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<S[z] = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Res[f,0] = Res[\>", f[z], "\<,0] = \>", 
        Res];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find  ",
  Cell[BoxData[
      \(\[Integral]\_\(\(C\_3\%+\) \((0)\)\)\(\(\(\ \)\(1\)\)\/\(z\^4\  + \ 
                z\^3\  - \ 2  z\^2\)\) \[DifferentialD]z\)]],
  "  where ",
  Cell[BoxData[
      \(\(C\_3\%+\) \((0)\)\)]],
  " denotes the circle ",
  Cell[BoxData[
      \(\(C\_3\%+\) \((0)\) = {z : \ \(\(|\)\(z\)\(|\)\) = 3}\)]],
  " with positive orientation.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004a0000`b000`400?l0
0000o`00003oo`3ooolb0?ooo`00o`3ooolb0?ooo`00o`3ooolb0?ooo`00
o`3ooolb0?ooo`00o`3ooolb0?ooo`00o`3ooolb0?ooo`00o`3ooolb0?oo
o`00a03oool00`000000oooo0?ooo`1Z0?ooo`00_P3oool2000000@0oooo
00<000000?ooo`3oool0JP3oool00;d0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`1Z0?ooo`00_03ooolB0000of<0oooo002f
0?ooo`H0003o103oool01@000000oooo0?ooo`3oool0000000T0oooo1P00
0?mM0?ooo`00/P3oool40000o`L0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0=0?ooo`@0003oF@3oool00:h0oooo10000?l<
0?ooo`800000103oool00`000000oooo0?ooo`0A0?ooo`@0003oE@3oool0
0:X0oooo10000?lF0?ooo`030000003oool0oooo01D0oooo10000?mA0?oo
o`00Z03oool20000oaX0oooo00<000000?ooo`3oool06@3oool20000odl0
oooo002T0?ooo`@0003o703oool00`000000oooo0?ooo`0K0?ooo`@0003o
B`3oool00:<0oooo00<0003o0?ooo`3oool07P3oool00`000000oooo0?oo
o`0O0?ooo`030000o`3oool0oooo04P0oooo002Q0?ooo`80003o8@3oool0
0`000000oooo0?ooo`0P0?ooo`80003oB03oool009l0oooo0P000?lS0?oo
o`030000003oool0oooo0280oooo0P000?m60?ooo`00W@3oool20000obD0
oooo00<000000?ooo`3oool0903oool20000od@0oooo002K0?ooo`80003o
9`3oool00`000000oooo0?ooo`0V0?ooo`80003o@P3oool009X0oooo00<0
003o0?ooo`3oool09`3oool00`000000oooo0?ooo`0X0?ooo`80003o@03o
ool009P0oooo0P000?lZ0?ooo`030000003oool0oooo02X0oooo00<0003o
0?ooo`3oool0?@3oool009H0oooo0P000?l/0?ooo`030000003oool0oooo
02/0oooo0P000?lm0?ooo`00U03oool20000obh0oooo00<000000?ooo`3o
ool0;@3oool00`000?l0oooo0?ooo`0j0?ooo`00T`3oool00`000?l0oooo
0?ooo`0^0?ooo`030000003oool0oooo02h0oooo00<0003o0?ooo`3oool0
>@3oool009<0oooo00<0003o0?ooo`3oool0;P3oool00`000000oooo0?oo
o`0_0?ooo`030000o`3oool0oooo03P0oooo002A0?ooo`80003o<@3oool0
0`000000oooo0?ooo`0`0?ooo`80003o>03oool00900oooo00<0003o0?oo
o`3oool0<@3oool00`000000oooo0?ooo`0b0?ooo`80003o=P3oool008l0
oooo00<0003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`03
0000o`3oool0oooo03@0oooo002>0?ooo`030000o`3oool0oooo03<0oooo
00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0c0?ooo`00S03o
ool20000ocH0oooo00<000000?ooo`3oool0=@3oool20000oc<0oooo002;
0?ooo`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0=`3oool0
0`000?l0oooo0?ooo`0`0?ooo`00RP3oool00`000?l0oooo0?ooo`0g0?oo
o`030000003oool0oooo03P0oooo00<0003o0?ooo`3oool0;`3oool008T0
oooo00<0003o0?ooo`3oool0<@3oool4000000<0oooo00<000000?ooo`3o
ool0>@3oool00`000?l0oooo0?ooo`0^0?ooo`00R03oool00`000?l0oooo
0?ooo`0b0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
>P3oool00`000?l0oooo0?ooo`0]0?ooo`00Q`3oool00`000?l0oooo0?oo
o`0d0?ooo`030000003oool0oooo00<0oooo0`00000j0?ooo`030000o`3o
ool0oooo02d0oooo00270?ooo`030000o`3oool0oooo02d0oooo10000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>`3oool0
0`000?l0oooo0?ooo`0/0?ooo`00Q@3oool20000ocH0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0l0?ooo`80003o;03oool0
08@0oooo00<0003o0?ooo`3oool0=`3oool2000000@0oooo00<000000?oo
o`3oool0?@3oool00`000?l0oooo0?ooo`0Z0?ooo`00Q03oool00`000?l0
oooo0?ooo`0m0?ooo`030000003oool0oooo03h0oooo00<0003o0?ooo`3o
ool0:@3oool008<0oooo00<0003o0?ooo`3oool0?P3oool00`000000oooo
0?ooo`0n0?ooo`030000o`3oool0oooo02T0oooo00230?ooo`030000o`3o
ool0oooo03h0oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo0?oo
o`0X0?ooo`00PP3oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0
oooo0400oooo00<0003o0?ooo`3oool09`3oool00840oooo00<0003o0?oo
o`3oool0@03oool00`000000oooo0?ooo`110?ooo`030000o`3oool0oooo
02H0oooo00200?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3o
ool0@P3oool00`000?l0oooo0?ooo`0U0?ooo`00O`3oool00`000?l0oooo
0?ooo`120?ooo`030000003oool0oooo0480oooo00<0003o0?ooo`3oool0
9@3oool007l0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?oo
o`130?ooo`030000o`3oool0oooo02@0oooo001n0?ooo`030000o`3oool0
oooo04<0oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`0S
0?ooo`00O@3oool00`000?l0oooo0?ooo`140?ooo`030000003oool0oooo
04@0oooo00<0003o0?ooo`3oool08`3oool007d0oooo00<0003o0?ooo`3o
ool0A03oool00`000000oooo0?ooo`150?ooo`030000o`3oool0oooo0280
oooo001l0?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool0
A@3oool00`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000?l0oooo0?oo
o`150?ooo`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool08@3o
ool007/0oooo00<0003o0?ooo`3oool0AP3oool00`000000oooo0?ooo`16
0?ooo`030000o`3oool0oooo0240oooo001k0?ooo`030000o`3oool0oooo
04H0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0P0?oo
o`00NP3oool00`000?l0oooo0?ooo`170?ooo`030000003oool0oooo04L0
oooo00<0003o0?ooo`3oool0803oool007X0oooo00<0003o0?ooo`3oool0
A`3oool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo01l0oooo
001i0?ooo`030000o`3oool0oooo04P0oooo00<000000?ooo`3oool0B03o
ool00`000?l0oooo0?ooo`0O0?ooo`00N@3oool00`000?l0oooo0?ooo`18
0?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3oool07P3oool0
07T0oooo00<0003o0?ooo`3oool0B03oool00`000000oooo0?ooo`190?oo
o`030000o`3oool0oooo01h0oooo001h0?ooo`030000o`3oool0oooo04T0
oooo00<000000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`0N0?ooo`00
N03oool00`000?l0oooo0?ooo`190?ooo`030000003oool0oooo04X0oooo
00<0003o0?ooo`3oool07@3oool007L0oooo00<0003o0?ooo`3oool0@`3o
ool500000080oooo00<000000?ooo`3oool0BP3oool00`000?l0oooo0?oo
o`0M0?ooo`00M`3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0L
0?ooo`00MP3oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo
0080oooo0`00001;0?ooo`030000o`3oool0oooo01`0oooo001f0?ooo`03
0000o`3oool0oooo03h0oooo100000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`0K0?ooo`00
MP3oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`0K0?ooo`00MP3o
ool00`000?l0oooo0?ooo`150?ooo`800000103oool00`000000oooo0?oo
o`1<0?ooo`030000o`3oool0oooo01/0oooo001e0?ooo`030000o`3oool0
oooo04`0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`0K
0?ooo`00M@3oool00`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo
04d0oooo00<0003o0?ooo`3oool06P3oool007D0oooo00<0003o0?ooo`3o
ool0C03oool00`000000oooo0?ooo`1=0?ooo`030000o`3oool0oooo01X0
oooo001e0?ooo`030000o`3oool0oooo04`0oooo00<000000?ooo`3oool0
C@3oool00`000?l0oooo0?ooo`0J0?ooo`00M03oool00`000?l0oooo0?oo
o`1=0?ooo`030000003oool0oooo04d0oooo00<0003o0?ooo`3oool06P3o
ool007@0oooo00<0003o0?ooo`3oool0C@3oool00`000000oooo0?ooo`1>
0?ooo`030000o`3oool0oooo01T0oooo001d0?ooo`030000o`3oool0oooo
04d0oooo00<000000?ooo`3oool0CP3oool00`000?l0oooo0?ooo`0I0?oo
o`00M03oool00`000?l0oooo0?ooo`1=0?ooo`030000003oool0oooo04h0
oooo00<0003o0?ooo`3oool06@3oool007<0oooo00<0003o0?ooo`3oool0
CP3oool00`000000oooo0?ooo`1>0?ooo`030000o`3oool0oooo01T0oooo
001c0?ooo`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool0C`3o
ool00`000?l0oooo0?ooo`0H0?ooo`00L`3oool00`000?l0oooo0?ooo`1>
0?ooo`030000003oool0oooo04l0oooo00<0003o0?ooo`3oool0603oool0
07<0oooo00<0003o0?ooo`3oool0CP3oool00`000000oooo0?ooo`1?0?oo
o`030000o`3oool0oooo01P0oooo001c0?ooo`030000o`3oool0oooo04h0
oooo00<000000?ooo`3oool0C`3oool00`000?l0oooo0?ooo`0H0?ooo`00
L`3oool00`000?l000000000000I0?ooo`@000005`3oool5000001D0oooo
00<000000?ooo`3oool05`3oool5000001H0oooo1000000I0?ooo`030000
o`000000oooo01P0oooo001b0?ooo`050000o`000000oooo0?ooo`000000
603oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01T0oooo00@000000000o`3oool00000603oool00780oooo
00@0003o0?ooo`3oool000006P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo01X0oooo00<0003o0?ooo`3o
ool05`3oool006d0oooo100000000`3oool0003o0?ooo`020?ooo`030000
003oool0oooo0100oooo100000040?ooo`030000003oool0oooo0100oooo
100000040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo
00<0003o0000003oool05`3oool00780oooo00D0003o0000003oool0oooo
0000000H0?ooo`040000003oool0oooo000001T0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01H0
oooo00@000000?ooo`3oool00000603oool010000000oooo0000o`00000H
0?ooo`00LP3oool010000?l0oooo00000000000J0?ooo`8000006@3oool2
000001L0oooo00<000000?ooo`3oool0603oool2000001T0oooo0P00000J
0?ooo`03000000000?l0oooo01P0oooo001b0?ooo`030000o`3oool0oooo
04l0oooo00<000000?ooo`3oool0D03oool00`000?l0oooo0?ooo`0G0?oo
o`00LP3oool00`000?l0oooo0?ooo`1?0?ooo`030000003oool0oooo0500
oooo00<0003o0?ooo`3oool05`3oool00780oooo00<0003o0?ooo`3oool0
603oool30?l003<0oooo0`3o000I0?ooo`<0o`00=@3oool00`000?l0oooo
0?ooo`0G0?ooo`00LP3oool00`000?l0oooo0?ooo`0G0?ooo`D0o`00<@3o
ool50?l001L0oooo1@3o000d0?ooo`030000o`3oool0oooo00H0oooo0P00
00000`3oool000000000000<0?ooo`00K`3oool3000000030000o`000000
000001L000001@3o000a000000D0o`005`0000050?l003@0000000@0003o
00000000000000001P3oool00`000000oooo0000000=0?ooo`00LP3oool0
0`000?l0oooo0?ooo`0G0?ooo`D0o`00603oool00`000000oooo0?ooo`0F
0?ooo`D0o`005`3oool50?l001P0oooo00<000000?ooo`3oool06@3oool0
0`000?l0oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo001b0?oo
o`030000o`3oool0oooo01P0oooo0`3o000I0?ooo`030000003oool0oooo
01L0oooo0`3o000I0?ooo`<0o`006@3oool00`000000oooo0?ooo`0I0?oo
o`030000o`3oool0oooo00H0oooo0P0000000`3oool000000000000<0?oo
o`00LP3oool00`000?l0oooo0?ooo`0R0?ooo`D000008P3oool3000000<0
oooo00<000000?ooo`3oool0203oool2000001X0oooo0`00000Y0?ooo`03
0000o`3oool0oooo01L0oooo001b0?ooo`030000o`3oool0oooo01`0oooo
1@0000030?ooo`030000003oool0oooo01/0oooo1@0000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@0000050?ooo`030000
003oool0oooo00l0oooo1@0000040?ooo`030000003oool0oooo02P0oooo
00<0003o0?ooo`3oool05`3oool00780oooo00<0003o0?ooo`3oool07@3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01`0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0140oooo00@000000?ooo`3oool000000P3oool4
000002T0oooo00<0003o0?ooo`3oool05`3oool00780oooo00<0003o0?oo
o`3oool07P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`000000:P3oool00`000?l0oooo0?ooo`0G0?ooo`00LP3oool00`000?l0
oooo0?ooo`0O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool07P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`000000503oool00`000000oooo0?ooo`020?ooo`800000:P3oool0
0`000?l0oooo0?ooo`0G0?ooo`00LP3oool00`000?l0oooo0?ooo`0M0?oo
o`040000003oool0oooo00000080oooo0P00000N0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0A0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0:03oool00`000?l0oooo0?ooo`0G0?ooo`00LP3oool00`000?l0oooo
0?ooo`0M0?ooo`D000008@3oool5000000L0oooo00@000000?ooo`3oool0
oooo1@00000G0?ooo`D00000;P3oool00`000?l0oooo0?ooo`0G0?ooo`00
LP3oool00`000?l0oooo0?ooo`1?0?ooo`030000003oool0oooo04l0oooo
00<0003o0?ooo`3oool0603oool007<0oooo00<0003o0?ooo`3oool0CP3o
ool00`000000oooo0?ooo`1?0?ooo`030000o`3oool0oooo01P0oooo001c
0?ooo`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool0C`3oool0
0`000?l0oooo0?ooo`0H0?ooo`00L`3oool00`000?l0oooo0?ooo`1>0?oo
o`030000003oool0oooo04l0oooo00<0003o0?ooo`3oool0603oool007<0
oooo00<0003o0?ooo`3oool0CP3oool00`000000oooo0?ooo`1?0?ooo`03
0000o`3oool0oooo01P0oooo001c0?ooo`030000o`3oool0oooo04h0oooo
00<000000?ooo`3oool0C`3oool00`000?l0oooo0?ooo`0H0?ooo`00L`3o
ool00`000?l0oooo0?ooo`1>0?ooo`030000003oool0oooo04h0oooo00<0
003o0?ooo`3oool06@3oool007@0oooo00<0003o0?ooo`3oool0C@3oool0
0`000000oooo0?ooo`1>0?ooo`030000o`3oool0oooo01T0oooo001d0?oo
o`030000o`3oool0oooo04d0oooo00<000000?ooo`3oool0CP3oool00`00
0?l0oooo0?ooo`0I0?ooo`00M03oool00`000?l0oooo0?ooo`1=0?ooo`03
0000003oool0oooo04h0oooo00<0003o0?ooo`3oool06@3oool007@0oooo
00<0003o0?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000
o`3oool0oooo01X0oooo001e0?ooo`030000o`3oool0oooo04`0oooo00<0
00000?ooo`3oool0C@3oool00`000?l0oooo0?ooo`0J0?ooo`00M@3oool0
0`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo04d0oooo00<0003o
0?ooo`3oool06P3oool007D0oooo00<0003o0?ooo`3oool0C03oool00`00
0000oooo0?ooo`1=0?ooo`030000o`3oool0oooo01X0oooo001e0?ooo`03
0000o`3oool0oooo04`0oooo00<000000?ooo`3oool0C03oool00`000?l0
oooo0?ooo`0K0?ooo`00MP3oool00`000?l0oooo0?ooo`1;0?ooo`030000
003oool0oooo04`0oooo00<0003o0?ooo`3oool06`3oool007H0oooo00<0
003o0?ooo`3oool0A03oool500000080oooo00<000000?ooo`3oool0C03o
ool00`000?l0oooo0?ooo`0K0?ooo`00MP3oool00`000?l0oooo0?ooo`16
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C03oool0
0`000?l0oooo0?ooo`0K0?ooo`00MP3oool00`000?l0oooo0?ooo`160?oo
o`030000003oool0oooo0080oooo0`00001;0?ooo`030000o`3oool0oooo
01`0oooo001g0?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo01`0
oooo001g0?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1:0?ooo`030000o`3oool0oooo01d0oooo
001h0?ooo`030000o`3oool0oooo04<0oooo0P0000040?ooo`030000003o
ool0oooo04X0oooo00<0003o0?ooo`3oool07@3oool007T0oooo00<0003o
0?ooo`3oool0B03oool00`000000oooo0?ooo`190?ooo`030000o`3oool0
oooo01h0oooo001i0?ooo`030000o`3oool0oooo04P0oooo00<000000?oo
o`3oool0B@3oool00`000?l0oooo0?ooo`0N0?ooo`00N@3oool00`000?l0
oooo0?ooo`180?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3o
ool07P3oool007T0oooo00<0003o0?ooo`3oool0B03oool00`000000oooo
0?ooo`180?ooo`030000o`3oool0oooo01l0oooo001j0?ooo`030000o`3o
ool0oooo04L0oooo00<000000?ooo`3oool0B03oool00`000?l0oooo0?oo
o`0O0?ooo`00NP3oool00`000?l0oooo0?ooo`170?ooo`030000003oool0
oooo04L0oooo00<0003o0?ooo`3oool0803oool007/0oooo00<0003o0?oo
o`3oool0AP3oool00`000000oooo0?ooo`170?ooo`030000o`3oool0oooo
0200oooo001k0?ooo`030000o`3oool0oooo04H0oooo00<000000?ooo`3o
ool0AP3oool00`000?l0oooo0?ooo`0Q0?ooo`00O03oool00`000?l0oooo
0?ooo`150?ooo`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool0
8@3oool007`0oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?oo
o`150?ooo`030000o`3oool0oooo0280oooo001m0?ooo`030000o`3oool0
oooo04@0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`0R
0?ooo`00OP3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo
04@0oooo00<0003o0?ooo`3oool08`3oool007h0oooo00<0003o0?ooo`3o
ool0@`3oool00`000000oooo0?ooo`130?ooo`030000o`3oool0oooo02@0
oooo001o0?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0
@`3oool00`000?l0oooo0?ooo`0T0?ooo`00O`3oool00`000?l0oooo0?oo
o`120?ooo`030000003oool0oooo0480oooo00<0003o0?ooo`3oool09@3o
ool00800oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`12
0?ooo`030000o`3oool0oooo02D0oooo00210?ooo`030000o`3oool0oooo
0400oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo0?ooo`0V0?oo
o`00PP3oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo0400
oooo00<0003o0?ooo`3oool09`3oool008<0oooo00<0003o0?ooo`3oool0
?P3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0oooo02P0oooo
00230?ooo`030000o`3oool0oooo03h0oooo00<000000?ooo`3oool0?P3o
ool00`000?l0oooo0?ooo`0Y0?ooo`00Q03oool00`000?l0oooo0?ooo`0m
0?ooo`030000003oool0oooo03h0oooo00<0003o0?ooo`3oool0:@3oool0
08D0oooo00<0003o0?ooo`3oool0=@3oool4000000<0oooo00<000000?oo
o`3oool0?@3oool00`000?l0oooo0?ooo`0Z0?ooo`00QP3oool00`000?l0
oooo0?ooo`0d0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0?03oool00`000?l0oooo0?ooo`0[0?ooo`00Q`3oool00`000?l0oooo
0?ooo`0d0?ooo`030000003oool0oooo00<0oooo0`00000k0?ooo`030000
o`3oool0oooo02`0oooo00270?ooo`030000o`3oool0oooo03D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0j0?ooo`030000o`3o
ool0oooo02d0oooo00280?ooo`030000o`3oool0oooo0380oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0j0?ooo`030000o`3o
ool0oooo02d0oooo00290?ooo`80003o<`3oool2000000@0oooo00<00000
0?ooo`3oool0>03oool20000oc00oooo002;0?ooo`030000o`3oool0oooo
03H0oooo00<000000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0`0?oo
o`00S03oool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo03H0
oooo00<0003o0?ooo`3oool0<@3oool008d0oooo00<0003o0?ooo`3oool0
=03oool00`000000oooo0?ooo`0e0?ooo`030000o`3oool0oooo0380oooo
002>0?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool0=03o
ool00`000?l0oooo0?ooo`0c0?ooo`00SP3oool00`000?l0oooo0?ooo`0c
0?ooo`030000003oool0oooo03<0oooo00<0003o0?ooo`3oool0=03oool0
08l0oooo00<0003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?oo
o`030000o`3oool0oooo03@0oooo002@0?ooo`80003o<P3oool00`000000
oooo0?ooo`0a0?ooo`80003o=`3oool00980oooo0P000?l`0?ooo`030000
003oool0oooo02l0oooo0P000?li0?ooo`00U03oool00`000?l0oooo0?oo
o`0]0?ooo`030000003oool0oooo02h0oooo00<0003o0?ooo`3oool0>@3o
ool009D0oooo00<0003o0?ooo`3oool0;03oool00`000000oooo0?ooo`0]
0?ooo`030000o`3oool0oooo03X0oooo002F0?ooo`030000o`3oool0oooo
02/0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0k0?oo
o`00U`3oool20000ob/0oooo00<000000?ooo`3oool0:P3oool20000och0
oooo002I0?ooo`030000o`3oool0oooo02P0oooo00<000000?ooo`3oool0
:03oool20000od00oooo002J0?ooo`80003o:03oool00`000000oooo0?oo
o`0W0?ooo`030000o`3oool0oooo0400oooo002L0?ooo`80003o9P3oool0
0`000000oooo0?ooo`0U0?ooo`80003o@`3oool009h0oooo0P000?lT0?oo
o`030000003oool0oooo02<0oooo0P000?m50?ooo`00X03oool20000ob80
oooo00<000000?ooo`3oool08@3oool20000odL0oooo002R0?ooo`<0003o
7`3oool00`000000oooo0?ooo`0N0?ooo`<0003oB@3oool00:D0oooo0P00
0?lM0?ooo`030000003oool0oooo01`0oooo0P000?m<0?ooo`00Y`3oool2
0000oa/0oooo00<000000?ooo`3oool06P3oool20000odh0oooo002Y0?oo
o`@0003o5`3oool00`000000oooo0?ooo`0F0?ooo`@0003oD03oool00:d0
oooo10000?lC0?ooo`030000003oool0oooo0180oooo10000?mD0?ooo`00
/@3oool40000o`T0oooo0P0000040?ooo`030000003oool0oooo00h0oooo
10000?mH0?ooo`00]@3oool60000o`80oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`080?ooo`H0003oG03oool00;/0oooo5000
0?mR0?ooo`00`03oool01@000000oooo0?ooo`3oool0000006`0oooo002m
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0JP3o
ool00;h0oooo0P0000040?ooo`030000003oool0oooo06X0oooo003o0?oo
oc80oooo003o0?oooc80oooo003o0?oooc80oooo003o0?oooc80oooo003o
0?oooc80oooo003o0?oooc80oooo00320?ooo`800000K@3oool00<<0oooo
00<000000?ooo`3oool0J`3oool00<@0oooo00<000000?ooo`3oool0JP3o
ool00<<0oooo00<000000?ooo`000000J`3oool00<80oooo00@000000?oo
o`3oool00000J`3oool00<40oooo0`0000000`3oool000000000001Z0?oo
o`00o`3ooolb0?ooo`00o`3ooolb0?ooo`00o`3ooolb0?ooo`00o`3ooolb
0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{305, 195},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  We write the integrand as  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(\(\(\ \)\(1\)\)\/\(z\^4\  + \ z\^3\  - \ 2  z\^2\)\ \
 = \ \(\(\ \)\(1\)\)\/\(z\^2\ \((z + 2)\)\ \((z - 1)\)\)\)\)]],
  ".  \nThe singularities of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " that lie inside ",
  Cell[BoxData[
      \(\(C\_3\%+\) \((0)\)\)]],
  " are simple poles at the points ",
  Cell[BoxData[
      \(z = 1\)]],
  " and ",
  Cell[BoxData[
      \(z = \(-2\)\)]],
  ", and a pole of order ",
  StyleBox["2",
    FontFamily->"Courier New"],
  " at the origin.  We compute the residues as follows:  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, 
          0]\ \  = \ \ \(lim\+\(z\  \[Rule] 0\)\ \(d\/dz\) \((\(z\^2\) 
                  f \((z)\))\)\ \  = \ \ lim\+\(z\  \[Rule] 0\)\ \(d\/dz\) \
\((\(z\^2\) \(\(\ \)\(1\)\)\/\(z\^2\ \((z + 2)\)\ \((z - 1)\)\))\)\)\)\(\
\[IndentingNewLine]\)
      \)\ \ \), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] 0\)\ \(d\/dz\) \((\(\(\ \)\(1\)\)\/\(\((z + 2)\)\ \((z \
- 1)\)\))\)\ \  = \ \ lim\+\(z\  \[Rule] 0\)\ \(d\/dz\) \((1\/\(z\^2 + z - \
2\))\)\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(lim\+\(z\
\  \[Rule] 0\)\(\(-2\)\ z - 1\)\/\((z\^2 + z - 2)\)\^2\ \  = \ \ \
\(-\(1\/4\)\)\)\)\)}]],
  "    \n\t\t\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, 
          1]\ \  = \ \ \(lim\+\(z\  \[Rule] 1\)\ \((z - 1)\) 
              f \((z)\)\ \  = \ \ lim\+\(z\  \[Rule] 1\)\ \((z - 
                  1)\) \(\(\ \)\(1\)\)\/\(z\^2\ \((z + 2)\)\ \((z - \
1)\)\)\)\)\(\[IndentingNewLine]\)
      \)\ \ \), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(lim\+\(z\
\  \[Rule] 1\)\(\(\ \)\(1\)\)\/\(z\^2\ \((z + 2)\)\)\ \  = \ \ 1\/3\)\)\)}]],
  "  \n\t\t\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[
          f, \(-2\)]\ \  = \ \ \(lim\+\(z\  \[Rule] \(-2\)\)\ \((z - \
\((\(-2\))\))\) 
              f \((z)\)\ \  = \ \ lim\+\(z\  \[Rule] \(-2\)\)\ \((z + 
                  2)\) \(\(\ \)\(1\)\)\/\(z\^2\ \((z + 2)\)\ \((z - \
1)\)\)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] \(-2\)\)\ \(\(\ \)\(1\)\)\/\(z\^2\ \((z - 1)\)\)\ \  = \
\ \ \(-\(1\/12\)\)\)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "Finally, the residue theorem yields \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_\(\(C\_3\%+\) \((0)\)\)\(\(\(\ \)\(1\)\)\/\(z\^4\  + \
\ z\^3\  - \ 2 
                     z\^2\)\) \[DifferentialD]z\ \  = \ \ 2  \[Pi]\ \
\[ImaginaryI]\ \((Res[f, 0]\  + \ Res[f, 1]\  + \ 
              Res[f, \(-2\)])\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(\(\(=\)\(\ \ \)\(2  \[Pi]\ \[ImaginaryI]\ \((\(-\(1\/4\)\)\  + \ 
              1\/3\  - \ 1\/12)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(\(=\)\(\ \ \)\(0\)\)\)}]],
  "\n\nThe answer,  ",
  Cell[BoxData[
      \(\[Integral]\_\(\(C\_3\%+\) \((0)\)\)\(\(\(\ \)\(1\)\)\/\(z\^4\  + \ 
                  z\^3\  - \ 2  z\^2\)\) \[DifferentialD]z\ \  = \ \ 0\)]],
  ",  is not at all obvious, and all the preceding calculations are required \
to get it."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \(\(\ \)\(1\)\)\/\(z\^4\  + \ z\^3\  - \ 2  z\^2\)\)],
    AspectRatioFixed->True],
  "  and ",
  "locate the",
  " singularities.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Z = \(z = 0\); \ Remove[z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, Res1, Res2, Res3, Res4];\)\ \), "\n", 
    \(\(f[
          z_]\  = \(\(\ \)\(1\)\)\/\(z\^4\  + \ z\^3\  - \ 2  z\^2\);\)\ \), \
"\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[Denominator[f[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, 
            z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The singularities are\>"];\)\ \), "\n", 
    \(\(Z\_1\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2];\)\ \), "\n", 
    \(\(Z\_3\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3];\)\ \), "\n", 
    \(\(Z\_4\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(4\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", 
        Z\_4];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Find out which singularities lie within a circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_2], Im[Z\_2]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_3], Im[Z\_3]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_4], Im[Z\_4]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] + 0.2}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] + 0.2}, {1, 0}], 
            Text[\*"\"\<\!\(z\_3\)\>\"", {Re[Z\_3], Im[Z\_3] + 0.2}, {\(-1\), 
                0}], Text[\*"\"\<\!\(z\_4\)\>\"", {Re[Z\_4], 
                Im[Z\_4] + 0.2}, {\(-1\), 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 3]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-3.1\), 3.1}, {\(-3.1\), 3.1}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], 
            Range[\(-3\), 3, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<, Is |\>", 
        Z\_1, "\<| < 3 ?  \>", N[Abs[Z\_1]] < 3];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<,  Is |\>", 
        Z\_2, "\<| < 3 ?   \>", N[Abs[Z\_2]] < 3];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3, "\<,  Is |\>", 
        Z\_3, "\<| < 3 ?   \>", N[Abs[Z\_3]] < 3];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", Z\_4, "\<,  Is |\>", 
        Z\_4, "\<| < 3 ?   \>", 
        N[Abs[Z\_4]] < 3];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Compute the residues at  ",
  Cell[BoxData[
      \(z\_1, z\_2, \ and\ \ z\_4\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Res1\  = \ Residue[f[z], {z, Z\_1}];\)\ \), "\n", 
    \(\(Res2\  = \ Residue[f[z], {z, Z\_2}];\)\ \), "\n", 
    \(\(Res4\  = \ Residue[f[z], {z, Z\_4}];\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_1, "\<] = \>", Res1];\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_2, "\<] = \>", Res2];\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_4, "\<] = \>", 
        Res4];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["The integral is computed by the residue calculus.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(val\  = 
        2\ \[Pi]\ \[ImaginaryI]\ \((Res1\  + \ Res2\  + \ 
              Res4)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", Z\_1, "\<] = \>", Res1];\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_2, "\<] = \>", Res2];\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_4, "\<] = \>", 
        Res4];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_2], Im[Z\_2]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_4], Im[Z\_4]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] + 0.2}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] + 0.2}, {\(-1\), 
                0}], Text[\*"\"\<\!\(z\_4\)\>\"", {Re[Z\_4], 
                Im[Z\_4] + 0.2}, {\(-1\), 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 3]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-3.1\), 3.1}, {\(-3.1\), 3.1}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], 
            Range[\(-3\), 3, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) \>\"", 
        f[z], "\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI]((\>", 
        Res1\ , "\<) + (\>", \ Res2\ , "\<) + (\>", \ 
        Res4, "\<))\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) \>\"", 
        f[z], "\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>", 
        Res1\  + \ Res2\  + \ Res4, "\<) = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The contour is the circle  C:|z| = 3,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<with positive orientation.\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find  ",
  Cell[BoxData[
      \(\[Integral]\_\(\(C\_2\%+\) \((1)\)\)\(1\/\(z\^4\  + \ 
                4\)\) \[DifferentialD]z\)]],
  "  where ",
  Cell[BoxData[
      \(\(C\_2\%+\) \((1)\)\)]],
  " denotes the circle ",
  Cell[BoxData[
      \(\(C\_2\%+\) \((1)\) = {z : \ \(\(|\)\(z - 1\)\(|\)\) = 2}\)]],
  " with positive orientation.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004a0000WB000`400?l0
0000o`00003oo`3ooolb0?ooo`00o`3ooolb0?ooo`00o`3ooolb0?ooo`00
o`3ooolb0?ooo`00o`3ooolb0?ooo`00o`3ooolb0?ooo`00o`3ooolb0?oo
o`00]03oool00`000000oooo0?ooo`1j0?ooo`00[@3oool4000000<0oooo
00<000000?ooo`3oool0NP3oool00:d0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1j0?ooo`00[P3oool00`000000oooo0?ooo`03
0?ooo`800000603oool>0000oeD0oooo002W0?ooo`@00000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo1P000?l>0?oo
o`H0003oC`3oool00:d0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`0<0?ooo`D0003o6P3oool50000odX0oooo002^0?ooo`80
0000103oool00`000000oooo0?ooo`080?ooo`@0003o903oool40000odH0
oooo002d0?ooo`030000003oool0oooo00H0oooo0P000?l/0?ooo`80003o
A03oool00;@0oooo00<000000?ooo`3oool0103oool20000oc00oooo0P00
0?m20?ooo`00]03oool00`000000oooo0?ooo`020?ooo`80003o=03oool0
0`000?l0oooo0?ooo`0o0?ooo`00]03oool00`000000oooo0?ooo`020000
ocL0oooo0P000?lo0?ooo`00]03oool00`000000003o0000o`0k0?ooo`80
003o?@3oool00;@0oooo00<0003o0?ooo`3oool0?@3oool20000oc/0oooo
002b0?ooo`80003o00<000000?ooo`3oool0?`3oool20000ocT0oooo002`
0?ooo`80003o0P3oool00`000000oooo0?ooo`110?ooo`80003o=`3oool0
0:l0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`130?oo
o`030000o`3oool0oooo03@0oooo002]0?ooo`80003o1@3oool00`000000
oooo0?ooo`140?ooo`030000o`3oool0oooo03<0oooo002/0?ooo`030000
o`3oool0oooo00D0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo
0?ooo`0b0?ooo`00Z`3oool00`000?l0oooo0?ooo`060?ooo`030000003o
ool0oooo04H0oooo0P000?lb0?ooo`00ZP3oool00`000?l0oooo0?ooo`07
0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool0;`3oool0
0:T0oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`190?oo
o`030000o`3oool0oooo02h0oooo002X0?ooo`030000o`3oool0oooo00T0
oooo00<000000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`0]0?ooo`00
YP3oool20000o``0oooo00<000000?ooo`3oool0B`3oool00`000?l0oooo
0?ooo`0/0?ooo`00Y@3oool00`000?l0oooo0?ooo`0<0?ooo`030000003o
ool0oooo04`0oooo00<0003o0?ooo`3oool0:`3oool00:@0oooo00<0003o
0?ooo`3oool03@3oool00`000000oooo0?ooo`1=0?ooo`030000o`3oool0
oooo02X0oooo002T0?ooo`030000o`3oool0oooo00d0oooo00<000000?oo
o`3oool0C@3oool00`000?l0oooo0?ooo`0Z0?ooo`00X`3oool00`000?l0
oooo0?ooo`0>0?ooo`030000003oool0oooo04h0oooo00<0003o0?ooo`3o
ool0:@3oool00:80oooo00<0003o0?ooo`3oool03`3oool00`000000oooo
0?ooo`1?0?ooo`030000o`3oool0oooo02P0oooo002Q0?ooo`030000o`3o
ool0oooo0100oooo00<000000?ooo`3oool0D03oool00`000?l0oooo0?oo
o`0W0?ooo`00X03oool00`000?l0oooo0?ooo`0A0?ooo`030000003oool0
oooo0540oooo00<0003o0?ooo`3oool09P3oool00:00oooo00<0003o0?oo
o`3oool04@3oool00`000000oooo0?ooo`1A0?ooo`030000o`3oool0oooo
02H0oooo002O0?ooo`030000o`3oool0oooo0180oooo00<000000?ooo`3o
ool0DP3oool00`000?l0oooo0?ooo`0U0?ooo`00WP3oool00`000?l0oooo
0?ooo`0C0?ooo`030000003oool0oooo05<0oooo00<0003o0?ooo`3oool0
903oool009h0oooo00<0003o0?ooo`3oool0303oool500000080oooo00<0
00000?ooo`3oool0E03oool00`000?l0oooo0?ooo`0S0?ooo`00T`3oool2
0?l000P0oooo00<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01`0oooo0P3o000f0?ooo`030000o`3oool0
oooo02<0oooo002B0?ooo`@0o`001`3oool00`000?l0oooo0?ooo`0?0?oo
o`030000003oool0oooo0080oooo0P00000L0?ooo`@0o`00=P3oool00`00
0?l0oooo0?ooo`0R0?ooo`00TP3oool40?l000H0oooo00<0003o0?ooo`3o
ool0203oool4000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0K0?ooo`@0o`00=P3oool00`000?l0oooo0?ooo`0R0?ooo`00
T`3oool20?l000L0oooo00<0003o0?ooo`3oool0403oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01`0oooo0P3o000h0?ooo`030000
o`3oool0oooo0240oooo002=0?ooo`D000002@3oool00`000?l0oooo0?oo
o`0@0?ooo`800000103oool00`000000oooo0?ooo`0W0?ooo`800000;@3o
ool00`000?l0oooo0?ooo`0Q0?ooo`00Q`3oool5000000<0oooo00<00000
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0
oooo0200oooo1@0000040?ooo`030000003oool0oooo02/0oooo00<0003o
0?ooo`3oool0803oool008P0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`080?ooo`030000o`3oool0oooo01L0oooo00<00000
0?ooo`3oool08@3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo02`0oooo00<0003o0?ooo`3oool0803oool008T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000o`3oool0
oooo01L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02`0oooo00<0003o0?ooo`3oool07`3oool0
08X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?oo
o`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool08`3oool01`00
0000oooo0?ooo`3oool000000?ooo`000000;P3oool00`000?l0oooo0?oo
o`0O0?ooo`00R03oool010000000oooo0?ooo`0000020?ooo`8000002@3o
ool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo0240oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0]0?ooo`030000
o`3oool0oooo01l0oooo00280?ooo`D000002`3oool00`000?l0oooo0?oo
o`0I0?ooo`030000003oool0oooo0240oooo1@00000c0?ooo`030000o`3o
ool0oooo01h0oooo002H0?ooo`030000o`3oool0oooo01T0oooo00<00000
0?ooo`3oool0F@3oool00`000?l0oooo0?ooo`0N0?ooo`00V03oool00`00
0?l0oooo0?ooo`0I0?ooo`030000003oool0oooo05T0oooo00<0003o0?oo
o`3oool07P3oool009L0oooo00<0003o0?ooo`3oool06P3oool00`000000
oooo0?ooo`1J0?ooo`030000o`3oool0oooo01d0oooo002G0?ooo`030000
o`3oool0oooo01X0oooo00<000000?ooo`3oool0FP3oool00`000?l0oooo
0?ooo`0M0?ooo`00U`3oool00`000?l0oooo0?ooo`0J0?ooo`030000003o
ool0oooo05X0oooo00<0003o0?ooo`3oool07@3oool009H0oooo00<0003o
0?ooo`3oool06`3oool00`000000oooo0?ooo`1K0?ooo`030000o`3oool0
oooo01`0oooo002F0?ooo`030000o`3oool0oooo01/0oooo00<000000?oo
o`3oool0F`3oool00`000?l0oooo0?ooo`0L0?ooo`00UP3oool00`000?l0
oooo0?ooo`0K0?ooo`030000003oool0oooo05`0oooo00<0003o0?ooo`3o
ool06`3oool009H0oooo00<0003o0?ooo`3oool06`3oool00`000000oooo
0?ooo`1L0?ooo`030000o`3oool0oooo01/0oooo002F0?ooo`030000o`3o
ool0oooo01/0oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?oo
o`0K0?ooo`00U@3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0
oooo05`0oooo00<0003o0?ooo`3oool06`3oool007D0oooo1000000L0?oo
o`030000o`0000000000008000006P3oool00`000000oooo0?ooo`0K0?oo
o`D000006`3oool4000001d0oooo00<0003o0000003oool06`3oool007D0
oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0000000L0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0M0?ooo`04000000000?l0oooo000001/0oooo001f0?ooo`03
0000003oool0oooo01`0oooo00<0003o0?ooo`000000703oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool07P3oool00`000?l0oooo0?ooo`0J0?ooo`00K`3oool4000000@0oooo
00<000000?ooo`3oool05@3oool400000080oooo00<0003o0?ooo`000000
703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool07@3oool00`000?l000000?ooo`0J0?ooo`00M@3o
ool010000000oooo0?ooo`00000L0?ooo`030000o`3oool0000001`0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`040000
003oool0oooo000001`0oooo00@000000?ooo`000?l000006`3oool007H0
oooo0P00000M0?ooo`030000o`000000000001`0oooo00<000000?ooo`3o
ool0703oool2000001h0oooo0P00000N0?ooo`03000000000?l0oooo01/0
oooo002E0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0
G@3oool00`000?l0oooo0?ooo`0J0?ooo`00U03oool00`000?l0oooo0?oo
o`0M0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool06P3o
ool009@0oooo00<0003o0?ooo`3oool07@3oool00`000000oooo0?ooo`1M
0?ooo`030000o`3oool0oooo01X0oooo002D0?ooo`030000o`3oool0oooo
01d0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`060?oo
o`80000000<0oooo0000000000003`3oool00740oooo8`0000000`000?l0
00000000001m000000040000o`0000000000000000H0oooo00<000000?oo
o`000000403oool007@0oooo00<000000?ooo`3oool07@3oool00`000?l0
oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00P0
oooo00<000000?ooo`3oool03`3oool009@0oooo00<0003o0?ooo`3oool0
7@3oool00`000000oooo0?ooo`1M0?ooo`030000o`3oool0oooo00H0oooo
0P0000000`3oool000000000000?0?ooo`00U03oool00`000?l0oooo0?oo
o`0M0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool06P3o
ool009@0oooo00<0003o0?ooo`3oool07@3oool00`000000oooo0?ooo`1M
0?ooo`030000o`3oool0oooo01X0oooo002E0?ooo`030000o`3oool0oooo
01`0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0J0?oo
o`00U@3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo05d0
oooo00<0003o0?ooo`3oool06P3oool009D0oooo00<0003o0?ooo`3oool0
703oool00`000000oooo0?ooo`1M0?ooo`030000o`3oool0oooo01X0oooo
002E0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0G@3o
ool00`000?l0oooo0?ooo`0J0?ooo`00U@3oool00`000?l0oooo0?ooo`0L
0?ooo`030000003oool0oooo05`0oooo00<0003o0?ooo`3oool06`3oool0
09D0oooo00<0003o0?ooo`3oool0703oool00`000000oooo0?ooo`1L0?oo
o`030000o`3oool0oooo01/0oooo002E0?ooo`030000o`3oool0oooo01`0
oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?ooo`0K0?ooo`00
U@3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo05`0oooo
00<0003o0?ooo`3oool06`3oool009H0oooo00<0003o0?ooo`3oool06`3o
ool00`000000oooo0?ooo`1L0?ooo`030000o`3oool0oooo01/0oooo002F
0?ooo`030000o`3oool0oooo01/0oooo00<000000?ooo`3oool0G03oool0
0`000?l0oooo0?ooo`0K0?ooo`00UP3oool00`000?l0oooo0?ooo`0K0?oo
o`030000003oool0oooo05/0oooo00<0003o0?ooo`3oool0703oool009H0
oooo00<0003o0?ooo`3oool06`3oool00`000000oooo0?ooo`1K0?ooo`03
0000o`3oool0oooo01`0oooo002F0?ooo`030000o`3oool0oooo01/0oooo
00<000000?ooo`3oool0F`3oool00`000?l0oooo0?ooo`0L0?ooo`00U`3o
ool00`000?l0oooo0?ooo`0J0?ooo`030000003oool0oooo05X0oooo00<0
003o0?ooo`3oool07@3oool009L0oooo00<0003o0?ooo`3oool06P3oool0
0`000000oooo0?ooo`1J0?ooo`030000o`3oool0oooo01d0oooo002G0?oo
o`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0FP3oool00`00
0?l0oooo0?ooo`0M0?ooo`00V03oool00`000?l0oooo0?ooo`0I0?ooo`03
0000003oool0oooo05T0oooo00<0003o0?ooo`3oool07P3oool009P0oooo
00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`1I0?ooo`030000
o`3oool0oooo01h0oooo002H0?ooo`030000o`3oool0oooo01T0oooo00<0
00000?ooo`3oool0F@3oool00`000?l0oooo0?ooo`0N0?ooo`00V@3oool0
0`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo05P0oooo00<0003o
0?ooo`3oool07`3oool009T0oooo00<0003o0?ooo`3oool0603oool00`00
0000oooo0?ooo`1H0?ooo`030000o`3oool0oooo01l0oooo002J0?ooo`03
0000o`3oool0oooo01L0oooo00<000000?ooo`3oool0F03oool00`000?l0
oooo0?ooo`0O0?ooo`00VP3oool00`000?l0oooo0?ooo`0G0?ooo`030000
003oool0oooo05L0oooo00<0003o0?ooo`3oool0803oool009/0oooo00<0
003o0?ooo`3oool05P3oool00`000000oooo0?ooo`1G0?ooo`030000o`3o
ool0oooo0200oooo002K0?ooo`030000o`3oool0oooo01H0oooo00<00000
0?ooo`3oool0EP3oool00`000?l0oooo0?ooo`0Q0?ooo`00W03oool00`00
0?l0oooo0?ooo`0>0?ooo`D000000P3oool00`000000oooo0?ooo`1F0?oo
o`030000o`3oool0oooo0240oooo002C0?ooo`80o`001`3oool00`000?l0
oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0703oool20?l003L0oooo00<0003o0?ooo`3oool08P3oool00980oooo
103o00070?ooo`030000o`3oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool2000001`0oooo103o000e0?ooo`030000o`3oool0oooo02<0oooo
002B0?ooo`@0o`00203oool00`000?l0oooo0?ooo`0>0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool06`3oool40?l003D0oooo00<0
003o0?ooo`3oool08`3oool009<0oooo0P3o00090?ooo`030000o`3oool0
oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L
0?ooo`80o`00=@3oool00`000?l0oooo0?ooo`0T0?ooo`00SP3oool30000
00h0oooo00<0003o0?ooo`3oool0303oool2000000@0oooo00<000000?oo
o`3oool0:03oool3000002P0oooo00<0003o0?ooo`3oool0903oool008h0
oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0B0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool09P3oool00`000?l0
oooo0?ooo`0U0?ooo`00Q`3oool5000000<0oooo00<000000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`0A0?ooo`030000003oool0oooo0200oooo
1@0000020?ooo`@000009P3oool00`000?l0oooo0?ooo`0V0?ooo`00R03o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00h0oooo
00<0003o0?ooo`3oool04@3oool00`000000oooo0?ooo`0Q0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`0000009`3oool00`000?l0
oooo0?ooo`0V0?ooo`00R@3oool00`000000oooo0?ooo`020?ooo`030000
003oool000000100oooo00<0003o0?ooo`3oool0403oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000
o`3oool0oooo02L0oooo002:0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0S0?ooo`030000o`3oool0oooo02P0oooo00280?ooo`040000003oool0
oooo000001L0oooo00<0003o0?ooo`3oool03P3oool00`000000oooo0?oo
o`0Q0?ooo`040000003oool0oooo000002T0oooo00<0003o0?ooo`3oool0
:@3oool008P0oooo1@00000G0?ooo`030000o`3oool0oooo00d0oooo00<0
00000?ooo`3oool08@3oool5000002L0oooo00<0003o0?ooo`3oool0:P3o
ool00:D0oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`1<
0?ooo`030000o`3oool0oooo02/0oooo002V0?ooo`030000o`3oool0oooo
00/0oooo00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0/0?oo
o`00Y`3oool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo04/0
oooo00<0003o0?ooo`3oool0;03oool00:P0oooo00<0003o0?ooo`3oool0
2@3oool00`000000oooo0?ooo`1:0?ooo`030000o`3oool0oooo02d0oooo
002Y0?ooo`030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0B@3o
ool00`000?l0oooo0?ooo`0^0?ooo`00ZP3oool00`000?l0oooo0?ooo`07
0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool0;`3oool0
0:/0oooo00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`160?oo
o`80003o<P3oool00:`0oooo00<0003o0?ooo`3oool01@3oool00`000000
oooo0?ooo`150?ooo`030000o`3oool0oooo0380oooo002]0?ooo`80003o
1@3oool00`000000oooo0?ooo`140?ooo`030000o`3oool0oooo03<0oooo
002_0?ooo`80003o0`3oool00`000000oooo0?ooo`120?ooo`80003o=P3o
ool00;40oooo0P000?l00`3oool000000?ooo`110?ooo`80003o>03oool0
0;<0oooo00<0003o0000003oool0?`3oool20000ocX0oooo002d0?ooo`03
0000o`3oool0oooo03d0oooo00<0003o0?ooo`3oool0>P3oool00;@0oooo
00<000000000o`000?l0>`3oool20000ocd0oooo002d0?ooo`030000003o
ool0oooo0080003o>03oool00`000?l0oooo0?ooo`0m0?ooo`00]03oool0
0`000000oooo0?ooo`020?ooo`<0003o<P3oool30000od00oooo002d0?oo
o`030000003oool0oooo00D0oooo0`000?l/0?ooo`<0003o@`3oool00;@0
oooo00<000000?ooo`3oool0203oool20000obL0oooo0`000?m60?ooo`00
]03oool00`000000oooo0?ooo`0:0?ooo`<0003o8P3oool20000odT0oooo
002]0?ooo`@000000`3oool00`000000oooo0?ooo`0=0?ooo`D0003o603o
ool50000od/0oooo002]0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool04P3oool70000o`T0oooo20000?m@0?ooo`00[P3oool00`00
0000oooo0?ooo`030?ooo`8000006P3oool90000oeP0oooo002_0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0NP3oool00:d0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`1j0?ooo`00
[P3oool2000000@0oooo00<000000?ooo`3oool0NP3oool00?l0oooo<P3o
ool00?l0oooo<P3oool00?l0oooo<P3oool00?l0oooo<P3oool00?l0oooo
<P3oool00?l0oooo<P3oool00;80oooo0P00001m0?ooo`00/`3oool00`00
0000oooo0?ooo`1k0?ooo`00]03oool00`000000oooo0?ooo`1j0?ooo`00
/`3oool00`000000oooo0000001k0?ooo`00/P3oool010000000oooo0?oo
o`00001k0?ooo`00/@3oool3000000030?ooo`000000000007X0oooo003o
0?oooc80oooo003o0?oooc80oooo003o0?oooc80oooo003o0?oooc80oooo
0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{305, 157},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The singularities of the integrand  ",
  Cell[BoxData[
      \(f \((z)\) = 1\/\(z\^4\  + \ 4\)\)]],
  "  that lie inside ",
  Cell[BoxData[
      \(\(C\_2\%+\) \((1)\)\)]],
  " are simple poles occurring at the points  ",
  Cell[BoxData[
      \(z = 1 \[PlusMinus] \[ImaginaryI]\)]],
  ",  as the points  ",
  Cell[BoxData[
      \(z = \(-1\) \[PlusMinus] \[ImaginaryI]\)]],
  ",  lie outside ",
  Cell[BoxData[
      \(\(C\_2\%+\) \((1)\)\)]],
  ".  Factoring the denominator is tedious, so we use a different approach.  \
If ",
  Cell[BoxData[
      \(z\_0\)]],
  " is any one of the singularities of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " , then we can use L'H\[OHat]pital's rule to compute ",
  Cell[BoxData[
      \(Res[f, z\_0]\)]],
  ": \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, 
          z\_0]\ \  = \ \ \(lim\+\(z\  \[Rule] \ z\_0\)\ \((z - z\_0)\) 
              f \((z)\)\ \  = \ \ lim\+\(z\  \[Rule] \ z\_0\)\ \((z - z\_0)\) 
              1\/\(z\^4\  + \ 4\)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] \ z\_0\)\ \((z - z\_0)\)\/\(z\^4\  + \ 4\)\ \  = \(\('\
\) \(\(0\/0\)'\)\)\)\)\(\ \ \ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] \ z\_0\)\ 
            1\/\(4  z\^3\)\ \  = \ \ 1\/\(4  z\_0\%3\)\)\)\)}]],
  "\n"
}], "Text"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(z\_0\%4\  = \ \(-4\)\)]],
  ",  we can simplify this expression further to yield \n\n\t\t\t",
  Cell[BoxData[
      \(Res[f, 
          z\_0]\ \  = \ \ \(1\/\(4  z\_0\%3\)\ \  = \ \ \(z\_0\/\(4  \
z\_0\%4\)\ \  = \ \ \(z\_0\/\(4 \((\(-4\))\)\)\ \  = \ \ \(-\(1\/16\)\) 
                z\_0\)\)\)\)]],
  "\n\nWe now use the residue theorem to get  \n\n\t\t\t",
  Cell[BoxData[{
      \(\[Integral]\_\(\(C\_2\%+\) \((1)\)\)\(1\/\(z\^4\  + \ 
                  4\)\) \[DifferentialD]z\ \  = \ \ 2  \[Pi]\ \[ImaginaryI]\ \
\((Res[f, 1 + \[ImaginaryI]]\  + \ 
              Res[f, 1 - \[ImaginaryI]])\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\
\ \ \)\(2  \[Pi]\ \[ImaginaryI]\ \((\(-\(\(1 + \[ImaginaryI]\)\/16\)\)\  - \
\(1 - \[ImaginaryI]\)\/16)\)\ \  = \ \ 2  \[Pi]\ \[ImaginaryI]\ \((\(\(-1\) - \
\[ImaginaryI]\)\/16\  + \(\(-1\) + \[ImaginaryI]\)\/16)\)\)\)\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\
\ \ \)\(2  \[Pi]\ \[ImaginaryI]\ \((\(-\(1\/8\)\))\)\)\)\[IndentingNewLine]\),
     "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\
\ \ \)\(-\(\(\[ImaginaryI]\ \[Pi]\)\/4\)\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = 1\/\(z\^4\  + \ 4\)\)],
    AspectRatioFixed->True],
  "  and ",
  "locate the",
  " singularities.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Z = \(z = 0\); \ Remove[z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, Res1, Res2, Res3, Res4];\)\ \), "\n", 
    \(\(f[z_]\  = 1\/\(z\^4\  + \ 4\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[Denominator[f[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, 
            z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The singularities are\>"];\)\ \), "\n", 
    \(\(Z\_1\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2];\)\ \), "\n", 
    \(\(Z\_3\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3];\)\ \), "\n", 
    \(\(Z\_4\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(4\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", 
        Z\_4];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Find out which singularities lie within a circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z - 1\)\(|\)\) = 2. \)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_2], Im[Z\_2]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_3], Im[Z\_3]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_4], Im[Z\_4]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] + 0.2}, {1, 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] + 0.2}, {1, 0}], 
            Text[\*"\"\<\!\(z\_3\)\>\"", {Re[Z\_3], Im[Z\_3] + 0.2}, {\(-1\), 
                0}], Text[\*"\"\<\!\(z\_4\)\>\"", {Re[Z\_4], 
                Im[Z\_4] + 0.2}, {\(-1\), 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{1, 0}, 2]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-2.1\), 3.1}, {\(-2.1\), 2.1}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], 
            Range[\(-3\), 3, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 
          4\/5, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<, Is |\>", 
        Z\_1, "\< - 1| < 2 ?  \>", N[Abs[Z\_1 - 1]] < 2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<, Is |\>", 
        Z\_2, "\< - 1| < 2 ?  \>", N[Abs[Z\_2 - 1]] < 2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3, "\<,  Is |\>", 
        Z\_3, "\< - 1| < 2 ?   \>", N[Abs[Z\_3 - 1]] < 2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", Z\_4, "\<,  Is |\>", 
        Z\_4, "\< - 1| < 2 ?   \>", 
        N[Abs[Z\_4 - 1]] < 2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Compute the residues at  ",
  Cell[BoxData[
      \(z\_3, \ and\ \ z\_4\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Res3\  = \ Residue[f[z], {z, Z\_3}];\)\ \), "\n", 
    \(\(Res4\  = \ Residue[f[z], {z, Z\_4}];\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_3, "\<] = \>", Res3];\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_4, "\<] = \>", 
        Res4];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["The integral is computed by the residue calculus.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(val\  = 
        2\ \[Pi]\ \[ImaginaryI]\ \((\ 
            Res3\  + \ Res4)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", Z\_3, "\<] = \>", Res3];\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_4, "\<] = \>", 
        Res4];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_3], Im[Z\_3]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_4], Im[Z\_4]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_3\)\>\"", {Re[Z\_3], 
                Im[Z\_3] + 0.2}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_4\)\>\"", {Re[Z\_4], Im[Z\_4] + 0.2}, {\(-1\), 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{1, 0}, 2]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-2.1\), 3.1}, {\(-2.1\), 2.1}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], 
            Range[\(-3\), 3, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 
          4\/5, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) \>\"", 
        f[z], "\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI]((\>", \ 
        Res3\ , "\<) + (\>", \ 
        Res4, "\<))\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) \>\"", 
        f[z], "\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>", 
        Res3\  + \ Res4, "\<) = \>", val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The contour is the circle  C:|z-1| = 2,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<with positive orientation.\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\t",
  StyleBox["The theory of residues can be used to expand the quotient of two \
polynomials into its partial fraction representation.",
    FontFamily->"Times New Roman",
    FontSize->12]
}], "SmallText"],

Cell[TextData[{
  StyleBox["Example 8.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let ",
  StyleBox["P(z)",
    FontFamily->"Courier New"],
  " be a polynomial of degree at most ",
  StyleBox["2",
    FontFamily->"Courier New"],
  ".  If ",
  StyleBox["a",
    FontFamily->"Courier New"],
  " , ",
  StyleBox["b",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["c",
    FontFamily->"Courier New"],
  " are distinct complex numbers, then  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ \(\(P \((z)\)\)\/\(\((z\  - \ a)\) \((z\  - \ \
b)\) \((z\  - \ c)\)\)\ \  = \ \ \[DoubleStruckCapitalA]\/\(z\  - \ a\)\  + \ \
\[DoubleStruckCapitalB]\/\(z\  - \ b\)\  + \ \[DoubleStruckCapitalC]\/\(z\  - \
\ c\)\)\)]],
  ",  \nwhere\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(\[DoubleStruckCapitalA]\  = \ \(Res[f, 
                a]\  = \ \(P \((a)\)\)\/\(\((a\  - \ b)\) \((a\  - \ c)\)\)\)\
\), 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", \(\[DoubleStruckCapitalB]\  = \ \(Res[f, 
                b]\  = \ \(P \((b)\)\)\/\(\((b\  - \ a)\) \((b\  - \ c)\)\)\)\
\), 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"\[DoubleStruckCapitalC]", " ", "=", " ", 
        RowBox[{\(Res[f, c]\), " ", "=", " ", 
          RowBox[{\(\(P \((c)\)\)\/\(\((c\  - \ a)\) \((c\  - \ b)\)\)\), 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Solution.  It will suffice to prove that  ",
  Cell[BoxData[
      \(A\  = \ Res[f, a]\)]],
  ".  We expand ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " in its Laurent series about the point ",
  Cell[BoxData[
      \(z = a\)]],
  " by writing the three terms ",
  Cell[BoxData[
      \(A\/\(z\  - \ a\)\)]],
  ", ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalB]\/\(z\  - \ b\)\)]],
  ", and ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalC]\/\(z\  - \ c\)\)]],
  " in their Laurent series about the point ",
  Cell[BoxData[
      \(z = a\)]],
  " and adding them.  The term ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalA]\/\(z\  - \ a\)\)]],
  " is itself a one-term Laurent series about the point ",
  Cell[BoxData[
      \(z = a\)]],
  ".  The term ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalB]\/\(z\  - \ b\)\)]],
  " is analytic at the point ",
  Cell[BoxData[
      \(z = a\)]],
  ", and its Laurent series is actually a Taylor series given by  \n\n\t\t\t\
",
  Cell[BoxData[{
      \(\(\(\[DoubleStruckCapitalB]\/\(z - b\)\ \  = \ \ \((\(-\
\[DoubleStruckCapitalB]\)\/\(b - a\))\) \((1\/\(1 - \(z - a\)\/\(b - a\)\))\)\
\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \ \
\)\(\((\(-\[DoubleStruckCapitalB]\)\/\(b - a\))\) \(\[Sum]\+\(n = 0\)\%\
\[Infinity]\((\(z - a\)\/\(b - a\))\)\^n\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\((\(-\[DoubleStruckCapitalB]\)\/\(b - a\))\) \(\[Sum]\+\(n = 0\)\%\
\[Infinity]\((z - a)\)\^n\/\((b - a)\)\^n\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(-\ \(\[Sum]\+\(n = \
0\)\%\[Infinity]\( \[DoubleStruckCapitalB] \((z - a)\)\^n\)\/\((b - a)\)\^\(n \
+ 1\)\)\)\)\)}]],
  "  \n\nwhich is valid for  ",
  Cell[BoxData[
      \(\(\(|\)\(z - a\)\(|\)\(\(<\)\(\(|\)\(b - a\)\(|\)\)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Likewise, the Laurent expansion of the term ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalC]\/\(z\  - \ c\)\)]],
  " is  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(\[DoubleStruckCapitalC]\/\(z\  - \ c\)\)\(\ \ \)\(=\)\)\)]],
  Cell[BoxData[
      \(\(\(\ \ \)\(-\ \(\[Sum]\+\(n = 0\)\%\[Infinity]\( \
\[DoubleStruckCapitalC] \((z - a)\)\^n\)\/\((c - a)\)\^\(n + 1\)\)\)\)\)]],
  ",  \n\t\t\nwhich is valid for  ",
  Cell[BoxData[
      \(\(\(|\)\(z - a\)\(|\)\(\(<\)\(\(|\)\(c - a\)\(|\)\)\)\)\)]],
  ".  Thus the Laurent series of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " about the point ",
  Cell[BoxData[
      \(z = a\)]],
  " is  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ \[DoubleStruckCapitalA]\/\(z\  - \ a\)\  - \ \ \
\[Sum]\+\(n = 0\)\%\[Infinity]\( \[DoubleStruckCapitalB] \((z - \
a)\)\^n\)\/\((b - a)\)\^\(n + 1\)\  - \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\( \
\[DoubleStruckCapitalC] \((z - a)\)\^n\)\/\((c - a)\)\^\(n + 1\)\)]],
  ", \n\nwhich is valid for  ",
  Cell[BoxData[
      \(\(\(|\)\(z - a\)\(|\)\(\(<\)\(\ \)\(R\)\)\)\)]],
  ", where  ",
  Cell[BoxData[
      \(R = min {\(\(|\)\(b - a\)\(|\)\), \(\(|\)\(c - a\)\(|\)\)}\)]],
  ".  Therefore  ",
  Cell[BoxData[
      \(Res[f, a]\  = \ \[DoubleStruckCapitalA]\)]],
  ",  and calculation reveals that \n\n\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, 
          a]\ \  = \ \ \(lim\+\(z\  \[Rule] a\)\ \((z - a)\) 
              f \((z)\)\  = \ \ lim\+\(z\  \[Rule] a\)\ \((z - 
                  a)\) \(P \((z)\)\)\/\(\((z\  - \ a)\) \((z\  - \ b)\) \((z\ \
 - \ c)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(lim\+\(z\  \
\[Rule] a\)\ \(P \((z)\)\)\/\(\((z\  - \ b)\) \((z\  - \ c)\)\)\ \  = \ \ \(P \
\((a)\)\)\/\(\((a\  - \ b)\) \((a\  - \ c)\)\)\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 8.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(Z = \(z = 0\); \ Remove[z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<            \!\(\[DoubleStruckCapitalB]\/\(z - b\)\) = \
\>\"", \[DoubleStruckCapitalB]\/\(z - b\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<(\!\(\(-\[DoubleStruckCapitalB]\)\/\(b - \
a\)\))(\!\(1\/\(1 - \(\(-a\) + z\)\/\(\(-a\) + b\)\)\)) = \>\"", 
        Simplify[\((\(-\[DoubleStruckCapitalB]\)\/\(b - a\))\) \((1\/\(1 - \(\
\(-a\) + z\)\/\(\(-a\) + b\)\))\)]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<(\!\(\(-\[DoubleStruckCapitalB]\)\/\(b - \
a\)\))\!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\((\(z - a\)\/\(b - a\))\)\^n\) \
= \>\"", \((\(-\[DoubleStruckCapitalB]\)\/\(b - a\))\) \(\[Sum]\+\(n = 0\)\%\
\[Infinity]\((\(z - a\)\/\(b - a\))\)\^n\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   - \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\(\
\[DoubleStruckCapitalB] \((z - a)\)\^n\)\/\((b - a)\)\^\(n + 1\)\) = \>\"", \
\(-\ \(\[Sum]\+\(n = 0\)\%\[Infinity]\( \[DoubleStruckCapitalB] \((z - \
a)\)\^n\)\/\((b - a)\)\^\(n + 1\)\)\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   - \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\(\
\[DoubleStruckCapitalB] \((z - a)\)\^n\)\/\((b - a)\)\^\(n + 1\)\) = \>\"", 
        Simplify[\(-\ \(\[Sum]\+\(n = 0\)\%\[Infinity]\( \
\[DoubleStruckCapitalB] \((z - a)\)\^n\)\/\((b - a)\)\^\(n + 1\)\)\)\ ]\ ];\)\
\ \)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<            \!\(\[DoubleStruckCapitalC]\/\(z\\\  - \\\ c\
\)\) = \>\"", \[DoubleStruckCapitalC]\/\(z\  - \ c\)\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    - \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\(\
\[DoubleStruckCapitalC] \((z - a)\)\^n\)\/\((c - a)\)\^\(n + 1\)\) = \>\"", 
        Simplify[\(-\ \(\[Sum]\+\(n = 0\)\%\[Infinity]\( \
\[DoubleStruckCapitalC] \((z - a)\)\^n\)\/\((c - a)\)\^\(n + 1\)\)\)\ ]\ ];\)\
\ \)}], "Input"],

Cell[BoxData[{
    \(\(f[
          z_] = \[DoubleStruckCapitalA]\/\(z - a\) + \
\[DoubleStruckCapitalB]\/\(z - b\) + \[DoubleStruckCapitalC]\/\(z - c\);\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<                            f[z] = \>", 
        f[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[DoubleStruckCapitalA]\/\(z\\\  - \\\ a\)\)- \!\(\
\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\(\[DoubleStruckCapitalB] \((z - \
a)\)\^n\)\/\((b - a)\)\^\(n + 1\)\)- \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\
\(\[DoubleStruckCapitalC] \((z - a)\)\^n\)\/\((c - a)\)\^\(n + 1\)\) = \>\"", \
\[DoubleStruckCapitalA]\/\(z\  - \ a\) - \ \[Sum]\+\(n = 0\)\%\[Infinity]\( \
\[DoubleStruckCapitalB] \((z - a)\)\^n\)\/\((b - a)\)\^\(n + 1\) - \ \[Sum]\+\
\(n = 0\)\%\[Infinity]\( \[DoubleStruckCapitalC] \((z - a)\)\^n\)\/\((c - \
a)\)\^\(n + 1\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[DoubleStruckCapitalA]\/\(z\\\  - \\\ a\)\)- \!\(\
\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\(\[DoubleStruckCapitalB] \((z - \
a)\)\^n\)\/\((b - a)\)\^\(n + 1\)\)- \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\
\(\[DoubleStruckCapitalC] \((z - a)\)\^n\)\/\((c - a)\)\^\(n + 1\)\) = \>\"", 
        Simplify[\[DoubleStruckCapitalA]\/\(z\  - \ a\) - \ \[Sum]\+\(n = 0\)\
\%\[Infinity]\( \[DoubleStruckCapitalB] \((z - a)\)\^n\)\/\((b - a)\)\^\(n + \
1\) - \ \[Sum]\+\(n = 0\)\%\[Infinity]\( \[DoubleStruckCapitalC] \((z - \
a)\)\^n\)\/\((c - a)\)\^\(n + 1\)]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Express  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(3  z\  + \ 2\)\/\(z \((z\  - \ 1)\) \((z\  - \ 2)\)\
\)\)],
    AspectRatioFixed->True],
  "  in partial fractions.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Solution.  In Example 8.7 use  ",
  Cell[BoxData[
      \(a = 0, b = 1, c = 2\)]],
  "  and  ",
  Cell[BoxData[
      \(P \((z)\) = 3  z + 2\)]],
  ".  Computing the residues, we obtain  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(\[DoubleStruckCapitalA]\  = \ \(Res[f, 
                0]\  = \ \(\(P \((0)\)\)\/\(\((0\  - \ 1)\) \((0\  - \ 2)\)\) \
= \ \(2\/\(\((\(-\ 1\))\) \((\(-\ 2\))\)\) = \ \(2\/1\  = \ 1\)\)\)\)\), 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", \(\[DoubleStruckCapitalB]\  = \ \(Res[f, 
                1]\  = \ \(\(P \((1)\)\)\/\(\((1\  - \ 0)\) \((1\  - \ 2)\)\) \
= \ \(5\/\(\((1\ )\) \((\(-\ 1\))\)\) = \ \(5\/\(-\ 1\)\  = \ \
\(-5\)\)\)\)\)\), 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"\[DoubleStruckCapitalC]", " ", "=", " ", 
        RowBox[{\(Res[f, 2]\), " ", "=", " ", 
          RowBox[{\(\(P \((2)\)\)\/\(\((2\  - \ 0)\) \((2\  - \ 1)\)\)\), 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "=", " ", 
            RowBox[{\(8\/\(\((2)\) \((1)\)\)\), "=", " ", 
              RowBox[{\(8\/2\), " ", "=", " ", 
                RowBox[{"4", 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[".",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]}]}]}]}]}]}]],
  " \n\nThe formula for ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " in Example 8.7 gives us  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\ \  = \ \ \[DoubleStruckCapitalA]\/\(z - 0\)\  + \ \
\[DoubleStruckCapitalB]\/\(z - 1\)\  + \ \[DoubleStruckCapitalC]\/\(z - 2\)\)\
\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(1\/\(z - 0\)\  + \ \
\(-5\)\/\(z - 1\)\  + \ 4\/\(z - 2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1\/z\  - \ 
          5\/\(z - 1\)\  + \ 4\/\(z - 2\)\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[BoxData[{
    \(Z = \(z = 0\); \ Remove[z, Z];\ \), "\[IndentingNewLine]", 
    \(\(P[z_] = 3  z + 2;\)\), "\[IndentingNewLine]", 
    \(\(f[
          z_]\  = \ \(3  z + 2\)\/\(z \((z - 1)\) \((z - 2)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(a = 0;\)\), "\[IndentingNewLine]", 
    \(\(b = 1;\)\), "\[IndentingNewLine]", 
    \(\(c = 2;\)\), "\[IndentingNewLine]", 
    \(\(\[DoubleStruckCapitalA]\  = \ 
        P[a]\/\(\((a - b)\) \((a - c)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[DoubleStruckCapitalB]\  = \ 
        P[b]\/\(\((b - a)\) \((b - c)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[DoubleStruckCapitalC]\  = \ 
        P[c]\/\(\((c - a)\) \((c - b)\)\);\)\), "\[IndentingNewLine]", 
    \(\(F[
          z_] = \[DoubleStruckCapitalA]\/\(z - a\) + \
\[DoubleStruckCapitalB]\/\(z - b\) + \[DoubleStruckCapitalC]\/\(z - c\);\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<P[z] = \>", P[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f(z) = \!\(P[z]\/\(\((z - a)\) \((z - b)\) \((z - c)\)\)\
\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<   a = \>", a\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<   b = \>", b];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<   c = \>", c\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \[DoubleStruckCapitalA] = \!\(P[a]\/\(\((a - b)\) \
\((a - c)\)\)\) = \>\"", \[DoubleStruckCapitalA]];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \[DoubleStruckCapitalB] = \!\(P[b]\/\(\((b - a)\) \
\((b - c)\)\)\) = \>\"", \[DoubleStruckCapitalB]];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \[DoubleStruckCapitalC] = \!\(P[c]\/\(\((c - a)\) \
\((c - b)\)\)\) = \>\"", \[DoubleStruckCapitalC]];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[z] = \!\(\[DoubleStruckCapitalA]\/\(z - a\)\) + \!\(\
\[DoubleStruckCapitalB]\/\(z - b\)\) + \!\(\[DoubleStruckCapitalC]\/\(z - c\)\
\)\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = (\>", \[DoubleStruckCapitalA]\/\(z - a\), "\<) + \
(\>", \[DoubleStruckCapitalB]\/\(z - b\), "\<) + (\>", \
\[DoubleStruckCapitalC]\/\(z - c\), "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", F[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \(3  z\  + \ 2\)\/\(z \((z\  - \ 1)\) \((z\  - \ 2)\)\)\)],
    AspectRatioFixed->True],
  "  and find the partial fraction expansion.  "
}], "Text"],

Cell[BoxData[{
    \(\(Remove[z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, i, p, R, solset];\)\ \), "\n", 
    \(\(f[
          z_]\  = \ \(3  z\  + \ 2\)\/\(z \((z - 1)\) \((z - 2)\)\);\)\ \), "\
\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[Denominator[f[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, z]];\)\ \), "\n", 
    \(\(Z\  = \ Table[0, {Length[solset]}];\)\ \), "\n", 
    \(\(R\  = \ Table[0, {Length[solset]}];\)\ \), "\n", 
    \(\(F[z_]\  = \ 0;\)\ \), "\n", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[solset], \(i++\), \n\ \ \ Z\_\(\(\[LeftDoubleBracket]\)\(i\)\
\(\[RightDoubleBracket]\)\) = 
          ReplaceAll[z, 
            solset\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
]; \ \n\ \ \ If[1 \[Equal] i, p\  = \ 1]; \ \n\ \ \ If[1 < i; \ 
          Z\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\[RightDoubleBracket]\)\) \
\[Equal] Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\), 
          p = p + 1, p = 1]; \ \n\ \ \ Print["\<z\>"\_i, "\< = \>", 
          Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]; \ \n\
\ \ \ R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Residue[\(\((z - 
                      Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\))\)\^\(p - 1\)\) f[z], {z, 
              Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)}];\
 \ \n\ \ \ Print["\<Res[\>", \((z - Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\))\)\^\(p - 1\), "\< f,\>", 
          Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\), "\<] \
= \>", R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]; \ \n\ \
\ \ Print["\< \>"]; \ \n\ \ \ F[z_]\  = \ 
          F[z]\  + \ 
            R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\/\((\
z - Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\))\)\^p;\ \
];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Compare this with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Apart  procedure for the partial fraction expansion."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", Apart[f[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
In a moment, we will see that our subroutine will work for complex factors \
and \"Apart\" does not.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark 8.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  If a repeated root occurs, then the process is similar, and it is easy \
to show that if ",
  StyleBox["P(z)",
    FontFamily->"Courier New"],
  " has degree of at most ",
  StyleBox["2",
    FontFamily->"Courier New"],
  ", then\n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ \(\(P \((z)\)\)\/\(\(\((z\  - \ a)\)\^2\) \((z\  \
- \ b)\)\)\ \  = \ \ \[DoubleStruckCapitalA]\/\((z\  - \ a)\)\^2\  + \ \
\[DoubleStruckCapitalB]\/\(z\  - \ a\)\  + \ \[DoubleStruckCapitalC]\/\(z\  - \
\ b\)\)\)]],
  ",  \nwhere\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(\[DoubleStruckCapitalA]\  = \ 
            Res[\((z - a)\) f \((z)\), a]\), 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", \(\[DoubleStruckCapitalB]\  = \ Res[f, a]\), 
          
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"\[DoubleStruckCapitalC]", " ", "=", " ", 
        RowBox[{\(Res[f, b]\), 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[".",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}]}]],
  "   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 8.9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Express  ",
  Cell[BoxData[
      \(f \((z)\) = \(z\^2\  + \ 3  z\  + \ 2\)\/\(\(z\^2\) \((z\  - \ 1)\)\)\
\)],
    AspectRatioFixed->True],
  "  in partial fractions.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Solution.  Using the Remark 8.1 and  ",
  Cell[BoxData[
      \(a = 0, b = 1\)]],
  "  and  ",
  Cell[BoxData[
      \(P \((z)\) = z\^2\  + \ 3  z\  + \ 2\)]],
  ",  we have  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ \(\(P \((z)\)\)\/\(\(\((z\  - \ 0)\)\^2\) \((z\  \
- \ 1)\)\)\ \  = \ \ \[DoubleStruckCapitalA]\/\((z\  - \ 0)\)\^2\  + \ \
\[DoubleStruckCapitalB]\/\(z\  - \ 0\)\  + \ \[DoubleStruckCapitalC]\/\(z\  - \
\ 1\)\)\)]],
  "\n\nwhere  \n\t\t\t",
  Cell[BoxData[{
      \(\[DoubleStruckCapitalA]\ \  = \ \ \(Res[\((z - 0)\) f \((z)\), 0] = \ 
          Res[z \( z\^2\  + \ 3  z\  + \ 2\)\/\(\(z\^2\) \((z\  - \ 1)\)\), 
            0]\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \(\(=\)\(\ \ \)\(Res[\(z\^2\  + \ 3  z\  + \ 2\)\/\(z \((z\ \
 - \ 1)\)\), 0]\)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \(\(=\)\(\ \ \)\(lim\+\(z\  \[Rule] \ 0\)\ \((z - 
                0)\) \(z\^2\  + \ 3  z\  + \ 2\)\/\(z \((z\  - \ 1)\)\)\)\)\),
     "\[IndentingNewLine]", 
      \(\ \ \ \ \ \(\(=\)\(\ \ \)\(2\/\(-\ 1\)\ \  = \ \ \(-2\)\)\)\)}]],
  "    \n\t\t\t\n\t\t\t",
  Cell[BoxData[{
      RowBox[{"\[DoubleStruckCapitalB]", "  ", "=", "  ", 
        RowBox[{\(Res[f, 0]\), 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "=", 
          " ", \(Res[\(z\^2\  + \ 3  z\  + \ 2\)\/\(\(z\^2\) \((z\  - \ \
1)\)\), 0]\)}]}], "\[IndentingNewLine]", 
      RowBox[{
        "    ", \(\(=\)\(\ \ \)\(lim\+\(z\  \[Rule] 0\)\ \(d\/dz\) \((\(\((z \
- 0)\)\^2\) \(z\^2\  + \ 3  z\  + \ 2\)\/\(\(z\^2\) \((z\  - \ \
1)\)\))\)\)\)}], "\[IndentingNewLine]", 
      RowBox[{
        "    ", \(\(=\)\(\ \ \)\(lim\+\(z\  \[Rule] 0\)\ \(d\/dz\) \((\(z\^2\ \
 + \ 3  z\  + \ 2\)\/\(z\  - \ 1\))\)\)\)}], "\[IndentingNewLine]", 
      RowBox[{
        "    ", \(\(=\)\(\ \ \)\(lim\+\(z\  \[Rule] 0\)\ \(\((2  z + 3)\) \
\((z - 1)\) - \((1)\) \((z\^2\  + \ 3  z\  + \ 2)\)\)\/\((z - 1)\)\^2\)\)}], 
    "\[IndentingNewLine]", 
      RowBox[{
        "    ", \(\(=\)\(\ \ \)\(lim\+\(z\  \[Rule] \ 0\)\ \(z\^2 - 2\ z - \
5\)\/\((z - 1)\)\^2\)\)}], "\[IndentingNewLine]", 
      RowBox[{"    ", \(\(=\)\(\ \ \)\(\(-5\)\/1\ \  = \ \ \(-5\)\)\)}]}]],
  "    \n\t\t\t\t\t\t\n\t\t\t",
  Cell[BoxData[{
      \(\[DoubleStruckCapitalC]\ \  = \ \ Res[\(z\^2\  + \ 3  z\  + \ 2\)\/\(\
\(z\^2\) \((z\  - \ 1)\)\), 1]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\ \)\(lim\+\(z\  \[Rule] \ 1\)\ \((z - 
                1)\) \(z\^2\  + \ 3  z\  + \ 2\)\/\(\(z\^2\) \((z\  - \ \
1)\)\)\)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\ \)\(lim\+\(z\  \[Rule] \ 1\)\ \(z\^2\  + \ 3  z\  \
+ \ 2\)\/z\^2\)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\(1\  + \ 3\  + \ 2\)\/1\ \  = \ \ 6\)\)\)}]],
  "    "
}], "Text"],

Cell[TextData[{
  "Thus,  \n\t\t",
  Cell[BoxData[{
      \(f \((z)\)\  = \ \(\(z\^2\  + \ 3  z\  + \ 2\)\/\(\(z\^2\) \((z\  - \ \
1)\)\)\  = \ \[DoubleStruckCapitalA]\/\((z\  - \ 0)\)\^2\  + \ \
\[DoubleStruckCapitalB]\/\(z\  - \ 0\)\  + \ \[DoubleStruckCapitalC]\/\(z\  - \
\ 1\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(-2\)\/\(\(z\)\(\ \)\)\^2\  + \
\ \(-5\)\/z\  + \ 6\/\(z\  - \ 1\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(-\(2\/\(\(z\)\(\ \)\)\^2\)\)\
\  - \ 5\/z\  + \ 6\/\(z\  - \ 1\)\)\)\)}],
    AspectRatioFixed->True],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = \(z\^2\  + \ 3  z\  + \ 2\)\/\(\(z\^2\) \((z\  - \ 1)\)\)\)],
    AspectRatioFixed->True],
  " and find the partial fraction expansion.  "
}], "Text"],

Cell[BoxData[{
    \(Z = \(z = 0\); \ Remove[z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, i, p, R, solset];\)\ \), "\n", 
    \(\(f[
          z_]\  = \ \(z\^2\  + \ 3  z\  + \ 2\)\/\(\(z\^2\) \((z - 1)\)\);\)\ \
\), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[Denominator[f[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, z]];\)\ \), "\n", 
    \(\(Z\  = \ Table[0, {Length[solset]}];\)\ \), "\n", 
    \(\(R\  = \ Table[0, {Length[solset]}];\)\ \), "\n", 
    \(\(F[z_]\  = \ 0;\)\ \), "\n", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[solset], \(i++\), \n\ \ \ Z\_\(\(\[LeftDoubleBracket]\)\(i\)\
\(\[RightDoubleBracket]\)\) = 
          ReplaceAll[z, 
            solset\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
]; \ \n\ \ \ If[1 \[Equal] i, p\  = \ 1]; \ \n\ \ \ If[1 < i; \ 
          Z\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\[RightDoubleBracket]\)\) \
\[Equal] Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\), 
          p = p + 1, p = 1]; \ \n\ \ \ Print["\<z\>"\_i, "\< = \>", 
          Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]; \ \n\
\ \ \ R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Residue[\(\((z - 
                      Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\))\)\^\(p - 1\)\) f[z], {z, 
              Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)}];\
 \ \n\ \ \ Print["\<Res[\>", \((z - Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\))\)\^\(p - 1\), "\< f,\>", 
          Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\), "\<] \
= \>", R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]; \ \n\ \
\ \ Print["\< \>"]; \ \n\ \ \ F[z_]\  = \ 
          F[z]\  + \ 
            R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\/\((\
z - Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\))\)\^p;\ \
];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Compare this with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Apart  procedure for the partial fraction expansion."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", Apart[f[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
In the next example we will see that our subroutine will work for complex \
factors and \"Apart\" does not.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Express  of  ",
  Cell[BoxData[
      \(f[z] = 1\/\(z\^4\  - \ 1\)\)],
    AspectRatioFixed->True],
  "  in partial fractions.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution for Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  "
}], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = 1\/\(z\^4\  - \ 1\)\)],
    AspectRatioFixed->True],
  " and find the partial fraction expansion.  "
}], "Text"],

Cell[BoxData[{
    \(Z = \(z = 0\); \ Remove[z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, i, p, R, solset];\)\ \), "\n", 
    \(\(f[z_]\  = \ 1\/\(z\^4 - 1\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[Denominator[f[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, z]];\)\ \), "\n", 
    \(\(Z\  = \ Table[0, {Length[solset]}];\)\ \), "\n", 
    \(\(R\  = \ Table[0, {Length[solset]}];\)\ \), "\n", 
    \(\(F[z_]\  = \ 0;\)\ \), "\n", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[solset], \(i++\), \n\ \ \ Z\_\(\(\[LeftDoubleBracket]\)\(i\)\
\(\[RightDoubleBracket]\)\) = 
          ReplaceAll[z, 
            solset\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
]; \ \n\ \ \ If[1 \[Equal] i, p\  = \ 1]; \ \n\ \ \ If[1 < i; \ 
          Z\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\[RightDoubleBracket]\)\) \
\[Equal] Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\), 
          p = p + 1, p = 1]; \ \n\ \ \ Print["\<z\>"\_i, "\< = \>", 
          Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]; \ \n\
\ \ \ R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Residue[\(\((z - 
                      Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\))\)\^\(p - 1\)\) f[z], {z, 
              Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)}];\
 \ \n\ \ \ Print["\<Res[\>", \((z - Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\))\)\^\(p - 1\), "\< f,\>", 
          Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\), "\<] \
= \>", R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]; \ \n\ \
\ \ Print["\< \>"]; \ \n\ \ \ F[z_]\  = \ 
          F[z]\  + \ 
            R\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\/\((\
z - Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\))\)\^p;\ \
];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Which is an improvement on ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s \"Apart\"  procedure."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", Apart[f[z]]];\)\ \)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Residue Calculus",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ResidueCalcBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Contour Integrals",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ContourIntegralBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{918, 583},
WindowMargins->{{27, Automatic}, {Automatic, 0}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[38391, 956, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[44358, 1172, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 144992, 3466}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 115, 2, 33, "Text"],
Cell[2220, 66, 114, 2, 33, "Text"],
Cell[2337, 70, 651, 12, 128, "Text"],
Cell[2991, 84, 1375, 40, 96, "Text",
  Evaluatable->False],
Cell[4369, 126, 1286, 46, 172, "Text"],
Cell[5658, 174, 719, 22, 118, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[6402, 200, 111, 2, 33, "Text"],
Cell[6516, 204, 204, 7, 37, "Text"],
Cell[6723, 213, 404, 8, 157, "Input"],
Cell[7130, 223, 182, 7, 36, "Text",
  Evaluatable->False],
Cell[7315, 232, 245, 5, 71, "Input"],
Cell[7563, 239, 291, 10, 33, "Text",
  Evaluatable->False],
Cell[7857, 251, 210, 4, 78, "Input"]
}, Closed]],
Cell[8082, 258, 342, 14, 34, "Text",
  Evaluatable->False],
Cell[8427, 274, 1816, 39, 288, "Text"],

Cell[CellGroupData[{
Cell[10268, 317, 111, 2, 33, "Text"],
Cell[10382, 321, 953, 18, 240, "Input"],
Cell[11338, 341, 206, 6, 37, "Text"],
Cell[11547, 349, 400, 8, 164, "Input"],
Cell[11950, 359, 231, 10, 36, "Text",
  Evaluatable->False],
Cell[12184, 371, 245, 5, 71, "Input"],
Cell[12432, 378, 291, 10, 33, "Text",
  Evaluatable->False],
Cell[12726, 390, 193, 4, 70, "Input"]
}, Closed]],
Cell[12934, 397, 2927, 95, 232, "Text"],
Cell[15864, 494, 505, 17, 38, "Text",
  Evaluatable->False],
Cell[16372, 513, 16623, 275, 209, 16509, 271, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[32998, 790, 618, 20, 80, "Text"],

Cell[CellGroupData[{
Cell[33641, 814, 111, 2, 33, "Text"],
Cell[33755, 818, 107, 2, 33, "Text",
  Evaluatable->False],
Cell[33865, 822, 394, 8, 137, "Input"],
Cell[34262, 832, 152, 5, 33, "Text",
  Evaluatable->False],
Cell[34417, 839, 1447, 29, 309, "Input"]
}, Closed]],
Cell[35879, 871, 2162, 69, 126, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[38066, 944, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[38214, 950, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[38391, 956, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[38751, 968, 1465, 46, 30, "Text"],
Cell[40219, 1016, 1829, 59, 90, "Text",
  Evaluatable->False],
Cell[42051, 1077, 1873, 74, 198, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[43949, 1155, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[44097, 1161, 258, 9, 33, "Text",
  Evaluatable->False],
Cell[44358, 1172, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[44718, 1184, 331, 13, 33, "Text",
  Evaluatable->False],
Cell[45052, 1199, 3452, 81, 442, "Text"],
Cell[48507, 1282, 1728, 32, 362, "Text"],

Cell[CellGroupData[{
Cell[50260, 1318, 195, 7, 33, "Text"],
Cell[50458, 1327, 158, 6, 36, "Text"],
Cell[50619, 1335, 290, 6, 124, "Input"],
Cell[50912, 1343, 222, 7, 33, "Text",
  Evaluatable->False],
Cell[51137, 1352, 843, 16, 200, "Input"],
Cell[51983, 1370, 291, 10, 33, "Text",
  Evaluatable->False],
Cell[52277, 1382, 189, 4, 70, "Input"],
Cell[52469, 1388, 192, 7, 36, "Text",
  Evaluatable->False],
Cell[52664, 1397, 435, 9, 131, "Input"]
}, Closed]],
Cell[53114, 1409, 537, 17, 35, "Text",
  Evaluatable->False],
Cell[53654, 1428, 17860, 296, 209, 17746, 292, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[71517, 1726, 2492, 59, 373, "Text"],
Cell[74012, 1787, 1063, 21, 200, "Text"],

Cell[CellGroupData[{
Cell[75100, 1812, 195, 7, 33, "Text"],
Cell[75298, 1821, 266, 10, 37, "Text",
  Evaluatable->False],
Cell[75567, 1833, 1668, 37, 404, "Input"],
Cell[77238, 1872, 196, 7, 33, "Text",
  Evaluatable->False],
Cell[77437, 1881, 1851, 33, 270, "Input"],
Cell[79291, 1916, 169, 7, 33, "Text",
  Evaluatable->False],
Cell[79463, 1925, 465, 9, 150, "Input"],
Cell[79931, 1936, 113, 2, 33, "Text",
  Evaluatable->False],
Cell[80047, 1940, 2176, 41, 418, "Input"]
}, Closed]],
Cell[82238, 1984, 510, 17, 35, "Text",
  Evaluatable->False],
Cell[82751, 2003, 14257, 237, 171, 14143, 233, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[97011, 2242, 1534, 41, 229, "Text"],
Cell[98548, 2285, 1383, 28, 288, "Text"],

Cell[CellGroupData[{
Cell[99956, 2317, 195, 7, 33, "Text"],
Cell[100154, 2326, 235, 10, 37, "Text",
  Evaluatable->False],
Cell[100392, 2338, 1622, 35, 404, "Input"],
Cell[102017, 2375, 202, 7, 33, "Text",
  Evaluatable->False],
Cell[102222, 2384, 1881, 33, 285, "Input"],
Cell[104106, 2419, 163, 7, 33, "Text",
  Evaluatable->False],
Cell[104272, 2428, 339, 7, 110, "Input"],
Cell[104614, 2437, 113, 2, 33, "Text",
  Evaluatable->False],
Cell[104730, 2441, 1891, 36, 373, "Input"]
}, Closed]],
Cell[106636, 2480, 228, 6, 29, "SmallText"],
Cell[106867, 2488, 3736, 105, 211, "Text",
  Evaluatable->False],
Cell[110606, 2595, 1977, 56, 303, "Text"],
Cell[112586, 2653, 1886, 46, 287, "Text"],

Cell[CellGroupData[{
Cell[114497, 2703, 111, 2, 33, "Text"],
Cell[114611, 2707, 1410, 20, 239, "Input"],
Cell[116024, 2729, 486, 8, 83, "Input"],
Cell[116513, 2739, 1476, 22, 146, "Input"]
}, Closed]],
Cell[118004, 2764, 340, 12, 35, "Text",
  Evaluatable->False],
Cell[118347, 2778, 4466, 111, 333, "Text"],

Cell[CellGroupData[{
Cell[122838, 2893, 195, 7, 33, "Text"],
Cell[123036, 2902, 2285, 42, 637, "Input"],
Cell[125324, 2946, 222, 6, 38, "Text"],
Cell[125549, 2954, 2318, 43, 510, "Input"],
Cell[127870, 2999, 212, 7, 33, "Text",
  Evaluatable->False],
Cell[128085, 3008, 185, 4, 70, "Input"],
Cell[128273, 3014, 173, 5, 33, "Text",
  Evaluatable->False]
}, Closed]],
Cell[128461, 3022, 3640, 102, 185, "Text",
  Evaluatable->False],
Cell[132104, 3126, 338, 12, 39, "Text",
  Evaluatable->False],
Cell[132445, 3140, 2985, 64, 532, "Text"],
Cell[135433, 3206, 670, 14, 144, "Text"],

Cell[CellGroupData[{
Cell[136128, 3224, 195, 7, 33, "Text"],
Cell[136326, 3233, 223, 6, 39, "Text"],
Cell[136552, 3241, 2337, 43, 514, "Input"],
Cell[138892, 3286, 212, 7, 33, "Text",
  Evaluatable->False],
Cell[139107, 3295, 185, 4, 70, "Input"],
Cell[139295, 3301, 180, 5, 33, "Text",
  Evaluatable->False]
}, Closed]],
Cell[139490, 3309, 301, 11, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[139816, 3324, 219, 8, 33, "Text"],
Cell[140038, 3334, 185, 6, 36, "Text"],
Cell[140226, 3342, 2286, 41, 508, "Input"],
Cell[142515, 3385, 190, 7, 33, "Text",
  Evaluatable->False],
Cell[142708, 3394, 151, 3, 50, "Input"]
}, Closed]],
Cell[142874, 3400, 290, 7, 30, "Text"],
Cell[143167, 3409, 313, 10, 33, "Text"],
Cell[143483, 3421, 318, 10, 33, "Text"],
Cell[143804, 3433, 257, 5, 33, "Text"],
Cell[144064, 3440, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

