(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     95494,       2137]*)
(*NotebookOutlinePosition[     96353,       2169]*)
(*  CellTagsIndexPosition[     96277,       2163]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["8.2  Trigonometric Integrals",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
\tAs indicated at the beginning of this chapter, we can evaluate certain \
definite real integrals with the aid of the residue theorem.  One way to do \
this is by interpreting the definite integral as the parametric form of an \
integral of an analytic function along a simple closed contour.\
\>", "Text"],

Cell[TextData[{
  "\tSuppose we wish to evaluate an integral of the form  \n\n",
  StyleBox["(8-3)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_0\%\(2  \[Pi]\)\ \ F \((cos\ \[Theta], 
            sin\ \[Theta])\) \[DifferentialD]\[Theta]\)]],
  ",    \n\nwhere ",
  StyleBox["F(u,v)",
    FontFamily->"Courier New"],
  " is a function of the two real variables ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v",
    FontFamily->"Courier New"],
  ".  Consider the unit circle ",
  Cell[BoxData[
      \(\(C\_1\) \((0)\) = {z : \(\(|\)\(z\)\(|\)\) = 1}\)]],
  " with parametrization  \n\n\t\t\t",
  Cell[BoxData[
      \(\(C\_1\%+\) \((0)\) : \ \ z\  = \ \(cos\ \[Theta]\  + \ \[ImaginaryI]\
\ sin\ \[Theta]\ \  = \ \ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)\)]],
  ",    for    ",
  Cell[BoxData[
      \(0 \[LessEqual] \[Theta] \[LessEqual] 2  \[Pi]\)]],
  ";   \n\nwhich gives us the following symbolic differentials.\n\n\t\t\t",
  Cell[BoxData[
      \(\[DifferentialD]z\ \  = \ \ \(\((\(-sin\)\ \[Theta]\  + \ \
\[ImaginaryI]\ cos\ \[Theta])\) \[DifferentialD]\[Theta]\ \ \  = \ \ \
\[ImaginaryI]\ \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\) \
\[DifferentialD]\[Theta]\)\)]],
  ",    and   \n",
  StyleBox["(8-4)",
    FontColor->RGBColor[0, 0, 1]],
  "\n\t\t\t",
  Cell[BoxData[
      \(\[DifferentialD]\[Theta]\ \ \  = \ \ \(\[DifferentialD]z\/\(\
\[ImaginaryI]\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)\ \  = \ \ \
\[DifferentialD]z\/\(\[ImaginaryI]\ z\)\)\)]],
  ".  \n\nCombining   ",
  Cell[BoxData[
      \(z\  = \ cos\ \[Theta]\  + \ \[ImaginaryI]\ sin\ \[Theta]\)]],
  "   with   ",
  Cell[BoxData[
      \(1\/z\  = \ cos\ \[Theta]\  - \ \[ImaginaryI]\ sin\ \[Theta]\)]],
  ",   we can obtain  \n\n",
  StyleBox["(8-5)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(cos\ \[Theta]\ \  = \ \ \(1\/2\) \((z + 1\/z)\)\)]],
  "    and    ",
  Cell[BoxData[
      \(sin\ \[Theta]\ \  = \ \ \(1\/\(2  \[ImaginaryI]\)\) \((z - 
              1\/z)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Using the substitutions for  ",
  Cell[BoxData[
      \(cos\ \[Theta]\)]],
  ",  ",
  Cell[BoxData[
      \(sin\ \[Theta]\)]],
  " , and  ",
  Cell[BoxData[
      \(\[DifferentialD]\[Theta]\)]],
  "  in Expression ",
  StyleBox["(8-3)",
    FontColor->RGBColor[0, 0, 1]],
  " transforms the definite integral into a contour integral \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_0\%\(2  \[Pi]\)\ \ F \((cos\ \[Theta], 
              sin\ \[Theta])\) \[DifferentialD]\[Theta]\ \ \  = \ \ \
\[ContourIntegral]\_\(\(\ \)\(\(C\_1\%+\) \((0)\)\)\)\ 
          f \((z)\)\ \(\(\[DifferentialD]z\)\(\ \)\)\)]],
  ",  \n\nwhere the new integrand is  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(1\/\[ImaginaryI]z\) 
          F \((\(1\/2\) \((z + 1\/z)\), \(1\/\(2  \[ImaginaryI]\)\) \((z - 
                  1\/z)\))\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "\tSuppose that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic inside and on the unit circle ",
  Cell[BoxData[
      \(\(C\_1\) \((0)\)\)]],
  ", except at the points  ",
  Cell[BoxData[
      \(z\_1, z\_2, \  ... , z\_n\)]],
  "  that lie interior to  ",
  Cell[BoxData[
      \(\(C\_1\) \((0)\)\)]],
  ".  Then the residue theorem gives\n\n",
  StyleBox["(8-6)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_0\%\(2  \[Pi]\)\ \ F \((cos\ \[Theta], 
              sin\ \[Theta])\) \[DifferentialD]\[Theta]\ \ \  = \ \ 2  \[Pi]\ \
\[ImaginaryI]\ \(\[Sum]\+\(k = 1\)\%n Res[f, z\_k]\)\)]],
  ".  \n\nThe situation is illustrated in Figure 8.2."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 8.2",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/integralstrigonometric/\
IntegralsTrigFigures/mat0802.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  The change of variables from a definite integral on ",
  Cell[BoxData[
      \(\([0, 2  \[Pi]]\)\)]],
  " to a contour integral around ",
  StyleBox["C",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  "Some of these problems can be solved using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s table of integrals."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["We need to use the following substitution procedure.",
  
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[f0, F, sub, \[Theta], z];\)\ \), "\n", 
    \(\(sub[
          F_, \[Theta]_]\  := \[IndentingNewLine]Module[{}, \
\[IndentingNewLine]Clear[f0]; \ \[IndentingNewLine]f0\  = \ 
            F; \ \[IndentingNewLine]f0\  = \ 
            ReplaceAll[
              f0, {Cos[\[Theta]] \[Rule] \(z + 1\/z\)\/2, 
                Sin[\[Theta]] \[Rule] \(z - 1\/z\)\/\(2  \[ImaginaryI]\)}]; \ \
\[IndentingNewLine]f0\  = \ 
            ReplaceAll[
              f0, {Cos[2  \[Theta]] \[Rule] \(z\^2 + 1\/z\^2\)\/2, 
                Sin[2  \[Theta]] \[Rule] \(z\^2 - 1\/z\^2\)\/\(2  \
\[ImaginaryI]\)}]; \ \[IndentingNewLine]f0\  = \ 
            ReplaceAll[
              f0, {Cos[3  \[Theta]] \[Rule] \(z\^3 + 1\/z\^3\)\/2, 
                Sin[3  \[Theta]] \[Rule] \(z\^3 - 1\/z\^3\)\/\(2  \
\[ImaginaryI]\)}]; \ \[IndentingNewLine]f0\  = \ 
            f0\/\(\[ImaginaryI]\ z\); \ \[IndentingNewLine]f0\  = \ 
            Together[f0]; \ \[IndentingNewLine]f0\  = \ 
            Cancel[f0]; \ \[IndentingNewLine]Return[
            f0];\ \ ];\)\ \)}], "Input",
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 8.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "    Evaluate  ",
  Cell[BoxData[
      \(\[Integral]\_0\%\(2  \[Pi]\)\(\(\(\ \)\(1\)\)\/\(1\  + \ 
                3\ \(cos\^2\) \[Theta]\)\) \[DifferentialD]\[Theta]\)]],
  "  by using complex analysis.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005B0000i2000`400?l0
0000o`00003oo`3ooomC0?ooo`00o`3ooomC0?ooo`00o`3ooomC0?ooo`00
o`3ooomC0?ooo`00o`3ooomC0?ooo`00e03oool00`000000oooo0?ooo`1k
0?ooo`00e03oool00`000000oooo0?ooo`1k0?ooo`00e03oool00`000000
oooo0?ooo`1k0?ooo`00c03oool4000000@0oooo00<000000?ooo`3oool0
N`3oool00<`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1k0?ooo`00c@3oool00`000000oooo0?ooo`040?ooo`800000O03oool0
0<H0oooo100000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0N`3oool00<`0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1k0?ooo`00c@3oool2000000D0oooo00<000000?ooo`3o
ool0N`3oool00=@0oooo00<000000?ooo`3oool0N`3oool00=@0oooo00<0
00000?ooo`3oool01`3oool200000780oooo003D0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0K`3oool00=@0oooo00<000000?oo
o`3oool01@0000030?ooo`030000003oool0oooo0700oooo003D0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo06l0oooo003D0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0000001a0?ooo`00
e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0L03oool00=<0oooo0P3o00030?ooo`040000003o
ool0oooo000007H0oooo003B0?ooo`@0o`000P3oool5000007D0oooo003A
0?ooo`H0o`00N`3oool00=40oooo1P3o001k0?ooo`00dP3oool40?l007`0
oooo003C0?ooo`80o`00O@3oool00=@0oooo00<000000?ooo`3oool0N`3o
ool00=@0oooo00<000000?ooo`3oool0N`3oool00=@0oooo00<000000?oo
o`3oool0N`3oool00=@0oooo00<000000?ooo`3oool0N`3oool00=@0oooo
00<000000?ooo`3oool0N`3oool00=@0oooo00<000000?ooo`3oool0N`3o
ool00=@0oooo00<000000?ooo`3oool0N`3oool00=@0oooo00<000000?oo
o`3oool0N`3oool00=@0oooo00<000000?ooo`3oool0N`3oool00=@0oooo
00<000000?ooo`3oool0N`3oool00=@0oooo00<000000?ooo`3oool0N`3o
ool00=@0oooo00<000000?ooo`3oool0N`3oool00=@0oooo00<000000?oo
o`3oool0N`3oool00=@0oooo00<000000?ooo`3oool0N`3oool00=@0oooo
00<000000?ooo`3oool0N`3oool00=@0oooo00<000000?ooo`3oool0N`3o
ool00=@0oooo00<000000?ooo`3oool0N`3oool00=@0oooo00<000000?oo
o`3oool0N`3oool00=@0oooo00<000000?ooo`3oool0N`3oool00=@0oooo
00<000000?ooo`3oool0N`3oool00=@0oooo00<000000?ooo`3oool0N`3o
ool00=@0oooo00<000000?ooo`3oool0N`3oool00=@0oooo00<000000?oo
o`3oool0N`3oool00=@0oooo00<000000?ooo`3oool0N`3oool00=@0oooo
00<000000?ooo`3oool0N`3oool00=@0oooo00<000000?ooo`3oool0N`3o
ool00=@0oooo00<000000?ooo`3oool0N`3oool00=@0oooo00<000000?oo
o`3oool0N`3oool00=@0oooo00<000000?ooo`3oool0N`3oool00=@0oooo
00<000000?ooo`3oool0N`3oool00<`0oooo1@0000030?ooo`030000003o
ool0oooo07/0oooo003>0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0N`3oool00<d0oooo3P000?mg0?ooo`00aP3oool2000000D0
003o00<0oooo0000003oool0103oool00`000000oooo0?ooo`040?ooo`D0
003oLP3oool00<H0oooo0P000?l60?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool20000og00oooo00320?ooo`@0003o1`3o
ool2000000D0oooo00<000000?ooo`3oool02`3oool50000of/0oooo002o
0?ooo`<0003o4P3oool00`000000oooo0?ooo`0@0?ooo`80003oJ@3oool0
0;d0oooo0P000?lE0?ooo`030000003oool0oooo0180oooo0P000?mW0?oo
o`00_03oool00`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo01@0
oooo00<0003o0?ooo`3oool0I03oool00;/0oooo00<0003o0?ooo`3oool0
5P3oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo06<0oooo
002i0?ooo`80003o6@3oool00`000000oooo0?ooo`0F0?ooo`80003oH`3o
ool00;L0oooo0P000?lK0?ooo`030000003oool0oooo01P0oooo0P000?mQ
0?ooo`00]P3oool00`000?l0oooo0?ooo`0K0?ooo`030000003oool0oooo
01X0oooo00<0003o0?ooo`3oool0GP3oool00;D0oooo00<0003o0?ooo`3o
ool0703oool00`000000oooo0?ooo`0K0?ooo`030000o`3oool0oooo05d0
oooo002c0?ooo`80003o7`3oool00`000000oooo0?ooo`060?ooo`D00000
4@3oool20000oed0oooo002b0?ooo`030000o`3oool0oooo01l0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000o`3o
ool0oooo05/0oooo002b0?ooo`030000o`3oool0oooo01l0oooo00<00000
0?ooo`3oool01@0000030?ooo`030000003oool0oooo01<0oooo00<0003o
0?ooo`3oool0FP3oool00;40oooo00<0003o0?ooo`3oool0803oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
000F0?ooo`030000o`3oool0oooo05T0oooo002`0?ooo`030000o`3oool0
oooo0240oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0F03oool0
0:h0oooo0P000?lT0?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool0oooo0P00000H0?ooo`80003oF03oool00:d0oooo00<0003o0?oo
o`3oool08`3oool20?l000<0oooo00@000000?ooo`3oool000007@3oool0
0`000?l0oooo0?ooo`1F0?ooo`00[@3oool00`000?l0oooo0?ooo`0R0?oo
o`@0o`000P3oool5000001d0oooo00<0003o0?ooo`3oool0E@3oool00:`0
oooo00<0003o0?ooo`3oool08P3oool60?l002@0oooo00<0003o0?ooo`3o
ool0E03oool00:/0oooo00<0003o0?ooo`3oool08`3oool60?l002D0oooo
00<0003o0?ooo`3oool0D`3oool00:X0oooo00<0003o0?ooo`3oool09@3o
ool40?l002H0oooo00<0003o0?ooo`3oool0D`3oool00:X0oooo00<0003o
0?ooo`3oool09P3oool20?l002P0oooo00<0003o0?ooo`3oool0DP3oool0
0:T0oooo00<0003o0?ooo`3oool0:03oool00`000000oooo0?ooo`0V0?oo
o`030000o`3oool0oooo0580oooo002Y0?ooo`030000o`3oool0oooo02P0
oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`1A0?ooo`00
Z@3oool00`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo
00<0003o0?ooo`3oool0D@3oool00:P0oooo00<0003o0?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0500oooo002X
0?ooo`030000o`3oool0oooo02T0oooo00<000000?ooo`3oool0:03oool0
0`000?l0oooo0?ooo`1@0?ooo`00Y`3oool00`000?l0oooo0?ooo`0Z0?oo
o`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0D03oool00:L0
oooo00<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000o`3oool0oooo04l0oooo002V0?ooo`030000o`3oool0oooo02/0oooo
00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`1?0?ooo`00YP3o
ool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo02X0oooo00<0
003o0?ooo`3oool0CP3oool00:D0oooo00<0003o0?ooo`3oool0;03oool0
0`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo04h0oooo002U0?oo
o`030000o`3oool0oooo02`0oooo00<000000?ooo`3oool0:`3oool00`00
0?l0oooo0?ooo`1=0?ooo`00Y@3oool00`000?l0oooo0?ooo`0/0?ooo`03
0000003oool0oooo02/0oooo00<0003o0?ooo`3oool0C@3oool00:@0oooo
00<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000
o`3oool0oooo04`0oooo002T0?ooo`030000o`3oool0oooo02d0oooo00<0
00000?ooo`3oool0;03oool00`000?l0oooo0?ooo`1<0?ooo`00L`3oool4
000002d0oooo00<0003o0000000000000P00000[0?ooo`030000003oool0
oooo02/0oooo00<000000000o`0000000P00000/0?ooo`@000006`3oool0
07<0oooo00<000000?ooo`3oool0;P3oool00`000?l0oooo0000000]0?oo
o`030000003oool0oooo02`0oooo00<0003o0000003oool0;@3oool00`00
0000oooo0?ooo`0L0?ooo`00M03oool00`000000oooo0?ooo`0/0?ooo`04
0000o`3oool0oooo000002d0oooo00<000000?ooo`3oool0;03oool00`00
0?l000000?ooo`0^0?ooo`030000003oool0oooo01/0oooo001]0?ooo`@0
0000103oool00`000000oooo0?ooo`0V0?ooo`@0000000D0oooo0000o`3o
ool0oooo0000000]0?ooo`030000003oool0oooo02d0oooo00<0003o0?oo
o`3oool0;P3oool00`000000oooo0?ooo`0J0?ooo`00L`3oool010000000
oooo0?ooo`00000/0?ooo`040000o`3oool0oooo000002d0oooo00<00000
0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0/0?ooo`040000003oool0
oooo000001/0oooo001d0?ooo`800000;@3oool010000?l0oooo00000000
000]0?ooo`030000003oool0oooo02`0oooo00<000000000o`3oool0;P3o
ool2000001`0oooo002S0?ooo`030000o`3oool0oooo02h0oooo00<00000
0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`1;0?ooo`00X`3oool00`00
0?l0oooo0?ooo`0^0?ooo`030000003oool0oooo02d0oooo00<0003o0?oo
o`3oool0B`3oool00:<0oooo00<0003o0?ooo`3oool0;P3oool00`000000
oooo0?ooo`0]0?ooo`030000o`3oool0oooo04/0oooo002S0?ooo`030000
o`3oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`000?l0oooo
0?ooo`0j0?ooo`80000000<0oooo000000000000303oool00:<0oooo00<0
003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`030000o`3o
ool0oooo03/0oooo00<000000?ooo`0000003@3oool006d0oooo=P000000
0`000?l000000000001N000000030000o`000000000003@00000203oool0
0`000000oooo0?ooo`0<0?ooo`00LP3oool00`000000oooo0?ooo`0^0?oo
o`030000o`3oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`00
0?l0oooo0?ooo`0^0?ooo`030000003oool0oooo00T0oooo0P0000000`3o
ool000000000000<0?ooo`00X`3oool00`000?l0oooo0?ooo`0^0?ooo`03
0000003oool0oooo02d0oooo00<0003o0?ooo`3oool0B`3oool00:<0oooo
00<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`030000
o`3oool0oooo04/0oooo002S0?ooo`030000o`3oool0oooo02h0oooo00<0
00000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`1;0?ooo`00X`3oool0
0`000?l0oooo0?ooo`0^0?ooo`030000003oool0oooo02d0oooo00<0003o
0?ooo`3oool0B`3oool00:<0oooo00<0003o0?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo04/0oooo002S0?ooo`03
0000o`3oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`000?l0
oooo0?ooo`1;0?ooo`00X`3oool00`000?l0oooo0?ooo`0^0?ooo`030000
003oool0oooo02`0oooo00<0003o0?ooo`3oool0C03oool00:@0oooo00<0
003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000o`3o
ool0oooo04`0oooo002T0?ooo`030000o`3oool0oooo02d0oooo00<00000
0?ooo`3oool0;03oool00`000?l0oooo0?ooo`1<0?ooo`00Y03oool00`00
0?l0oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<0003o0?oo
o`3oool0C03oool00:@0oooo00<0003o0?ooo`3oool0;@3oool00`000000
oooo0?ooo`0/0?ooo`030000o`3oool0oooo04`0oooo002T0?ooo`030000
o`3oool0oooo02d0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo
0?ooo`1=0?ooo`00Y@3oool00`000?l0oooo0?ooo`0/0?ooo`030000003o
ool0oooo02/0oooo00<0003o0?ooo`3oool0C@3oool00:D0oooo00<0003o
0?ooo`3oool0;03oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0
oooo04h0oooo002V0?ooo`030000o`3oool0oooo02/0oooo00<000000?oo
o`3oool0:P3oool00`000?l0oooo0?ooo`1>0?ooo`00YP3oool00`000?l0
oooo0?ooo`0[0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3o
ool0CP3oool00:L0oooo00<0003o0?ooo`3oool0:P3oool00`000000oooo
0?ooo`0Y0?ooo`030000o`3oool0oooo04l0oooo002W0?ooo`030000o`3o
ool0oooo02X0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?oo
o`1?0?ooo`00Y`3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003oool0
oooo00L0oooo0`00000N0?ooo`030000o`3oool0oooo0500oooo002X0?oo
o`030000o`3oool0oooo02T0oooo00<000000?ooo`3oool01@0000020?oo
o`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool0D03oool00:P0
oooo00<0003o0?ooo`3oool0:@3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo0000000N0?ooo`030000o`3oool0
oooo0540oooo002Y0?ooo`030000o`3oool0oooo02P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01`0oooo00<0003o0?ooo`3oool0D@3oool00:T0oooo00<0003o0?ooo`3o
ool0:03oool00`000000oooo0?ooo`030?ooo`070000003oool0oooo0?oo
o`000000oooo0000000L0?ooo`030000o`3oool0oooo0580oooo002Z0?oo
o`030000o`3oool0oooo02H0oooo0P3o00030?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`1B
0?ooo`00ZP3oool00`000?l0oooo0?ooo`0U0?ooo`@0o`000P3oool50000
01l0oooo00<0003o0?ooo`3oool0D`3oool00:/0oooo00<0003o0?ooo`3o
ool08`3oool60?l002D0oooo00<0003o0?ooo`3oool0D`3oool00:`0oooo
00<0003o0?ooo`3oool08P3oool60?l002@0oooo00<0003o0?ooo`3oool0
E03oool00:d0oooo00<0003o0?ooo`3oool08P3oool40?l002@0oooo00<0
003o0?ooo`3oool0E@3oool00:d0oooo00<0003o0?ooo`3oool08`3oool2
0?l002@0oooo00<0003o0?ooo`3oool0EP3oool00:h0oooo00<0003o0?oo
o`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo
05H0oooo002_0?ooo`030000o`3oool0oooo0280oooo00<000000?ooo`3o
ool08@3oool00`000?l0oooo0?ooo`1G0?ooo`00/03oool00`000?l0oooo
0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0
F03oool00;40oooo0P000?lQ0?ooo`030000003oool0oooo01h0oooo0P00
0?mK0?ooo`00/P3oool00`000?l0oooo0?ooo`0O0?ooo`030000003oool0
oooo01d0oooo00<0003o0?ooo`3oool0F`3oool00;<0oooo00<0003o0?oo
o`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo
05/0oooo002d0?ooo`030000o`3oool0oooo01d0oooo00<000000?ooo`3o
ool0703oool00`000?l0oooo0?ooo`1L0?ooo`00]@3oool00`000?l0oooo
0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool0
G@3oool00;H0oooo0P000?lL0?ooo`030000003oool0oooo01T0oooo0P00
0?mP0?ooo`00^03oool00`000?l0oooo0?ooo`0I0?ooo`030000003oool0
oooo01P0oooo00<0003o0?ooo`3oool0H03oool00;T0oooo00<0003o0?oo
o`3oool0603oool00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo
0640oooo002j0?ooo`80003o603oool00`000000oooo0?ooo`0E0?ooo`80
003oI03oool00;`0oooo0`000?lE0?ooo`030000003oool0oooo01<0oooo
0P000?mV0?ooo`00_`3oool20000oa<0oooo00<000000?ooo`3oool0403o
ool30000ofP0oooo00310?ooo`80003o4@3oool00`000000oooo0?ooo`0>
0?ooo`80003oJ`3oool00<<0oooo1@000?l40?ooo`D000000`3oool00`00
0000oooo0?ooo`090?ooo`D0003oK@3oool00<P0oooo0P000?l40?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool20000og80
oooo003:0?oooa@0003oM03oool00<h0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1k0?ooo`00cP3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo07/0oooo003=0?ooo`8000001@3oool00`00
0000oooo0?ooo`1k0?ooo`00e03oool00`000000oooo0?ooo`1k0?ooo`00
e03oool00`000000oooo0?ooo`1k0?ooo`00e03oool00`000000oooo0?oo
o`1k0?ooo`00e03oool00`000000oooo0?ooo`1k0?ooo`00e03oool00`00
0000oooo0?ooo`1k0?ooo`00e03oool00`000000oooo0?ooo`1k0?ooo`00
e03oool00`000000oooo0?ooo`1k0?ooo`00e03oool00`000000oooo0?oo
o`1k0?ooo`00e03oool00`000000oooo0?ooo`1k0?ooo`00e03oool00`00
0000oooo0?ooo`1k0?ooo`00e03oool00`000000oooo0?ooo`1k0?ooo`00
e03oool00`000000oooo0?ooo`1k0?ooo`00e03oool00`000000oooo0?oo
o`1k0?ooo`00e03oool00`000000oooo0?ooo`1k0?ooo`00e03oool00`00
0000oooo0?ooo`1k0?ooo`00e03oool00`000000oooo0?ooo`1k0?ooo`00
e03oool00`000000oooo0?ooo`1k0?ooo`00e03oool00`000000oooo0?oo
o`1k0?ooo`00e03oool00`000000oooo0?ooo`1k0?ooo`00e03oool00`00
0000oooo0?ooo`1k0?ooo`00e03oool00`000000oooo0?ooo`1k0?ooo`00
e03oool00`000000oooo0?ooo`1k0?ooo`00e03oool00`000000oooo0?oo
o`1k0?ooo`00e03oool00`000000oooo0?ooo`1k0?ooo`00e03oool00`00
0000oooo0?ooo`080?ooo`<00000L03oool00=@0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`1_0?ooo`00e03oool00`000000oooo
0?ooo`0500000080oooo1000001`0?ooo`00e03oool01@000000oooo0?oo
o`3oool000000080oooo00H000000?ooo`3oool000000?ooo`00001a0?oo
o`00e03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo0P00001a0?ooo`00d`3oool20?l000D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1_0?ooo`00dP3oool40?l00080oooo00@0
00000?ooo`3oool00000MP3oool00=40oooo1P3o00000`3oool000000000
0003000007D0oooo003A0?ooo`H0o`00N`3oool00=80oooo103o001l0?oo
o`00d`3oool20?l007d0oooo003D0?ooo`030000003oool0oooo07/0oooo
003D0?ooo`030000003oool0oooo07/0oooo003D0?ooo`030000003oool0
oooo07/0oooo003D0?ooo`030000003oool0oooo07/0oooo003D0?ooo`03
0000003oool0oooo07/0oooo003D0?ooo`030000003oool0oooo07/0oooo
003D0?ooo`030000003oool0oooo07/0oooo003D0?ooo`030000003oool0
oooo07/0oooo003<0?ooo`@00000103oool00`000000oooo0?ooo`1k0?oo
o`00c03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07/0
oooo003=0?ooo`030000003oool0oooo00@0oooo0P00001l0?ooo`00cP3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07/0oooo003<
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0N`3o
ool00<d0oooo0P0000050?ooo`030000003oool0oooo07/0oooo003D0?oo
o`030000003oool0oooo07/0oooo003D0?ooo`030000003oool0oooo07/0
oooo003o0?oooe<0oooo003o0?oooe<0oooo003o0?oooe<0oooo003o0?oo
oe<0oooo003o0?oooe<0oooo003o0?oooe<0oooo003o0?oooe<0oooo003B
0?ooo`800000OP3oool00=<0oooo00<000000?ooo`3oool0O03oool00=@0
oooo00<000000?ooo`3oool0N`3oool00=<0oooo00<000000?ooo`000000
O03oool00=80oooo00@000000?ooo`3oool00000O03oool00=40oooo0`00
00000`3oool000000000001k0?ooo`00o`3ooomC0?ooo`00o`3ooomC0?oo
o`00o`3ooomC0?ooo`00o`3ooomC0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{338, 228},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  Using Substitutions ",
  StyleBox["(8-4)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(8-5)",
    FontColor->RGBColor[0, 0, 1]],
  ", we transform the integral to  \n\n\t\t\t",
  Cell[BoxData[
      \(\[ContourIntegral]\_\(\(\ \)\(\(C\_1\%+\) \((0)\)\)\)\ \(1\/\(1 + 
                  3 \((\(z + z\^\(-1\)\)\/2)\)\^2\)\) 
            1\/\(\[ImaginaryI]\ z\)\ \[DifferentialD]z\ \  = \ \ \(\
\[ContourIntegral]\_\(\(\ \)\(\(C\_1\%+\) \((0)\)\)\)\ \(\(-4\)\ \
\[ImaginaryI]\ z\)\/\(3  z\^4 + 10  z\^2 + 3\)\ \[DifferentialD]z\ \  = \ \ \
\[ContourIntegral]\_\(\(\ \)\(\(C\_1\%+\) \((0)\)\)\)\ 
            f \((z)\)\ \[DifferentialD]z\)\)]],
  "\n\nwhere  ",
  Cell[BoxData[
      \(f \((z)\) = \(\(-4\)\ \[ImaginaryI]\ z\)\/\(3  z\^4 + 10  z\^2 + \
3\)\)]],
  ".  The singularities of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " are poles located at the points where  ",
  Cell[BoxData[
      \(3  z\^4 + 10  z\^2 + 3 = 0\)]],
  "  or equivalently, where  ",
  Cell[BoxData[
      \(3 \((z\^2)\)\^2 + 10  z\^2 + 3 = 0\)]],
  ".  Using the quadratic formula, we see that the singular points satisfy \
the relation  ",
  Cell[BoxData[
      \(z\^2\  = \ \(\(\(-10\) \[PlusMinus] \@\(100 - 36\)\)\/6\  = \ \
\(\(-5\) \[PlusMinus] 4\)\/3\)\)]],
  "  which implies that  ",
  Cell[BoxData[
      \(z\^2\  = 3\)]],
  "  or  ",
  Cell[BoxData[
      \(z\^2 = \(-\(1\/3\)\)\)]],
  ".  Hence the only singularities that lie inside the unit circle are simple \
poles corresponding to the solutions of  ",
  Cell[BoxData[
      \(z\^2 = \(-\(1\/3\)\)\)]],
  ",  which are the two points  ",
  Cell[BoxData[
      \(z\_1 = \(-\(\[ImaginaryI]\/\@3\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(z\_2 = \[ImaginaryI]\/\@3\)]],
  ".  We use Theorem 8.2 and L'H\[OHat]pital's rule to get the residues at ",
  Cell[BoxData[
      \(z\_1\)]],
  " and ",
  Cell[BoxData[
      \(z\_2\)]],
  ":  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, z\_k]\  = \ 
        lim\+\(z\  \[Rule] \ z\_k\)\ \((z - z\_k)\) 
            f \((z)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \
\)\(lim\+\(z\  \[Rule] \ z\_k\)\ \((z - 
                z\_k)\) \(\(-4\)\ \[ImaginaryI]\ z\)\/\(3  z\^4 + 10  z\^2 + \
3\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(lim\+\(z\
\  \[Rule] \ z\_k\)\ \(\(-4\)\ \[ImaginaryI]\ z \((z - z\_k)\)\)\/\(3  z\^4 + \
10  z\^2 + 3\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(lim\+\(z\
\  \[Rule] \ z\_k\)\ \(\(-4\)\ \[ImaginaryI]\ \((z\^2 - \ z\ z\_k)\)\)\/\(3  \
z\^4 + 10  z\^2 + 3\)\ \  = \ \ \(\('\) \(\(0\/0\)'\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(lim\+\(z\
\  \[Rule] \ z\_k\)\ \(\(-4\)\ \[ImaginaryI]\ \((2  z\  - \ z\_k)\)\)\/\(12  \
z\^3 + 20  z\)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(lim\+\(z\
\  \[Rule] \ z\_k\)\ \(\(-4\)\ \[ImaginaryI]\ \((2\ z\_k\  - \ \
z\_k)\)\)\/\(12  z\_k\%3 + 20\ z\_k\)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(\(-\ \
\[ImaginaryI]\)\ 4 
               z\_k\)\/\(\((12  z\_k\%2 + 
                  20)\)\ z\_k\)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(\(-\ \
\[ImaginaryI]\)\ 4\)\/\((12  z\_k\%2 + 
                20)\)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(-\ \
\[ImaginaryI]\)\/\(3  z\_k\%2 + 5\)\)\(\ \ \)\)\)}]],
  "   "
}], "Text"],

Cell[TextData[{
  "\nAs  ",
  Cell[BoxData[
      \(z\_k = \(\[PlusMinus]\(\[ImaginaryI]\/\@3\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(z\_k\%2\  = \ \(-1\)\/3\)]],
  ",  the residues are given by  ",
  Cell[BoxData[
      \(Res[f, 
          z\_k]\  = \ \(Res[
            f, \(\[PlusMinus]\[ImaginaryI]\)\/\@3]\  = \ \(\(-\ \[ImaginaryI]\
\)\/\(3 \((\(-1\)\/3)\) + 5\)\  = \ \(\(-\ \[ImaginaryI]\)\/\(\(-1\) + 5\) = \
\ \(-\(\(\(\ \)\(\[ImaginaryI]\)\)\/4\)\)\)\)\)\)]],
  ".  We now use Equation ",
  StyleBox["(8-6)",
    FontColor->RGBColor[0, 0, 1]],
  " to compute the value of the integral: \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_0\%\(2  \[Pi]\)\(\(\(\ \)\(1\)\)\/\(1\  + \ 
                  3\ \(cos\^2\) \[Theta]\)\) \[DifferentialD]\[Theta]\ \  = \ \
\ 2  \[Pi]\ \[ImaginaryI]\ \((Res[f, z\_1]\  + \ 
              Res[f, z\_2])\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(2  \[Pi]\ \[ImaginaryI]\ \((Res[
                f, \[ImaginaryI]\/\@3]\  + \ 
              Res[f, \(-\[ImaginaryI]\)\/\@3])\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \ \)\(2  \[Pi]\ \[ImaginaryI]\ \((\(-\(\(\(\ \)\(\[ImaginaryI]\
\)\)\/4\)\)\  - \ \(\(\ \)\(\[ImaginaryI]\)\)\/4)\) = \ \ \ 2  \[Pi]\ \
\[ImaginaryI]\ \((\(-\(\(\(\ \)\(\[ImaginaryI]\)\)\/2\)\))\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(=\)\(\ \ \)\(\[Pi]\)\)\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(F[\[Theta]] = \(\(\ \)\(1\)\)\/\(1\  + \ 3\ Cos[\[Theta]]\^2\)\)],
    AspectRatioFixed->True],
  " and use substitution to obtain the complex function f[z].  "
}], "Text"],

Cell[BoxData[{
    \(Z = 0; \ Remove[Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, G, F, Res1, Res2, Res3, Res4, solset, \[Theta], val, 
        z];\)\ \), "\n", 
    \(\(F[\[Theta]_]\  = \(\(\ \)\(1\)\)\/\(1\  + \ 3\ Cos[\[Theta]]\^2\);\)\ \
\), "\n", 
    \(\(f[z_]\  = \ sub[F[\[Theta]], \[Theta]];\)\ \), "\n", 
    \(\(Print["\<F[\[Theta]] = \>", F[\[Theta]]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Locate the singularities of  ",
  Cell[BoxData[
      \(f[
          z] = \(\(-\ 4\)\ \[ImaginaryI]\ z\)\/\(3\ z\^4\  + \ 10\ z\^2\  + \ \
3\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[Denominator[f[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, 
            z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The singularities are\>"];\)\ \), "\n", 
    \(\(Z\_1\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2];\)\ \), "\n", 
    \(\(Z\_3\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3];\)\ \), "\n", 
    \(\(Z\_4\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(4\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", 
        Z\_4];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Find out which singularities lie inside the unit circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_2], Im[Z\_2]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_3], Im[Z\_3]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_4], Im[Z\_4]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] - 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] - 0.1}, {\(-1\), 
                0}], Text[\*"\"\<\!\(z\_3\)\>\"", {Re[Z\_3], 
                Im[Z\_3] - 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_4\)\>\"", {Re[Z\_4], Im[Z\_4] - 0.1}, {\(-1\), 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 1]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-2.1\), 2.1}, {\(-2.1\), 2.1}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<,  Is |\>", 
        Z\_1, "\<| < 1 ?  \>", N[Abs[Z\_1]] < 1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<,   Is |\>", 
        Z\_2, "\<| < 1 ?   \>", N[Abs[Z\_2]] < 1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3, "\<, Is |\>", 
        Z\_3, "\<| < 1 ?  \>", N[Abs[Z\_3]] < 1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", Z\_4, "\<,  Is |\>", 
        Z\_4, "\<| < 1 ?   \>", 
        N[Abs[Z\_4]] < 1];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Compute the residues at  ",
  Cell[BoxData[
      \(z\_1 = \(-\(\[ImaginaryI]\/\@3\)\), \ 
      and\ \ z\_2 = \[ImaginaryI]\/\@3\)]],
  ", and use the residue calculus to compute the value of the integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Res1\  = \ Residue[f[z], {z, Z\_1}];\)\ \), "\n", 
    \(\(Res2\  = \ Residue[f[z], {z, Z\_2}];\)\ \), "\[IndentingNewLine]", 
    \(\(val\  = 
        2\ \[Pi]\ \[ImaginaryI]\ \((Res1\  + \ 
              Res2)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", Z\_1, "\<] = \>", Res1];\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_2, "\<] = \>", 
        Res2];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_2], Im[Z\_2]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] - 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] - 0.1}, {\(-1\), 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 1]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-1.1\), 1.1}, {\(-1.1\), 1.1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], 
            Range[\(-1\), 1, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI]((\>", 
        Res1\ , "\<) + (\>", \ 
        Res2\ , "\<))\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>", 
        Res1\  + \ Res2\ , "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The contour is the circle  C:|z| = 1,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<taken with the positive orientation.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral] \>"\+0\%\(2  \[Pi]\), 
        F[\[Theta]], "\< \[DifferentialD]\[Theta] = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Evaluate  ",
  Cell[BoxData[
      \(\[Integral]\_0\%\(2  \[Pi]\)\(\(\(\ \)\(1\)\)\/\(1\  + \ 
                3\ \(cos\^2\) t\)\) \[DifferentialD]t\)]],
  "  by using a computer algebra system.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Solution.  We can obtain the antiderivative of ",
  Cell[BoxData[
      \(\(\(\ \)\(1\)\)\/\(1\  + \ 3\ \(cos\^2\) t\)\)]],
  " by using software such as Mathematica or MAPLE.  It is   ",
  Cell[BoxData[
      \(\[Integral]\(\(\(\ \)\(1\)\)\/\(1\  + \ 
                  3\ \(cos\^2\) 
                    t\)\) \[DifferentialD]t\ \  = \ \ \(\(-\(1\/2\)\)\ Arctan \
\((\ cot\ t)\)\ \  = \ \ g \((t)\)\)\)]],
  ".  \nSince  ",
  Cell[BoxData[
      \(cot\ 0\)]],
  "  and  ",
  Cell[BoxData[
      \(cot\ 2  \[Pi]\)]],
  "  are not defined, the computations for both ",
  Cell[BoxData[
      \(g \((0)\)\)]],
  " and ",
  Cell[BoxData[
      \(g \((2  \[Pi])\)\)]],
  " are indeterminate.  The graph ",
  Cell[BoxData[
      \(s = g \((t)\)\)]],
  "shown in Figure 8.3 reveals another problem:  \nThe integrand ",
  Cell[BoxData[
      \(\(\(\ \)\(1\)\)\/\(1\  + \ 3\ \(cos\^2\) t\)\)]],
  " is a continuous function for all ",
  StyleBox["t",
    FontFamily->"Courier New"],
  ", but the function ",
  Cell[BoxData[
      \(g \((t)\)\)]],
  " has a discontinuity at ",
  Cell[BoxData[
      \(t = \[Pi]\)]],
  ".  This condition appears to be a violation of the fundamental theorem of \
calculus, which asserts that the integral of a continuous function must be \
differentiable and hence continuous.  The problem is that ",
  Cell[BoxData[
      \(g \((t)\)\)]],
  " is not an antiderivative of ",
  Cell[BoxData[
      \(\(\(\ \)\(1\)\)\/\(1\  + \ 3\ \(cos\^2\) t\)\)]],
  " for all ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " in the interval ",
  Cell[BoxData[
      \(\([0, 2  \[Pi]]\)\)]],
  ".  Oddly, it is the antiderivative at all points except ",
  Cell[BoxData[
      \(0\)]],
  ", ",
  Cell[BoxData[
      \(\[Pi]\)]],
  ", and ",
  Cell[BoxData[
      \(2  \[Pi]\)]],
  ", which you can verify by computing ",
  Cell[BoxData[
      \(g' \((t)\)\)]],
  " and showing that it equals ",
  Cell[BoxData[
      \(\(\(\ \)\(1\)\)\/\(1\  + \ 3\ \(cos\^2\) t\)\)]],
  " whenever ",
  Cell[BoxData[
      \(g \((t)\)\)]],
  " is defined."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000WB000`400?l0
0000o`00003oo`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00
o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00Q@3oool0
0`000000oooo0?ooo`3P0?ooo`00Q@3oool00`000000oooo0?ooo`3P0?oo
o`00Q@3oool00`000000oooo0?ooo`3P0?ooo`00Q@3oool00`000000oooo
0?ooo`3P0?ooo`00Q@3oool00`000000oooo0?ooo`3P0?ooo`00Q@3oool0
0`000000oooo0?ooo`3P0?ooo`00NP3oool3000000P0oooo00<000000?oo
o`3oool0h03oool007/0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`3P0?ooo`00N03oool5000000P0oooo00<000000?ooo`3oool0
h03oool007P0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`3P0?ooo`00N@3oool00`000000oooo000000090?ooo`030000003o
ool0oooo0>00oooo001j0?ooo`8000002@3oool00`000000oooo0?ooo`3P
0?ooo`00Q@3oool00`000000oooo0?ooo`3P0?ooo`00K`3oool4000000<0
oooo200000070?ooo`030?l0o`000000oooo06<0oooo00<0o`3o0?ooo`3o
ool0NP3oool008D0oooo00<000000?l0o`3o0?l0I03oool20?l0ogX0oooo
00250?ooo`030000003oool0oooo0080o`3oI03oool20?l0ogP0oooo0025
0?ooo`030000003oool0oooo0080oooo0P3o0?mT0?ooo`80o`3oMP3oool0
08D0oooo00<000000?ooo`3oool0103oool20?l0of@0oooo0P3o0?md0?oo
o`00M`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool20?l0of@0oooo00<0o`3o0?ooo`3o
ool0L@3oool007P0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`080?ooo`80o`3oH`3oool20?l0og40oooo001i0?ooo`030000
003oool0000000T0oooo00<000000?ooo`3oool02P3oool00`3o0?l0oooo
0?ooo`1R0?ooo`80o`3oK`3oool007T0oooo00<000000?ooo`0000002@3o
ool00`000000oooo0?ooo`0;0?ooo`80o`3oI03oool20?l0ofd0oooo001h
0?ooo`D00000203oool00`000000oooo0?ooo`0=0?ooo`80o`3oI03oool2
0?l0of/0oooo00250?ooo`030000003oool0oooo00l0oooo00<0o`3o0?oo
o`3oool0H`3oool00`3o0?l0oooo0?ooo`1X0?ooo`00Q@3oool00`000000
oooo0?ooo`0@0?ooo`80o`3oI03oool20?l0ofP0oooo00250?ooo`030000
003oool0oooo0180oooo00<0o`3o0?ooo`3oool0H`3oool00`3o0?l0oooo
0?ooo`1U0?ooo`00Q@3oool00`000000oooo0?ooo`0C0?ooo`030?l0o`3o
ool0oooo06<0oooo00<0o`3o0?ooo`3oool0I03oool008D0oooo00<00000
0?ooo`3oool0503oool20?l0of@0oooo0P3o0?mT0?ooo`00Q@3oool00`00
0000oooo0?ooo`0F0?ooo`030?l0o`3oool0oooo06<0oooo00<0o`3o0?oo
o`3oool0H@3oool008D0oooo00<000000?ooo`3oool05`3oool20?l0of@0
oooo00<0o`3o0?ooo`3oool0H03oool008D0oooo00<000000?ooo`3oool0
6@3oool20?l0of<0oooo0P3o0?mP0?ooo`00Q@3oool00`000000oooo0?oo
o`0K0?ooo`030?l0o`3oool0oooo0680oooo00<0o`3o0?ooo`3oool0G@3o
ool008D0oooo00<000000?ooo`3oool0703oool00`3o0?l0oooo0?ooo`1R
0?ooo`030?l0o`3oool0oooo05`0oooo00250?ooo`030000003oool0oooo
01d0oooo00<0o`3o0?ooo`3oool0HP3oool00`3o0?l0oooo0?ooo`1K0?oo
o`00Q@3oool00`000000oooo0?ooo`0M0?ooo`030?l0o`3oool0oooo06<0
oooo00<0o`3o0?ooo`3oool0FP3oool008D0oooo00<000000?ooo`3oool0
7P3oool00`3o0?l0oooo0?ooo`1S0?ooo`030?l0o`3oool0oooo05T0oooo
00250?ooo`030000003oool0oooo01l0oooo00<0o`3o0?ooo`3oool0H`3o
ool00`3o0?l0oooo0?ooo`1H0?ooo`00Q@3oool00`000000oooo0?ooo`0P
0?ooo`030?l0o`3oool0oooo06<0oooo00<0o`3o0?ooo`3oool0E`3oool0
08D0oooo00<000000?ooo`3oool08@3oool00`3o0?l0oooo0?ooo`1S0?oo
o`030?l0o`3oool0oooo05H0oooo00250?ooo`030000003oool0oooo0240
oooo00<0o`3o0?ooo`3oool0H`3oool00`3o0?l0oooo0?ooo`1F0?ooo`00
Q@3oool00`000000oooo0?ooo`0R0?ooo`030?l0o`3oool0oooo06<0oooo
00<0o`3o0?ooo`3oool0E@3oool008D0oooo00<000000?ooo`3oool08`3o
ool00`3o0?l0oooo0?ooo`1S0?ooo`030?l0o`3oool0oooo05@0oooo0025
0?ooo`030000003oool0oooo02@0oooo00<0o`3o0?ooo`3oool0H`3oool0
0`3o0?l0oooo0?ooo`060?ooo`@00000B@3oool008D0oooo00<000000?oo
o`3oool0903oool00`3o0?l0oooo0?ooo`1S0?ooo`030?l0o`3oool0oooo
00H0oooo00<000000?ooo`3oool0BP3oool008D0oooo00<000000?ooo`3o
ool09@3oool00`3o0?l0oooo0?ooo`060?ooo`@00000F@3oool00`3o0?l0
oooo0?ooo`060?ooo`030000003oool0oooo04T0oooo00250?ooo`030000
003oool0oooo02H0oooo00<0o`3o0?ooo`3oool01@3oool00`000000oooo
0?ooo`1K0?ooo`030?l0o`3oool0oooo00H0oooo00<000000?ooo`3oool0
B03oool008D0oooo00<000000?ooo`3oool09P3oool00`3o0?l0oooo0?oo
o`060?ooo`030000003oool0oooo05X0oooo00<0o`3o0?ooo`3oool0103o
ool010000000oooo0?ooo`0000190?ooo`00Q@3oool00`000000oooo0?oo
o`0W0?ooo`030?l0o`3oool0oooo00H0oooo00<000000?ooo`3oool0FP3o
ool00`3o0?l0oooo0?ooo`040?ooo`800000BP3oool008D0oooo00<00000
0?ooo`3oool0:03oool00`3o0?l0oooo0?ooo`030?ooo`040000003oool0
oooo000005/0oooo00<0o`3o0?ooo`3oool0D03oool008D0oooo00<00000
0?ooo`3oool0:03oool00`3o0?l0oooo0?ooo`040?ooo`800000G03oool0
0`000000o`3o00000009000000030?ooo`000000000000800000@P3oool0
08D0oooo00<000000?ooo`3oool0:@3oool00`3o0?l0oooo0?ooo`1R0?oo
o`030?l0o`3oool0oooo04l0oooo00250?ooo`030000003oool0oooo02T0
oooo00<0o`3o0?ooo`0000000`0000000`3oool0000000000002000005/0
oooo00<0o`3o0?ooo`3oool0CP3oool008D0oooo00<000000?ooo`3oool0
:P3oool00`3o0?l0oooo0?ooo`0c0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool09`3oool00`3o0?l0oooo0?ooo`0`0?ooo`@00000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo
00250?ooo`030000003oool0oooo02/0oooo00<0o`3o0?ooo`3oool0<`3o
ool010000000oooo0?ooo`00000[0?ooo`030?l0o`3oool0oooo02l0oooo
00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00000A0?ooo`00
Q@3oool00`000000oooo0?ooo`0[0?ooo`030?l0o`3oool0oooo03@0oooo
00<000000?ooo`000000:`3oool00`3o0?l000000?ooo`040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`060?ooo`030000003oool000000140oooo00250?ooo`030000003o
ool0oooo02`0oooo00<0o`3o0?ooo`3oool0<`3oool00`000000oooo0000
000Z0?ooo`040000003oool0o`3o000000D0oooo00@000000?ooo`3oool0
0000:03oool00`000000oooo0?ooo`050?ooo`030000003oool000000140
oooo00250?ooo`030000003oool0oooo02d0oooo00<0o`3o0?ooo`3oool0
0P3oool00`000000oooo0?ooo`0/0?ooo`D00000:`3oool00`000000o`3o
0?ooo`050?ooo`030000003oool0000002H0oooo00@000000?ooo`3oool0
00001@3oool500000100oooo00250?ooo`030000003oool0oooo02d0oooo
00D0o`3o0000003oool0oooo0000001P0?ooo`030?l0o`3oool0oooo00@0
oooo00<000000?ooo`0000009`3oool2000001/0oooo00250?ooo`030000
003oool0oooo02h0oooo00@0o`3o0000003oool00000G@3oool01@000000
oooo0?ooo`000000o`3o00@0oooo1@0000130?ooo`00Q@3oool00`000000
oooo0?ooo`0^0?ooo`040?l0o`000000oooo000005h0oooo0P0000000`3o
ool0o`3o0?ooo`1;0?ooo`00Q@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003o0?l0000000800000H@3oool00`3o0?l0oooo0?ooo`190?ooo`00
Q@3oool00`000000oooo0?ooo`0_0?ooo`030?l0o`3oool0oooo0680oooo
00<0o`3o0?ooo`3oool0>P3oool3000000`0oooo00250?ooo`030000003o
ool0oooo0300oooo00<0o`3o0?ooo`3oool0HP3oool00`3o0?l0oooo0?oo
o`0h0?ooo`050000003oool0oooo0?ooo`0000002`3oool008D0oooo<`00
00000`3o0?l000000000001S000000030?l0o`0000000000030000001`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0025
0?ooo`030000003oool0oooo0300oooo00<000000?l0o`3oool0<03oool0
0`000000oooo0?ooo`0`0?ooo`030?l0o`3oool0oooo02l0oooo00<00000
0?ooo`3oool01@3oool6000000X0oooo00250?ooo`030000003oool0oooo
0340oooo00<0o`3o0?ooo`3oool0H`3oool00`3o0?l0oooo0?ooo`0g0?oo
o`050000003oool0oooo0?ooo`0000002P3oool008D0oooo00<000000?oo
o`3oool0<P3oool00`3o0?l0oooo0?ooo`1R0?ooo`030?l0o`3oool0oooo
03P0oooo0`00000;0?ooo`00Q@3oool00`000000oooo0?ooo`0b0?ooo`03
0?l0o`3oool0oooo06<0oooo00<0o`3o0?ooo`3oool0A@3oool008D0oooo
00<000000?ooo`3oool0<`3oool00`3o0?l0oooo0?ooo`1R0?ooo`030?l0
o`3oool0oooo04D0oooo00250?ooo`030000003oool0oooo03<0oooo00<0
o`3o0?ooo`3oool0H`3oool00`3o0?l0oooo0?ooo`140?ooo`00Q@3oool0
0`000000oooo0?ooo`0d0?ooo`030?l0o`3oool0oooo0680oooo00<0o`3o
0?ooo`3oool0A03oool008D0oooo00<000000?ooo`3oool0=03oool00`3o
0?l0oooo0?ooo`1S0?ooo`030?l0o`3oool0oooo04<0oooo00250?ooo`03
0000003oool0oooo03D0oooo00<0o`3o0?ooo`3oool0H`3oool00`3o0?l0
oooo0?ooo`120?ooo`00Q@3oool00`000000oooo0?ooo`0e0?ooo`030?l0
o`3oool0oooo06<0oooo00<0o`3o0?ooo`3oool0@P3oool008D0oooo00<0
00000?ooo`3oool0=P3oool00`3o0?l0oooo0?ooo`1S0?ooo`030?l0o`3o
ool0oooo0440oooo00250?ooo`030000003oool0oooo03H0oooo00<0o`3o
0?ooo`3oool0H`3oool00`3o0?l0oooo0?ooo`110?ooo`00Q@3oool00`00
0000oooo0?ooo`0g0?ooo`030?l0o`3oool0oooo06<0oooo00<0o`3o0?oo
o`3oool0@03oool008D0oooo00<000000?ooo`3oool0=`3oool00`3o0?l0
oooo0?ooo`1S0?ooo`030?l0o`3oool0oooo0400oooo00250?ooo`030000
003oool0oooo03P0oooo00<0o`3o0?ooo`3oool0H`3oool00`3o0?l0oooo
0?ooo`0o0?ooo`00Q@3oool00`000000oooo0?ooo`0i0?ooo`030?l0o`3o
ool0oooo06<0oooo00<0o`3o0?ooo`3oool0?P3oool008D0oooo00<00000
0?ooo`3oool0>P3oool00`3o0?l0oooo0?ooo`1R0?ooo`030?l0o`3oool0
oooo03h0oooo00250?ooo`030000003oool0oooo03X0oooo00<0o`3o0?oo
o`3oool0H`3oool00`3o0?l0oooo0?ooo`0m0?ooo`00Q@3oool00`000000
oooo0?ooo`0k0?ooo`030?l0o`3oool0oooo06<0oooo00<0o`3o0?ooo`3o
ool0?03oool008D0oooo00<000000?ooo`3oool0?03oool00`3o0?l0oooo
0?ooo`1R0?ooo`030?l0o`3oool0oooo03`0oooo00250?ooo`030000003o
ool0oooo03d0oooo00<0o`3o0?ooo`3oool0HP3oool00`3o0?l0oooo0?oo
o`0k0?ooo`00Q@3oool00`000000oooo0?ooo`0n0?ooo`030?l0o`3oool0
oooo0680oooo00<0o`3o0?ooo`3oool0>P3oool008D0oooo00<000000?oo
o`3oool0?P3oool00`3o0?l0oooo0?ooo`1S0?ooo`030?l0o`3oool0oooo
03T0oooo00250?ooo`030000003oool0oooo03l0oooo00<0o`3o0?ooo`3o
ool0HP3oool00`3o0?l0oooo0?ooo`0i0?ooo`00Q@3oool00`000000oooo
0?ooo`100?ooo`030?l0o`3oool0oooo0680oooo00<0o`3o0?ooo`3oool0
>03oool008D0oooo00<000000?ooo`3oool0@03oool00`3o0?l0oooo0?oo
o`1S0?ooo`030?l0o`3oool0oooo03L0oooo00250?ooo`030000003oool0
oooo0440oooo00<0o`3o0?ooo`3oool0H`3oool00`3o0?l0oooo0?ooo`0f
0?ooo`00Q@3oool00`000000oooo0?ooo`120?ooo`030?l0o`3oool0oooo
06<0oooo00<0o`3o0?ooo`3oool0=@3oool008D0oooo00<000000?ooo`3o
ool0@`3oool00`3o0?l0oooo0?ooo`1S0?ooo`030?l0o`3oool0oooo03@0
oooo00250?ooo`030000003oool0oooo04@0oooo00<0o`3o0?ooo`3oool0
H`3oool00`3o0?l0oooo0?ooo`0c0?ooo`00Q@3oool00`000000oooo0?oo
o`150?ooo`030?l0o`3oool0oooo06<0oooo00<0o`3o0?ooo`3oool0<P3o
ool008D0oooo00<000000?ooo`3oool0AP3oool00`3o0?l0oooo0?ooo`1S
0?ooo`030?l0o`3oool0oooo0340oooo00250?ooo`030000003oool0oooo
04L0oooo0P3o0?mT0?ooo`80o`3o<@3oool008D0oooo00<000000?ooo`3o
ool0B@3oool00`3o0?l0oooo0?ooo`1S0?ooo`030?l0o`3oool0oooo02h0
oooo00250?ooo`030000003oool0oooo04X0oooo00<0o`3o0?ooo`3oool0
H`3oool00`3o0?l0oooo0?ooo`0]0?ooo`00Q@3oool00`000000oooo0?oo
o`1;0?ooo`80o`3oI03oool20?l0obd0oooo00250?ooo`030000003oool0
oooo04d0oooo00<0o`3o0?ooo`3oool0H`3oool00`3o0?l0oooo0?ooo`0Z
0?ooo`00Q@3oool00`000000oooo0?ooo`1>0?ooo`80o`3oI03oool20?l0
obX0oooo00250?ooo`030000003oool0oooo0500oooo0P3o0?mT0?ooo`80
o`3o:03oool008D0oooo00<000000?ooo`3oool0DP3oool00`3o0?l0oooo
0?ooo`1S0?ooo`030?l0o`3oool0oooo02D0oooo00250?ooo`030000003o
ool0oooo05<0oooo00<0o`3o0?ooo`3oool0H`3oool00`3o0?l0oooo0?oo
o`0T0?ooo`00NP3oool3000000P0oooo00<000000?ooo`3oool0E03oool2
0?l0of@0oooo0P3o0?lT0?ooo`00N`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo05H0oooo00<0o`3o0?ooo`3oool0H`3oool00`3o
0?l0oooo0?ooo`0Q0?ooo`00N03oool5000000P0oooo00<000000?ooo`3o
ool0E`3oool20?l0of@0oooo0P3o0?lQ0?ooo`00N03oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo05T0oooo0`3o0?mS0?ooo`80
o`3o7`3oool007T0oooo00<000000?ooo`0000002@3oool00`000000oooo
0?ooo`1L0?ooo`80o`3oH`3oool20?l0oad0oooo001j0?ooo`8000002@3o
ool00`000000oooo0?ooo`1N0?ooo`80o`3oH`3oool20?l0oa/0oooo0025
0?ooo`030000003oool0oooo0600oooo0P3o0?mS0?ooo`80o`3o6@3oool0
07H0oooo200000070?ooo`800000H`3oool20?l0of<0oooo0P3o0?lG0?oo
o`00Q@3oool00`000000oooo0?ooo`3P0?ooo`00Q@3oool00`000000oooo
0?ooo`3P0?ooo`00Q@3oool00`000000oooo0?ooo`3P0?ooo`00Q@3oool0
0`000000oooo0?ooo`3P0?ooo`00M`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0h03oool007P0
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`3P0?oo
o`00N@3oool00`000000oooo000000090?ooo`030000003oool0oooo0>00
oooo001i0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0
h03oool007P0oooo1@0000080?ooo`030000003oool0oooo0>00oooo0025
0?ooo`030000003oool0oooo0>00oooo00250?ooo`030000003oool0oooo
0>00oooo00250?ooo`030000003oool0oooo0>00oooo00250?ooo`030000
003oool0oooo0>00oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?oo
ofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o
0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo00230?ooo`<00000
hP3oool008H0oooo00<000000?ooo`3oool0g`3oool008<0oooo0`00003R
0?ooo`00P`3oool400000>40oooo003o0?ooofT0oooo003o0?ooofT0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0
oooo003o0?ooofT0oooo003o0?ooofT0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{360, 157},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 8.3",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/integralstrigonometric/\
IntegralsTrigFigures/mat0803.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Graph of  ",
  Cell[BoxData[
      \(g \((t)\) = \(\[Integral]\(\(\(\ \)\(1\)\)\/\(1\  + \ 
                    3\ \(cos\^2\) 
                      t\)\) \[DifferentialD]t\ \  = \ \ \(-\(1\/2\)\)\ Arctan \
\((\ cot\ t)\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe integration algorithm used by computer algebra systems here (the \
Risch-Norman algorithm) gives the antiderivative  ",
  Cell[BoxData[
      \(g \((t)\)\  = \ \(-\(1\/2\)\)\ Arctan \((\ cot\ t)\)\)]],
  ",  and we must take great care in using this information.  We get the \
proper value of the integral by using ",
  Cell[BoxData[
      \(g \((t)\)\)]],
  " on the open subintervals ",
  Cell[BoxData[
      \(\((0, \[Pi])\)\)]],
  " and ",
  Cell[BoxData[
      \(\((0, 2  \[Pi])\)\)]],
  " where it is continuous, and taking appropriate limits:   \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_0\%\(2  \[Pi]\)\(\(\(\ \)\(1\)\)\/\(1\  + \ 
                  3\ \(cos\^2\) 
                    t\)\) \[DifferentialD]t\ \  = \ \ \[Integral]\_0\%\[Pi]\(\
\(\(\ \)\(1\)\)\/\(1\  + \ 
                    3\ \(cos\^2\) 
                      t\)\) \[DifferentialD]t\ \  + \ \ \
\[Integral]\_\[Pi]\%\(2  \[Pi]\)\(\(\(\ \)\(1\)\)\/\(1\  + \ 
                    3\ \(cos\^2\) 
                      t\)\) \[DifferentialD]t\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(\(\(lim\+\ \)\+\(t \[Rule] \(\[Pi]\^-\)\)\)\+\(s \[Rule] \
\(0\^+\)\)\ \[Integral]\_s\%t\(\(\(\ \)\(1\)\)\/\(1\  + \ 
                      3\ \(cos\^2\) 
                        t\)\) \[DifferentialD]t\ \  + \ \ \ \(\(lim\+\ \
\)\+\(t \[Rule] 2 \( \[Pi]\^-\)\)\)\+\(s \[Rule] \(\[Pi]\^+\)\)\ \
\[Integral]\_s\%t\(\(\(\ \)\(1\)\)\/\(1\  + \ 
                      3\ \(cos\^2\) 
                        t\)\) \[DifferentialD]t\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(lim\+\(t \[Rule] \(\[Pi]\^-\)\)\ g \((t)\)\  - \ 
          lim\+\(s \[Rule] \(0\^+\)\)\ g \((s)\) + \ 
          lim\+\(t \[Rule] 2 \( \[Pi]\^-\)\)\ g \((t)\)\  - \ 
          lim\+\(s \[Rule] \(\[Pi]\^+\)\)\ 
            g \((s)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(\[Pi]\/4\ \  - \ \ \(-\[Pi]\)\/4\ \  + \ \ \[Pi]\/4\ \  - \
\(-\[Pi]\)\/4\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(=\)\(\ \ \)\(\[Pi]\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(F[\[Theta]] = \(\(\ \)\(1\)\)\/\(1\  + \ 3\ Cos[\[Theta]]\^2\)\)],
    AspectRatioFixed->True],
  " and use substitution to obtain the complex function f[z].  "
}], "Text"],

Cell[BoxData[{
    \(Z = 0; \ Remove[Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, G, F, Res1, Res2, Res3, Res4, solset, \[Theta], val, 
        z];\)\ \), "\n", 
    \(\(F[\[Theta]_]\  = \(\(\ \)\(1\)\)\/\(1\  + \ 3\ Cos[\[Theta]]\^2\);\)\ \
\), "\n", 
    \(\(f[z_]\  = \ sub[F[\[Theta]], \[Theta]];\)\ \), "\n", 
    \(\(Print["\<F[\[Theta]] = \>", F[\[Theta]]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  is capable of finding some of these difficult integrals.  The function  \
",
  Cell[BoxData[
      \(F[\[Theta]] = \(\(\ \)\(1\)\)\/\(1\  + \ 3\ Cos[\[Theta]]\^2\)\)],
    AspectRatioFixed->True],
  "  can be integrated."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(G[\[Theta]_]\  = \ \[Integral]F[\[Theta]] \[DifferentialD]\[Theta];\)\
\ \), "\n", 
    \(\(val\  = \ \[Integral]\_0\%\(2  \[Pi]\)F[\[Theta]] \[DifferentialD]\
\[Theta];\)\ \), "\n", 
    \(\(Print["\<G[\[Theta]] = \[Integral] \>", 
        F[\[Theta]], "\< \[DifferentialD]\[Theta] = \>", 
        G[\[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<\[Integral] \>"\+0\%\(2  \[Pi]\), 
        F[\[Theta]], "\< \[DifferentialD]\[Theta] = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral] \>"\+0\%\(2  \[Pi]\), 
        F[\[Theta]], "\< \[DifferentialD]\[Theta] = \>", 
        ComplexExpand[val]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "However, direct substitution using  ",
  Cell[BoxData[
      \(G[\[Theta]]\)]],
  "  and the endpoints of the interval seems to be ",
  StyleBox["erroneous",
    FontColor->RGBColor[1, 0, 1]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<        G[0] = \>", G[0]];\)\ \), "\n", 
    \(\(Print["\<       G[2\[Pi]] = \>", G[2  \[Pi]]];\)\ \), "\n", 
    \(\(Print["\<G[2\[Pi]] - G[0] = \>", 
        G[2  \[Pi]] - G[0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "This is due to the fact that  ",
  Cell[BoxData[
      \(cot \((0)\), \ cot \((\[Pi])\), \ and\ \ cot \((2  \[Pi])\)\)]],
  "  are undefined.  A graph of  ",
  Cell[BoxData[
      \(G[\[Theta]]\)]],
  "  reveals that it has a discontinuity at  ",
  Cell[BoxData[
      \(\[Theta] = \[Pi]\)]],
  "  in the middle of the interval  ",
  Cell[BoxData[
      \(\([0, 2  \[Pi]]\)\)]],
  ".  This is a violation of the Fundamental Theorem of Calculus, which \
asserts that the integral of a continuous function must be continuous. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[G[\[Theta]], {\[Theta], 0, \[Pi]}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = 
        Plot[G[\[Theta]], {\[Theta], \[Pi], 2  \[Pi]}, 
          PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, 
        PlotRange \[Rule] {{0, 2  \[Pi]}, {\(-1\), 
              1}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 
              2  \[Pi], \[Pi]\/2], 
            Range[\(-\[Pi]\)\/4, \[Pi]\/4, \[Pi]\/2]}, \
\[IndentingNewLine]AxesLabel \[Rule] {"\<\[Theta]\>", "\<s\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), "\n", 
    \(\(Print["\<s = \>", G[\[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The indefinite integrand  ",
  Cell[BoxData[
      \(G[\[Theta]]\)]],
  "  can be used piecewise over  ",
  Cell[BoxData[
      \(\((0, \[Pi])\)\ \ and\ \ \((\[Pi], 2  \[Pi])\)\)]],
  "  where it is continuous, by using the left and right hand limits at the \
endpoints. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(lim1 = 
        Limit[G[\[Theta]], \[Theta] \[Rule] \[Pi], \ \ \ Direction \[Rule] 
            1];\)\ \), "\[IndentingNewLine]", 
    \(\(lim2 = 
        Limit[G[\[Theta]], \[Theta] \[Rule] 
            0, \ \ \ \ Direction \[Rule] \(-1\)];\)\ \), \
"\[IndentingNewLine]", 
    \(\(lim3 = 
        Limit[G[\[Theta]], \[Theta] \[Rule] 2  \[Pi], 
          Direction \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(lim4 = 
        Limit[G[\[Theta]], \[Theta] \[Rule] \[Pi], \ \ \ Direction \[Rule] \
\(-1\)];\)\ \), "\[IndentingNewLine]", 
    \(\(val\  = \ \((lim1\  - lim2)\)\  + \ \((lim3\  - \ 
              lim4)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(\[Theta] \[Rule] \(\[Pi]\^-\)\)\) (\>\"", 
        G[\[Theta]], "\<) = \>", lim1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(\[Theta] \[Rule] \(\[Pi]\^+\)\)\) (\>\"", 
        G[\[Theta]], "\<) = \>", lim2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(\[Theta] \[Rule] 2 \( \[Pi]\^-\)\)\) (\>\"", 
        G[\[Theta]], "\<) = \>", lim3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(\[Theta] \[Rule] 2 \( \[Pi]\^+\)\)\) (\>\"", 
        G[\[Theta]], "\<) = \>", lim4];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral] \>"\+0\%\(2  \[Pi]\), 
        F[\[Theta]], "\< \[DifferentialD]\[Theta] = (\>", lim1\ , "\< - (\>", 
        lim2, "\<)) + (\>", lim3\ , "\< - (\>", 
        lim4, "\<))\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<\[Integral] \>"\+0\%\(2  \[Pi]\), 
        F[\[Theta]], "\< \[DifferentialD]\[Theta] = \>", \((lim1\  - 
            lim2)\), "\< + \>", \((lim3\  - \ lim4)\), "\< = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The above answer is correct too.  Limits were required because  ",
  Cell[BoxData[
      \(G[\[Theta]]\)]],
  "  is not continuous at  ",
  Cell[BoxData[
      \(\[Pi] = 0, \[Pi]\ \ and\ \ 2  \[Pi]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "    Evaluate  ",
  Cell[BoxData[
      \(\[Integral]\_0\%\(2  \[Pi]\)\(\(\(\ \)\(cos \((2  \
\[Theta])\)\)\)\/\(5\  - \ 
                4\ cos \((\[Theta])\)\)\) \(\(\[DifferentialD]\[Theta]\)\(\ \
\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005F0000WB000`400?l0
0000o`00003oo`3ooomG0?ooo`00o`3ooomG0?ooo`00o`3ooomG0?ooo`00
o`3ooomG0?ooo`00o`3ooomG0?ooo`00o`3ooomG0?ooo`00]03oool00`00
0000oooo0?ooo`2O0?ooo`00]03oool00`000000oooo0?ooo`2O0?ooo`00
]03oool00`000000oooo0?ooo`2O0?ooo`00]03oool00`000000oooo0?oo
o`2O0?ooo`00[03oool5000000<0oooo00<000000?ooo`3oool0W`3oool0
0:h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2O0?oo
o`00[P3oool<0000oi`0oooo002V0?ooo`8000001P000?l00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo1P000?nF0?ooo`00X`3o
ool50000o`H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`090?ooo`H0003oT03oool00:00oooo0`000?l:0?ooo`8000001@3oool0
0`000000oooo0?ooo`0?0?ooo`<0003oS@3oool009h0oooo0P000?lD0?oo
o`030000003oool0oooo0180oooo0P000?n;0?ooo`00W03oool20000oaH0
oooo00<000000?ooo`3oool0503oool20000ohT0oooo002J0?ooo`80003o
603oool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo08H0oooo
002H0?ooo`80003o6P3oool00`000000oooo0?ooo`0G0?ooo`<0003oQ@3o
ool009H0oooo0P000?lL0?ooo`030000003oool0oooo01X0oooo0P000?n3
0?ooo`00U03oool20000oah0oooo00<000000?ooo`3oool0703oool20000
oh40oooo002C0?ooo`030000o`3oool0oooo01h0oooo00<000000?ooo`3o
ool07P3oool00`000?l0oooo0?ooo`1n0?ooo`00TP3oool00`000?l0oooo
0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0
O@3oool00900oooo0P000?lR0?ooo`030000003oool0oooo0200oooo00<0
003o0?ooo`3oool0O03oool008h0oooo0P000?lT0?ooo`030000003oool0
oooo0240oooo0P000?ml0?ooo`00S@3oool00`000?l0oooo0?ooo`0T0?oo
o`030000003oool0oooo02<0oooo0P000?mj0?ooo`00S03oool00`000?l0
oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3o
ool0M`3oool008/0oooo00<0003o0?ooo`3oool09P3oool00`000000oooo
0?ooo`0V0?ooo`030000o`3oool0oooo07H0oooo002:0?ooo`030000o`3o
ool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?oo
o`1e0?ooo`00R@3oool00`000?l0oooo0?ooo`0X0?ooo`030000003oool0
oooo02P0oooo00<0003o0?ooo`3oool0M03oool008T0oooo00<0003o0?oo
o`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo
07@0oooo00280?ooo`030000o`3oool0oooo02T0oooo00<000000?ooo`3o
ool0:@3oool00`000?l0oooo0?ooo`1c0?ooo`00Q`3oool00`000?l0oooo
0?ooo`0Z0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0
LP3oool008H0oooo00<0003o0?ooo`3oool0:`3oool00`000000oooo0?oo
o`0[0?ooo`030000o`3oool0oooo0740oooo00250?ooo`030000o`3oool0
oooo02`0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`1`
0?ooo`00Q03oool00`000?l0oooo0?ooo`0]0?ooo`030000003oool0oooo
02d0oooo00<0003o0?ooo`3oool0K`3oool008<0oooo00<0003o0?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo06h0
oooo00230?ooo`030000o`3oool0oooo02h0oooo00<000000?ooo`3oool0
;P3oool00`000?l0oooo0?ooo`1^0?ooo`00PP3oool00`000?l0oooo0?oo
o`0_0?ooo`030000003oool0oooo02l0oooo00<0003o0?ooo`3oool0K@3o
ool00840oooo00<0003o0?ooo`3oool0<03oool00`000000oooo0?ooo`0_
0?ooo`030000o`3oool0oooo06d0oooo00200?ooo`030000o`3oool0oooo
0340oooo00<000000?ooo`3oool0<03oool00`000?l0oooo0?ooo`1/0?oo
o`00P03oool00`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo0340
oooo00<0003o0?ooo`3oool0J`3oool007l0oooo00<0003o0?ooo`3oool0
<P3oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo06/0oooo
001o0?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0<P3o
ool00`000?l0oooo0?ooo`1Z0?ooo`00OP3oool00`000?l0oooo0?ooo`0c
0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3oool0JP3oool0
07d0oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?oo
o`030000o`3oool0oooo06T0oooo001m0?ooo`030000o`3oool0oooo03@0
oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`1Y0?ooo`00
O03oool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo03@0oooo
00<0003o0?ooo`3oool0J03oool007`0oooo00<0003o0?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo06P0oooo001l
0?ooo`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0=@3oool0
0`000?l0oooo0?ooo`1W0?ooo`00N`3oool00`000?l0oooo0?ooo`0f0?oo
o`030000003oool0oooo03D0oooo00<0003o0?ooo`3oool0I`3oool007/0
oooo00<0003o0?ooo`3oool0=P3oool00`000000oooo0?ooo`0f0?ooo`03
0000o`3oool0oooo06H0oooo001k0?ooo`030000o`3oool0oooo03H0oooo
00<000000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`1V0?ooo`00NP3o
ool00`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo03H0oooo00<0
003o0?ooo`3oool0IP3oool007X0oooo00<0003o0?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0f0?ooo`030000o`3oool0oooo06H0oooo001j0?oo
o`030000o`3oool0oooo03L0oooo00<000000?ooo`3oool0=P3oool00`00
0?l0oooo0?ooo`1V0?ooo`00N@3oool00`000?l0oooo0?ooo`0h0?ooo`03
0000003oool0oooo03L0oooo00<0003o0?ooo`3oool0I@3oool007T0oooo
00<0003o0?ooo`3oool0>03oool00`000000oooo0?ooo`0g0?ooo`030000
o`3oool0oooo06D0oooo001i0?ooo`030000o`3oool0oooo03P0oooo00<0
00000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`1U0?ooo`00N@3oool0
0`000?l0oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo00<0003o
0?ooo`3oool0I03oool007T0oooo00<0003o0?ooo`3oool0>03oool00`00
0000oooo0?ooo`0h0?ooo`030000o`3oool0oooo06@0oooo001h0?ooo`03
000000000?l0000000800000=`3oool00`000000oooo0?ooo`0g0?ooo`03
000000000?l0000000800000>03oool4000002L0oooo001h0?ooo`030000
o`3oool0000003T0oooo00<000000?ooo`3oool0>03oool00`000?l00000
0?ooo`0i0?ooo`030000003oool0oooo02P0oooo001h0?ooo`030000o`3o
ool0000003T0oooo00<000000?ooo`3oool0>03oool00`000?l000000?oo
o`0j0?ooo`030000003oool0oooo02L0oooo001b0?ooo`@000000P3oool0
0`000?l0oooo0000000i0?ooo`030000003oool0oooo03P0oooo00<0003o
0000003oool0>`3oool00`000000oooo0?ooo`0V0?ooo`00N03oool00`00
0?l0oooo0000000i0?ooo`030000003oool0oooo03T0oooo00<0003o0?oo
o`3oool0>03oool010000000oooo0?ooo`00000W0?ooo`00N03oool00`00
0?l000000000000i0?ooo`030000003oool0oooo03P0oooo00<000000000
o`3oool0>P3oool2000002P0oooo001h0?ooo`030000o`3oool0oooo03T0
oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`1S0?ooo`00
N03oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo
00<0003o0?ooo`3oool0H`3oool007P0oooo00<0003o0?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo06<0oooo001h
0?ooo`030000o`3oool0oooo03L0oooo0`3o000L0?ooo`<0o`00703oool0
0`000?l0oooo0?ooo`0h0?ooo`<0o`004P3oool2000000030?ooo`000000
00000140oooo001g0?ooo`030000o`3oool0oooo03L0oooo1@3o000J0?oo
o`D0o`006`3oool00`000?l0oooo0?ooo`0g0?ooo`D0o`004P3oool00`00
0000oooo0000000B0?ooo`00L@3oool6000000030000o`000000000003L0
00001@3o000J000000D0o`006`0000000`000?l000000000000g000000D0
o`002`0000080?ooo`030000003oool0oooo0140oooo001g0?ooo`030000
o`3oool0oooo03L0oooo1@3o000J0?ooo`D0o`006`3oool00`000?l0oooo
0?ooo`0g0?ooo`D0o`004@3oool2000000030?ooo`00000000000140oooo
001h0?ooo`030000o`3oool0oooo03L0oooo0`3o000L0?ooo`<0o`00703o
ool00`000?l0oooo0?ooo`0h0?ooo`<0o`00:03oool007P0oooo00<0003o
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0
oooo06<0oooo001h0?ooo`030000o`3oool0oooo03T0oooo00<000000?oo
o`3oool0>@3oool00`000?l0oooo0?ooo`1S0?ooo`00N03oool00`000?l0
oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<0003o0?ooo`3o
ool0H`3oool007P0oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo
0?ooo`0i0?ooo`030000o`3oool0oooo06<0oooo001h0?ooo`030000o`3o
ool0oooo03T0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?oo
o`1S0?ooo`00N03oool00`000?l0oooo0?ooo`0^0?ooo`D000001P3oool0
0`000000oooo0?ooo`070?ooo`<000006`3oool200000140oooo00<0003o
0?ooo`3oool0AP3oool3000001/0oooo001h0?ooo`030000o`3oool0oooo
0300oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`170?ooo`030000003oool0oooo01X0oooo001h0?ooo`03
0000o`3oool0oooo02P0oooo1@0000030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@0000030?ooo`030000003oool0oooo01<0
oooo1@0000030?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`3o
ool0?P3oool500000080oooo1000000K0?ooo`00N@3oool00`000?l0oooo
0?ooo`0X0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo0000000F0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0o0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000703oool007T0oooo00<0
003o0?ooo`3oool0:@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000001H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0000000@0?ooo`030000o`3oool0oooo0400oooo00<0
00000?ooo`3oool00`3oool2000001`0oooo001i0?ooo`030000o`3oool0
oooo02X0oooo00@000000?ooo`3oool0oooo0P0000080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool06P3oool007T0oooo00<0003o0?ooo`3oool0:03oool0
10000000oooo0?ooo`00000<0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000001@0
oooo00<0003o0?ooo`3oool0@03oool010000000oooo0?ooo`00000Q0?oo
o`00N@3oool00`000?l0oooo0?ooo`0X0?ooo`D000002`3oool010000000
oooo0?ooo`3oool5000001T0oooo1@00000C0?ooo`030000o`3oool0oooo
0400oooo1@00000P0?ooo`00NP3oool00`000?l0oooo0?ooo`0g0?ooo`03
0000003oool0oooo03H0oooo00<0003o0?ooo`3oool0IP3oool007X0oooo
00<0003o0?ooo`3oool0=`3oool00`000000oooo0?ooo`0f0?ooo`030000
o`3oool0oooo06H0oooo001j0?ooo`030000o`3oool0oooo03L0oooo00<0
00000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`1V0?ooo`00N`3oool0
0`000?l0oooo0?ooo`0f0?ooo`030000003oool0oooo03H0oooo00<0003o
0?ooo`3oool0IP3oool007/0oooo00<0003o0?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0f0?ooo`030000o`3oool0oooo06H0oooo001k0?ooo`03
0000o`3oool0oooo03H0oooo00<000000?ooo`3oool0=@3oool00`000?l0
oooo0?ooo`1W0?ooo`00O03oool00`000?l0oooo0?ooo`0e0?ooo`030000
003oool0oooo03D0oooo00<0003o0?ooo`3oool0I`3oool007`0oooo00<0
003o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0d0?ooo`030000o`3o
ool0oooo06P0oooo001l0?ooo`030000o`3oool0oooo03D0oooo00<00000
0?ooo`3oool0=03oool00`000?l0oooo0?ooo`1X0?ooo`00O@3oool00`00
0?l0oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<0003o0?oo
o`3oool0J@3oool007d0oooo00<0003o0?ooo`3oool0=03oool00`000000
oooo0?ooo`0c0?ooo`030000o`3oool0oooo06T0oooo001n0?ooo`030000
o`3oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo
0?ooo`1Z0?ooo`00O`3oool00`000?l0oooo0?ooo`0b0?ooo`030000003o
ool0oooo0380oooo00<0003o0?ooo`3oool0JP3oool007l0oooo00<0003o
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0
oooo06/0oooo00200?ooo`030000o`3oool0oooo0340oooo00<000000?oo
o`3oool0<@3oool00`000?l0oooo0?ooo`1[0?ooo`00P03oool00`000?l0
oooo0?ooo`0a0?ooo`030000003oool0oooo0300oooo00<0003o0?ooo`3o
ool0K03oool00840oooo00<0003o0?ooo`3oool0<03oool00`000000oooo
0?ooo`0`0?ooo`030000o`3oool0oooo06`0oooo00210?ooo`030000o`3o
ool0oooo0300oooo00<000000?ooo`3oool0;`3oool00`000?l0oooo0?oo
o`1]0?ooo`00PP3oool00`000?l0oooo0?ooo`0_0?ooo`030000003oool0
oooo02l0oooo00<0003o0?ooo`3oool0K@3oool008<0oooo00<0003o0?oo
o`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo
06h0oooo00240?ooo`030000o`3oool0oooo02d0oooo00<000000?ooo`3o
ool0;@3oool00`000?l0oooo0?ooo`1_0?ooo`00Q@3oool00`000?l0oooo
0?ooo`0/0?ooo`030000003oool0oooo02`0oooo00<0003o0?ooo`3oool0
L03oool008H0oooo00<0003o0?ooo`3oool0:`3oool00`000000oooo0?oo
o`0[0?ooo`030000o`3oool0oooo0740oooo00270?ooo`030000o`3oool0
oooo02X0oooo00<000000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`1b
0?ooo`00Q`3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo
02X0oooo00<0003o0?ooo`3oool0LP3oool008P0oooo00<0003o0?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo07<0
oooo00290?ooo`030000o`3oool0oooo02P0oooo00<000000?ooo`3oool0
:03oool00`000?l0oooo0?ooo`1d0?ooo`00RP3oool00`000?l0oooo0?oo
o`0W0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0M@3o
ool008/0oooo00<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`0V
0?ooo`030000o`3oool0oooo07H0oooo002<0?ooo`030000o`3oool0oooo
02D0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`1g0?oo
o`00S@3oool00`000?l0oooo0?ooo`0T0?ooo`030000003oool0oooo02<0
oooo0P000?mj0?ooo`00SP3oool00`000?l0oooo0?ooo`0S0?ooo`030000
003oool0oooo0280oooo00<0003o0?ooo`3oool0NP3oool008l0oooo0P00
0?lS0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool0N`3o
ool00940oooo00<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`0P
0?ooo`030000o`3oool0oooo07`0oooo002B0?ooo`80003o803oool00`00
0000oooo0?ooo`0N0?ooo`80003oO`3oool009@0oooo0P000?lN0?ooo`03
0000003oool0oooo01`0oooo0P000?n10?ooo`00UP3oool00`000?l0oooo
0?ooo`0K0?ooo`030000003oool0oooo01X0oooo0P000?n30?ooo`00U`3o
ool20000oa/0oooo00<000000?ooo`3oool0603oool20000ohD0oooo002I
0?ooo`80003o6@3oool00`000000oooo0?ooo`0G0?ooo`030000o`3oool0
oooo08D0oooo002K0?ooo`80003o5`3oool00`000000oooo0?ooo`0E0?oo
o`80003oR03oool009d0oooo0`000?lD0?ooo`030000003oool0oooo0180
oooo0`000?n:0?ooo`00X03oool20000oa80oooo00<000000?ooo`3oool0
3`3oool30000ohd0oooo002R0?ooo`H0003o103oool5000000<0oooo00<0
00000?ooo`3oool02@3oool60000oi00oooo002X0?ooo`H0003o00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`H0003oUP3oool0
0:h0oooo30000?nL0?ooo`00[P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo09l0oooo002^0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0W`3oool00:d0oooo0P0000050?ooo`030000003o
ool0oooo09l0oooo002d0?ooo`030000003oool0oooo09l0oooo002d0?oo
o`030000003oool0oooo09l0oooo002d0?ooo`030000003oool0oooo09l0
oooo003o0?oooeL0oooo003o0?oooeL0oooo003o0?oooeL0oooo003o0?oo
oeL0oooo003o0?oooeL0oooo003o0?oooeL0oooo003o0?oooeL0oooo002b
0?ooo`800000XP3oool00;<0oooo00<000000?ooo`3oool0X03oool00;@0
oooo00<000000?ooo`3oool0W`3oool00;<0oooo00<000000?ooo`000000
X03oool00;80oooo00@000000?ooo`3oool00000X03oool00;40oooo0`00
00000`3oool000000000002O0?ooo`00o`3ooomG0?ooo`00o`3ooomG0?oo
o`00o`3ooomG0?ooo`00o`3ooomG0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{342, 157},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  For values of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " that lie on the unit circle ",
  Cell[BoxData[
      \(\(C\_1\) \((0)\)\)]],
  ", we have \n\n\t\t\t",
  Cell[BoxData[
      \(z\^2\  = \ 
        cos\ 2  \[Theta]\  + \ \[ImaginaryI]\ sin\ 2  \[Theta]\)]],
  "   and   ",
  Cell[BoxData[
      \(z\^\(-2\)\  = \ 
        cos\ 2  \[Theta]\  - \ \[ImaginaryI]\ sin\ 2  \[Theta]\)]],
  "\n\nWe solve for  ",
  Cell[BoxData[
      RowBox[{"cos", " ", "2", "\[Theta]", "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "sin", " ", "2", "\[Theta]"}]]],
  "  to obtain the substitutions  \n\n\t\t\t",
  Cell[BoxData[
      \(cos\ 2  \[Theta]\  = \ \(1\/2\) \((z\^2 + z\^\(-2\))\)\)]],
  "    and    ",
  Cell[BoxData[
      \(sin\ 2  \[Theta]\  = \ \(1\/\(2  \[ImaginaryI]\)\) \((z\^2 - 
              z\^\(-2\))\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Using the identity for ",
  Cell[BoxData[
      \(\(\(cos\)\(\ \)\(2\)  \(\[Theta]\)\(\ \)\)\)]],
  " along with Substitutions ",
  StyleBox["(8-4)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(8-5)",
    FontColor->RGBColor[0, 0, 1]],
  ", we rewrite the integral as  \n\n\n\t\t\t",
  Cell[BoxData[{
      \(\[ContourIntegral]\_\(\(\ \)\(\(C\_1\%+\) \((0)\)\)\)\ \(\(\(1\/2\) \
\((z\^2 + z\^\(-2\))\)\)\/\(5 - 4 \((\(z + z\^\(-1\)\)\/2)\)\)\) 
            1\/\(\[ImaginaryI]\ z\)\ \[DifferentialD]z\ \  = \ \ \
\[ContourIntegral]\_\(\(\ \)\(\(C\_1\%+\) \((0)\)\)\)\ \(\[ImaginaryI]\ \
\((z\^4 + 1)\)\)\/\(2\ z\^2\ \((2\ z\^2 - 5\ z + 2)\)\)\ \
\(\(\[DifferentialD]z\)\(\ \ \)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\[ContourIntegral]\_\(\(\ \
\)\(\(C\_1\%+\) \((0)\)\)\)\ \(\[ImaginaryI]\ \((z\^4 + 1)\)\)\/\(2\ z\^2\ \
\((z - 2)\)\ \((2\ z - 1)\)\)\ \[DifferentialD]z\ \  = \ \ \[ContourIntegral]\
\_\(\(\ \)\(\(C\_1\%+\) \((0)\)\)\)\ f \((z)\)\ \[DifferentialD]z\)\)\)}]],
  "\n\nwhere  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(\[ImaginaryI]\ \((z\^4 + 1)\)\)\/\(2\ z\^2\ \((z - \
2)\)\ \((2\ z - 1)\)\)\)]],
  ".  The singularities of ",
  Cell[BoxData[
      \(f \((t)\)\)]],
  " lying inside ",
  Cell[BoxData[
      \(\(C\_1\) \((0)\)\)]],
  " are poles located at the points ",
  Cell[BoxData[
      \(z\_1 = \(z\_2 = 0\)\)]],
  " and ",
  Cell[BoxData[
      \(z\_3 = 1\/2\)]],
  ".  We use Theorem 8.2 to get the residues: \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, 
          0]\ \  = \ \ \(lim\+\(z\  \[Rule] 0\)\ \(d\/dz\) \((\(z\^2\) 
                  f \((z)\))\)\ \  = \ \ lim\+\(z\  \[Rule] 0\)\ \(d\/dz\) \
\((\(z\^2\) \(\[ImaginaryI]\ \((z\^4 + 1)\)\)\/\(2\ z\^2\ \((z - 2)\)\ \((2\ \
z - 1)\)\))\)\)\)\(\[IndentingNewLine]\)
      \)\ \ \), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] 0\)\ \(d\/dz\) \((\[ImaginaryI] \( z\^4 + 1\)\/\(2\ \
\((z - 2)\)\ \((2\ z - 1)\)\))\)\ \  = \ \ lim\+\(z\  \[Rule] 0\)\ \(d\/dz\) \
\((\[ImaginaryI] \( z\^4 + 1\)\/\(2 \((2\ z\^2 - 5\ z + 2)\)\))\)\)\)\(\ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] 0\)\((\[ImaginaryI] \( 4\ \(z\^3\) \((2\ z\^2 - 5\ z + \
2)\) - \((4  z - 5)\) \((z\^4 + 1)\)\)\/\(2\ \((2\ z\^2 - 5\ z + 2)\)\^2\))\)\
\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \ \)\(\
\[ImaginaryI] \(\((4\[Cross]0\^3)\) \((2\[Cross]0\^2 - 5\[Cross]0 + 2)\) - \
\((4\[Cross]0 - 5)\) \((0\^4 + 1)\)\)\/\(2\ \((2\[Cross]0\^2 - 5\[Cross]0 + \
2)\)\^2\)\ \ \  = \ \ \ \[ImaginaryI] \(\((0)\)\[Cross]\((2)\) - \((\(-5\))\) \
\((1)\)\)\/\(2\ \((2)\)\^2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(5\ \
\[ImaginaryI]\)\/8\)\)\)}]],
  "    \n\t\t\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, 
          1\/2]\ \  = \ \ \(lim\+\(z\  \[Rule] 1\/2\)\ \((z - 1\/2)\) 
              f \((z)\)\ \  = \ \ lim\+\(z\  \[Rule] 1\/2\)\ \((z - 
                  1\/2)\) \(\[ImaginaryI]\ \((z\^4 + 1)\)\)\/\(2\ z\^2\ \((z \
- 2)\)\ \((2\ z - 1)\)\)\)\)\(\[IndentingNewLine]\)
      \)\ \ \), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] 1\/2\)\((z - 
                  1\/2)\) \(\[ImaginaryI]\ \((z\^4 + 1)\)\)\/\(4\ z\^2\ \((z \
- 2)\) \((z - 1\/2)\)\)\ \  = \ \ lim\+\(z\  \[Rule] 1\/2\)\[ImaginaryI] \(\(\
\ \)\(z\^4 + 1\)\)\/\(4\ z\^2\ \((z - 2)\)\)\)\)\(\ \ \)\(\[IndentingNewLine]\
\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\
\[ImaginaryI] \(\(\ \)\(\((1\/2)\)\^4 + 1\)\)\/\(4\ \ \(\((1\/2)\)\^2\) \
\((1\/2 - 2)\)\)\ \  = \ \ \(\[ImaginaryI] \(\(\ \)\(1\/16 + \
1\)\)\/\(4\ \ \((1\/4)\) \((1\/2 - 2)\)\)\ \  = \ \ \[ImaginaryI] \(\(\ \
\)\(17\/16\)\)\/\(4\ \ \((1\/4)\) \((\(-3\)\/2)\)\)\)\)\)\(\ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(-\(\(17\ \[ImaginaryI]\)\/24\)\)\)\)}]],
  "   "
}], "Text"],

Cell[TextData[{
  "Therefore we conclude that  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_0\%\(2  \[Pi]\)\(\(\(\ \)\(cos \((2  \[Theta])\)\)\)\
\/\(5\  - \ 
                  4\ cos \((\[Theta])\)\)\) \[DifferentialD]\[Theta]\ \  = \ \
\ 2  \[Pi]\ \[ImaginaryI]\ \((Res[f, z\_1]\  + \ 
              Res[f, z\_2])\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \(\(\(=\)\(\ \ \)\(2  \[Pi]\ \[ImaginaryI]\ \((Res[f, 0]\  + \ 
              Res[f, 1\/2])\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \(\(\(=\)\(\ \ \ \)\(2  \[Pi]\ \[ImaginaryI]\ \((\(5\ \[ImaginaryI]\)\/8\  \
- \ \(17\ \[ImaginaryI]\)\/24)\)\ \  = \ \ 2  \[Pi]\ \[ImaginaryI]\ \((\(-\(\
\[ImaginaryI]\/12\)\))\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \(\(=\)\(\ \ \)\(\[Pi]\/6\)\)\)}]],
  "    "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(F[\[Theta]] = \(\(\ \)\(Cos[2  \[Theta]]\)\)\/\(5\  - \ 4\ Cos[\
\[Theta]]\)\)],
    AspectRatioFixed->True],
  " and use substitution to obtain the complex function f[z].  "
}], "Text"],

Cell[BoxData[{
    \(Z = 0; \ Remove[Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, G, F, Res1, Res2, Res3, Res4, solset, \[Theta], val, 
        z];\)\ \), "\n", 
    \(\(F[\[Theta]_]\  = \(\(\ \)\(Cos[2  \[Theta]]\)\)\/\(5\  - \ 4\ Cos[\
\[Theta]]\);\)\ \), "\n", 
    \(\(f[z_]\  = \ sub[F[\[Theta]], \[Theta]];\)\ \), "\n", 
    \(\(Print["\<F[\[Theta]] = \>", F[\[Theta]]];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Locate the singularities of  ",
  Cell[BoxData[
      \(f[
          z] = \(\[ImaginaryI]\ \((1\  + \ z\^4)\)\)\/\(2\ z\^2\ \((2\  - \ 5\
\ z\  + \ 2\ z\^2)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[Denominator[f[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, 
            z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The singularities are\>"];\)\ \), "\n", 
    \(\(Z\_1\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2];\)\ \), "\n", 
    \(\(Z\_3\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3];\)\ \), "\n", 
    \(\(Z\_4\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(4\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", 
        Z\_4];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Find out which singularities lie inside the unit circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_2], Im[Z\_2]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_3], Im[Z\_3]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_4], Im[Z\_4]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1] - 0.05, 
                Im[Z\_1] + 0.2}, {1, 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] + 0.2}, {\(-1\), 
                0}], Text[\*"\"\<\!\(z\_3\)\>\"", {Re[Z\_3], 
                Im[Z\_3] + 0.2}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_4\)\>\"", {Re[Z\_4], Im[Z\_4] + 0.2}, {\(-1\), 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 1]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-1.1\), 2.2}, {\(-1.1\), 1.1}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], 
            Range[\(-3\), 3, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 
          2\/3, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<,   Is |\>", 
        Z\_1, "\<| < 1 ?   \>", N[Abs[Z\_1]] < 1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<,   Is |\>", 
        Z\_2, "\<| < 1 ?   \>", N[Abs[Z\_2]] < 1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3, "\<,  Is |\>", 
        Z\_3, "\<| < 1 ?  \>", N[Abs[Z\_3]] < 1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", Z\_4, "\<,   Is |\>", 
        Z\_4, "\<| < 1 ?   \>", 
        N[Abs[Z\_4]] < 1];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Compute the residues at  ",
  Cell[BoxData[
      \(z\_1 = 1, \ and\ \ z\_3 = 1\/2\)]],
  ", and use the residue calculus to compute the value of the integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Res1\  = \ Residue[f[z], {z, Z\_1}];\)\ \), "\n", 
    \(\(Res3\  = \ Residue[f[z], {z, Z\_3}];\)\ \), "\[IndentingNewLine]", 
    \(\(val\  = 
        2\ \[Pi]\ \[ImaginaryI]\ \((Res1\  + \ 
              Res3)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", Z\_1, "\<] = \>", Res1];\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_3, "\<] = \>", 
        Res3];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_3], Im[Z\_3]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] - 0.15}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_3\)\>\"", {Re[Z\_3], 
                Im[Z\_3] - 0.15}, {\(-1\), 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 1]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-1.1\), 1.1}, {\(-1.1\), 1.1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], 
            Range[\(-1\), 1, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI]((\>", 
        Res1\ , "\<) + (\>", \ 
        Res3\ , "\<))\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>", 
        Res1\  + \ Res3\ , "\<) = \>", val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The contour is the circle  C:|z| = 1,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<taken with the positive orientation.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral] \>"\+0\%\(2  \[Pi]\), 
        F[\[Theta]], "\< \[DifferentialD]\[Theta] = \>", 
        val];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  is capable of finding some of these difficult integrals.  The function  \
",
  Cell[BoxData[
      \(F[\[Theta]] = \(\(\ \)\(Cos[2  \[Theta]]\)\)\/\(5\  - \ 4\ Cos[\
\[Theta]]\)\)],
    AspectRatioFixed->True],
  "  can be integrated."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(G[\[Theta]_]\  = \ \[Integral]F[\[Theta]] \[DifferentialD]\[Theta];\)\
\ \), "\n", 
    \(\(val\  = \ \[Integral]\_0\%\(2  \[Pi]\)F[\[Theta]] \[DifferentialD]\
\[Theta];\)\ \), "\n", 
    \(\(Print["\<G[\[Theta]] = \[Integral] \>", 
        F[\[Theta]], "\< \[DifferentialD]\[Theta] = \>", 
        G[\[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<\[Integral] \>"\+0\%\(2  \[Pi]\), 
        F[\[Theta]], "\< \[DifferentialD]\[Theta] = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "However, direct substitution using ",
  Cell[BoxData[
      \(G \((\[Theta])\)\)]],
  " and the endpoints of the interval seems to be ",
  StyleBox["erroneous",
    FontColor->RGBColor[1, 0, 1]],
  ".  This is due to the fact that in the interior of the interval, ",
  Cell[BoxData[
      \(tan \((\[Pi]\/2)\)\)]],
  " is undefined. Hence ",
  Cell[BoxData[
      \(G \((\[Theta])\)\)]],
  "is discontinuous."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<        G[0] = \>", G[0]];\)\ \), "\n", 
    \(\(Print["\<       G[2\[Pi]] = \>", G[2  \[Pi]]];\)\ \), "\n", 
    \(\(Print["\<G[2\[Pi]] - G[0] = \>", 
        G[2  \[Pi]] - G[0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "This is due to the fact that  ",
  Cell[BoxData[
      \(tan \((\[Pi]\/2)\)\)]],
  " is undefined.  A graph of  ",
  Cell[BoxData[
      \(G[\[Theta]]\)]],
  "  reveals that it has a discontinuity at  ",
  Cell[BoxData[
      \(\[Theta] = \[Pi]\)]],
  "  in the middle of the interval  ",
  Cell[BoxData[
      \(\([0, 2  \[Pi]]\)\)]],
  ".  This is a violation of the Fundamental Theorem of Calculus, which \
asserts that the integral of a continuous function must be continuous. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[G[\[Theta]], {\[Theta], 0, \[Pi]}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = 
        Plot[G[\[Theta]], {\[Theta], \[Pi], 2  \[Pi]}, 
          PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, 
        PlotRange \[Rule] {{0, 2  \[Pi]}, {\(-4.5\), 
              0.5}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 
              2  \[Pi], \[Pi]\/2], 
            Range[\(\(-4\) \[Pi]\)\/3, \[Pi]\/3, \[Pi]\/3]}, \
\[IndentingNewLine]AxesLabel \[Rule] {"\<\[Theta]\>", "\<s\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), "\n", 
    \(\(Print["\<s = \>", G[\[Theta]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The indefinite integrand  ",
  Cell[BoxData[
      \(G[\[Theta]]\)]],
  "  can be used piecewise over  ",
  Cell[BoxData[
      \(\((0, \[Pi])\)\ \ and\ \ \((\[Pi], 2  \[Pi])\)\)]],
  "  where it is continuous, by using the left and right hand limits at the \
endpoints. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(lim1 = 
        Limit[G[\[Theta]], \[Theta] \[Rule] \[Pi], \ \ \ Direction \[Rule] 
            1];\)\ \), "\[IndentingNewLine]", 
    \(\(val2 = G[0];\)\ \), "\[IndentingNewLine]", 
    \(\(val3 = G[2  \[Pi]];\)\ \), "\[IndentingNewLine]", 
    \(\(lim4 = 
        Limit[G[\[Theta]], \[Theta] \[Rule] \[Pi], \ \ \ Direction \[Rule] \
\(-1\)];\)\ \), "\[IndentingNewLine]", 
    \(\(val\  = \ \((lim1\  - val2)\)\  + \ \((val3\  - \ 
              lim4)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(\[Theta] \[Rule] \(\[Pi]\^-\)\)\) (\>\"", 
        G[\[Theta]], "\<) = \>", lim1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<G[0] = \>", val2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<G[2\[Pi]] = \>", val3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(\[Theta] \[Rule] \(\[Pi]\^+\)\)\) (\>\"", 
        G[\[Theta]], "\<) = \>", lim4];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral] \>"\+0\%\(2  \[Pi]\), 
        F[\[Theta]], "\< \[DifferentialD]\[Theta] = (\>", lim1\ , "\< - (\>", 
        val2, "\<)) + (\>", val3\ , "\< - (\>", 
        lim4, "\<))\>"];\)\ \), "\n", 
    \(\(Print["\<\[Integral] \>"\+0\%\(2  \[Pi]\), 
        F[\[Theta]], "\< \[DifferentialD]\[Theta] = \>", \((lim1\  - 
            val2)\), "\< + \>", \((val3\  - \ lim4)\), "\< = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The above answer is correct too.  Limits were required because  ",
  Cell[BoxData[
      \(G[\[Theta]]\)]],
  "  is not continuous at  ",
  Cell[BoxData[
      \(\(\(\[Theta] = \[Pi]\)\(\ \)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Residue Calculus",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ResidueCalcBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Contour Integrals",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ContourIntegralBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Cauchy Principal Value",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/CauchyPrincipalValuelBib.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{958, 650},
WindowMargins->{{23, Automatic}, {0, Automatic}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 96156, 2155}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 118, 2, 33, "Text"],
Cell[2223, 66, 317, 5, 52, "Text"],
Cell[2543, 73, 2138, 60, 350, "Text",
  Evaluatable->False],
Cell[4684, 135, 908, 27, 118, "Text",
  Evaluatable->False],
Cell[5595, 164, 784, 24, 110, "Text",
  Evaluatable->False],
Cell[6382, 190, 540, 18, 33, "Text"],
Cell[6925, 210, 204, 7, 33, "Text",
  Evaluatable->False],
Cell[7132, 219, 194, 5, 33, "Text",
  Evaluatable->False],
Cell[7329, 226, 1137, 23, 342, "Input",
  InitializationCell->True],
Cell[8469, 251, 373, 11, 37, "Text",
  Evaluatable->False],
Cell[8845, 264, 14716, 244, 242, 14602, 240, "GraphicsData", "Bitmap", "Text",
  
  Evaluatable->False],
Cell[23564, 510, 3999, 96, 637, "Text"],
Cell[27566, 608, 1697, 38, 266, "Text"],

Cell[CellGroupData[{
Cell[29288, 650, 196, 7, 33, "Text"],
Cell[29487, 659, 238, 6, 38, "Text"],
Cell[29728, 667, 498, 10, 166, "Input"],
Cell[30229, 679, 234, 9, 37, "Text",
  Evaluatable->False],
Cell[30466, 690, 1449, 32, 330, "Input"],
Cell[31918, 724, 203, 7, 33, "Text",
  Evaluatable->False],
Cell[32124, 733, 1830, 32, 270, "Input"],
Cell[33957, 767, 286, 8, 43, "Text",
  Evaluatable->False],
Cell[34246, 777, 2384, 45, 503, "Input"]
}, Closed]],
Cell[36645, 825, 366, 11, 34, "Text",
  Evaluatable->False],
Cell[37014, 838, 2084, 70, 144, "Text"],
Cell[39101, 910, 11975, 199, 171, 11861, 195, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[51079, 1111, 583, 18, 37, "Text"],
Cell[51665, 1131, 2465, 51, 299, "Text"],

Cell[CellGroupData[{
Cell[54155, 1186, 196, 7, 33, "Text"],
Cell[54354, 1195, 238, 6, 38, "Text"],
Cell[54595, 1203, 498, 10, 166, "Input"],
Cell[55096, 1215, 354, 11, 38, "Text",
  Evaluatable->False],
Cell[55453, 1228, 803, 16, 240, "Input"],
Cell[56259, 1246, 279, 10, 33, "Text",
  Evaluatable->False],
Cell[56541, 1258, 290, 6, 90, "Input"],
Cell[56834, 1266, 604, 17, 52, "Text",
  Evaluatable->False],
Cell[57441, 1285, 916, 18, 184, "Input"],
Cell[58360, 1305, 351, 11, 33, "Text",
  Evaluatable->False],
Cell[58714, 1318, 1851, 34, 364, "Input"],
Cell[60568, 1354, 289, 10, 33, "Text",
  Evaluatable->False]
}, Closed]],
Cell[60872, 1367, 383, 13, 39, "Text",
  Evaluatable->False],
Cell[61258, 1382, 13252, 220, 171, 13138, 216, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[74513, 1604, 1112, 34, 151, "Text"],
Cell[75628, 1640, 4420, 91, 683, "Text"],
Cell[80051, 1733, 1091, 21, 210, "Text"],

Cell[CellGroupData[{
Cell[81167, 1758, 196, 7, 33, "Text"],
Cell[81366, 1767, 252, 7, 38, "Text"],
Cell[81621, 1776, 510, 10, 166, "Input"],
Cell[82134, 1788, 252, 9, 42, "Text",
  Evaluatable->False],
Cell[82389, 1799, 1449, 32, 330, "Input"],
Cell[83841, 1833, 203, 7, 33, "Text",
  Evaluatable->False],
Cell[84047, 1842, 1841, 32, 285, "Input"],
Cell[85891, 1876, 239, 7, 36, "Text",
  Evaluatable->False],
Cell[86133, 1885, 2211, 42, 439, "Input"],
Cell[88347, 1929, 368, 12, 38, "Text",
  Evaluatable->False],
Cell[88718, 1943, 579, 12, 179, "Input"],
Cell[89300, 1957, 488, 16, 55, "Text",
  Evaluatable->False],
Cell[89791, 1975, 290, 6, 90, "Input"],
Cell[90084, 1983, 561, 17, 55, "Text",
  Evaluatable->False],
Cell[90648, 2002, 926, 18, 186, "Input"],
Cell[91577, 2022, 351, 11, 33, "Text",
  Evaluatable->False],
Cell[91931, 2035, 1471, 26, 329, "Input"],
Cell[93405, 2063, 284, 10, 33, "Text",
  Evaluatable->False]
}, Closed]],
Cell[93704, 2076, 290, 7, 30, "Text"],
Cell[93997, 2085, 313, 10, 33, "Text"],
Cell[94313, 2097, 318, 10, 33, "Text"],
Cell[94634, 2109, 331, 11, 33, "Text"],
Cell[94968, 2122, 257, 5, 33, "Text"],
Cell[95228, 2129, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

