(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    127703,       2706]*)
(*NotebookOutlinePosition[    128643,       2740]*)
(*  CellTagsIndexPosition[    128566,       2734]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["8.3  Improper Integrals of Rational Functions",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tAn important application of the theory of residues is the evaluation of \
certain types of improper integrals.  Let ",
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  " be a continuous function of the real variable ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " on the interval  ",
  Cell[BoxData[
      \(0 \[LessEqual] x < \[Infinity]\)]],
  ".  Recall from calculus that the improper integral of ",
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  " over  [",
  Cell[BoxData[
      StyleBox[\(0, \[Infinity]\),
        FontWeight->"Plain"]]],
  ")  is defined by \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_0\%\[Infinity]\ 
          f \((x)\) \[DifferentialD]x\ \  = \ \ lim\+\(b\  \[Rule] \ \
\[Infinity]\)\ \[Integral]\_0\%b\ f \((x)\) \[DifferentialD]x\)]],
  ",  \n\t\nprovided that the limit exists.  If ",
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  "  is defined for all real ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ", then the integral of ",
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  " over",
  StyleBox[" ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      StyleBox[\((\(-\[Infinity]\), \[Infinity])\),
        FontWeight->"Plain",
        FontColor->GrayLevel[0]]],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " is defined by \n\n",
  StyleBox["(8-7)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\ 
          f \((x)\) \[DifferentialD]x\ \  = \ \ lim\+\(a\  \[Rule] \ \(-\
\[Infinity]\)\)\ \[Integral]\_a\%0\ f \((x)\) \[DifferentialD]x\  + \ 
          lim\+\(b\  \[Rule] \ \[Infinity]\)\ \[Integral]\_0\%b\ 
              f \((x)\) \[DifferentialD]x\)]],
  ",  \n\nprovided both limits exist.  If the integral in Equation ",
  StyleBox["(8-7)",
    FontColor->RGBColor[0, 0, 1]],
  " exists, we can obtain its value by taking a single limit:\n\n",
  StyleBox["(8-8)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\ 
          f \((x)\) \[DifferentialD]x\ \  = \ \ lim\+\(R\  \[Rule] \ \
\[Infinity]\)\ \[Integral]\_\(-R\)\%R\ f \((x)\) \[DifferentialD]x\)]],
  ".  \n\nFor some functions the limit on the right side of Equation ",
  StyleBox["(8-8)",
    FontColor->RGBColor[0, 0, 1]],
  " exists, but the limit on the right side of Equation ",
  StyleBox["(8-7)",
    FontColor->RGBColor[0, 0, 1]],
  " doesn't exist."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 8.13.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  Cell[BoxData[
      \("\!\(lim\+\(R \[Rule] \[Infinity]\)\) \!\(\[Integral]\_\(-R\)\%R\) x \
\[DifferentialD]x"\ \  = \ \ \(\*"\"\<\!\(lim\+\(R \[Rule] \
\[Infinity]\)\)\>\""\ \((\[Integral]\_\(-R\)\%0\ 
                  x \[DifferentialD]x\ \  + \ \ \[Integral]\_0\%R\ 
                  x \[DifferentialD]x\ )\)\ \  = \ \ \(\*"\"\<\!\(lim\+\(R \
\[Rule] \[Infinity]\)\)\>\""\ \((\(-\(R\^2\/2\)\)\  + \ 
                  R\^2\/2)\)\ \  = \ \ \(\*"\"\<\!\(lim\+\(R \[Rule] \
\[Infinity]\)\)\>\""\ \((\ 0\ )\)\ \  = \ \ 0\)\)\)\)],
    AspectRatioFixed->True],
  ",  \n\nbut Equation ",
  StyleBox["(8-7)",
    FontColor->RGBColor[0, 0, 1]],
  " tells us that the improper integral of  ",
  Cell[BoxData[
      \(f \((x)\) = x\)],
    AspectRatioFixed->True],
  "  over",
  StyleBox[" ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      StyleBox[\((\(-\[Infinity]\), \[Infinity])\),
        FontWeight->"Plain",
        FontColor->GrayLevel[0]]],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  doesn't exist, because the calculation  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\ 
          x \[DifferentialD]x\), "  ", "=", "  ", 
        RowBox[{\(lim\+\(a\  \[Rule] \ \(-\[Infinity]\)\)\ \[Integral]\_a\%0\ 
                x \[DifferentialD]x\ \  + \ \ lim\+\(b\  \[Rule] \ \
\[Infinity]\)\ \[Integral]\_0\%b\ x \[DifferentialD]x\), "  ", "=", "  ", 
          RowBox[{
            RowBox[{
              StyleBox["'",
                FontColor->GrayLevel[0]], "\[Infinity]"}], 
            "-", \(\[Infinity]'\)}]}]}]]],
  "    is undefined .  \n\nTherefore we can use Equation ",
  StyleBox["(8-8)",
    FontColor->RGBColor[0, 0, 1]],
  " to extend the notion of the value of an improper integral, as Definition \
8.2 indicates.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005m0000RR000`400?l0
0000o`00003oo`3ooomn0?ooo`00o`3ooomn0?ooo`00o`3ooomn0?ooo`00
o`3ooomn0?ooo`00o`3ooomn0?ooo`00M@3oool40?l006l0oooo00<00000
0?ooo`3oool0TP3oool007H0oooo1@3o001]0?ooo`030000003oool0oooo
0980oooo001h0?ooo`D0o`00J`3oool00`000000oooo0?ooo`2B0?ooo`00
NP3oool50?l006T0oooo00<000000?ooo`3oool0TP3oool007`0oooo1@3o
001W0?ooo`030000003oool0oooo0980oooo001n0?ooo`D0o`00I@3oool0
0`000000oooo0?ooo`2B0?ooo`00P03oool50?l006<0oooo00<000000?oo
o`3oool0TP3oool00880oooo1@3o001Q0?ooo`030000003oool0oooo0980
oooo00240?ooo`D0o`00G`3oool00`000000oooo0?ooo`2B0?ooo`00QP3o
ool50?l005d0oooo00<000000?ooo`3oool0TP3oool008P0oooo103o001L
0?ooo`030000003oool0oooo0980oooo002:0?ooo`@0o`00FP3oool00`00
0000oooo0?ooo`2B0?ooo`00R`3oool50?l005P0oooo00<000000?ooo`3o
ool0TP3oool008d0oooo1@3o001F0?ooo`030000003oool0oooo0980oooo
002=0?ooo`80ol3;1@3o001D0?ooo`030000003oool0oooo0980oooo002=
0?ooo`@0ol3;1@3o001B0?ooo`030000003oool0oooo0980oooo002=0?oo
o`H0ol3;1@3o001@0?ooo`030000003oool0oooo0980oooo002=0?ooo`P0
ol3;1@3o001>0?ooo`030000003oool0oooo0980oooo002=0?ooo`X0ol3;
1@3o001<0?ooo`030000003oool0oooo0980oooo002=0?ooo``0ol3;103o
001;0?ooo`030000003oool0oooo0980oooo002=0?ooo`h0ol3;103o0019
0?ooo`030000003oool0oooo0980oooo002=0?ooo`l0ol3;1P3o00160?oo
o`030000003oool0oooo0980oooo002=0?oooa40ol3;1`3o00130?ooo`03
0000003oool0oooo0980oooo002=0?oooa@0ol3;1P3o00110?ooo`030000
003oool0oooo0980oooo002=0?oooaL0ol3;1@3o000o0?ooo`030000003o
ool0oooo0980oooo002=0?oooaT0ol3;1@3o000m0?ooo`030000003oool0
oooo0980oooo002=0?oooa/0ol3;1@3o000k0?ooo`030000003oool0oooo
0980oooo002=0?oooad0ol3;103o000j0?ooo`030000003oool0oooo0980
oooo002=0?oooal0ol3;103o000h0?ooo`030000003oool0oooo0980oooo
002=0?ooob00ol3;1@3o000f0?ooo`030000003oool0oooo0980oooo002=
0?ooob80ol3;1@3o000d0?ooo`030000003oool0oooo0980oooo002=0?oo
ob@0ol3;1@3o000b0?ooo`030000003oool0oooo0980oooo002=0?ooobH0
ol3;1@3o000`0?ooo`030000003oool0oooo0980oooo002=0?ooobP0ol3;
1@3o000^0?ooo`030000003oool0oooo0980oooo002=0?ooobX0ol3;1@3o
000/0?ooo`030000003oool0oooo0980oooo002=0?ooob`0ol3;1@3o000Z
0?ooo`030000003oool0oooo0980oooo002=0?ooobh0ol3;1P3o000W0?oo
o`030000003oool0oooo0980oooo002=0?oooc00ol3;1P3o000U0?ooo`03
0000003oool0oooo0980oooo002=0?oooc<0ol3;1@3o000S0?ooo`030000
003oool0oooo0980oooo002=0?ooocD0ol3;1@3o000Q0?ooo`030000003o
ool0oooo0980oooo002=0?ooocL0ol3;1@3o000O0?ooo`030000003oool0
oooo0980oooo002=0?ooocT0ol3;1@3o000M0?ooo`030000003oool0oooo
0980oooo002=0?oooc/0ol3;1@3o000K0?ooo`030000003oool0oooo0980
oooo002=0?ooocd0ol3;1@3o000I0?ooo`030000003oool0oooo0980oooo
002=0?ooocl0ol3;1@3o000G0?ooo`030000003oool0oooo0980oooo002=
0?oood40ol3;1@3o000E0?ooo`030000003oool0oooo0980oooo002=0?oo
od<0ol3;1@3o000C0?ooo`030000003oool0oooo0980oooo002=0?ooodD0
ol3;103o000B0?ooo`030000003oool0oooo0980oooo002=0?ooodL0ol3;
103o000@0?ooo`030000003oool0oooo0980oooo002=0?ooodP0ol3;1@3o
000>0?ooo`030000003oool0oooo0980oooo002=0?ooodX0ol3;1@3o000<
0?ooo`030000003oool0oooo05D0oooo0`0000020?ooo`030000003oool0
oooo03D0oooo002=0?oood`0ol3;1@3o000:0?ooo`030000003oool0oooo
05H0oooo00@000000?ooo`3oool00000>03oool008d0ooooCP3o`</50?l0
00P0oooo00<000000?ooo`3oool0EP3oool3000003T0oooo002=0?oooe00
ol3;1@3o00060?ooo`030000003oool0oooo05H0oooo00@000000?ooo`3o
ool00000>03oool008d0ooooDP3o`</50?l000@0oooo00<000000?ooo`3o
ool0EP3oool010000000oooo0?ooo`00000h0?ooo`00S@3ooomD0?o0b`D0
o`000P3oool00`000000oooo0?ooo`1E0?ooo`@00000>@3oool008d0oooo
EP3o`</50?l000030000003oool0oooo07L0oooo0P0000000`3oool00000
0000000F0?ooo`00MP3ooooU000000P0oooo00<000000?ooo`0000005`3o
ool00>P0oooo00<000000000o`000?l00P000?mF003oob40oooo00<00000
0?ooo`3oool05P3oool00>P0oooo00<000000?ooo`000?l010000?mD003o
oal0oooo0P0000000`3oool000000000000F0?ooo`00j03oool010000000
oooo0?ooo`3oool50000oe800?oo>P3oool00>P0oooo00<000000?ooo`3o
ool00`3oool50000oe000?oo>P3oool008d0oooo0`0000020?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool01@3oool50000odh00?oo
>P3oool008P0oooo100000020?ooo`040000003oool0oooo000005H0oooo
00<000000?ooo`3oool01`3oool50000od`00?oo>P3oool008h0oooo0`00
001G0?ooo`030000003oool0oooo00T0oooo10000?m;003oocX0oooo002>
0?ooo`040000003oool0oooo000005H0oooo00<000000?ooo`3oool02`3o
ool40000odT00?oo>P3oool008h0oooo00@000000?ooo`3oool00000EP3o
ool00`000000oooo0?ooo`0<0?ooo`D0003oA`00oolj0?ooo`00S@3oool4
000005L0oooo00<000000?ooo`3oool03P3oool50000odD00?oo>P3oool0
0>P0oooo00<000000?ooo`3oool0403oool50000od<00?oo>P3oool00>P0
oooo00<000000?ooo`3oool04P3oool50000od400?oo>P3oool00>P0oooo
00<000000?ooo`3oool0503oool50000ocl00?oo>P3oool00>P0oooo00<0
00000?ooo`3oool05P3oool50000ocd00?oo>P3oool00>P0oooo00<00000
0?ooo`3oool0603oool50000oc/00?oo>P3oool00>P0oooo00<000000?oo
o`3oool06P3oool60000ocP00?oo>P3oool00>P0oooo00<000000?ooo`3o
ool0703oool60000ocH00?oo>P3oool00>P0oooo00<000000?ooo`3oool0
7`3oool50000oc@00?oo>P3oool00>P0oooo00<000000?ooo`3oool08@3o
ool50000oc800?oo>P3oool00>P0oooo00<000000?ooo`3oool08`3oool5
0000oc000?oo>P3oool00>P0oooo00<000000?ooo`3oool09@3oool50000
obh00?oo>P3oool00>P0oooo00<000000?ooo`3oool09`3oool50000ob`0
0?oo>P3oool00>P0oooo00<000000?ooo`3oool0:@3oool50000obX00?oo
>P3oool00>P0oooo00<000000?ooo`3oool0:`3oool40000obT00?oo>P3o
ool00>P0oooo00<000000?ooo`3oool0;@3oool40000obL00?oo>P3oool0
0>P0oooo00<000000?ooo`3oool0;P3oool50000obD00?oo>P3oool00>P0
oooo00<000000?ooo`3oool0<03oool50000ob<00?oo>P3oool00>P0oooo
00<000000?ooo`3oool0<P3oool50000ob400?oo>P3oool00>P0oooo00<0
00000?ooo`3oool0=03oool50000oal00?oo>P3oool00>P0oooo00<00000
0?ooo`3oool0=P3oool50000oad00?oo>P3oool00>P0oooo00<000000?oo
o`3oool0>03oool50000oa/00?oo>P3oool00>P0oooo00<000000?ooo`3o
ool0>P3oool50000oaT00?oo>P3oool00>P0oooo00<000000?ooo`3oool0
?03oool60000oaH00?oo>P3oool00>P0oooo00<000000?ooo`3oool0?P3o
ool60000oa@00?oo>P3oool00>P0oooo00<000000?ooo`3oool0@@3oool5
0000oa800?oo>P3oool00>P0oooo00<000000?ooo`3oool0@`3oool50000
oa000?oo>P3oool00>P0oooo00<000000?ooo`3oool0A@3oool50000o`h0
0?oo>P3oool00>P0oooo00<000000?ooo`3oool0A`3oool50000o``00?oo
>P3oool00>P0oooo00<000000?ooo`3oool0B@3oool50000o`X00?oo>P3o
ool00>P0oooo00<000000?ooo`3oool0B`3oool50000o`P00?oo>P3oool0
0>P0oooo00<000000?ooo`3oool0C@3oool50000o`H00?oo>P3oool00>P0
oooo00<000000?ooo`3oool0C`3oool50000o`@00?oo>P3oool00>P0oooo
00<000000?ooo`3oool0D@3oool50000o`800?oo>P3oool00>P0oooo00<0
00000?ooo`3oool0D`3oool40000o`03003oo`3oool0oooo03P0oooo003X
0?ooo`030000003oool0oooo05D0oooo10000?li0?ooo`00j03oool00`00
0000oooo0?ooo`1F0?ooo`D0003o=`3oool00>P0oooo00<000000?ooo`3o
ool0F03oool50000ocD0oooo003X0?ooo`030000003oool0oooo05X0oooo
1@000?lc0?ooo`00j03oool00`000000oooo0?ooo`1L0?ooo`D0003o<@3o
ool00>P0oooo00<000000?ooo`3oool0GP3oool50000obl0oooo003X0?oo
o`030000003oool0oooo0600oooo1@000?l]0?ooo`00j03oool00`000000
oooo0?ooo`1R0?ooo`D0003o:`3oool00>P0oooo00<000000?ooo`3oool0
I03oool60000obP0oooo003X0?ooo`030000003oool0oooo06H0oooo1P00
0?lV0?ooo`00j03oool00`000000oooo0?ooo`1Y0?ooo`D0003o903oool0
0>P0oooo00<000000?ooo`3oool0J`3oool50000ob80oooo003X0?ooo`03
0000003oool0oooo06d0oooo10000?lQ0?ooo`00o`3ooomK0?ooo`030000
o`3oool0oooo0200oooo003o0?ooogh0oooo003o0?ooogh0oooo003o0?oo
ogh0oooo003o0?ooogh0oooo003o0?ooogh0oooo003o0?ooogh0oooo003o
0?ooogh0oooo003D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0W@3oool00=<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`2L0?ooo`00b`3oool4000000<0oooo00@000000?ooo`3oool0
oooo0P0000000`3oool00000000000040?ooo`030000003oool0oooo00L0
oooo100000070?ooo`80000000<0oooo000000000000Q03oool00<`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000D0oooo00<000000?ooo`3oool04`3oool00`000000oooo
000000250?ooo`00c03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`070?ooo`@000002@3oool00`000000oooo0?ooo`240?ooo`00b`3oool4
000000<0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000000
00040?ooo`030000003oool0oooo0180oooo0P0000000`3oool000000000
00240?ooo`00c03oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0W03oool00<d0oooo0P0000050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0W@3oool00?l0
ooooOP3oool00?l0ooooOP3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{381, 138},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.13.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[x] = x\)],
    AspectRatioFixed->True],
  "  and investigate the ",
  " Cauchy Principal Value ."
}], "Text"],

Cell[BoxData[{
    \(x = 0; \ Remove[x];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, lim1, lim2, R, x];\)\ \), "\n", 
    \(\(f[x_]\  = \ x;\)\ \), "\n", 
    \(\(F[x_]\  = \[Integral]f[x] \[DifferentialD]x;\)\ \), "\n", 
    \(\(lim\  = \ 
        Limit[\ F[R]\  - \ F[\(-R\)], \ 
          R \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`FilledPlot`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(g1 = 
        Plot[f[x], {x, \(-1.5\), 0}, 
          PlotStyle \[Rule] {Thickness[0.01], Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[f[x], {x, 0, 1.5}, PlotStyle \[Rule] {Thickness[0.01], Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g11 = 
        FilledPlot[f[x], {x, \(-1\), 0}, PlotStyle \[Rule] Red, 
          Fills \[Rule] Pink, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g22 = 
        FilledPlot[f[x], {x, 0, 1}, PlotStyle \[Rule] Blue, 
          Fills \[Rule] Cyan, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(ends = 
        Graphics[{{Text["\<-R\>", {\(-1\), 
                  0}, {0, \(-1\)}]}, {Text["\<R\>", {1, 0}, {0, 
                  1}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[g11, g22, g1, g2, ends, 
        PlotRange \[Rule] {{\(-1.25\), 1.25}, {\(-1.25\), 1.25}}, 
        AspectRatio \[Rule] 
          1\/2, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<   s = f[x]\
\>"}, Ticks \[Rule] None, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), "\n", 
    \(\(Print["\<         f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print["\<         F[x] = \[Integral] x \[DifferentialD]x = \>", 
        F[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(R \[Rule] \[Infinity]\)\) \
\!\(\[Integral]\_\(-R\)\%R\) x \[DifferentialD]x = \!\(lim\+\(R \[Rule] \
\[Infinity]\)\) (\!\(\[Integral]\_\(-R\)\%0\) \>\"", 
        f[x], \*"\"\< \[DifferentialD]x + \!\(\[Integral]\_0\%R\) \>\"", 
        f[x], "\< \[DifferentialD]x) = \>", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(R \[Rule] \[Infinity]\)\) \
\!\(\[Integral]\_\(-R\)\%R\) x \[DifferentialD]x = \!\(lim\+\(R \[Rule] \
\[Infinity]\)\) ((\>\"", F[x], "\<)\>", "\<|\>"\+\(-R\)\%0, "\< + (\>", 
        F[x], "\<)\>", "\<|\>"\+0\%R, "\<) = \>", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(R \[Rule] \[Infinity]\)\) \
\!\(\[Integral]\_\(-R\)\%R\) x \[DifferentialD]x = \!\(lim\+\(R \[Rule] \
\[Infinity]\)\) ((\>\"", \[Integral]\_\(-R\)\%0\ 
          f[x]\ \[DifferentialD]x, "\<) + (\>", \[Integral]\_0\%R\ 
          f[x]\ \[DifferentialD]x, "\<)) = \>", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(R \[Rule] \[Infinity]\)\) \
\!\(\[Integral]\_\(-R\)\%R\) x \[DifferentialD]x = \!\(lim\+\(R \[Rule] \
\[Infinity]\)\) (\>\"", F[R], "\< - \>", F[\(-R\)], "\<) = \>", 
        lim];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(R \[Rule] \[Infinity]\)\) \
\!\(\[Integral]\_\(-R\)\%R\) x \[DifferentialD]x = \!\(lim\+\(R \[Rule] \
\[Infinity]\)\) (\>\"", F[R] - \ F[\(-R\)], "\<) = \>", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<P.V. \!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\) \>\
\"", f[x], "\< \[DifferentialD]x = \>", lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  Cell[BoxData[
      \("\!\(lim\+\(R \[Rule] \[Infinity]\)\) \!\(\[Integral]\_\(-R\)\%R\) \
|x| \[DifferentialD]x"\ \  = \ \ \("\!\(lim\+\(R \[Rule] \[Infinity]\)\)"\ \
\((\[Integral]\_\(-R\)\%0\ \(\(|\)\(x\)\(|\)\(\[DifferentialD]x\ \  + \ \ \
\[Integral]\_0\%R\)\(\ \)\(|\)\(x\)\(|\)\(\[DifferentialD]x\)\)\ )\)\ \  = \ \
\ \("\!\(lim\+\(R \[Rule] \[Infinity]\)\)"\ \((R\^2\/2 + 
                  R\^2\/2)\)\ \  = \ \ \("\!\(lim\+\(R \[Rule] \
\[Infinity]\)\)"\ \((\ R\^2\ )\)\ \  = \ \ \[Infinity]\)\)\)\)],
    AspectRatioFixed->True],
  ",  \n\nand Equation ",
  StyleBox["(8-7)",
    FontColor->RGBColor[0, 0, 1]],
  " tells us that the improper integral of  ",
  Cell[BoxData[
      \(f \((x)\) = \(\(|\)\(x\)\(|\)\)\)],
    AspectRatioFixed->True],
  "  over",
  StyleBox[" ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      StyleBox[\((\(-\[Infinity]\), \[Infinity])\),
        FontWeight->"Plain",
        FontColor->GrayLevel[0]]],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  also diverges to ",
  Cell[BoxData[
      RowBox[{
        StyleBox["'",
          FontColor->GrayLevel[0]], \(\[Infinity]'\)}]]],
  ", because  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\ \(\(|\)\(x\)\(|\)\(\
\[DifferentialD]x\)\)\ \  = \ \ \(lim\+\(a\  \[Rule] \ \(-\[Infinity]\)\)\ \
\[Integral]\_a\%0\  | 
            x | \[DifferentialD]x\ \  + \ \ lim\+\(b\  \[Rule] \ \
\[Infinity]\)\ \[Integral]\_0\%b\  | 
            x | \[DifferentialD]x\ \  = \ \ \(\[Infinity] + \[Infinity]\ \  = \
\ \ \[Infinity]\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005m0000RR000`400?l0
0000o`00003oo`3ooomn0?ooo`00o`3ooomn0?ooo`00o`3ooomn0?ooo`00
o`3ooomn0?ooo`00o`3ooomn0?ooo`00j03oool00`000000oooo0?ooo`2B
0?ooo`00j03oool00`000000oooo0?ooo`2B0?ooo`00j03oool00`000000
oooo0?ooo`2B0?ooo`00j03oool00`000000oooo0?ooo`2B0?ooo`00j03o
ool00`000000oooo0?ooo`2B0?ooo`00j03oool00`000000oooo0?ooo`2B
0?ooo`00j03oool00`000000oooo0?ooo`2B0?ooo`00j03oool00`000000
oooo0?ooo`2B0?ooo`00j03oool00`000000oooo0?ooo`2B0?ooo`00j03o
ool00`000000oooo0?ooo`2B0?ooo`00j03oool00`000000oooo0?ooo`2B
0?ooo`00j03oool00`000000oooo0?ooo`2B0?ooo`00S@3oool300000080
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1E0?ooo`<0
00000P3oool00`000000oooo0?ooo`0e0?ooo`00R03oool400000080oooo
00@000000?ooo`3oool00000EP3oool00`000000oooo0?ooo`1F0?ooo`04
0000003oool0oooo000003P0oooo002>0?ooo`<00000E`3oool00`000000
oooo0?ooo`1F0?ooo`<00000>@3oool008h0oooo00@000000?ooo`3oool0
0000EP3oool00`000000oooo0?ooo`1F0?ooo`040000003oool0oooo0000
03P0oooo002>0?ooo`040000003oool0oooo000005H0oooo00<000000?oo
o`3oool0EP3oool010000000oooo0?ooo`00000h0?ooo`00S@3oool40000
05L0oooo00<000000?ooo`3oool0E@3oool4000003T0oooo003X0?ooo`03
0000003oool0oooo07L0oooo0P0000000`3oool000000000000F0?ooo`00
MP3ooooU000000P0oooo00<000000?ooo`0000005`3oool008d0ooooF@3o
`</20?l00003000000000?l0003o05P00?oo8@3oool00`000000oooo0?oo
o`0F0?ooo`00S@3ooomH0?o0b`<0o`0000<000000000o`000?l00P000?mF
003ooal0oooo0P0000000`3oool000000000000F0?ooo`00S@3ooomG0?o0
b`<0o`0000<0oooo0000003oool010000?mE003oocX0oooo002=0?oooeH0
ol3;0`3o00020?ooo`040000003oool0oooo0?ooo`<0003oE000oolj0?oo
o`00S@3ooomE0?o0b`<0o`000`3oool00`000000oooo0?ooo`020?ooo`<0
003oD`00oolj0?ooo`00S@3ooomD0?o0b`<0o`00103oool00`000000oooo
0?ooo`030?ooo`<0003oDP00oolj0?ooo`00S@3ooomB0?o0b`@0o`001@3o
ool00`000000oooo0?ooo`040?ooo`@0003oD000oolj0?ooo`00S@3ooomA
0?o0b`@0o`001P3oool00`000000oooo0?ooo`050?ooo`@0003oC`00oolj
0?ooo`00S@3ooom@0?o0b`<0o`00203oool00`000000oooo0?ooo`070?oo
o`<0003oCP00oolj0?ooo`00S@3ooom>0?o0b`@0o`002@3oool00`000000
oooo0?ooo`080?ooo`<0003oC@00oolj0?ooo`00S@3ooom=0?o0b`@0o`00
2P3oool00`000000oooo0?ooo`090?ooo`<0003oC000oolj0?ooo`00S@3o
oom;0?o0b`@0o`00303oool00`000000oooo0?ooo`0:0?ooo`<0003oB`00
oolj0?ooo`00S@3ooom:0?o0b`@0o`003@3oool00`000000oooo0?ooo`0;
0?ooo`<0003oBP00oolj0?ooo`00S@3ooom90?o0b`<0o`003`3oool00`00
0000oooo0?ooo`0<0?ooo`<0003oB@00oolj0?ooo`00S@3ooom80?o0b`<0
o`00403oool00`000000oooo0?ooo`0=0?ooo`<0003oB000oolj0?ooo`00
S@3ooom70?o0b`<0o`004@3oool00`000000oooo0?ooo`0>0?ooo`@0003o
AP00oolj0?ooo`00S@3ooom60?o0b`<0o`004P3oool00`000000oooo0?oo
o`0?0?ooo`@0003oA@00oolj0?ooo`00S@3ooom50?o0b`<0o`004`3oool0
0`000000oooo0?ooo`0A0?ooo`@0003o@`00oolj0?ooo`00S@3ooom40?o0
b`<0o`00503oool00`000000oooo0?ooo`0B0?ooo`@0003o@P00oolj0?oo
o`00S@3ooom30?o0b`<0o`005@3oool00`000000oooo0?ooo`0D0?ooo`<0
003o@@00oolj0?ooo`00S@3ooom10?o0b`@0o`005P3oool00`000000oooo
0?ooo`0E0?ooo`@0003o?`00oolj0?ooo`00S@3ooom00?o0b`@0o`005`3o
ool00`000000oooo0?ooo`0F0?ooo`@0003o?P00oolj0?ooo`00S@3ooolo
0?o0b`<0o`006@3oool00`000000oooo0?ooo`0H0?ooo`<0003o?@00oolj
0?ooo`00S@3oooln0?o0b`<0o`006P3oool00`000000oooo0?ooo`0I0?oo
o`<0003o?000oolj0?ooo`00S@3ooolm0?o0b`<0o`006`3oool00`000000
oooo0?ooo`0J0?ooo`<0003o>`00oolj0?ooo`00S@3ooolk0?o0b`@0o`00
703oool00`000000oooo0?ooo`0K0?ooo`<0003o>P00oolj0?ooo`00S@3o
oolj0?o0b`@0o`007@3oool00`000000oooo0?ooo`0L0?ooo`<0003o>@00
oolj0?ooo`00S@3oooli0?o0b`<0o`007`3oool00`000000oooo0?ooo`0M
0?ooo`<0003o>000oolj0?ooo`00S@3ooolh0?o0b`<0o`00803oool00`00
0000oooo0?ooo`0N0?ooo`<0003o=`00oolj0?ooo`00S@3ooolg0?o0b`<0
o`008@3oool00`000000oooo0?ooo`0O0?ooo`<0003o=P00oolj0?ooo`00
S@3ooole0?o0b`@0o`008P3oool00`000000oooo0?ooo`0P0?ooo`@0003o
=000oolj0?ooo`00S@3ooold0?o0b`@0o`008`3oool00`000000oooo0?oo
o`0Q0?ooo`@0003o<`00oolj0?ooo`00S@3ooolc0?o0b`<0o`009@3oool0
0`000000oooo0?ooo`0S0?ooo`<0003o<P00oolj0?ooo`00S@3ooolb0?o0
b`<0o`009P3oool00`000000oooo0?ooo`0T0?ooo`<0003o<@00oolj0?oo
o`00S@3oool`0?o0b`@0o`009`3oool00`000000oooo0?ooo`0U0?ooo`<0
003o<000oolj0?ooo`00S@3oool_0?o0b`@0o`00:03oool00`000000oooo
0?ooo`0V0?ooo`@0003o;P00oolj0?ooo`00S@3oool^0?o0b`<0o`00:P3o
ool00`000000oooo0?ooo`0W0?ooo`@0003o;@00oolj0?ooo`00S@3oool]
0?o0b`<0o`00:`3oool00`000000oooo0?ooo`0Y0?ooo`<0003o;000oolj
0?ooo`00S@3oool/0?o0b`<0o`00;03oool00`000000oooo0?ooo`0Z0?oo
o`<0003o:`00oolj0?ooo`00S@3ooolZ0?o0b`@0o`00;@3oool00`000000
oooo0?ooo`0[0?ooo`<0003o:P00oolj0?ooo`00S@3ooolY0?o0b`@0o`00
;P3oool00`000000oooo0?ooo`0/0?ooo`@0003o:000oolj0?ooo`00S@3o
oolX0?o0b`<0o`00<03oool00`000000oooo0?ooo`0]0?ooo`@0003o9`00
oolj0?ooo`00S@3ooolW0?o0b`<0o`00<@3oool00`000000oooo0?ooo`0_
0?ooo`<0003o9P00oolj0?ooo`00S@3ooolV0?o0b`<0o`00<P3oool00`00
0000oooo0?ooo`0`0?ooo`<0003o9@00oolj0?ooo`00S@3ooolT0?o0b`@0
o`00<`3oool00`000000oooo0?ooo`0a0?ooo`@0003o8`00oolj0?ooo`00
S@3ooolS0?o0b`@0o`00=03oool00`000000oooo0?ooo`0b0?ooo`@0003o
8P00oolj0?ooo`00S@3ooolR0?o0b`<0o`00=P3oool00`000000oooo0?oo
o`0d0?ooo`<0003o8@00oolj0?ooo`00S@3ooolQ0?o0b`<0o`00=`3oool0
0`000000oooo0?ooo`0e0?ooo`<0003o8000oolj0?ooo`00S@3ooolP0?o0
b`<0o`00>03oool00`000000oooo0?ooo`0f0?ooo`<0003o7`00oolj0?oo
o`00S@3ooolO0?o0b`<0o`00>@3oool00`000000oooo0?ooo`0g0?ooo`@0
003o7@00oolj0?ooo`00S@3ooolN0?o0b`<0o`00>P3oool00`000000oooo
0?ooo`0h0?ooo`@0003o7000oolj0?ooo`00S@3ooolM0?o0b`<0o`00>`3o
ool00`000000oooo0?ooo`0j0?ooo`<0003o6`00oolj0?ooo`00S@3ooolK
0?o0b`@0o`00?03oool00`000000oooo0?ooo`0k0?ooo`<0003o6P00oolj
0?ooo`00S@3ooolJ0?o0b`@0o`00?@3oool00`000000oooo0?ooo`0l0?oo
o`<0003o6@00oolj0?ooo`00S@3ooolH0?o0b`@0o`00?`3oool00`000000
oooo0?ooo`0m0?ooo`@0003o5`00oolj0?ooo`00S@3ooolG0?o0b`@0o`00
@03oool00`000000oooo0?ooo`0n0?ooo`@0003o5P00oolj0?ooo`00S@3o
oolF0?o0b`<0o`00@P3oool00`000000oooo0?ooo`100?ooo`<0003o5@00
oolj0?ooo`00S@3ooolE0?o0b`<0o`00@`3oool00`000000oooo0?ooo`11
0?ooo`<0003o5000oolj0?ooo`00S@3ooolC0?o0b`@0o`00A03oool00`00
0000oooo0?ooo`120?ooo`@0003o4P00oolj0?ooo`00S@3ooolB0?o0b`@0
o`00A@3oool00`000000oooo0?ooo`130?ooo`@0003o4@00oolj0?ooo`00
S@3ooolA0?o0b`<0o`00A`3oool00`000000oooo0?ooo`150?ooo`<0003o
4000oolj0?ooo`00S@3oool@0?o0b`<0o`00B03oool00`000000oooo0?oo
o`160?ooo`<0003o3`00oolj0?ooo`00S@3oool?0?o0b`<0o`00B@3oool0
0`000000oooo0?ooo`170?ooo`<0003o3P00oolj0?ooo`00S@3oool>0?o0
b`<0o`00BP3oool00`000000oooo0?ooo`180?ooo`@0003o3000oolj0?oo
o`00S@3oool=0?o0b`<0o`00B`3oool00`000000oooo0?ooo`190?ooo`@0
003o2`00oolj0?ooo`00S@3oool<0?o0b`<0o`00C03oool00`000000oooo
0?ooo`1;0?ooo`<0003o2P00oolj0?ooo`00S@3oool:0?o0b`@0o`00C@3o
ool00`000000oooo0?ooo`1<0?ooo`<0003o2@00oolj0?ooo`00S@3oool9
0?o0b`@0o`00CP3oool00`000000oooo0?ooo`1=0?ooo`<0003o2000oolj
0?ooo`00S@3oool70?o0b`@0o`00D03oool00`000000oooo0?ooo`1>0?oo
o`@0003o1P00oolj0?ooo`00S@3oool60?o0b`@0o`00D@3oool00`000000
oooo0?ooo`1?0?ooo`@0003o1@00oolj0?ooo`00S@3oool50?o0b`<0o`00
D`3oool00`000000oooo0?ooo`1A0?ooo`<0003o1000oolj0?ooo`00S@3o
ool40?o0b`<0o`00E03oool00`000000oooo0?ooo`1B0?ooo`<0003o0`00
oolj0?ooo`00S@3oool20?o0b`@0o`00E@3oool00`000000oooo0?ooo`1C
0?ooo`<0003o0P00oolj0?ooo`00S@3oool00`3o`</0o`000?l000020?l0
05H0oooo00<000000?ooo`3oool0E03oool40000ocX0oooo002=0?ooo`<0
o`00F03oool00`000000oooo0?ooo`1E0?ooo`@0003o>@3oool008`0oooo
0`3o001I0?ooo`030000003oool0oooo05L0oooo0`000?lh0?ooo`00R`3o
ool30?l005X0oooo00<000000?ooo`3oool0F03oool30000ocL0oooo002:
0?ooo`<0o`00F`3oool00`000000oooo0?ooo`1I0?ooo`@0003o=@3oool0
08T0oooo0`3o001L0?ooo`030000003oool0oooo05X0oooo10000?ld0?oo
o`00R03oool30?l005d0oooo00<000000?ooo`3oool0G03oool30000oc<0
oooo00270?ooo`<0o`00GP3oool00`000000oooo0?ooo`1M0?ooo`<0003o
<P3oool008H0oooo0`3o001O0?ooo`030000003oool0oooo05h0oooo0`00
0?la0?ooo`00Q03oool40?l00600oooo00<000000?ooo`3oool0G`3oool4
0000obl0oooo00230?ooo`@0o`00H@3oool00`000000oooo0?ooo`1P0?oo
o`@0003o;P3oool00880oooo0`3o001S0?ooo`030000003oool0oooo0680
oooo0`000?l]0?ooo`00P03oool40?l006@0oooo00<000000?ooo`3oool0
H`3oool30000ob`0oooo001o0?ooo`@0o`00I@3oool00`000000oooo0?oo
o`1T0?ooo`<0003o:`3oool007d0oooo103o001W0?ooo`030000003oool0
oooo06D0oooo10000?lY0?ooo`00O03oool40?l006P0oooo00<000000?oo
o`3oool0IP3oool40000obP0oooo001k0?ooo`<0o`00JP3oool00`000000
oooo0?ooo`1X0?ooo`<0003o9`3oool007X0oooo0`3o001[0?ooo`030000
003oool0oooo06T0oooo0`000?lV0?ooo`00N03oool40?l006`0oooo00<0
00000?ooo`3oool0JP3oool40000ob@0oooo001g0?ooo`@0o`00K@3oool0
0`000000oooo0?ooo`1[0?ooo`@0003o8`3oool007H0oooo0`3o001_0?oo
o`030000003oool0oooo06d0oooo0`000?lR0?ooo`00M@3oool30?l00700
oooo00<000000?ooo`3oool0KP3oool30000ob40oooo001f0?ooo`030?l0
003oool0oooo0>40oooo00<0003o0?ooo`3oool0803oool00?l0ooooOP3o
ool00?l0ooooOP3oool00?l0ooooOP3oool00?l0ooooOP3oool00?l0oooo
OP3oool00?l0ooooOP3oool00?l0ooooOP3oool00=@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0M`3oool00=<0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0M`3oool00</0oooo100000030?ooo`040000
003oool0oooo0?ooo`80000000<0oooo000000000000103oool00`000000
oooo0?ooo`070?ooo`@000002P3oool00`000000oooo0?ooo`0200000003
0?ooo`000000000000@0oooo00<000000?ooo`3oool0M`3oool00<`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000D0oooo00<000000?ooo`3oool05@3oool01`000000oooo
0?ooo`3oool000000?ooo`0000001@3oool00`000000oooo0?ooo`1g0?oo
o`00c03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`@0
00002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0M`3oool00</0oooo100000030?ooo`040000
003oool0oooo0?ooo`80000000<0oooo000000000000103oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0080000000<0oooo00000000
0000103oool00`000000oooo0?ooo`1g0?ooo`00c03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo07L0oooo
003=0?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`1g0?ooo`00o`3ooomn0?ooo`00o`3ooomn0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{381, 138},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[x] = \(\(\(|\)\(x\)\(|\)\)\  = \ Abs[x]\)\)],
    AspectRatioFixed->True],
  "  and investigate the ",
  " Cauchy Principal Value ."
}], "Text"],

Cell[BoxData[{
    \(x = 0; \ Remove[x];\ \), "\n", 
    \(\(Clear[f, F, lim1, lim2, R, x];\)\ \), "\n", 
    \(\(f[x_]\  = \ Abs[x];\)\ \), "\n", 
    \(\(F[x_]\  = \[Integral]f[x] \[DifferentialD]x;\)\ \), "\n", 
    \(\(lim\  = \ 
        Limit[\ \[Integral]\_\(-R\)\%0\ \(-x\)\ \[DifferentialD]x + \
\[Integral]\_0\%R\ x\ \[DifferentialD]x, \ 
          R \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(Needs["\<Graphics`FilledPlot`\>"];\)\ \), "\n", 
    \(\(g1 = 
        Plot[f[x], {x, \(-1.5\), 0}, 
          PlotStyle \[Rule] {Thickness[0.01], Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(g2 = 
        Plot[f[x], {x, 0, 1.5}, PlotStyle \[Rule] {Thickness[0.01], Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(g11 = 
        FilledPlot[f[x], {x, \(-1\), 0}, PlotStyle \[Rule] Red, 
          Fills \[Rule] Pink, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(g22 = 
        FilledPlot[f[x], {x, 0, 1}, PlotStyle \[Rule] Blue, 
          Fills \[Rule] Cyan, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(ends = 
        Graphics[{{Text["\<-R\>", {\(-1\), 0}, {0, 1}]}, {Text["\<R\>", {1, 
                  0}, {0, 1}]}}];\)\ \), "\n", 
    \(\(Show[g11, g22, g1, g2, ends, 
        PlotRange \[Rule] {{\(-1.25\), 1.25}, {\(-0.25\), 1.25}}, 
        AspectRatio \[Rule] 
          1\/2, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<   s = f[x]\
\>"}, Ticks \[Rule] None, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), "\n", 
    \(\(Print["\<           f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print["\<           F[x] = \[Integral] x \[DifferentialD]x = \>", 
        F[x]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(R \[Rule] \[Infinity]\)\) \
\!\(\[Integral]\_\(-R\)\%R\) |x| \[DifferentialD]x = \!\(lim\+\(R \[Rule] \
\[Infinity]\)\) (\!\(\[Integral]\_\(-R\)\%0\) \>\"", \(-x\), \*"\"\< \
\[DifferentialD]x + \!\(\[Integral]\_0\%R\) \>\"", 
        x, "\< \[DifferentialD]x) = \>", lim];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(R \[Rule] \[Infinity]\)\) \
\!\(\[Integral]\_\(-R\)\%R\) |x| \[DifferentialD]x = \!\(lim\+\(R \[Rule] \
\[Infinity]\)\) ((\>\"", \[Integral]\(-x\) \[DifferentialD]x, "\<)\>", \
"\<|\>"\+\(-R\)\%0, "\< + (\>", \[Integral]x \[DifferentialD]x, "\<)\>", "\<|\
\>"\+0\%R, "\<) = \>", lim];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(R \[Rule] \[Infinity]\)\) \
\!\(\[Integral]\_\(-R\)\%R\) |x| \[DifferentialD]x = \!\(lim\+\(R \[Rule] \
\[Infinity]\)\) ((\>\"", \[Integral]\_\(-R\)\%0\ \(-x\)\ \[DifferentialD]x, "\
\<) + (\>", \[Integral]\_0\%R\ x\ \[DifferentialD]x, "\<)) = \>", 
        lim];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(R \[Rule] \[Infinity]\)\) \
\!\(\[Integral]\_\(-R\)\%R\) |x| \[DifferentialD]x = \!\(lim\+\(R \[Rule] \
\[Infinity]\)\) (\>\"", \[Integral]\_\(-R\)\%0\ \(-x\)\ \[DifferentialD]x + \
\[Integral]\_0\%R\ x\ \[DifferentialD]x, "\<) = \>", lim];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<P.V. \!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\) \>\
\"", f[x], "\< \[DifferentialD]x = \>", lim];\)\ \)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Definition 8.2 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Cauchy Principal Value - P.V.",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CauchyPrincipalValue.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  " be a continuous real valued function for all ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ".  The Cauchy principal value (P.V.) of the integral  ",
  Cell[BoxData[
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\ 
        f \((x)\) \[DifferentialD]x\)]],
  "  is defined by \n\n\t\t\t",
  Cell[BoxData[
      \(P . 
          V . \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\ 
            f \((x)\) \[DifferentialD]x\)\ \  = \ \ lim\+\(R\  \[Rule] \ \
\[Infinity]\)\ \[Integral]\_\(-R\)\%R\ f \((x)\) \[DifferentialD]x\)]],
  ",  \n\nprovided the limit exists."
}], "Text"],

Cell[TextData[{
  "\tExample 8.13 shows that  ",
  Cell[BoxData[
      \(P . 
          V . \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\ 
            x \[DifferentialD]x\)\ \  = \ \ 0\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 8.14.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Cauchy principal value of  ",
  Cell[BoxData[
      \("\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\!\(1\/\(x\^2\\  + \
\\ 1\)\)\[DifferentialD]x"\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00l`3oool00`000000oooo0?ooo`2M
0?ooo`00l`3oool00`000000oooo0?ooo`2M0?ooo`00l`3oool00`000000
oooo0?ooo`2M0?ooo`00Q@3oool300000080oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`1X0?ooo`<000000P3oool00`000000oooo
0?ooo`0]0?ooo`00P03oool400000080oooo00@000000?ooo`3oool00000
J@3oool00`000000oooo0?ooo`1Y0?ooo`040000003oool0oooo00000300
oooo00260?ooo`<00000JP3oool00`000000oooo0?ooo`1Y0?ooo`<00000
<@3oool008H0oooo00@000000?ooo`3oool00000J@3oool00`000000oooo
0?ooo`1Y0?ooo`040000003oool0oooo00000300oooo00260?ooo`040000
003oool0oooo000006T0oooo00<000000?ooo`3oool0J@3oool010000000
oooo0?ooo`00000`0?ooo`00Q@3oool4000006X0oooo00<000000?ooo`3o
ool0J03oool400000340oooo003c0?ooo`030000003oool0oooo09d0oooo
003c0?ooo`030000003oool0oooo0840oooo0P0000000`3oool000000000
000G0?ooo`00M`3ooooi000000P0oooo00<000000?ooo`000000603oool0
08@0ooooK`3o`</00`0000000?oo003oo`1[003ooaP0oooo00<000000?oo
o`3oool05`3oool008@0ooooK`3o`</00`0000000?oo003oo`1[003ooaH0
oooo0P0000000`3oool000000000000G0?ooo`00Q03ooom_0?o0b`030000
0000ool00?oo06/00?oo<P3oool008@0ooooK`3o`</00`0000000?oo003o
o`1[003ooc80oooo00240?ooofl0ol3;00<00000003oo`00ool0J`00oolb
0?ooo`00Q03ooom_0?o0b`0300000000ool00?oo06/00?oo<P3oool008@0
ooooK`3o`</00`0000000?oo003oo`1[003ooc80oooo00240?ooofl0ol3;
00<00000003oo`00ool0J`00oolb0?ooo`00Q03ooom_0?o0b`0300000000
ool00?oo06/00?oo<P3oool008@0ooooK`3o`</00`0000000?oo003oo`1[
003ooc80oooo00240?ooofl0ol3;00<00000003oo`00ool0J`00oolb0?oo
o`00Q03ooom_0?o0b`0300000000ool00?oo06/00?oo<P3oool008@0oooo
K`3o`</00`0000000?oo003oo`1[003ooc80oooo00240?ooofl0ol3;00<0
0000003oo`00ool0J`00oolb0?ooo`00Q03ooom_0?o0b`0300000000ool0
0?oo06/00?oo<P3oool008@0ooooK`3o`</00`0000000?oo003oo`1[003o
oc80oooo001g0?ooo`030?l0003oool0oooo00X0ooooK`3o`</00`000000
0?oo003oo`1[003oo`h0oooo00<0003o0?ooo`3oool08@3oool007H0oooo
1@3o00090?ooofl0ol3;00<00000003oo`00ool0J`00ool;0?ooo`D0003o
8P3oool007L0oooo1`3o00060?ooofl0ol3;00<00000003oo`00ool0J`00
ool80?ooo`L0003o8`3oool007X0oooo1`3o00030?ooofl0ol3;00<00000
003oo`00ool0J`00ool50?ooo`L0003o9P3oool007d0oooo2@3o001]0?o0
b`0300000000ool00?oo06X00?oo2P000?lY0?ooo`00P03oool90?l006X0
ol3;00<00000003oo`00ool0I`00ool90000obd0oooo00260?ooo`H0o`00
I`3o`</00`0000000?oo003oo`1U003oo`H0003o<P3oool008P0oooo1P3o
001U0?o0b`0300000000ool00?oo06800?oo1P000?le0?ooo`00R`3oool5
0?l006<0ol3;00<00000003oo`00ool0G`00ool70000ocL0oooo002=0?oo
o`D0o`00H@3o`</00`0000000?oo003oo`1M003oo`H0003o>P3oool008l0
oooo1P3o001N0?o0b`0300000000ool00?oo05/00?oo1@000?lm0?ooo`00
T@3oool70?l005/0ol3;00<00000003oo`00ool0F@00ool50000ocl0oooo
002D0?ooo`H0o`00F@3o`</00`0000000?oo003oo`1F003oo`H0003o@@3o
ool009L0oooo1@3o001G0?o0b`0300000000ool00?oo05@00?oo1P000?m3
0?ooo`00V@3oool50?l005D0ol3;00<00000003oo`00ool0DP00ool50000
odH0oooo002K0?ooo`D0o`00D`3o`</00`0000000?oo003oo`1A003oo`@0
003oB03oool009d0oooo1@3o001A0?o0b`0300000000ool00?oo04l00?oo
10000?m:0?ooo`00W`3oool50?l004l0ol3;00<00000003oo`00ool0CP00
ool40000od/0oooo002Q0?ooo`@0o`00CP3o`</00`0000000?oo003oo`1<
003oo`@0003oC@3oool00:<0oooo0`3o001=0?o0b`0300000000ool00?oo
04X00?oo1@000?m>0?ooo`00Y03oool40?l004/0ol3;00<00000003oo`00
ool0B000ool50000oe00oooo002U0?ooo`@0o`00BP3o`</00`0000000?oo
003oo`16003oo`D0003oDP3oool00:L0oooo103o00180?o0b`0300000000
ool00?oo04D00?oo10000?mD0?ooo`00Z03oool50?l004H0ol3;00<00000
003oo`00ool0@`00ool40000oeH0oooo002Z0?ooo`D0o`00A03o`</00`00
00000?oo003oo`12003oo`@0003oE`3oool00:`0oooo103o00130?o0b`03
00000000ool00?oo04400?oo0`000?mI0?ooo`00[P3oool30?l00480ol3;
00<00000003oo`00ool0@000ool30000oeX0oooo002_0?ooo`@0o`00@03o
`</00`0000000?oo003oo`0o003oo`<0003oF`3oool00;00oooo103o000o
0?o0b`0300000000ool00?oo03h00?oo0`000?mL0?ooo`00/P3oool30?l0
03h0ol3;00<00000003oo`00ool0?@00ool30000oed0oooo002c0?ooo`<0
o`00?@3o`</00`0000000?oo003oo`0l003oo`<0003oGP3oool00;@0oooo
0`3o000l0?o0b`0300000000ool00?oo03/00?oo0`000?mO0?ooo`00]@3o
ool30?l003/0ol3;00<00000003oo`00ool0>@00ool40000of00oooo002f
0?ooo`<0o`00>P3o`</00`0000000?oo003oo`0h003oo`@0003oH@3oool0
0;L0oooo0`3o000i0?o0b`0300000000ool00?oo03L00?oo0`000?mS0?oo
o`00^03oool30?l003P0ol3;00<00000003oo`00ool0=P00ool30000of@0
oooo002i0?ooo`<0o`00=`3o`</00`0000000?oo003oo`0e003oo`<0003o
I@3oool00;X0oooo0`3o000f0?o0b`0300000000ool00?oo03@00?oo0`00
0?mV0?ooo`00^`3oool30?l003D0ol3;00<00000003oo`00ool0<`00ool3
0000ofL0oooo002l0?ooo`<0o`00=03o`</00`0000000?oo003oo`0b003o
o`<0003oJ03oool00;d0oooo0`3o000c0?o0b`0300000000ool00?oo0340
0?oo0`000?mY0?ooo`00_P3oool30?l00380ol3;00<00000003oo`00ool0
<000ool30000ofX0oooo002o0?ooo`<0o`00<@3o`</00`0000000?oo003o
o`0_003oo`<0003oJ`3oool00<00oooo0`3o000`0?o0b`0300000000ool0
0?oo02h00?oo0`000?m/0?ooo`00`@3oool30?l002l0ol3;00<00000003o
o`00ool0;@00ool30000ofd0oooo00320?ooo`<0o`00;P3o`</00`000000
0?oo003oo`0/003oo`<0003oKP3oool00<<0oooo0`3o000]0?o0b`030000
0000ool00?oo02/00?oo0`000?m_0?ooo`00a03oool30?l002`0ol3;00<0
0000003oo`00ool0:P00ool30000og00oooo00350?ooo`<0o`00:`3o`</0
0`0000000?oo003oo`0Y003oo`<0003oL@3oool00<H0oooo0`3o000Z0?o0
b`0300000000ool00?oo02P00?oo0`000?mb0?ooo`00a`3oool20?l002X0
ol3;00<00000003oo`00ool09`00ool30000og<0oooo00380?ooo`80o`00
:@3o`</00`0000000?oo003oo`0V003oo`<0003oM03oool00<P0oooo0`3o
000X0?o0b`0300000000ool00?oo02D00?oo0`000?me0?ooo`00b@3oool3
0?l002L0ol3;00<00000003oo`00ool09@00ool20000ogH0oooo003:0?oo
o`80o`009`3o`</00`0000000?oo003oo`0T003oo`80003oM`3oool00</0
oooo0P3o000V0?o0b`0300000000ool00?oo02<00?oo0P000?mh0?ooo`00
c03oool20?l002D0ol3;00<00000003oo`00ool08P00ool20000ogT0oooo
003=0?ooo`030?l0003o`</0ol3;02<0ol3;00<00000003oo`00ool08P00
ool20000ogT0oooo003=0?ooo`80o`00903o`</00`0000000?oo003oo`0Q
003oo`80003oNP3oool00<h0oooo0P3o000S0?o0b`0300000000ool00?oo
02000?oo0P000?mk0?ooo`00c`3oool20?l00280ol3;00<00000003oo`00
ool07`00ool20000og`0oooo003@0?ooo`80o`008@3o`</00`0000000?oo
003oo`0O003oo`030000o`3oool0oooo07/0oooo003@0?ooo`<0o`00803o
`</00`0000000?oo003oo`0N003oo`80003oO@3oool00=40oooo0`3o000O
0?o0b`0300000000ool00?oo01d00?oo0P000?mn0?ooo`00dP3oool20?l0
01l0ol3;00<00000003oo`00ool07000ool20000ogl0oooo003C0?ooo`80
o`007P3o`</00`0000000?oo003oo`0L003oo`030000o`3oool0oooo07h0
oooo003C0?ooo`<0o`007@3o`</00`0000000?oo003oo`0K003oo`80003o
P03oool00=@0oooo0`3o000L0?o0b`0300000000ool00?oo01X00?oo0P00
0?n10?ooo`00e@3oool20?l001`0ol3;00<00000003oo`00ool06@00ool2
0000oh80oooo003F0?ooo`80o`006`3o`</00`0000000?oo003oo`0H003o
o`<0003oPP3oool00=L0oooo0P3o000J0?o0b`0300000000ool00?oo01L0
0?oo0`000?n30?ooo`00f03oool20?l001T0ol3;00<00000003oo`00ool0
5`00ool20000oh@0oooo003I0?ooo`030?l0003o`</0ol3;01L0ol3;00<0
0000003oo`00ool05P00ool20000ohD0oooo003I0?ooo`80o`00603o`</0
0`0000000?oo003oo`0E003oo`<0003oQ@3oool00=X0oooo0P3o000G0?o0
b`0300000000ool00?oo01@00?oo0`000?n60?ooo`00f`3oool20?l001H0
ol3;00<00000003oo`00ool04`00ool30000ohL0oooo003L0?ooo`80o`00
5@3o`</00`0000000?oo003oo`0B003oo`<0003oR03oool00=`0oooo0`3o
000D0?o0b`0300000000ool00?oo01400?oo0`000?n90?ooo`00g@3oool3
0?l001<0ol3;00<00000003oo`00ool04@00ool20000ohX0oooo003N0?oo
o`<0o`004P3o`</00`0000000?oo003oo`0@003oo`80003oR`3oool00=l0
oooo0`3o000A0?o0b`0300000000ool00?oo00l00?oo0`000?n;0?ooo`00
h03oool30?l00100ol3;00<00000003oo`00ool03P00ool30000oh`0oooo
003Q0?ooo`<0o`003`3o`</00`0000000?oo003oo`0=003oo`<0003oS@3o
ool00>80oooo0`3o000>0?o0b`0300000000ool00?oo00`00?oo0`000?n>
0?ooo`00h`3oool40?l000`0ol3;00<00000003oo`00ool02`00ool30000
ohl0oooo003T0?ooo`@0o`002`3o`</00`0000000?oo003oo`0:003oo`<0
003oT03oool00>H0oooo0`3o000:0?o0b`0300000000ool00?oo00T00?oo
0`000?nA0?ooo`00i`3oool30?l000T0ol3;00<00000003oo`00ool01`00
ool40000oi80oooo003X0?ooo`<0o`00203o`</00`0000000?oo003oo`05
003oo`D0003oT`3oool00>T0oooo103o00060?o0b`0300000000ool00?oo
00@00?oo10000?nE0?ooo`00jP3oool60?l000<0ol3;00@00000003oo`00
ool00?oo1@000?nG0?ooo`00k03oool60?l000030000o`000000003o00H0
003oV03oool00>l0oooo0`3o00000`000?l000000000o`030000oi/0oooo
003c0?ooo`030000003oool0oooo09d0oooo003c0?ooo`030000003oool0
oooo09d0oooo003c0?ooo`030000003oool0oooo09d0oooo003c0?ooo`03
0000003oool0oooo09d0oooo003c0?ooo`030000003oool0oooo09d0oooo
003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0
oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oo
oi@0oooo003L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05d0
oooo003K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1L0?ooo`00d`3o
ool4000000<0oooo00@000000?ooo`3oool0oooo0P0000000`3oool00000
000000040?ooo`030000003oool0oooo00L0oooo1000000>0?ooo`D00000
0P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`80
000000<0oooo000000000000203oool4000000@0oooo00@000000?ooo`3o
ool0oooo1@0000030?ooo`030000003oool0oooo05/0oooo003D0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`030?ooo`D0
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05/0
oooo003D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo
1000000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0F`3oool00=<0oooo1000
00030?ooo`040000003oool0oooo0?ooo`80000000<0oooo000000000000
103oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool200000003
0?ooo`000000000000X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0F`3oool00=@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0G03oool00=D0
oooo0P0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0703oool2000000H0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`800000103oool2000000X0oooo0P0000030?ooo`03
0000003oool0oooo05d0oooo003o0?oooi@0oooo003o0?oooi@0oooo0000
\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  \n\t\t",
  Cell[BoxData[{
      \(\(\(P . 
          V . \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\ \(1\/\(x\^2\  + \ 
                    1\)\) \[DifferentialD]x\)\ \  = \ \ lim\+\(R\  \[Rule] \ \
\[Infinity]\)\ \[Integral]\_\(-R\)\%R\ \(1\/\(x\^2\  + \ 
                    1\)\) \[DifferentialD]x\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \)\(lim\+\(R\  \[Rule] \ \[Infinity]\)\ \([Arctan \((R)\)\ \  - \
\ \ Arctan \((\(-R\))\)]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \)\(lim\+\(R\  \[Rule] \ \[Infinity]\)\ 
            Arctan \((R)\)\ \  - \ \ lim\+\(R\  \[Rule] \ \[Infinity]\)\ 
            Arctan \((\(-R\))\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(\[Pi]\/2\ \  - \ \ \(-\[Pi]\)\/2\)\)\(\ \ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(=\)\(\ \ \)\(\[Pi]\)\)\)}]],
  "   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.14.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Method (i).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Enter the function  ",
  Cell[BoxData[
      \(f[x] = x\)],
    AspectRatioFixed->True],
  "  and investigate the  Cauchy Principal Value ."
}], "Text"],

Cell[BoxData[{
    \(x = 0; \ Remove[x];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, lim1, lim2, R, x];\)\ \), "\n", 
    \(\(f[x_]\  = \ 1\/\(x\^2 + 1\);\)\ \), "\n", 
    \(\(F[x_]\  = \[Integral]f[x] \[DifferentialD]x;\)\ \), "\n", 
    \(\(lim\  = \ 
        Limit[\ F[R]\  - \ F[\(-R\)], \ 
          R \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`FilledPlot`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(g1 = 
        Plot[f[x], {x, \(-2.5\), 0}, 
          PlotStyle \[Rule] {Thickness[0.01], Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[f[x], {x, 0, 2.5}, PlotStyle \[Rule] {Thickness[0.01], Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g11 = 
        FilledPlot[f[x], {x, \(-2\), 0}, PlotStyle \[Rule] Red, 
          Fills \[Rule] Pink, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g22 = 
        FilledPlot[f[x], {x, 0, 2}, PlotStyle \[Rule] Blue, 
          Fills \[Rule] Cyan, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(ends = 
        Graphics[{{Text["\<-R\>", {\(-2\), 0}, {0, 1}]}, {Text["\<R\>", {2, 
                  0}, {0, 1}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[g11, g22, g1, g2, ends, 
        PlotRange \[Rule] {{\(-2.25\), 2.25}, {\(-0.1\), 1.05}}, 
        AspectRatio \[Rule] 
          1\/2, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<   s = f[x]\
\>"}, Ticks \[Rule] None, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), "\n", 
    \(\(Print["\<         f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print["\<         F[x] = \[Integral] x \[DifferentialD]x = \>", 
        F[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(R \[Rule] \[Infinity]\)\) \
\!\(\[Integral]\_\(-R\)\%R\) x \[DifferentialD]x = \!\(lim\+\(R \[Rule] \
\[Infinity]\)\) (\!\(\[Integral]\_\(-R\)\%0\) \>\"", 
        f[x], \*"\"\< \[DifferentialD]x + \!\(\[Integral]\_0\%R\) \>\"", 
        f[x], "\< \[DifferentialD]x) = \>", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(R \[Rule] \[Infinity]\)\) \
\!\(\[Integral]\_\(-R\)\%R\) x \[DifferentialD]x = \!\(lim\+\(R \[Rule] \
\[Infinity]\)\) ((\>\"", F[x], "\<)\>", "\<|\>"\+\(-R\)\%0, "\< + (\>", 
        F[x], "\<)\>", "\<|\>"\+0\%R, "\<) = \>", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(R \[Rule] \[Infinity]\)\) \
\!\(\[Integral]\_\(-R\)\%R\) x \[DifferentialD]x = \!\(lim\+\(R \[Rule] \
\[Infinity]\)\) ((\>\"", \[Integral]\_\(-R\)\%0\ 
          f[x]\ \[DifferentialD]x, "\<) + (\>", \[Integral]\_0\%R\ 
          f[x]\ \[DifferentialD]x, "\<)) = \>", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(R \[Rule] \[Infinity]\)\) \
\!\(\[Integral]\_\(-R\)\%R\) x \[DifferentialD]x = \!\(lim\+\(R \[Rule] \
\[Infinity]\)\) (\>\"", \[Integral]\_\(-R\)\%0\ 
            f[x]\ \[DifferentialD]x\  + \ \[Integral]\_0\%R\ 
            f[x]\ \[DifferentialD]x, "\<) = \>", 
        lim];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<P.V. \!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\) \>\
\"", f[x], "\< \[DifferentialD]x = \>", lim];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method (ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Enter the function  ",
  Cell[BoxData[
      \(f[z] = 1\/\(z\^2\  + \ 1\)\)],
    AspectRatioFixed->True],
  "  and locate the singularities."
}], "Text"],

Cell[BoxData[{
    \(Z = \(z = \(x = 0\)\); \ Remove[x, z, Z];\ \), "\n", 
    \(\(Clear[f, g, Res1, Res2, solset, val];\)\ \), "\n", 
    \(\(f[z_]\  = \ 1\/\(z\^2\  + \ 1\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[Denominator[f[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, 
            z]];\)\ \), "\[IndentingNewLine]", 
    \(\ \(Print[solset];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The singularities are\>"];\)\ \), "\n", 
    \(\(Z\_1\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2];\)\ \), "\n", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell["Determine which poles lie in the upper half plane ?", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_2], Im[Z\_2]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] - 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] - 0.1}, {\(-1\), 
                0}]}];\)\ \), "\n", 
    \(\(Show[dots, centers, 
        PlotRange \[Rule] {{\(-2.2\), 2.2}, {\(-2.2\), 2.2}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<, Is  Im(\>", 
        Z\_1, "\<) > 0 ?  \>", N[Im[Z\_1]] > 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<,  Is  Im(\>", 
        Z\_2, "\<) > 0 ?   \>", 
        N[Im[Z\_2]] > 0];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Compute the residues at  ",
  Cell[BoxData[
      \(z\_2 = \[ImaginaryI]\)]],
  ", and use the residue calculus to compute the value of the integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Res2\  = \ Residue[f[z], {z, Z\_2}];\)\ \), "\[IndentingNewLine]", 
    \(\(val\  = 2  \[Pi]\ \[ImaginaryI]\ \ Res2;\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_2, "\<] = \>", 
        Res2];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{Red, PointSize[0.03], 
            Point[{Re[Z\_2], Im[Z\_2]}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], 
                Im[Z\_2]}, {\(-1.2\), 0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ 
        Graphics[{VioletRed, 
            Circle[{0, 0}, 2, {0, \[Pi]}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(segment = 
        Graphics[{Thickness[0.02], Magenta, 
            Line[{{\(-2\), 0}, {2, 0}}]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, segment, 
        PlotRange \[Rule] {{\(-2.1\), 2.1}, {\(-0.05\), 2.05}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 1, 1]}, 
        AspectRatio \[Rule] 1\/2, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>", 
        Res2\ , "\<) = \>", val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The contour is the semicircle \!\(C\_R\) and interval \
[-R,R],\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<taken with the positive orientation.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value \
of the integral.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"\
", f[x], "\< \[DifferentialD]x = 2\[Pi]\[ImaginaryI](\>", Res2, "\<) = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Or, we can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s integral table and evaluate the integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(int = 
        Integrate[f[x], {x, \(-\[Infinity]\), \[Infinity]}, 
          PrincipalValue \[Rule] True];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        int];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "However, for this simple integral ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s can find the correct answer without resorting to the PrincipalValue \
option."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(g[x_]\  = \[Integral]f[x] \[DifferentialD]x;\)\ \), "\n", 
    \(\(val\  = \[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[
              x] \[DifferentialD]x;\)\ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print["\<g[x] = \[Integral]\>", f[x], "\< \[DifferentialD]x = \>", 
        g[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<g[\[Infinity]] = \>", 
        g[\[Infinity]], "\<,    g[-\[Infinity]] = \>", \ 
        g[\(-\[Infinity]\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = g[\[Infinity]]-g[-\[Infinity]] = (\>", 
        g[\[Infinity]]\ , "\<) - (\>", \ 
        g[\(-\[Infinity]\)], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        g[\[Infinity]]\  - \ 
          g[\(-\[Infinity]\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["The above answer is correct too.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tIf  ",
  Cell[BoxData[
      \(f \((x)\) = \(P \((x)\)\)\/\(Q \((x)\)\)\)]],
  ",  where ",
  StyleBox["P(x)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Q(x)",
    FontFamily->"Courier New"],
  " are polynomials, then ",
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  " is called a rational function.  Techniques in calculus were developed to \
integrate rational functions.  We now show how the Residue Theorem can be \
used to obtain the ",
  StyleBox[ButtonBox["Cauchy",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " principal value of the integral of ",
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  " over  ",
  Cell[BoxData[
      \(\((\(-\[Infinity]\), \[Infinity])\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 8.3 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Contour Integration for Rational Functions",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ContourIntegration.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(f \((z)\) = \(P \((z)\)\)\/\(Q \((z)\)\)\)]],
  "  where ",
  StyleBox["P(x)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Q(x)",
    FontFamily->"Courier New"],
  " are polynomials, of degree m and n , respectively.  If ",
  Cell[BoxData[
      \(Q \((x)\) \[NotEqual] 0\)]],
  " for all real ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " and  ",
  Cell[BoxData[
      \(n \[GreaterEqual] m + 2\)]],
  ",  then the Cauchy Principal Value (P.V.) of the integral is\n\n\t\t\t",
  Cell[BoxData[
      \(P . 
          V . \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                    P \((x)\)\)\/\(Q \((x)\)\)\) \[DifferentialD]x\)\ \  = \ \
\ 2  \[Pi]\ \[ImaginaryI]\ \(\[Sum]\+\(j = 1\)\%k Res[P\/Q, z\_j]\)\)]],
  ".  \n\nwhere  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_k\)}]]],
  "  are the poles of  ",
  Cell[BoxData[
      \(\(P \((z)\)\)\/\(Q \((z)\)\)\)]],
  "  that lie in the upper half plane.   The situation is illustrated in \
Figure 8.4.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 8.4",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/integralsrational/\
IntegralsRationalFigures/mat0804.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  The poles  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_k\)}]]],
  "  of  ",
  Cell[BoxData[
      \(\(P \((x)\)\)\/\(Q \((x)\)\)\)]],
  "  that lie in the upper half-plane. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Proof of Theorem 8.3",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[" is in the book.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.15.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  "Evaluate",
  "  ",
  Cell[BoxData[
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( 
              1\/\(\((x\^2\  + \ 1)\) \((x\^2\  + \ 
                    4)\)\)\) \[DifferentialD]x\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:80000Sb000`400?l0
0000o`00003oo`3ooooo0?ooohX0oooo003o0?ooool0ooooRP3oool00?l0
ooooo`3ooon:0?ooo`00o`3ooooo0?ooohX0oooo003o0?ooool0ooooRP3o
ool00?l0ooooo`3ooon:0?ooo`00dP3oool00`000000oooo0?ooo`3o0?oo
ok@0oooo003B0?ooo`030000003oool0oooo0?P0oooo1@00000n0?ooo`D0
0000L`3oool00=80oooo00<000000?ooo`3oool02@3oool200000>l0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1c0?ooo`00dP3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0>`0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`1c0?ooo`00dP3oool0
0`000000oooo0?ooo`020?ooo`D000000`3oool00`000000oooo0?ooo`3U
0?ooo`@00000103oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo07<0oooo003B0?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3/0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0L`3oool00<X0oooo100000030?oo
o`80o`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
0>d0oooo0P0000110?ooo`800000M@3oool00<X0oooo00<000000?ooo`3o
ool00`3oool40?l000H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`3o0?ooojL0oooo003;0?ooo`040000003oool0oooo0?ooo`H0
o`000`3oool010000000oooo0?ooo`00003o0?ooojd0oooo00340?ooo`@0
0000103oool00`000000oooo0?ooo`060?l000<0oooo1@00003o0?oooj`0
oooo003:0?ooo`040000003oool0oooo00000080oooo103o003o0?oooa`0
oooo00<000000?ooo`3oool0L@3oool2000000030?ooo`00000000000200
oooo003;0?ooo`800000103oool20?l00;80ooooe@00ool:0?ooo`030000
003oool000000240oooo003B0?ooo`030000003oool0oooo0:d0oooo0`00
003E003oo`8000002@3oool00`000000oooo0?ooo`0P0?ooo`00dP3oool0
0`000000oooo0?ooo`2`0?ooomD00?oo2@3oool2000000030?ooo`000000
00000200oooo003B0?ooo`030000003oool0oooo0;40oooo00<0003o0?oo
o`3oool0IP3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo
02d0oooo003B0?ooo`030000003oool0oooo0;40oooo00<0003o0?ooo`3o
ool0IP3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo02d0
oooo003B0?ooo`030000003oool0oooo0;40oooo00<0003o0?ooo`3oool0
IP3oool00`000000oooo0?ooo`1U0?ooo`030000o`3oool0oooo02h0oooo
003B0?ooo`030000003oool0oooo0;40oooo00<0003o0?ooo`3oool0IP3o
ool00`000000oooo0?ooo`1U0?ooo`030000o`3oool0oooo02h0oooo003B
0?ooo`030000003oool0oooo0;40oooo00<0003o0?ooo`3oool0IP3oool0
0`000000oooo0?ooo`1U0?ooo`030000o`3oool0oooo02h0oooo003B0?oo
o`030000003oool0oooo0;40oooo00<0003o0?ooo`3oool0IP3oool00`00
0000oooo0?ooo`1U0?ooo`030000o`3oool0oooo02h0oooo003B0?ooo`03
0000003oool0oooo0;40oooo00<0003o0?ooo`3oool0IP3oool00`000000
oooo0?ooo`1U0?ooo`030000o`3oool0oooo02h0oooo003B0?ooo`030000
003oool0oooo0;40oooo00<0003o0?ooo`3oool0IP3oool00`000000oooo
0?ooo`1U0?ooo`030000o`3oool0oooo02h0oooo003B0?ooo`030000003o
ool0oooo0;40oooo00<0003o0?ooo`3oool0IP3oool00`000000oooo0?oo
o`1U0?ooo`030000o`3oool0oooo02h0oooo003B0?ooo`030000003oool0
oooo0;40oooo00<0003o0?ooo`3oool0IP3oool00`000000oooo0?ooo`1U
0?ooo`030000o`3oool0oooo02h0oooo003B0?ooo`030000003oool0oooo
0;80oooo00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`1U0?oo
o`030000o`3oool0oooo02h0oooo003B0?ooo`030000003oool0oooo0;80
oooo00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`1U0?ooo`03
0000o`3oool0oooo02h0oooo003B0?ooo`030000003oool0oooo0;80oooo
00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`1T0?ooo`030000
o`3oool0oooo02l0oooo003B0?ooo`030000003oool0oooo0;80oooo00<0
003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`1T0?ooo`030000o`3o
ool0oooo02l0oooo003B0?ooo`030000003oool0oooo00P0oooo1@00002U
0?ooo`030000o`3oool0oooo06D0oooo00<000000?ooo`3oool0I03oool0
0`000?l0oooo0?ooo`0_0?ooo`00dP3oool00`000000oooo0?ooo`020?oo
o`D000000`3oool00`000000oooo0?ooo`2U0?ooo`030000o`3oool0oooo
06D0oooo00<000000?ooo`3oool0I03oool00`000?l0oooo0?ooo`0_0?oo
o`00dP3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0Y@3oool00`000?l0oooo0?ooo`1U0?oo
o`030000003oool0oooo06@0oooo00<0003o0?ooo`3oool0;`3oool00=40
oooo0P3o00060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0Y@3oool00`000?l0oooo0?ooo`1U0?ooo`030000003oool0oooo06@0
oooo00<0003o0?ooo`3oool0;`3oool00<X0oooo1@0000000`3oool0o`00
0?l000020?l000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`2V0?ooo`030000o`3oool0oooo06@0oooo00<000000?ooo`3oool0
I03oool00`000?l0oooo0?ooo`0_0?ooo`00c03oool00`000000oooo0?oo
o`060?l000<0oooo00@000000?ooo`3oool000000P3oool200000:P0oooo
00<0003o0?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000
o`3oool0oooo02l0oooo003<0?ooo`030000003oool0oooo00H0o`000`3o
ool500000:/0oooo00<0003o0?ooo`3oool0I03oool00`000000oooo0?oo
o`1S0?ooo`030000o`3oool0oooo0300oooo00340?ooo`@00000103oool0
10000000oooo0?ooo`3oool40?l00;@0oooo00<0003o0?ooo`3oool0I03o
ool00`000000oooo0?ooo`1S0?ooo`030000o`3oool0oooo0300oooo003<
0?ooo`030000003oool0oooo0080oooo0P3o002e0?ooo`030000o`3oool0
oooo06@0oooo00<000000?ooo`3oool0HP3oool00`000?l0oooo0?ooo`0a
0?ooo`00b`3oool2000000D0oooo00<000000?ooo`3oool0]03oool00`00
0?l0oooo0?ooo`1S0?ooo`030000003oool0oooo0680oooo00<0003o0?oo
o`3oool0<@3oool00=80oooo00<000000?ooo`3oool0]03oool00`000?l0
oooo0?ooo`1S0?ooo`030000003oool0oooo0680oooo00<0003o0?ooo`3o
ool0<@3oool00=80oooo00<000000?ooo`3oool0]@3oool00`000?l0oooo
0?ooo`1R0?ooo`030000003oool0oooo0680oooo00<0003o0?ooo`3oool0
<@3oool00=80oooo00<000000?ooo`3oool0]@3oool00`000?l0oooo0?oo
o`1R0?ooo`030000003oool0oooo00T0oooo0`00001F0?ooo`030000o`3o
ool0oooo0340oooo003B0?ooo`030000003oool0oooo0;D0oooo00<0003o
0?ooo`3oool0HP3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo05D0oooo00<0003o0?ooo`3oool0<P3oool00=80oooo00<000000?oo
o`3oool0]@3oool00`000?l0oooo0?ooo`1R0?ooo`040000003oool0oooo
0?ooo`D00000103oool00`000000oooo0?ooo`1D0?ooo`030000o`3oool0
oooo0380oooo003B0?ooo`030000003oool0oooo0;D0oooo00<0003o0?oo
o`3oool0HP3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0E03oool00`000?l0oooo0?ooo`0b
0?ooo`00dP3oool00`000000oooo0?ooo`2f0?ooo`030000o`3oool0oooo
0640oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0000005@0oooo00<0003o0?ooo`3oool0<`3oool00=80
oooo00<000000?ooo`3oool0]P3oool00`000?l0oooo0?ooo`1I0?ooo`D0
00000P3oool20?l000H0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`1C0?ooo`030000o`3oool0oooo03<0oooo003B0?ooo`030000
003oool0oooo0;H0oooo00<0003o0?ooo`3oool0F`3oool010000000oooo
0?ooo`3oool40?l000<0oooo00@000000?ooo`3oool00000F@3oool00`00
0?l0oooo0?ooo`0d0?ooo`00dP3oool00`000000oooo0?ooo`2g0?ooo`03
0000o`3oool0oooo05X0oooo00<000000?ooo`3oool01P3o00020?ooo`D0
0000F03oool00`000?l0oooo0?ooo`0d0?ooo`00K03oool4000002l0oooo
1@00000^0?ooo`030000003oool0oooo02h0oooo1@00000^0?ooo`@00000
DP3oool00`000?l0oooo0?ooo`1J0?ooo`030000003oool0oooo00H0o`00
G`3oool00`000?l0oooo0?ooo`0d0?ooo`00K03oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo05@0oooo00<0
003o0?ooo`3oool0F@3oool010000000oooo0?ooo`3oool40?l00600oooo
00<0003o0?ooo`3oool0=03oool006d0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`1C0?ooo`030000o`3o
ool0oooo05P0oooo0P0000040?ooo`80o`00H@3oool00`000?l0oooo0?oo
o`0d0?ooo`00IP3oool4000000@0oooo00<000000?ooo`3oool0:03oool4
000000@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0DP3oool0
0`000?l0oooo0?ooo`1O0?ooo`030000003oool0oooo05h0oooo00<0003o
0?ooo`3oool0=@3oool006`0oooo00@000000?ooo`3oool00000<@3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool0;P3oool010000000oooo0?ooo`00001D0?ooo`030000o`3o
ool0oooo05h0oooo00<000000?ooo`3oool0GP3oool00`000?l0oooo0?oo
o`0e0?ooo`00K@3oool200000340oooo0P00000`0?ooo`030000003oool0
oooo02l0oooo0P00000a0?ooo`800000E@3oool00`000?l0oooo0?ooo`1N
0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool0=P3oool0
0=80oooo00<000000?ooo`3oool0^P3oool00`000?l0oooo0?ooo`1M0?oo
o`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool0=P3oool00=80
oooo00<000000?ooo`3oool0^P3oool00`000?l0oooo0?ooo`1M0?ooo`03
0000003oool0oooo05d0oooo00<0003o0?ooo`3oool0=P3oool00=80oooo
00<000000?ooo`3oool0^`3oool00`000?l0oooo0?ooo`1L0?ooo`030000
003oool0oooo05`0oooo00<0003o0?ooo`3oool0=`3oool00=80oooo00<0
00000?ooo`3oool0^`3oool00`000?l0oooo0?ooo`1L0?ooo`030000003o
ool0oooo05`0oooo00<0003o0?ooo`3oool0=`3oool00=80oooo00<00000
0?ooo`3oool0M@3oool2000000030?ooo`00000000000440oooo00<0003o
0?ooo`3oool0G03oool00`000000oooo0?ooo`1K0?ooo`030000o`3oool0
oooo03P0oooo001Q0?ooon<000001`3oool00`000000oooo000000130?oo
o`030000o`3oool0oooo05/0oooo00<000000?ooo`3oool0FP3oool00`00
0?l0oooo0?ooo`0i0?ooo`00J`3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0@P3oool00`000?l0oooo0?ooo`1K0?ooo`030000003oool0oooo05T0
oooo00<0003o0?ooo`3oool0>P3oool006/0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0?0?ooo`800000
00<0oooo000000000000@`3oool00`000?l0oooo0?ooo`1J0?ooo`030000
003oool0oooo05T0oooo00<0003o0?ooo`3oool0>P3oool00=80oooo00<0
00000?ooo`3oool0_@3oool00`000?l0oooo0?ooo`1J0?ooo`030000003o
ool0oooo05T0oooo00<0003o0?ooo`3oool0>P3oool00=80oooo00<00000
0?ooo`3oool0_P3oool00`000?l0oooo0?ooo`1I0?ooo`030000003oool0
oooo05P0oooo00<0003o0?ooo`3oool0>`3oool00=80oooo00<000000?oo
o`3oool0_P3oool00`000?l0oooo0?ooo`1I0?ooo`030000003oool0oooo
05P0oooo00<0003o0?ooo`3oool0>`3oool00=80oooo00<000000?ooo`3o
ool0_`3oool00`000?l0oooo0?ooo`1H0?ooo`030000003oool0oooo05L0
oooo00<0003o0?ooo`3oool0?03oool00=80oooo00<000000?ooo`3oool0
`03oool00`000?l0oooo0?ooo`1G0?ooo`030000003oool0oooo05L0oooo
00<0003o0?ooo`3oool0?03oool00=80oooo00<000000?ooo`3oool0`03o
ool00`000?l0oooo0?ooo`1G0?ooo`030000003oool0oooo05H0oooo00<0
003o0?ooo`3oool0?@3oool00=80oooo00<000000?ooo`3oool0`@3oool0
0`000?l0oooo0?ooo`1F0?ooo`030000003oool0oooo05D0oooo00<0003o
0?ooo`3oool0?P3oool00=80oooo00<000000?ooo`3oool0`@3oool00`00
0?l0oooo0?ooo`1F0?ooo`030000003oool0oooo05@0oooo00<0003o0?oo
o`3oool0?`3oool00=80oooo00<000000?ooo`3oool0`P3oool00`000?l0
oooo0?ooo`1E0?ooo`030000003oool0oooo05@0oooo00<0003o0?ooo`3o
ool0?`3oool00=80oooo00<000000?ooo`3oool0``3oool00`000?l0oooo
0?ooo`1D0?ooo`030000003oool0oooo05<0oooo00<0003o0?ooo`3oool0
@03oool00=80oooo00<000000?ooo`3oool0a03oool00`000?l0oooo0?oo
o`1C0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool0@@3o
ool00=80oooo00<000000?ooo`3oool0a03oool00`000?l0oooo0?ooo`1C
0?ooo`030000003oool0oooo0540oooo00<0003o0?ooo`3oool0@P3oool0
0=80oooo00<000000?ooo`3oool0a@3oool00`000?l0oooo0?ooo`1B0?oo
o`030000003oool0oooo0540oooo00<0003o0?ooo`3oool0@P3oool00=80
oooo00<000000?ooo`3oool0aP3oool00`000?l0oooo0?ooo`1A0?ooo`03
0000003oool0oooo00X0oooo0`0000130?ooo`030000o`3oool0oooo04<0
oooo003B0?ooo`030000003oool0oooo0<L0oooo00<0003o0?ooo`3oool0
D03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0440oooo
00<0003o0?ooo`3oool0A03oool00=80oooo00<000000?ooo`3oool0b03o
ool00`000?l0oooo0?ooo`1?0?ooo`040000003oool0oooo0?ooo`D00000
0`3oool400000440oooo00<0003o0?ooo`3oool0A@3oool00=80oooo00<0
00000?ooo`3oool0b@3oool00`000?l0oooo0?ooo`1>0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo
000000120?ooo`030000o`3oool0oooo04D0oooo003B0?ooo`030000003o
ool0oooo00T0oooo0`00002m0?ooo`030000o`3oool0oooo04h0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`800000@@3o
ool00`000?l0oooo0?ooo`160?ooo`00dP3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0;h0oooo00<0003o0?ooo`3oool0A@3oool4
000000<0oooo0P3o00060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0?P3oool00`000?l0oooo0?ooo`170?ooo`00dP3oool00`00
0000oooo0?ooo`020?ooo`D000000`3oool00`000000oooo0?ooo`2n0?oo
o`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool00`3oool40?l0
00<0oooo00@000000?ooo`3oool00000A@3oool00`000?l0oooo0?ooo`18
0?ooo`00dP3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0_`3oool00`000?l0oooo0?ooo`14
0?ooo`040000003oool0oooo0?ooo`H0o`000P3oool5000004<0oooo00<0
003o0?ooo`3oool0B@3oool00<X0oooo1@0000020?ooo`80o`001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool000000<40oooo00<0003o
0?ooo`3oool0A03oool00`000000oooo0?ooo`060?l004T0oooo00<0003o
0?ooo`3oool0BP3oool00<`0oooo00@000000?ooo`3oool0oooo103o0006
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0`@3oool0
0`000?l0oooo0?ooo`110?ooo`040000003oool0oooo00000080oooo103o
001:0?ooo`030000o`3oool0oooo04X0oooo003<0?ooo`030000003oool0
oooo00H0o`000`3oool010000000oooo0?ooo`0000370?ooo`030000o`3o
ool0oooo0480oooo0P0000040?ooo`80o`00BP3oool00`000?l0oooo0?oo
o`1;0?ooo`00c03oool00`000000oooo0?ooo`060?l000<0oooo1@000037
0?ooo`030000o`3oool0oooo04P0oooo00<000000?ooo`3oool0A`3oool0
0`000?l0oooo0?ooo`1<0?ooo`00c03oool010000000oooo0?ooo`3oool4
0?l00=40oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`16
0?ooo`030000o`3oool0oooo04d0oooo003;0?ooo`800000103oool20?l0
0=<0oooo00<0003o0?ooo`3oool0AP3oool00`000000oooo0?ooo`150?oo
o`030000o`3oool0oooo04h0oooo003B0?ooo`030000003oool0oooo0=80
oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`140?ooo`03
0000o`3oool0oooo04l0oooo003B0?ooo`030000003oool0oooo0=<0oooo
00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`130?ooo`030000
o`3oool0oooo0500oooo003B0?ooo`030000003oool0oooo0=@0oooo0P00
0?m40?ooo`030000003oool0oooo0440oooo0P000?mC0?ooo`00dP3oool0
0`000000oooo0?ooo`3F0?ooo`030000o`3oool0oooo0440oooo00<00000
0?ooo`3oool0@03oool00`000?l0oooo0?ooo`1C0?ooo`00dP3oool00`00
0000oooo0?ooo`3G0?ooo`030000o`3oool0oooo0400oooo00<000000?oo
o`3oool0?`3oool00`000?l0oooo0?ooo`1D0?ooo`00dP3oool00`000000
oooo0?ooo`3H0?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3o
ool0?P3oool00`000?l0oooo0?ooo`1E0?ooo`00dP3oool00`000000oooo
0?ooo`3I0?ooo`030000o`3oool0oooo03h0oooo00<000000?ooo`3oool0
?@3oool00`000?l0oooo0?ooo`1F0?ooo`00dP3oool00`000000oooo0?oo
o`3J0?ooo`80003o?P3oool00`000000oooo0?ooo`0k0?ooo`80003oF@3o
ool00=80oooo00<000000?ooo`3oool0g03oool00`000?l0oooo0?ooo`0k
0?ooo`030000003oool0oooo03X0oooo00<0003o0?ooo`3oool0F@3oool0
0=80oooo00<000000?ooo`3oool0g@3oool00`000?l0oooo0?ooo`0j0?oo
o`030000003oool0oooo03T0oooo00<0003o0?ooo`3oool0FP3oool00=80
oooo00<000000?ooo`3oool0gP3oool30000ocT0oooo00<000000?ooo`3o
ool0=`3oool20000oed0oooo003B0?ooo`030000003oool0oooo0>40oooo
0P000?lg0?ooo`030000003oool0oooo03D0oooo0P000?mO0?ooo`00dP3o
ool00`000000oooo0?ooo`3S0?ooo`030000o`3oool0oooo03@0oooo00<0
00000?ooo`3oool0=03oool00`000?l0oooo0?ooo`1O0?ooo`00dP3oool0
0`000000oooo0?ooo`3T0?ooo`030000o`3oool0oooo03<0oooo00<00000
0?ooo`3oool0<P3oool20000of80oooo003B0?ooo`030000003oool0oooo
0>D0oooo0P000?lc0?ooo`030000003oool0oooo0300oooo0P000?mT0?oo
o`00dP3oool00`000000oooo0?ooo`3W0?ooo`80003o<@3oool00`000000
oooo0?ooo`0^0?ooo`80003oIP3oool00=80oooo00<000000?ooo`3oool0
2P3oool300000=`0oooo00<0003o0?ooo`3oool0;P3oool00`000000oooo
0?ooo`0]0?ooo`030000o`3oool0oooo06H0oooo003B0?ooo`030000003o
ool0oooo0080oooo1@0000040?ooo`030000003oool0oooo0=`0oooo0P00
0?l^0?ooo`030000003oool0oooo02`0oooo00<0003o0?ooo`3oool0I`3o
ool00=80oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`@00000g`3oool20000ob`0oooo00<000000?ooo`3oool0:@3o
ool30000ofX0oooo003A0?ooo`80o`001P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool000000>80oooo0`000?lY0?ooo`030000003oool0
oooo02L0oooo0P000?m]0?ooo`00bP3oool400000080oooo103o00060?oo
o`030000003oool0oooo0080oooo0P00003U0?ooo`80003o9`3oool00`00
0000oooo0?ooo`0T0?ooo`<0003oK`3oool00<X0oooo00<000000?ooo`3o
ool00P3oool60?l000<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`3U0?ooo`80003o9@3oool00`000000oooo0?ooo`0R0?oo
o`80003oLP3oool00</0oooo00@000000?ooo`3oool0oooo1P3o00030?oo
o`D00000k@3oool50000ob00oooo00<000000?ooo`3oool07@3oool50000
og@0oooo003<0?ooo`040000003oool0oooo0?ooo`@0o`00n`3oool30000
oad0oooo00<000000?ooo`3oool06`3oool20000ogT0oooo003:0?ooo`04
0000003oool0oooo000000<0oooo0P3o003o0?ooo`80003o6`3oool00`00
0000oooo0?ooo`0H0?ooo`<0003oN`3oool00</0oooo0P0000050?ooo`03
0000003oool0oooo0?l0oooo1@000?lF0?ooo`030000003oool0oooo01<0
oooo1@000?mn0?ooo`00dP3oool00`000000oooo0?ooo`3o0?ooo`D0oooo
1@000?lA0?ooo`030000003oool0oooo00h0oooo1@000?n30?ooo`00dP3o
ool00`000000oooo0?ooo`3o0?ooo`X0oooo2`000?l60?ooo`030000003o
ool0oooo00@0oooo2P000?n80?ooo`00dP3oool00`000000oooo0?ooo`3o
0?oooaD0oooo3@000?nB0?ooo`00dP3oool00`000000oooo0?ooo`3o0?oo
oa/0oooo00<000000?ooo`3oool0UP3oool00?l0ooool03oool00`000000
oooo0?ooo`2F0?ooo`00o`3ooooo0?ooohX0oooo003o0?ooool0ooooRP3o
ool00?l0ooooo`3ooon:0?ooo`00o`3ooooo0?ooohX0oooo003o0?ooool0
ooooRP3oool00?l0ooooo`3ooon:0?ooo`00o`3ooooo0?ooohX0oooo003@
0?ooo`800000o`3ooolL0?ooo`800000V@3oool00=40oooo00<000000?oo
o`3oool0o`3ooolK0?ooo`030000003oool0oooo09L0oooo003B0?ooo`03
0000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`2F0?ooo`00
d@3oool00`000000oooo0000003o0?oooa/0oooo00<000000?ooo`000000
U`3oool00=00oooo00@000000?ooo`3oool00000o`3ooolJ0?ooo`040000
003oool0oooo000009L0oooo003?0?ooo`<0000000<0oooo000000000000
o`3ooolH0?ooo`<0000000<0oooo000000000000UP3oool00?l0ooooo`3o
oon:0?ooo`00o`3ooooo0?ooohX0oooo003o0?ooool0ooooRP3oool00?l0
ooooo`3ooon:0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{648, 143},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  We write the integrand as  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(1\/\(\((z\^2\  + \ 1)\) \((z\^2\  + \ 4)\)\)\  = \ 
          1\/\(\((z + \[ImaginaryI])\) \((z - \[ImaginaryI])\) \((z + 2  \
\[ImaginaryI])\) \((z - 2  \[ImaginaryI])\)\)\)\)]],
  ".  We see that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has simple poles at the points ",
  Cell[BoxData[
      \(z = \(\[PlusMinus]\[ImaginaryI]\)\)]],
  " and ",
  Cell[BoxData[
      \(z = \(\[PlusMinus]2\) \[ImaginaryI]\)]],
  ",  and that the points  ",
  Cell[BoxData[
      \(z\_2 = \[ImaginaryI]\)]],
  "  and  ",
  Cell[BoxData[
      \(z\_4 = 2  \[ImaginaryI]\)]],
  ",  are the only singularities of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " in the upper half-plane.  Computing the residues, we obtain  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[
          f, \[ImaginaryI]]\ \  = \ \ \(lim\+\(z\  \[Rule] \ \[ImaginaryI]\)\ \
\((z - \[ImaginaryI])\) 
              f \((z)\)\  = \ \ lim\+\(z\  \[Rule] \ \[ImaginaryI]\)\ \((z - \
\[ImaginaryI])\) 
              1\/\(\((z + \[ImaginaryI])\) \((z - \[ImaginaryI])\) \((z + 2  \
\[ImaginaryI])\) \((z - 2  \[ImaginaryI])\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(lim\+\(z\
\  \[Rule] \ \[ImaginaryI]\)\ 
            1\/\(\((z + \[ImaginaryI])\) \((z + 2  \[ImaginaryI])\) \((z - 2  \
\[ImaginaryI])\)\)\ \  = \ \ \(1\/\(\((\[ImaginaryI] + \[ImaginaryI])\) \((\
\[ImaginaryI] + 2  \[ImaginaryI])\) \((\[ImaginaryI] - 2  \[ImaginaryI])\)\)\ \
\  = \ \ 1\/\(\((2  \[ImaginaryI])\) \((3  \[ImaginaryI])\) \((\(-\
\[ImaginaryI]\))\)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(-\(\
\[ImaginaryI]\/6\)\)\)\)}]],
  "  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, 
          
          2  \[ImaginaryI]]\ \  = \ \ lim\+\(z\  \[Rule] 2  \[ImaginaryI]\)\ \
\((z - 2  \[ImaginaryI])\) f \((z)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\
\(lim\+\(z\  \[Rule] 2  \[ImaginaryI]\)\ \((z - 2  \[ImaginaryI])\) 
            1\/\(\((z + \[ImaginaryI])\) \((z - \[ImaginaryI])\) \((z + 2  \
\[ImaginaryI])\) \((z - 2  \[ImaginaryI])\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\
\(lim\+\(z\  \[Rule] 2  \[ImaginaryI]\)\ 
            1\/\(\((z + \[ImaginaryI])\) \((z - \[ImaginaryI])\) \((z + 2  \
\[ImaginaryI])\)\)\ \  = \ \ 1\/\(\((2  \[ImaginaryI] + \[ImaginaryI])\) \((2 \
 \[ImaginaryI] - \[ImaginaryI])\) \((2  \[ImaginaryI] + 2  \[ImaginaryI])\)\)\
\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\
\(1\/\(\((3  \[ImaginaryI])\) \((\[ImaginaryI])\) \((4  \
\[ImaginaryI])\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\
\[ImaginaryI]\/12\)\)\)}]],
  "   "
}], "Text"],

Cell[TextData[{
  "Using Theorem 8.3, we conclude that  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( 
                1\/\(\((x\^2\  + \ 1)\) \((x\^2\  + \ 
                      4)\)\)\) \[DifferentialD]x\ \  = \ \ 2  \[Pi]\ \
\[ImaginaryI]\ \((Res[f, \[ImaginaryI]]\  + \ 
              Res[f, 2  \[ImaginaryI]])\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(2  \[Pi]\ \[ImaginaryI]\ \((\(-\(\[ImaginaryI]\
\/6\)\)\  + \ \[ImaginaryI]\/12)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(2  \[Pi]\ \[ImaginaryI]\ \((\(-\(\[ImaginaryI]\
\/12\)\))\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \(\(=\)\(\ \ \)\(\[Pi]\/6\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.15.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = 1\/\(\((z\^2\  + \ 1)\) \((z\^2\  + \ 4)\)\)\)],
    AspectRatioFixed->True],
  "  and ",
  "locate the",
  " singularities."
}], "Text"],

Cell[BoxData[{
    \(Z = \(z = \(x = 0\)\); \ Remove[x, z, Z];\ \), "\n", 
    \(\(Clear[f, g, Res1, Res2, Res3, Res4, solset, val];\)\ \), "\n", 
    \(\(f[z_]\  = \ 
        1\/\(\((z\^2\  + \ 1)\) \((z\^2\  + \ 4)\)\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[Denominator[f[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, 
            z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The singularities are\>"];\)\ \), "\n", 
    \(\(Z\_1\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2];\)\ \), "\n", 
    \(\(Z\_3\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3];\)\ \), "\n", 
    \(\(Z\_4\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(4\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", 
        Z\_4];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell["Determine which poles lie in the upper half plane ?", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_2], Im[Z\_2]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_3], Im[Z\_3]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_4], Im[Z\_4]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] - 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] - 0.1}, {\(-1\), 
                0}], Text[\*"\"\<\!\(z\_3\)\>\"", {Re[Z\_3], 
                Im[Z\_3] - 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_4\)\>\"", {Re[Z\_4], Im[Z\_4] - 0.1}, {\(-1\), 
                0}]}];\)\ \), "\n", 
    \(\(Show[dots, centers, 
        PlotRange \[Rule] {{\(-2.2\), 2.2}, {\(-2.2\), 2.2}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<,  Is  Im(\>", 
        Z\_1, "\<) > 0 ?   \>", N[Im[Z\_1]] > 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<,   Is  Im(\>", 
        Z\_2, "\<) > 0 ?    \>", 
        N[Im[Z\_2]] > 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3, "\<, Is  Im(\>", 
        Z\_3, "\<) > 0 ?  \>", N[Im[Z\_3]] > 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", Z\_4, "\<,  Is  Im(\>", 
        Z\_4, "\<) > 0 ?   \>", 
        N[Im[Z\_4]] > 0];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Compute the residues at  ",
  Cell[BoxData[
      \(z\_2 = \(\[ImaginaryI]\ \ and\ \ z\_4 = 2  \[ImaginaryI]\)\)]],
  ", and use the residue calculus to compute the value of the integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Res2\  = \ Residue[f[z], {z, Z\_2}];\)\ \), "\n", 
    \(\(Res4\  = \ Residue[f[z], {z, Z\_4}];\)\ \), "\[IndentingNewLine]", 
    \(\(val\  = \ 
        2\ \[Pi]\ \[ImaginaryI]\ \((Res2\  + \ 
              Res4)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", Z\_2, "\<] = \>", Res2];\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_4, "\<] = \>", 
        Res4];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_2], Im[Z\_2]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_4], Im[Z\_4]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], 
                Im[Z\_2]}, {\(-1.2\), 0}], 
            Text[\*"\"\<\!\(z\_4\)\>\"", {Re[Z\_4], Im[Z\_4]}, {\(-1.2\), 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ 
        Graphics[{VioletRed, 
            Circle[{0, 0}, 3, {0, \[Pi]}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(segment = 
        Graphics[{Thickness[0.02], Magenta, 
            Line[{{\(-3\), 0}, {3, 0}}]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, segment, 
        PlotRange \[Rule] {{\(-3.1\), 3.1}, {\(-0.05\), 3.05}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 2, 1]}, 
        AspectRatio \[Rule] 1\/2, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI]((\>", 
        Res2\ , "\<) + (\>", \ 
        Res4\ , "\<))\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>", 
        Res2\  + \ Res4\ , "\<) = \>", val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The contour is the semicircle \!\(C\_R\) and interval \
[-R,R],\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<taken with the positive orientation.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value \
of the integral.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"\
", f[x], "\< \[DifferentialD]x \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= 2\[Pi]\[ImaginaryI](\>", Res2, "\< + (\>", \ 
        Res4, "\<)) = \>", val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Or, we can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s integral table and evaluate the integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(int = 
        Integrate[f[x], {x, \(-\[Infinity]\), \[Infinity]}, 
          PrincipalValue \[Rule] True];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        int];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "However, for this simple integral ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s can find the correct answer without resorting to the PrincipalValue \
option."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(g[x_]\  = \[Integral]f[x] \[DifferentialD]x;\)\ \), "\n", 
    \(\(val\  = \[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[
              x] \[DifferentialD]x;\)\ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print["\<g[x] = \[Integral]\>", f[x], "\< \[DifferentialD]x = \>", 
        g[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<g[\[Infinity]] = \>", 
        g[\[Infinity]], "\<,    g[-\[Infinity]] = \>", \ 
        g[\(-\[Infinity]\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = g[\[Infinity]]-g[-\[Infinity]] = (\>", 
        g[\[Infinity]]\ , "\<) - (\>", \ 
        g[\(-\[Infinity]\)], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        g[\[Infinity]]\  - \ 
          g[\(-\[Infinity]\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["The above answer is correct too.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.16.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  "Evaluate",
  "  ",
  Cell[BoxData[
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( 
              1\/\((x\^2 + 4)\)\^3\) \[DifferentialD]x\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:50000Sb000`400?l0
0000o`00003oo`3ooooo0?ooohL0oooo003o0?ooool0ooooQ`3oool00?l0
ooooo`3ooon70?ooo`00o`3ooooo0?ooohL0oooo003o0?ooool0ooooQ`3o
ool00?l0ooooo`3ooon70?ooo`00b03oool00`000000oooo0?ooo`3o0?oo
ok/0oooo00380?ooo`030000003oool0oooo0?l0oooo1@00000n0?ooo`D0
0000L`3oool00<P0oooo00<000000?ooo`3oool02@3oool5000000<0oooo
00<000000?ooo`3oool02P3oool3000000@0oooo00<000000?ooo`3oool0
2P3oool200000<d0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`1c0?ooo`00b03oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00<0oooo0P00000;0?ooo`030000003oool0oooo00@0oooo0P00
000=0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`1c0?ooo`00b03oool00`000000oooo0?ooo`03
0?ooo`D000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo1@0000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool5000000<0oooo00<000000?ooo`3oool0``3oool4
000000@0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1c
0?ooo`00a`3oool30?l000D0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`040?ooo`800000103oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0bP3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo07<0oooo00300?ooo`@000000P3o
ool50?l000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000303o
ool00`000000oooo0?ooo`020?ooo`030000003oool000000</0oooo0P00
00110?ooo`800000M@3oool00<00oooo00<000000?ooo`3oool00P3oool7
0?l000D0oooo00@000000?ooo`3oool0oooo0P00000>0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0?l0ooooQ@3oool00<40oooo00@00000
0?ooo`3oool0oooo1`3o00030?ooo`040000003oool0oooo00000100oooo
00@000000?ooo`3oool00000403oool010000000oooo0?ooo`00003o0?oo
oh/0oooo002j0?ooo`@00000103oool00`000000oooo0?ooo`070?l000<0
oooo1@00000?0?ooo`D000003`3oool500000?l0ooooRP3oool00<00oooo
00@000000?ooo`3oool000000P3oool50?l00?l0oooo8P3oool00`000000
oooo0?ooo`1a0?ooo`80000000<0oooo000000000000803oool00<40oooo
0P0000040?ooo`<0o`00^03ooooE003oo`X0oooo00<000000?ooo`000000
8@3oool00<P0oooo00<000000?ooo`3oool0]03oool300000=D00?oo0P00
00090?ooo`030000003oool0oooo0200oooo00380?ooo`030000003oool0
oooo0;L0ooooe@00ool90?ooo`80000000<0oooo000000000000803oool0
0<P0oooo00<000000?ooo`3oool0^03oool00`000?l0oooo0?ooo`1V0?oo
o`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool0;@3oool00<P0
oooo00<000000?ooo`3oool0^03oool00`000?l0oooo0?ooo`1V0?ooo`03
0000003oool0oooo06H0oooo00<0003o0?ooo`3oool0;@3oool00<P0oooo
00<000000?ooo`3oool0^03oool00`000?l0oooo0?ooo`1V0?ooo`030000
003oool0oooo06D0oooo00<0003o0?ooo`3oool0;P3oool00<P0oooo00<0
00000?ooo`3oool0^03oool00`000?l0oooo0?ooo`1V0?ooo`030000003o
ool0oooo06D0oooo00<0003o0?ooo`3oool0;P3oool00<P0oooo00<00000
0?ooo`3oool0^03oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0
oooo06D0oooo00<0003o0?ooo`3oool0;P3oool00<P0oooo00<000000?oo
o`3oool0^03oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo
06D0oooo00<0003o0?ooo`3oool0;P3oool00<P0oooo00<000000?ooo`3o
ool0^03oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo06D0
oooo00<0003o0?ooo`3oool0;P3oool00<P0oooo00<000000?ooo`3oool0
^03oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo06D0oooo
00<0003o0?ooo`3oool0;P3oool00<P0oooo00<000000?ooo`3oool0^03o
ool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo06D0oooo00<0
003o0?ooo`3oool0;P3oool00<P0oooo00<000000?ooo`3oool0^03oool0
0`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo06D0oooo00<0003o
0?ooo`3oool0;P3oool00<P0oooo00<000000?ooo`3oool0^@3oool00`00
0?l0oooo0?ooo`1U0?ooo`030000003oool0oooo06D0oooo00<0003o0?oo
o`3oool0;P3oool00<P0oooo00<000000?ooo`3oool0^@3oool00`000?l0
oooo0?ooo`1U0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3o
ool0;P3oool00<P0oooo00<000000?ooo`3oool0^@3oool00`000?l0oooo
0?ooo`1U0?ooo`030000003oool0oooo06@0oooo00<0003o0?ooo`3oool0
;`3oool00<P0oooo00<000000?ooo`3oool0^@3oool00`000?l0oooo0?oo
o`1U0?ooo`030000003oool0oooo06@0oooo00<0003o0?ooo`3oool0;`3o
ool00<P0oooo00<000000?ooo`3oool0^@3oool00`000?l0oooo0?ooo`1U
0?ooo`030000003oool0oooo06@0oooo00<0003o0?ooo`3oool0;`3oool0
0<P0oooo00<000000?ooo`3oool0^@3oool00`000?l0oooo0?ooo`1U0?oo
o`030000003oool0oooo06@0oooo00<0003o0?ooo`3oool0;`3oool00<P0
oooo00<000000?ooo`3oool0^@3oool00`000?l0oooo0?ooo`1U0?ooo`03
0000003oool0oooo06@0oooo00<0003o0?ooo`3oool0;`3oool00<P0oooo
00<000000?ooo`3oool0^@3oool00`000?l0oooo0?ooo`1U0?ooo`030000
003oool0oooo06@0oooo00<0003o0?ooo`3oool0;`3oool00<00oooo1@00
00030?ooo`030000003oool0oooo0;X0oooo00<0003o0?ooo`3oool0I03o
ool00`000000oooo0?ooo`1T0?ooo`030000o`3oool0oooo02l0oooo0032
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0^P3oool0
0`000?l0oooo0?ooo`1T0?ooo`030000003oool0oooo06@0oooo00<0003o
0?ooo`3oool0;`3oool00<80oooo00<000000?ooo`3oool00`3oool30000
0;X0oooo00<0003o0?ooo`3oool0I03oool00`000000oooo0?ooo`1S0?oo
o`030000o`3oool0oooo0300oooo002j0?ooo`@00000103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0;X0oooo00<0003o0?ooo`3o
ool0I03oool00`000000oooo0?ooo`1S0?ooo`030000o`3oool0oooo0300
oooo00320?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
^P3oool00`000?l0oooo0?ooo`1T0?ooo`030000003oool0oooo0680oooo
00<0003o0?ooo`3oool0<@3oool00<40oooo0P0000050?ooo`030000003o
ool0oooo0;/0oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?oo
o`1R0?ooo`030000o`3oool0oooo0340oooo00380?ooo`030000003oool0
oooo0;/0oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?ooo`1R
0?ooo`030000o`3oool0oooo0340oooo00380?ooo`030000003oool0oooo
0;`0oooo00<0003o0?ooo`3oool0HP3oool00`000000oooo0?ooo`1R0?oo
o`030000o`3oool0oooo0340oooo00380?ooo`030000003oool0oooo0;`0
oooo00<0003o0?ooo`3oool0HP3oool00`000000oooo0?ooo`1R0?ooo`03
0000o`3oool0oooo0340oooo00380?ooo`030000003oool0oooo0;`0oooo
00<0003o0?ooo`3oool0HP3oool00`000000oooo0?ooo`1Q0?ooo`030000
o`3oool0oooo0380oooo00380?ooo`030000003oool0oooo0;`0oooo00<0
003o0?ooo`3oool0HP3oool00`000000oooo0?ooo`1Q0?ooo`030000o`3o
ool0oooo0380oooo00380?ooo`030000003oool0oooo0;`0oooo00<0003o
0?ooo`3oool0HP3oool00`000000oooo0?ooo`1Q0?ooo`030000o`3oool0
oooo0380oooo00380?ooo`030000003oool0oooo0;d0oooo00<0003o0?oo
o`3oool0H@3oool00`000000oooo0?ooo`1P0?ooo`030000o`3oool0oooo
03<0oooo00380?ooo`030000003oool0oooo0;d0oooo00<0003o0?ooo`3o
ool0F@3oool5000000<0oooo00<000000?ooo`3oool0H03oool00`000?l0
oooo0?ooo`0c0?ooo`00b03oool00`000000oooo0?ooo`2m0?ooo`030000
o`3oool0oooo05/0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`1O0?ooo`030000o`3oool0oooo03@0oooo00380?ooo`030000003o
ool0oooo0;h0oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo0?oo
o`030?ooo`800000H03oool00`000?l0oooo0?ooo`0d0?ooo`00b03oool0
0`000000oooo0?ooo`2n0?ooo`030000o`3oool0oooo05X0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`1O0?ooo`030000o`3oool0
oooo03@0oooo001N0?ooo`@00000<P3oool5000002l0oooo00<000000?oo
o`3oool0<@3oool500000340oooo1000001D0?ooo`030000o`3oool0oooo
05T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1O0?oo
o`030000o`3oool0oooo03@0oooo001N0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0E@3oool00`000?l0
oooo0?ooo`1H0?ooo`8000001@3oool00`000000oooo0?ooo`1O0?ooo`03
0000o`3oool0oooo03@0oooo001O0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0E03oool00`000?l0oooo
0?ooo`1O0?ooo`030000003oool0oooo05h0oooo00<0003o0?ooo`3oool0
=@3oool005P0oooo100000040?ooo`030000003oool0oooo02/0oooo1000
00040?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo05@0oooo00<0
003o0?ooo`3oool0GP3oool00`000000oooo0?ooo`1N0?ooo`030000o`3o
ool0oooo03D0oooo001N0?ooo`040000003oool0oooo000003@0oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo0340oooo00@000000?ooo`3oool00000E@3oool00`000?l0oooo
0?ooo`1N0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool0
=P3oool005l0oooo0P00000d0?ooo`800000<@3oool00`000000oooo0?oo
o`0b0?ooo`800000=03oool2000005L0oooo00<0003o0?ooo`3oool0G@3o
ool00`000000oooo0?ooo`1M0?ooo`030000o`3oool0oooo03H0oooo0038
0?ooo`030000003oool0oooo0<40oooo00<0003o0?ooo`3oool0G@3oool0
0`000000oooo0?ooo`1M0?ooo`030000o`3oool0oooo03H0oooo00380?oo
o`030000003oool0oooo0<80oooo00<0003o0?ooo`3oool0G03oool00`00
0000oooo0?ooo`1L0?ooo`030000o`3oool0oooo03L0oooo00380?ooo`03
0000003oool0oooo0<80oooo00<0003o0?ooo`3oool0G03oool00`000000
oooo0?ooo`1L0?ooo`030000o`3oool0oooo03L0oooo00380?ooo`030000
003oool0oooo0<80oooo00<0003o0?ooo`3oool0G03oool00`000000oooo
0?ooo`1K0?ooo`030000o`3oool0oooo03P0oooo00380?ooo`030000003o
ool0oooo07/0oooo0P0000000`3oool00000000000130?ooo`030000o`3o
ool0oooo05/0oooo00<000000?ooo`3oool0FP3oool00`000?l0oooo0?oo
o`0i0?ooo`00D`3oooo/000000P0oooo00<000000?ooo`000000A03oool0
0`000?l0oooo0?ooo`1K0?ooo`030000003oool0oooo05T0oooo00<0003o
0?ooo`3oool0>P3oool005d0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
04@0oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`1I0?oo
o`030000o`3oool0oooo03X0oooo001M0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool03`3oool200000003
0?ooo`000000000004@0oooo00<0003o0?ooo`3oool0FP3oool00`000000
oooo0?ooo`1I0?ooo`030000o`3oool0oooo03X0oooo00380?ooo`030000
003oool0oooo0<D0oooo00<0003o0?ooo`3oool0F@3oool00`000000oooo
0?ooo`1H0?ooo`030000o`3oool0oooo03/0oooo00380?ooo`030000003o
ool0oooo0<D0oooo00<0003o0?ooo`3oool0F@3oool00`000000oooo0?oo
o`1H0?ooo`030000o`3oool0oooo03/0oooo00380?ooo`030000003oool0
oooo0<H0oooo00<0003o0?ooo`3oool0F03oool00`000000oooo0?ooo`1G
0?ooo`030000o`3oool0oooo03`0oooo00380?ooo`030000003oool0oooo
0<L0oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo0?ooo`1G0?oo
o`030000o`3oool0oooo03`0oooo00380?ooo`030000003oool0oooo0<L0
oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo0?ooo`1F0?ooo`03
0000o`3oool0oooo03d0oooo00380?ooo`030000003oool0oooo0<P0oooo
00<0003o0?ooo`3oool0EP3oool00`000000oooo0?ooo`1E0?ooo`030000
o`3oool0oooo03h0oooo00380?ooo`030000003oool0oooo0<P0oooo00<0
003o0?ooo`3oool0EP3oool00`000000oooo0?ooo`1D0?ooo`030000o`3o
ool0oooo03l0oooo00380?ooo`030000003oool0oooo0<T0oooo00<0003o
0?ooo`3oool0E@3oool00`000000oooo0?ooo`1D0?ooo`030000o`3oool0
oooo03l0oooo00380?ooo`030000003oool0oooo0<X0oooo00<0003o0?oo
o`3oool0E03oool00`000000oooo0?ooo`1C0?ooo`030000o`3oool0oooo
0400oooo00380?ooo`030000003oool0oooo0</0oooo00<0003o0?ooo`3o
ool0D`3oool00`000000oooo0?ooo`1B0?ooo`030000o`3oool0oooo0440
oooo00380?ooo`030000003oool0oooo0</0oooo00<0003o0?ooo`3oool0
D`3oool00`000000oooo0?ooo`1A0?ooo`030000o`3oool0oooo0480oooo
00380?ooo`030000003oool0oooo0<`0oooo00<0003o0?ooo`3oool0DP3o
ool00`000000oooo0?ooo`1A0?ooo`030000o`3oool0oooo0480oooo0038
0?ooo`030000003oool0oooo0<d0oooo00<0003o0?ooo`3oool0D@3oool0
0`000000oooo0?ooo`0:0?ooo`<00000@`3oool00`000?l0oooo0?ooo`13
0?ooo`00b03oool00`000000oooo0?ooo`3>0?ooo`030000o`3oool0oooo
0500oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`110?oo
o`030000o`3oool0oooo04@0oooo00380?ooo`030000003oool0oooo0<l0
oooo00<0003o0?ooo`3oool0C`3oool010000000oooo0?ooo`3oool50000
00<0oooo100000110?ooo`030000o`3oool0oooo04D0oooo00380?ooo`03
0000003oool0oooo0=00oooo00<0003o0?ooo`3oool0CP3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`000000@P3oool00`000?l0oooo0?ooo`150?ooo`00b03oool00`000000
oooo0?ooo`3@0?ooo`030000o`3oool0oooo04h0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`800000@@3oool00`000?l0
oooo0?ooo`160?ooo`00b03oool00`000000oooo0?ooo`3A0?ooo`030000
o`3oool0oooo04D0oooo100000030?ooo`80o`001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03h0oooo00<0003o0?ooo`3oool0
A`3oool00<P0oooo00<000000?ooo`3oool0dP3oool00`000?l0oooo0?oo
o`140?ooo`030000003oool0oooo00<0oooo103o00030?ooo`040000003o
ool0oooo000004D0oooo00<0003o0?ooo`3oool0B03oool00<P0oooo00<0
00000?ooo`3oool0d`3oool00`000?l0oooo0?ooo`140?ooo`040000003o
ool0oooo0?ooo`H0o`000P3oool5000004<0oooo00<0003o0?ooo`3oool0
B@3oool00<P0oooo00<000000?ooo`3oool0e03oool00`000?l0oooo0?oo
o`140?ooo`030000003oool0oooo00H0o`00B@3oool00`000?l0oooo0?oo
o`1:0?ooo`00b03oool00`000000oooo0?ooo`3E0?ooo`030000o`3oool0
oooo0440oooo00@000000?ooo`3oool000000P3oool40?l004X0oooo00<0
003o0?ooo`3oool0BP3oool00<00oooo1@0000030?ooo`030000003oool0
oooo0=D0oooo00<0003o0?ooo`3oool0@P3oool2000000@0oooo0P3o001:
0?ooo`030000o`3oool0oooo04/0oooo00320?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0eP3oool00`000?l0oooo0?ooo`180?oo
o`030000003oool0oooo04L0oooo00<0003o0?ooo`3oool0C03oool00<80
oooo00<000000?ooo`3oool00`3oool300000=L0oooo00<0003o0?ooo`3o
ool0A`3oool00`000000oooo0?ooo`160?ooo`030000o`3oool0oooo04d0
oooo00320?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
f03oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo04D0oooo
00<0003o0?ooo`3oool0CP3oool00<80oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`3I0?ooo`030000o`3oool0oooo04D0oooo00<0
00000?ooo`3oool0A03oool00`000?l0oooo0?ooo`1?0?ooo`00`@3oool2
000000D0oooo00<000000?ooo`3oool0fP3oool00`000?l0oooo0?ooo`14
0?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool0D03oool0
0<P0oooo00<000000?ooo`3oool0f`3oool20000od@0oooo00<000000?oo
o`3oool0@@3oool20000oe<0oooo00380?ooo`030000003oool0oooo0=d0
oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`03
0000o`3oool0oooo05<0oooo00380?ooo`030000003oool0oooo0=h0oooo
00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`0o0?ooo`030000
o`3oool0oooo05@0oooo00380?ooo`030000003oool0oooo0=l0oooo00<0
003o0?ooo`3oool0?`3oool00`000000oooo0?ooo`0n0?ooo`030000o`3o
ool0oooo05D0oooo00380?ooo`030000003oool0oooo0>00oooo00<0003o
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0
oooo05H0oooo00380?ooo`030000003oool0oooo0>40oooo0P000?ln0?oo
o`030000003oool0oooo03/0oooo0P000?mI0?ooo`00b03oool00`000000
oooo0?ooo`3S0?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3o
ool0>P3oool00`000?l0oooo0?ooo`1I0?ooo`00b03oool00`000000oooo
0?ooo`3T0?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0
>@3oool00`000?l0oooo0?ooo`1J0?ooo`00b03oool00`000000oooo0?oo
o`3U0?ooo`<0003o>@3oool00`000000oooo0?ooo`0g0?ooo`80003oG@3o
ool00<P0oooo00<000000?ooo`3oool0j03oool20000ocL0oooo00<00000
0?ooo`3oool0=@3oool20000oel0oooo00380?ooo`030000003oool0oooo
0>X0oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`0d0?oo
o`030000o`3oool0oooo05l0oooo00380?ooo`030000003oool0oooo0>/0
oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`80
003oHP3oool00<P0oooo00<000000?ooo`3oool0k03oool20000oc<0oooo
00<000000?ooo`3oool0<03oool20000of@0oooo00380?ooo`030000003o
ool0oooo0>h0oooo0P000?la0?ooo`030000003oool0oooo02h0oooo0P00
0?mV0?ooo`00b03oool00`000000oooo0?ooo`3`0?ooo`030000o`3oool0
oooo02h0oooo00<000000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`1V
0?ooo`00b03oool00`000000oooo0?ooo`3a0?ooo`80003o;P3oool00`00
0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo06L0oooo00380?ooo`03
0000003oool0oooo00/0oooo0`0000030?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`80
0000_`3oool20000ob`0oooo00<000000?ooo`3oool0:@3oool30000ofX0
oooo00380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0P3oool2000000/0oooo00<000000?ooo`000000103oool2000000/0oooo
00<000000?ooo`000000`03oool30000obT0oooo00<000000?ooo`3oool0
9`3oool20000ofd0oooo00380?ooo`030000003oool0oooo00<0oooo1@00
00020?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`D00000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo1@00
00020?ooo`030000003oool000000<<0oooo0P000?lW0?ooo`030000003o
ool0oooo02@0oooo0`000?m_0?ooo`00a`3oool30?l000D0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo000000050?ooo`800000103o
ool010000000oooo0?ooo`0000020?ooo`8000001P3oool2000000@0oooo
00@000000?ooo`3oool000000P3oool200000<H0oooo0P000?lU0?ooo`03
0000003oool0oooo0280oooo0P000?mb0?ooo`00`03oool400000080oooo
1@3o00050?ooo`030000003oool0oooo00<0oooo0P00000<0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0<L0oooo1@000?lP0?ooo`030000
003oool0oooo01d0oooo1@000?md0?ooo`00`03oool00`000000oooo0?oo
o`020?ooo`L0o`001@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00/0oooo00@000000?ooo`3oool0oooo0`00000=0?ooo`030000
003oool0oooo0080oooo0P00003<0?ooo`<0003o7@3oool00`000000oooo
0?ooo`0K0?ooo`80003oN@3oool00<40oooo00@000000?ooo`3oool0oooo
1`3o00030?ooo`040000003oool0oooo00000100oooo00@000000?ooo`3o
ool00000403oool010000000oooo0?ooo`00003D0?ooo`80003o6`3oool0
0`000000oooo0?ooo`0H0?ooo`<0003oN`3oool00<80oooo00<000000?oo
o`3oool01`3o00030?ooo`D000003`3oool5000000l0oooo1@00003E0?oo
o`D0003o5P3oool00`000000oooo0?ooo`0C0?ooo`D0003oOP3oool00<00
oooo00@000000?ooo`3oool000000P3oool50?l00?l0oooo303oool50000
oa40oooo00<000000?ooo`3oool03P3oool50000oh<0oooo00310?ooo`80
0000103oool30?l00?l0oooo4P3oool;0000o`H0oooo00<000000?ooo`3o
ool0103oool:0000ohP0oooo00380?ooo`030000003oool0oooo0?l0oooo
703oool=0000oi80oooo00380?ooo`030000003oool0oooo0?l0oooo8P3o
ool00`000000oooo0?ooo`2F0?ooo`00o`3oooo]0?ooo`030000003oool0
oooo09H0oooo003o0?ooool0ooooQ`3oool00?l0ooooo`3ooon70?ooo`00
o`3ooooo0?ooohL0oooo003o0?ooool0ooooQ`3oool00?l0ooooo`3ooon7
0?ooo`00o`3ooooo0?ooohL0oooo003o0?ooool0ooooQ`3oool00<H0oooo
0P00003o0?ooob<0oooo0P00002I0?ooo`00a`3oool00`000000oooo0?oo
o`3o0?ooob80oooo00<000000?ooo`3oool0U`3oool00<P0oooo00<00000
0?ooo`3oool0o`3ooolR0?ooo`030000003oool0oooo09H0oooo00370?oo
o`030000003oool000000?l0oooo8P3oool00`000000oooo0000002G0?oo
o`00aP3oool010000000oooo0?ooo`00003o0?ooob40oooo00@000000?oo
o`3oool00000U`3oool00<D0oooo0`0000000`3oool000000000003o0?oo
oal0oooo0`0000000`3oool000000000002F0?ooo`00o`3ooooo0?ooohL0
oooo003o0?ooool0ooooQ`3oool00?l0ooooo`3ooon70?ooo`00o`3ooooo
0?ooohL0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{645, 143},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The integrand  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(1\/\((z\^2 + 4)\)\^3\  = \ \ 1\/\(\(\((z + 2  \
\[ImaginaryI])\)\^3\) \((z - 2  \[ImaginaryI])\)\^3\)\)\)]],
  "  has a poles of order 3 at the points ",
  Cell[BoxData[
      \(z = \(\[PlusMinus]2\) \[ImaginaryI]\)]],
  ", and  ",
  Cell[BoxData[
      \(z = 2  \[ImaginaryI]\)]],
  "  is the only singularity of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " in the upper half-plane.  Computing the residue at   ",
  Cell[BoxData[
      \(z\_4 = 2  \[ImaginaryI]\)]],
  ", we get  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, 
          2  \[ImaginaryI]]\ \  = \ \ \(1\/\(2!\)\) \(lim\+\(z\  \[Rule] 2  \
\[ImaginaryI]\)\ \(d\^2\/dz\^2\) \((\(\((z - 2  \[ImaginaryI])\)\^3\) 
                  f \((z)\))\)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\
\(1\/2\) \(lim\+\(z\  \[Rule] 2  \[ImaginaryI]\)\ \(d\^2\/dz\^2\) \((\(\((z - 
                          2  \[ImaginaryI])\)\^3\) 
                  1\/\(\(\((z + 2  \[ImaginaryI])\)\^3\) \((z - 2  \
\[ImaginaryI])\)\^3\))\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\
\(1\/2\) \(lim\+\(z\  \[Rule] 2  \[ImaginaryI]\)\ \(d\^2\/dz\^2\) \((1\/\((z \
+ 2  \[ImaginaryI])\)\^3)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\
\(1\/2\) \(lim\+\(z\  \[Rule] 2  \[ImaginaryI]\)\ \(d\/dz\) \((\(-3\)\/\((z + \
2  \[ImaginaryI])\)\^4)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\
\(1\/2\) \(lim\+\(z\  \[Rule] 2  \[ImaginaryI]\)\ \((12\/\((z + 2  \
\[ImaginaryI])\)\^5)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\
\(1\/2\) \((12\/\((2  \[ImaginaryI] + 2  \[ImaginaryI])\)\^5)\)\ \  = \ \ \
\(\(1\/2\) \((12\/\((4  \[ImaginaryI])\)\^5)\)\  = \ \ \(1\/2\) \((12\/\(1024\
\ \[ImaginaryI]\))\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(-\(\(3\ \[ImaginaryI]\)\/512\)\)\)\)}]],
  "   "
}], "Text"],

Cell[TextData[{
  "Therefore \n\n\t\t\t",
  Cell[BoxData[
      \("\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\!\(1\/\((x\^2 + \
4)\)\^3\)\[DifferentialD]x"\ \  = \ \ \(2  \[Pi]\ \[ImaginaryI]\ \ Res[f, 
              2  \[ImaginaryI]]\ \  = \ \ \(2  \[Pi]\ \[ImaginaryI]\ \
\((\(\(-3\)\ \[ImaginaryI]\)\/512)\)\ \  = \ \ \(3  \[Pi]\)\/256\)\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.16.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = 1\/\((z\^2\  + \ 4)\)\^3\)],
    AspectRatioFixed->True],
  "  and ",
  "locate the",
  " singularities."
}], "Text"],

Cell[BoxData[{
    \(Z = \(z = \(x = 0\)\); \ Remove[x, z, Z];\ \), "\n", 
    \(\(Clear[f, g, Res1, Res2, Res3, Res4, solset, val];\)\ \), "\n", 
    \(\(f[z_]\  = \ 1\/\((z\^2\  + \ 4)\)\^3;\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[Denominator[f[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, 
            z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The singularities are\>"];\)\ \), "\n", 
    \(\(Z\_1\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2];\)\ \), "\n", 
    \(\(Z\_3\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3];\)\ \), "\n", 
    \(\(Z\_4\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(4\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", 
        Z\_4];\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_5\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(5\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_5\) = \>\"", Z\_5];\)\ \), "\n", 
    \(\(Z\_6\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(6\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_6\) = \>\"", 
        Z\_6];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell["Which poles lie in the upper half plane ?", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_2], Im[Z\_2]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_3], Im[Z\_3]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_4], Im[Z\_4]}], 
              Point[{Re[Z\_5], Im[Z\_5]}]}, {Red, PointSize[0.03], 
              Point[{Re[Z\_6], Im[Z\_6]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] - 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2] + 0.3, 
                Im[Z\_2] - 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_3\)\>\"", {Re[Z\_3] + 0.6, 
                Im[Z\_3] - 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_4\)\>\"", {Re[Z\_4], Im[Z\_4] - 0.1}, {\(-1\), 
                0}], Text[\*"\"\<\!\(z\_5\)\>\"", {Re[Z\_5] + 0.3, 
                Im[Z\_5] - 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_6\)\>\"", {Re[Z\_6] + 0.6, 
                Im[Z\_6] - 0.1}, {\(-1\), 0}]}];\)\ \), "\n", 
    \(\(Show[dots, centers, 
        PlotRange \[Rule] {{\(-2.2\), 2.2}, {\(-2.2\), 2.2}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<,  Is  Im(\>", 
        Z\_1, "\<) > 0 ?  \>", N[Im[Z\_1]] > 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<,  Is  Im(\>", 
        Z\_2, "\<) > 0 ?  \>", 
        N[Im[Z\_2]] > 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3, "\<,  Is  Im(\>", 
        Z\_3, "\<) > 0 ?  \>", N[Im[Z\_3]] > 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", Z\_4, "\<,   Is  Im(\>", 
        Z\_4, "\<) > 0 ?   \>", 
        N[Im[Z\_4]] > 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_5\) = \>\"", Z\_5, "\<,   Is  Im(\>", 
        Z\_5, "\<) > 0 ?   \>", N[Im[Z\_5]] > 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_6\) = \>\"", Z\_6, "\<,   Is  Im(\>", 
        Z\_6, "\<) > 0 ?   \>", 
        N[Im[Z\_6]] > 0];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Compute the residues at  ",
  Cell[BoxData[
      \(z\_4 = 2  \[ImaginaryI]\)]],
  ", and use the residue calculus to compute the value of the integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Res4\  = \ Residue[f[z], {z, Z\_4}];\)\ \), "\n", 
    \(\(val\  = \ 2\ \[Pi]\ \[ImaginaryI]\ Res4;\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_4, "\<] = \>", 
        Res4];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{Red, PointSize[0.03], 
            Point[{Re[Z\_4], Im[Z\_4]}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_4\)\>\"", {Re[Z\_4], 
                Im[Z\_4]}, {\(-1.2\), 0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ 
        Graphics[{VioletRed, 
            Circle[{0, 0}, 3, {0, \[Pi]}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(segment = 
        Graphics[{Thickness[0.02], Magenta, 
            Line[{{\(-3\), 0}, {3, 0}}]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, segment, 
        PlotRange \[Rule] {{\(-3.1\), 3.1}, {\(-0.05\), 3.05}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 2, 1]}, 
        AspectRatio \[Rule] 1\/2, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>", 
        Res4\ , "\<) = \>", val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The contour is the semicircle \!\(C\_R\) and interval \
[-R,R],\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<taken with the positive orientation.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value \
of the integral.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"\
", f[x], "\< \[DifferentialD]x = 2\[Pi]\[ImaginaryI](\>", Res4, "\<) = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Or, we can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s integral table and evaluate the integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(int = 
        Integrate[f[x], {x, \(-\[Infinity]\), \[Infinity]}, 
          PrincipalValue \[Rule] True];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        int];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "However, for this simple integral ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s can find the correct answer without resorting to the PrincipalValue \
option."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(g[x_]\  = \[Integral]f[x] \[DifferentialD]x;\)\ \), "\n", 
    \(\(val\  = \[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[
              x] \[DifferentialD]x;\)\ \), "\[IndentingNewLine]", 
    \(\(lim1 = 
        Limit[g[x], x \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(lim2 = Limit[g[x], x \[Rule] \(-\[Infinity]\)];\)\ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print["\<g[x] = \[Integral]\>", f[x], "\< \[DifferentialD]x = \>", 
        g[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< g[\[Infinity]] =  \!\(lim\+\(x \[Rule] \[Infinity]\)\) \
(\>\"", g[x], "\<) = \>", lim1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<g[-\[Infinity]] =  \!\(lim\+\(x \[Rule] \(-\[Infinity]\)\
\)\) (\>\"", g[x], "\<) = \>", lim2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = g[\[Infinity]]-g[-\[Infinity]] = (\>", 
        lim1\ , "\<) - (\>", \ lim2, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        lim1\  - lim2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["The above answer is correct too.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Residue Calculus",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ResidueCalcBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Contour Integrals",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ContourIntegralBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Cauchy Principal Value",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/CauchyPrincipalValuelBib.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Hilbert Transformation",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/HilbertTransBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["The z-Transform",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ZTransformBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{939, 651},
WindowMargins->{{22, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[63856, 1405, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 128347, 2723}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 135, 2, 33, "Text"],
Cell[2240, 66, 2511, 70, 283, "Text"],
Cell[4754, 138, 2004, 51, 152, "Text",
  Evaluatable->False],
Cell[6761, 191, 8185, 137, 152, 8071, 133, "GraphicsData", "Bitmap", "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[14971, 332, 196, 7, 33, "Text"],
Cell[15170, 341, 177, 7, 33, "Text"],
Cell[15350, 350, 3586, 67, 604, "Input"]
}, Closed]],
Cell[18951, 420, 1781, 48, 111, "Text",
  Evaluatable->False],
Cell[20735, 470, 10027, 167, 152, 9913, 163, "GraphicsData", "Bitmap", "Text",
  
  Evaluatable->False],

Cell[CellGroupData[{
Cell[30787, 641, 115, 2, 33, "Text"],
Cell[30905, 645, 212, 7, 33, "Text"],
Cell[31120, 654, 3223, 60, 563, "Input"]
}, Closed]],
Cell[34358, 717, 1079, 30, 126, "Text"],
Cell[35440, 749, 209, 7, 33, "Text"],
Cell[35652, 758, 339, 11, 37, "Text",
  Evaluatable->False],
Cell[35994, 771, 10471, 175, 163, 10357, 171, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[46468, 948, 1332, 27, 213, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[47825, 979, 196, 7, 33, "Text"],
Cell[48024, 988, 258, 9, 33, "Text"],
Cell[48285, 999, 3451, 64, 584, "Input"],
Cell[51739, 1065, 261, 9, 37, "Text"],
Cell[52003, 1076, 1092, 24, 325, "Input"],
Cell[53098, 1102, 116, 2, 33, "Text",
  Evaluatable->False],
Cell[53217, 1106, 1154, 22, 170, "Input"],
Cell[54374, 1130, 229, 7, 33, "Text",
  Evaluatable->False],
Cell[54606, 1139, 2020, 37, 423, "Input"],
Cell[56629, 1178, 197, 7, 33, "Text",
  Evaluatable->False],
Cell[56829, 1187, 331, 7, 83, "Input"],
Cell[57163, 1196, 252, 8, 33, "Text",
  Evaluatable->False],
Cell[57418, 1206, 1292, 24, 295, "Input"],
Cell[58713, 1232, 96, 2, 33, "Text",
  Evaluatable->False]
}, Closed]],
Cell[58824, 1237, 897, 30, 54, "Text"],
Cell[59724, 1269, 2346, 71, 146, "Text",
  Evaluatable->False],
Cell[62073, 1342, 1349, 42, 38, "Text"],

Cell[CellGroupData[{
Cell[63447, 1388, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[63595, 1394, 258, 9, 33, "Text",
  Evaluatable->False],
Cell[63856, 1405, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[64216, 1417, 376, 14, 38, "Text",
  Evaluatable->False],
Cell[64595, 1433, 16835, 279, 157, 16721, 275, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[81433, 1714, 3222, 70, 407, "Text"],
Cell[84658, 1786, 1057, 20, 209, "Text"],

Cell[CellGroupData[{
Cell[85740, 1810, 196, 7, 33, "Text"],
Cell[85939, 1819, 210, 8, 39, "Text"],
Cell[86152, 1829, 1602, 36, 406, "Input"],
Cell[87757, 1867, 116, 2, 33, "Text",
  Evaluatable->False],
Cell[87876, 1871, 1767, 32, 250, "Input"],
Cell[89646, 1905, 267, 7, 33, "Text",
  Evaluatable->False],
Cell[89916, 1914, 2673, 49, 527, "Input"],
Cell[92592, 1965, 197, 7, 33, "Text",
  Evaluatable->False],
Cell[92792, 1974, 331, 7, 83, "Input"],
Cell[93126, 1983, 252, 8, 33, "Text",
  Evaluatable->False],
Cell[93381, 1993, 1292, 24, 295, "Input"],
Cell[94676, 2019, 96, 2, 33, "Text",
  Evaluatable->False]
}, Closed]],
Cell[94787, 2024, 331, 13, 39, "Text",
  Evaluatable->False],
Cell[95121, 2039, 17624, 292, 157, 17510, 288, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[112748, 2333, 2448, 50, 381, "Text"],
Cell[115199, 2385, 373, 8, 78, "Text"],

Cell[CellGroupData[{
Cell[115597, 2397, 196, 7, 33, "Text"],
Cell[115796, 2406, 190, 8, 40, "Text"],
Cell[115989, 2416, 2105, 46, 487, "Input"],
Cell[118097, 2464, 106, 2, 33, "Text",
  Evaluatable->False],
Cell[118206, 2468, 2376, 42, 330, "Input"],
Cell[120585, 2512, 232, 7, 33, "Text",
  Evaluatable->False],
Cell[120820, 2521, 2003, 37, 423, "Input"],
Cell[122826, 2560, 197, 7, 33, "Text",
  Evaluatable->False],
Cell[123026, 2569, 331, 7, 83, "Input"],
Cell[123360, 2578, 252, 8, 33, "Text",
  Evaluatable->False],
Cell[123615, 2588, 1547, 26, 371, "Input"],
Cell[125165, 2616, 96, 2, 33, "Text",
  Evaluatable->False]
}, Closed]],
Cell[125276, 2621, 290, 7, 30, "Text"],
Cell[125569, 2630, 313, 10, 33, "Text"],
Cell[125885, 2642, 318, 10, 33, "Text"],
Cell[126206, 2654, 331, 11, 33, "Text"],
Cell[126540, 2667, 320, 10, 33, "Text"],
Cell[126863, 2679, 311, 10, 33, "Text"],
Cell[127177, 2691, 257, 5, 33, "Text"],
Cell[127437, 2698, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

