(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     80334,       1803]*)
(*NotebookOutlinePosition[     81387,       1841]*)
(*  CellTagsIndexPosition[     81311,       1835]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["8.4  Improper Integrals Involving Trigonometric \
Functions",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tLet ",
  StyleBox["P(x)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Q(x)",
    FontFamily->"Courier New"],
  " be polynomials of degree ",
  StyleBox["m",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ", respectively, where  ",
  Cell[BoxData[
      \(n \[GreaterEqual] m + 1\)]],
  ".  We can show (but omit the proof) that if  ",
  Cell[BoxData[
      \(Q \((x)\) \[NotEqual] 0\)]],
  "  for all real ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ", then  \n\n\t\t\t",
  Cell[BoxData[
      \(P . 
        V . \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( P \((x)\) 
                  cos \((\[Alpha]\ x)\)\)\/\(Q \((x)\)\)\) \
\[DifferentialD]x\)\)]],
  "    and    ",
  Cell[BoxData[
      \(P . 
        V . \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( P \((x)\) 
                  sin \((\[Alpha]\ x)\)\)\/\(Q \((x)\)\)\) \
\[DifferentialD]x\)\)]],
  "  \n\nare convergent improper integrals.  You may encounter integrals of \
this type in the study of ",
  StyleBox[ButtonBox["Fourier",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Fourier.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " ",
  StyleBox[ButtonBox["transforms",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/FourierTransform.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " and ",
  StyleBox[ButtonBox["Fourier integrals",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/FourierTransform.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ".  We now show how to evaluate them."
}], "Text"],

Cell[TextData[{
  "\tParticularly important is our use of the identities\n\n\t\t\t",
  Cell[BoxData[
      \(cos \((\[Alpha]\ x)\)\  = \ 
        Re[\[ExponentialE]\^\(\[ImaginaryI]\ \[Alpha]\ x\)]\)]],
  "    and    ",
  Cell[BoxData[
      \(sin \((\[Alpha]\ x)\)\  = \ 
        Im[\[ExponentialE]\^\(\[ImaginaryI]\ \[Alpha]\ x\)]\)]],
  "  \n\nwhere  ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  "  is a positive real number.  The crucial step in the proof of Theorem 8.4 \
wouldn't hold if we were to use  ",
  Cell[BoxData[
      \(cos \((\[Alpha]\ z)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(sin \((\[Alpha]\ z)\)\)]],
  "  are used instead of  ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Alpha]\ z\)\)]],
  ", as you will see when you get to Lemma 8.1."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 8.4 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Contour Integration for Improper Trig. Integrals",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ContourIntegration.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["P(x)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Q(x)",
    FontFamily->"Courier New"],
  " be polynomials with real coefficients, of degree ",
  StyleBox["m",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ", respectively, where  ",
  Cell[BoxData[
      \(n \[GreaterEqual] m + 1\)]],
  "  and  ",
  Cell[BoxData[
      \(Q \((x)\) \[NotEqual] 0\)]],
  "  for all real ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " .  If  ",
  Cell[BoxData[
      \(\[Alpha] > 0\)]],
  "  and  \n\n",
  StyleBox["(8-12)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Alpha]\ z\)\ P \
\((z)\)\)\/\(Q \((z)\)\)\)]],
  ",    then\n\n",
  StyleBox["(8-13)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(P . 
          V . \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                    P \((x)\)\)\/\(Q \((x)\)\)\) 
              cos \((\[Alpha]\ x)\) \[DifferentialD]x\)\ \  = \ \ \(-\ 
            2\) \[Pi]\ \ \(\[Sum]\+\(j = 1\)\%k\ Im \((Res[f, z\_j])\)\)\)]],
  ",    and  \n\t\n",
  StyleBox["(8-14)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(P . 
          V . \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                    P \((x)\)\)\/\(Q \((x)\)\)\) 
              sin \((\[Alpha]\ x)\) \[DifferentialD]x\)\ \  = \ \ 2  \[Pi]\
\ \ \(\[Sum]\+\(j = 1\)\%k\ Re \((Res[f, z\_j])\)\)\)]],
  ",\n  \nwhere  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_k\)}]]],
  "  are the poles of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " that lie in the upper half plane and  ",
  Cell[BoxData[
      \(Re \((Res[f, z\_j])\)\)]],
  "  and  ",
  Cell[BoxData[
      \(Im \((Res[f, z\_j])\)\)]],
  "  are the real and imaginary parts of  ",
  Cell[BoxData[
      \(Res[f, z\_j]\)]],
  ",  respectively.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 8.4",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/integralstrigonometricimproper/\
IntegralsTrigImproperFigures/mat0804.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  The poles  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_k\)}]]],
  "  of  ",
  Cell[BoxData[
      \(\(\(P \((x)\)\)\/\(Q \((x)\)\)\) cos \((\[Alpha]\ x)\)\)]],
  "  or  ",
  Cell[BoxData[
      \(\(\(P \((x)\)\)\/\(Q \((x)\)\)\) sin \((\[Alpha]\ x)\)\)]],
  "  that lie in the upper half-plane. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Proof of Theorem 8.4",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[" is in the book.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\<\
\tThe proof of Theorem 8.4 is similar to the proof of Theorem 8.3.  Before \
turning to the proof, we illustrate how to use Theorem 8.4. \
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 8.17.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Evaluate  ",
  Cell[BoxData[
      \(P . V . \ 
        "\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\!\(\(x\\ sin\\ \
x\)\/\(x\^2\\  + \\ 4\)\)\[DifferentialD]x"\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:`0000VR000`400?l0
0000o`00003oo`3ooooo0?oook80oooo003o0?ooool0oooo/P3oool00?l0
ooooo`3ooonb0?ooo`00o`3ooooo0?oook80oooo003o0?ooool0oooo/P3o
ool00=@0oooo00<000000?ooo`3oool02@3oool500000?l0ooooc03oool0
0=@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oo
o`40oooo1@0000160?ooo`D00000N`3oool00=@0oooo00<000000?ooo`3o
ool00`3oool5000000<0oooo00<000000?ooo`3oool0o`3oool30?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool0N`3oool00=@0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo0?l0oooo0`3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo07/0oooo003<0?ooo`@000000P3oool30?l000L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3j0?ooo`@00000
103oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo07/0oooo
003<0?ooo`030000003oool0oooo0080oooo1@3o00070?ooo`040000003o
ool0oooo0?ooo`800000o`3oool50?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool0N`3oool00<d0oooo00<000000?ooo`3oool01`3o
00040?ooo`040000003oool0oooo00000?l0oooo203oool2000004T0oooo
0P00001m0?ooo`00aP3oool4000000@0oooo00<000000?ooo`3o00001P3o
00040?ooo`D00000o`3ooooA0?ooo`00c03oool010000000oooo0?ooo`00
00070?l00?l0oooofP3oool00<d0oooo0P0000020?ooo`D0o`00o`3ooooK
0?ooo`00dP3oool30?l00?l0oooog03oool00=@0oooo00<000000?ooo`3o
ool0_`3oooo[003oo`T0oooo0P0000000`3oool000000000000Q0?ooo`00
e03oool00`000000oooo0?ooo`2m0?ooo`800000j`00ool2000000P0oooo
00<000000?ooo`0000008P3oool00=@0oooo00<000000?ooo`3oool0_`3o
ooo[003oo`/0oooo00<000000?ooo`3oool08@3oool00=@0oooo00<00000
0?ooo`3oool0`03oool00`000?l0oooo0?ooo`1:0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1:
0?ooo`030000o`3oool0oooo00P0oooo0P0000000`3oool000000000000Q
0?ooo`00e03oool00`000000oooo0?ooo`300?ooo`030000o`3oool0oooo
0740oooo00<000000?ooo`3oool0L@3oool00`000?l0oooo0?ooo`0^0?oo
o`00e03oool00`000000oooo0?ooo`300?ooo`030000o`3oool0oooo0740
oooo00<000000?ooo`3oool0L@3oool00`000?l0oooo0?ooo`0^0?ooo`00
e03oool00`000000oooo0?ooo`310?ooo`030000o`3oool0oooo0700oooo
00<000000?ooo`3oool0L03oool00`000?l0oooo0?ooo`0_0?ooo`00e03o
ool00`000000oooo0?ooo`310?ooo`030000o`3oool0oooo0700oooo00<0
00000?ooo`3oool0L03oool00`000?l0oooo0?ooo`0_0?ooo`00e03oool0
0`000000oooo0?ooo`310?ooo`030000o`3oool0oooo0700oooo00<00000
0?ooo`3oool0L03oool00`000?l0oooo0?ooo`0_0?ooo`00e03oool00`00
0000oooo0?ooo`310?ooo`030000o`3oool0oooo0700oooo00<000000?oo
o`3oool0L03oool00`000?l0oooo0?ooo`0_0?ooo`00e03oool00`000000
oooo0?ooo`310?ooo`030000o`3oool0oooo0700oooo00<000000?ooo`3o
ool0L03oool00`000?l0oooo0?ooo`0_0?ooo`00e03oool00`000000oooo
0?ooo`310?ooo`030000o`3oool0oooo0700oooo00<000000?ooo`3oool0
L03oool00`000?l0oooo0?ooo`0_0?ooo`00e03oool00`000000oooo0?oo
o`310?ooo`030000o`3oool0oooo0700oooo00<000000?ooo`3oool0L03o
ool00`000?l0oooo0?ooo`0_0?ooo`00e03oool00`000000oooo0?ooo`31
0?ooo`030000o`3oool0oooo0700oooo00<000000?ooo`3oool0L03oool0
0`000?l0oooo0?ooo`0_0?ooo`00e03oool00`000000oooo0?ooo`310?oo
o`030000o`3oool0oooo0700oooo00<000000?ooo`3oool0L03oool00`00
0?l0oooo0?ooo`0_0?ooo`00e03oool00`000000oooo0?ooo`310?ooo`03
0000o`3oool0oooo0700oooo00<000000?ooo`3oool0L03oool00`000?l0
oooo0?ooo`0_0?ooo`00e03oool00`000000oooo0?ooo`310?ooo`030000
o`3oool0oooo0700oooo00<000000?ooo`3oool0L03oool00`000?l0oooo
0?ooo`0_0?ooo`00e03oool00`000000oooo0?ooo`310?ooo`030000o`3o
ool0oooo0700oooo00<000000?ooo`3oool0K`3oool00`000?l0oooo0?oo
o`0`0?ooo`00e03oool00`000000oooo0?ooo`320?ooo`030000o`3oool0
oooo06l0oooo00<000000?ooo`3oool0K`3oool00`000?l0oooo0?ooo`0`
0?ooo`00e03oool00`000000oooo0?ooo`320?ooo`030000o`3oool0oooo
06l0oooo00<000000?ooo`3oool0K`3oool00`000?l0oooo0?ooo`0`0?oo
o`00e03oool00`000000oooo0?ooo`320?ooo`030000o`3oool0oooo06l0
oooo00<000000?ooo`3oool0K`3oool00`000?l0oooo0?ooo`0`0?ooo`00
e03oool00`000000oooo0?ooo`320?ooo`030000o`3oool0oooo06l0oooo
00<000000?ooo`3oool0K`3oool00`000?l0oooo0?ooo`0`0?ooo`00e03o
ool00`000000oooo0?ooo`320?ooo`030000o`3oool0oooo06l0oooo00<0
00000?ooo`3oool0K`3oool00`000?l0oooo0?ooo`0`0?ooo`00c03oool5
000000<0oooo00<000000?ooo`3oool0``3oool00`000?l0oooo0?ooo`1^
0?ooo`030000003oool0oooo06h0oooo00<0003o0?ooo`3oool0<@3oool0
0<h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`330?oo
o`030000o`3oool0oooo06h0oooo00<000000?ooo`3oool0KP3oool00`00
0?l0oooo0?ooo`0a0?ooo`00cP3oool00`000000oooo0?ooo`030?ooo`80
0000a03oool00`000?l0oooo0?ooo`1^0?ooo`030000003oool0oooo06h0
oooo00<0003o0?ooo`3oool0<@3oool00<H0oooo100000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0``3oool00`000?l0oooo
0?ooo`1^0?ooo`030000003oool0oooo06h0oooo00<0003o0?ooo`3oool0
<@3oool00<h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`330?ooo`030000o`3oool0oooo06h0oooo00<000000?ooo`3oool0KP3o
ool00`000?l0oooo0?ooo`0a0?ooo`00c@3oool2000000D0oooo00<00000
0?ooo`3oool0``3oool00`000?l0oooo0?ooo`1^0?ooo`030000003oool0
oooo06h0oooo00<0003o0?ooo`3oool0<@3oool00=@0oooo00<000000?oo
o`3oool0a03oool00`000?l0oooo0?ooo`1]0?ooo`030000003oool0oooo
06d0oooo00<0003o0?ooo`3oool0<P3oool00=@0oooo00<000000?ooo`3o
ool0a03oool00`000?l0oooo0?ooo`1]0?ooo`030000003oool0oooo06d0
oooo00<0003o0?ooo`3oool0<P3oool00=@0oooo00<000000?ooo`3oool0
a03oool00`000?l0oooo0?ooo`1]0?ooo`030000003oool0oooo06`0oooo
00<0003o0?ooo`3oool0<`3oool00=@0oooo00<000000?ooo`3oool0a@3o
ool00`000?l0oooo0?ooo`1/0?ooo`030000003oool0oooo06`0oooo00<0
003o0?ooo`3oool0<`3oool00=@0oooo00<000000?ooo`3oool0a@3oool0
0`000?l0oooo0?ooo`1/0?ooo`030000003oool0oooo06`0oooo00<0003o
0?ooo`3oool0<`3oool00=@0oooo00<000000?ooo`3oool0a@3oool00`00
0?l0oooo0?ooo`1/0?ooo`030000003oool0oooo06`0oooo00<0003o0?oo
o`3oool0<`3oool00=@0oooo00<000000?ooo`3oool0a@3oool00`000?l0
oooo0?ooo`1/0?ooo`030000003oool0oooo06`0oooo00<0003o0?ooo`3o
ool0<`3oool00=@0oooo00<000000?ooo`3oool0a@3oool00`000?l0oooo
0?ooo`1/0?ooo`030000003oool0oooo06`0oooo00<0003o0?ooo`3oool0
<`3oool00=@0oooo00<000000?ooo`3oool0aP3oool00`000?l0oooo0?oo
o`1[0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool0=03o
ool00=@0oooo00<000000?ooo`3oool0aP3oool00`000?l0oooo0?ooo`1S
0?ooo`D000000`3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0
oooo03@0oooo003D0?ooo`030000003oool0oooo0<H0oooo00<0003o0?oo
o`3oool0I@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
06X0oooo00<0003o0?ooo`3oool0=@3oool00=@0oooo00<000000?ooo`3o
ool0a`3oool00`000?l0oooo0?ooo`1T0?ooo`030000003oool0oooo00<0
oooo0`00001Z0?ooo`030000o`3oool0oooo03D0oooo003D0?ooo`030000
003oool0oooo0<L0oooo00<0003o0?ooo`3oool0I03oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool0
=@3oool00=@0oooo00<000000?ooo`3oool0b03oool00`000?l0oooo0?oo
o`1S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0J@3o
ool00`000?l0oooo0?ooo`0f0?ooo`00H03oool4000003H0oooo1@00000e
0?ooo`030000003oool0oooo03D0oooo1@00000f0?ooo`@00000E03oool0
0`000?l0oooo0?ooo`1R0?ooo`8000001@3oool00`000000oooo0?ooo`1Y
0?ooo`030000o`3oool0oooo03H0oooo001P0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0E@3oool00`00
0?l0oooo0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<0003o0?oo
o`3oool0=P3oool00640oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`1E0?ooo`030000o`3oool0oooo06P0
oooo00<000000?ooo`3oool0J03oool00`000?l0oooo0?ooo`0g0?ooo`00
FP3oool4000000@0oooo00<000000?ooo`3oool0;`3oool4000000@0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0E03oool00`000?l0oooo
0?ooo`1X0?ooo`030000003oool0oooo06P0oooo00<0003o0?ooo`3oool0
=`3oool00600oooo00@000000?ooo`3oool00000>03oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
=P3oool010000000oooo0?ooo`00001E0?ooo`030000o`3oool0oooo06P0
oooo00<000000?ooo`3oool0I`3oool00`000?l0oooo0?ooo`0h0?ooo`00
H@3oool2000003P0oooo0P00000g0?ooo`030000003oool0oooo03H0oooo
0P00000i0?ooo`800000E`3oool00`000?l0oooo0?ooo`1W0?ooo`030000
003oool0oooo06L0oooo00<0003o0?ooo`3oool0>03oool00=@0oooo00<0
00000?ooo`3oool0b`3oool00`000?l0oooo0?ooo`1V0?ooo`030000003o
ool0oooo06H0oooo00<0003o0?ooo`3oool0>@3oool00=@0oooo00<00000
0?ooo`3oool0b`3oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0
oooo06H0oooo00<0003o0?ooo`3oool0>@3oool00=@0oooo00<000000?oo
o`3oool0c03oool00`000?l0oooo0?ooo`1U0?ooo`030000003oool0oooo
06D0oooo00<0003o0?ooo`3oool0>P3oool00=@0oooo00<000000?ooo`3o
ool0QP3oool2000000030?ooo`00000000000440oooo00<0003o0?ooo`3o
ool0I@3oool00`000000oooo0?ooo`1T0?ooo`030000o`3oool0oooo03/0
oooo003D0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`000000
@`3oool00`000?l0oooo0?ooo`1T0?ooo`030000003oool0oooo06@0oooo
00<0003o0?ooo`3oool0>`3oool005<0ooooo`000004000000T0oooo00<0
00000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`1T0?ooo`030000003o
ool0oooo06@0oooo00<0003o0?ooo`3oool0>`3oool005l0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0A
0?ooo`80000000<0oooo000000000000@`3oool00`000?l0oooo0?ooo`1S
0?ooo`030000003oool0oooo06<0oooo00<0003o0?ooo`3oool0?03oool0
05l0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`1I0?ooo`030000o`3oool0oooo06<0oooo00<000000?oo
o`3oool0H`3oool00`000?l0oooo0?ooo`0l0?ooo`00e03oool00`000000
oooo0?ooo`3>0?ooo`030000o`3oool0oooo06<0oooo00<000000?ooo`3o
ool0HP3oool00`000?l0oooo0?ooo`0m0?ooo`00e03oool00`000000oooo
0?ooo`3?0?ooo`030000o`3oool0oooo0680oooo00<000000?ooo`3oool0
HP3oool00`000?l0oooo0?ooo`0m0?ooo`00e03oool00`000000oooo0?oo
o`3@0?ooo`030000o`3oool0oooo0640oooo00<000000?ooo`3oool0H@3o
ool00`000?l0oooo0?ooo`0n0?ooo`00e03oool00`000000oooo0?ooo`3@
0?ooo`030000o`3oool0oooo0640oooo00<000000?ooo`3oool0H@3oool0
0`000?l0oooo0?ooo`0n0?ooo`00e03oool00`000000oooo0?ooo`3A0?oo
o`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0H03oool00`00
0?l0oooo0?ooo`0o0?ooo`00e03oool00`000000oooo0?ooo`3A0?ooo`03
0000o`3oool0oooo0600oooo00<000000?ooo`3oool0G`3oool00`000?l0
oooo0?ooo`100?ooo`00e03oool00`000000oooo0?ooo`3B0?ooo`030000
o`3oool0oooo05l0oooo00<000000?ooo`3oool0G`3oool00`000?l0oooo
0?ooo`100?ooo`00e03oool00`000000oooo0?ooo`3C0?ooo`030000o`3o
ool0oooo05h0oooo00<000000?ooo`3oool0GP3oool00`000?l0oooo0?oo
o`110?ooo`00e03oool00`000000oooo0?ooo`3C0?ooo`030000o`3oool0
oooo05h0oooo00<000000?ooo`3oool0GP3oool00`000?l0oooo0?ooo`11
0?ooo`00e03oool00`000000oooo0?ooo`3D0?ooo`030000o`3oool0oooo
05d0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`120?oo
o`00e03oool00`000000oooo0?ooo`3E0?ooo`030000o`3oool0oooo05`0
oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?ooo`130?ooo`00
e03oool00`000000oooo0?ooo`3F0?ooo`030000o`3oool0oooo05/0oooo
00<000000?ooo`3oool0F`3oool00`000?l0oooo0?ooo`140?ooo`00e03o
ool00`000000oooo0?ooo`3F0?ooo`030000o`3oool0oooo05/0oooo00<0
00000?ooo`3oool0FP3oool00`000?l0oooo0?ooo`150?ooo`00e03oool0
0`000000oooo0?ooo`3G0?ooo`030000o`3oool0oooo05X0oooo00<00000
0?ooo`3oool0FP3oool00`000?l0oooo0?ooo`150?ooo`00e03oool00`00
0000oooo0?ooo`3H0?ooo`030000o`3oool0oooo05T0oooo00<000000?oo
o`3oool0F@3oool00`000?l0oooo0?ooo`160?ooo`00e03oool00`000000
oooo0?ooo`3H0?ooo`030000o`3oool0oooo05T0oooo00<000000?ooo`3o
ool0F@3oool00`000?l0oooo0?ooo`160?ooo`00e03oool00`000000oooo
0?ooo`3I0?ooo`030000o`3oool0oooo05P0oooo00<000000?ooo`3oool0
F03oool00`000?l0oooo0?ooo`170?ooo`00e03oool00`000000oooo0?oo
o`3J0?ooo`030000o`3oool0oooo05L0oooo00<000000?ooo`3oool0E`3o
ool00`000?l0oooo0?ooo`180?ooo`00e03oool00`000000oooo0?ooo`3K
0?ooo`030000o`3oool0oooo05H0oooo00<000000?ooo`3oool02`3oool3
000004P0oooo00<0003o0?ooo`3oool0B@3oool00=@0oooo00<000000?oo
o`3oool0g03oool00`000?l0oooo0?ooo`1D0?ooo`<0o`00303oool00`00
0000oooo0?ooo`170?ooo`030000o`3oool0oooo04X0oooo003D0?ooo`03
0000003oool0oooo0=d0oooo00<0003o0?ooo`3oool0C03oool400000080
oooo1@3o00040?ooo`D000000`3oool00`000000oooo0?ooo`160?ooo`03
0000o`3oool0oooo04X0oooo003D0?ooo`030000003oool0oooo0=d0oooo
00<0003o0?ooo`3oool0C03oool00`000000oooo0?ooo`020?ooo`L0o`00
103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo04D0
oooo00<0003o0?ooo`3oool0B`3oool00=@0oooo00<000000?ooo`3oool0
gP3oool00`000?l0oooo0?ooo`1<0?ooo`040000003oool0oooo0?ooo`L0
o`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000004D0
oooo00<0003o0?ooo`3oool0C03oool00=@0oooo00<000000?ooo`3oool0
g`3oool00`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo00L0o`00
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04<0oooo
00<0003o0?ooo`3oool0C@3oool00<`0oooo1@0000030?ooo`030000003o
ool0oooo0>00oooo00<0003o0?ooo`3oool0B@3oool010000000oooo0?oo
o`0000020?ooo`D0o`001@3oool010000000oooo0?ooo`0000180?ooo`03
0000o`3oool0oooo04h0oooo003>0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0h@3oool00`000?l0oooo0?ooo`190?ooo`800000
103oool30?l000H0oooo1@0000160?ooo`030000o`3oool0oooo04l0oooo
003>0?ooo`030000003oool0oooo00<0oooo0P00003S0?ooo`030000o`3o
ool0oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000?l0oooo0?oo
o`1@0?ooo`00cP3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0><0oooo00<0003o0?ooo`3oool0CP3oool00`000000oooo0?ooo`1>
0?ooo`030000o`3oool0oooo0540oooo003>0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0i03oool00`000?l0oooo0?ooo`1=0?oo
o`030000003oool0oooo04d0oooo00<0003o0?ooo`3oool0DP3oool00<d0
oooo0P0000050?ooo`030000003oool0oooo0>D0oooo00<0003o0?ooo`3o
ool0C03oool00`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo05<0
oooo003D0?ooo`030000003oool0oooo0>H0oooo00<0003o0?ooo`3oool0
B`3oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo05@0oooo
003D0?ooo`030000003oool0oooo0>L0oooo0P000?m;0?ooo`030000003o
ool0oooo04T0oooo0P000?mG0?ooo`00e03oool00`000000oooo0?ooo`3Y
0?ooo`030000o`3oool0oooo04P0oooo00<000000?ooo`3oool0B03oool0
0`000?l0oooo0?ooo`1G0?ooo`00e03oool00`000000oooo0?ooo`3Z0?oo
o`030000o`3oool0oooo04L0oooo00<000000?ooo`3oool0A`3oool00`00
0?l0oooo0?ooo`1H0?ooo`00e03oool00`000000oooo0?ooo`3[0?ooo`03
0000o`3oool0oooo04H0oooo00<000000?ooo`3oool0AP3oool00`000?l0
oooo0?ooo`1I0?ooo`00e03oool00`000000oooo0?ooo`3/0?ooo`030000
o`3oool0oooo04D0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo
0?ooo`1J0?ooo`00e03oool00`000000oooo0?ooo`3]0?ooo`030000o`3o
ool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?oo
o`1K0?ooo`00e03oool00`000000oooo0?ooo`3^0?ooo`80003oA03oool0
0`000000oooo0?ooo`120?ooo`80003oGP3oool00=@0oooo00<000000?oo
o`3oool0l03oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo
0440oooo00<0003o0?ooo`3oool0GP3oool00=@0oooo00<000000?ooo`3o
ool0l@3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo0400
oooo00<0003o0?ooo`3oool0G`3oool00=@0oooo00<000000?ooo`3oool0
lP3oool20000od00oooo00<000000?ooo`3oool0?P3oool20000of80oooo
003D0?ooo`030000003oool0oooo0?@0oooo00<0003o0?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo0680oooo003D
0?ooo`030000003oool0oooo0?D0oooo0P000?lm0?ooo`030000003oool0
oooo03/0oooo0P000?mU0?ooo`00e03oool00`000000oooo0?ooo`3g0?oo
o`80003o>`3oool00`000000oooo0?ooo`0i0?ooo`80003oI`3oool00=@0
oooo00<000000?ooo`3oool0n@3oool00`000?l0oooo0?ooo`0h0?ooo`03
0000003oool0oooo03P0oooo00<0003o0?ooo`3oool0I`3oool00=@0oooo
00<000000?ooo`3oool0nP3oool30000ocL0oooo00<000000?ooo`3oool0
=@3oool30000ofX0oooo003D0?ooo`030000003oool0oooo0?d0oooo0P00
0?le0?ooo`030000003oool0oooo03<0oooo0P000?m]0?ooo`00e03oool0
0`000000oooo0?ooo`3o0?ooo`030000o`3oool0oooo0380oooo00<00000
0?ooo`3oool0<P3oool00`000?l0oooo0?ooo`1]0?ooo`00e03oool00`00
0000oooo0?ooo`3o0?ooo`40oooo0P000?lb0?ooo`030000003oool0oooo
0300oooo0P000?m`0?ooo`00e03oool00`000000oooo0?ooo`0:0?ooo`<0
0000m@3oool20000oc00oooo00<000000?ooo`3oool0;P3oool20000og80
oooo003D0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
m`3oool30000obd0oooo00<000000?ooo`3oool0:`3oool30000og@0oooo
003D0?ooo`030000003oool0oooo00<0oooo1@0000030?ooo`030000003o
ool0oooo0?T0oooo0P000?l[0?ooo`030000003oool0oooo02T0oooo0P00
0?mg0?ooo`00e03oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0n`3oool30000obP0oooo00<0
00000?ooo`3oool09P3oool30000ogT0oooo003B0?ooo`<0o`001`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool000000?l0oooo0`000?lU
0?ooo`030000003oool0oooo02<0oooo0`000?ml0?ooo`00c03oool40000
00030?ooo`3o0000o`0000<0o`001`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0?l0oooo0P3oool20000ob<0oooo00<000000?oo
o`3oool08@3oool20000ogl0oooo003<0?ooo`040000003oool0oooo0?oo
o`L0o`00103oool010000000oooo0?ooo`00003o0?ooo`X0oooo0`000?lP
0?ooo`030000003oool0oooo01h0oooo0`000?n10?ooo`00c@3oool00`00
0000oooo0?ooo`070?l000@0oooo1@00003o0?ooo``0oooo0`000?lM0?oo
o`030000003oool0oooo01/0oooo0`000?n40?ooo`00cP3oool00`000000
oooo0?l000060?l00?l0oooo603oool50000oaP0oooo00<000000?ooo`3o
ool05P3oool50000ohL0oooo003<0?ooo`050000003oool0oooo0000003o
ool01@3o003o0?oooah0oooo1P000?lB0?ooo`030000003oool0oooo0100
oooo1P000?n<0?ooo`00c@3oool2000000<0oooo0`3o003o0?ooobD0oooo
2@000?l90?ooo`030000003oool0oooo00P0oooo20000?nB0?ooo`00e03o
ool00`000000oooo0?ooo`3o0?ooob`0oooo50000?nJ0?ooo`00e03oool0
0`000000oooo0?ooo`3o0?ooocD0oooo00<000000?ooo`3oool0XP3oool0
0?l0ooooo`3oool=0?ooo`030000003oool0oooo0:80oooo003o0?ooool0
oooo/P3oool00?l0ooooo`3ooonb0?ooo`00o`3ooooo0?oook80oooo003o
0?ooool0oooo/P3oool00?l0ooooo`3ooonb0?ooo`00o`3ooooo0?oook80
oooo003o0?ooool0oooo/P3oool00?l0ooooo`3ooonb0?ooo`00dP3oool2
00000?l0oooo=P3oool200000:D0oooo003C0?ooo`030000003oool0oooo
0?l0oooo=@3oool00`000000oooo0?ooo`2S0?ooo`00e03oool00`000000
oooo0?ooo`3o0?ooocD0oooo00<000000?ooo`3oool0XP3oool00=<0oooo
00<000000?ooo`000000o`3ooole0?ooo`030000003oool000000:<0oooo
003B0?ooo`040000003oool0oooo00000?l0oooo=03oool010000000oooo
0?ooo`00002S0?ooo`00d@3oool3000000030?ooo`00000000000?l0oooo
<P3oool3000000030?ooo`00000000000:80oooo003o0?ooool0oooo/P3o
ool00?l0ooooo`3ooonb0?ooo`00o`3ooooo0?oook80oooo003o0?ooool0
oooo/P3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{688, 154},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The function",
  " ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " ",
  "in Equation ",
  StyleBox["(8-12)",
    FontColor->RGBColor[0, 0, 1]],
  " is  ",
  Cell[BoxData[
      \(f \((z)\) = \(\(z\ \[ExponentialE]\^\(\[ImaginaryI]\ z\)\)\/\(z\^2\  \
+ \ 4\) = \(z\ \[ExponentialE]\^\(\[ImaginaryI]\ z\)\)\/\(\((z + 2  \
\[ImaginaryI])\) \((z - 2  \[ImaginaryI])\)\)\)\)]],
  ",  which has a simple pole at the point  ",
  Cell[BoxData[
      \(z\_2 = 2  \[ImaginaryI]\)]],
  "  in the upper half-plane.  Calculating the residue yields \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, 
          2  \[ImaginaryI]]\ \  = \ \ lim\+\(z\  \[Rule] 2  \[ImaginaryI]\)\ \
\((z - 2  \[ImaginaryI])\) f \((z)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] 2  \[ImaginaryI]\)\ \((z - 
                2  \[ImaginaryI])\) \(z\ \[ExponentialE]\^\(\[ImaginaryI]\ \
z\)\)\/\(\((z + 2  \[ImaginaryI])\) \((z - 2  \[ImaginaryI])\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] 2  \[ImaginaryI]\)\ \(z\ \[ExponentialE]\^\(\
\[ImaginaryI]\ z\)\)\/\(z + 2  \[ImaginaryI]\)\ \  = \ \ \(\((2  \
\[ImaginaryI])\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \((2  \
\[ImaginaryI])\)\)\)\/\(2  \[ImaginaryI] + 2  \[ImaginaryI]\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\
\(\((2  \[ImaginaryI])\)\ \[ExponentialE]\^\(-2\)\)\/\(4  \[ImaginaryI]\)\)\)\
\(\[IndentingNewLine]\)
      \(\ \)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(\
\(\ \)\(1\)\)\/\(2  \[ExponentialE]\^2\)\)\)\)}]],
  "   "
}], "Text"],

Cell[TextData[{
  "Using Equation ",
  StyleBox["(8-14)",
    FontColor->RGBColor[0, 0, 1]],
  " gives \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(P . V . \ 
          "\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\!\(\(x\\ sin\\ \
x\)\/\(x\^2 + 4\)\)\[DifferentialD]x"\ \  = \ \ 2  \[Pi]\ \ Re \((Res[f, 
              z\_1])\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(2  \[Pi]\ \ Re \((Res[f, 
              2  \[ImaginaryI]])\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(2  \[Pi]\ \ Re \((\(\(\ \)\(1\)\)\/\(2  \[ExponentialE]\^2\
\))\)\ \  = \ \ 2  \[Pi]\ \((\(\(\ \)\(1\)\)\/\(2  \
\[ExponentialE]\^2\))\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(=\)\(\ \ \)\(\[Pi]\/\[ExponentialE]\^2\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.17.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the functions  ",
  Cell[BoxData[
      \(F[x] = \(x\ Sin[x]\)\/\(x\^2\  + \ 4\)\)],
    AspectRatioFixed->False],
  "  and  ",
  Cell[BoxData[
      \(f[
          z] = \(z\ \[ExponentialE]\^\(\[ImaginaryI]\ z\)\)\/\(z\^2\  + \ 4\)\
\)],
    AspectRatioFixed->True],
  "  and ",
  "locate the",
  " singularities of  f[z]."
}], "Text"],

Cell[BoxData[{
    \(Z = \(z = \(x = 0\)\); \ Remove[x, z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, g, Res1, Res2, solset, 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\(F[x_] = \(x\ Sin[x]\)\/\(x\^2\  + \ 4\);\)\ \), "\n", 
    \(\(f[
          z_]\  = \ \(z\ \[ExponentialE]\^\(\[ImaginaryI]\ z\)\)\/\(z\^2\  + \
\ 4\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[x] = \>", F[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[Denominator[f[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, 
            z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The singularities are\>"];\)\ \), "\n", 
    \(\(Z\_1\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", 
        Z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell["Which poles lie in the upper half plane?", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_2], Im[Z\_2]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] - 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] - 0.1}, {\(-1\), 
                0}]}];\)\ \), "\n", 
    \(\(Show[dots, centers, 
        PlotRange \[Rule] {{\(-2.2\), 2.2}, {\(-2.2\), 2.2}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<, Is  Im(\>", 
        Z\_1, "\<) > 0 ?  \>", N[Im[Z\_1]] > 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<,  Is  Im(\>", 
        Z\_2, "\<) > 0 ?   \>", 
        N[Im[Z\_2]] > 0];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Compute the residues at  ",
  Cell[BoxData[
      \(z\_2 = 2  \[ImaginaryI]\)]],
  ", and use the residue calculus to compute the value of the integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Res2\  = \ Residue[f[z], {z, Z\_2}];\)\ \), "\[IndentingNewLine]", 
    \(\(val\  = 2  \[Pi]\ \ Re[Res2];\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_2, "\<] = \>", 
        Res2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Re[Res[f,\>", Z\_2, "\<]] = \>", 
        Re[Res2]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{Red, PointSize[0.03], 
            Point[{Re[Z\_2], Im[Z\_2]}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], 
                Im[Z\_2]}, {\(-1.2\), 0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ 
        Graphics[{Blue, 
            Circle[{0, 0}, 3, {0, \[Pi]}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(segment = 
        Graphics[{Thickness[0.015], Cyan, 
            Line[{{\(-3\), 0}, {3, 0}}]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, segment, 
        PlotRange \[Rule] {{\(-3.1\), 3.1}, {\(-0.05\), 3.05}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 2, 1]}, 
        AspectRatio \[Rule] 1\/2, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = 2\[Pi] Re[\>", Res2\ , "\<] = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The contour is the semicircle \!\(C\_R\) and interval \
[-R,R],\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<taken with the positive orientation.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value \
of the integral.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"\
", F[x], "\< \[DifferentialD]x = 2\[Pi] Re[\>", Res2, "\<] = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral of  f[z] for this problem is  g[z],  but it cannot be used \
in any meaningful way to solve the problem at hand."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(g[x_]\  = \[Integral]F[x] \[DifferentialD]x;\)\ \), "\n", 
    \(\(Print["\<F[x] = \>", F[x]];\)\ \), "\n", 
    \(\(Print["\<g[x] = \[Integral] \>", F[x], "\< \[DifferentialD]x = \>", 
        g[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<      g[\[Infinity]] = \>", g[\[Infinity]]];\)\ \), "\n", 
    \(\(Print["\<     g[-\[Infinity]] = \>", 
        g[\(-\[Infinity]\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<g[\[Infinity]]-g[-\[Infinity]] = \>", 
        Simplify[g[\[Infinity]] - g[\(-\[Infinity]\)]]];\)\ \), "\n", 
    \(\(Print["\<g[\[Infinity]]-g[-\[Infinity]] = \>", 
        N[g[\[Infinity]] - 
            g[\(-\[Infinity]\)]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "This looks good, however it ",
  StyleBox["cannot",
    FontColor->RGBColor[1, 0, 1]],
  " be used to solve for the definite integral. This does ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " agree with the answer obtained with the residue calculus."
}], "Text"],

Cell[BoxData[
    \(\(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        F[x], "\< \[DifferentialD]x = \>", val, "\< = \>", 
        N[val]];\)\(\ \)\(\[IndentingNewLine]\)
    \)\)], "Input",
  AspectRatioFixed->False],

Cell["\<\
However, the definite integral will produce the following result.\
\>", "Text"],

Cell[BoxData[{
    \(\(val\  = \[Integral]\_\(-\[Infinity]\)\%\[Infinity] F[
              x] \[DifferentialD]x\ ;\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        F[x], "\< \[DifferentialD]x = \>", val, "\< = \>", 
        N[val]];\)\ \), "\n", 
    \(\)}], "Input"],

Cell["Which is also the correct answer.", "Text"],

Cell["The PrincipalValue option can also be used.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(int = 
        Integrate[F[x], {x, \(-\[Infinity]\), \[Infinity]}, 
          PrincipalValue \[Rule] True];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        F[x], "\< \[DifferentialD]x = \>", 
        int];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.18.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Evaluate  ",
  Cell[BoxData[
      \(P . V . \ 
        "\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\!\(\(cos\\ x\)\/\(x\
\^4 + 4\)\)\[DifferentialD]x"\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:c0000VR000`400?l0
0000o`00003oo`3ooooo0?oookD0oooo003o0?ooool0oooo]@3oool00?l0
ooooo`3ooone0?ooo`00o`3ooooo0?oookD0oooo003o0?ooool0oooo]@3o
ool00=@0oooo00<000000?ooo`3oool0o`3ooooM0?ooo`00e03oool00`00
0000oooo0?ooo`3o0?oooa80oooo1@0000160?ooo`D00000N`3oool00=@0
oooo00<000000?ooo`3oool0o`3ooolD0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0N`3oool00:D0oooo1@00000Z0?ooo`030000
003oool0oooo04D0oooo0P00003<0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool0N`3oool009l0oooo1@0000030?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0?@3oool5000000D0oooo00<0
00000?ooo`3oool0`@3oool4000000@0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`1k0?ooo`00X03oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0?P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0<X0oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1k0?ooo`00X@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0<P0oooo0P0000190?ooo`800000O@3oool00:80oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool00P3oool00`000000oooo0000003o
0?oooiD0oooo002P0?ooo`040000003oool0oooo00000080oooo0P00000/
0?ooo`030000003oool0oooo03h0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`3o0?oooi@0oooo002H0?ooo`<0o`001@3oool5
000002L0oooo1@0000030?ooo`030000003oool0oooo03H0oooo0`3o0005
0?ooo`D00000o`3ooonJ0?ooo`00U`3oool50?l00380oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0e0?ooo`D0o`00o`3ooonS0?oo
o`00UP3oool70?l00340oooo00<000000?ooo`3oool00`3oool2000003D0
oooo1`3o00270?ooon/00?oo2@3oool2000000030?ooo`00000000000240
oooo002F0?ooo`L0o`00:@3oool4000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0d0?ooo`L0o`00Q@3oool200000>/00?oo
0P0000080?ooo`030000003oool000000280oooo002F0?ooo`L0o`00<@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo1`3o
00270?ooon/00?oo2`3oool00`000000oooo0?ooo`0Q0?ooo`00U`3oool5
0?l00340oooo0P0000050?ooo`030000003oool0oooo03D0oooo1@3o0029
0?ooo`030000o`3oool0oooo04X0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04X0oooo00<0003o
0?ooo`3oool0203oool2000000030?ooo`00000000000240oooo002H0?oo
o`<0o`00>@3oool00`000000oooo0?ooo`0f0?ooo`<0o`00RP3oool00`00
0?l0oooo0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<0003o0?oo
o`3oool0;P3oool00=@0oooo00<000000?ooo`3oool0``3oool00`000?l0
oooo0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<0003o0?ooo`3o
ool0;P3oool00=@0oooo00<000000?ooo`3oool0a03oool00`000?l0oooo
0?ooo`1`0?ooo`030000003oool0oooo0700oooo00<0003o0?ooo`3oool0
;`3oool00=@0oooo00<000000?ooo`3oool0a03oool00`000?l0oooo0?oo
o`1`0?ooo`030000003oool0oooo0700oooo00<0003o0?ooo`3oool0;`3o
ool00=@0oooo00<000000?ooo`3oool0a03oool00`000?l0oooo0?ooo`1`
0?ooo`030000003oool0oooo0700oooo00<0003o0?ooo`3oool0;`3oool0
0=@0oooo00<000000?ooo`3oool0a03oool00`000?l0oooo0?ooo`1`0?oo
o`030000003oool0oooo0700oooo00<0003o0?ooo`3oool0;`3oool00=@0
oooo00<000000?ooo`3oool0a03oool00`000?l0oooo0?ooo`1`0?ooo`03
0000003oool0oooo0700oooo00<0003o0?ooo`3oool0;`3oool00=@0oooo
00<000000?ooo`3oool0a03oool00`000?l0oooo0?ooo`1`0?ooo`030000
003oool0oooo0700oooo00<0003o0?ooo`3oool0;`3oool00=@0oooo00<0
00000?ooo`3oool0a03oool00`000?l0oooo0?ooo`1`0?ooo`030000003o
ool0oooo0700oooo00<0003o0?ooo`3oool0;`3oool00=@0oooo00<00000
0?ooo`3oool0a03oool00`000?l0oooo0?ooo`1`0?ooo`030000003oool0
oooo0700oooo00<0003o0?ooo`3oool0;`3oool00=@0oooo00<000000?oo
o`3oool0a03oool00`000?l0oooo0?ooo`1`0?ooo`030000003oool0oooo
0700oooo00<0003o0?ooo`3oool0;`3oool00=@0oooo00<000000?ooo`3o
ool0a03oool00`000?l0oooo0?ooo`1`0?ooo`030000003oool0oooo0700
oooo00<0003o0?ooo`3oool0;`3oool00=@0oooo00<000000?ooo`3oool0
a03oool00`000?l0oooo0?ooo`1`0?ooo`030000003oool0oooo0700oooo
00<0003o0?ooo`3oool0;`3oool00=@0oooo00<000000?ooo`3oool0a03o
ool00`000?l0oooo0?ooo`1`0?ooo`030000003oool0oooo06l0oooo00<0
003o0?ooo`3oool0<03oool00=@0oooo00<000000?ooo`3oool0a@3oool0
0`000?l0oooo0?ooo`1_0?ooo`030000003oool0oooo06l0oooo00<0003o
0?ooo`3oool0<03oool00=@0oooo00<000000?ooo`3oool0a@3oool00`00
0?l0oooo0?ooo`1_0?ooo`030000003oool0oooo06l0oooo00<0003o0?oo
o`3oool0<03oool00=@0oooo00<000000?ooo`3oool0a@3oool00`000?l0
oooo0?ooo`1_0?ooo`030000003oool0oooo06l0oooo00<0003o0?ooo`3o
ool0<03oool00=@0oooo00<000000?ooo`3oool0a@3oool00`000?l0oooo
0?ooo`1_0?ooo`030000003oool0oooo06l0oooo00<0003o0?ooo`3oool0
<03oool00=@0oooo00<000000?ooo`3oool0a@3oool00`000?l0oooo0?oo
o`1_0?ooo`030000003oool0oooo06l0oooo00<0003o0?ooo`3oool0<03o
ool00=@0oooo00<000000?ooo`3oool0aP3oool00`000?l0oooo0?ooo`1^
0?ooo`030000003oool0oooo06h0oooo00<0003o0?ooo`3oool0<@3oool0
0=@0oooo00<000000?ooo`3oool0aP3oool00`000?l0oooo0?ooo`1^0?oo
o`030000003oool0oooo06h0oooo00<0003o0?ooo`3oool0<@3oool00=@0
oooo00<000000?ooo`3oool0aP3oool00`000?l0oooo0?ooo`1^0?ooo`03
0000003oool0oooo06h0oooo00<0003o0?ooo`3oool0<@3oool00=@0oooo
00<000000?ooo`3oool0aP3oool00`000?l0oooo0?ooo`1^0?ooo`030000
003oool0oooo06h0oooo00<0003o0?ooo`3oool0<@3oool00=@0oooo00<0
00000?ooo`3oool0aP3oool00`000?l0oooo0?ooo`1^0?ooo`030000003o
ool0oooo06h0oooo00<0003o0?ooo`3oool0<@3oool00=@0oooo00<00000
0?ooo`3oool0aP3oool00`000?l0oooo0?ooo`1^0?ooo`030000003oool0
oooo06h0oooo00<0003o0?ooo`3oool0<@3oool00=@0oooo00<000000?oo
o`3oool0a`3oool00`000?l0oooo0?ooo`1]0?ooo`030000003oool0oooo
06d0oooo00<0003o0?ooo`3oool0<P3oool00=@0oooo00<000000?ooo`3o
ool0a`3oool00`000?l0oooo0?ooo`1]0?ooo`030000003oool0oooo06d0
oooo00<0003o0?ooo`3oool0<P3oool00=@0oooo00<000000?ooo`3oool0
a`3oool00`000?l0oooo0?ooo`1]0?ooo`030000003oool0oooo06`0oooo
00<0003o0?ooo`3oool0<`3oool00=@0oooo00<000000?ooo`3oool0b03o
ool00`000?l0oooo0?ooo`1/0?ooo`030000003oool0oooo06`0oooo00<0
003o0?ooo`3oool0<`3oool00=@0oooo00<000000?ooo`3oool0b03oool0
0`000?l0oooo0?ooo`1B0?ooo`<000005`3oool00`000000oooo0?ooo`0a
0?ooo`<00000>03oool00`000?l0oooo0?ooo`0c0?ooo`00e03oool00`00
0000oooo0?ooo`380?ooo`030000o`3oool0oooo0580oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
03L0oooo00<0003o0?ooo`3oool0<`3oool00=@0oooo00<000000?ooo`3o
ool0b03oool00`000?l0oooo0?ooo`1:0?ooo`D00000103oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo02P0oooo1@0000030?ooo`@0
0000>03oool00`000?l0oooo0?ooo`0c0?ooo`00e03oool00`000000oooo
0?ooo`380?ooo`030000o`3oool0oooo04/0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02T0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000000i0?oo
o`030000o`3oool0oooo03<0oooo003D0?ooo`030000003oool0oooo0<T0
oooo00<0003o0?ooo`3oool0@`3oool30?l000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0000000G0?ooo`030000003oool0oooo0280
oooo0`3o00050?ooo`030000003oool0oooo00@0oooo0P00000h0?ooo`03
0000o`3oool0oooo03@0oooo003D0?ooo`030000003oool0oooo0<T0oooo
00<0003o0?ooo`3oool0@P3oool50?l000D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0>0?ooo`D000000`3oool00`000000oooo
0?ooo`0Q0?ooo`D0o`001@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo03H0oooo00<0003o0?ooo`3oool0=03oool00=@0oooo00<0
00000?ooo`3oool0b@3oool00`000?l0oooo0?ooo`110?ooo`L0o`000P3o
ool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0803oool70?l00080oooo00@000000?ooo`3oool0
0000?@3oool00`000?l0oooo0?ooo`0e0?ooo`00e03oool00`000000oooo
0?ooo`3:0?ooo`030000o`3oool0oooo0400oooo1`3o00020?ooo`D00000
5P3oool00`000000oooo0?ooo`030?ooo`<00000803oool70?l00080oooo
1@00000l0?ooo`030000o`3oool0oooo03D0oooo003D0?ooo`030000003o
ool0oooo0<X0oooo00<0003o0?ooo`3oool0@03oool70?l001d0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0P0?ooo`L0o`00@`3o
ool00`000?l0oooo0?ooo`0e0?ooo`00e03oool00`000000oooo0?ooo`3;
0?ooo`030000o`3oool0oooo0400oooo1@3o000N0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool08@3oool50?l004<0oooo00<0003o
0?ooo`3oool0=P3oool00600oooo1000000f0?ooo`D00000=@3oool00`00
0000oooo0?ooo`0e0?ooo`D00000=P3oool4000005L0oooo00<0003o0?oo
o`3oool0@@3oool30?l001h0oooo0P0000050?ooo`030000003oool0oooo
0280oooo0`3o00140?ooo`030000o`3oool0oooo03H0oooo001P0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0F03oool00`000?l0oooo0?ooo`1Y0?ooo`030000003oool0oooo06T0
oooo00<0003o0?ooo`3oool0=P3oool00640oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1H0?ooo`030000
o`3oool0oooo06P0oooo00<000000?ooo`3oool0J03oool00`000?l0oooo
0?ooo`0g0?ooo`00FP3oool4000000@0oooo00<000000?ooo`3oool0;`3o
ool4000000@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0E`3o
ool00`000?l0oooo0?ooo`1X0?ooo`030000003oool0oooo06P0oooo00<0
003o0?ooo`3oool0=`3oool00600oooo00@000000?ooo`3oool00000>03o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0=P3oool010000000oooo0?ooo`00001H0?ooo`030000
o`3oool0oooo06P0oooo00<000000?ooo`3oool0I`3oool00`000?l0oooo
0?ooo`0h0?ooo`00H@3oool2000003P0oooo0P00000g0?ooo`030000003o
ool0oooo03H0oooo0P00000i0?ooo`800000FP3oool00`000?l0oooo0?oo
o`1W0?ooo`030000003oool0oooo06L0oooo00<0003o0?ooo`3oool0>03o
ool00=@0oooo00<000000?ooo`3oool0cP3oool00`000?l0oooo0?ooo`1V
0?ooo`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool0>@3oool0
0=@0oooo00<000000?ooo`3oool0cP3oool00`000?l0oooo0?ooo`1V0?oo
o`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool0>@3oool00=@0
oooo00<000000?ooo`3oool0c`3oool00`000?l0oooo0?ooo`1U0?ooo`03
0000003oool0oooo06D0oooo00<0003o0?ooo`3oool0>P3oool00=@0oooo
00<000000?ooo`3oool0QP3oool2000000030?ooo`000000000004@0oooo
00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`1T0?ooo`030000
o`3oool0oooo03/0oooo003D0?ooo`030000003oool0oooo08L0oooo00<0
00000?ooo`000000AP3oool00`000?l0oooo0?ooo`1T0?ooo`030000003o
ool0oooo06@0oooo00<0003o0?ooo`3oool0>`3oool005<0ooooo`000004
000000T0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`1T
0?ooo`030000003oool0oooo06@0oooo00<0003o0?ooo`3oool0>`3oool0
05l0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0A0?ooo`80000000<0oooo000000000000AP3oool00`00
0?l0oooo0?ooo`1S0?ooo`030000003oool0oooo06<0oooo00<0003o0?oo
o`3oool0?03oool005l0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`1L0?ooo`030000o`3oool0oooo06<0
oooo00<000000?ooo`3oool0H`3oool00`000?l0oooo0?ooo`0l0?ooo`00
e03oool00`000000oooo0?ooo`3A0?ooo`030000o`3oool0oooo06<0oooo
00<000000?ooo`3oool0HP3oool00`000?l0oooo0?ooo`0m0?ooo`00e03o
ool00`000000oooo0?ooo`3B0?ooo`030000o`3oool0oooo0680oooo00<0
00000?ooo`3oool0HP3oool00`000?l0oooo0?ooo`0m0?ooo`00e03oool0
0`000000oooo0?ooo`3C0?ooo`030000o`3oool0oooo0640oooo00<00000
0?ooo`3oool0H@3oool00`000?l0oooo0?ooo`0n0?ooo`00e03oool00`00
0000oooo0?ooo`3C0?ooo`030000o`3oool0oooo0640oooo00<000000?oo
o`3oool0H@3oool00`000?l0oooo0?ooo`0n0?ooo`00e03oool00`000000
oooo0?ooo`3D0?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3o
ool0H03oool00`000?l0oooo0?ooo`0o0?ooo`00e03oool00`000000oooo
0?ooo`3D0?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0
G`3oool00`000?l0oooo0?ooo`100?ooo`00e03oool00`000000oooo0?oo
o`3E0?ooo`030000o`3oool0oooo05l0oooo00<000000?ooo`3oool0G`3o
ool00`000?l0oooo0?ooo`100?ooo`00e03oool00`000000oooo0?ooo`3F
0?ooo`030000o`3oool0oooo05h0oooo00<000000?ooo`3oool0GP3oool0
0`000?l0oooo0?ooo`110?ooo`00e03oool00`000000oooo0?ooo`3F0?oo
o`030000o`3oool0oooo05h0oooo00<000000?ooo`3oool0GP3oool00`00
0?l0oooo0?ooo`110?ooo`00e03oool00`000000oooo0?ooo`3G0?ooo`03
0000o`3oool0oooo05d0oooo00<000000?ooo`3oool0G@3oool00`000?l0
oooo0?ooo`120?ooo`00e03oool00`000000oooo0?ooo`3H0?ooo`030000
o`3oool0oooo05`0oooo00<000000?ooo`3oool0G03oool00`000?l0oooo
0?ooo`130?ooo`00e03oool00`000000oooo0?ooo`3I0?ooo`030000o`3o
ool0oooo05/0oooo00<000000?ooo`3oool0F`3oool00`000?l0oooo0?oo
o`140?ooo`00e03oool00`000000oooo0?ooo`3I0?ooo`030000o`3oool0
oooo05/0oooo00<000000?ooo`3oool0FP3oool00`000?l0oooo0?ooo`15
0?ooo`00e03oool00`000000oooo0?ooo`3J0?ooo`030000o`3oool0oooo
05X0oooo00<000000?ooo`3oool0FP3oool00`000?l0oooo0?ooo`150?oo
o`00e03oool00`000000oooo0?ooo`3K0?ooo`030000o`3oool0oooo05T0
oooo00<000000?ooo`3oool0F@3oool00`000?l0oooo0?ooo`160?ooo`00
e03oool00`000000oooo0?ooo`3K0?ooo`030000o`3oool0oooo05T0oooo
00<000000?ooo`3oool0F@3oool00`000?l0oooo0?ooo`160?ooo`00e03o
ool00`000000oooo0?ooo`3L0?ooo`030000o`3oool0oooo05P0oooo00<0
00000?ooo`3oool0F03oool00`000?l0oooo0?ooo`170?ooo`00e03oool0
0`000000oooo0?ooo`3M0?ooo`030000o`3oool0oooo05L0oooo00<00000
0?ooo`3oool0E`3oool00`000?l0oooo0?ooo`180?ooo`00e03oool00`00
0000oooo0?ooo`3N0?ooo`030000o`3oool0oooo05H0oooo00<000000?oo
o`3oool0EP3oool00`000?l0oooo0?ooo`190?ooo`00e03oool00`000000
oooo0?ooo`3O0?ooo`030000o`3oool0oooo05D0oooo00<000000?ooo`3o
ool0E@3oool00`000?l0oooo0?ooo`1:0?ooo`00e03oool00`000000oooo
0?ooo`3P0?ooo`030000o`3oool0oooo04`0oooo100000040?ooo`030000
003oool0oooo05D0oooo00<0003o0?ooo`3oool0BP3oool00=@0oooo00<0
00000?ooo`3oool0h03oool00`000?l0oooo0?ooo`1<0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0E03oool00`000?l0oooo0?oo
o`1;0?ooo`00e03oool00`000000oooo0?ooo`3Q0?ooo`030000o`3oool0
oooo04`0oooo00<000000?ooo`3oool0103oool3000005<0oooo00<0003o
0?ooo`3oool0C03oool00=@0oooo00<000000?ooo`3oool0hP3oool00`00
0?l0oooo0?ooo`1<0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0DP3oool00`000?l0oooo0?ooo`1=0?ooo`00e03oool00`000000
oooo0?ooo`3S0?ooo`030000o`3oool0oooo04T0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1A0?ooo`030000o`3oool0oooo
04h0oooo003D0?ooo`030000003oool0oooo0>@0oooo00<0003o0?ooo`3o
ool0B@3oool2000000D0oooo00<000000?ooo`3oool0D03oool00`000?l0
oooo0?ooo`1?0?ooo`00e03oool00`000000oooo0?ooo`3U0?ooo`030000
o`3oool0oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000?l0oooo
0?ooo`1@0?ooo`00e03oool00`000000oooo0?ooo`3V0?ooo`030000o`3o
ool0oooo04h0oooo00<000000?ooo`3oool0CP3oool00`000?l0oooo0?oo
o`1A0?ooo`00e03oool00`000000oooo0?ooo`3W0?ooo`030000o`3oool0
oooo04d0oooo00<000000?ooo`3oool0C@3oool00`000?l0oooo0?ooo`1B
0?ooo`00e03oool00`000000oooo0?ooo`3X0?ooo`030000o`3oool0oooo
04`0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`1C0?oo
o`00e03oool00`000000oooo0?ooo`3Y0?ooo`030000o`3oool0oooo04/0
oooo00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`1D0?ooo`00
e03oool00`000000oooo0?ooo`3Z0?ooo`80003oB`3oool00`000000oooo
0?ooo`190?ooo`80003oE`3oool00=@0oooo00<000000?ooo`3oool0k03o
ool00`000?l0oooo0?ooo`180?ooo`030000003oool0oooo04P0oooo00<0
003o0?ooo`3oool0E`3oool00=@0oooo00<000000?ooo`3oool0k@3oool0
0`000?l0oooo0?ooo`170?ooo`030000003oool0oooo04L0oooo00<0003o
0?ooo`3oool0F03oool00=@0oooo00<000000?ooo`3oool0kP3oool00`00
0?l0oooo0?ooo`160?ooo`030000003oool0oooo04H0oooo00<0003o0?oo
o`3oool0F@3oool00=@0oooo00<000000?ooo`3oool0k`3oool00`000?l0
oooo0?ooo`150?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3o
ool0FP3oool00=@0oooo00<000000?ooo`3oool0l03oool00`000?l0oooo
0?ooo`140?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool0
F`3oool00=@0oooo00<000000?ooo`3oool0l@3oool20000od@0oooo00<0
00000?ooo`3oool0@P3oool20000oeh0oooo003D0?ooo`030000003oool0
oooo0?<0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`11
0?ooo`030000o`3oool0oooo05h0oooo003D0?ooo`030000003oool0oooo
0?@0oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`100?oo
o`030000o`3oool0oooo05l0oooo003D0?ooo`030000003oool0oooo0?D0
oooo0P000?m00?ooo`030000003oool0oooo03h0oooo0P000?mR0?ooo`00
e03oool00`000000oooo0?ooo`3g0?ooo`030000o`3oool0oooo03d0oooo
00<000000?ooo`3oool0?@3oool00`000?l0oooo0?ooo`1R0?ooo`00YP3o
ool3000002/0oooo00<000000?ooo`3oool0AP3oool300000:l0oooo0P00
0?lm0?ooo`030000003oool0oooo03/0oooo0P000?mU0?ooo`00YP3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool0/03oool20000oc/0oooo00<000000?ooo`3oool0>@3oool2
0000ofL0oooo002O0?ooo`D000000`3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo03d0oooo1@0000030?ooo`@00000/`3oool00`00
0?l0oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo00<0003o0?oo
o`3oool0I`3oool00:00oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo03h0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0000002e0?ooo`<0003o=`3oool0
0`000000oooo0?ooo`0e0?ooo`<0003oJP3oool00:40oooo00<000000?oo
o`3oool00P3oool00`000000oooo0000000[0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0103oool200000;P0oooo0P000?le0?oo
o`030000003oool0oooo03<0oooo0P000?m]0?ooo`00XP3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0;P0
oooo00<0003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?ooo`03
0000o`3oool0oooo06d0oooo002H0?ooo`<0o`001@3oool010000000oooo
0?ooo`00000`0?ooo`030000003oool0oooo03H0oooo0`3o00050?ooo`04
0000003oool0oooo00000<40oooo0P000?lb0?ooo`030000003oool0oooo
0300oooo0P000?m`0?ooo`00U`3oool50?l000@0oooo1@00000W0?ooo`D0
00000`3oool00`000000oooo0?ooo`0e0?ooo`D0o`00103oool500000<80
oooo0P000?l`0?ooo`030000003oool0oooo02h0oooo0P000?mb0?ooo`00
UP3oool70?l00340oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0d0?ooo`L0o`00c03oool30000obd0oooo00<000000?ooo`3oool0
:`3oool30000og@0oooo002F0?ooo`L0o`00<@3oool00`000000oooo0?oo
o`030?ooo`800000=@3oool70?l00<l0oooo0P000?l[0?ooo`030000003o
ool0oooo02T0oooo0P000?mg0?ooo`00UP3oool70?l00340oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`L0o`00d@3oool3
0000obP0oooo00<000000?ooo`3oool09P3oool30000ogT0oooo002G0?oo
o`D0o`00<P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
03D0oooo1@3o003E0?ooo`<0003o9@3oool00`000000oooo0?ooo`0S0?oo
o`<0003oO03oool009P0oooo0`3o000b0?ooo`8000001@3oool00`000000
oooo0?ooo`0f0?ooo`<0o`00f@3oool20000ob<0oooo00<000000?ooo`3o
ool08@3oool20000ogl0oooo003D0?ooo`030000003oool0oooo0?l0oooo
5@3oool30000ob00oooo00<000000?ooo`3oool07P3oool30000oh40oooo
003D0?ooo`030000003oool0oooo0?l0oooo603oool30000oad0oooo00<0
00000?ooo`3oool06`3oool30000oh@0oooo003D0?ooo`030000003oool0
oooo0?l0oooo6`3oool50000oaP0oooo00<000000?ooo`3oool05P3oool5
0000ohL0oooo003D0?ooo`030000003oool0oooo0?l0oooo803oool60000
oa80oooo00<000000?ooo`3oool0403oool60000oh`0oooo003D0?ooo`03
0000003oool0oooo0?l0oooo9P3oool90000o`T0oooo00<000000?ooo`3o
ool0203oool80000oi80oooo003D0?ooo`030000003oool0oooo0?l0oooo
;`3ooolD0000oiX0oooo003D0?ooo`030000003oool0oooo0?l0oooo>03o
ool00`000000oooo0?ooo`2R0?ooo`00o`3ooooo0?oooa00oooo00<00000
0?ooo`3oool0XP3oool00?l0ooooo`3ooone0?ooo`00o`3ooooo0?oookD0
oooo003o0?ooool0oooo]@3oool00?l0ooooo`3ooone0?ooo`00o`3ooooo
0?oookD0oooo003o0?ooool0oooo]@3oool00?l0ooooo`3ooone0?ooo`00
o`3ooooo0?oookD0oooo003B0?ooo`800000o`3oooli0?ooo`800000Y@3o
ool00=<0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0
oooo0:<0oooo003D0?ooo`030000003oool0oooo0?l0oooo>03oool00`00
0000oooo0?ooo`2R0?ooo`00d`3oool00`000000oooo0000003o0?ooocP0
oooo00<000000?ooo`000000X`3oool00=80oooo00@000000?ooo`3oool0
0000o`3ooolg0?ooo`040000003oool0oooo00000:<0oooo003A0?ooo`<0
000000<0oooo000000000000o`3ooole0?ooo`<0000000<0oooo00000000
0000XP3oool00?l0ooooo`3ooone0?ooo`00o`3ooooo0?oookD0oooo003o
0?ooool0oooo]@3oool00?l0ooooo`3ooone0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{691, 154},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The function ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " in Equation ",
  StyleBox["(8-12)",
    FontColor->RGBColor[0, 0, 1]],
  " is  ",
  Cell[BoxData[
      \(f \((z)\) = \(\[ExponentialE]\^\(\[ImaginaryI]\ z\)\/\(z\^4 + 4\)\  = \
\ \ \[ExponentialE]\^\(\[ImaginaryI]\ z\)\/\(\((z + 1 + \[ImaginaryI])\) \((z \
+ 1 - \[ImaginaryI])\) \((z - 1 + \[ImaginaryI])\) \((z - 1 - \
\[ImaginaryI])\)\)\)\)]],
  ",  which has simple poles at the points  ",
  Cell[BoxData[
      \(z\_2 = \(-1\) + \[ImaginaryI]\)]],
  "  and  ",
  Cell[BoxData[
      \(z\_4 = 1 + \[ImaginaryI]\)]],
  "  in the upper half-plane.  We get the residues with the aid of \
L'H\[OHat]pital's rule:  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, 
          1 + \[ImaginaryI]]\ \  = \ \ lim\+\(z\  \[Rule] 1 + \[ImaginaryI]\)\
\ \((z - 1 - \[ImaginaryI])\) f \((z)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\
\ \ \)\(lim\+\(z\  \[Rule] 1 + \[ImaginaryI]\)\ \(\((z - 1 - \[ImaginaryI])\) \
\[ExponentialE]\^\(\[ImaginaryI]\ z\)\)\/\(\((z + 1 + \[ImaginaryI])\) \((z + \
1 - \[ImaginaryI])\) \((z - 1 + \[ImaginaryI])\) \((z - 1 - \
\[ImaginaryI])\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\
\ \ \)\(lim\+\(z\  \[Rule] 1 + \[ImaginaryI]\)\ \(\((z - 1 - \[ImaginaryI])\) \
\[ExponentialE]\^\(\[ImaginaryI]\ z\)\)\/\(z\^4 + 4\)\ \  = \ \ \(\('\) \(\(0\
\/0\)'\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\
\ \ \)\(lim\+\(z\  \[Rule] 1 + \[ImaginaryI]\)\ \(\((1)\) \[ExponentialE]\^\(\
\[ImaginaryI]\ z\)\  + \ \((z - 1 - \[ImaginaryI])\) \[ImaginaryI]\ \
\[ExponentialE]\^\(\[ImaginaryI]\ z\)\)\/\(4  z\^3\)\)\)\(\[IndentingNewLine]\
\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\
\ \ \)\(lim\+\(z\  \[Rule] 1 + \[ImaginaryI]\)\ \(\((1 + \[ImaginaryI] \((z - \
1 - \[ImaginaryI])\))\)\ \[ExponentialE]\^\(\[ImaginaryI]\ z\)\)\/\(4\ z\^3\)\
\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\
\ \ \)\(\(\((1 + \[ImaginaryI] \((1 + \[ImaginaryI] - 1 - \[ImaginaryI])\))\)\
\ \[ExponentialE]\^\(\[ImaginaryI]\ \((1 + \[ImaginaryI])\)\)\)\/\(4\ \((1 + \
\[ImaginaryI])\)\^3\)\ \  = \ \ \(\((1)\)\ \[ExponentialE]\^\(\(-1\) + \
\[ImaginaryI]\)\)\/\(4\ \((1 + \[ImaginaryI])\)\^3\)\)\)\(\[IndentingNewLine]\
\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\
\ \ \)\(\[ExponentialE]\^\(\(-1\) + \[ImaginaryI]\)\/\(\(-8\) + 8\ \
\[ImaginaryI]\)\ \  = \ \ \(\((\(-1\) - \[ImaginaryI])\) \
\[ExponentialE]\^\(\(-1\) + \[ImaginaryI]\)\)\/16\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\
\ \ \)\(\(\((\(-1\) - \[ImaginaryI])\) \[ExponentialE]\^\(\(-1\) + \
\[ImaginaryI]\)\)\/16 = \ \ \(\((\(-1\) - \[ImaginaryI])\) \
\(\[ExponentialE]\^\(-1\)\) \((cos\ 1 + \[ImaginaryI]\ sin\ 1)\)\)\/16\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \
\ \)\(\(sin\ 1\  - 
              cos\ 1\ \  - \ \[ImaginaryI]\ \((cos\ 1\  + 
                    sin\ 1\ )\)\)\/\(16  \[ExponentialE]\)\)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "Similarly,\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[
          f, \(-1\) + \[ImaginaryI]]\ \  = \ \ lim\+\(z\  \[Rule] \(-1\) + \
\[ImaginaryI]\)\ \((z + 1 - \[ImaginaryI])\) 
            f \((z)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\
\ \ \)\(lim\+\(z\  \[Rule] \(-1\) + \[ImaginaryI]\)\ \(\((z - 1 - \
\[ImaginaryI])\) \[ExponentialE]\^\(\[ImaginaryI]\ z\)\)\/\(\((z + 1 + \
\[ImaginaryI])\) \((z + 1 - \[ImaginaryI])\) \((z - 1 + \[ImaginaryI])\) \((z \
- 1 - \[ImaginaryI])\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \
\ \)\(\(cos\ 1\  - \ 
              sin\ 1\  - \ \[ImaginaryI]\ \((cos\ 1\  + 
                    sin\ 1\ )\)\)\/\(16  \[ExponentialE]\)\)\)\)}]]
}], "Text"],

Cell[TextData[{
  "Using Equation ",
  StyleBox["(8-13)",
    FontColor->RGBColor[0, 0, 1]],
  ", we get  \n\n\t\t\t",
  Cell[BoxData[{
      \(P . 
            V . \ "\<\>" \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                    cos\ x\)\/\(x\^4 + 
                    4\)\) \[DifferentialD]x "\<\>"\)\ \  = \ \ \(-2\) \[Pi]\ \
\((Im \((Res[f, z\_1])\)\  + \ Im \((Res[f, z\_2])\))\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \(\(=\)\(\ \ \)\(\(-2\) \[Pi]\ \((Im \((Res[f, 1 + \[ImaginaryI]])\)\  + \ 
              Im \((Res[
                    f, \(-1\) + \[ImaginaryI]])\))\)\)\)\[IndentingNewLine]\),
     "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \(\(=\)\(\ \ \)\(\(-2\) \[Pi]\ \((Im \((\(sin\ 1\  - cos\ 1\ \  - \ \
\[ImaginaryI]\ \((cos\ 1\  + sin\ 1\ )\)\)\/\(16  \[ExponentialE]\))\)\  + \ 
              Im \((\(cos\ 1\  - \ sin\ 1\  - \ \[ImaginaryI]\ \((cos\ 1\  + \
sin\ 1\ )\)\)\/\(16  \[ExponentialE]\))\))\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \(\(=\)\(\ \ \)\(\(-2\) \[Pi]\ \((\(-\ \ \((cos\ 1\  + sin\ 1\ )\)\)\/\(16  \
\[ExponentialE]\)\  + \ \(\(\ \)\(-\ \ \((cos\ 1\  + sin\ 1\ )\)\)\)\/\(16  \
\[ExponentialE]\))\)\ \  = \ \ \(-2\) \[Pi]\ \((\(-\ \ \((cos\ 1\  + sin\ 1\ \
)\)\)\/\(8  \[ExponentialE]\))\)\)\)\ \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \(\(=\)\(\ \ \)\(\(\[Pi]\ \((cos\ 1\  + 
                  sin\ 1\ )\)\)\/\(4  \[ExponentialE]\)\)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.18.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the functions  ",
  Cell[BoxData[
      \(F[x] = Cos[x]\/\(x\^4 + 4\)\)],
    AspectRatioFixed->False],
  "  and  ",
  Cell[BoxData[
      \(f[z] = \[ExponentialE]\^\(\[ImaginaryI]\ z\)\/\(z\^4\  + \ 4\)\)],
    AspectRatioFixed->True],
  "  and ",
  "locate the",
  " singularities of  f[z]."
}], "Text"],

Cell[BoxData[{
    \(Z = \(z = \(x = 0\)\); \ Remove[x, z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, g, Res1, Res2, Res3, Res4, solset, 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\(F[x_] = Cos[x]\/\(x\^4\  + \ 4\);\)\ \), "\n", 
    \(\(f[
          z_]\  = \ \[ExponentialE]\^\(\[ImaginaryI]\ z\)\/\(z\^4\  + \ \
4\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[x] = \>", F[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[Denominator[f[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, 
            z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The singularities are\>"];\)\ \), "\n", 
    \(\(Z\_1\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2];\)\ \), "\n", 
    \(\(Z\_3\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3];\)\ \), "\n", 
    \(\(Z\_4\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(4\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", 
        Z\_4];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell["Which poles lie in the upper half plane?", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_2], Im[Z\_2]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_3], Im[Z\_3]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_4], Im[Z\_4]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] - 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] - 0.1}, {\(-1\), 
                0}], Text[\*"\"\<\!\(z\_3\)\>\"", {Re[Z\_3], 
                Im[Z\_3] - 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_4\)\>\"", {Re[Z\_4], Im[Z\_4] - 0.1}, {\(-1\), 
                0}]}];\)\ \), "\n", 
    \(\(Show[dots, centers, 
        PlotRange \[Rule] {{\(-2.2\), 2.2}, {\(-2.2\), 2.2}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<,  Is  Im(\>", 
        Z\_1, "\<) > 0 ?   \>", N[Im[Z\_1]] > 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<,  Is  Im(\>", 
        Z\_2, "\<) > 0 ?   \>", 
        N[Im[Z\_2]] > 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3, "\<,   Is  Im(\>", 
        Z\_3, "\<) > 0 ?    \>", N[Im[Z\_3]] > 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", Z\_4, "\<,   Is  Im(\>", 
        Z\_4, "\<) > 0 ?    \>", 
        N[Im[Z\_4]] > 0];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Compute the residues at  ",
  Cell[BoxData[
      \(z\_2 = \(\(-1\) + \[ImaginaryI]\ \ and\ \ z\_4 = 
          1 + \[ImaginaryI]\)\)]],
  ",  and use the residue calculus to compute the value of the integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Res2\  = \ Residue[f[z], {z, Z\_2}];\)\ \), "\n", 
    \(\(Res4\  = \ Residue[f[z], {z, Z\_4}];\)\ \), "\[IndentingNewLine]", 
    \(\(val\  = \ 
        Together[\(-\ 2\)\ \[Pi]\ \((\ 
              Im[Res2]\  + \ Im[Res4]\ )\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", Z\_2, "\<] = \>", Res2];\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_4, "\<] = \>", 
        Res4];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Im[Res[f,\>", Z\_2, "\<]] = \>", Im[Res2]];\)\ \), "\n", 
    \(\(Print["\<Im[Res[f,\>", Z\_4, "\<]] = \>", 
        Im[Res4]];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_2], Im[Z\_2]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_4], Im[Z\_4]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], 
                Im[Z\_2]}, {\(-1.2\), 0}], 
            Text[\*"\"\<\!\(z\_4\)\>\"", {Re[Z\_4], Im[Z\_4]}, {\(-1.2\), 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ 
        Graphics[{Blue, 
            Circle[{0, 0}, 3, {0, \[Pi]}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(segment = 
        Graphics[{Thickness[0.015], Cyan, 
            Line[{{\(-3\), 0}, {3, 0}}]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, segment, 
        PlotRange \[Rule] {{\(-3.1\), 3.1}, {\(-0.05\), 3.05}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 2, 1]}, 
        AspectRatio \[Rule] 1\/2, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = - 2\[Pi](Im[\>", 
        Res2\ , "\<] + Im[\>", \ 
        Res4\ , "\<])\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = - 2\[Pi](\>", 
        Im[Res2]\ , "\< + (\>", \ 
        Im[Res4]\ , "\<))\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = - 2\[Pi](\>", 
        Im[Res2]\ \  + \ \ Im[
            Res4]\ , "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The contour is the semicircle \!\(C\_R\) and interval \
[-R,R],\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<taken with the positive orientation.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value \
of the integral.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"\
", f[x], "\< \[DifferentialD]x \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= - 2\[Pi](Im[\>", Res2\ , "\<] + Im[\>", \ 
        Res4\ , "\<])\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", val, "\< = \>", 
        N[val]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The integral of  F[x] for this problem is  g[x],  but it cannot be used \
in any meaningful way to solve the problem at hand."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(g[x_]\  = \[Integral]F[x] \[DifferentialD]x;\)\ \), "\n", 
    \(\(Print["\<F[x] = \>", F[x]];\)\ \), "\n", 
    \(\(Print["\<g[x] = \[Integral] \>", F[x], "\< \[DifferentialD]x = \>", 
        g[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<      g[\[Infinity]] = \>", g[\[Infinity]]];\)\ \), "\n", 
    \(\(Print["\<     g[-\[Infinity]] = \>", 
        g[\(-\[Infinity]\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<g[\[Infinity]]-g[-\[Infinity]] = \>", 
        Simplify[g[\[Infinity]] - g[\(-\[Infinity]\)]]];\)\ \), "\n", 
    \(\(Print["\<g[\[Infinity]]-g[-\[Infinity]] = \>", 
        N[g[\[Infinity]] - 
            g[\(-\[Infinity]\)]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "This looks good, however it ",
  StyleBox["cannot",
    FontColor->RGBColor[1, 0, 1]],
  " be used to solve for the definite integral. This does ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " agree with the answer obtained with the residue calculus."
}], "Text"],

Cell[BoxData[
    \(\(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        F[x], "\< \[DifferentialD]x = \>", val, "\< = \>", 
        N[val]];\)\(\ \)\(\[IndentingNewLine]\)
    \)\)], "Input",
  AspectRatioFixed->False],

Cell["\<\
However, the definite integral will produce the following result.\
\>", "Text"],

Cell[BoxData[{
    \(\(val\  = \[Integral]\_\(-\[Infinity]\)\%\[Infinity] F[
              x] \[DifferentialD]x\ ;\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        F[x], "\< \[DifferentialD]x = \>", val, "\< = \>", 
        N[val]];\)\ \), "\n", 
    \(\)}], "Input"],

Cell["Which is also the correct answer.", "Text"],

Cell["The PrincipalValue option can also be used.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(int = 
        Integrate[F[x], {x, \(-\[Infinity]\), \[Infinity]}, 
          PrincipalValue \[Rule] True];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        F[x], "\< \[DifferentialD]x = \>", 
        int];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tWe are almost ready to give the proof of Theorem 8.4, but first we need \
one preliminary result known as ",
  StyleBox[ButtonBox["Jordan's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Jordan.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " lemma.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Lemma 8.1, (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Jordan's Lemma",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/JordansLemma.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose that ",
  StyleBox["P(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Q(z)",
    FontFamily->"Courier New"],
  " are polynomials of degree ",
  StyleBox["m",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ", respectively, where  ",
  Cell[BoxData[
      \(n \[GreaterEqual] m + 1\)]],
  ".  If  ",
  Cell[BoxData[
      \(C\_R\)]],
  "  is the upper semicircle ",
  Cell[BoxData[
      \(z = 
        R\ \[ExponentialE]\^\[ImaginaryI]\[Theta]\ \ for\ \ 0\  \[LessEqual] \
\ \[Theta]\  \[LessEqual] \ 2  \[Pi]\)]],
  ",  then\n\n\t\t\t",
  Cell[BoxData[
      \(\(\(\(lim\)\(\ \)\)\+\(R\  \[Rule] \ \[Infinity]\)\) \
\(\[Integral]\_\(C\_R\)\ \(\[ExponentialE]\^\[ImaginaryI]z\ P \((z)\)\)\/\(Q \
\((z)\)\)\ \[DifferentialD]z\)\ \  = \ \ 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Proof of Lemma 8.1",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[" is in the book.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Residue Calculus",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ResidueCalcBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Contour Integrals",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ContourIntegralBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Cauchy Principal Value",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/CauchyPrincipalValuelBib.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Hilbert Transformation",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/HilbertTransBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{988, 627},
WindowMargins->{{13, Automatic}, {Automatic, 0}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[9997, 324, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[77861, 1718, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 80996, 1821}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 149, 3, 33, "Text"],
Cell[2254, 67, 1758, 56, 117, "Text"],
Cell[4015, 125, 792, 23, 128, "Text"],
Cell[4810, 150, 3262, 106, 247, "Text",
  Evaluatable->False],
Cell[8075, 258, 1488, 45, 38, "Text"],

Cell[CellGroupData[{
Cell[9588, 307, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[9736, 313, 258, 9, 33, "Text",
  Evaluatable->False],
Cell[9997, 324, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[10357, 336, 161, 3, 30, "Text"],
Cell[10521, 341, 347, 12, 37, "Text",
  Evaluatable->False],
Cell[10871, 355, 17563, 291, 168, 17449, 287, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[28437, 648, 1906, 43, 264, "Text"],
Cell[30346, 693, 1058, 23, 199, "Text"],

Cell[CellGroupData[{
Cell[31429, 720, 196, 7, 33, "Text"],
Cell[31628, 729, 361, 14, 39, "Text"],
Cell[31992, 745, 1404, 31, 402, "Input"],
Cell[33399, 778, 105, 2, 33, "Text",
  Evaluatable->False],
Cell[33507, 782, 1154, 22, 170, "Input"],
Cell[34664, 806, 232, 7, 33, "Text",
  Evaluatable->False],
Cell[34899, 815, 2137, 40, 463, "Input"],
Cell[37039, 857, 288, 8, 33, "Text",
  Evaluatable->False],
Cell[37330, 867, 826, 15, 223, "Input"],
Cell[38159, 884, 294, 8, 33, "Text"],
Cell[38456, 894, 247, 5, 62, "Input"],
Cell[38706, 901, 89, 2, 33, "Text"],
Cell[38798, 905, 317, 6, 95, "Input"],
Cell[39118, 913, 49, 0, 33, "Text"],
Cell[39170, 915, 107, 2, 33, "Text",
  Evaluatable->False],
Cell[39280, 919, 331, 7, 83, "Input"]
}, Closed]],
Cell[39626, 929, 337, 12, 34, "Text",
  Evaluatable->False],
Cell[39966, 943, 18933, 313, 168, 18819, 309, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[58902, 1258, 3635, 71, 481, "Text"],
Cell[62540, 1331, 898, 18, 163, "Text"],
Cell[63441, 1351, 1764, 33, 243, "Text"],

Cell[CellGroupData[{
Cell[65230, 1388, 196, 7, 33, "Text"],
Cell[65429, 1397, 330, 12, 39, "Text"],
Cell[65762, 1411, 1908, 41, 482, "Input"],
Cell[67673, 1454, 105, 2, 33, "Text",
  Evaluatable->False],
Cell[67781, 1458, 1771, 32, 250, "Input"],
Cell[69555, 1492, 289, 8, 33, "Text",
  Evaluatable->False],
Cell[69847, 1502, 3276, 62, 675, "Input"],
Cell[73126, 1566, 288, 8, 33, "Text",
  Evaluatable->False],
Cell[73417, 1576, 826, 15, 223, "Input"],
Cell[74246, 1593, 294, 8, 33, "Text"],
Cell[74543, 1603, 247, 5, 62, "Input"],
Cell[74793, 1610, 89, 2, 33, "Text"],
Cell[74885, 1614, 317, 6, 95, "Input"],
Cell[75205, 1622, 49, 0, 33, "Text"],
Cell[75257, 1624, 107, 2, 33, "Text",
  Evaluatable->False],
Cell[75367, 1628, 331, 7, 83, "Input"]
}, Closed]],
Cell[75713, 1638, 430, 13, 30, "Text",
  Evaluatable->False],
Cell[76146, 1653, 1283, 44, 102, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[77454, 1701, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[77602, 1707, 256, 9, 33, "Text",
  Evaluatable->False],
Cell[77861, 1718, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[78221, 1730, 290, 7, 30, "Text"],
Cell[78514, 1739, 313, 10, 33, "Text"],
Cell[78830, 1751, 318, 10, 33, "Text"],
Cell[79151, 1763, 331, 11, 33, "Text"],
Cell[79485, 1776, 320, 10, 33, "Text"],
Cell[79808, 1788, 257, 5, 33, "Text"],
Cell[80068, 1795, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

