(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    143809,       3113]*)
(*NotebookOutlinePosition[    144944,       3153]*)
(*  CellTagsIndexPosition[    144867,       3147]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["8.5  Indented Contour Integrals",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tIf ",
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  " is continuous on the interval  ",
  Cell[BoxData[
      \(b < x \[LessEqual] c\)]],
  ", but discontinuous at ",
  StyleBox["b",
    FontFamily->"Courier New"],
  ", then the improper integral of ",
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  " over ",
  Cell[BoxData[
      \(\([b, c]\)\)]],
  " is defined by  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_b\%c\ 
          f \((x)\) \[DifferentialD]x\ \  = \ \ lim\+\(r\  \[Rule] \ \(b\^+\)\
\)\ \[Integral]\_r\%c\ f \((x)\) \[DifferentialD]x\)]],
  "\n\nprovided that the limit exists.  Similarly, if ",
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  " is continuous on the interval  ",
  Cell[BoxData[
      \(a \[LessEqual] x < b\)]],
  ", but discontinuous at ",
  StyleBox["b",
    FontFamily->"Courier New"],
  ", then the improper integral of ",
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  " over ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  " is defined by  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_a\%b\ f \((x)\) \[DifferentialD]x\  = \ 
        lim\+\(r\  \[Rule] \ \(b\^-\)\)\ \[Integral]\_a\%r\ 
            f \((x)\) \[DifferentialD]x\)]],
  "\n\nprovided that the limit exists.  For example,  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_0\%9\( 
                1\/\(2 \@ x\)\) \[DifferentialD]x\ \  = \ \ \(lim\+\(r\  \
\[Rule] \ \(0\^+\)\)\ \[Integral]\_r\%9\ \(1\/\(2 \@ x\)\) \[DifferentialD]x\ \
\  = \ \ \(\(\(lim\+\(r\  \[Rule] \ \(0\^+\)\)\@x\)\( \[VerticalSeparator] \+\
\(x = r\)\%\(x = 9\)\)\)\ \  = \ \ \(3\  - \ 
                lim\+\(r\  \[Rule] \ \(0\^+\)\)\@x\  = \ \ 3\)\)\)\)]],
  ". \n"
}], "Text"],

Cell[TextData[{
  "\tIf we let ",
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  " be continuous for all values of ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " in the interval ",
  Cell[BoxData[
      \(\([a, c]\)\)]],
  ",  except at the value ",
  Cell[BoxData[
      \(x = b\)]],
  ",  where ",
  Cell[BoxData[
      \(a < b < c\)]],
  ".  The Cauchy principal value of ",
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  " over ",
  Cell[BoxData[
      \(\([a, c]\)\)]],
  " is defined by\n\t\n\t\t\t",
  Cell[BoxData[
      \(P . 
          V . \(\[Integral]\_a\%c\ 
            f \((x)\) \[DifferentialD]x\)\ \  = \ \ lim\+\(r\  \[Rule] \ \
\(0\^+\)\)\ \((\ \[Integral]\_a\%\(b - r\)\ 
                f \((x)\) \[DifferentialD]x\ \  + \ \ \[Integral]\_\(b + \
r\)\%c\ f \((x)\) \[DifferentialD]x\ )\)\)]],
  ",  \n\t\nprovided that the limit exists. "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 8.19.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Evaluate  ",
  Cell[BoxData[
      \(P . 
        V . \ \(\[Integral]\_\(-1\)\%8\( 
                1\/x\^\(1/3\)\) \[DifferentialD]x\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006o0000Zb000`400?l0
0000o`00003oo`3oooo00?ooo`00o`3oooo00?ooo`00o`3oooo00?ooo`00
o`3oooo00?ooo`00o`3oooo00?ooo`00o`3oooo00?ooo`00VP3oool20?l0
00030?ooo`000000oooo0?l0oooo8@3oool009X0oooo0P3o00000`3oool0
00000?ooo`3o0?ooob40oooo002J0?ooo`<0o`0000<000000?ooo`3oool0
o`3ooolP0?ooo`00VP3oool20?l000030?ooo`000000oooo0?l0oooo8@3o
ool009X0oooo0P3o00000`3oool000000?ooo`3o0?ooob40oooo002J0?oo
o`80o`0000<0oooo0000003oool0o`3ooolQ0?ooo`00VP3oool20?l00003
0?ooo`000000oooo0?l0oooo8@3oool009X0oooo0P3o00000`3oool00000
0?ooo`3o0?ooob40oooo002I0?ooo`80o`000P3oool00`000000oooo0?oo
o`3o0?ooob00oooo002I0?ooo`80o`000P3oool00`000000oooo0?ooo`3o
0?ooob00oooo002I0?ooo`80o`000P3oool00`000000oooo0?ooo`3o0?oo
ob00oooo002I0?ooo`80o`000P3oool00`000000oooo0?ooo`3o0?ooob00
oooo002D0?ooo`@000000`3o00020?ooo`030000003oool0oooo0?l0oooo
803oool009@0oooo00@000000?ooo`3oool0oooo0P3o00030?ooo`030000
003oool0oooo0?l0oooo803oool009D0oooo00<000000?ooo`3oool00P3o
00030?ooo`<00000o`3ooolP0?ooo`00SP3oool4000000@0oooo00@00000
0?ooo`3o0000o`000`3oool00`000000oooo0?ooo`3o0?ooob00oooo002D
0?ooo`040000003oool0oooo00000080o`000`3oool00`000000oooo0?oo
o`3o0?ooob00oooo002E0?ooo`80000000<0oooo0?l0003o00000`3oool0
0`000000oooo0?ooo`3o0?ooob00oooo002H0?ooo`030?l0003oool0oooo
0080oooo00<000000?ooo`3oool0o`3ooolP0?ooo`00U`3oool20?l000@0
oooo00<000000?ooo`3oool0o`3ooolP0?ooo`00U`3oool00`3o0000oooo
0?ooo`030?ooo`030000003oool0oooo0?l0oooo803oool009H0oooo0P3o
00050?ooo`030000003oool0oooo0?l0oooo803oool009H0oooo0P3o0005
0?ooo`030000003oool0oooo0?l0oooo803oool009H0oooo0P3o00050?oo
o`030000003oool0oooo0?l0oooo803oool009D0oooo0`3o00050?ooo`03
0000003oool0oooo0?l0oooo803oool009D0oooo0P3o00000`3o`</0oooo
0?ooo`030?ooo`030000003oool0oooo0?l0oooo803oool009D0oooo0P3o
00000`3o`</0oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo803o
ool009@0oooo0P3o00020?o0b`D0oooo00<000000?ooo`3oool0o`3ooolP
0?ooo`00U03oool20?l00080ol3;1@3oool00`000000oooo0?ooo`3o0?oo
ob00oooo002C0?ooo`80o`000`3o`</50?ooo`030000003oool0oooo0?l0
oooo803oool00980oooo0`3o00030?o0b`D0oooo00<000000?ooo`3oool0
o`3ooolP0?ooo`00T@3oool30?l000@0ol3;1@3oool00`000000oooo0?oo
o`3o0?ooob00oooo002A0?ooo`80o`001@3o`</50?ooo`030000003oool0
oooo0?l0oooo803oool00900oooo0P3o00060?o0b`D0oooo00<000000?oo
o`3oool0o`3ooolP0?ooo`00S`3oool20?l000L0ol3;1@3oool00`000000
oooo0?ooo`3o0?ooob00oooo002=0?ooo`@0o`001`3o`</50?ooo`030000
003oool0oooo0?l0oooo803oool008`0oooo103o00080?o0b`D0oooo00<0
00000?ooo`3oool0o`3ooolP0?ooo`00R`3oool30?l000X0ol3;1@3oool0
0`000000oooo0?ooo`3o0?ooob00oooo00280?ooo`D0o`002`3o`</50?oo
o`030000003oool0oooo0?l0oooo803oool008L0oooo1@3o000<0?o0b`D0
oooo00<000000?ooo`3oool0o`3ooolP0?ooo`00Q03oool50?l000l0ol3;
1@3oool00`000000oooo0?ooo`3o0?ooob00oooo00220?ooo`H0o`00303o
`</5000000@0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`00O`3oool6
0?l00140ol3;00<000000?o0b`3oool0103oool00`000000oooo0?ooo`3o
0?ooob00oooo001m0?ooo`H0o`004`3o`</00`000000ol3;0?ooo`040?oo
o`<00000o`3ooolP0?ooo`00O@3oool30?l000h0ol3;100000040?o0b`03
0000003o`</0oooo00@0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`00
OP3ooolH0?o0b`030000003o`</0oooo00@0oooo00<000000?ooo`3oool0
o`3ooolP0?ooo`00OP3ooolG0?o0b`80000000<0ol3;0?ooo`3oool00`3o
ool00`000000oooo0?ooo`3o0?ooob00oooo001n0?oooaX0ol3;1@3oool0
0`000000oooo0?ooo`3o0?ooob00oooo001n0?oooaX0ol3;1@3oool00`00
0000oooo0?ooo`3o0?ooob00oooo001n0?oooaX0ol3;1@3oool00`000000
oooo0?ooo`3o0?ooob00oooo001n0?oooaX0ol3;1@3oool00`000000oooo
0?ooo`3o0?ooob00oooo001n0?oooaX0ol3;1@3oool00`000000oooo0?oo
o`3o0?ooob00oooo001n0?oooaX0ol3;1@3oool00`000000oooo0?ooo`3o
0?ooob00oooo001n0?oooaX0ol3;1@3oool00`000000oooo0?ooo`3o0?oo
ob00oooo001n0?oooaX0ol3;1@3oool00`000000oooo0?ooo`3o0?ooob00
oooo001n0?oooaX0ol3;1@3oool00`000000oooo0?ooo`3o0?ooob00oooo
001n0?oooaX0ol3;1@3oool00`000000oooo0?ooo`3o0?ooob00oooo001n
0?oooaX0ol3;1@3oool00`000000oooo0?ooo`3o0?ooob00oooo001n0?oo
oaX0ol3;1@3oool00`000000oooo0?ooo`3o0?ooob00oooo001n0?oooaX0
ol3;1@3oool00`000000oooo0?ooo`3o0?ooob00oooo001n0?oooaX0ol3;
1@3oool00`000000oooo0?ooo`3o0?ooob00oooo001n0?ooo`030?o0b`00
0000000000<000003`3o`</4000000030?o0b`3oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool400000180oooo1@00000J0?ooo`@00000703o
ool2000001h0oooo0`00000J0?ooo`800000703oool3000001h0oooo00<0
00000?ooo`3oool06P3oool2000002`0oooo001n0?ooo`<0ol3;00<00000
0?o0b`3o`</02@3o`</4000000<0ol3;00@000000?o0b`3o`</0ol3;1@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0L0?ooo`040000003o
ool0oooo000001h0oooo00<000000?ooo`3oool0603oool010000000oooo
0?ooo`00000K0?ooo`040000003oool0oooo000001d0oooo00<000000?oo
o`3oool06@3oool010000000oooo0?ooo`00000[0?ooo`00OP3oool30?o0
b`030000003o`</0ol3;0100ol3;00@000000?o0b`3o`</0ol3;1@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01X0oooo1@00000L0?ooo`030000003oool0oooo01T0oooo00@00000
0?ooo`3oool000007@3oool00`000000oooo0?ooo`0I0?ooo`040000003o
ool0oooo000002/0oooo001i0?ooo`@0000000D0oooo0?o0b`3o`</0ol3;
0000000A0?o0b`@0000000<0ol3;0?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`@00000503oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool06@3oool010000000oooo
0?ooo`00000K0?ooo`800000703oool3000001l0oooo00<000000?ooo`3o
ool06@3oool2000002`0oooo001n0?ooo`<0ol3;00<000000?o0b`3o`</0
503o`</50?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
6P3oool010000000oooo0?ooo`00000K0?ooo`040000003oool0oooo0000
01`0oooo00<000000?ooo`0000006`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01/0oooo00@000000?ooo`3oool000006P3oool0
10000000oooo0?ooo`00000[0?ooo`00OP3oool20?o0b`8000005P3o`</5
0?ooo`030000003oool0oooo01X0oooo0P00000M0?ooo`8000007@3oool2
000001h0oooo0P00000K0?ooo`<00000703oool3000001/0oooo1000000K
0?ooo`800000;03oool007h0oooo6P3o`</50?ooo`030000003oool0oooo
0?l0oooo803oool007h0oooo6P3o`</50?ooo`030000003oool0oooo0?l0
oooo803oool007h0oooo6P3o`</50?ooo`030000003oool0oooo0?l0oooo
803oool007h0oooo6P3o`</50?ooo`030000003oool0oooo0?l0oooo803o
ool007h0oooo6P3o`</50?ooo`030000003oool0oooo0?l0oooo0`3oool2
000000030?ooo`000000000001P0oooo001g0?ooool00000900000090?oo
o`030000003oool0000001T0oooo001n0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
00000000ool00?oo01H00?oo00<000000000o`000?l070000?l00`000000
003o0000o`0L0000o`03000000000?l0003o01`0003o00<000000000o`00
0?l06`000?l00`000000003o0000o`0L0000o`03000000000?l0003o01`0
003o00<000000000o`000?l06`000?l00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo01P0oooo001n0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
0000ool00?oo01H00?oo00<000000000o`000?l070000?l00`000000003o
0000o`0L0000o`03000000000?l0003o01`0003o00<000000000o`000?l0
6`000?l00`000000003o0000o`0L0000o`03000000000?l0003o01`0003o
00<000000000o`000?l06`000?l00`000000oooo0?ooo`0=0?ooo`800000
00<0oooo000000000000603oool009d0oooo00<000000?ooo`3oool00P3o
oolI003oomL0003o;@3oool009d0oooo00<000000?ooo`3oool00P3ooolI
003oomL0003o;@3oool009d0oooo00<000000?ooo`3oool00P3ooolI003o
omL0003o;@3oool009d0oooo00<000000?ooo`3oool00P3ooolI003oomL0
003o;@3oool009d0oooo00<000000?ooo`3oool00P3ooolI003oomL0003o
;@3oool009d0oooo00<000000?ooo`3oool00P3ooolI003oomL0003o;@3o
ool009d0oooo00<000000?ooo`3oool00P3ooolI003oomL0003o;@3oool0
09d0oooo00<000000?ooo`3oool00P3ooolI003oomL0003o;@3oool009d0
oooo00<000000?ooo`3oool00P3ooolI003oomL0003o;@3oool009d0oooo
00<000000?ooo`3oool00P3ooolI003oomL0003o;@3oool009d0oooo00<0
00000?ooo`3oool00P3ooolI003oomL0003o;@3oool009d0oooo00<00000
0?ooo`3oool00P3ooolI003oomL0003o;@3oool009d0oooo00<000000?oo
o`3oool00P3ooolI003oomP0003o;03oool009d0oooo00<000000?ooo`3o
ool00P3ooolI003oomP0003o;03oool009d0oooo00<000000?ooo`3oool0
0P3ooolI003oojh0003oEP3oool009d0oooo00<000000?ooo`3oool00P3o
oolI003oohH0003oOP3oool009d0oooo00<000000?ooo`3oool00P3ooolI
003oog80003oTP3oool009d0oooo00<000000?ooo`3oool00P3ooolI003o
oe<0003o/@3oool009d0oooo00<000000?ooo`3oool00P3ooolI003oodP0
003o_03oool009d0oooo00<000000?ooo`3oool00P3ooolI003ooc@0003o
d03oool009d0oooo00<000000?ooo`3oool00P3ooolI003oobX0003ofP3o
ool009d0oooo00<000000?ooo`3oool00P3ooolI003oob40003oh`3oool0
09d0oooo00<000000?ooo`3oool00P3ooolI003ooa/0003oj@3oool009d0
oooo00<000000?ooo`3oool00P3ooolI003ooaD0003ok`3oool009@0oooo
1@0000040?ooo`030000003oool0oooo0080oooo6@00ool@0000oo@0oooo
002F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
oolI003oo`/0003on@3oool009H0oooo00<000000?ooo`3oool0103oool3
00000080oooo5`00ool80000ooh0oooo002F0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3ooolE003oo`H0003oo`3oool30?oo
o`00UP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo4P00ool60000ool0oooo1P3oool009D0oooo0P0000060?ooo`030000
003oool0oooo0080oooo4000ool60000ool0oooo203oool009d0oooo00<0
00000?ooo`3oool00P3oool>003oo`D0003oo`3oool;0?ooo`00W@3oool0
0`000000oooo0?ooo`020?ooo`d00?oo10000?oo0?ooo`d0oooo002M0?oo
o`030000003oool0oooo0080oooo2`00ool40000ool0oooo3`3oool009d0
oooo00<000000?ooo`3oool00P3oool:003oo`@0003oo`3oool@0?ooo`00
W@3oool00`000000oooo0?ooo`020?ooo`T00?oo0`000?oo0?oooa80oooo
002M0?ooo`030000003oool0oooo0080oooo2000ool30000ool0oooo4`3o
ool009d0oooo00<000000?ooo`3oool00P3oool7003oo`<0003oo`3ooolD
0?ooo`00W@3oool00`000000oooo0?ooo`020?ooo`H00?oo0`000?oo0?oo
oaD0oooo002M0?ooo`030000003oool0oooo0080oooo1@00ool30000ool0
oooo5P3oool009d0oooo00<000000?ooo`3oool00P3oool5003oo`80003o
o`3ooolG0?ooo`00W@3oool00`000000oooo0?ooo`020?ooo`@00?oo0P00
0?oo0?oooaP0oooo002M0?ooo`030000003oool0oooo0080oooo0`00ool2
0000ool0oooo6@3oool009d0oooo00<000000?ooo`3oool00P3oool3003o
o`80003oo`3ooolI0?ooo`00W@3oool00`000000oooo0?ooo`020?ooo`80
0?oo0P000?oo0?oooaX0oooo002M0?ooo`030000003oool0oooo0080oooo
0P00ool20000ool0oooo6P3oool009d0oooo00<000000?ooo`3oool00P3o
ool00`00ool0003o0000o`3o0?oooa/0oooo002M0?ooo`030000003oool0
oooo0080oooo00<00?oo0000o`3oool0o`3ooolK0?ooo`00W@3oool00`00
0000oooo0?ooo`020?ooo`80003oo`3ooolL0?ooo`00W@3oool00`000000
oooo0?ooo`020?ooo`80003oo`3ooolL0?ooo`00W@3oool00`000000oooo
0?ooo`020?ooo`80003oo`3ooolL0?ooo`00W@3oool010000000oooo0?oo
o`3oool30000ool0oooo703oool009d0oooo00@000000?ooo`3oool0oooo
0P000?oo0?oooad0oooo002M0?ooo`040000003oool0oooo0?ooo`80003o
o`3ooolM0?ooo`00U03oool4000000D0oooo00@000000?ooo`3oool0oooo
0P000?oo0?oooad0oooo002D0?ooo`030000003oool0oooo00H0oooo00@0
00000?ooo`3oool0oooo0P000?oo0?oooad0oooo002E0?ooo`030000003o
ool0oooo00D0oooo0`0000020000ool0oooo7P3oool009H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020000ool0oooo7P3oool0
09@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`02
0000ool0oooo7P3oool009D0oooo0P0000060?ooo`030000003oool0oooo
0080003oo`3ooolN0?ooo`00W@3oool00`000000oooo0000o`020000ool0
oooo7P3oool009d0oooo00@000000?ooo`000?l0003oo`3ooolO0?ooo`00
W@3oool010000000oooo0000o`000?oo0?oooal0oooo002M0?ooo`040000
003oool0003o0000ool0oooo7`3oool009d0oooo00@000000000o`000?l0
003oo`3ooolO0?ooo`00W@3oool00`000000003o0000o`3o0?ooob00oooo
002M0?ooo`03000000000?l0003o0?l0oooo803oool009d0oooo00<00000
0000o`000?l0o`3ooolP0?ooo`00W@3oool00`000000003o0000o`3o0?oo
ob00oooo002M0?ooo`03000000000?l0003o0?l0oooo803oool009d0oooo
00<000000000o`000?l0o`3ooolP0?ooo`00W@3oool00`000000003o0000
o`3o0?ooob00oooo002N0?ooo`80003oo`3ooolP0?ooo`00o`3oooo00?oo
o`00o`3oooo00?ooo`00o`3oooo00?ooo`00o`3oooo00?ooo`00o`3oooo0
0?ooo`00o`3oooo00?ooo`00o`3oooo00?ooo`00o`3oooo00?ooo`00o`3o
ooo00?ooo`00o`3oooo00?ooo`00V`3oool300000?l0oooo8P3oool009h0
oooo00<000000?ooo`3oool0o`3ooolO0?ooo`00V`3oool300000?l0oooo
8P3oool009/0oooo1000003o0?ooob40oooo003o0?oool00oooo003o0?oo
ol00oooo003o0?oool00oooo003o0?oool00oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{447, 171},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  Evaluating the integrals and computing limits gives  \n\n\t\t\t\
",
  Cell[BoxData[{
      \(P . 
          V . \(\[Integral]\_\(-1\)\%8\( 
                  1\/x\^\(1/3\)\) \[DifferentialD]x\)\ \  = \ \ lim\+\(r\  \
\[Rule] \ \(0\^+\)\)\ \((\ \[Integral]\_\(-1\)\%\(-r\)\(1\/x\^\(1/3\)\) \
\[DifferentialD]x\ \  + \ \ \[Integral]\_r\%8\( 
                      1\/x\^\(1/3\)\) \[DifferentialD]x\ )\)\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\
\)\(\ \ \)\(lim\+\(r\  \[Rule] \ \(0\^+\)\)\ \((\(\(\(3\)\(\ \)\)\/2\) 
                x\^\(2/3\)\( \[VerticalSeparator] \+\(x = \(-1\)\)\%\(-r\)\)\ \
\ \(+\ \ \(\(\(3\)\(\ \)\)\/2\)\) 
                x\^\(2/3\)\( \[VerticalSeparator] \+\(x = 
                    r\)\%8\)\ )\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\
\)\(\ \ \)\(lim\+\(r\  \[Rule] \ \(0\^+\)\)\ \((\(\(\(3\)\(\ \)\)\/2\) 
                r\^\(2/3\)\ \  - \ \ \(\(3\)\(\ \)\)\/2\ \  + \ \ 6\ \  - \ \ \
\(\(\(3\)\(\ \)\)\/2\) r\^\(2/3\)\ )\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\
\)\(\ \ \)\((\(\(\(3\)\(\ \)\)\/2\) 
              0\^\(2/3\)\ \  - \ \ \(\(3\)\(\ \)\)\/2\ \  + \ \ 6\ \  - \ \ \
\(\(\(3\)\(\ \)\)\/2\) 0\^\(2/3\)\ )\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\
\)\(\ \ \)\((\(-\(\(\(3\)\(\ \)\)\/2\)\)\ \  + \ \ 6\ \
)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\
\)\(\ \ \)\(9\/2\)\)\)}]],
  "    "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.19.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "We must guide ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and write an appropriate form of the anti-derivative."
}], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 1\/x\^\(1/3\);\)\ \), "\n", 
    \(\(F[x_] = \(3\/2\) \((x\^2)\)\^\(1/3\);\)\ \), "\n", 
    \(\(Print["\< F[x] = \>", F[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<F'[x] = \>", \(F'\)[x], "\< = \>", 
        PowerExpand[\(F'\)[x]]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The integrand is discontinuous at x = 0 where it has a singularity.  \
Indeed, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has a branch cut for  ",
  Cell[BoxData[
      \(w\  = \ z\^\(1/3\)\)]],
  "  along the negative x-axis and maps these points onto the ray ",
  Cell[BoxData[
      \(Arg[w] = \[Pi]\/3\)]],
  ".  Hence the function  ",
  Cell[BoxData[
      \(f[x] = 1\/x\^\(1/3\)\)]],
  "  does not have the graph as taught in elementary calculus.  We must use \
the following function  h[x]."
}], "Text"],

Cell[BoxData[{
    \(\(h[x_ /; \ x > 0] := 1\/x\^\(1/3\);\)\ \), "\[IndentingNewLine]", 
    \(\(h[
          x_ /; \ x < 
              0] := \(-1\)\/Abs[x]\^\(1/3\);\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`FilledPlot`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(g11 = 
        Plot[h[x], {x, \(-1\), \(-0.01\)}, 
          PlotStyle \[Rule] {Thickness[0.0075], Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g22 = 
        Plot[h[x], {x, 0.01, 8}, PlotStyle \[Rule] {Thickness[0.0075], Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g1 = 
        FilledPlot[h[x], {x, \(-1\), \(-0.15\)}, PlotStyle \[Rule] Red, 
          Fills \[Rule] Pink, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g2 = 
        FilledPlot[h[x], {x, 0.16, 8}, PlotStyle \[Rule] Blue, 
          Fills \[Rule] Cyan, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g3 = 
        FilledPlot[h[x], {x, 1, 8}, PlotStyle \[Rule] Blue, 
          Fills \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[g1, g2, g11, g22, g3, PlotRange \[Rule] {\(-2.5\), 2.5}, 
        AxesLabel \[Rule] {"\<x\>", "\<s\>"}, \[IndentingNewLine]Ticks \
\[Rule] {{\(-1\), {\(-0.15\), "\<-r  \>"}, {0.16, "\< r\>"}, 1, 2, 3, 4, 5, 
              6, 7, 8}, Range[\(-3\), 3, 1]}, AspectRatio \[Rule] \ 1\/2, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<        s = \>", f[x]];\)\ \)}], "Input"],

Cell["Now we pursue the Cauchy principal value of the integral.", "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%8\)\>\"", 
        f[x], \*"\"\<\[DifferentialD]x  =  \!\(lim\+\(r \[Rule] 0\)\) ( \!\(\
\[Integral]\_\(-1\)\%\(-r\)\)\!\(1\/x\^\(1/3\)\)\[DifferentialD]x  +  \!\(\
\[Integral]\_r\%8\)\!\(1\/x\^\(1/3\)\)\[DifferentialD]x )\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%8\)\>\"", 
        f[x], \*"\"\<\[DifferentialD]x  =  \!\(lim\+\(r \[Rule] 0\)\) \
((\>\"", F[x], "\<)\>", "\<|\>"\+\(-1\)\%\(-r\), "\< + (\>", 
        F[x], "\<)\>", "\<|\>"\+r\%8, "\<)\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%8\)\>\"", 
        f[x], \*"\"\<\[DifferentialD]x  =  \!\(lim\+\(r \[Rule] 0\)\) \
((\>\"", F[\(-r\)] - \ F[\(-1\)], "\<) + (\>", 
        F[8] - \ F[r], "\<))\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%8\)\>\"", 
        f[x], \*"\"\<\[DifferentialD]x  =  \!\(lim\+\(r \[Rule] 0\)\) (\>\"", 
        F[\(-r\)] - \ F[\(-1\)] + F[8] - \ 
          F[r], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%8\)\>\"", 
        f[x], "\<\[DifferentialD]x  =  \>", 
        Limit[F[\(-r\)] - \ F[\(-1\)] + F[8] - \ F[r], 
          r \[Rule] 0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Warning.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The following computations will not produce the principal value of the \
real integral.  Indeed, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has a branch cut for  ",
  Cell[BoxData[
      \(w = \(g[z] = \(3\ z\^\(2/3\)\)\/2\)\)]],
  "  along the negative x-axis and maps these points onto the ray ",
  Cell[BoxData[
      \(Arg[w] = \(2\ \[Pi]\)\/3\)]],
  ",  in particular ",
  Cell[BoxData[
      \(g[\(-1\)] = \(-\(3\/4\)\) + \(3\ \[ImaginaryI]\ \@3\)\/4\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(g[x_]\  = \[Integral]f[x] \[DifferentialD]x;\)\ \), "\n", 
    \(\(val\  = \[Integral]\_\(-8\)\%1 f[x] \[DifferentialD]x;\)\ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print["\<g[x] = \[Integral]\>", f[x], "\< \[DifferentialD]x = \>", 
        g[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<g[8] = \>", g[8]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[-1] = \>", \ g[\(-1\)], "\< = \>", 
        ComplexExpand[g[\(-8\)]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The following answers are suspect because\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<the branch cuts occur on the negative x-axis.\>"];\)\ \), "\n\
", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%8\)\>\"", 
        f[x], "\< \[DifferentialD]x = g[8]-g[-1] = (\>", 
        g[8]\ , "\<) - (\>", \ 
        g[\(-1\)], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%8\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        g[8]\  - \ g[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%8\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        g[8]\  - ComplexExpand[g[\(-1\)]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%8\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Correction.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The following choice for the form for the indefinite integral will \
produce the desired computation."
}], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 1\/x\^\(1/3\);\)\ \), "\n", 
    \(\(F[x_] = \(3\/2\) \((x\^2)\)\^\(1/3\);\)\ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print["\<F[x] = \[Integral]\>", f[x], "\< \[DifferentialD]x = \>", 
        F[x]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<F[8] = \>", F[8], "\<,     F[-1] = \>", \ 
        F[\(-1\)]];\)\ \), "\n", 
    \(\(Plot[F[x], {x, \(-1\), 8}, PlotRange \[Rule] {0, 6}, 
        AxesLabel \[Rule] {"\<x\>", "\<s\>"}, \[IndentingNewLine]PlotStyle \
\[Rule] Magenta, 
        Ticks \[Rule] {Range[\(-1\), 8, 1], 
            Range[0, 6, 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<      s = F[x] = \>", F[x]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%8\)\>\"", 
        f[x], "\< \[DifferentialD]x = F[8]-F[-1] = (\>", 
        F[8]\ , "\<) - (\>", \ F[\(-1\)], "\<)\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-1\)\%8\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        F[8]\  - \ F[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Which is also the correct answer.", "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The PrincipalValue option does not give and answer to this problem."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(int = 
        Integrate[F[x], {x, \(-\[Infinity]\), \[Infinity]}, 
          PrincipalValue \[Rule] True];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        F[x], "\< \[DifferentialD]x = \>", 
        int];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "We are done.\n",
  "\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Observe that  ",
  Cell[BoxData[
      \(P . 
          V . \ \(\[Integral]\_\(-1\)\%8\( 
                  1\/x\^\(1/3\)\) \[DifferentialD]x\)\ \  = \ \ \(P . 
              V . \ \(\[Integral]\_\(-1\)\%1\( 
                      1\/x\^\(1/3\)\) \[DifferentialD]x\)\ \  + \ \ \ \
\[Integral]\_1\%8\( 
                    1\/x\^\(1/3\)\) \[DifferentialD]x\ \  = \ \ 0\ \  + \ \ \
\[Integral]\_1\%8\( 1\/x\^\(1/3\)\) \[DifferentialD]x\)\)]]
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`FilledPlot`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(g11 = 
        Plot[h[x], {x, \(-1\), \(-0.01\)}, 
          PlotStyle \[Rule] {Thickness[0.0075], Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g22 = 
        Plot[h[x], {x, 0.01, 8}, PlotStyle \[Rule] {Thickness[0.0075], Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g1 = 
        FilledPlot[h[x], {x, \(-1\), \(-0.001\)}, PlotStyle \[Rule] Red, 
          Fills \[Rule] Honeydew, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g2 = 
        FilledPlot[h[x], {x, 0.001, 8}, PlotStyle \[Rule] Blue, 
          Fills \[Rule] Honeydew, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g3 = 
        FilledPlot[h[x], {x, 1, 8}, PlotStyle \[Rule] Blue, 
          Fills \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[g1, g2, g11, g22, g3, PlotRange \[Rule] {\(-2.5\), 2.5}, 
        AxesLabel \[Rule] {"\<x\>", "\<s\>"}, \[IndentingNewLine]Ticks \
\[Rule] {{\(-1\), {\(-0.15\), "\<-r  \>"}, {0.16, "\< r\>"}, 1, 2, 3, 4, 5, 
              6, 7, 8}, Range[\(-3\), 3, 1]}, AspectRatio \[Rule] \ 1\/2, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<   \>", \
\*"\"\<P.V.\!\(\[Integral]\_\(-1\)\%8\)\!\(1\/x\^\(1/3\)\)\[DifferentialD]x = \
P.V.\!\(\[Integral]\_\(-1\)\%1\)\!\(1\/x\^\(1/3\)\)\[DifferentialD]x + \!\(\
\[Integral]\_1\%8\)\!\(1\/x\^\(1/3\)\)\[DifferentialD]x\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<   \>", \
\*"\"\<P.V.\!\(\[Integral]\_\(-1\)\%8\)\!\(1\/x\^\(1/3\)\)\[DifferentialD]x = \
 0 + \!\(\[Integral]\_1\%8\)\!\(1\/x\^\(1/3\)\)\[DifferentialD]x\>\""];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<       \>", \
\*"\"\<\!\(\[Integral]\_1\%8\)\!\(1\/x\^\(1/3\)\)\[DifferentialD]x =  \>\"", \
\[Integral]\_1\%8\( 
                1\/x\^\(1/3\)\) \[DifferentialD]x\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<   \>", \
\*"\"\<P.V.\!\(\[Integral]\_\(-1\)\%8\)\!\(1\/x\^\(1/3\)\)\[DifferentialD]x = \
 \>\"", \[Integral]\_1\%8\( 
                1\/x\^\(1/3\)\) \[DifferentialD]x];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tIn this section we show how to use residues to evaluate the Cauchy \
principal value of the integral of ",
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  " over ",
  Cell[BoxData[
      \(\((\(-\[Infinity]\), \[Infinity])\)\)]],
  " when the integrand ",
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  " has simple poles on the ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " axis.  We state our main results and then look at some examples before \
giving proofs."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 8.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  Cell[BoxData[
      \(f \((z)\) = \(P \((z)\)\)\/\(Q \((z)\)\)\)]],
  " where ",
  StyleBox["P(x)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Q(x)",
    FontFamily->"Courier New"],
  " are polynomials with real coefficients of degree ",
  StyleBox["m",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ", respectively, and  ",
  Cell[BoxData[
      \(n \[GreaterEqual] m + 2\)]],
  ".  If ",
  StyleBox["Q(x)",
    FontFamily->"Courier New"],
  " has simple zeros at the points ",
  Cell[BoxData[
      RowBox[{\(t\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(t\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(t\_L\)}]]],
  " on the ",
  StyleBox["x",
    FontFamily->"Courier New"],
  "-axis, then  \n\n",
  StyleBox["(8-20)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(P . 
          V . \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                    P \((x)\)\)\/\(Q \((x)\)\)\) \[DifferentialD]x\)\ \  = \ \
\ 2  \[Pi]\ \[ImaginaryI]\ \(\[Sum]\+\(j = 1\)\%k Res[P\/Q, 
                z\_j]\)\ \  + \ \ \[Pi]\ \[ImaginaryI]\ \(\[Sum]\+\(j = \
1\)\%L Res[P\/Q, t\_j]\)\)]],
  ",  \n\nwhere ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_k\)}]]],
  " are the poles of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " that lie in the upper half-plane.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Proof of Theorem 8.5",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[" is in the book.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 8.6",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/integralsindentedcontour/\
IntegralsIndentedContourFigures/mat0806.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  The poles ",
  Cell[BoxData[
      RowBox[{\(t\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(t\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(t\_L\)}]]],
  " of ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " that lie on the x-axis and the poles ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_k\)}]]],
  " that lie above the semicircles ",
  Cell[BoxData[
      RowBox[{\(C\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(C\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(C\_L\)}]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 8.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["P(x)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Q(x)",
    FontFamily->"Courier New"],
  " be polynomials, of degree ",
  StyleBox["m",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ", respectively, where ",
  Cell[BoxData[
      \(n \[GreaterEqual] m + 1\)]],
  " and let ",
  StyleBox["Q(x)",
    FontFamily->"Courier New"],
  " have simple zeros at the points  ",
  Cell[BoxData[
      RowBox[{\(t\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(t\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(t\_L\)}]]],
  "  on the x-axis.  If ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  " is a positive real number and if  ",
  Cell[BoxData[
      \(f \((z)\) = \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Alpha]\ z\)\ P \
\((z)\)\)\/\(Q \((z)\)\)\)]],
  ", then we can compute the Cauchy Principal Value (P.V.) of the following \
integrals \n\n",
  StyleBox["(8-21)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(P . 
          V . \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                    P \((x)\)\)\/\(Q \((x)\)\)\) 
              cos\ \[Alpha]\ x \[DifferentialD]x\)\ \  = \ \ \(-\ 
              2\) \[Pi]\ \(\[Sum]\+\(j = 1\)\%k 
                Im \((Res[f, 
                    z\_j])\)\)\ \  - \ \ \[Pi]\ \(\[Sum]\+\(j = 1\)\%L 
                Im \((Res[f, t\_j])\)\)\)]],
  ",  \n\t\n\t\tand  \n\t\n",
  StyleBox["(8-22)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(P . 
          V . \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                    P \((x)\)\)\/\(Q \((x)\)\)\) 
              sin\ \[Alpha]\ x\ \[DifferentialD]x\)\ \  = \ \ 2  \[Pi]\ \ \(\
\[Sum]\+\(j = 1\)\%k 
                Re \((Res[f, 
                    z\_j])\)\)\ \  + \ \ \[Pi]\ \ \(\[Sum]\+\(j = 1\)\%L 
                Re \((Res[f, t\_j])\)\)\)]],
  ",    \n\nwhere ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_k\)}]]],
  " are the poles of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " that lie in the upper half plane.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Proof of Theorem 8.6",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[" is in the book.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The formulas in these theorems give the Cauchy principal value of the \
integral, which pays special attention to the manner in which any limits are \
taken.  They are similar to those in Sections 8.3 and 8.4, except here we add \
one-half of the value of each residue at the points ",
  Cell[BoxData[
      RowBox[{\(t\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(t\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(t\_r\)}]]],
  " on the ",
  StyleBox["x",
    FontFamily->"Courier New"],
  "-axis."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 8.20.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Evaluate  ",
  Cell[BoxData[
      \("P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\!\(x\/\(x\^3 - \
8\)\)\[DifferentialD]x"\)]],
  "  by using complex analysis.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008K0000YB000`400?l0
0000o`00003oo`3ooooo0?oooad0oooo003o0?ooool0oooo7@3oool00?l0
ooooo`3ooolM0?ooo`00o`3ooooo0?oooad0oooo003o0?ooool0oooo7@3o
ool00900oooo00<000000?ooo`3oool0jP3oool00`000000oooo0?ooo`2K
0?ooo`00T03oool00`000000oooo0?ooo`3Z0?ooo`030000003oool0oooo
05H0oooo1@0000100?ooo`00T03oool00`000000oooo0?ooo`3Z0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0@03oool00900oooo
00<000000?ooo`3oool0jP3oool00`000000oooo0?ooo`1@0?ooo`D00000
0`3oool00`000000oooo0?ooo`100?ooo`00T03oool00`000000oooo0?oo
o`3Z0?ooo`030000003oool0oooo0540oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`100?ooo`00R@3oool4000000<0oooo00<0
00000?ooo`3oool0``3oool500000280oooo00<000000?ooo`3oool08`3o
ool5000002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`100?ooo`00R@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0<D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo02/0oooo00@000000?ooo`3oool0oooo0P00
00120?ooo`00RP3oool00`000000oooo0?ooo`030?ooo`800000aP3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0:@3oool010000000oooo0?ooo`0000160?ooo`00P`3oool4
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2m
0?ooo`@00000103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0:@3oool5000004D0oooo001l0?oo
o`<000002P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo0<D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo07<0oooo001l0?ooo`030000003oool0oooo
00/0oooo0P0000040?ooo`030000003oool0oooo0<@0oooo0P00000T0?oo
o`030000003oool0oooo02@0oooo0P00001e0?ooo`00M03oool5000000@0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3Z0?ooo`03
0000003oool0oooo09/0oooo001e0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3Z0?ooo`03
0000003oool0oooo09/0oooo001f0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`0000004@3oool00`000000oooo0?ooo`3Z0?ooo`030000
003oool0oooo09/0oooo001_0?ooo`<0o`001@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0jP3o
ool00`000000oooo0?ooo`1<0?ooo`<0o`3oC03oool006h0oooo1@3o0002
0?ooo`040000003oool0oooo000001L0oooo00<000000?ooo`3oool0jP3o
ool00`000000oooo0?ooo`1;0?ooo`D0o`3o<@3oool2000000030?ooo`00
0000000001D0oooo001^0?ooo`D0o`000P3oool5000001H0oooo00<00000
0?ooo`3oool0L03oooo4003oo`<0oooo1`3o0?l30?ooob<00?oo2`3oool0
0`000000oooo0000000F0?ooo`00KP3oool50?l001d0oooo00<000000?oo
o`3oool0K@3oool300000<@00?oo0`0000070?l0o`<000008`00ool30000
00T0oooo00<000000?ooo`3oool05@3oool006l0oooo0`3o000N0?ooo`03
0000003oool0oooo0700ooooa000ool30?ooo`L0o`3o0`3ooolS003oo`X0
oooo0P0000000`3oool000000000000E0?ooo`00T03oool00`000000oooo
0?ooo`1a0?ooo`030000o`3oool0oooo07H0oooo00<000000?ooo`3oool0
A@3oool00`000?l0oooo0?ooo`030?ooo`D0o`3o103oool00`000?l0oooo
0?ooo`0N0?ooo`030000o`3oool0oooo02<0oooo002@0?ooo`030000003o
ool0oooo0740oooo00<0003o0?ooo`3oool0MP3oool00`000000oooo0?oo
o`150?ooo`030000o`3oool0oooo00@0oooo0`3o0?l50?ooo`030000o`3o
ool0oooo01h0oooo00<0003o0?ooo`3oool08`3oool00900oooo00<00000
0?ooo`3oool0LP3oool00`000?l0oooo0?ooo`1e0?ooo`030000003oool0
oooo04H0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0O
0?ooo`030000o`3oool0oooo02<0oooo002@0?ooo`030000003oool0oooo
0780oooo00<0003o0?ooo`3oool0M@3oool00`000000oooo0?ooo`170?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0803oool00`00
0?l0oooo0?ooo`0S0?ooo`00T03oool00`000000oooo0?ooo`1b0?ooo`03
0000o`3oool0oooo07D0oooo00<000000?ooo`3oool0B03oool20000o`L0
oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0S0?ooo`00
T03oool00`000000oooo0?ooo`1b0?ooo`030000o`3oool0oooo07D0oooo
00<000000?ooo`3oool0BP3oool20000o`80oooo0`000?lS0?ooo`030000
o`3oool0oooo02@0oooo002@0?ooo`030000003oool0oooo0780oooo00<0
003o0?ooo`3oool0M@3oool00`000000oooo0?ooo`1<0?ooo`80003o9P3o
ool00`000?l0oooo0?ooo`0T0?ooo`00T03oool00`000000oooo0?ooo`1b
0?ooo`030000o`3oool0oooo07D0oooo00<000000?ooo`3oool0M03oool0
0`000?l0oooo0?ooo`0T0?ooo`00T03oool00`000000oooo0?ooo`1b0?oo
o`030000o`3oool0oooo07D0oooo00<000000?ooo`3oool0M03oool00`00
0?l0oooo0?ooo`0T0?ooo`00T03oool00`000000oooo0?ooo`1b0?ooo`03
0000o`3oool0oooo07D0oooo00<000000?ooo`3oool0M03oool00`000?l0
oooo0?ooo`0T0?ooo`00T03oool00`000000oooo0?ooo`1b0?ooo`030000
o`3oool0oooo07D0oooo00<000000?ooo`3oool0M03oool00`000?l0oooo
0?ooo`0T0?ooo`00T03oool00`000000oooo0?ooo`1b0?ooo`030000o`3o
ool0oooo07D0oooo00<000000?ooo`3oool0M03oool00`000?l0oooo0?oo
o`0T0?ooo`00T03oool00`000000oooo0?ooo`1b0?ooo`030000o`3oool0
oooo07D0oooo00<000000?ooo`3oool0M03oool00`000?l0oooo0?ooo`0T
0?ooo`00T03oool00`000000oooo0?ooo`1b0?ooo`030000o`3oool0oooo
07D0oooo00<000000?ooo`3oool0M03oool00`000?l0oooo0?ooo`0T0?oo
o`00T03oool00`000000oooo0?ooo`1c0?ooo`030000o`3oool0oooo07@0
oooo00<000000?ooo`3oool0M03oool00`000?l0oooo0?ooo`0T0?ooo`00
T03oool00`000000oooo0?ooo`1c0?ooo`030000o`3oool0oooo07@0oooo
00<000000?ooo`3oool0M03oool00`000?l0oooo0?ooo`0T0?ooo`00T03o
ool00`000000oooo0?ooo`1c0?ooo`030000o`3oool0oooo07@0oooo00<0
00000?ooo`3oool0M03oool00`000?l0oooo0?ooo`0T0?ooo`00T03oool0
0`000000oooo0?ooo`1c0?ooo`030000o`3oool0oooo07@0oooo00<00000
0?ooo`3oool0L`3oool00`000?l0oooo0?ooo`0U0?ooo`00R@3oool50000
0080oooo00<000000?ooo`3oool0L`3oool00`000?l0oooo0?ooo`1d0?oo
o`030000003oool0oooo07<0oooo00<0003o0?ooo`3oool09@3oool008/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1c0?ooo`03
0000o`3oool0oooo07@0oooo00<000000?ooo`3oool0L`3oool00`000?l0
oooo0?ooo`0U0?ooo`00R`3oool00`000000oooo0?ooo`020?ooo`800000
M@3oool00`000?l0oooo0?ooo`1c0?ooo`030000003oool0oooo0780oooo
00<0003o0?ooo`3oool09P3oool008<0oooo100000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0M03oool00`000?l0oooo0?oo
o`1c0?ooo`030000003oool0oooo0780oooo00<0003o0?ooo`3oool09P3o
ool008/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d
0?ooo`030000o`3oool0oooo07<0oooo00<000000?ooo`3oool0LP3oool0
0`000?l0oooo0?ooo`0V0?ooo`00RP3oool2000000@0oooo00<000000?oo
o`3oool0M03oool00`000?l0oooo0?ooo`1c0?ooo`030000003oool0oooo
0780oooo00<0003o0?ooo`3oool09P3oool00900oooo00<000000?ooo`3o
ool0M03oool00`000?l0oooo0?ooo`1c0?ooo`030000003oool0oooo0780
oooo00<0003o0?ooo`3oool09P3oool00900oooo00<000000?ooo`3oool0
M03oool00`000?l0oooo0?ooo`1c0?ooo`030000003oool0oooo0780oooo
00<0003o0?ooo`3oool09P3oool00900oooo00<000000?ooo`3oool0M@3o
ool00`000?l0oooo0?ooo`1b0?ooo`030000003oool0oooo0740oooo00<0
003o0?ooo`3oool09`3oool00900oooo00<000000?ooo`3oool0M@3oool0
0`000?l0oooo0?ooo`1b0?ooo`030000003oool0oooo0740oooo00<0003o
0?ooo`3oool09`3oool00900oooo00<000000?ooo`3oool0M@3oool00`00
0?l0oooo0?ooo`1b0?ooo`030000003oool0oooo0740oooo00<0003o0?oo
o`3oool09`3oool00900oooo00<000000?ooo`3oool0MP3oool00`000?l0
oooo0?ooo`1a0?ooo`030000003oool0oooo0700oooo00<0003o0?ooo`3o
ool0:03oool00900oooo00<000000?ooo`3oool0MP3oool00`000?l0oooo
0?ooo`1a0?ooo`030000003oool0oooo0700oooo00<0003o0?ooo`3oool0
:03oool00900oooo00<000000?ooo`3oool0MP3oool00`000?l0oooo0?oo
o`1a0?ooo`030000003oool0oooo0700oooo00<0003o0?ooo`3oool0:03o
ool00900oooo00<000000?ooo`3oool0M`3oool00`000?l0oooo0?ooo`1`
0?ooo`030000003oool0oooo0700oooo00<0003o0?ooo`3oool0:03oool0
0900oooo00<000000?ooo`3oool0M`3oool00`000?l0oooo0?ooo`1`0?oo
o`030000003oool0oooo0700oooo00<0003o0?ooo`3oool0:03oool00900
oooo00<000000?ooo`3oool0M`3oool00`000?l0oooo0?ooo`1`0?ooo`03
0000003oool0oooo06l0oooo00<0003o0?ooo`3oool0:@3oool00900oooo
00<000000?ooo`3oool0M`3oool00`000?l0oooo0?ooo`1`0?ooo`030000
003oool0oooo06l0oooo00<0003o0?ooo`3oool0:@3oool00900oooo00<0
00000?ooo`3oool0M`3oool00`000?l0oooo0?ooo`1X0?ooo`D000000`3o
ool00`000000oooo0?ooo`1_0?ooo`030000o`3oool0oooo02T0oooo002@
0?ooo`030000003oool0oooo07P0oooo00<0003o0?ooo`3oool0J@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo06h0oooo00<0003o
0?ooo`3oool0:P3oool00900oooo00<000000?ooo`3oool0N03oool00`00
0?l0oooo0?ooo`1Y0?ooo`030000003oool0oooo00<0oooo0P00001_0?oo
o`030000o`3oool0oooo02X0oooo002@0?ooo`030000003oool0oooo07P0
oooo00<0003o0?ooo`3oool0J@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo06h0oooo00<0003o0?ooo`3oool0:P3oool00900oooo
00<000000?ooo`3oool0N@3oool00`000?l0oooo0?ooo`1X0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0K@3oool00`000?l0oooo
0?ooo`0[0?ooo`00T03oool00`000000oooo0?ooo`1i0?ooo`030000o`3o
ool0oooo06L0oooo0P0000050?ooo`030000003oool0oooo06d0oooo00<0
003o0?ooo`3oool0:`3oool00900oooo00<000000?ooo`3oool0NP3oool0
0`000?l0oooo0?ooo`1]0?ooo`030000003oool0oooo06d0oooo00<0003o
0?ooo`3oool0:`3oool00500oooo1000000M0?ooo`D000006P3oool00`00
0000oooo0?ooo`0L0?ooo`D000006`3oool4000003X0oooo00<0003o0?oo
o`3oool0K@3oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0oooo
02`0oooo001@0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0?03oool00`000?l0oooo0?ooo`1/0?ooo`03
0000003oool0oooo06`0oooo00<0003o0?ooo`3oool0;03oool00540oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0k0?ooo`030000o`3oool0oooo06`0oooo00<000000?ooo`3oool0
J`3oool00`000?l0oooo0?ooo`0]0?ooo`00BP3oool4000000@0oooo00<0
00000?ooo`3oool05P3oool4000000@0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`1[0?ooo`030000003o
ool0oooo06X0oooo00<0003o0?ooo`3oool0;P3oool00500oooo00@00000
0?ooo`3oool000007`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool06`3oool010000000oooo0?oo
o`00000l0?ooo`030000o`3oool0oooo06/0oooo00<000000?ooo`3oool0
JP3oool00`000?l0oooo0?ooo`0^0?ooo`00D@3oool2000001l0oooo0P00
000L0?ooo`030000003oool0oooo01d0oooo0P00000N0?ooo`800000?P3o
ool00`000?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo06T0oooo00<0
003o0?ooo`3oool0;`3oool00900oooo00<000000?ooo`3oool0O@3oool0
0`000?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo06T0oooo00<0003o
0?ooo`3oool0;`3oool00900oooo00<000000?ooo`3oool0O@3oool00`00
0?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo06T0oooo00<0003o0?oo
o`3oool0;`3oool00900oooo00<000000?ooo`3oool0?@3oool30?l0o`X0
oooo0P0000000`3oool000000000000_0?ooo`030000o`3oool0oooo06T0
oooo00<000000?ooo`3oool0J03oool00`000?l0oooo0?ooo`0`0?ooo`00
T03oool00`000000oooo0?ooo`0l0?ooo`D0o`3o2P3oool00`000000oooo
0000000`0?ooo`030000o`3oool0oooo06T0oooo00<000000?ooo`3oool0
J03oool00`000?l0oooo0?ooo`0`0?ooo`00B@3ooon6000000D0o`3o1@00
00060?ooo`030000003oool0oooo0300oooo00<0003o0?ooo`3oool0J03o
ool00`000000oooo0?ooo`1W0?ooo`030000o`3oool0oooo0340oooo001?
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01/0oooo1@3o0?l9
0?ooo`80000000<0oooo000000000000<@3oool00`000?l0oooo0?ooo`1W
0?ooo`030000003oool0oooo06L0oooo00<0003o0?ooo`3oool0<@3oool0
0900oooo00<000000?ooo`3oool0?@3oool30?l0od00oooo00<0003o0?oo
o`3oool0I`3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo
0380oooo002@0?ooo`030000003oool0oooo0840oooo00<0003o0?ooo`3o
ool0IP3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo0380
oooo002@0?ooo`030000003oool0oooo0840oooo00<0003o0?ooo`3oool0
IP3oool00`000000oooo0?ooo`1U0?ooo`030000o`3oool0oooo03<0oooo
002@0?ooo`030000003oool0oooo04H0oooo1@00000g0?ooo`030000o`3o
ool0oooo06D0oooo00<000000?ooo`3oool0I03oool00`000?l0oooo0?oo
o`0d0?ooo`00T03oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo03P0oooo00<0003o0?ooo`3oool0I03oool00`000000oooo0?ooo`1T
0?ooo`030000o`3oool0oooo03@0oooo002@0?ooo`030000003oool0oooo
0400oooo1@0000030?ooo`030000003oool0oooo03P0oooo00<0003o0?oo
o`3oool0I03oool00`000000oooo0?ooo`1S0?ooo`030000o`3oool0oooo
03D0oooo002@0?ooo`030000003oool0oooo0440oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo
06<0oooo00<000000?ooo`3oool0H`3oool00`000?l0oooo0?ooo`0e0?oo
o`00T03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`1S0?ooo`03
0000003oool0oooo0680oooo00<0003o0?ooo`3oool0=P3oool00900oooo
00<000000?ooo`3oool0@`3oool010000000oooo0?ooo`3oool2000003`0
oooo00<0003o0?ooo`3oool0HP3oool00`000000oooo0?ooo`1Q0?ooo`03
0000o`3oool0oooo03L0oooo002@0?ooo`030000003oool0oooo0440oooo
00@000000?ooo`3oool00000@@3oool00`000?l0oooo0?ooo`0g0?ooo`<0
o`00303oool2000001T0oooo00<000000?ooo`3oool0H@3oool00`000?l0
oooo0?ooo`0g0?ooo`00T03oool00`000000oooo0?ooo`110?ooo`D00000
@03oool00`000?l0oooo0?ooo`0f0?ooo`D0o`00103oool5000000@0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1P0?ooo`030000
o`3oool0oooo03P0oooo002@0?ooo`030000003oool0oooo08L0oooo00<0
003o0?ooo`3oool0=03oool70?l000@0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0600oooo
00<0003o0?ooo`3oool0>03oool00900oooo00<000000?ooo`3oool0Q`3o
ool00`000?l0oooo0?ooo`0d0?ooo`L0o`001@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3o
ool00`000?l0oooo0?ooo`0i0?ooo`00T03oool00`000000oooo0?ooo`28
0?ooo`030000o`3oool0oooo03<0oooo1`3o00060?ooo`070000003oool0
oooo0?ooo`000000oooo0000000H0?ooo`030000003oool0oooo05h0oooo
00<0003o0?ooo`3oool0>P3oool00900oooo00<000000?ooo`3oool0R@3o
ool00`000?l0oooo0?ooo`0c0?ooo`D0o`001@3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
G@3oool00`000?l0oooo0?ooo`0k0?ooo`00T03oool00`000000oooo0?oo
o`2:0?ooo`030000o`3oool0oooo03<0oooo0`3o00060?ooo`D00000703o
ool00`000000oooo0?ooo`1L0?ooo`030000o`3oool0oooo03`0oooo002@
0?ooo`030000003oool0oooo08/0oooo00<0003o0?ooo`3oool0G03oool0
0`000000oooo0?ooo`1K0?ooo`030000o`3oool0oooo03d0oooo002@0?oo
o`030000003oool0oooo08`0oooo00<0003o0?ooo`3oool0F`3oool00`00
0000oooo0?ooo`1K0?ooo`030000o`3oool0oooo03d0oooo002@0?ooo`03
0000003oool0oooo08`0oooo00<0003o0?ooo`3oool0F`3oool00`000000
oooo0?ooo`1J0?ooo`030000o`3oool0oooo03h0oooo002@0?ooo`030000
003oool0oooo08d0oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo
0?ooo`1J0?ooo`030000o`3oool0oooo03h0oooo002@0?ooo`030000003o
ool0oooo08h0oooo00<0003o0?ooo`3oool0F@3oool00`000000oooo0?oo
o`1I0?ooo`030000o`3oool0oooo03l0oooo002@0?ooo`030000003oool0
oooo08l0oooo00<0003o0?ooo`3oool0D03oool4000000@0oooo00<00000
0?ooo`3oool0F03oool00`000?l0oooo0?ooo`100?ooo`00T03oool00`00
0000oooo0?ooo`2@0?ooo`030000o`3oool0oooo04l0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1G0?ooo`030000o`3oool0oooo
0440oooo002@0?ooo`030000003oool0oooo0940oooo00<0003o0?ooo`3o
ool0C`3oool00`000000oooo0?ooo`040?ooo`800000E`3oool00`000?l0
oooo0?ooo`120?ooo`00T03oool00`000000oooo0?ooo`2B0?ooo`030000
o`3oool0oooo04l0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`1E0?ooo`030000o`3oool0oooo04<0oooo002@0?ooo`030000003o
ool0oooo09<0oooo00<0003o0?ooo`3oool0C03oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo05@0oooo00<0003o0?ooo`3oool0
A03oool00900oooo00<000000?ooo`3oool0U03oool00`000?l0oooo0?oo
o`1<0?ooo`8000001@3oool00`000000oooo0?ooo`1C0?ooo`030000o`3o
ool0oooo04D0oooo002@0?ooo`030000003oool0oooo09@0oooo00<0003o
0?ooo`3oool0D`3oool00`000000oooo0?ooo`1C0?ooo`030000o`3oool0
oooo04D0oooo00290?ooo`D000000P3oool00`000000oooo0?ooo`2E0?oo
o`030000o`3oool0oooo0580oooo00<000000?ooo`3oool0DP3oool00`00
0?l0oooo0?ooo`160?ooo`00R`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo09H0oooo00<0003o0?ooo`3oool0D@3oool00`000000
oooo0?ooo`1@0?ooo`80003oB@3oool008/0oooo00<000000?ooo`3oool0
0P3oool2000009P0oooo00<0003o0?ooo`3oool0D03oool00`000000oooo
0?ooo`1?0?ooo`030000o`3oool0oooo04T0oooo002;0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0V03oool00`000?l0oooo0?oo
o`1?0?ooo`030000003oool0oooo04h0oooo00<0003o0?ooo`3oool0BP3o
ool008/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2I
0?ooo`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool0C@3oool0
0`000?l0oooo0?ooo`1;0?ooo`00RP3oool2000000@0oooo00<000000?oo
o`3oool0VP3oool00`000?l0oooo0?ooo`1=0?ooo`030000003oool0oooo
04`0oooo00<0003o0?ooo`3oool0C03oool00900oooo00<000000?ooo`3o
ool0V`3oool00`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo04/0
oooo00<0003o0?ooo`3oool0C@3oool00900oooo00<000000?ooo`3oool0
W03oool20000od`0oooo00<000000?ooo`3oool0B@3oool20000oe00oooo
002@0?ooo`030000003oool0oooo09h0oooo0P000?m:0?ooo`030000003o
ool0oooo04P0oooo00<0003o0?ooo`3oool0D03oool00900oooo00<00000
0?ooo`3oool0X03oool00`000?l0oooo0?ooo`170?ooo`030000003oool0
oooo04L0oooo00<0003o0?ooo`3oool0D@3oool00900oooo00<000000?oo
o`3oool0X@3oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo
04D0oooo0P000?mD0?ooo`00T03oool00`000000oooo0?ooo`2R0?ooo`03
0000o`3oool0oooo04D0oooo00<000000?ooo`3oool0A03oool00`000?l0
oooo0?ooo`1D0?ooo`00T03oool00`000000oooo0?ooo`2S0?ooo`030000
o`3oool0oooo04@0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo
0?ooo`1E0?ooo`00T03oool00`000000oooo0?ooo`2T0?ooo`80003oA03o
ool00`000000oooo0?ooo`110?ooo`80003oF03oool00900oooo00<00000
0?ooo`3oool0YP3oool20000od80oooo00<000000?ooo`3oool0?`3oool2
0000oeX0oooo002@0?ooo`030000003oool0oooo0:P0oooo00<0003o0?oo
o`3oool0?`3oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo
05X0oooo002@0?ooo`030000003oool0oooo0:T0oooo00<0003o0?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo05/0
oooo002@0?ooo`030000003oool0oooo0:X0oooo0P000?ln0?ooo`030000
003oool0oooo03/0oooo0P000?mN0?ooo`00T03oool00`000000oooo0?oo
o`2/0?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3o
ool00`000?l0oooo0?ooo`1N0?ooo`00T03oool00`000000oooo0?ooo`2]
0?ooo`80003o>`3oool00`000000oooo0?ooo`0h0?ooo`80003oH@3oool0
07`0oooo0P00000B0?ooo`030000003oool0oooo0:l0oooo0P000?li0?oo
o`030000003oool0oooo03H0oooo0P000?mS0?ooo`00M03oool5000000D0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2a0?ooo`80
003o=`3oool00`000000oooo0?ooo`0e0?ooo`030000o`3oool0oooo06<0
oooo001e0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`2c0?ooo`80003o=@3oool00`000000
oooo0?ooo`0b0?ooo`<0003oIP3oool007H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0;D0oooo
0`000?lb0?ooo`030000003oool0oooo02l0oooo0`000?mY0?ooo`00K`3o
ool30?l000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
000A0?ooo`030000003oool0oooo0;P0oooo0P000?l`0?ooo`030000003o
ool0oooo02d0oooo0P000?m/0?ooo`00KP3oool50?l00080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0;X0oooo0P000?l^0?ooo`030000003oool0oooo02`0oooo00<0
003o0?ooo`3oool0K03oool006h0oooo1@3o00020?ooo`D000005P3oool0
0`000000oooo0?ooo`2l0?ooo`030000o`3oool0oooo02/0oooo00<00000
0?ooo`3oool0:P3oool20000ofl0oooo001^0?ooo`D0o`007@3oool00`00
0000oooo0?ooo`2m0?ooo`<0003o:P3oool00`000000oooo0?ooo`0W0?oo
o`<0003oL@3oool006l0oooo0`3o000N0?ooo`030000003oool0oooo0<00
oooo0`000?lW0?ooo`030000003oool0oooo02@0oooo0`000?md0?ooo`00
T03oool00`000000oooo0?ooo`330?ooo`<0003o903oool00`000000oooo
0?ooo`0R0?ooo`80003oM`3oool00900oooo00<000000?ooo`3oool0aP3o
ool50000oal0oooo00<000000?ooo`3oool0703oool60000ogT0oooo002@
0?ooo`030000003oool0oooo0</0oooo0`000?lL0?ooo`030000003oool0
oooo01T0oooo0`000?mo0?ooo`00T03oool00`000000oooo0?ooo`3>0?oo
o`H0003o5P3oool00`000000oooo0?ooo`0C0?ooo`H0003oPP3oool008T0
oooo100000030?ooo`030000003oool0oooo0=@0oooo1P000?l@0?ooo`03
0000003oool0oooo00d0oooo1P000?n80?ooo`00R@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0=X0oooo2@000?l70?ooo`030000
003oool0oooo00D0oooo20000?n>0?ooo`00RP3oool00`000000oooo0?oo
o`030?ooo`800000i03oool?0000oiH0oooo002;0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0jP3oool00`000000oooo0?ooo`2K
0?ooo`00R@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo0>X0oooo00<000000?ooo`3oool0V`3oool008X0oooo0P0000040?oo
o`030000003oool0oooo0>X0oooo00<000000?ooo`3oool0V`3oool00900
oooo00<000000?ooo`3oool0jP3oool00`000000oooo0?ooo`2K0?ooo`00
T03oool00`000000oooo0?ooo`3o0?ooohT0oooo002@0?ooo`030000003o
ool0oooo0?l0ooooR@3oool00?l0ooooo`3ooolM0?ooo`00o`3ooooo0?oo
oad0oooo003o0?ooool0oooo7@3oool00?l0ooooo`3ooolM0?ooo`00o`3o
oooo0?oooad0oooo003o0?ooool0oooo7@3oool008h0oooo0P00003[0?oo
o`800000WP3oool008l0oooo00<000000?ooo`3oool0jP3oool00`000000
oooo0?ooo`2L0?ooo`00T03oool00`000000oooo0?ooo`3Z0?ooo`030000
003oool0oooo09/0oooo002?0?ooo`030000003oool000000>X0oooo00<0
00000?ooo`000000W03oool008h0oooo00@000000?ooo`3oool00000j@3o
ool010000000oooo0?ooo`00002L0?ooo`00S@3oool3000000030?ooo`00
000000000>L0oooo0`0000000`3oool000000000002K0?ooo`00o`3ooooo
0?oooad0oooo003o0?ooool0oooo7@3oool00?l0ooooo`3ooolM0?ooo`00
o`3ooooo0?oooad0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{539, 165},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The integrand  \n\n\t\t\t",
  Cell[BoxData[{
      \(f \((z)\)\ \  = \ \ \(\(P \((z)\)\)\/\(Q \((z)\)\)\ \  = \ \ \
z\/\(z\^3 - 8\)\)\ \ \), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(z\/\(\((z - 2)\) \((z\^2 + 
                  2\ z + 4)\)\)\)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(z\/\(\((z - 2)\) \((z + 
                  1 + \[ImaginaryI]\ \@3)\) \((z + 
                  1 - \[ImaginaryI]\ \@3)\)\)\)\)\)}]],
  "  \n\nhas simple poles at the points  ",
  Cell[BoxData[
      \(t\_1 = 2\)]],
  "  on the ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " axis and  ",
  Cell[BoxData[
      \(z\_1 = \(-1\) + \[ImaginaryI]\ \@3\)]],
  "  in the upper half-plane.  Computing the residues we get\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, 
          2]\ \  = \ \ \(lim\+\(z\  \[Rule] 2\)\ \((z - 2)\) 
              f \((z)\)\ \  = \ \ lim\+\(z\  \[Rule] 2\)\ \((z - 2)\) 
              z\/\(\((z - 2)\) \((z\^2 + 2\ z + 4)\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] 2\)\ 
            z\/\((z\^2 + 2\ z + 4)\)\ \  = \ \ \(2\/\((2\^2 + 2\[Cross]2 + 4)\
\)\ \  = \ \ 2\/\((4 + 4 + 4)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1\/6\)\)\
\)}]],
  "  \n\t\t\t\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[
          f, \(-1\) + \[ImaginaryI]\ \@3]\ \  = \ \ lim\+\(z\  \[Rule] \(-1\) \
+ \[ImaginaryI]\ \@3\)\ \((z + 1 - \[ImaginaryI]\ \@3)\) 
            f \((z)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(\(\(=\)\(\ \ \)\(lim\+\(z\  \[Rule] \(-1\) + \[ImaginaryI]\ \@3\)\
\ \((z + 1 - \[ImaginaryI]\ \@3)\) 
            z\/\(\((z - 2)\) \((z + 1 + \[ImaginaryI]\ \@3)\) \((z + 1 - \
\[ImaginaryI]\ \@3)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(\(\(=\)\(\ \ \)\(lim\+\(z\  \[Rule] \(-1\) + \[ImaginaryI]\ \@3\)\
\ z\/\(\((z - 2)\) \((z + 1 + \[ImaginaryI]\ \
\@3)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(\(\(=\)\(\ \ \ \)\(\(\(-1\) + \[ImaginaryI]\ \@3\)\/\(\((\(-1\) + \
\[ImaginaryI]\ \@3 - 2)\) \((\(-1\) + \[ImaginaryI]\ \@3 + 1 + \[ImaginaryI]\ \
\@3)\)\)\ \  = \ \ \(\(-1\) + \[ImaginaryI]\ \@3\)\/\(\((\(-3\) + \
\[ImaginaryI]\ \@3)\) \((2\ \[ImaginaryI]\ \
\@3)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(\(-1\) + \[ImaginaryI]\ \@3\)\/\(\(-6\) - 6\ \
\[ImaginaryI]\ \@3\)\ \  = \ \ \(\(\((\(-1\) + \[ImaginaryI]\ \@3)\) \
\((\(-6\) + 6\ \[ImaginaryI]\ \@3)\)\)\/\(\((\(-6\) - 6\ \[ImaginaryI]\ \
\@3)\) \((\(-6\) + 6\ \[ImaginaryI]\ \@3)\)\)\ \  = \ \ \(\(-12\) - 12\ \
\[ImaginaryI]\ \@3\)\/144\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(\(=\)\(\ \ \)\(\(\(-1\) - \ \[ImaginaryI]\ \@3\)\/12\)\)\)}]]
}], "Text"],

Cell[TextData[{
  "By Theorem 8.5,  \n\n\t\t\t",
  Cell[BoxData[{
      \(\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\!\(x\/\(x\
\^3 - 8\)\)\[DifferentialD]x\>\""\ \  = \ \ 2  \[Pi]\ \[ImaginaryI]\ Res[
              P\/Q, z\_1]\  + \ \[Pi]\ \[ImaginaryI]\ Res[P\/Q, 
              t\_1]\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\
\(\ \ \)\(2  \[Pi]\ \[ImaginaryI]\ \((\(\(-1\) - \ \[ImaginaryI]\ \
\@3\)\/12)\)\  + \ \[Pi]\ \[ImaginaryI]\ \((1\/6)\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\
\(\ \ \)\(\[Pi]\ \[ImaginaryI]\ \((\(\(-1\) - \ \[ImaginaryI]\ \@3\)\/6)\)\  \
+ \ \[Pi]\ \[ImaginaryI]\ \((1\/6)\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\
\(\ \ \)\(\[Pi]\ \[ImaginaryI]\ \((\(\(-\ \[ImaginaryI]\)\ \@3\)\/6)\)\)\)\ \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\
\(\ \ \)\(\(\[Pi] \@ 3\)\/6\)\)\)}]],
  "    "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.20.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function and  ",
  Cell[BoxData[
      \(f[z] = z\/\(z\^3\  - \ 8\)\)],
    AspectRatioFixed->True],
  "  and ",
  "locate the",
  " singularities."
}], "Text"],

Cell[BoxData[{
    \(Z = \(z = \(x = 0\)\); \ Remove[x, z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, Res1, Res2, solset, val];\)\ \), "\n", 
    \(\(f[z_]\  = \ z\/\(z\^3\  - \ 8\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[Denominator[f[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, 
            z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The singularities are\>"];\)\ \), "\n", 
    \(\(Z\_1\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        ComplexExpand[
          ReplaceAll[z, 
            solset\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)\
]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2];\)\ \), "\n", 
    \(\(Z\_3\  = \ 
        ComplexExpand[
          ReplaceAll[z, 
            solset\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)\
]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", 
        Z\_3];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell["\<\
Which poles lie in the upper half plane ?  Which poles lie on the real axis ?\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Magenta, PointSize[0.03], 
              Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, PointSize[0.03], 
              Point[{Re[Z\_2], Im[Z\_2]}]}, {Red, PointSize[0.03], 
              Point[{Re[Z\_3], Im[Z\_3]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] + 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] - 0.1}, {\(-1\), 
                0}], Text[\*"\"\<\!\(z\_3\)\>\"", {Re[Z\_3], 
                Im[Z\_3] - 0.1}, {\(-1\), 0}]}];\)\ \), "\n", 
    \(\(Show[dots, centers, 
        PlotRange \[Rule] {{\(-2.2\), 2.2}, {\(-2.2\), 2.2}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<,         Is  Im(\>", 
        Z\_1, "\<) > 0 ?         \>", N[Im[Z\_1]] > 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<, Is  Im(\>", 
        Z\_2, "\<) > 0 ?  \>", 
        N[Im[Z\_2]] > 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3, "\<, Is  Im(\>", 
        Z\_3, "\<) > 0 ?  \>", 
        N[Im[Z\_3]] > 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<,         Is  Im(\>", 
        Z\_1, "\<) = 0 ?         \>", N[Im[Z\_1]] \[Equal] 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<, Is  Im(\>", 
        Z\_2, "\<) = 0 ?  \>", N[Im[Z\_2]] \[Equal] 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3, "\<, Is  Im(\>", 
        Z\_3, "\<) = 0 ?  \>", 
        N[Im[Z\_3]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Compute the residues at  ",
  Cell[BoxData[
      \(z\_1 = \(2\ \ and\ \ z\_3 = \(-1\) + \[ImaginaryI]\ \@3\)\)]],
  ",  and use the residue calculus to compute the value of the integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Res1\  = \ Residue[f[z], {z, Z\_1}];\)\ \), "\n", 
    \(\(Res3\  = \ Residue[f[z], {z, Z\_3}];\)\ \), "\[IndentingNewLine]", 
    \(\(val\  = \ 
        2\ \[Pi]\ \[ImaginaryI]\ \ Res3 + \[Pi]\ \[ImaginaryI]\ \ Res1;\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", Z\_1, "\<] = \>", Res1];\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_3, "\<] = \>", 
        Res3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", Z\_3, "\<] = \>", 
        ComplexExpand[Res3]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Magenta, PointSize[0.03], 
              Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, PointSize[0.03], 
              Point[{Re[Z\_3], Im[Z\_3]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] - 0.2}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_3\)\>\"", {Re[Z\_3], Im[Z\_3]}, {\(-1.2\), 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ 
        Graphics[{{Blue, Circle[{0, 0}, 3, {0, \[Pi]}]}, {Blue, 
              Circle[{Re[Z\_1], Im[Z\_1]}, 
                0.2, {0, \[Pi]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(segment = 
        Graphics[{Thickness[0.015], Cyan, 
            Line[{{\(-3\), 0}, {3, 0}}]}];\)\ \), "\n", 
    \(\(Show[centers, contour, segment, dots, 
        PlotRange \[Rule] {{\(-3.1\), 3.1}, {\(-0.05\), 3.05}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 2, 1]}, 
        AspectRatio \[Rule] 1\/2, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>", 
        ComplexExpand[Res3]\ , "\<) + \[Pi]\[ImaginaryI](\>", \ 
        Res1\ , "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = \[Pi]\[ImaginaryI](\>", 
        2\ ComplexExpand[Res3]\  + \ 
          Res1\ , "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = \>", 
        ComplexExpand[val]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The indented contour is the semicircle \!\(C\_R\) \
portions of [-R,R],\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and a little indent semicircle around the pole on the \
x-axis,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<taken with the positive orientation.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value \
of the integral.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"\
", f[x], "\< \[DifferentialD]x = \>", 
        ComplexExpand[val]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"\
", f[x], "\< \[DifferentialD]x = \>", 
        Chop[N[val]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.21.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Evaluate  ",
  Cell[BoxData[
      \("P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\!\(t\/\(t\^3 - \
8\)\)\[DifferentialD]t"\)]],
  "  by using a computer algebra system.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005f0000YB000`400?l0
0000o`00003oo`3ooomg0?ooo`00o`3ooomg0?ooo`00o`3ooomg0?ooo`00
o`3ooomg0?ooo`00o`3ooomg0?ooo`00o`3ooomg0?ooo`00o`3ooomg0?oo
o`00o`3ooomg0?ooo`00dP3oool200000:80oooo00390?ooo`<000001P3o
ool2000000D0oooo0P00002K0?ooo`00bP3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`070?ooo`030?l0o`3oool0oooo0880oooo0037
0?ooo`D000000`3oool01@000000oooo0000003oool0000000H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030?l0o`3o
ool0oooo0880oooo00370?ooo`040000003oool0oooo000000D0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01`3oool00`3o0?l0oooo0?ooo`220?ooo`00b03o
ool00`000000oooo000000090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo
00<0o`3o0?ooo`3oool0PP3oool00<T0oooo0P0000090?ooo`030000003o
ool0oooo0080oooo0P00000<0?ooo`030000003oool0oooo00L0oooo00<0
o`3o0?ooo`3oool0PP3oool00=D0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`070?ooo`030?l0o`3oool0oooo0880oooo003E0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`3o
0?l0oooo0?ooo`220?ooo`00e@3oool:000000P0oooo0P0000080?ooo`03
0?l0o`3oool0oooo0880oooo003W0?ooo`030000003oool0oooo00L0oooo
00<0o`3o0?ooo`3oool0PP3oool00;d0oooo100000030?oooa00000000<0
oooo0000000000001P0000000`3oool00000000000070?ooo`030000003o
ool0oooo00L0oooo00<0o`3o0?ooo`3oool0PP3oool00>L0oooo00<00000
0?ooo`3oool01`3oool00`3o0?l0oooo0?ooo`220?ooo`00i`3oool00`00
0000oooo0?ooo`070?ooo`030?l0o`3oool0oooo0880oooo003W0?ooo`03
0000003oool0oooo00L0oooo00<0o`3o0?ooo`3oool0PP3oool007h0oooo
103o0?m=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`070?ooo`030?l0o`3oool0oooo0880oooo
00220?ooo`T0o`3oA@3oool010000000oooo0?ooo`00000C0?ooo`030000
003oool0oooo00L0oooo00<0o`3o0?ooo`3oool0PP3oool008/0oooo2@3o
0?lm0?ooo`030000003oool0000001<0oooo00<000000?ooo`3oool01`3o
ool00`3o0?l0oooo0?ooo`220?ooo`00U03oool90?l0oc@0oooo00<00000
0?ooo`0000004`3oool00`000000oooo0?ooo`070?ooo`030?l0o`3oool0
oooo0880oooo002M0?ooo`T0o`3o:P3oool500000180oooo00<000000?oo
o`3oool01`3oool00`3o0?l0oooo0?ooo`220?ooo`00YP3oool60?l0oc/0
oooo00<000000?ooo`3oool01`3oool00`3o0?l0oooo0?ooo`220?ooo`00
[03oool40?l0ocL0oooo00<000000?ooo`3oool01`3oool00`3o0?l0oooo
0?ooo`220?ooo`00/03oool40?l0oc<0oooo00<000000?ooo`3oool01`3o
ool00`3o0?l0oooo0?ooo`220?ooo`00]03oool40?l0obl0oooo00<00000
0?ooo`3oool01`3oool00`3o0?l0oooo0?ooo`220?ooo`00^03oool20?l0
obd0oooo00<000000?ooo`3oool01`3oool00`3o0?l0oooo0?ooo`220?oo
o`00^P3oool30?l0obX0oooo00<000000?ooo`3oool01`3oool20?l0oh<0
oooo002m0?ooo`80o`3o:03oool00`000000oooo0?ooo`070?ooo`80o`3o
P`3oool00;l0oooo0P3o0?lV0?ooo`030000003oool0oooo00L0oooo0P3o
0?n30?ooo`00`@3oool20?l0ob@0oooo00<000000?ooo`3oool01`3oool2
0?l0oh<0oooo00330?ooo`80o`3o8P3oool00`000000oooo0?ooo`070?oo
o`80o`3oP`3oool00<D0oooo00<0o`3o0?ooo`3oool07`3oool00`000000
oooo0?ooo`070?ooo`80o`3oP`3oool00<H0oooo0P3o0?lO0?ooo`030000
003oool0oooo00L0oooo0P3o0?n30?ooo`00b03oool00`3o0?l0oooo0?oo
o`0L0?ooo`030000003oool0oooo00L0oooo0P3o0?n30?ooo`00b@3oool0
0`3o0?l0oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo0P3o0?n3
0?ooo`00bP3oool20?l0oa/0oooo00<000000?ooo`3oool01P3oool00`3o
0?l0oooo0?l0o`230?ooo`00c03oool00`3o0?l0oooo0?ooo`0H0?ooo`03
0000003oool0oooo00H0oooo00<0o`3o0?ooo`3o0?l0P`3oool00<d0oooo
00<0o`3o0?ooo`3oool05`3oool00`000000oooo0?ooo`060?ooo`030?l0
o`3oool0o`3o08<0oooo003>0?ooo`030?l0o`3oool0oooo01H0oooo00<0
00000?ooo`3oool01P3oool00`3o0?l0oooo0?l0o`230?ooo`00c`3oool0
0`3o0?l0oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo00<0o`3o
0?ooo`3o0?l0P`3oool00<l0oooo00<0o`3o0?ooo`3oool05@3oool00`00
0000oooo0?ooo`060?ooo`030?l0o`3oool0o`3o08<0oooo003@0?ooo`03
0?l0o`3oool0oooo01@0oooo00<000000?ooo`3oool01P3oool00`3o0?l0
oooo0?l0o`230?ooo`00d@3oool00`3o0?l0oooo0?ooo`0C0?ooo`030000
003oool0oooo00H0oooo00<0o`3o0?ooo`3o0?l0P`3oool00=80oooo00<0
o`3o0?ooo`3oool04P3oool00`000000oooo0?ooo`060?ooo`030?l0o`3o
ool0o`3o08<0oooo003B0?ooo`030?l0o`3oool0oooo0180oooo00<00000
0?ooo`3oool01P3oool00`3o0?l0oooo0?l0o`230?ooo`00d`3oool00`3o
0?l0oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo00<0o`3o0?oo
o`3o0?l0P`3oool00=<0oooo00<0o`3o0?ooo`3oool04@3oool00`000000
oooo0?ooo`060?ooo`030?l0o`3oool0o`3o08<0oooo003D0?ooo`030?l0
o`3oool0oooo0100oooo00<000000?ooo`3oool01P3oool00`3o0?l0oooo
0?l0o`230?ooo`00e03oool00`3o0?l0oooo0?ooo`0@0?ooo`030000003o
ool0oooo00H0oooo00<0o`3o0?ooo`3o0?l0P`3oool00=D0oooo00<0o`3o
0?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`030?l0o`3oool0
o`3o08<0oooo003F0?ooo`030?l0o`3oool0oooo00h0oooo00<000000?oo
o`3oool01P3oool00`3o0?l0oooo0?l0o`230?ooo`00eP3oool00`3o0?l0
oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<0o`3o0?ooo`3o
0?l0P`3oool00=L0oooo00<0o`3o0?ooo`3oool03@3oool00`000000oooo
0?ooo`060?ooo`030?l0o`3oool0o`3o08<0oooo003G0?ooo`030?l0o`3o
ool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`3o0?l0oooo0?l0
o`230?ooo`00f03oool00`3o0?l0oooo0?ooo`0<0?ooo`030000003oool0
oooo00H0oooo00<0o`3o0?ooo`3o0?l0P`3oool00=P0oooo00<0o`3o0?oo
o`3oool0303oool00`000000oooo0?ooo`060?ooo`030?l0o`3oool0o`3o
08<0oooo003I0?ooo`030?l0o`3oool0oooo00/0oooo00<000000?ooo`3o
ool01@3oool0103o0?l0oooo0?ooo`3o0?n30?ooo`00f@3oool00`3o0?l0
oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00D0o`3o0?ooo`3o
ool0oooo0?l0o`220?ooo`00f@3oool00`3o0?l0oooo0?ooo`0;0?ooo`03
0000003oool0oooo00D0oooo00D0o`3o0?ooo`3oool0oooo0?l0o`220?oo
o`00fP3oool00`3o0?l0oooo0?ooo`0:0?ooo`030000003oool0oooo00D0
oooo00D0o`3o0?ooo`3oool0oooo0?l0o`220?ooo`00fP3oool00`3o0?l0
oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00D0o`3o0?ooo`3o
ool0oooo0?l0o`220?ooo`00O03oool4000000<0oooo0P00000[0?ooo`D0
00000P3oool200000240oooo00<0o`3o0?ooo`3oool02P3oool00`000000
oooo0?ooo`050?ooo`050?l0o`3oool0oooo0?ooo`3o0?l08P3oool50000
0080oooo0P00000[0?ooo`@000000`3oool2000002<0oooo001l0?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool00000;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool07`3oool0
0`3o0?l0oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00D0o`3o
0?ooo`3oool0oooo0?l0o`0T0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000008P3oool007d0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0O0?ooo`030?l0o`3oool0oooo
00T0oooo00<000000?ooo`3oool01@3oool01@3o0?l0oooo0?ooo`3oool0
o`3o02@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00000R0?ooo`00MP3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0280oooo100000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0O0?ooo`03
0?l0o`3oool0oooo00T0oooo00<000000?ooo`3oool01@3oool01@3o0?l0
oooo0?ooo`3oool0o`3o02@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo02X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0200oooo001l0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000;03oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0803oool00`3o0?l0
oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00D0o`3o0?ooo`3o
ool0oooo0?l0o`0T0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0X0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000008P3oool007d0oooo0P0000040?ooo`800000;03o
ool2000000@0oooo0P00000S0?ooo`030?l0o`3oool0oooo00P0oooo00<0
00000?ooo`3oool01@3oool00`3o0?l0oooo0?ooo`020?ooo`030?l0o`3o
ool0oooo0200oooo0P0000040?ooo`800000;03oool2000000@0oooo0P00
000S0?ooo`00g03oool00`3o0?l0oooo0?ooo`080?ooo`030000003oool0
oooo00D0oooo00<0o`3o0?ooo`3oool00P3oool00`3o0?l0oooo0?ooo`1o
0?ooo`00g03oool00`3o0?l0oooo0?ooo`080?ooo`030000003oool0oooo
00@0oooo00<0o`3o0?ooo`3oool00`3oool00`3o0?l0oooo0?ooo`1o0?oo
o`00g@3oool00`3o0?l0oooo0?ooo`070?ooo`030000003oool0oooo00@0
oooo00<0o`3o0?ooo`3oool00`3oool00`3o0?l0oooo0?ooo`1o0?ooo`00
g@3oool00`3o0?l0oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo
00<0o`3o0?ooo`3oool00`3oool00`3o0?l0oooo0?ooo`1U0?ooo`800000
00<0oooo0000000000005@3oool007P0ooooI@0000000`3o0?l000000000
000>000000030?l0o`000000000000<0000000<0o`3o000000000000G`00
00070?ooo`030000003oool0000001H0oooo001n0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0:@3oool00`3o0?l0oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<0o`3o0?ooo`3oool00`3oool0
0`3o0?l0oooo0?ooo`0T0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0E0?ooo`00OP3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo02T0oooo00<0o`3o0?oo
o`3oool01P3oool00`000000oooo0?ooo`040?ooo`030?l0o`3oool0oooo
00@0oooo00<0o`3o0?ooo`3oool08`3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo00X0oooo0P0000000`3oool000000000000E0?oo
o`00gP3oool00`3o0?l0oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<0o`3o0?ooo`3oool0103oool00`3o0?l0oooo0?ooo`1n0?ooo`00
g`3oool00`3o0?l0oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<0o`3o0?ooo`3oool0103oool00`3o0?l0oooo0?ooo`1n0?ooo`00g`3o
ool00`3o0?l0oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0
o`3o0?ooo`3oool01@3oool00`3o0?l0oooo0?ooo`1n0?ooo`00g`3oool0
0`3o0?l0oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0o`3o
0?ooo`3oool01@3oool00`3o0?l0oooo0?ooo`1n0?ooo`00g`3oool00`3o
0?l0oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0o`3o0?oo
o`3oool01@3oool00`3o0?l0oooo0?ooo`1n0?ooo`00h03oool00`3o0?l0
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0o`3o0?ooo`3o
ool01@3oool00`3o0?l0oooo0?ooo`1n0?ooo`00h03oool00`3o0?l0oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<0o`3o0?ooo`3oool0
1`3oool00`3o0?l0oooo0?ooo`1m0?ooo`00h03oool00`3o0?l0oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00<0o`3o0?ooo`3oool01`3o
ool00`3o0?l0oooo0?ooo`1m0?ooo`00h03oool00`3o0?l0oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<0o`3o0?ooo`3oool01`3oool0
0`3o0?l0oooo0?ooo`1m0?ooo`00h@3oool00`3o0?l0oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<0o`3o0?ooo`3oool01`3oool00`3o
0?l0oooo0?ooo`1m0?ooo`00h@3oool00`3o0?l0oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<0o`3o0?ooo`3oool01`3oool00`3o0?l0
oooo0?ooo`1m0?ooo`00h@3oool00`3o0?l0oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`3o0?l02`3oool00`3o0?l0oooo0?ooo`1l0?ooo`00
hP3oool00`3o0?l0oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`3o
0?l02`3oool00`3o0?l0oooo0?ooo`1l0?ooo`00hP3oool00`3o0?l0oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`3o0?l02`3oool00`3o0?l0
oooo0?ooo`1l0?ooo`00h`3oool01@3o0?l0oooo0?ooo`3oool000000080
oooo00<0o`3o0?ooo`3oool02P3oool00`3o0?l0oooo0?ooo`1l0?ooo`00
h`3oool01`3o0?l0oooo0?ooo`3oool000000?ooo`3o0?l03P3oool00`3o
0?l0oooo0?ooo`1k0?ooo`00i03oool01P3o0?l0oooo0?ooo`000000oooo
0?l0o`h0oooo00<0o`3o0?ooo`3oool0N`3oool00>D0oooo00@0o`3o0?oo
o`000000o`3o3`3oool00`3o0?l0oooo0?ooo`1k0?ooo`00iP3oool30?l0
oa00oooo00<0o`3o0?ooo`3oool0NP3oool00>L0oooo00<000000?ooo`3o
ool03`3oool00`3o0?l0oooo0?ooo`1j0?ooo`00i`3oool00`000000oooo
0?ooo`0?0?ooo`030?l0o`3oool0oooo07X0oooo003W0?ooo`030000003o
ool0oooo0100oooo00<0o`3o0?ooo`3oool0N@3oool00>L0oooo00<00000
0?ooo`3oool0403oool00`3o0?l0oooo0?ooo`1i0?ooo`00i`3oool00`00
0000oooo0?ooo`0@0?ooo`030?l0o`3oool0oooo07T0oooo003W0?ooo`03
0000003oool0oooo0140oooo00<0o`3o0?ooo`3oool0N03oool00>L0oooo
00<000000?ooo`3oool04@3oool00`3o0?l0oooo0?ooo`1h0?ooo`00i`3o
ool00`000000oooo0?ooo`0B0?ooo`030?l0o`3oool0oooo07L0oooo003W
0?ooo`030000003oool0oooo01<0oooo00<0o`3o0?ooo`3oool0MP3oool0
0>L0oooo00<000000?ooo`3oool0503oool00`3o0?l0oooo0?ooo`1e0?oo
o`00i`3oool00`000000oooo0?ooo`0E0?ooo`030?l0o`3oool0oooo07@0
oooo003W0?ooo`030000003oool0oooo01H0oooo00<0o`3o0?ooo`3oool0
L`3oool00>L0oooo00<000000?ooo`3oool05P3oool00`3o0?l0oooo0?oo
o`1c0?ooo`00i`3oool00`000000oooo0?ooo`0G0?ooo`030?l0o`3oool0
oooo0780oooo003W0?ooo`030000003oool0oooo01P0oooo00<0o`3o0?oo
o`3oool0L@3oool00>L0oooo00<000000?ooo`3oool06@3oool00`3o0?l0
oooo0?ooo`1`0?ooo`00i`3oool00`000000oooo0?ooo`0J0?ooo`030?l0
o`3oool0oooo06l0oooo003W0?ooo`030000003oool0oooo01/0oooo00<0
o`3o0?ooo`3oool0KP3oool00>L0oooo00<000000?ooo`3oool0703oool2
0?l0ofh0oooo003W0?ooo`030000003oool0oooo01h0oooo0P3o0?m/0?oo
o`00i`3oool00`000000oooo0?ooo`0P0?ooo`030?l0o`3oool0oooo06T0
oooo003W0?ooo`030000003oool0oooo0240oooo0P3o0?mY0?ooo`00i`3o
ool00`000000oooo0?ooo`0S0?ooo`80o`3oI`3oool00>L0oooo00<00000
0?ooo`3oool09@3oool20?l0ofD0oooo003W0?ooo`030000003oool0oooo
02L0oooo103o0?mQ0?ooo`00i`3oool00`000000oooo0?ooo`0[0?ooo`@0
o`3oG@3oool00>L0oooo00<000000?ooo`3oool0;`3oool40?l0oeT0oooo
003W0?ooo`030000003oool0oooo03<0oooo103o0?mE0?ooo`00i`3oool0
0`000000oooo0?ooo`0g0?ooo`D0o`3oD03oool00>L0oooo00<000000?oo
o`3oool0?03oool40?l0od`0oooo003W0?ooo`030000003oool0oooo0400
oooo1`3o0?m50?ooo`00i`3oool00`000000oooo0?ooo`170?ooo`T0o`3o
?03oool00=80oooo0P00000C0?ooo`030000003oool0oooo0500oooo2@3o
0?lc0?ooo`00b@3oool3000000H0oooo0P0000050?ooo`800000303oool0
0`000000oooo0?ooo`1I0?ooo`d0o`3o9P3oool00<X0oooo00<000000?oo
o`3oool0103oool00`000000oooo000000040?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`3oool0S03oool00<L0oooo1@0000030?oo
o`050000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo08`0oooo00370?ooo`040000003oool0oooo
000000D0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0S03oool00<P0oooo00<00000
0?ooo`0000002@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`2<0?ooo`00b@3oool2
000000T0oooo00<000000?ooo`3oool00P3oool2000000`0oooo00<00000
0?ooo`3oool0S03oool00=D0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`2<0?ooo`00e@3oool00`000000oooo0?ooo`0?0?ooo`80
0000S@3oool00=D0oooo2P0000080?ooo`030000003oool0oooo08`0oooo
00340?oooa00000000<0oooo0000000000001P0000000`3oool000000000
00070?ooo`030000003oool0oooo08`0oooo003W0?ooo`030000003oool0
oooo08`0oooo003W0?ooo`030000003oool0oooo08`0oooo003W0?ooo`03
0000003oool0oooo08`0oooo003W0?ooo`030000003oool0oooo08`0oooo
003?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0W`3o
ool00=00oooo00@000000?ooo`3oool00000XP3oool00=40oooo00<00000
0?ooo`000000XP3oool00=40oooo00<000000?ooo`000000XP3oool00=00
oooo1@00002Q0?ooo`00o`3ooomg0?ooo`00o`3ooomg0?ooo`00o`3ooomg
0?ooo`00o`3ooomg0?ooo`00o`3ooomg0?ooo`00i@3oool3000008h0oooo
003X0?ooo`030000003oool0oooo08/0oooo003U0?ooo`<00000SP3oool0
0>D0oooo1000002=0?ooo`00o`3ooomg0?ooo`00o`3ooomg0?ooo`00o`3o
oomg0?ooo`00o`3ooomg0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{374, 165},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  Computer algebra systems such as Mathematica or MAPLE give the \
indefinite integral   \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\(t\/\(t\^3 - 
                  8\)\) \[DifferentialD]t\ \  = \ \ \(\(Arctan \((\(1 + t\)\/\
\@3)\)\)\/\(2\ \@3\)\  + \ \(Log \((t - 2)\)\)\/6\ \  - \ \(Log \((t\^2 + 2\ \
t + 4)\)\)\/12\ \ \  = \ \ g \((t)\)\)\)]],
  ".  \n\nHowever, for real numbers, we should write the second term as  ",
  Cell[BoxData[
      \(Log[\((t - 2)\)\^2]\/12\)]],
  "  and use the equivalent formula:  \n\n\t\t\t",
  Cell[BoxData[{
      \(\ \(\(g \((t)\)\ \  = \ \ \(Arctan \((\(1 + t\)\/\@3)\)\)\/\(2\ \@3\)\
\  + \ Log[\((t - 2)\)\^2]\/12\ \  - \ \(Log \((t\^2 + 2\ t + 4)\)\)\/12\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(Arctan \((\(1 + \
t\)\/\@3)\)\)\/\(2\ \@3\)\  + \ Log[\((t - 2)\)\^2]\/12\ \  - \ 
          Log[\((t + 2)\)\^2]\/12\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(Arctan \((\(1 + \
t\)\/\@3)\)\)\/\(2\ \@3\)\ \ \  + \ \ 1\/12\ \ Log[\((t - 2)\)\^2\/\((t + \
2)\)\^2]\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(Arctan \((\(1 + \
t\)\/\@3)\)\)\/\(2\ \@3\)\ \ \  + \ \ 1\/12\ \ Log[\((\(t - 2\)\/\(t + 2\))\)\
\^2]\)\)\)}]],
  "    \n"
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 8.5",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/integralsindentedcontour/\
IntegralsIndentedContourFigures/mat0805.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Graph of  ",
  Cell[BoxData[
      \(s\  = \ \(g \((t)\)\  = \ \[Integral]\(t\/\(t\^3 - 
                    8\)\) \[DifferentialD]t\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThis antiderivative has the property that  ",
  Cell[BoxData[
      \(lim\_\(t \[Rule] 2\)\ g \((t)\)\  = \ \(-\[Infinity]\)\)]],
  ",  as shown in Figure 8.5.  We also compute  \n\n\t\t\t",
  Cell[BoxData[{
      \(lim\_\(t \[Rule] \[Infinity]\)\ 
          g \((t)\)\ \  = \ \ lim\_\(t \[Rule] \[Infinity]\)\ \((\ \(Arctan \
\((\(1 + t\)\/\@3)\)\)\/\(2\ \@3\)\ \ \  + \ \ 1\/12\ \ Log[\((\(t - 2\)\/\(t \
+ 2\))\)\^2])\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\
\(lim\_\(t \[Rule] \[Infinity]\)\ \ \(Arctan \((\(1 + t\)\/\@3)\)\)\/\(2\ \@3\
\)\  + lim\_\(t \[Rule] \[Infinity]\)\ 
            1\/12\ \ Log[\((1 - 4\/\(t + 2\))\)\^2]\)\)\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\
\(\(\[Pi]\/2\)\/\(2\ \@3\)\  + \ 1\/12\ \ Log[\((1 - 0)\)\^2]\)\)\ \ \), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\
\(\(\[Pi] \@ 3\)\/\(\(12\)\(\ \)\)\)\)\)}]],
  "  \n\n\t\t\t",
  Cell[BoxData[{
      \(lim\_\(t \[Rule] \(-\[Infinity]\)\)\ 
          g \((t)\)\ \  = \ \ lim\_\(t \[Rule] \(-\[Infinity]\)\)\ \((\ \
\(Arctan \((\(1 + t\)\/\@3)\)\)\/\(2\ \@3\)\ \ \  + \ \ 1\/12\ \ Log[\((\(t - \
2\)\/\(t + 2\))\)\^2])\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \
\ \)\(lim\_\(t \[Rule] \(-\[Infinity]\)\)\ \ \(Arctan \((\(1 + \
t\)\/\@3)\)\)\/\(2\ \@3\)\ \ \  + 
          lim\_\(t \[Rule] \(-\[Infinity]\)\)\ \ 1\/12\ \ Log[\((1 - 4\/\(t + \
2\))\)\^2]\)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \
\ \)\(\(-\(\[Pi]\/2\)\)\/\(2\ \@3\)\  + \ 
          1\/12\ \ Log[\((1 - 0)\)\^2]\)\)\ \ \), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \
\ \)\(-\(\(\[Pi] \@ 3\)\/\(\(12\)\(\ \)\)\)\)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "The Cauchy principal limit at  ",
  Cell[BoxData[
      \(t = 2\)]],
  "  as  ",
  Cell[BoxData[
      \(r \[Rule] 0\)]],
  "  is  \n\n",
  Cell[BoxData[{
      \(\t\t\(\(lim\_\(r \[Rule] \(0\^+\)\)\ \((g \((2 + r)\) - 
              g \((2 - r)\))\)\  = \ 
        lim\_\(r \[Rule] \(0\^+\)\)\ \((\(ArcTan \( 3 + r\)\/\@3\)\/\(2\ \
\@3\) + \(Log  r\^2\/\((4 + r)\)\^2\)\/12\  - \(ArcTan \( 3 - r\)\/\@3\)\/\(2\
\ \@3\) - \(Log  r\^2\/\((4 - r)\)\^2\)\/12)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(\(\(=\)\(\ \)\(lim\_\(r \[Rule] \(0\^+\)\)\ \((\(ArcTan \( 3 + \
r\)\/\@3\)\/\(2\ \@3\) - \(ArcTan \( 3 - r\)\/\@3\)\/\(2\ \@3\) + 
              1\/12\ Log \((4 - r)\)\^2\/\((4 + r)\)\^2)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(ArcTan  3\/\@3\)\/\(2\ \@3\) - \(ArcTan  \
3\/\@3\)\/\(2\ \@3\) + 1\/12\ Log\ 1\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(\(=\)\(\ \ \)\(0\)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "Therefore the Cauchy principal value of the improper integral is  \n\n\t\t\
",
  Cell[BoxData[{
      \(P . 
          V . \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( 
                  t\/\(t\^3 - 
                    8\)\) \[DifferentialD]t\)\ \ \  = \ \ \ lim\+\(r\  \
\[Rule] \ \(0\^+\)\)\ \((\[Integral]\_\(-\[Infinity]\)\%\(2 - r\)\ \
\(t\/\(t\^3 - 
                        8\)\) \[DifferentialD]t\ \  + \ \ \[Integral]\_\(2 + \
r\)\%\[Infinity]\ \(t\/\(t\^3 - 
                        8\)\) \[DifferentialD]t)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(=\)\(\ \ \)\(lim\_\(t \[Rule] \[Infinity]\)\ g \((t)\)\  - \ 
          lim\_\(r \[Rule] \(0\^+\)\)\ \((g \((2 + r)\) - 
                g \((2 - r)\))\)\  - \ 
          lim\_\(t \[Rule] \(-\[Infinity]\)\)\ 
            g \((t)\)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(=\)\(\ \ \)\(\(\[Pi] \@ 3\)\/\(\(12\)\(\ \)\)\  - \ 
          0\  - \ \(\(-\[Pi]\) \@3\)\/\(\(12\)\(\ \)\)\)\)\[IndentingNewLine]\
\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(=\)\(\ \ \)\(\(\[Pi] \@ 3\)\/\(\(6\)\(\ \)\)\)\)\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.21.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function and  ",
  Cell[BoxData[
      \(f[z] = z\/\(z\^3\  - \ 8\)\)],
    AspectRatioFixed->True],
  "  and ",
  "locate the",
  " singularities."
}], "Text"],

Cell[BoxData[{
    \(Z = \(z = \(x = 0\)\); \ Remove[x, z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, Res1, Res2, solset, val];\)\ \), "\n", 
    \(\(f[z_]\  = \ z\/\(z\^3\  - \ 8\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Warning.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  The indefinite integral of f[x] is g[x], but it ",
  StyleBox["cannot",
    FontColor->RGBColor[1, 0, 1]],
  " be used in any meaningful way to solve the problem at hand."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(g[
          x_]\  = \[Integral]f[
              x] \[DifferentialD]x;\)\ \), "\[IndentingNewLine]", 
    \(\(lim1 = \ 
        Limit[g[x], x \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(lim2 = Limit[g[x], x \[Rule] \(-\[Infinity]\)];\)\ \), "\n", 
    \(\(Print["\<g[x] = \[Integral]\>", f[x], "\<\[DifferentialD]x = \>", 
        g[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< g[\[Infinity]] =  \!\(lim\+\(x \[Rule] \[Infinity]\)\) \
(\>\"", g[x], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< g[\[Infinity]] = \>", lim1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<g[-\[Infinity]] =  \!\(lim\+\(x \[Rule] \(-\[Infinity]\)\
\)\) (\>\"", g[x], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[-\[Infinity]] = \>", lim2];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    The following answer is suspect\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<because of singularities on the real axis.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<g[\[Infinity]] - g[-\[Infinity]] = \>", 
        lim1 - lim2];\)\ \), "\n", 
    \(\(Print["\<g[\[Infinity]] - g[-\[Infinity]] = \>", 
        ComplexExpand[lim1 - lim2]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[\[Infinity]] - g[-\[Infinity]] = \>", 
        N[lim1 - lim2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Warning.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  " The following computation will ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " produce the correct answer."
}], "Text"],

Cell[BoxData[{
    \(\(val\  = \[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[
              x] \[DifferentialD]x;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    The following answer is suspect\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<because of singularities on the real axis.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        N[val]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\n",
  StyleBox["Correction.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The indefinite integral of g[x] can be written in an algebraic form that \
will produce the correct answer for real functions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(g[
          x_]\  = \[Integral]f[
              x] \[DifferentialD]x;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \[Integral]\>", f[x], "\<\[DifferentialD]x = \>", 
        g[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(g[x_] = 
        ArcTan[\(1 + x\)\/\@3]\/\(2\ \@3\) + 
          1\/12\ Log[\((\(-2\) + x)\)\^2\/\(4 + 2\ x + x\^2\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(lim1 = \ 
        Limit[g[x], x \[Rule] \[Infinity]];\)\ \), "\[IndentingNewLine]", 
    \(\(lim2 = 
        Limit[g[x], 
          x \[Rule] \(-\[Infinity]\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The following version of g[x] will produce the correct \
result.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<g[x] = \[Integral]\>", f[x], "\<\[DifferentialD]x = \>", 
        g[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< g[\[Infinity]] =  \!\(lim\+\(x \[Rule] \[Infinity]\)\) \
(\>\"", g[x], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< g[\[Infinity]] = \>", lim1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<g[-\[Infinity]] =  \!\(lim\+\(x \[Rule] \(-\[Infinity]\)\
\)\) (\>\"", g[x], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[-\[Infinity]] = \>", lim2];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[g[x], {x, \(-20\), 20}, PlotRange \[Rule] {\(-0.5\), 0.5}, 
        AxesLabel \[Rule] {"\<x\>", "\<s\>"}, \[IndentingNewLine]PlotStyle \
\[Rule] Magenta, 
        Ticks \[Rule] {Range[\(-20\), 20, 10], 
            Range[\(-\[Pi]\)\/\(4\ \@3\), \[Pi]\/\(4\ \@3\), \[Pi]\/\(4\ \
\@3\)]}];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<g[x] = \>", g[x]]\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"\
", f[x], "\< \[DifferentialD]x = (\>", lim1, "\<) - (\>", 
        lim2, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"\
", f[x], "\< \[DifferentialD]x = \>", 
        lim1 - lim2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"\
", f[x], "\< \[DifferentialD]x = \>", 
        N[lim1 - lim2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Which is also the correct answer.", "Text"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in \"PrincipalValue\" option to evaluate this definite integral \
."
}], "Text"],

Cell[BoxData[{
    \(\(val\  = \ 
        Integrate[f[x], {x, \(-\[Infinity]\), \[Infinity]}, 
          PrincipalValue \[Rule] True];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"\
", f[x], "\< \[DifferentialD]x = \>", val, "\< = \>", 
        N[val]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Which is also the correct answer.", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.22.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \("P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\!\(\(sin\\ \
x\)\/\(\((x - 1)\) \((x\^2\\  + \\ 4)\)\)\)\[DifferentialD]x = \
\!\(\[Pi]\/5\)(Cos[1]-\!\(1\/\[ExponentialE]\^2\))"\)]],
  ".    "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008o0000YB000`400?l0
0000o`00003oo`3ooooo0?oood40oooo003o0?ooool0oooo@@3oool00?l0
ooooo`3ooom10?ooo`00o`3ooooo0?oood40oooo003o0?ooool0oooo@@3o
ool00900oooo00<000000?ooo`3oool0203oool500000?l0ooooX03oool0
0900oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`360?oo
o`D00000C03oool5000008<0oooo002@0?ooo`030000003oool0oooo0080
oooo1@0000030?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`230?ooo`00T03oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0b03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo08<0
oooo002@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`300?ooo`@00000103oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo08<0oooo00290?ooo`@000000P3o
ool30?l000H0oooo00@000000?ooo`3oool0oooo0P00003:0?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool0P`3oool008T0oooo00<0
00000?ooo`3oool00P3oool50?l000<0oooo00@000000?ooo`3oool00000
c@3oool2000004l0oooo0P0000250?ooo`00RP3oool010000000oooo0?oo
o`3oool50?l000<0oooo1@00003o0?ooojD0oooo00230?ooo`@00000103o
ool00`000000oooo0?ooo`050?l00?l0oooo[@3oool008T0oooo00@00000
0?ooo`3oool000000P3oool30?l00?l0oooo[P3oool008X0oooo0P000004
0?ooo`030000003oool0oooo0?l0oooo9@3oool30?l0ohD0oooo002@0?oo
o`030000003oool0oooo0?`0oooo00<000000?ooo`3oool0903oool50?l0
oeh0oooo0P0000000`3oool000000000000Q0?ooo`00T03oool00`000000
oooo0?ooo`1m0?oooj800?oo0`3oool70?l0o`@0ooooCP00ool<0?ooo`03
0000003oool000000280oooo002@0?ooo`030000003oool0oooo07X0oooo
0`00002R003oo`<000001`3o0?l4000004h00?oo100000090?ooo`030000
003oool0oooo0240oooo002@0?ooo`030000003oool0oooo07d0ooooXP00
ool30?ooo`L0o`3o103ooom>003oo`/0oooo0P0000000`3oool000000000
000Q0?ooo`00T03oool00`000000oooo0?ooo`1n0?ooo`030000o`3oool0
oooo07/0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`03
0?ooo`D0o`3o1@3oool00`000?l0oooo0?ooo`190?ooo`030000o`3oool0
oooo0300oooo002@0?ooo`030000003oool0oooo07h0oooo00<0003o0?oo
o`3oool0N`3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo
00<0oooo0`3o0?l60?ooo`030000o`3oool0oooo04T0oooo00<0003o0?oo
o`3oool0<03oool00900oooo00<000000?ooo`3oool0OP3oool00`000?l0
oooo0?ooo`1k0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`190?ooo`030000o`3oool0oooo0300
oooo002@0?ooo`030000003oool0oooo07h0oooo00<0003o0?ooo`3oool0
N`3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo00X0oooo
00<0003o0?ooo`3oool0BP3oool00`000?l0oooo0?ooo`0`0?ooo`00T03o
ool00`000000oooo0?ooo`1n0?ooo`030000o`3oool0oooo07/0oooo00<0
00000?ooo`3oool08@3oool00`000?l0oooo0?ooo`080?ooo`80003oC03o
ool00`000?l0oooo0?ooo`0`0?ooo`00T03oool00`000000oooo0?ooo`1n
0?ooo`030000o`3oool0oooo07/0oooo00<000000?ooo`3oool08P3oool2
0000o`H0oooo0P000?m>0?ooo`030000o`3oool0oooo0300oooo002@0?oo
o`030000003oool0oooo07h0oooo00<0003o0?ooo`3oool0N`3oool00`00
0000oooo0?ooo`0T0?ooo`H0003oD03oool00`000?l0oooo0?ooo`0`0?oo
o`00T03oool00`000000oooo0?ooo`1n0?ooo`030000o`3oool0oooo07/0
oooo00<000000?ooo`3oool0NP3oool00`000?l0oooo0?ooo`0`0?ooo`00
T03oool00`000000oooo0?ooo`1n0?ooo`030000o`3oool0oooo07/0oooo
00<000000?ooo`3oool0NP3oool00`000?l0oooo0?ooo`0`0?ooo`00T03o
ool00`000000oooo0?ooo`1o0?ooo`030000o`3oool0oooo07X0oooo00<0
00000?ooo`3oool0;`3oool2000004T0oooo00<0003o0?ooo`3oool0<03o
ool00900oooo00<000000?ooo`3oool0O`3oool00`000?l0oooo0?ooo`1j
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0AP3oool0
0`000?l0oooo0?ooo`0`0?ooo`00T03oool00`000000oooo0?ooo`1o0?oo
o`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0:03oool50000
00<0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0`0?oo
o`00T03oool00`000000oooo0?ooo`1o0?ooo`030000o`3oool0oooo07X0
oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool0<03oool00900
oooo00<000000?ooo`3oool0O`3oool00`000?l0oooo0?ooo`1j0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000170?ooo`030000o`3oool0oooo0340oooo002@0?ooo`030000
003oool0oooo07l0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
AP3oool00`000?l0oooo0?ooo`0a0?ooo`00T03oool00`000000oooo0?oo
o`1o0?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0:@3o
ool010000000oooo0?ooo`00001<0?ooo`030000o`3oool0oooo0340oooo
002@0?ooo`030000003oool0oooo0800oooo00<0003o0?ooo`3oool0N@3o
ool00`000000oooo0?ooo`0Y0?ooo`D00000B`3oool00`000?l0oooo0?oo
o`0a0?ooo`00T03oool00`000000oooo0?ooo`200?ooo`030000o`3oool0
oooo07T0oooo00<000000?ooo`3oool0N@3oool00`000?l0oooo0?ooo`0a
0?ooo`00T03oool00`000000oooo0?ooo`200?ooo`030000o`3oool0oooo
07T0oooo00<000000?ooo`3oool0N@3oool00`000?l0oooo0?ooo`0a0?oo
o`00T03oool00`000000oooo0?ooo`200?ooo`030000o`3oool0oooo07T0
oooo00<000000?ooo`3oool0N@3oool00`000?l0oooo0?ooo`0a0?ooo`00
T03oool00`000000oooo0?ooo`200?ooo`030000o`3oool0oooo07T0oooo
00<000000?ooo`3oool0N@3oool00`000?l0oooo0?ooo`0a0?ooo`00T03o
ool00`000000oooo0?ooo`210?ooo`030000o`3oool0oooo07P0oooo00<0
00000?ooo`3oool0N03oool00`000?l0oooo0?ooo`0b0?ooo`00R@3oool5
00000080oooo00<000000?ooo`3oool0P@3oool00`000?l0oooo0?ooo`1h
0?ooo`030000003oool0oooo07P0oooo00<0003o0?ooo`3oool0<P3oool0
08/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`210?oo
o`030000o`3oool0oooo07P0oooo00<000000?ooo`3oool0N03oool00`00
0?l0oooo0?ooo`0b0?ooo`00R`3oool00`000000oooo0?ooo`020?ooo`80
0000PP3oool00`000?l0oooo0?ooo`1h0?ooo`030000003oool0oooo07L0
oooo00<0003o0?ooo`3oool0<`3oool008<0oooo100000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0P@3oool00`000?l0oooo
0?ooo`1h0?ooo`030000003oool0oooo07L0oooo00<0003o0?ooo`3oool0
<`3oool008/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`210?ooo`030000o`3oool0oooo07P0oooo00<000000?ooo`3oool0M`3o
ool00`000?l0oooo0?ooo`0c0?ooo`00RP3oool2000000@0oooo00<00000
0?ooo`3oool0PP3oool00`000?l0oooo0?ooo`1g0?ooo`030000003oool0
oooo07L0oooo00<0003o0?ooo`3oool0<`3oool00900oooo00<000000?oo
o`3oool0PP3oool00`000?l0oooo0?ooo`1g0?ooo`030000003oool0oooo
07L0oooo00<0003o0?ooo`3oool0<`3oool00900oooo00<000000?ooo`3o
ool0PP3oool00`000?l0oooo0?ooo`1g0?ooo`030000003oool0oooo07L0
oooo00<0003o0?ooo`3oool0<`3oool00900oooo00<000000?ooo`3oool0
P`3oool00`000?l0oooo0?ooo`1f0?ooo`030000003oool0oooo07H0oooo
00<0003o0?ooo`3oool0=03oool00900oooo00<000000?ooo`3oool0P`3o
ool00`000?l0oooo0?ooo`1f0?ooo`030000003oool0oooo07H0oooo00<0
003o0?ooo`3oool0=03oool00900oooo00<000000?ooo`3oool0P`3oool0
0`000?l0oooo0?ooo`1f0?ooo`030000003oool0oooo07H0oooo00<0003o
0?ooo`3oool0=03oool00900oooo00<000000?ooo`3oool0Q03oool00`00
0?l0oooo0?ooo`1e0?ooo`030000003oool0oooo07D0oooo00<0003o0?oo
o`3oool0=@3oool00900oooo00<000000?ooo`3oool0Q03oool00`000?l0
oooo0?ooo`1e0?ooo`030000003oool0oooo07D0oooo00<0003o0?ooo`3o
ool0=@3oool00900oooo00<000000?ooo`3oool0Q03oool00`000?l0oooo
0?ooo`1e0?ooo`030000003oool0oooo07D0oooo00<0003o0?ooo`3oool0
=@3oool00900oooo00<000000?ooo`3oool0Q03oool00`000?l0oooo0?oo
o`1e0?ooo`030000003oool0oooo07@0oooo00<0003o0?ooo`3oool0=P3o
ool00900oooo00<000000?ooo`3oool0Q03oool00`000?l0oooo0?ooo`1e
0?ooo`030000003oool0oooo07@0oooo00<0003o0?ooo`3oool0=P3oool0
0900oooo00<000000?ooo`3oool0Q03oool00`000?l0oooo0?ooo`1]0?oo
o`D000000`3oool00`000000oooo0?ooo`1d0?ooo`030000o`3oool0oooo
03H0oooo002@0?ooo`030000003oool0oooo08D0oooo00<0003o0?ooo`3o
ool0KP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07<0
oooo00<0003o0?ooo`3oool0=`3oool00900oooo00<000000?ooo`3oool0
Q@3oool00`000?l0oooo0?ooo`1^0?ooo`030000003oool0oooo00<0oooo
0P00001d0?ooo`030000o`3oool0oooo03L0oooo002@0?ooo`030000003o
ool0oooo08H0oooo00<0003o0?ooo`3oool0K@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo07<0oooo00<0003o0?ooo`3oool0=`3o
ool00900oooo00<000000?ooo`3oool0QP3oool00`000?l0oooo0?ooo`1]
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0LP3oool0
0`000?l0oooo0?ooo`0h0?ooo`00T03oool00`000000oooo0?ooo`270?oo
o`030000o`3oool0oooo06/0oooo0P0000050?ooo`030000003oool0oooo
0780oooo00<0003o0?ooo`3oool0>03oool00900oooo00<000000?ooo`3o
ool0Q`3oool00`000?l0oooo0?ooo`1b0?ooo`030000003oool0oooo0780
oooo00<0003o0?ooo`3oool0>03oool00900oooo00<000000?ooo`3oool0
R03oool00`000?l0oooo0?ooo`1a0?ooo`030000003oool0oooo0740oooo
00<0003o0?ooo`3oool0>@3oool00900oooo00<000000?ooo`3oool0R03o
ool00`000?l0oooo0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<0
003o0?ooo`3oool0>@3oool00500oooo1000000M0?ooo`D000006P3oool0
0`000000oooo0?ooo`0L0?ooo`D000006`3oool4000004P0oooo00<0003o
0?ooo`3oool0L@3oool00`000000oooo0?ooo`1a0?ooo`030000o`3oool0
oooo03T0oooo001@0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`1`0?oo
o`030000003oool0oooo0700oooo00<0003o0?ooo`3oool0>P3oool00540
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`190?ooo`030000o`3oool0oooo0700oooo00<000000?ooo`3o
ool0L03oool00`000?l0oooo0?ooo`0j0?ooo`00BP3oool4000000@0oooo
00<000000?ooo`3oool05P3oool4000000@0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0B03oool00`000?l0oooo0?ooo`1`0?ooo`030000
003oool0oooo06l0oooo00<0003o0?ooo`3oool0>`3oool00500oooo00@0
00000?ooo`3oool000007`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool06`3oool010000000oooo
0?ooo`00001:0?ooo`030000o`3oool0oooo06l0oooo00<000000?ooo`3o
ool0KP3oool00`000?l0oooo0?ooo`0l0?ooo`00D@3oool2000001l0oooo
0P00000L0?ooo`030000003oool0oooo01d0oooo0P00000N0?ooo`800000
C03oool00`000?l0oooo0?ooo`1^0?ooo`030000003oool0oooo06h0oooo
00<0003o0?ooo`3oool0?03oool00900oooo00<000000?ooo`3oool0R`3o
ool00`000?l0oooo0?ooo`1^0?ooo`030000003oool0oooo06d0oooo00<0
003o0?ooo`3oool0?@3oool00900oooo00<000000?ooo`3oool0S03oool0
0`000?l0oooo0?ooo`1]0?ooo`030000003oool0oooo06d0oooo00<0003o
0?ooo`3oool0?@3oool00900oooo00<000000?ooo`3oool07@3oool30?l0
obX0oooo0P0000000`3oool000000000000m0?ooo`030000o`3oool0oooo
06d0oooo00<000000?ooo`3oool0K@3oool00`000?l0oooo0?ooo`0m0?oo
o`00T03oool00`000000oooo0?ooo`0L0?ooo`D0o`3o:P3oool00`000000
oooo0000000o0?ooo`030000o`3oool0oooo06`0oooo00<000000?ooo`3o
ool0K03oool00`000?l0oooo0?ooo`0n0?ooo`00B@3ooomV000000D0o`3o
9@0000060?ooo`030000003oool0oooo03h0oooo00<0003o0?ooo`3oool0
K03oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0oooo03h0oooo
001?0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0L0?ooo`D0o`3o7@3oool00`000000oooo0?oo
o`090?ooo`80000000<0oooo000000000000?P3oool00`000?l0oooo0?oo
o`1/0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool0?`3o
ool00900oooo00<000000?ooo`3oool07@3oool30?l0ofh0oooo00<0003o
0?ooo`3oool0J`3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0
oooo03l0oooo002@0?ooo`030000003oool0oooo02P0oooo0P00001T0?oo
o`030000o`3oool0oooo06/0oooo00<000000?ooo`3oool0JP3oool00`00
0?l0oooo0?ooo`100?ooo`00T03oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo0680oooo00<0003o0?ooo`3oool0JP3oool00`000000
oooo0?ooo`1Y0?ooo`030000o`3oool0oooo0440oooo002@0?ooo`030000
003oool0oooo0240oooo1@0000030?ooo`030000003oool0oooo06@0oooo
00<0003o0?ooo`3oool0J@3oool00`000000oooo0?ooo`1X0?ooo`030000
o`3oool0oooo0480oooo002@0?ooo`030000003oool0oooo0280oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1T0?ooo`030000
o`3oool0oooo06P0oooo00<000000?ooo`3oool0J03oool00`000?l0oooo
0?ooo`120?ooo`00T03oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`000000IP3oool00`000?l0oooo0?oo
o`1X0?ooo`030000003oool0oooo06L0oooo00<0003o0?ooo`3oool0@`3o
ool00900oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool0I`3oool0
0`000000oooo0?ooo`1W0?ooo`030000o`3oool0oooo04<0oooo002@0?oo
o`030000003oool0oooo0280oooo00@000000?ooo`3oool00000K03oool0
0`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo06H0oooo00<0003o
0?ooo`3oool0A03oool00900oooo00<000000?ooo`3oool08P3oool50000
06`0oooo00<0003o0?ooo`3oool0IP3oool00`000000oooo0?ooo`1V0?oo
o`030000o`3oool0oooo04@0oooo002@0?ooo`030000003oool0oooo09<0
oooo00<0003o0?ooo`3oool0IP3oool00`000000oooo0?ooo`1U0?ooo`03
0000o`3oool0oooo04D0oooo002@0?ooo`030000003oool0oooo09@0oooo
00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`1T0?ooo`030000
o`3oool0oooo04H0oooo002@0?ooo`030000003oool0oooo09D0oooo00<0
003o0?ooo`3oool0I03oool00`000000oooo0?ooo`1S0?ooo`030000o`3o
ool0oooo04L0oooo002@0?ooo`030000003oool0oooo09H0oooo00<0003o
0?ooo`3oool0H`3oool00`000000oooo0?ooo`1S0?ooo`030000o`3oool0
oooo04L0oooo002@0?ooo`030000003oool0oooo09H0oooo00<0003o0?oo
o`3oool0H`3oool00`000000oooo0?ooo`1R0?ooo`030000o`3oool0oooo
04P0oooo002@0?ooo`030000003oool0oooo09L0oooo00<0003o0?ooo`3o
ool0HP3oool00`000000oooo0?ooo`1R0?ooo`030000o`3oool0oooo04P0
oooo002@0?ooo`030000003oool0oooo09P0oooo00<0003o0?ooo`3oool0
H@3oool00`000000oooo0?ooo`1Q0?ooo`030000o`3oool0oooo04T0oooo
002@0?ooo`030000003oool0oooo09T0oooo00<0003o0?ooo`3oool0H03o
ool00`000000oooo0?ooo`1P0?ooo`030000o`3oool0oooo04X0oooo002@
0?ooo`030000003oool0oooo09X0oooo00<0003o0?ooo`3oool0G`3oool0
0`000000oooo0?ooo`1O0?ooo`030000o`3oool0oooo04/0oooo002@0?oo
o`030000003oool0oooo09/0oooo00<0003o0?ooo`3oool0GP3oool00`00
0000oooo0?ooo`1N0?ooo`030000o`3oool0oooo04`0oooo002@0?ooo`03
0000003oool0oooo09`0oooo00<0003o0?ooo`3oool0G@3oool00`000000
oooo0?ooo`0;0?ooo`<00000C`3oool00`000?l0oooo0?ooo`1=0?ooo`00
T03oool00`000000oooo0?ooo`2L0?ooo`030000o`3oool0oooo05D0oooo
100000020?ooo`<0o`003@3oool00`000000oooo0?ooo`1?0?ooo`030000
o`3oool0oooo04d0oooo002@0?ooo`030000003oool0oooo09d0oooo00<0
003o0?ooo`3oool0E03oool00`000000oooo0?ooo`020?ooo`D0o`001@3o
ool5000000<0oooo00<000000?ooo`3oool0C@3oool00`000?l0oooo0?oo
o`1>0?ooo`00T03oool00`000000oooo0?ooo`2N0?ooo`030000o`3oool0
oooo05@0oooo00<000000?ooo`3oool01`3o00050?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?oo
o`1?0?ooo`00T03oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0
oooo05@0oooo00<000000?ooo`3o00001P3o00060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`000000C03oool00`000?l0oooo0?ooo`1@
0?ooo`00T03oool00`000000oooo0?ooo`2P0?ooo`030000o`3oool0oooo
0540oooo00@000000?ooo`3oool000001`3o00070?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`1A
0?ooo`00T03oool00`000000oooo0?ooo`2Q0?ooo`030000o`3oool0oooo
0540oooo0P0000020?ooo`D0o`001P3oool010000000oooo0?ooo`00001?
0?ooo`030000o`3oool0oooo0580oooo002@0?ooo`030000003oool0oooo
0:80oooo00<0003o0?ooo`3oool0E@3oool30?l000L0oooo1@00001=0?oo
o`030000o`3oool0oooo05<0oooo002@0?ooo`030000003oool0oooo0:80
oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo0?ooo`1G0?ooo`03
0000o`3oool0oooo05<0oooo00290?ooo`D000000P3oool00`000000oooo
0?ooo`2S0?ooo`030000o`3oool0oooo05H0oooo00<000000?ooo`3oool0
EP3oool00`000?l0oooo0?ooo`1D0?ooo`00R`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0:@0oooo00<0003o0?ooo`3oool0E@3o
ool00`000000oooo0?ooo`1D0?ooo`80003oE`3oool008/0oooo00<00000
0?ooo`3oool00P3oool200000:H0oooo00<0003o0?ooo`3oool0E03oool0
0`000000oooo0?ooo`1C0?ooo`030000o`3oool0oooo05L0oooo002;0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0YP3oool00`00
0?l0oooo0?ooo`1C0?ooo`030000003oool0oooo0580oooo00<0003o0?oo
o`3oool0F03oool008/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`2W0?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3o
ool0D@3oool00`000?l0oooo0?ooo`1I0?ooo`00RP3oool2000000@0oooo
00<000000?ooo`3oool0Z03oool20000oe80oooo00<000000?ooo`3oool0
D03oool00`000?l0oooo0?ooo`1J0?ooo`00T03oool00`000000oooo0?oo
o`2Z0?ooo`030000o`3oool0oooo04l0oooo00<000000?ooo`3oool0C`3o
ool00`000?l0oooo0?ooo`1K0?ooo`00T03oool00`000000oooo0?ooo`2[
0?ooo`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool0C@3oool2
0000oeh0oooo002@0?ooo`030000003oool0oooo0:`0oooo00<0003o0?oo
o`3oool0C@3oool00`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo
05h0oooo002@0?ooo`030000003oool0oooo0:d0oooo00<0003o0?ooo`3o
ool0C03oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo05l0
oooo002@0?ooo`030000003oool0oooo0:h0oooo00<0003o0?ooo`3oool0
B`3oool00`000000oooo0?ooo`1:0?ooo`030000o`3oool0oooo0600oooo
002@0?ooo`030000003oool0oooo0:l0oooo0P000?m;0?ooo`030000003o
ool0oooo04T0oooo00<0003o0?ooo`3oool0H@3oool00900oooo00<00000
0?ooo`3oool0/@3oool00`000?l0oooo0?ooo`180?ooo`030000003oool0
oooo04L0oooo0P000?mT0?ooo`00T03oool00`000000oooo0?ooo`2b0?oo
o`80003oB03oool00`000000oooo0?ooo`150?ooo`80003oIP3oool00900
oooo00<000000?ooo`3oool0]03oool20000odH0oooo00<000000?ooo`3o
ool0A03oool00`000?l0oooo0?ooo`1V0?ooo`00T03oool00`000000oooo
0?ooo`2f0?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0
@`3oool00`000?l0oooo0?ooo`1W0?ooo`00T03oool00`000000oooo0?oo
o`2g0?ooo`80003o@`3oool00`000000oooo0?ooo`110?ooo`80003oJP3o
ool00900oooo00<000000?ooo`3oool0^@3oool00`000?l0oooo0?ooo`10
0?ooo`030000003oool0oooo03l0oooo0P000?m/0?ooo`00T03oool00`00
0000oooo0?ooo`2j0?ooo`80003o@03oool00`000000oooo0?ooo`0m0?oo
o`80003oKP3oool00900oooo00<000000?ooo`3oool0_03oool20000och0
oooo00<000000?ooo`3oool0?03oool00`000?l0oooo0?ooo`1^0?ooo`00
T03oool00`000000oooo0?ooo`2n0?ooo`030000o`3oool0oooo03/0oooo
00<000000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`1_0?ooo`00T03o
ool00`000000oooo0?ooo`2o0?ooo`80003o>`3oool00`000000oooo0?oo
o`0i0?ooo`80003oLP3oool00900oooo00<000000?ooo`3oool0`@3oool0
0`000?l0oooo0?ooo`0h0?ooo`030000003oool0oooo03L0oooo0P000?md
0?ooo`00T03oool00`000000oooo0?ooo`320?ooo`<0003o=`3oool00`00
0000oooo0?ooo`0d0?ooo`<0003oMP3oool00900oooo00<000000?ooo`3o
ool0a@3oool20000ocD0oooo00<000000?ooo`3oool0<P3oool20000ogT0
oooo002@0?ooo`030000003oool0oooo0<L0oooo0P000?lc0?ooo`030000
003oool0oooo0340oooo00<0003o0?ooo`3oool0N@3oool00900oooo00<0
00000?ooo`3oool0b@3oool20000oc40oooo00<000000?ooo`3oool0;`3o
ool20000og`0oooo002@0?ooo`030000003oool0oooo0</0oooo0`000?l^
0?ooo`030000003oool0oooo02`0oooo0`000?mn0?ooo`00T03oool00`00
0000oooo0?ooo`090?ooo`<00000`P3oool20000ob`0oooo00<000000?oo
o`3oool0:@3oool30000oh40oooo002@0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0a03oool30000obT0oooo00<000000?ooo`3o
ool09P3oool30000oh@0oooo002@0?ooo`030000003oool0oooo0080oooo
1@0000030?ooo`030000003oool0oooo0<H0oooo0`000?lV0?ooo`030000
003oool0oooo02<0oooo0`000?n70?ooo`00T03oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
b@3oool30000ob<0oooo00<000000?ooo`3oool0803oool30000ohX0oooo
002@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0000003=0?ooo`<0003o803oool00`000000oooo0?oo
o`0M0?ooo`<0003oS@3oool008T0oooo100000020?ooo`<0o`001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0<l0oooo1P000?lJ
0?ooo`030000003oool0oooo01L0oooo1P000?n@0?ooo`00R@3oool00`00
0000oooo0?ooo`020?ooo`D0o`000`3oool010000000oooo0?ooo`00003K
0?ooo`<0003o5`3oool00`000000oooo0?ooo`0D0?ooo`<0003oUP3oool0
08X0oooo00@000000?ooo`3oool0oooo1@3o00030?ooo`D00000g@3oool8
0000o`l0oooo00<000000?ooo`3oool0303oool80000oiT0oooo002;0?oo
o`030000003oool0oooo00D0o`00k@3ooolN0000oj40oooo00290?ooo`04
0000003oool0oooo00000080oooo0`3o003m0?ooo`030000003oool0oooo
0:d0oooo002:0?ooo`800000103oool00`000000oooo0?ooo`3l0?ooo`03
0000003oool0oooo0:d0oooo002@0?ooo`030000003oool0oooo0?l0oooo
[@3oool00900oooo00<000000?ooo`3oool0o`3ooon]0?ooo`00T03oool0
0`000000oooo0?ooo`3o0?ooojd0oooo003o0?ooool0oooo@@3oool00?l0
ooooo`3ooom10?ooo`00o`3ooooo0?oood40oooo003o0?ooool0oooo@@3o
ool00?l0ooooo`3ooom10?ooo`00o`3ooooo0?oood40oooo002>0?ooo`80
0000o@3oool200000;00oooo002?0?ooo`030000003oool0oooo0?`0oooo
00<000000?ooo`3oool0[P3oool00900oooo00<000000?ooo`3oool0o03o
ool00`000000oooo0?ooo`2]0?ooo`00S`3oool00`000000oooo0000003l
0?ooo`030000003oool000000:h0oooo002>0?ooo`040000003oool0oooo
00000?/0oooo00@000000?ooo`3oool00000[P3oool008d0oooo0`000000
0`3oool000000000003i0?ooo`<0000000<0oooo000000000000[@3oool0
0?l0ooooo`3ooom10?ooo`00o`3ooooo0?oood40oooo003o0?ooool0oooo
@@3oool00?l0ooooo`3ooom10?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{575, 165},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The integrand  ",
  Cell[BoxData[
      \(f \((z)\) = \(\[ExponentialE]\^\(\[ImaginaryI]\ z\)\/\(\((z - 1)\) \
\((z\^2\  + \ 4)\)\) = \[ExponentialE]\^\(\[ImaginaryI]\ z\)\/\(\((z - 1)\) \
\((z + 2  \[ImaginaryI])\) \((z - 2  \[ImaginaryI])\)\)\)\)]],
  "  has simple poles at the points  ",
  Cell[BoxData[
      \(t\_1 = 1\)]],
  "  on the ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " axis and  ",
  Cell[BoxData[
      \(z\_1 = 2  \[ImaginaryI]\)]],
  "  in the upper half-plane.  Computing the residues we get  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, 
          1]\ \  = \ \ lim\+\(z\  \[Rule] 1\)\ \((z - 1)\) 
            f \((z)\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] 1\)\ \((z - 
                1)\) \[ExponentialE]\^\(\[ImaginaryI]\ z\)\/\(\((z - 1)\) \
\((z\^2\  + \ 4)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] 1\)\ \[ExponentialE]\^\(\[ImaginaryI]\ z\)\/\((z\^2\  \
+ \ 4)\)\ \  = \ \ \[ExponentialE]\^\[ImaginaryI]\/\((1\^2\  + \ 4)\)\)\)\(\ \
\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(cos\ 1\
\ \  + \ \[ImaginaryI]\ sin\ 1\)\/5\)\)\)}]],
  "  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[f, 
          2  \[ImaginaryI]]\ \  = \ \ lim\+\(z\  \[Rule] 2  \[ImaginaryI]\)\ \
\((z - 2  \[ImaginaryI])\) f \((z)\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\
\(lim\+\(z\  \[Rule] 2  \[ImaginaryI]\)\ \((z - 
                2  \[ImaginaryI])\) \[ExponentialE]\^\(\[ImaginaryI]\ z\)\/\(\
\((z - 1)\) \((z + 2  \[ImaginaryI])\) \((z - 2  \[ImaginaryI])\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\
\(lim\+\(z\  \[Rule] 2  \[ImaginaryI]\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \
z\)\/\(\((z - 1)\) \((z + 2  \[ImaginaryI])\)\)\ \  = \ \ \[ExponentialE]\^\(\
\[ImaginaryI]\ \((2  \[ImaginaryI])\)\)\/\(\((2  \[ImaginaryI] - 1)\) \((2  \
\[ImaginaryI] + 2  \[ImaginaryI])\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\
\(\[ExponentialE]\^\(-2\)\/\((\(-8\) - 4\ \[ImaginaryI])\)\ \  = \ \ \(\(\(\
\[ExponentialE]\^\(-2\)\) \((\(-8\) + 4\ \[ImaginaryI])\)\)\/\(\((\(-8\) - 4\ \
\[ImaginaryI])\) \((\(-8\) + 4\ \[ImaginaryI])\)\)\ \ \  = \ \ \(\(-8\) + 4\ \
\[ImaginaryI]\)\/\(80  \[ExponentialE]\^2\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \ \)\
\(\(\(-2\) + \[ImaginaryI]\)\/\(20  \[ExponentialE]\^2\)\)\)\)}]]
}], "Text"],

Cell[TextData[{
  "By Theorem 8.6,\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(P . 
          V . \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( 
                  1\/\(\((x - 1)\) \((x\^2\  + \ 4)\)\)\) 
              sin\ \ x\ \[DifferentialD]x\)\ \  = \ \ 2  \[Pi]\ \ Re \((Res[
                f, z\_1])\)\ \  + \ \ \[Pi]\ \ Re \((Res[f, 
                t\_1])\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(2  \
\[Pi]\ \ Re \((Res[f, 2  \[ImaginaryI]])\)\ \  + \ \ \[Pi]\ \ Re \((Res[f, 
                1])\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(2  \
\[Pi]\ \ Re \((\(\(-2\) + \[ImaginaryI]\)\/\(20  \[ExponentialE]\^2\))\)\ \  \
+ \ \ \[Pi]\ \ Re \((\(cos\ 1\ \  + \ \[ImaginaryI]\ sin\ 1\)\/5)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(2  \[Pi]\
\ \(-2\)\/\(20  \[ExponentialE]\^2\)\ \  + \ \ \[Pi]\ \(cos\ 1\)\/5\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\[Pi]\/5\
\ \ \((cos\ 1\  - \ 1\/\[ExponentialE]\^2)\)\)\)\)}]],
  "   \n"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.22.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function and  ",
  Cell[BoxData[
      \(f[
          z] = \[ExponentialE]\^\(\[ImaginaryI]\ z\)\/\(\((z\  - \ 1)\) \
\((z\^2\  + \ 4)\)\)\)],
    AspectRatioFixed->True],
  "  and ",
  "locate the",
  " singularities."
}], "Text"],

Cell[BoxData[{
    \(Z = \(z = \(x = 0\)\); \ Remove[x, z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, Res1, Res2, solset, val];\)\ \), "\[IndentingNewLine]", 
    \(\(F[x_]\  = \ Sin[x]\/\(\((x - 1)\) \((x\^2\  + \ 4)\)\);\)\ \), "\n", 
    \(\(f[
          z_]\  = \ \[ExponentialE]\^\(\[ImaginaryI]\ z\)\/\(\((z - 1)\) \((z\
\^2\  + \ 4)\)\);\)\ \), "\n", 
    \(\(Print["\<F[x] = \>", F[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[Denominator[f[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[f[z]] \[Equal] 0, 
            z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The singularities are\>"];\)\ \), "\n", 
    \(\(Z\_1\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2];\)\ \), "\n", 
    \(\(Z\_3\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", 
        Z\_3];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell["\<\
Which poles lie in the upper half plane ?  Which poles lie on the real axis ?\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_2], Im[Z\_2]}]}, {Magenta, 
              PointSize[0.03], 
              Point[{Re[Z\_3], Im[Z\_3]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] - 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] - 0.1}, {\(-1\), 
                0}], Text[\*"\"\<\!\(z\_3\)\>\"", {Re[Z\_3], 
                Im[Z\_3] + 0.1}, {\(-1\), 0}]}];\)\ \), "\n", 
    \(\(Show[dots, centers, 
        PlotRange \[Rule] {{\(-2.2\), 2.2}, {\(-2.2\), 2.2}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<, Is  Im(\>", 
        Z\_1, "\<) > 0 ?  \>", N[Im[Z\_1]] > 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<,   Is  Im(\>", 
        Z\_2, "\<) > 0 ?  \>", 
        N[Im[Z\_2]] > 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3, "\<,    Is  Im(\>", 
        Z\_3, "\<) > 0 ?    \>", 
        N[Im[Z\_3]] > 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<, Is  Im(\>", 
        Z\_1, "\<) = 0 ?  \>", N[Im[Z\_1]] \[Equal] 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<,  Is  Im(\>", 
        Z\_2, "\<) = 0 ?   \>", N[Im[Z\_2]] \[Equal] 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3, "\<,    Is  Im(\>", 
        Z\_3, "\<) = 0 ?    \>", 
        N[Im[Z\_3]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Compute the residues at  ",
  Cell[BoxData[
      \(z\_2 = \(2  \[ImaginaryI]\ \ and\ \ z\_3 = 1\)\)]],
  ",  and use the residue calculus to compute the value of the integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Res2\  = \ Residue[f[z], {z, Z\_2}];\)\ \), "\n", 
    \(\(Res3\  = \ Residue[f[z], {z, Z\_3}];\)\ \), "\[IndentingNewLine]", 
    \(\(val\  = \ 
        2\ \[Pi]\ Re[Res2] + \[Pi]\ Re[\ 
              Res3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", Z\_2, "\<] = \>", Res2];\)\ \), "\n", 
    \(\(Print["\<Res[f,\>", Z\_3, "\<] = \>", 
        Res3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Re[Res[f,\>", Z\_2, "\<]] = \>", Re[Res2]];\)\ \), "\n", 
    \(\(Print["\<Re[Res[f,\>", Z\_3, "\<]] = \>", 
        Re[Res3]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], 
              Point[{Re[Z\_2], Im[Z\_2]}]}, {Magenta, PointSize[0.03], 
              Point[{Re[Z\_3], Im[Z\_3]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], 
                Im[Z\_2]}, {\(-1.2\), 0}], 
            Text[\*"\"\<\!\(z\_3\)\>\"", {Re[Z\_3] - 0.05, 
                Im[Z\_3] + 0.3}, {\(-1\), 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ 
        Graphics[{{Blue, Circle[{0, 0}, 3, {0, \[Pi]}]}, {Blue, 
              Circle[{Re[Z\_3], Im[Z\_3]}, 
                0.2, {0, \[Pi]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(segment = 
        Graphics[{Thickness[0.015], Cyan, 
            Line[{{\(-3\), 0}, {3, 0}}]}];\)\ \), "\n", 
    \(\(Show[centers, contour, segment, dots, 
        PlotRange \[Rule] {{\(-3.1\), 3.1}, {\(-0.05\), 3.05}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 2, 1]}, 
        AspectRatio \[Rule] 1\/2, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = 2\[Pi] Re[\>", 
        Res2\ , "\<] + \[Pi] Re[\>", \ 
        Res3\ , "\<]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = 2\[Pi](\>", 
        Re[Res2\ ], "\<) + \[Pi](\>", 
        Re[\ Res3]\ , "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The indented contour is the semicircle \!\(C\_R\) \
portions of [-R,R],\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and a little indent semicircle around the pole on the \
x-axis,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<taken with the positive orientation.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value \
of the integral.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"\
", f[x], "\< \[DifferentialD]x = \>", val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"\
", f[x], "\< \[DifferentialD]x = \>", 
        Chop[N[val]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Warning.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The indefinite integral of F[x] is g[x], but it cannot be used in any \
meaningful way to solve the problem at hand."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(g[x_]\  = \[Integral]f[x] \[DifferentialD]x;\)\ \), "\n", 
    \(\(Print["\<g[x] = \[Integral]\>", f[x], "\<\[DifferentialD]x = \>", 
        g[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< g[\[Infinity]] = \>", 
        g[\[Infinity]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[-\[Infinity]] = \>", g[\(-\[Infinity]\)]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    The following answer is suspect\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<because of singularities on the real axis.\>"];\)\ \), "\n", \

    \(\(Print["\<g[\[Infinity]]-g[-\[Infinity]] = \>", 
        g[\[Infinity]]\  - \ g[\(-\[Infinity]\)]];\)\ \), "\n", 
    \(\(Print["\<g[\[Infinity]]-g[-\[Infinity]] = \>", 
        ComplexExpand[
          g[\[Infinity]] - 
            g[\(-\[Infinity]\)]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[\[Infinity]]-g[-\[Infinity]] = \>", 
        N[g[\[Infinity]] - 
            g[\(-\[Infinity]\)]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in \"PrincipalValue\" option to evaluate the definite integral ."
}], "Text"],

Cell[BoxData[{
    \(\(F0[x] = 
        Expand[Sin[x]\ Apart[
              1\/\(\((\(-1\) + x)\)\ \((4 + x\^2)\)\)]];\)\ \), "\n", 
    \(\(val1 = 
        Integrate[\(F0[x]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\), {x, \(-\[Infinity]\), \[Infinity]}, 
          PrincipalValue \[Rule] True];\)\ \), "\n", 
    \(\(val2 = 
        Integrate[\(F0[x]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), {x, \(-\[Infinity]\), \[Infinity]}, 
          PrincipalValue \[Rule] True];\)\ \), "\n", 
    \(\(val3 = 
        Integrate[\(F0[x]\)\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\), {x, \(-\[Infinity]\), \[Infinity]}, 
          PrincipalValue \[Rule] True];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"\
", F[x], "\< \[DifferentialD]x = \>", 
        val1 + val2 + val3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\)\>\"\
", F[x], "\< \[DifferentialD]x = \>", 
        N[val1 + val2 + val3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Which is also the correct answer.", "Text"]
}, Closed]],

Cell["\<\
\tThe proofs of Theorems 8.5 and 8.6 depend on the following result.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Lemma 8.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " have a simple pole at the point  ",
  Cell[BoxData[
      \(t\_0\)]],
  "  on the ",
  StyleBox["x",
    FontFamily->"Courier New"],
  "-axis.  If the contour is  ",
  Cell[BoxData[
      \(\(C\_r\) : z = 
        t\_0 + r\ \[ExponentialE]\^\[ImaginaryI]\[Theta]\ \ for\ \ 0\  \
\[LessEqual] \ \[Theta]\  \[LessEqual] \ \[Pi]\)]],
  ",  then \n\n\t\t",
  Cell[BoxData[
      \(\(\(\(lim\)\(\ \)\)\+\(r\  \[Rule] \ 0\)\) \(\[Integral]\_\(C\_r\)\ 
            f \((z)\)\ \[DifferentialD]z\)\ \  = \ \ \[ImaginaryI]\ \[Pi]\ \
Res[f, t\_0]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Proof of Lemma 8.2",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[" is in the book.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Residue Calculus",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ResidueCalcBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Contour Integrals",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ContourIntegralBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Cauchy Principal Value",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/CauchyPrincipalValuelBib.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{968, 636},
WindowMargins->{{4, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[34222, 811, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[41953, 1058, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[141659, 3040, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 144452, 3130}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 121, 2, 33, "Text"],
Cell[2226, 66, 1709, 50, 260, "Text"],
Cell[3938, 118, 890, 31, 130, "Text"],
Cell[4831, 151, 316, 12, 36, "Text",
  Evaluatable->False],
Cell[5150, 165, 11674, 194, 185, 11560, 190, "GraphicsData", "Bitmap", "Text",
  
  Evaluatable->False],
Cell[16827, 361, 1817, 34, 309, "Text"],

Cell[CellGroupData[{
Cell[18669, 399, 196, 7, 33, "Text"],
Cell[18868, 408, 158, 5, 33, "Text"],
Cell[19029, 415, 450, 9, 197, "Input"],
Cell[19482, 426, 545, 16, 55, "Text"],
Cell[20030, 444, 1702, 32, 315, "Input"],
Cell[21735, 478, 73, 0, 33, "Text"],
Cell[21811, 480, 1309, 23, 201, "Input"],
Cell[23123, 505, 599, 18, 65, "Text"],
Cell[23725, 525, 1529, 29, 393, "Input"],
Cell[25257, 556, 219, 6, 33, "Text"],
Cell[25479, 564, 1093, 21, 306, "Input"],
Cell[26575, 587, 49, 0, 33, "Text"],
Cell[26627, 589, 229, 7, 33, "Text",
  Evaluatable->False],
Cell[26859, 598, 331, 7, 83, "Input"],
Cell[27193, 607, 580, 16, 74, "Text"],
Cell[27776, 625, 2385, 45, 361, "Input"]
}, Closed]],
Cell[30176, 673, 516, 16, 49, "Text"],
Cell[30695, 691, 3093, 99, 141, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[33813, 794, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[33961, 800, 258, 9, 33, "Text",
  Evaluatable->False],
Cell[34222, 811, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[34582, 823, 3143, 96, 30, "Text"],
Cell[37728, 921, 3791, 116, 228, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[41544, 1041, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[41692, 1047, 258, 9, 33, "Text",
  Evaluatable->False],
Cell[41953, 1058, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[42313, 1070, 1348, 38, 49, "Text"],
Cell[43664, 1110, 339, 11, 36, "Text",
  Evaluatable->False],
Cell[44006, 1123, 20011, 331, 179, 19897, 327, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[64020, 1456, 3438, 68, 647, "Text"],
Cell[67461, 1526, 1195, 21, 316, "Text"],

Cell[CellGroupData[{
Cell[68681, 1551, 196, 7, 33, "Text"],
Cell[68880, 1560, 189, 8, 36, "Text"],
Cell[69072, 1570, 1495, 32, 362, "Input"],
Cell[70570, 1604, 152, 5, 33, "Text",
  Evaluatable->False],
Cell[70725, 1611, 1981, 35, 310, "Input"],
Cell[72709, 1648, 267, 7, 33, "Text",
  Evaluatable->False],
Cell[72979, 1657, 3274, 60, 624, "Input"]
}, Closed]],
Cell[76268, 1720, 348, 11, 33, "Text",
  Evaluatable->False],
Cell[76619, 1733, 14220, 236, 179, 14106, 232, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[90842, 1971, 1433, 29, 498, "Text"],
Cell[92278, 2002, 507, 16, 36, "Text"],
Cell[92788, 2020, 1997, 37, 507, "Text"],
Cell[94788, 2059, 1518, 31, 310, "Text"],
Cell[96309, 2092, 1347, 27, 217, "Text"],

Cell[CellGroupData[{
Cell[97681, 2123, 196, 7, 33, "Text"],
Cell[97880, 2132, 189, 8, 36, "Text"],
Cell[98072, 2142, 338, 6, 122, "Input"],
Cell[98413, 2150, 334, 10, 33, "Text",
  Evaluatable->False],
Cell[98750, 2162, 1589, 30, 399, "Input"],
Cell[100342, 2194, 233, 8, 33, "Text"],
Cell[100578, 2204, 688, 13, 168, "Input"],
Cell[101269, 2219, 301, 9, 52, "Text",
  Evaluatable->False],
Cell[101573, 2230, 2556, 48, 616, "Input"],
Cell[104132, 2280, 49, 0, 33, "Text"],
Cell[104184, 2282, 258, 9, 33, "Text"],
Cell[104445, 2293, 368, 7, 83, "Input"],
Cell[104816, 2302, 49, 0, 33, "Text"]
}, Closed]],
Cell[104880, 2305, 404, 12, 36, "Text",
  Evaluatable->False],
Cell[105287, 2319, 19531, 323, 179, 19417, 319, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[124821, 2644, 3007, 59, 465, "Text"],
Cell[127831, 2705, 1632, 30, 266, "Text"],

Cell[CellGroupData[{
Cell[129488, 2739, 196, 7, 33, "Text"],
Cell[129687, 2748, 260, 10, 41, "Text"],
Cell[129950, 2760, 1705, 35, 448, "Input"],
Cell[131658, 2797, 152, 5, 33, "Text",
  Evaluatable->False],
Cell[131813, 2804, 1965, 35, 310, "Input"],
Cell[133781, 2841, 256, 7, 33, "Text",
  Evaluatable->False],
Cell[134040, 2850, 3328, 62, 664, "Input"],
Cell[137371, 2914, 280, 8, 33, "Text",
  Evaluatable->False],
Cell[137654, 2924, 1202, 24, 283, "Input"],
Cell[138859, 2950, 255, 8, 33, "Text"],
Cell[139117, 2960, 1123, 22, 193, "Input"],
Cell[140243, 2984, 49, 0, 33, "Text"]
}, Closed]],
Cell[140307, 2987, 141, 4, 30, "Text",
  Evaluatable->False],
Cell[140451, 2993, 776, 26, 77, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[141252, 3023, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[141400, 3029, 256, 9, 33, "Text",
  Evaluatable->False],
Cell[141659, 3040, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[142019, 3052, 290, 7, 30, "Text"],
Cell[142312, 3061, 313, 10, 33, "Text"],
Cell[142628, 3073, 318, 10, 33, "Text"],
Cell[142949, 3085, 331, 11, 33, "Text"],
Cell[143283, 3098, 257, 5, 33, "Text"],
Cell[143543, 3105, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

