(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     91357,       1950]*)
(*NotebookOutlinePosition[     92293,       1984]*)
(*  CellTagsIndexPosition[     92217,       1978]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["8.6  Integrands with Branch Points",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tWe now show how to evaluate certain improper real integrals involving \
the integrand  ",
  Cell[BoxData[
      \(\(x\^\[Alpha]\ P \((x)\)\)\/\(Q \((x)\)\)\)]],
  ".  Since the complex function  ",
  Cell[BoxData[
      \(\(\(z\^\[Alpha]\)\(\ \)\)\)]],
  "  is multivalued, so we must first specify the branch to be used."
}], "Text"],

Cell[TextData[{
  "\tLet ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  " be a real number with ",
  Cell[BoxData[
      \(0 < \[Alpha] < 1\)]],
  ".  In this section we use the branch of ",
  Cell[BoxData[
      \(\(\(z\^\[Alpha]\)\(\ \)\)\)]],
  " corresponding to the branch of the logarithm ",
  Cell[BoxData[
      \(\(log\_\(\(\ \)\(0\)\)\) \((z)\)\)]],
  " (see Equation ",
  StyleBox["(5-20)",
    FontColor->RGBColor[0, 0, 1]],
  ") as follows:\n\n\t\t\t",
  Cell[BoxData[
      \(z\^\[Alpha]\  = \ \(\[ExponentialE]\^\(\[Alpha]\ \((\(log\_\(\(\ \
\)\(0\)\)\) \((z)\))\)\)\  = \ \(\[ExponentialE]\^\(\[Alpha]\ \((ln | z | \ \
\(+\ \[ImaginaryI]\)\ \(arg\_\(\(\ \)\(0\)\)\) z)\)\)\  = \ \(\[ExponentialE]\
\^\(\[Alpha] \((ln\ r\  + \ \[ImaginaryI]\[Theta])\)\)\  = \ \(r\^\[Alpha]\) \
\((cos\ \[Alpha]\ \[Theta]\  + \ \[ImaginaryI]\ sin\ \[Alpha]\ \
\[Theta])\)\)\)\)\)]],
  ",  \n\nwhere  ",
  Cell[BoxData[
      \(z = r\ \[ExponentialE]\^\[ImaginaryI]\[Theta]\)]],
  "  and  ",
  Cell[BoxData[
      \(0 < \[Theta] \[LessEqual] 2  \[Pi]\)]],
  ".  Note that this is not the traditional principal branch of ",
  Cell[BoxData[
      \(z\^\[Alpha]\)]],
  " and that, as defined, the function ",
  Cell[BoxData[
      \(z\^\[Alpha]\)]],
  " is analytic in the domain ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(z = 
            r\ \(\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\) : \ r > 0\)\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", \(0 < \[Theta] < 2  \[Pi]\)}], " ",
         "}"}]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 8.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["P(x)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Q(x)",
    FontFamily->"Courier New"],
  " be polynomials of degree ",
  StyleBox["m",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["n",
    FontFamily->"Courier New"],
  ", respectively, where  ",
  Cell[BoxData[
      \(n \[GreaterEqual] m + 2\)]],
  ".  If  ",
  Cell[BoxData[
      RowBox[{\(Q \((x)\)\), "\[NotEqual]", 
        RowBox[{"0", "  ", 
          StyleBox["for",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", "x"}], ">", "0"}]]],
  ",  and ",
  StyleBox["Q(x)",
    FontFamily->"Courier New"],
  " has a zero of order at most ",
  StyleBox["1",
    FontFamily->"Courier New"],
  " at the origin, and ",
  Cell[BoxData[
      RowBox[{\(f \((z)\) = \(z\^\[Alpha]\ P \((z)\)\)\/\(Q \((z)\)\)\), ",", 
        
        RowBox[{
          RowBox[{
            StyleBox["where",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", "0"}], " ", "<", " ", "\[Alpha]",
           "<", " ", "1"}]}]]],
  ", then  \n\n\t\t\t",
  Cell[BoxData[
      \(P . 
          V . \(\[Integral]\_0\%\[Infinity]\(\( x\^\[Alpha]\ P \((x)\)\)\/\(Q \
\((x)\)\)\) \[DifferentialD]x\)\ \  = \ \ \(2  \[Pi]\ \[ImaginaryI]\)\/\(1\  \
- \ \[ExponentialE]\^\(\[ImaginaryI]\ \[Alpha]\ 2  \[Pi]\)\)\ \(\[Sum]\+\(j = \
1\)\%k Res[f, z\_j]\)\)]],
  ",  \n\n where  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_k\)}]]],
  "  are the non-zero poles of  ",
  Cell[BoxData[
      \(\(P \((z)\)\)\/\(Q \((z)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 8.7",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/integralsbranchpoints/\
IntegralsBranchPointsFigures/mat0807.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " that encloses the nonzero poles  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_k\)}]]],
  "  of  ",
  Cell[BoxData[
      \(\(P \((z)\)\)\/\(Q \((z)\)\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Proof of Theorem 8.7",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[" is in the book.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["\n",
    FontWeight->"Bold"],
  StyleBox["Example 8.23.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  "Evaluate",
  "  ",
  Cell[BoxData[
      \(P . 
        V . \ \(\[Integral]\_0\%\[Infinity]\( x\^\[Alpha]\/\(x \((x\  + \ 
                      1)\)\)\) \[DifferentialD]x\)\)]],
  ",  where  ",
  Cell[BoxData[
      \(0 < \[Alpha] < 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000870000ab000`400?l0
0000o`00003oo`3ooooo0?ooo`T0oooo003o0?ooool0oooo2@3oool00?l0
ooooo`3oool90?ooo`00o`3ooooo0?ooo`T0oooo003o0?ooool0oooo2@3o
ool00<D0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`1]
0?ooo`00a@3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo
06d0oooo00350?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3o
ool0K@3oool00<D0oooo00<000000?ooo`3oool0c`3oool00`000000oooo
0?ooo`1]0?ooo`00a@3oool00`000000oooo0?ooo`3?0?ooo`030000003o
ool0oooo06d0oooo00350?ooo`030000003oool0oooo0<<0oooo60000?mT
0?ooo`00_P3oool4000000<0oooo00<000000?ooo`3oool0_`3oool40000
o``0oooo00<000000?ooo`3oool02@3oool60000oeh0oooo002n0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0^@3oool60000oa00
oooo00<000000?ooo`3oool03`3oool40000oeX0oooo002o0?ooo`030000
003oool0oooo00<0oooo0P00002h0?ooo`80003o5P3oool00`000000oooo
0?ooo`0C0?ooo`@0003oEP3oool00;P0oooo100000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0]03oool30000oaP0oooo00<0
00000?ooo`3oool05`3oool20000oe@0oooo002n0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0/P3oool20000oa/0oooo00<0
00000?ooo`3oool06@3oool30000oe40oooo002o0?ooo`800000103oool0
0`000000oooo0?ooo`2^0?ooo`@0003o7@3oool00`000000oooo0?ooo`0L
0?ooo`80003oC`3oool00<D0oooo00<000000?ooo`3oool0[03oool20000
ob40oooo00<000000?ooo`3oool07P3oool20000odd0oooo00350?ooo`03
0000003oool0oooo0:X0oooo0P000?lS0?ooo`030000003oool0oooo0200
oooo0P000?m;0?ooo`00a@3oool00`000000oooo0?ooo`2X0?ooo`80003o
9@3oool00`000000oooo0?ooo`0R0?ooo`80003oB@3oool00<D0oooo00<0
00000?ooo`3oool0Y`3oool00`000?l0oooo0?ooo`0U0?ooo`030000003o
ool0oooo02@0oooo0P000?m70?ooo`00a@3oool00`000000oooo0?ooo`2U
0?ooo`80003o:03oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0
oooo04@0oooo00350?ooo`030000003oool0oooo0:<0oooo0P000?lZ0?oo
o`030000003oool0oooo02L0oooo0P000?m40?ooo`00a@3oool00`000000
oooo0?ooo`2Q0?ooo`80003o;03oool00`000000oooo0?ooo`0Y0?ooo`80
003o@P3oool00<D0oooo00<000000?ooo`3oool0X03oool00`000?l0oooo
0?ooo`0/0?ooo`030000003oool0oooo02/0oooo0P000?m00?ooo`00a@3o
ool00`000000oooo0?ooo`2N0?ooo`80003o;`3oool00`000000oooo0?oo
o`0]0?ooo`030000o`3oool0oooo03d0oooo00350?ooo`030000003oool0
oooo09d0oooo00<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0^
0?ooo`80003o?@3oool00<D0oooo00<000000?ooo`3oool0W03oool00`00
0?l0oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo00<0003o0?oo
o`3oool0>P3oool00<D0oooo00<000000?ooo`3oool0V`3oool00`000?l0
oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<0003o0?ooo`3o
ool0>@3oool00<D0oooo00<000000?ooo`3oool0V@3oool20000oc@0oooo
00<000000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`0h0?ooo`00a@3o
ool00`000000oooo0?ooo`2H0?ooo`030000o`3oool0oooo03@0oooo00<0
00000?ooo`3oool0<`3oool20000ocP0oooo00350?ooo`030000003oool0
oooo09L0oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0e
0?ooo`030000o`3oool0oooo03D0oooo00350?ooo`030000003oool0oooo
09H0oooo00<0003o0?ooo`3oool0=P3oool00`000000oooo0?ooo`0f0?oo
o`030000o`3oool0oooo03@0oooo00350?ooo`030000003oool0oooo09D0
oooo00<0003o0?ooo`3oool0=`3oool00`000000oooo0?ooo`0g0?ooo`03
0000o`3oool0oooo03<0oooo00350?ooo`030000003oool0oooo09@0oooo
00<0003o0?ooo`3oool0>03oool00`000000oooo0?ooo`0h0?ooo`030000
o`3oool0oooo0380oooo00350?ooo`030000003oool0oooo09<0oooo00<0
003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`0i0?ooo`030000o`3o
ool0oooo0340oooo00350?ooo`030000003oool0oooo0980oooo00<0003o
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000o`3oool0
oooo0300oooo00350?ooo`030000003oool0oooo0940oooo00<0003o0?oo
o`3oool0>`3oool00`000000oooo0?ooo`0k0?ooo`030000o`3oool0oooo
02l0oooo00350?ooo`030000003oool0oooo0900oooo00<0003o0?ooo`3o
ool0?03oool00`000000oooo0?ooo`0k0?ooo`030000o`3oool0oooo02l0
oooo00350?ooo`030000003oool0oooo08l0oooo00<0003o0?ooo`3oool0
?@3oool00`000000oooo0?ooo`0l0?ooo`030000o`3oool0oooo02h0oooo
00350?ooo`030000003oool0oooo08h0oooo00<0003o0?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0m0?ooo`80003o;P3oool00<D0oooo00<00000
0?ooo`3oool0SP3oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0
oooo03h0oooo00<0003o0?ooo`3oool0;03oool00<D0oooo00<000000?oo
o`3oool0S03oool20000od40oooo00<000000?ooo`3oool0?`3oool00`00
0?l0oooo0?ooo`0[0?ooo`00a@3oool00`000000oooo0?ooo`2;0?ooo`03
0000o`3oool0oooo0440oooo00<000000?ooo`3oool0?`3oool00`000?l0
oooo0?ooo`0[0?ooo`00a@3oool00`000000oooo0?ooo`2;0?ooo`030000
o`3oool0oooo0440oooo00<000000?ooo`3oool0@03oool00`000?l0oooo
0?ooo`0Z0?ooo`00a@3oool00`000000oooo0?ooo`2:0?ooo`030000o`3o
ool0oooo0480oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo0?oo
o`0Y0?ooo`00a@3oool00`000000oooo0?ooo`2:0?ooo`030000o`3oool0
oooo0480oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo0?ooo`0Y
0?ooo`00a@3oool00`000000oooo0?ooo`290?ooo`030000o`3oool0oooo
04<0oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0X0?oo
o`00a@3oool00`000000oooo0?ooo`280?ooo`030000o`3oool0oooo04@0
oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0W0?ooo`00
a@3oool00`000000oooo0?ooo`280?ooo`030000o`3oool0oooo04@0oooo
00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`0V0?ooo`00a@3o
ool00`000000oooo0?ooo`270?ooo`030000o`3oool0oooo03h0oooo1@00
00020?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool09@3o
ool00<D0oooo00<000000?ooo`3oool0Q`3oool00`000?l0oooo0?ooo`10
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A@3oool0
0`000?l0oooo0?ooo`0U0?ooo`00_P3oool500000080oooo00<000000?oo
o`3oool0QP3oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo
0080oooo0P0000170?ooo`030000o`3oool0oooo02@0oooo00300?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0QP3oool00`000?l0
oooo0?ooo`0i0?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo04H0oooo00<0003o0?ooo`3oool0903oool00<00oooo
00<000000?ooo`3oool00P3oool2000008H0oooo00<0003o0?ooo`3oool0
@P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04L0oooo
00<0003o0?ooo`3oool08`3oool00;P0oooo100000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0Q03oool00`000?l0oooo0?oo
o`120?ooo`800000103oool00`000000oooo0?ooo`170?ooo`030000o`3o
ool0oooo02<0oooo00300?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0Q03oool00`000?l0oooo0?ooo`180?ooo`030000003oool0
oooo04P0oooo00<0003o0?ooo`3oool08P3oool00;l0oooo0P0000040?oo
o`030000003oool0oooo08<0oooo00<0003o0?ooo`3oool0B@3oool00`00
0000oooo0?ooo`180?ooo`030000o`3oool0oooo0280oooo00350?ooo`03
0000003oool0oooo08<0oooo00<0003o0?ooo`3oool0B@3oool00`000000
oooo0?ooo`190?ooo`030000o`3oool0oooo0240oooo00350?ooo`030000
003oool0oooo0880oooo00<0003o0?ooo`3oool0BP3oool00`000000oooo
0?ooo`190?ooo`030000o`3oool0oooo0240oooo00350?ooo`030000003o
ool0oooo0880oooo00<0003o0?ooo`3oool0BP3oool00`000000oooo0?oo
o`190?ooo`030000o`3oool0oooo0240oooo00350?ooo`030000003oool0
oooo0840oooo00<0003o0?ooo`3oool0B`3oool00`000000oooo0?ooo`1:
0?ooo`030000o`3oool0oooo0200oooo00350?ooo`030000003oool0oooo
0840oooo00<0003o0?ooo`3oool0B`3oool00`000000oooo0?ooo`1:0?oo
o`030000o`3oool0oooo0200oooo00350?ooo`030000003oool0oooo0800
oooo00<0003o0?ooo`3oool0C03oool00`000000oooo0?ooo`1;0?ooo`03
0000o`3oool0oooo01l0oooo00350?ooo`030000003oool0oooo0800oooo
00<0003o0?ooo`3oool0C03oool00`000000oooo0?ooo`1;0?ooo`030000
o`3oool0oooo01l0oooo00350?ooo`030000003oool0oooo0800oooo00<0
003o0?ooo`3oool0C03oool00`000000oooo0?ooo`1<0?ooo`030000o`3o
ool0oooo01h0oooo00350?ooo`030000003oool0oooo0800oooo00<0003o
0?ooo`3oool0C03oool00`000000oooo0?ooo`1<0?ooo`030000o`3oool0
oooo01h0oooo00350?ooo`030000003oool0oooo07l0oooo00<0003o0?oo
o`3oool0C@3oool00`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo
01h0oooo00350?ooo`030000003oool0oooo07l0oooo00<0003o0?ooo`3o
ool0C@3oool00`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo01h0
oooo00350?ooo`030000003oool0oooo07l0oooo00<0003o0?ooo`3oool0
C@3oool00`000000oooo0?ooo`1=0?ooo`030000o`3oool0oooo01d0oooo
00350?ooo`030000003oool0oooo07h0oooo00<0003o0?ooo`3oool0CP3o
ool00`000000oooo0?ooo`1=0?ooo`030000o`3oool0oooo01d0oooo0035
0?ooo`030000003oool0oooo07h0oooo00<0003o0?ooo`3oool0CP3oool0
0`000000oooo0?ooo`1>0?ooo`030000o`3oool0oooo01`0oooo00350?oo
o`030000003oool0oooo07d0oooo00<0003o0?ooo`3oool0C`3oool00`00
0000oooo0?ooo`1>0?ooo`030000o`3oool0oooo01`0oooo00350?ooo`03
0000003oool0oooo07d0oooo00<0003o0?ooo`3oool0C`3oool00`000000
oooo0?ooo`1>0?ooo`030000o`3oool0oooo01`0oooo00350?ooo`030000
003oool0oooo07d0oooo00<0003o0?ooo`3oool0C`3oool00`000000oooo
0?ooo`1>0?ooo`030000o`3oool0oooo01`0oooo00350?ooo`030000003o
ool0oooo07d0oooo00<0003o0?ooo`3oool0C`3oool00`000000oooo0?oo
o`1?0?ooo`030000o`3oool0oooo01/0oooo00350?ooo`030000003oool0
oooo07d0oooo00<0003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`1?
0?ooo`030000o`3oool0oooo01/0oooo00350?ooo`030000003oool0oooo
07d0oooo00<0003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`1?0?oo
o`030000o`3oool0oooo01/0oooo00350?ooo`030000003oool0oooo07`0
oooo00<0003o0?ooo`3oool0D03oool00`000000oooo0?ooo`1?0?ooo`03
0000o`3oool0oooo01/0oooo00350?ooo`030000003oool0oooo07`0oooo
00<0003o0?ooo`3oool0D03oool00`000000oooo0?ooo`1?0?ooo`030000
o`3oool0oooo01/0oooo00350?ooo`030000003oool0oooo07`0oooo00<0
003o0?ooo`3oool0D03oool00`000000oooo0?ooo`1?0?ooo`030000o`3o
ool0oooo01/0oooo00350?ooo`030000003oool0oooo07`0oooo00<0003o
0?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0
oooo01X0oooo00350?ooo`030000003oool0oooo07`0oooo00<0003o0?oo
o`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo
01X0oooo001f0?ooo`@00000903oool500000280oooo00<000000?ooo`3o
ool02@3oool3000001L0oooo1@00000S0?ooo`@00000;@3oool00`000?l0
oooo0?ooo`0W0?ooo`D00000903oool00`000000oooo0?ooo`0U0?ooo`D0
00009P3oool00`000?l0oooo0?ooo`0J0?ooo`00MP3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0Z0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0V0?ooo`030000o`3oool0oooo01X0oooo001g0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`020?ooo`D000000`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?oo
o`0Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo01X0oooo001`
0?ooo`@00000103oool00`000000oooo0?ooo`0M0?ooo`@00000103oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?oo
o`0R0?ooo`@00000103oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?oo
o`0J0?ooo`00MP3oool010000000oooo0?ooo`00000V0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool08`3o
ool010000000oooo0?ooo`00000/0?ooo`030000o`3oool0oooo02X0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo02H0oooo00<0003o0?ooo`3oool06P3oool007L0oooo0P00
000V0?ooo`800000903oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool05`3oool2000002H0oooo0P00
000]0?ooo`030000o`3oool0oooo02T0oooo0P00000V0?ooo`030000003o
ool0oooo02H0oooo0P00000X0?ooo`030000o`3oool0oooo01X0oooo0035
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000M03o
ool00`000?l0oooo0?ooo`1A0?ooo`030000003oool0oooo0540oooo00<0
003o0?ooo`3oool06@3oool00<D0oooo00<000000?ooo`3oool00`3oool5
000007<0oooo00<0003o0?ooo`3oool0D@3oool00`00ool0oooo0?ooo`1A
0?ooo`030000o`3oool0oooo01T0oooo002L0?ooo`<0o`009@3oool30000
og`0oooo00<0003o0?ooo`3oool09P3oool30?l002H0ooooE`00oolK0?oo
o`00V`3oool50?l002<0oooo1@000?mK0?ooo`80000000<0oooo00000000
00006`3oool00`000?l0oooo0?ooo`0U0?ooo`D0o`00903ooomH003oo`T0
oooo0P0000000`3oool000000000000=0?ooo`00VP3oool70?l00240oooo
1`000?mK0?ooo`030000003oool0000001`0oooo00<0003o0?ooo`3oool0
903oool70?l002<0oooo0P00ool00`3oool000000?ooo`1M0?ooo`030000
003oool0000000h0oooo001]0?ooobd000001`3o000Q000000L0003oE@00
00070?ooo`030000003oool0oooo01L0oooo100000000`000?l000000000
000T000000L0o`008`000002003ooeX000001`3oool00`000000oooo0?oo
o`0=0?ooo`00M@3oool00`000000oooo0?ooo`0R0?ooo`L0o`008@3oool7
0000ob@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0;
0?ooo`80000000<0oooo0000000000006`3oool00`000?l0oooo0?ooo`0T
0?ooo`L0o`008`3oool4003oobT0oooo00<000000?ooo`3oool0<@3oool2
000000030?ooo`000000000000d0oooo002K0?ooo`D0o`008`3oool50000
og/0oooo00<0003o0?ooo`3oool09@3oool50?l002D0ooooE`00oolK0?oo
o`00W03oool30?l000L0oooo1@00000I0?ooo`<0003oO03oool00`000?l0
oooo0?ooo`0V0?ooo`<0o`009`3ooomF003ooa/0oooo002X0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0N`3oool00`000?l0oooo
0?ooo`1A0?ooo`030000003oool0oooo0540oooo00<0003o0?ooo`3oool0
6@3oool00:00oooo1@0000030?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0N`3oool00`000?l0oooo0?ooo`0`0?ooo`D00000703o
ool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo01X0oooo002Q
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`1k0?ooo`030000o`3oool0oooo02X0oooo1@00
00030?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0D03o
ool00`000?l0oooo0?ooo`0J0?ooo`00XP3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0N`3oool0
0`000?l0oooo0?ooo`0[0?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1@0?ooo`030000o`3o
ool0oooo01X0oooo002S0?ooo`040000003oool0oooo0?ooo`800000703o
ool00`000000oooo0?ooo`1k0?ooo`030000o`3oool0oooo02`0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0500oooo00<0003o0?ooo`3oool06P3oool00:40oooo00@00000
0?ooo`3oool00000803oool00`000000oooo0?ooo`1k0?ooo`030000o`3o
ool0oooo02d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo0500oooo00<0003o0?ooo`3oool06P3o
ool00:40oooo1@00000O0?ooo`030000003oool0oooo07`0oooo00<0003o
0?ooo`3oool0:P3oool010000000oooo0?ooo`0000020?ooo`8000007P3o
ool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo01X0oooo0035
0?ooo`030000003oool0oooo07`0oooo00<0003o0?ooo`3oool0:P3oool5
00000240oooo00<000000?ooo`3oool0D03oool00`000?l0oooo0?ooo`0J
0?ooo`00a@3oool00`000000oooo0?ooo`1l0?ooo`030000o`3oool0oooo
0500oooo00<000000?ooo`3oool0D03oool00`000?l0oooo0?ooo`0J0?oo
o`00a@3oool00`000000oooo0?ooo`1l0?ooo`030000o`3oool0oooo0500
oooo00<000000?ooo`3oool0C`3oool00`000?l0oooo0?ooo`0K0?ooo`00
a@3oool00`000000oooo0?ooo`1l0?ooo`030000o`3oool0oooo0500oooo
00<000000?ooo`3oool0C`3oool00`000?l0oooo0?ooo`0K0?ooo`00a@3o
ool00`000000oooo0?ooo`1l0?ooo`030000o`3oool0oooo0500oooo00<0
00000?ooo`3oool0C`3oool00`000?l0oooo0?ooo`0K0?ooo`00a@3oool0
0`000000oooo0?ooo`1m0?ooo`030000o`3oool0oooo04l0oooo00<00000
0?ooo`3oool0C`3oool00`000?l0oooo0?ooo`0K0?ooo`00a@3oool00`00
0000oooo0?ooo`1m0?ooo`030000o`3oool0oooo04l0oooo00<000000?oo
o`3oool0C`3oool00`000?l0oooo0?ooo`0K0?ooo`00a@3oool00`000000
oooo0?ooo`1m0?ooo`030000o`3oool0oooo04l0oooo00<000000?ooo`3o
ool0C`3oool00`000?l0oooo0?ooo`0K0?ooo`00a@3oool00`000000oooo
0?ooo`1m0?ooo`030000o`3oool0oooo04l0oooo00<000000?ooo`3oool0
CP3oool00`000?l0oooo0?ooo`0L0?ooo`00a@3oool00`000000oooo0?oo
o`1m0?ooo`030000o`3oool0oooo04l0oooo00<000000?ooo`3oool0CP3o
ool00`000?l0oooo0?ooo`0L0?ooo`00a@3oool00`000000oooo0?ooo`1m
0?ooo`030000o`3oool0oooo04l0oooo00<000000?ooo`3oool0CP3oool0
0`000?l0oooo0?ooo`0L0?ooo`00a@3oool00`000000oooo0?ooo`1n0?oo
o`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool0CP3oool00`00
0?l0oooo0?ooo`0L0?ooo`00a@3oool00`000000oooo0?ooo`1n0?ooo`03
0000o`3oool0oooo04h0oooo00<000000?ooo`3oool0C@3oool00`000?l0
oooo0?ooo`0M0?ooo`00a@3oool00`000000oooo0?ooo`1o0?ooo`030000
o`3oool0oooo04d0oooo00<000000?ooo`3oool0C@3oool00`000?l0oooo
0?ooo`0M0?ooo`00a@3oool00`000000oooo0?ooo`1o0?ooo`030000o`3o
ool0oooo04d0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?oo
o`0N0?ooo`00a@3oool00`000000oooo0?ooo`1o0?ooo`030000o`3oool0
oooo04d0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`0N
0?ooo`00a@3oool00`000000oooo0?ooo`200?ooo`030000o`3oool0oooo
04`0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`0N0?oo
o`00a@3oool00`000000oooo0?ooo`200?ooo`030000o`3oool0oooo04`0
oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`0N0?ooo`00
a@3oool00`000000oooo0?ooo`200?ooo`030000o`3oool0oooo04`0oooo
00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0O0?ooo`00a@3o
ool00`000000oooo0?ooo`200?ooo`030000o`3oool0oooo04`0oooo00<0
00000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0O0?ooo`00a@3oool0
0`000000oooo0?ooo`210?ooo`030000o`3oool0oooo04/0oooo00<00000
0?ooo`3oool0BP3oool00`000?l0oooo0?ooo`0P0?ooo`00a@3oool00`00
0000oooo0?ooo`210?ooo`030000o`3oool0oooo04/0oooo00<000000?oo
o`3oool0BP3oool00`000?l0oooo0?ooo`0P0?ooo`00a@3oool00`000000
oooo0?ooo`220?ooo`030000o`3oool0oooo04X0oooo00<000000?ooo`3o
ool0B@3oool00`000?l0oooo0?ooo`0Q0?ooo`00a@3oool00`000000oooo
0?ooo`220?ooo`030000o`3oool0oooo04X0oooo00<000000?ooo`3oool0
B@3oool00`000?l0oooo0?ooo`0Q0?ooo`00a@3oool00`000000oooo0?oo
o`230?ooo`030000o`3oool0oooo04T0oooo00<000000?ooo`3oool0B@3o
ool00`000?l0oooo0?ooo`0Q0?ooo`00a@3oool00`000000oooo0?ooo`23
0?ooo`030000o`3oool0oooo04T0oooo00<000000?ooo`3oool0B03oool0
0`000?l0oooo0?ooo`0R0?ooo`00a@3oool00`000000oooo0?ooo`240?oo
o`030000o`3oool0oooo04P0oooo00<000000?ooo`3oool0B03oool00`00
0?l0oooo0?ooo`0R0?ooo`00_P3oool500000080oooo00<000000?ooo`3o
ool0Q03oool00`000?l0oooo0?ooo`180?ooo`030000003oool0oooo04L0
oooo00<0003o0?ooo`3oool08`3oool00<00oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`250?ooo`030000o`3oool0oooo0400oooo
1@0000020?ooo`030000003oool0oooo04L0oooo00<0003o0?ooo`3oool0
8`3oool00<00oooo00<000000?ooo`3oool00P3oool2000008L0oooo00<0
003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo04H0oooo00<0003o0?ooo`3oool0903oool00<00oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`260?ooo`030000o`3oool0
oooo0440oooo00<000000?ooo`3oool00P3oool2000004L0oooo00<0003o
0?ooo`3oool0903oool00<00oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`270?ooo`030000o`3oool0oooo0400oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`150?ooo`030000o`3oool0oooo
02D0oooo002o0?ooo`800000103oool00`000000oooo0?ooo`270?ooo`03
0000o`3oool0oooo0400oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`150?ooo`030000o`3oool0oooo02D0oooo00350?ooo`030000
003oool0oooo08P0oooo00<0003o0?ooo`3oool0?P3oool2000000@0oooo
00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`0V0?ooo`00a@3o
ool00`000000oooo0?ooo`280?ooo`030000o`3oool0oooo04@0oooo00<0
00000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0W0?ooo`00a@3oool0
0`000000oooo0?ooo`290?ooo`030000o`3oool0oooo04<0oooo00<00000
0?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0X0?ooo`00a@3oool00`00
0000oooo0?ooo`2:0?ooo`030000o`3oool0oooo0480oooo00<000000?oo
o`3oool0@@3oool00`000?l0oooo0?ooo`0Y0?ooo`00a@3oool00`000000
oooo0?ooo`2:0?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3o
ool0@@3oool00`000?l0oooo0?ooo`0Y0?ooo`00a@3oool00`000000oooo
0?ooo`2;0?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0
@03oool00`000?l0oooo0?ooo`0Z0?ooo`00a@3oool00`000000oooo0?oo
o`2;0?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0?`3o
ool00`000?l0oooo0?ooo`0[0?ooo`00a@3oool00`000000oooo0?ooo`2<
0?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3oool0?`3oool0
0`000?l0oooo0?ooo`0[0?ooo`00a@3oool00`000000oooo0?ooo`2=0?oo
o`80003o@03oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo
02`0oooo00350?ooo`030000003oool0oooo08h0oooo00<0003o0?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo02`0
oooo00350?ooo`030000003oool0oooo08l0oooo00<0003o0?ooo`3oool0
?@3oool00`000000oooo0?ooo`0l0?ooo`80003o;`3oool00<D0oooo00<0
00000?ooo`3oool0T03oool00`000?l0oooo0?ooo`0l0?ooo`030000003o
ool0oooo03/0oooo00<0003o0?ooo`3oool0;`3oool00<D0oooo00<00000
0?ooo`3oool0T@3oool00`000?l0oooo0?ooo`0k0?ooo`030000003oool0
oooo03/0oooo00<0003o0?ooo`3oool0;`3oool00<D0oooo00<000000?oo
o`3oool0TP3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo
03X0oooo00<0003o0?ooo`3oool0<03oool00<D0oooo00<000000?ooo`3o
ool0T`3oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo03T0
oooo00<0003o0?ooo`3oool0<@3oool00<D0oooo00<000000?ooo`3oool0
U03oool00`000?l0oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo
00<0003o0?ooo`3oool0<P3oool00<D0oooo00<000000?ooo`3oool0U@3o
ool00`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<0
003o0?ooo`3oool0<`3oool00<D0oooo00<000000?ooo`3oool0UP3oool0
0`000?l0oooo0?ooo`0f0?ooo`030000003oool0oooo03H0oooo00<0003o
0?ooo`3oool0=03oool00<D0oooo00<000000?ooo`3oool0U`3oool00`00
0?l0oooo0?ooo`0e0?ooo`030000003oool0oooo03D0oooo00<0003o0?oo
o`3oool0=@3oool00<D0oooo00<000000?ooo`3oool0V03oool00`000?l0
oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<0003o0?ooo`3o
ool0=P3oool00<D0oooo00<000000?ooo`3oool0V@3oool00`000?l0oooo
0?ooo`0c0?ooo`030000003oool0oooo0380oooo0P000?li0?ooo`00a@3o
ool00`000000oooo0?ooo`2J0?ooo`80003o<`3oool00`000000oooo0?oo
o`0a0?ooo`030000o`3oool0oooo03T0oooo00350?ooo`030000003oool0
oooo09`0oooo00<0003o0?ooo`3oool0<03oool00`000000oooo0?ooo`0`
0?ooo`030000o`3oool0oooo03X0oooo00350?ooo`030000003oool0oooo
09d0oooo00<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0_0?oo
o`030000o`3oool0oooo03/0oooo00350?ooo`030000003oool0oooo09h0
oooo00<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`80
003o?P3oool00<D0oooo00<000000?ooo`3oool0W`3oool20000obh0oooo
00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0n0?ooo`00a@3o
ool00`000000oooo0?ooo`2Q0?ooo`030000o`3oool0oooo02/0oooo00<0
00000?ooo`3oool0:P3oool20000od40oooo00350?ooo`030000003oool0
oooo0:80oooo0P000?l[0?ooo`030000003oool0oooo02P0oooo0P000?m3
0?ooo`00a@3oool00`000000oooo0?ooo`2T0?ooo`80003o:@3oool00`00
0000oooo0?ooo`0V0?ooo`80003oA@3oool00<D0oooo00<000000?ooo`3o
ool0YP3oool20000obL0oooo00<000000?ooo`3oool09@3oool00`000?l0
oooo0?ooo`150?ooo`00a@3oool00`000000oooo0?ooo`2X0?ooo`030000
o`3oool0oooo02@0oooo00<000000?ooo`3oool08`3oool20000odP0oooo
00350?ooo`030000003oool0oooo0:T0oooo0P000?lT0?ooo`030000003o
ool0oooo0240oooo0P000?m:0?ooo`00a@3oool00`000000oooo0?ooo`2[
0?ooo`80003o8P3oool00`000000oooo0?ooo`0O0?ooo`80003oC03oool0
0<D0oooo00<000000?ooo`3oool0[@3oool40000oah0oooo00<000000?oo
o`3oool07@3oool20000odh0oooo002n0?ooo`@000000`3oool00`000000
oooo0?ooo`2a0?ooo`80003o703oool00`000000oooo0?ooo`0J0?ooo`<0
003oD03oool00;h0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2c0?ooo`<0003o6@3oool00`000000oooo0?ooo`0H0?ooo`80003o
D`3oool00;l0oooo00<000000?ooo`3oool00`3oool200000;L0oooo0P00
0?lG0?ooo`030000003oool0oooo01@0oooo10000?mE0?ooo`00`03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0;P0oooo10000?lC
0?ooo`030000003oool0oooo0100oooo10000?mI0?ooo`00_P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0;`0oooo1P000?l=
0?ooo`030000003oool0oooo00X0oooo1P000?mM0?ooo`00_`3oool20000
00@0oooo00<000000?ooo`3oool0`P3ooolJ0000of<0oooo00350?ooo`03
0000003oool0oooo0<l0oooo00<000000?ooo`3oool0K@3oool00<D0oooo
00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`1]0?ooo`00a@3o
ool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo06d0oooo0035
0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0K@3oool0
0<D0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`1]0?oo
o`00o`3ooooo0?ooo`T0oooo003o0?ooool0oooo2@3oool00?l0ooooo`3o
ool90?ooo`00o`3ooooo0?ooo`T0oooo003o0?ooool0oooo2@3oool00?l0
ooooo`3oool90?ooo`00``3oool200000=00oooo0P00001`0?ooo`00a03o
ool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo06h0oooo0035
0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0K@3oool0
0<@0oooo00<000000?ooo`000000c`3oool00`000000oooo0000001^0?oo
o`00``3oool010000000oooo0?ooo`00003>0?ooo`040000003oool0oooo
000006h0oooo00320?ooo`<0000000<0oooo000000000000c03oool30000
00030?ooo`000000000006d0oooo003o0?ooool0oooo2@3oool00?l0oooo
o`3oool90?ooo`00o`3ooooo0?ooo`T0oooo003o0?ooool0oooo2@3oool0
0001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{519, 199},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The function  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ x\^\[Alpha]\/\(x \((x\  + \ 1)\)\)\)]],
  "  has a nonzero pole at the point ",
  Cell[BoxData[
      \(z\_1 = \(-1\)\)]],
  ", and the denominator has a zero of order at most ",
  StyleBox["1",
    FontFamily->"Courier New"],
  " (in fact, exactly ",
  StyleBox["1",
    FontFamily->"Courier New"],
  ") at the origin.  Calculating the residue we get  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(Res[
          f, \(-1\)]\ \  = \ \ lim\+\(z\  \[Rule] \(-1\)\)\ \((z + 1)\) 
            f \((z)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] \(-1\)\)\ \((z + 1)\) 
            x\^\[Alpha]\/\(x \((x\  + \ 1)\)\)\)\)\(\ \ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] \(-1\)\)x\^\[Alpha]\/x\ \  = \ \ \
\((\(-1\))\)\^\[Alpha]\/\(-1\)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\
\((\(-1\))\)\^\[Alpha]\/\(-1\)\ \  = \ \ \(\(\((\[ExponentialE]\^\(\
\[ImaginaryI]\ \[Pi]\))\)\^\[Alpha]\)\(\ \
\)\)\/\(-1\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(\
\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Alpha]\ \[Pi]\)\)\(\ \
\)\)\/\(-1\)\)\)\)}]],
  "\n\nUsing Theorem 8.7, we have  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(P . 
          V . \(\[Integral]\_0\%\[Infinity]\( x\^\[Alpha]\/\(x \((x\  + \ 
                        1)\)\)\) \[DifferentialD]x\)\ \  = \ \ \(2  \[Pi]\ \
\[ImaginaryI]\)\/\(1\  - \ \[ExponentialE]\^\(\[ImaginaryI]\ \[Alpha]\ 2  \
\[Pi]\)\)\ Res[f, z\_1]\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \(\(\(=\)\(\ \ \)\(\(2  \[Pi]\ \[ImaginaryI]\)\/\(1\  - \ \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Alpha]\ 2  \[Pi]\)\)\ Res[
            f, \(-1\)]\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \(\(\(=\)\(\ \ \)\(\(2  \[Pi]\ \[ImaginaryI]\)\/\(1\  - \ \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Alpha]\ 2  \[Pi]\)\)\ \((\(\(\
\[ExponentialE]\^\(\[ImaginaryI]\ \[Alpha]\ \[Pi]\)\)\(\ \)\)\/\(-1\))\)\ \  \
= \ \ \(2  \[Pi]\ \[ImaginaryI]\)\/\(\[ExponentialE]\^\(\[ImaginaryI]\
\ \ \[Alpha]\ \[Pi]\) - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Alpha]\ \
\[Pi]\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \(\(\(=\)\(\ \ \)\(\[Pi]\/\(\(\[ExponentialE]\^\(\[ImaginaryI]\
\ \ \[Alpha]\ \[Pi]\) - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Alpha]\ \
\[Pi]\)\)\/\(2\ \[ImaginaryI]\)\)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \(\(=\)\(\ \ \)\(\[Pi]\/\(sin\ \[Alpha]\ \[Pi]\)\)\)\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.23.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function and  ",
  Cell[BoxData[
      \(f[z] = z\^\[Alpha]\/\(z \((z\  + \ 1)\)\)\)],
    AspectRatioFixed->True],
  "  and ",
  "locate the",
  " isolated singularities."
}], "Text"],

Cell[BoxData[{
    \(Z = \(z = \(x = 0\)\); Remove[x, z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, P, Q, Res1, solset, val];\)\ \), "\[IndentingNewLine]", 
    \(\(P[z_] = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Q[z_] = z \((z + 1)\);\)\ \), "\n", 
    \(\(f[
          z_]\  = \ \(z\^\[Alpha]\ P[z]\)\/Q[z];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P[z]\/Q[z]\) = \>\"", 
        P[z]\/Q[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        Denominator[P[z]\/Q[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[P[z]\/Q[z]] \[Equal] 0, 
            z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The singularities of \!\(P[z]\/Q[z]\) are\>\""];\)\ \), \
"\n", 
    \(\(Z\_1\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        ComplexExpand[
          ReplaceAll[z, 
            solset\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)\
]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", 
        Z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell["Which pole(s) are non-zero ?", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Blue, 
              PointSize[0.03], 
              Point[{Re[Z\_2], Im[Z\_2]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] + 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] - 0.1}, {\(-1\), 
                0}]}];\)\ \), "\n", 
    \(\(Show[dots, centers, 
        PlotRange \[Rule] {{\(-2.2\), 2.2}, {\(-2.2\), 2.2}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<, Is  \>", 
        Z\_1, "\< \[NotEqual] 0 ? \>", Z\_1 \[NotEqual] 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<,  Is   \>", 
        Z\_2, "\< \[NotEqual] 0 ? \>", 
        Z\_2 \[NotEqual] 0];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Compute the residues at  ",
  Cell[BoxData[
      \(z\_1 = \(-1\)\)]],
  ",  and use the residue calculus to compute the value of the integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Res1\  = \ Residue[f[z], {z, Z\_1}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", Z\_1, "\<] = \>", 
        Res1];\)\ \), "\[IndentingNewLine]", 
    \(\(Res1 = 
        ComplexExpand[Res1, 
          TargetFunctions \[Rule] {Im, Re}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", Z\_1, "\<] = \>", 
        Res1];\)\ \), "\[IndentingNewLine]", 
    \(\(Res1 = TrigToExp[Res1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", Z\_1, "\<] = \>", 
        Res1];\)\ \), "\[IndentingNewLine]", 
    \(\(val\  = \ \(2  \[Pi]\ \[ImaginaryI]\)\/\(1 - \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Alpha]\ 2  \[Pi]\)\)\ \ Res1;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{{Red, PointSize[0.03], 
              Point[{Re[Z\_1], Im[Z\_1]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(center = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] + 0.2}, {\(-1\), 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ 
        Graphics[{{VioletRed, 
              Circle[{0, 0}, 
                2, {0, 2  \[Pi]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(segment = 
        Graphics[{Thickness[0.015], Magenta, 
            Line[{{0, 0}, {2, 0}}]}];\)\ \), "\n", 
    \(\(Show[center, contour, segment, dot, 
        PlotRange \[Rule] {{\(-2.1\), 2.1}, {\(-2.1\), 2.1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 2, 1]}, 
        AspectRatio \[Rule] 1, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], \*"\"\<) \[DifferentialD]z = \!\(\(2  \[Pi]\\\ \
\[ImaginaryI]\)\/\(1\\\  - \\\ \[ExponentialE]\^\(\[ImaginaryI]\\\ \[Alpha]\\\
\ 2  \[Pi]\)\)\)(\>\"", \ Res1\ , "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = \>", 
        FullSimplify[val]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The contour is the circle \!\(C\_R\) and two segments \
near [0,R],\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and a little semicircle around the origin in quadrants II & \
III,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<taken with the positive orientation.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value \
of the integral.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_0\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_0\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        FullSimplify[val]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in \"PrincipalValue\" option to evaluate this definite integral \
."
}], "Text"],

Cell[BoxData[{
    \(\(val\  = \ 
        Integrate[f[x], {x, 0, \[Infinity]}, 
          Assumptions \[Rule] {0 < Re[\[Alpha]] < 1}, 
          PrincipalValue \[Rule] True];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P.V.\!\(\[Integral]\_0\%\[Infinity]\)\>\"", 
        f[x], "\< \[DifferentialD]x = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Which is also the correct answer.", "Text"]
}, Closed]],

Cell["\<\
\tWe can apply the preceding ideas to other multivalued functions.  \
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 8.24.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  "Evaluate",
  "  ",
  Cell[BoxData[
      \(P . 
          V . \ \(\[Integral]\_0\%\[Infinity]\(\( ln\ x\)\/\(x\^2\  + \ 
                    a\^2\)\) \[DifferentialD]x\)\  = \ \(\[Pi]\ Log[a]\)\/\(2\
\ a\)\)]],
  ",  where  ",
  Cell[BoxData[
      \(a > 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:d0000ab000`400?l0
0000o`00003oo`3ooooo0?oookH0oooo003o0?ooool0oooo]P3oool00?l0
ooooo`3ooonf0?ooo`00o`3ooooo0?oookH0oooo003o0?ooool0oooo]P3o
ool00;00oooo00<000000?ooo`3oool0o`3ooooo0?ooo`<0oooo002`0?oo
o`030000003oool0oooo0?/0oooo1@00001P0?ooo`D00000W03oool00;00
oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`1R0?ooo`03
0000003oool0oooo09`0oooo002`0?ooo`030000003oool0oooo0?d0oooo
00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`2L0?ooo`00/03o
ool00`000000oooo0?ooo`3e0?ooo`@00000103oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo09`0oooo002_0?ooo`<0003ooP3oool0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo09`0oooo002^0?oo
o`D0003oo03oool2000006<0oooo0P00002N0?ooo`00X@3oool5000000L0
oooo1`000?oo0?ooool0oooo0P3oool009/0oooo100000020?ooo`@00000
203oool70000ool0ooooo`3oool20?ooo`00Y03oool00`000000oooo0?oo
o`060?ooo`L0003o1`3oool500000?l0oooom@3oool00:80oooo0`000009
0?ooo`D0003o2P3oool00`000000oooo0?ooo`3o0?ooooD0oooo002_0?oo
o`<0003o0`3oool5000000<0oooo00<000000?ooo`3oool0o`3ooolR0?oo
o`030000003oool0oooo0=00oooo002`0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`3o0?oo
ob80oooo00<000000?ooo`3oool0Z@3oool2000000030?ooo`0000000000
0280oooo002`0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`220?oooiL00?oo203oool00`000000
oooo0?ooo`050?oooiL00?oo3P3oool00`000000oooo0000000S0?ooo`00
/03oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`80
0000P@3oool3000009L00?oo4000002G003oo`@000002`3oool00`000000
oooo0?ooo`0R0?ooo`00/03oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000008P0ooooU`00ool80?ooo`030000003oool0oooo00D0
ooooU`00ool=0?ooo`80000000<0oooo0000000000008P3oool00;00oooo
00<000000?ooo`3oool00`3oool5000008L0ooooU`00ool80?ooo`030000
003oool0oooo00D0ooooU`00oold0?ooo`00/03oool00`000000oooo0?oo
o`2A0?ooo`030000o`3oool0oooo08l0oooo0P000?l90?ooo`030000003o
ool0oooo00H0oooo0P000?nB0?ooo`030000o`3oool0oooo03<0oooo002`
0?ooo`030000003oool0oooo0940oooo00<0003o0?ooo`3oool0S`3oool3
0000o`P0oooo00<000000?ooo`3oool01P3oool20000oi80oooo00<0003o
0?ooo`3oool0<`3oool00;00oooo00<000000?ooo`3oool0T@3oool00`00
0?l0oooo0?ooo`2@0?ooo`<0003o1`3oool00`000000oooo0?ooo`050?oo
o`<0003oTP3oool00`000?l0oooo0?ooo`0c0?ooo`00/03oool00`000000
oooo0?ooo`2A0?ooo`030000o`3oool0oooo0940oooo0`000?l60?ooo`03
0000003oool0oooo00@0oooo0`000?nB0?ooo`030000o`3oool0oooo03@0
oooo002`0?ooo`030000003oool0oooo0940oooo00<0003o0?ooo`3oool0
TP3oool30000o`D0oooo00<000000?ooo`3oool00`3oool30000oi<0oooo
00<0003o0?ooo`3oool0=03oool00;00oooo00<000000?ooo`3oool0T@3o
ool00`000?l0oooo0?ooo`2C0?ooo`@0003o0`3oool010000000oooo0?oo
o`3oool40000oi@0oooo00<0003o0?ooo`3oool0=03oool00;00oooo00<0
00000?ooo`3oool0TP3oool00`000?l0oooo0?ooo`2C0?ooo`D0003o00<0
oooo0000003oool01@000?nE0?ooo`030000o`3oool0oooo03@0oooo002`
0?ooo`030000003oool0oooo0980oooo00<0003o0?ooo`3oool0U@3oool9
0000oiL0oooo00<0003o0?ooo`3oool0=03oool00;00oooo00<000000?oo
o`3oool0TP3oool00`000?l0oooo0?ooo`2G0?ooo`D0003oV@3oool00`00
0?l0oooo0?ooo`0d0?ooo`00/03oool00`000000oooo0?ooo`2B0?ooo`03
0000o`3oool0oooo09T0oooo00<000000?ooo`3oool0V@3oool00`000?l0
oooo0?ooo`0d0?ooo`00/03oool00`000000oooo0?ooo`2B0?ooo`030000
o`3oool0oooo09T0oooo00<000000?ooo`3oool0V@3oool00`000?l0oooo
0?ooo`0d0?ooo`00/03oool00`000000oooo0?ooo`2B0?ooo`030000o`3o
ool0oooo09T0oooo00<000000?ooo`3oool0V@3oool00`000?l0oooo0?oo
o`0d0?ooo`00/03oool00`000000oooo0?ooo`2B0?ooo`030000o`3oool0
oooo09T0oooo00<000000?ooo`3oool0V@3oool00`000?l0oooo0?ooo`0d
0?ooo`00/03oool00`000000oooo0?ooo`2B0?ooo`030000o`3oool0oooo
09T0oooo00<000000?ooo`3oool0V@3oool00`000?l0oooo0?ooo`0d0?oo
o`00/03oool00`000000oooo0?ooo`2B0?ooo`030000o`3oool0oooo09T0
oooo00<000000?ooo`3oool0V@3oool00`000?l0oooo0?ooo`0d0?ooo`00
/03oool00`000000oooo0?ooo`2B0?ooo`030000o`3oool0oooo09T0oooo
00<000000?ooo`3oool0V03oool00`000?l0oooo0?ooo`0e0?ooo`00/03o
ool00`000000oooo0?ooo`2B0?ooo`030000o`3oool0oooo09T0oooo00<0
00000?ooo`3oool0V03oool00`000?l0oooo0?ooo`0e0?ooo`00/03oool0
0`000000oooo0?ooo`2B0?ooo`030000o`3oool0oooo09T0oooo00<00000
0?ooo`3oool0V03oool00`000?l0oooo0?ooo`0e0?ooo`00/03oool00`00
0000oooo0?ooo`2C0?ooo`030000o`3oool0oooo09P0oooo00<000000?oo
o`3oool0V03oool00`000?l0oooo0?ooo`0e0?ooo`00/03oool00`000000
oooo0?ooo`2C0?ooo`030000o`3oool0oooo09P0oooo00<000000?ooo`3o
ool0V03oool00`000?l0oooo0?ooo`0e0?ooo`00/03oool00`000000oooo
0?ooo`2C0?ooo`030000o`3oool0oooo09P0oooo00<000000?ooo`3oool0
V03oool00`000?l0oooo0?ooo`0e0?ooo`00/03oool00`000000oooo0?oo
o`2C0?ooo`030000o`3oool0oooo09P0oooo00<000000?ooo`3oool0V03o
ool00`000?l0oooo0?ooo`0e0?ooo`00/03oool00`000000oooo0?ooo`2C
0?ooo`030000o`3oool0oooo09P0oooo00<000000?ooo`3oool0U`3oool0
0`000?l0oooo0?ooo`0f0?ooo`00/03oool00`000000oooo0?ooo`2D0?oo
o`030000o`3oool0oooo09L0oooo00<000000?ooo`3oool0U`3oool00`00
0?l0oooo0?ooo`0f0?ooo`00/03oool00`000000oooo0?ooo`2D0?ooo`03
0000o`3oool0oooo09L0oooo00<000000?ooo`3oool0U`3oool00`000?l0
oooo0?ooo`0f0?ooo`00/03oool00`000000oooo0?ooo`2D0?ooo`030000
o`3oool0oooo09L0oooo00<000000?ooo`3oool0U`3oool00`000?l0oooo
0?ooo`0f0?ooo`00/03oool00`000000oooo0?ooo`2D0?ooo`030000o`3o
ool0oooo09L0oooo00<000000?ooo`3oool0U`3oool00`000?l0oooo0?oo
o`0f0?ooo`00/03oool00`000000oooo0?ooo`2D0?ooo`030000o`3oool0
oooo09L0oooo00<000000?ooo`3oool0U`3oool00`000?l0oooo0?ooo`0f
0?ooo`00/03oool00`000000oooo0?ooo`2D0?ooo`030000o`3oool0oooo
09L0oooo00<000000?ooo`3oool0UP3oool00`000?l0oooo0?ooo`0g0?oo
o`00/03oool00`000000oooo0?ooo`2E0?ooo`030000o`3oool0oooo09H0
oooo00<000000?ooo`3oool0UP3oool00`000?l0oooo0?ooo`0g0?ooo`00
Z@3oool500000080oooo00<000000?ooo`3oool0U@3oool00`000?l0oooo
0?ooo`2F0?ooo`030000003oool0oooo09H0oooo00<0003o0?ooo`3oool0
=`3oool00:/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`2E0?ooo`030000o`3oool0oooo09H0oooo00<000000?ooo`3oool0UP3o
ool00`000?l0oooo0?ooo`0g0?ooo`00Z`3oool00`000000oooo0?ooo`02
0?ooo`800000UP3oool00`000?l0oooo0?ooo`2F0?ooo`030000003oool0
oooo09D0oooo00<0003o0?ooo`3oool0>03oool00:<0oooo100000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0UP3oool00`00
0?l0oooo0?ooo`2E0?ooo`030000003oool0oooo09D0oooo00<0003o0?oo
o`3oool0>03oool00:/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`2F0?ooo`030000o`3oool0oooo09D0oooo00<000000?ooo`3o
ool0U@3oool00`000?l0oooo0?ooo`0h0?ooo`00ZP3oool2000000@0oooo
00<000000?ooo`3oool0UP3oool00`000?l0oooo0?ooo`2E0?ooo`030000
003oool0oooo09D0oooo00<0003o0?ooo`3oool0>03oool00;00oooo00<0
00000?ooo`3oool0UP3oool00`000?l0oooo0?ooo`2E0?ooo`030000003o
ool0oooo09@0oooo00<0003o0?ooo`3oool0>@3oool00;00oooo00<00000
0?ooo`3oool0UP3oool00`000?l0oooo0?ooo`2E0?ooo`030000003oool0
oooo09@0oooo00<0003o0?ooo`3oool0>@3oool00;00oooo00<000000?oo
o`3oool0U`3oool00`000?l0oooo0?ooo`2D0?ooo`030000003oool0oooo
09@0oooo00<0003o0?ooo`3oool0>@3oool00;00oooo00<000000?ooo`3o
ool0U`3oool00`000?l0oooo0?ooo`2D0?ooo`030000003oool0oooo09<0
oooo00<0003o0?ooo`3oool0>P3oool00;00oooo00<000000?ooo`3oool0
U`3oool00`000?l0oooo0?ooo`2D0?ooo`030000003oool0oooo09<0oooo
00<0003o0?ooo`3oool0>P3oool00;00oooo00<000000?ooo`3oool0U`3o
ool00`000?l0oooo0?ooo`2D0?ooo`030000003oool0oooo09<0oooo00<0
003o0?ooo`3oool0>P3oool00;00oooo00<000000?ooo`3oool0V03oool0
0`000?l0oooo0?ooo`2C0?ooo`030000003oool0oooo09<0oooo00<0003o
0?ooo`3oool0>P3oool00;00oooo00<000000?ooo`3oool0V03oool00`00
0?l0oooo0?ooo`2C0?ooo`030000003oool0oooo0980oooo00<0003o0?oo
o`3oool0>`3oool00;00oooo00<000000?ooo`3oool0V@3oool00`000?l0
oooo0?ooo`2B0?ooo`030000003oool0oooo0980oooo00<0003o0?ooo`3o
ool0>`3oool00;00oooo00<000000?ooo`3oool0V@3oool00`000?l0oooo
0?ooo`2B0?ooo`030000003oool0oooo0980oooo00<0003o0?ooo`3oool0
>`3oool00;00oooo00<000000?ooo`3oool0V@3oool00`000?l0oooo0?oo
o`2B0?ooo`030000003oool0oooo0980oooo00<0003o0?ooo`3oool0>`3o
ool00;00oooo00<000000?ooo`3oool0V@3oool00`000?l0oooo0?ooo`29
0?ooo`D00000103oool00`000000oooo0?ooo`2A0?ooo`030000o`3oool0
oooo03`0oooo002`0?ooo`030000003oool0oooo09X0oooo00<0003o0?oo
o`3oool0RP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0940oooo00<0003o0?ooo`3oool0?03oool00;00oooo00<000000?ooo`3o
ool0VP3oool00`000?l0oooo0?ooo`2:0?ooo`030000003oool0oooo00@0
oooo0`00002@0?ooo`030000o`3oool0oooo03d0oooo002`0?ooo`030000
003oool0oooo09X0oooo00<0003o0?ooo`3oool0RP3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0900oooo00<0003o0?ooo`3oool0
?@3oool00;00oooo00<000000?ooo`3oool0V`3oool00`000?l0oooo0?oo
o`290?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0T03o
ool00`000?l0oooo0?ooo`0m0?ooo`00/03oool00`000000oooo0?ooo`2K
0?ooo`030000o`3oool0oooo08P0oooo0P0000060?ooo`030000003oool0
oooo08l0oooo00<0003o0?ooo`3oool0?P3oool00;00oooo00<000000?oo
o`3oool0W03oool00`000?l0oooo0?ooo`2?0?ooo`030000003oool0oooo
08l0oooo00<0003o0?ooo`3oool0?P3oool00;00oooo00<000000?ooo`3o
ool0W03oool00`000?l0oooo0?ooo`2?0?ooo`030000003oool0oooo08h0
oooo00<0003o0?ooo`3oool0?`3oool00;00oooo00<000000?ooo`3oool0
W03oool00`000?l0oooo0?ooo`2?0?ooo`030000003oool0oooo08h0oooo
00<0003o0?ooo`3oool0?`3oool00;00oooo00<000000?ooo`3oool0W03o
ool00`000?l0oooo0?ooo`2?0?ooo`030000003oool0oooo08h0oooo00<0
003o0?ooo`3oool0?`3oool00;00oooo00<000000?ooo`3oool0W@3oool0
0`000?l0oooo0?ooo`2>0?ooo`030000003oool0oooo08h0oooo00<0003o
0?ooo`3oool0?`3oool00;00oooo00<000000?ooo`3oool0WP3oool00`00
0?l0oooo0?ooo`2=0?ooo`030000003oool0oooo08d0oooo00<0003o0?oo
o`3oool0@03oool00;00oooo00<000000?ooo`3oool0WP3oool00`000?l0
oooo0?ooo`2=0?ooo`030000003oool0oooo08`0oooo00<0003o0?ooo`3o
ool0@@3oool00;00oooo00<000000?ooo`3oool0W`3oool00`000?l0oooo
0?ooo`2<0?ooo`030000003oool0oooo08`0oooo00<0003o0?ooo`3oool0
@@3oool00640oooo1000000T0?ooo`D000008P3oool00`000000oooo0?oo
o`0S0?ooo`D000008`3oool400000500oooo00<0003o0?ooo`3oool0S03o
ool00`000000oooo0?ooo`2;0?ooo`030000o`3oool0oooo0480oooo001Q
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0DP3oool00`000?l0oooo0?ooo`2;0?ooo`030000003oool0
oooo08/0oooo00<0003o0?ooo`3oool0@P3oool00680oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1A0?oo
o`030000o`3oool0oooo08/0oooo00<000000?ooo`3oool0R`3oool00`00
0?l0oooo0?ooo`120?ooo`00F`3oool4000000@0oooo00<000000?ooo`3o
ool07@3oool4000000@0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0D03oool00`000?l0oooo0?ooo`2;0?ooo`030000003oool0oooo08/0
oooo00<0003o0?ooo`3oool0@P3oool00640oooo00@000000?ooo`3oool0
00009P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool08`3oool010000000oooo0?ooo`00001B0?oo
o`030000o`3oool0oooo08X0oooo00<000000?ooo`3oool0RP3oool00`00
0?l0oooo0?ooo`130?ooo`00HP3oool2000002H0oooo0P00000T0?ooo`03
0000003oool0oooo02@0oooo0P00000V0?ooo`800000D`3oool00`000?l0
oooo0?ooo`2:0?ooo`030000003oool0oooo08T0oooo00<0003o0?ooo`3o
ool0A03oool00;00oooo00<000000?ooo`3oool0XP3oool00`000?l0oooo
0?ooo`290?ooo`030000003oool0oooo08T0oooo00<0003o0?ooo`3oool0
A03oool00;00oooo00<000000?ooo`3oool0XP3oool00`000?l0oooo0?oo
o`290?ooo`030000003oool0oooo08P0oooo00<0003o0?ooo`3oool0A@3o
ool00;00oooo00<000000?ooo`3oool0X`3oool00`000?l0oooo0?ooo`28
0?ooo`030000003oool0oooo08P0oooo00<0003o0?ooo`3oool0A@3oool0
0;00oooo00<000000?ooo`3oool0F`3oool2000000030?ooo`0000000000
04@0oooo00<0003o0?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?oo
o`030000o`3oool0oooo04H0oooo002`0?ooo`030000003oool0oooo05`0
oooo00<000000?ooo`000000A@3oool00`000?l0oooo0?ooo`270?ooo`03
0000003oool0oooo08H0oooo00<0003o0?ooo`3oool0A`3oool005P0oooo
/@0000070?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool0
QP3oool00`000000oooo0?ooo`260?ooo`030000o`3oool0oooo04L0oooo
001P0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool02`3oool2000000030?ooo`000000000004D0oooo00<0
003o0?ooo`3oool0QP3oool00`000000oooo0?ooo`250?ooo`030000o`3o
ool0oooo04P0oooo002`0?ooo`030000003oool0oooo0:H0oooo00<0003o
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`250?ooo`030000o`3oool0
oooo04P0oooo002`0?ooo`030000003oool0oooo0:L0oooo00<0003o0?oo
o`3oool0Q03oool00`000000oooo0?ooo`240?ooo`030000o`3oool0oooo
04T0oooo002`0?ooo`030000003oool0oooo0:L0oooo00<0003o0?ooo`3o
ool0Q03oool00`000000oooo0?ooo`230?ooo`030000o`3oool0oooo04X0
oooo002`0?ooo`030000003oool0oooo0:P0oooo00<0003o0?ooo`3oool0
P`3oool00`000000oooo0?ooo`230?ooo`030000o`3oool0oooo04X0oooo
002`0?ooo`030000003oool0oooo0:P0oooo00<0003o0?ooo`3oool0P`3o
ool00`000000oooo0?ooo`220?ooo`030000o`3oool0oooo04/0oooo002`
0?ooo`030000003oool0oooo0:T0oooo00<0003o0?ooo`3oool0PP3oool0
0`000000oooo0?ooo`220?ooo`030000o`3oool0oooo04/0oooo002`0?oo
o`030000003oool0oooo0:X0oooo00<0003o0?ooo`3oool0P@3oool00`00
0000oooo0?ooo`210?ooo`030000o`3oool0oooo04`0oooo002`0?ooo`03
0000003oool0oooo0:X0oooo00<0003o0?ooo`3oool0P@3oool00`000000
oooo0?ooo`200?ooo`030000o`3oool0oooo04d0oooo002`0?ooo`030000
003oool0oooo0:/0oooo00<0003o0?ooo`3oool0P03oool00`000000oooo
0?ooo`200?ooo`030000o`3oool0oooo04d0oooo002`0?ooo`030000003o
ool0oooo0:/0oooo00<0003o0?ooo`3oool0P03oool00`000000oooo0?oo
o`1o0?ooo`030000o`3oool0oooo04h0oooo002`0?ooo`030000003oool0
oooo0:`0oooo00<0003o0?ooo`3oool0O`3oool00`000000oooo0?ooo`1o
0?ooo`030000o`3oool0oooo04h0oooo002`0?ooo`030000003oool0oooo
0:d0oooo00<0003o0?ooo`3oool0OP3oool00`000000oooo0?ooo`1n0?oo
o`030000o`3oool0oooo04l0oooo002`0?ooo`030000003oool0oooo0:d0
oooo00<0003o0?ooo`3oool0OP3oool00`000000oooo0?ooo`1m0?ooo`03
0000o`3oool0oooo0500oooo002`0?ooo`030000003oool0oooo0:h0oooo
00<0003o0?ooo`3oool0O@3oool00`000000oooo0?ooo`1m0?ooo`030000
o`3oool0oooo0500oooo002`0?ooo`030000003oool0oooo0:l0oooo00<0
003o0?ooo`3oool0O03oool00`000000oooo0?ooo`1l0?ooo`030000o`3o
ool0oooo0540oooo002`0?ooo`030000003oool0oooo0:l0oooo00<0003o
0?ooo`3oool0O03oool00`000000oooo0?ooo`1k0?ooo`030000o`3oool0
oooo0580oooo002`0?ooo`030000003oool0oooo0;00oooo00<0003o0?oo
o`3oool0N`3oool00`000000oooo0?ooo`1k0?ooo`030000o`3oool0oooo
0580oooo002`0?ooo`030000003oool0oooo0;40oooo00<0003o0?ooo`3o
ool0NP3oool00`000000oooo0?ooo`1j0?ooo`030000o`3oool0oooo05<0
oooo002`0?ooo`030000003oool0oooo0;40oooo00<0003o0?ooo`3oool0
NP3oool00`000000oooo0?ooo`1i0?ooo`030000o`3oool0oooo05@0oooo
002`0?ooo`030000003oool0oooo0;80oooo00<0003o0?ooo`3oool0N@3o
ool00`000000oooo0?ooo`1h0?ooo`030000o`3oool0oooo05D0oooo002`
0?ooo`030000003oool0oooo0;<0oooo00<0003o0?ooo`3oool0N03oool0
0`000000oooo0?ooo`1g0?ooo`030000o`3oool0oooo05H0oooo002`0?oo
o`030000003oool0oooo0;@0oooo00<0003o0?ooo`3oool0M`3oool00`00
0000oooo0?ooo`1g0?ooo`030000o`3oool0oooo05H0oooo002`0?ooo`03
0000003oool0oooo0;D0oooo00<0003o0?ooo`3oool0MP3oool00`000000
oooo0?ooo`1f0?ooo`030000o`3oool0oooo05L0oooo002`0?ooo`030000
003oool0oooo0;H0oooo00<0003o0?ooo`3oool0M@3oool00`000000oooo
0?ooo`1e0?ooo`030000o`3oool0oooo05P0oooo002`0?ooo`030000003o
ool0oooo0;H0oooo00<0003o0?ooo`3oool0M03oool20?l000d0oooo0`00
001W0?ooo`030000o`3oool0oooo05P0oooo002`0?ooo`030000003oool0
oooo0;L0oooo00<0003o0?ooo`3oool0J@3oool5000000<0oooo1P3o0004
0?ooo`D000000P3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0
oooo05T0oooo002`0?ooo`030000003oool0oooo0;P0oooo00<0003o0?oo
o`3oool0J03oool4000000@0oooo1P3o00050?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0I03oool00`000?l0oooo0?ooo`1J
0?ooo`00/03oool00`000000oooo0?ooo`2i0?ooo`030000o`3oool0oooo
06X0oooo00@000000?ooo`3oool0oooo203o00050?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0H`3oool00`000?l0oooo0?ooo`1K
0?ooo`00/03oool00`000000oooo0?ooo`2j0?ooo`030000o`3oool0oooo
06L0oooo0`0000030?ooo`P0o`001P3oool01`000000oooo0?ooo`3oool0
00000?ooo`000000H`3oool00`000?l0oooo0?ooo`1L0?ooo`00/03oool0
0`000000oooo0?ooo`2k0?ooo`030000o`3oool0oooo06d0oooo1P3o0005
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0H@3o
ool00`000?l0oooo0?ooo`1M0?ooo`00/03oool00`000000oooo0?ooo`2k
0?ooo`030000o`3oool0oooo06d0oooo1P3o00050?ooo`D00000I@3oool0
0`000?l0oooo0?ooo`1N0?ooo`00/03oool00`000000oooo0?ooo`2l0?oo
o`030000o`3oool0oooo06h0oooo0P3o001`0?ooo`030000o`3oool0oooo
05l0oooo002`0?ooo`030000003oool0oooo0;d0oooo0P000?m_0?ooo`03
0000003oool0oooo06d0oooo00<0003o0?ooo`3oool0H03oool00;00oooo
00<000000?ooo`3oool0_`3oool00`000?l0oooo0?ooo`1/0?ooo`030000
003oool0oooo06`0oooo00<0003o0?ooo`3oool0H@3oool00;00oooo00<0
00000?ooo`3oool0`03oool00`000?l0oooo0?ooo`1[0?ooo`030000003o
ool0oooo06/0oooo00<0003o0?ooo`3oool0HP3oool00;00oooo00<00000
0?ooo`3oool0`@3oool00`000?l0oooo0?ooo`1Z0?ooo`030000003oool0
oooo06X0oooo00<0003o0?ooo`3oool0H`3oool00:T0oooo1@0000020?oo
o`030000003oool0oooo0<80oooo00<0003o0?ooo`3oool0J@3oool00`00
0000oooo0?ooo`1Y0?ooo`030000o`3oool0oooo06@0oooo002[0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0``3oool00`000?l0
oooo0?ooo`1X0?ooo`030000003oool0oooo06P0oooo00<0003o0?ooo`3o
ool0I@3oool00:/0oooo00<000000?ooo`3oool00P3oool200000<D0oooo
00<0003o0?ooo`3oool0I`3oool00`000000oooo0?ooo`1W0?ooo`030000
o`3oool0oooo06H0oooo002[0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0a@3oool00`000?l0oooo0?ooo`1V0?ooo`030000003o
ool0oooo06H0oooo00<0003o0?ooo`3oool0I`3oool00:/0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`360?ooo`80003oIP3oool0
0`000000oooo0?ooo`1T0?ooo`80003oJP3oool00:X0oooo0P0000040?oo
o`030000003oool0oooo0<P0oooo00<0003o0?ooo`3oool0H`3oool00`00
0000oooo0?ooo`1S0?ooo`030000o`3oool0oooo06X0oooo002`0?ooo`03
0000003oool0oooo0<T0oooo00<0003o0?ooo`3oool0HP3oool00`000000
oooo0?ooo`1R0?ooo`030000o`3oool0oooo06/0oooo002`0?ooo`030000
003oool0oooo0<X0oooo00<0003o0?ooo`3oool0H@3oool00`000000oooo
0?ooo`1Q0?ooo`030000o`3oool0oooo06`0oooo002`0?ooo`030000003o
ool0oooo0</0oooo00<0003o0?ooo`3oool0H03oool00`000000oooo0?oo
o`1P0?ooo`030000o`3oool0oooo06d0oooo002`0?ooo`030000003oool0
oooo0<`0oooo0P000?mP0?ooo`030000003oool0oooo05h0oooo0P000?m`
0?ooo`00/03oool00`000000oooo0?ooo`3>0?ooo`030000o`3oool0oooo
05d0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`1`0?oo
o`00/03oool00`000000oooo0?ooo`3?0?ooo`030000o`3oool0oooo05`0
oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?ooo`1a0?ooo`00
/03oool00`000000oooo0?ooo`3@0?ooo`80003oG03oool00`000000oooo
0?ooo`1J0?ooo`80003oM03oool00;00oooo00<000000?ooo`3oool0d@3o
ool00`000?l0oooo0?ooo`1J0?ooo`030000003oool0oooo05T0oooo00<0
003o0?ooo`3oool0M03oool00;00oooo00<000000?ooo`3oool0dP3oool0
0`000?l0oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<0003o
0?ooo`3oool0M03oool00;00oooo00<000000?ooo`3oool0d`3oool20000
oeT0oooo00<000000?ooo`3oool0E`3oool20000ogL0oooo002`0?ooo`03
0000003oool0oooo0=D0oooo00<0003o0?ooo`3oool0EP3oool00`000000
oooo0?ooo`1F0?ooo`030000o`3oool0oooo07L0oooo002`0?ooo`030000
003oool0oooo0=H0oooo0P000?mF0?ooo`030000003oool0oooo05@0oooo
0P000?mj0?ooo`00/03oool00`000000oooo0?ooo`3H0?ooo`80003oE03o
ool00`000000oooo0?ooo`1B0?ooo`80003oO03oool00;00oooo00<00000
0?ooo`3oool0fP3oool00`000?l0oooo0?ooo`1A0?ooo`030000003oool0
oooo0540oooo00<0003o0?ooo`3oool0O03oool00;00oooo00<000000?oo
o`3oool0f`3oool20000oe40oooo00<000000?ooo`3oool0C`3oool20000
ogl0oooo002`0?ooo`030000003oool0oooo0=d0oooo00<0003o0?ooo`3o
ool0CP3oool00`000000oooo0?ooo`1>0?ooo`030000o`3oool0oooo07l0
oooo002`0?ooo`030000003oool0oooo0=h0oooo0P000?m>0?ooo`030000
003oool0oooo04`0oooo0P000?n20?ooo`00/03oool00`000000oooo0?oo
o`3P0?ooo`80003oC03oool00`000000oooo0?ooo`1:0?ooo`80003oQ03o
ool00;00oooo00<000000?ooo`3oool0hP3oool00`000?l0oooo0?ooo`19
0?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3oool0Q03oool0
0;00oooo00<000000?ooo`3oool0h`3oool20000odT0oooo00<000000?oo
o`3oool0A`3oool20000ohL0oooo002`0?ooo`030000003oool0oooo0>D0
oooo10000?m50?ooo`030000003oool0oooo04<0oooo10000?n90?ooo`00
/03oool00`000000oooo0?ooo`3Y0?ooo`030000o`3oool0oooo0480oooo
00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`2;0?ooo`00/03o
ool00`000000oooo0?ooo`3Z0?ooo`80003o@P3oool00`000000oooo0?oo
o`100?ooo`80003oSP3oool00;00oooo00<000000?ooo`3oool0k03oool2
0000od00oooo00<000000?ooo`3oool0?P3oool20000oi00oooo002`0?oo
o`030000003oool0oooo0>h0oooo00<0003o0?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0l0?ooo`80003oTP3oool00;00oooo00<000000?ooo`3o
ool0k`3oool40000oc/0oooo00<000000?ooo`3oool0>@3oool30000oi@0
oooo002`0?ooo`030000003oool0oooo0?<0oooo0P000?li0?ooo`030000
003oool0oooo03L0oooo0P000?nG0?ooo`00/03oool00`000000oooo0?oo
o`3e0?ooo`<0003o=P3oool00`000000oooo0?ooo`0d0?ooo`<0003oV@3o
ool00;00oooo00<000000?ooo`3oool02@3oool300000>`0oooo0P000?ld
0?ooo`030000003oool0oooo0380oooo0P000?nL0?ooo`00/03oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0>h0oooo10000?l`0?oo
o`030000003oool0oooo02h0oooo10000?nN0?ooo`00/03oool00`000000
oooo0?ooo`020?ooo`D000000`3oool00`000000oooo0?ooo`3a0?ooo`<0
003o;@3oool00`000000oooo0?ooo`0Z0?ooo`@0003oXP3oool00;00oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo0?@0oooo0P000?l[0?ooo`030000003oool0oooo02T0
oooo00<0003o0?ooo`3oool0Y03oool00;00oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool000000?L0oooo
10000?lW0?ooo`030000003oool0oooo02D0oooo10000?nW0?ooo`00[`3o
ool30?l000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3j0?ooo`H0003o8@3oool00`000000oooo0?ooo`0O0?ooo`H0003oZ`3o
ool00:40oooo1@0000080?ooo`D0o`000`3oool010000000oooo0?ooo`00
003o0?ooo`L0oooo0`000?lN0?ooo`030000003oool0oooo01`0oooo0`00
0?na0?ooo`00X@3oool4000000P0oooo1`3o00020?ooo`D00000o`3oool9
0?ooo`H0003o603oool00`000000oooo0?ooo`0F0?ooo`H0003o]03oool0
0:@0oooo00<000000?ooo`3oool01P3oool70?l00?l0oooo5P3oool:0000
o`h0oooo00<000000?ooo`3oool0303oool:0000okX0oooo002R0?ooo`<0
0000203oool70?l00?l0oooo803ooolM0000ol@0oooo002^0?ooo`D0o`00
o`3oool_0?ooo`030000003oool0oooo0=00oooo002_0?ooo`<0o`00o`3o
ool`0?ooo`030000003oool0oooo0=00oooo002`0?ooo`030000003oool0
oooo0?l0oooo;`3oool00`000000oooo0?ooo`3@0?ooo`00/03oool00`00
0000oooo0?ooo`3o0?ooool0oooo0`3oool00;00oooo00<000000?ooo`3o
ool0o`3ooooo0?ooo`<0oooo002`0?ooo`030000003oool0oooo0?l0oooo
o`3oool30?ooo`00/03oool00`000000oooo0?ooo`3o0?ooool0oooo0`3o
ool00?l0ooooo`3ooonf0?ooo`00o`3ooooo0?oookH0oooo003o0?ooool0
oooo]P3oool00?l0ooooo`3ooonf0?ooo`00o`3ooooo0?oookH0oooo003o
0?ooool0oooo]P3oool00:h0oooo0P00003o0?oooc00oooo0P00003C0?oo
o`00[`3oool00`000000oooo0?ooo`3o0?ooobl0oooo00<000000?ooo`3o
ool0d@3oool00;00oooo00<000000?ooo`3oool0o`3oool_0?ooo`030000
003oool0oooo0=00oooo002_0?ooo`030000003oool000000?l0oooo;`3o
ool00`000000oooo0000003A0?ooo`00[P3oool010000000oooo0?ooo`00
003o0?ooobh0oooo00@000000?ooo`3oool00000d@3oool00:d0oooo0`00
00000`3oool000000000003o0?ooob`0oooo0`0000000`3oool000000000
003@0?ooo`00o`3ooooo0?oookH0oooo003o0?ooool0oooo]P3oool00?l0
ooooo`3ooonf0?ooo`00o`3ooooo0?oookH0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{692, 199},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  We use the function  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(log\_\(-\(\[Pi]\/2\)\)\ \((z)\)\)\/\(z\^2\  + \ \
a\^2\)\)]],
  ".  Recall that  \n\n\t\t\t",
  Cell[BoxData[
      \(log\_\(-\(\[Pi]\/2\)\)\ \((z)\)\ \  = \ \ \(ln | 
            z | \ \(+\ \ \[ImaginaryI]\)\ arg\_\(-\(\[Pi]\/2\)\)\ \((z)\)\ \  \
= \ \ ln\ r\ \  + \ \ \[ImaginaryI]\ \[Theta]\)\)]],
  ",  \n\n\nwhere  ",
  Cell[BoxData[
      \(z\  = \ r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\(-\(\[Pi]\/2\)\) < \[Theta] \[LessEqual] \(3  \[Pi]\)\/2\)]],
  ".  The path",
  " ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " ",
  "of integration will consist of the segments ",
  Cell[BoxData[
      RowBox[{\([\(-R\), \(-r\)]\), " ", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "[", \(r, R\), "]"}]}]]],
  " of the x axis together with the upper semicircles  ",
  Cell[BoxData[
      \(\(C\_r\) : \ z\  = \ 
        r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\(C\_R\) : \ z\  = \ 
        R\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)]],
  ",  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] \[Theta] \[LessEqual] \[Pi]\)]],
  ",  as shown in Figure 8.8."
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 8.8",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/integralsbranchpoints/\
IntegralsBranchPointsFigures/mat0808.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " for the integrand  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(log\_\(-\(\[Pi]\/2\)\)\ \((z)\)\)\/\(z\^2\  + \ \
a\^2\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe chose the branch  ",
  Cell[BoxData[
      \(log\_\(-\(\[Pi]\/2\)\)\ \((z)\)\)]],
  "  because it is analytic on ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " and its interior, hence so is the function ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " which has a simple pole in the upper half-plane at the point ",
  Cell[BoxData[
      \(z\_2 = a\ \[ImaginaryI]\)]],
  ". \n\n\t\t\t",
  Cell[BoxData[{
      \(\ \(\(Res[f, z\_1]\ \  = \ \ Res[f, a\ \[ImaginaryI]]\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] a\ \[ImaginaryI]\)\ \((z - a\ \[ImaginaryI])\) 
            f \((z)\)\)\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] a\ \[ImaginaryI]\)\ \((z - 
                a\ \[ImaginaryI])\) \(log\_\(-\(\[Pi]\/2\)\)\ \
\((z)\)\)\/\(\((z + a\ \[ImaginaryI])\) \((z - a\ \[ImaginaryI])\)\)\)\)\(\n\
\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(lim\+\(z\  \[Rule] a\ \[ImaginaryI]\)\ \(log\_\(-\(\[Pi]\/2\)\)\ \
\((z)\)\)\/\((z + a\ \[ImaginaryI])\)\)\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\(log\_\(-\(\[Pi]\/2\)\)\ \((a\ \[ImaginaryI])\)\)\/\((a\ \[ImaginaryI] + \
a\ \[ImaginaryI])\)\ \  = \ \ \(log\_\(-\(\[Pi]\/2\)\)\ \((a\ \
\[ImaginaryI])\)\)\/\(2  a\ \[ImaginaryI]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\(ln\ a\ \  + \ \ \[ImaginaryI]\ arg\_\(-\(\[Pi]\/2\)\)\ \((a\ \
\[ImaginaryI])\)\)\/\(2  a\ \[ImaginaryI]\)\ \  = \ \ \ \(ln\ a\ \  + \ \ \
\[ImaginaryI]\ \[Pi]\/2\)\/\(2  a\ \[ImaginaryI]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(ln\ \
a\)\/\(2  a\ \[ImaginaryI]\)\  + \[Pi]\/\(4  a\)\)\)\)}]]
}], "Text"],

Cell[TextData[{
  "This choice enables us to apply the residue theorem properly (see the \
hypotheses of Theorem 8.1), and we get  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[ContourIntegral]\_\(\(\ \)\(C\)\)\ 
          f \((z)\)\ \[DifferentialD]z\ \  = \ \ \(2  \[Pi]\ \[ImaginaryI]\ \
Res[f, z\_1]\ \  = \ \ 2  \[Pi]\ \[ImaginaryI]\ Res[f, 
              a\ \[ImaginaryI]]\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(2  \
\[Pi]\ \[ImaginaryI] \((\(ln\ a\)\/\(2  a\ \[ImaginaryI]\)\  + \[Pi]\/\(4  \
a\))\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(\
\[Pi]\ ln\ a\)\/a\  + \ \ \[ImaginaryI]  \[Pi]\^2\/\(2  a\)\)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "Keeping in mind the branch of logarithm that we're using, we then have  \n\
\n",
  StyleBox["(8-33)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[{
      \(\(\(\[ContourIntegral]\_\(\(\ \)\(C\)\)\ 
          f \((z)\)\ \[DifferentialD]z\ \  = \ \ \[Integral]\_\(-R\)\%\(-r\)\ 
            f \((x)\) \[DifferentialD]x\  + \ \[ContourIntegral]\_\(\(\ \
\)\(-C\_r\)\)\ f \((z)\)\ \[DifferentialD]z\  + \ \[Integral]\_r\%R\ 
            f \((x)\)\ \[DifferentialD]x\  + \ \[ContourIntegral]\_\(\(\ \
\)\(C\_R\)\)\ f \((z)\)\ \[DifferentialD]z\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\
\[Integral]\_\(-R\)\%\(-r\)\ \(\(ln | 
                    x | \ \(+\ \[ImaginaryI]\)\ \[Pi]\)\/\(x\^2\  + \ 
                    a\^2\)\) \[DifferentialD]x\  + \ \[ContourIntegral]\_\(\(\
\ \)\(-C\_r\)\)\ 
            f \((z)\)\ \[DifferentialD]z\  + \ \[Integral]\_r\%R\ \(ln\ x\)\/\
\(x\^2\  + \ a\^2\)\ \[DifferentialD]x\  + \ \[ContourIntegral]\_\(\(\ \
\)\(C\_R\)\)\ f \((z)\)\ \[DifferentialD]z\)\)\(\[IndentingNewLine]\)
      \(\ \)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(\
\[Pi]\ ln\ a\)\/a\  + \ \ \[ImaginaryI]  \[Pi]\^2\/\(2  a\)\)\)\)}]],
  "   "
}], "Text"],

Cell[TextData[{
  "If  ",
  Cell[BoxData[
      \(R\^2 > r\^2\)]],
  ",  then by the ML inequality (Theorem 6.3) \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(\[ContourIntegral]\_\(\(\ \)\(C\_R\)\)\ 
            f \((z)\)\ \[DifferentialD]z\)\(|\)\)\ \  = \ \ \(\(|\)\(\
\[Integral]\_0\%\[Pi]\ \(\(ln\ R\ \  + \ \[ImaginaryI]\ \
\[Theta]\)\/\(\(R\^2\) \(\(\[ExponentialE]\)\(\ \)\)\^\[ImaginaryI]2\[Theta]\ \
 + \ a\^2\)\) \[ImaginaryI]\ R\ \(\(\[ExponentialE]\)\(\ \)\)\^\[ImaginaryI]\
\[Theta]\ \[DifferentialD]\[Theta]\)\(|\)\(\[IndentingNewLine]\)\(\
\[IndentingNewLine]\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \)\(\(\[LessEqual]\)\(\ \ \)\(\(R \((ln\ R\ \  + \ \[Pi])\) \[Pi]\)\/\(R\^2\
\  - \ a\^2\)\)\)\)\)]],
  "\n\nand L'H\[OHat]pital's rule yields  ",
  Cell[BoxData[
      \(lim\_\(R \[Rule] \[Infinity]\)\ \[ContourIntegral]\_\(\(\ \
\)\(C\_R\)\)\ f \((z)\)\ \[DifferentialD]z\  = \ 0\)]],
  ".  A similar computation shows that  ",
  Cell[BoxData[
      \(lim\_\(r \[Rule] 0\)\ \[ContourIntegral]\_\(\(\ \)\(C\_r\)\)\ 
            f \((z)\)\ \[DifferentialD]z\  = \ 0\)]],
  ".  \nWe use these results when we take limits Equations ",
  StyleBox["(8-33)",
    FontColor->RGBColor[0, 0, 1]],
  " to get  \n\n\t\t\t",
  Cell[BoxData[{
      \(P . 
          V . \ \((\[Integral]\_\(-\[Infinity]\)\%0\ \(\(ln | 
                        x | \ \(+\ \[ImaginaryI]\)\ \[Pi]\)\/\(x\^2\  + \ 
                        a\^2\)\) \[DifferentialD]x\  + \ \[Integral]\_0\%\
\[Infinity]\ \(ln\ x\)\/\(x\^2\  + \ a\^2\)\ \[DifferentialD]x)\)\ \  = \ \ \
\(\(lim\+\ \)\+\(R \[Rule] \[Infinity]\)\)\+\(r \[Rule] \
0\)\((\[Integral]\_\(-R\)\%\(-r\)\ \(\(ln | 
                        x | \ \(+\ \[ImaginaryI]\)\ \[Pi]\)\/\(x\^2\  + \ 
                        a\^2\)\) \[DifferentialD]x\  + \ \[Integral]\_r\%R\ \
\(ln\ x\)\/\(x\^2\  + \ a\^2\)\ \[DifferentialD]x)\)\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \(\(\(=\)\(\ \ \)\(\[ContourIntegral]\_\(\(\ \)\(C\)\)\ 
          f \((z)\)\ \[DifferentialD]z\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \(\(=\)\(\ \ \ \)\(\(\[Pi]\ ln\ a\)\/a\  + \ \ \[ImaginaryI]  \
\[Pi]\^2\/\(2  a\)\)\)\)}]],
  "   \n\nEquating the real parts in this equation gives  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(P . 
          V . \ \((\[Integral]\_\(-\[Infinity]\)\%0\ \(\(ln | 
                        x | \ \(+\ \[ImaginaryI]\)\ \[Pi]\)\/\(x\^2\  + \ 
                        a\^2\)\) \[DifferentialD]x\  + \ \[Integral]\_0\%\
\[Infinity]\ \(ln\ x\)\/\(x\^2\  + \ a\^2\)\ \[DifferentialD]x)\)\ \  = \ \(\
\[Pi]\ ln\ a\)\/a\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\(\(P . 
          V . \ \((\[Integral]\_0\%\[Infinity]\ \(ln\ x\)\/\(x\^2\  + \ \
a\^2\)\ \[DifferentialD]x\  + \ \[Integral]\_0\%\[Infinity]\ \(ln\ \
x\)\/\(x\^2\  + \ a\^2\)\ \[DifferentialD]x)\)\ \  = \ \(\[Pi]\ ln\ \
a\)\/a\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(P . 
          V . \ \(\[Integral]\_0\%\[Infinity]\ \(ln\ x\)\/\(x\^2\  + \ a\^2\)\
\ \[DifferentialD]x\)\ \  = \ \(\[Pi]\ ln\ a\)\/\(2  a\)\)}]],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.24.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the function and  ",
  Cell[BoxData[
      \(f[z] = Log[z]\/\(a\^2\  + \ x\^2\)\)],
    AspectRatioFixed->True],
  "  and ",
  "locate the",
  " isolated singularities."
}], "Text"],

Cell[BoxData[{
    \(Z = \(z = \(x = \(a = 0\)\)\); 
    Remove[a, x, z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, P, Q, Res1, solset, val];\)\ \), "\[IndentingNewLine]", 
    \(\(P[z_] = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Q[z_] = z\^2 + a\^2;\)\ \), "\n", 
    \(\(f[z_]\  = \ \(Log[z]\ P[z]\)\/Q[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P[z]\/Q[z]\) = \>\"", 
        P[z]\/Q[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        Denominator[P[z]\/Q[z]] \[Equal] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ 
        Sort[Solve[Denominator[P[z]\/Q[z]] \[Equal] 0, 
            z]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The singularities of \!\(P[z]\/Q[z]\) are\>\""];\)\ \), \
"\n", 
    \(\(Z\_1\  = \ 
        ReplaceAll[z, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        ComplexExpand[
          ReplaceAll[z, 
            solset\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)\
]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", 
        Z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell["Which poles lie in the upper half plane ?  ", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(a = 2;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Blue, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_2], Im[Z\_2]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] + 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] - 0.1}, {\(-1\), 
                0}]}];\)\ \), "\n", 
    \(\(Show[dots, centers, 
        PlotRange \[Rule] {{\(-2.2\), 2.2}, {\(-2.2\), 2.2}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<For example, if  a = 2.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<, Is  Im(\>", 
        Z\_1, "\<) > 0 ?  \>", N[Im[Z\_1]] > 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<,  Is  Im(\>", 
        Z\_2, "\<) > 0 ?   \>", 
        N[Im[Z\_2]] > 0];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Compute the residues at  ",
  Cell[BoxData[
      \(z\_2 = 2  \[ImaginaryI]\)]],
  ",  and use the residue calculus to compute the value of the integral."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Res2\  = \ Residue[f[z], {z, Z\_2}];\)\ \), "\[IndentingNewLine]", 
    \(\(val\  = \ 
        2\ \[Pi]\ \[ImaginaryI]\ Res2;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", Z\_2, "\<] = \>", 
        Res2];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{{Red, PointSize[0.03], 
              Point[{Re[Z\_2], Im[Z\_2]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(center = 
        Graphics[{Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], 
                Im[Z\_2]}, {\(-1.2\), 0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ 
        Graphics[{{VioletRed, Circle[{0, 0}, 3, {0, \[Pi]}]}, {VioletRed, 
              Circle[{0, 0}, 
                0.2, {0, \[Pi]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(segment = 
        Graphics[{Thickness[0.015], Magenta, 
            Line[{{\(-3\), 0}, {3, 0}}]}];\)\ \), "\n", 
    \(\(Show[center, contour, segment, dot, 
        PlotRange \[Rule] {{\(-3.1\), 3.1}, {\(-0.05\), 3.05}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 2, 1]}, 
        AspectRatio \[Rule] 1\/2, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>", 
        Res2\ , "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = \>", 
        val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) (\>\"", 
        f[z], "\<) \[DifferentialD]z = \>", 
        ComplexExpand[val]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The indented contour is the semicircle \!\(C\_R\) \
portions of [-R,R],\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and a little indent semicircle around the origin on the \
x-axis,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<taken with the positive orientation.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value \
of the integral.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Further analysis must be done.  As shown in the text, the limit of the \
integrals taken over the semicircles are both zero.\nUse the fact that when x \
is negative  ",
  Cell[BoxData[
      \(Log[x]\  = \ Log[\(|\)\(x\)\(|\)]\  + \ \[ImaginaryI]\ \[Pi]\)]],
  ".  Then use this parameterize the line segment on the negative x-axis and \
obtain  \n\n",
  Cell[BoxData[
      \(P . 
          V . \((\ \[Integral]\_\(-\[Infinity]\)\%0\(\( 
                          Log[\(|\)\(x\)\(|\)] + \ \[ImaginaryI]\ \
\[Pi]\)\/\(x\^2\  + \ 
                        2\^2\)\) \[DifferentialD]x\  + \ \[Integral]\_0\%\
\[Infinity]\( Log[x]\/\(x\^2\  + \ 
                        2\^2\)\) \[DifferentialD]x\ )\) = \ \(\[Pi]\ Log[2]\)\
\/2 + \(\[ImaginaryI]\ \[Pi]\^2\)\/4\)]],
  ".  \n\nEquating the real parts in the above equation we obtain  \n\n",
  Cell[BoxData[
      \(P . 
          V . \ \(\[Integral]\_0\%\[Infinity]\( Log[x]\/\(x\^2\  + \ 
                    2\^2\)\) \[DifferentialD]x\)\  = \ \(\[Pi]\ \
Log[2]\)\/4\)]],
  ".  \n\nwhich is the correct value when  a = 2.  Similar computations will \
establish the general result."
}], "Text"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in \"PrincipalValue\" option to evaluate this definite integral \
with specific values of  a."
}], "Text"],

Cell[BoxData[
    \(\(\(For[a = 2, 
        a \[LessEqual] 5, \(a++\), \[IndentingNewLine]val\  = \ 
          Integrate[f[x], {x, 0, \[Infinity]}, 
            Assumptions \[Rule] {0 < Re[\[Alpha]] < 1}, 
            PrincipalValue \[Rule] 
              True]; \ \[IndentingNewLine]Print["\<a = \>", 
          a]; \ \[IndentingNewLine]Print[\*"\"\<P.V.\!\(\[Integral]\_0\%\
\[Infinity]\)\>\"", f[x], "\< \[DifferentialD]x = \>", 
          val]; \ \[IndentingNewLine]Print[\*"\"\<\!\(\(\[Pi]\\\ \\\ Log[a]\)\
\/\(2  a\)\) = \>\"", \(\[Pi]\ Log[a]\)\/\(2  a\)]; \ \
\[IndentingNewLine]Print["\<\>"];\ \ ];\)\(\ \)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[TextData[{
  "Which leads us to conjecture the general result  ",
  Cell[BoxData[
      \(P . 
          V . \ \(\[Integral]\_0\%\[Infinity]\( Log[z]\/\(x\^2\  + \ 
                    a\^2\)\) \[DifferentialD]x\)\  = \ \(\[Pi]\ Log[a]\)\/\(2\
\ a\)\)]],
  ",  where  ",
  Cell[BoxData[
      \(a > 0\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " do the integration. "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<   Example using a = 2\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\[Infinity]\)\!\(Log[x]\/\(x\^2 + \
2\^2\)\)\[DifferentialD]x = \>\"", \[Integral]\_0\%\[Infinity]\( Log[
                  x]\/\(x\^2 + 
                  2\^2\)\) \[DifferentialD]x];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\[Infinity]\)\!\(Log[x]\/\(x\^2 + \
3\^2\)\)\[DifferentialD]x = \>\"", \[Integral]\_0\%\[Infinity]\( Log[
                  x]\/\(x\^2 + 
                  3\^2\)\) \[DifferentialD]x];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\[Infinity]\)\!\(Log[x]\/\(x\^2 + \
4\^2\)\)\[DifferentialD]x = \>\"", \[Integral]\_0\%\[Infinity]\( Log[
                  x]\/\(x\^2 + 
                  4\^2\)\) \[DifferentialD]x];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\[Infinity]\)\!\(Log[x]\/\(x\^2 + \
5\^2\)\)\[DifferentialD]x = \>\"", \[Integral]\_0\%\[Infinity]\( Log[
                  x]\/\(x\^2 + 
                  5\^2\)\) \[DifferentialD]x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\[Infinity]\)\!\(Log[x]\/\(x\^2 + \
a\^2\)\)\[DifferentialD]x = \>\"", \[Integral]\_0\%\[Infinity]\( Log[
                  x]\/\(x\^2 + 
                  a\^2\)\) \[DifferentialD]x];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\[Infinity]\)\!\(Log[x]\/\(x\^2 + \
a\^2\)\)\[DifferentialD]x = \>\"", 
        Simplify[\[Integral]\_0\%\[Infinity]\( Log[x]\/\(x\^2 + 
                    a\^2\)\) \[DifferentialD]x, a > 0]\ ];\)\)}], "Input"],

Cell["\<\
However, we might not be able to use the anti-derivative for the computation.\
\
\>", "Text"],

Cell[BoxData[{
    \(\(f[
          x_]\  = \ \[Integral]\(Log[x]\/\(x\^2 + 
                  2\^2\)\) \[DifferentialD]x;\)\), "\[IndentingNewLine]", 
    \(\(F[x_]\  = \ Simplify[f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<F[x] = \[Integral]\!\(Log[x]\/\(x\^2 + 2\^2\)\)\>\""];\)\
\), "\[IndentingNewLine]", 
    \(\(Print["\<F[x] = \>", F[x]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(f[
          x_]\  = \ \[Integral]\(Log[x]\/\(x\^2 + 
                  2\^2\)\) \[DifferentialD]x;\)\), "\[IndentingNewLine]", 
    \(\(F[x_]\  = \ Simplify[f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(lim = Limit[F[x], x \[Rule] 0];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{F[x], \(\[Pi]\ Log[2. ]\)\/4}, {x, 0, 1000}, 
        PlotRange \[Rule] {All, {\(-0.25\), 0.55}}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[0, 1000, 200], 
            Range[0, 0.5, 0.25]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<F[x] = \>", F[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<      F[0] = \!\(lim\+\(x \[Rule] 0\)\) F[x]\>\""\ \
];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<      F[0] = \>", lim\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<F[1.0*\!\(10\^3\)] = \>\"", 
        Chop[F[1.0*10\^3]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<F[1.0*\!\(10\^4\)] = \>\"", 
        Chop[F[1.0*10\^4]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<F[1.0*\!\(10\^5\)] = \>\"", 
        Chop[F[1.0*10\^5]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<F[1.0*\!\(10\^6\)] = \>\"", 
        Chop[F[1.0*10\^6]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<F[1.0*\!\(10\^7\)] = \>\"", 
        Chop[F[1.0*10\^7]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<F[1.0*\!\(10\^8\)] = \>\"", 
        Chop[F[1.0*10\^8]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<F[1.0*\!\(10\^9\)] = \>\"", 
        Chop[F[1.0*10\^9]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(\(\[Pi]\\\ Log[2]\)\/4\) = \>\"", 
        N[\(\[Pi]\ Log[2]\)\/4]\ ];\)\), "\[IndentingNewLine]", 
    \(\(\(Print["\<      F[\[Infinity]] = \>", 
        F[\[Infinity]]\ ];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Residue Calculus",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ResidueCalcBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Contour Integrals",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ContourIntegralBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Cauchy Principal Value",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/CauchyPrincipalValuelBib.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Hilbert Transformation",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/HilbertTransBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{995, 640},
WindowMargins->{{3, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[9170, 291, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 92000, 1967}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 124, 2, 33, "Text"],
Cell[2229, 66, 355, 9, 58, "Text"],
Cell[2587, 77, 1766, 51, 128, "Text"],
Cell[4356, 130, 2925, 92, 147, "Text",
  Evaluatable->False],
Cell[7284, 224, 1452, 46, 38, "Text"],

Cell[CellGroupData[{
Cell[8761, 274, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[8909, 280, 258, 9, 33, "Text",
  Evaluatable->False],
Cell[9170, 291, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[9530, 303, 464, 19, 57, "Text",
  Evaluatable->False],
Cell[9997, 324, 23163, 383, 213, 23049, 379, "GraphicsData", "Bitmap", "Text",
  
  Evaluatable->False],
Cell[33163, 709, 3260, 65, 568, "Text"],

Cell[CellGroupData[{
Cell[36448, 778, 196, 7, 33, "Text"],
Cell[36647, 787, 213, 8, 38, "Text"],
Cell[36863, 797, 1579, 35, 473, "Input"],
Cell[38445, 834, 93, 2, 33, "Text",
  Evaluatable->False],
Cell[38541, 838, 1171, 22, 170, "Input"],
Cell[39715, 862, 223, 7, 33, "Text",
  Evaluatable->False],
Cell[39941, 871, 3159, 60, 646, "Input"],
Cell[43103, 933, 258, 9, 33, "Text"],
Cell[43364, 944, 381, 8, 83, "Input"],
Cell[43748, 954, 49, 0, 33, "Text"]
}, Closed]],
Cell[43812, 957, 92, 2, 30, "Text"],
Cell[43907, 961, 443, 18, 37, "Text",
  Evaluatable->False],
Cell[44353, 981, 22288, 368, 213, 22174, 364, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[66644, 1351, 1536, 45, 168, "Text"],
Cell[68183, 1398, 595, 20, 45, "Text"],
Cell[68781, 1420, 2083, 43, 409, "Text"],
Cell[70867, 1465, 832, 16, 164, "Text"],
Cell[71702, 1483, 1351, 26, 168, "Text"],
Cell[73056, 1511, 3453, 67, 483, "Text"],

Cell[CellGroupData[{
Cell[76534, 1582, 196, 7, 33, "Text"],
Cell[76733, 1591, 206, 8, 37, "Text"],
Cell[76942, 1601, 1575, 34, 470, "Input"],
Cell[78520, 1637, 108, 2, 33, "Text",
  Evaluatable->False],
Cell[78631, 1641, 1278, 24, 210, "Input"],
Cell[79912, 1667, 233, 7, 33, "Text",
  Evaluatable->False],
Cell[80148, 1676, 2289, 43, 478, "Input"],
Cell[82440, 1721, 1158, 25, 213, "Text"],
Cell[83601, 1748, 284, 9, 33, "Text"],
Cell[83888, 1759, 658, 12, 179, "Input"],
Cell[84549, 1773, 330, 11, 37, "Text"],
Cell[84882, 1786, 203, 8, 33, "Text"],
Cell[85088, 1796, 1668, 26, 253, "Input"],
Cell[86759, 1824, 103, 3, 33, "Text"],
Cell[86865, 1829, 446, 8, 137, "Input"],
Cell[87314, 1839, 1915, 35, 467, "Input"]
}, Closed]],
Cell[89244, 1877, 290, 7, 30, "Text"],
Cell[89537, 1886, 313, 10, 33, "Text"],
Cell[89853, 1898, 318, 10, 33, "Text"],
Cell[90174, 1910, 331, 11, 33, "Text"],
Cell[90508, 1923, 320, 10, 33, "Text"],
Cell[90831, 1935, 257, 5, 33, "Text"],
Cell[91091, 1942, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

