(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    146501,       3173]*)
(*NotebookOutlinePosition[    147828,       3219]*)
(*  CellTagsIndexPosition[    147751,       3213]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["8.7  The Argument Principle and Rouch\[EAcute]'s \
Theorem",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
\tWe now derive two results based on Cauchy's residue theorem. They have \
important practical applications and pertain only to functions all of whose \
isolated singularities are poles.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Definition 8.3 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Meromorphic Function",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/MeromorphicFunction.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "      A function ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is said to be meromorphic in a domain",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["D",
    FontFamily->"Courier New"],
  " provided the only singularities of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " are isolated poles and removable singularities."
}], "Text"],

Cell[TextData[{
  "\tWe make three important observations relating to this definition.\n\n",
  StyleBox["(i).",
    FontColor->RGBColor[0, 0, 1]],
  "   \tAnalytic functions are a special case of meromorphic functions.\n\n",
  StyleBox["(ii).",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " \tRational functions ",
  Cell[BoxData[
      \(f \((z)\) = \(P \((z)\)\)\/\(Q \((z)\)\)\)]],
  ", where ",
  StyleBox["P(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Q(z)",
    FontFamily->"Courier New"],
  " are polynomials, are meromorphic in the entire complex plane.\n\n",
  StyleBox["(iii).",
    FontColor->RGBColor[0, 0, 1]],
  " \tBy definition, meromorphic functions have no essential singularities."
}], "Text"],

Cell[TextData[{
  "\tSuppose that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic at each point on a simple closed contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is meromorphic in the domain that is the interior of ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".  We assert without proof that Theorem 7.13 can be extended to \
meromorphic functions so that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has at most a finite number of zeros that lie inside ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".   Since the function  ",
  Cell[BoxData[
      \(g \((z)\) = 1\/\(f \((x)\)\)\)]],
  "  is also meromorphic, it can have only a finite number of zeros inside ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", and so ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " can have at most a finite number of poles that lie inside ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".\n\n\tTheorem 8.8, known as the argument principle, is useful in \
determining the number of zeros and poles that a function has."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 8.8 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Argument Principle",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ArgumentPrinciple.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " be meromorphic in the simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  Suppose that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is meromorphic in the simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " and that ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a simple closed positively oriented contour in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " such that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has no zeros or poles  (",
  Cell[BoxData[
      \(f \((z)\) \[NotEqual] 
        0\ \ and\ \ f \((z)\) \[NotEqual] \[Infinity]\)]],
  ")  for  ",
  Cell[BoxData[
      \(z \[Element] C\)]],
  ".  Then\n\n",
  StyleBox["(8-34)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \(\[Integral]\_C\ \(\(f' \((z)\)\)\
\/\(f \((z)\)\)\) \[DifferentialD]z\)\ \  = \ \ Z\_f\  - \ P\_f\)]],
  ",  \n\nwhere  ",
  Cell[BoxData[
      \(Z\_f\)]],
  "  is the number of zeros of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " that lie inside ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " and  ",
  Cell[BoxData[
      \(P\_f\)]],
  "  is the number of poles that lie inside ",
  StyleBox["C",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Proof of Theorem 8.8",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[" is in the book.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Corollary 8.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is analytic in the simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  Let ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " be a simple closed positively oriented contour in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " such that for ",
  Cell[BoxData[
      \(z \[Element] C, f \((z)\) \[NotEqual] 0\)]],
  ".  Then  \n\n\t\t\t",
  Cell[BoxData[
      \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \(\[Integral]\_C\ \(\(f' \((z)\)\)\
\/\(f \((z)\)\)\) \[DifferentialD]z\)\ \  = \ \ Z\_f\)]],
  ",  \n\nwhere  ",
  Cell[BoxData[
      \(Z\_f\)]],
  "  is the number of zeros of ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " that lie inside ",
  StyleBox["C",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Proof of Corollary 8.1",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[" is in the book.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark 8.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Certain feedback control systems in engineering must be stable.  A test \
for stability involves the function ",
  Cell[BoxData[
      \(G \((z)\) = 1 + F \((z)\)\)]],
  ", where ",
  StyleBox["F(z)",
    FontFamily->"Courier New"],
  " is a rational function.  If ",
  StyleBox["G(z)",
    FontFamily->"Courier New"],
  " does not have any zeros in the region ",
  Cell[BoxData[
      \({z : Re \((z)\) \[GreaterEqual] 0}\)]],
  ", then the system is stable.  We determine the number of zeros of ",
  StyleBox["G(z)",
    FontFamily->"Courier New"],
  "  by writing ",
  Cell[BoxData[
      \(F \((z)\) = \(P \((z)\)\)\/\(Q \((z)\)\)\)]],
  ", where ",
  StyleBox["P(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Q(z)",
    FontFamily->"Courier New"],
  " are polynomials with no common zero.  Then ",
  Cell[BoxData[
      \(G \((z)\) = \(Q \((z)\) + P \((z)\)\)\/\(Q \((z)\)\)\)]],
  ", and we can check for the zeros of ",
  Cell[BoxData[
      \(Q \((z)\) + P \((z)\)\)]],
  " by using Theorem 8.8.  We select a value",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["R",
    FontFamily->"Courier New"],
  " so that ",
  Cell[BoxData[
      \(G \((z)\) \[NotEqual] 0\)]],
  " for ",
  Cell[BoxData[
      \({z : \(\(|\)\(z\)\(|\)\(\(>\)\(R\)\)\)}\)]],
  " and then integrate along the contour consisting of the right half of the \
circle ",
  Cell[BoxData[
      \(\(C\_R\) \((0)\)\)]],
  " and the line segment between ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[ImaginaryI]", " ", "R", "  ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], " ", "-", \(\[ImaginaryI]\ R\)}]]],
  ". This method is known as the Nyquist stability criterion."
}], "Text"],

Cell[TextData[{
  "\tWhy do we label Theorem 8.8 as the argument principle?  The answer lies \
with a fascinating application known as the winding number. \nRecall that a \
branch of the logarithm function, ",
  Cell[BoxData[
      \(log\_\[Alpha]\ \((z)\)\)]],
  ", is defined by \n\n\t\t\t",
  Cell[BoxData[
      \(log\_\[Alpha]\ \((z)\)\ \  = \ \ \(ln | 
            z | \ \(+\ \ \[ImaginaryI]\)\ arg\_\[Alpha]\ \((z)\)\ \  = \ \ ln\
\ r\ \  + \ \ \[ImaginaryI]\ \[Phi]\)\)]],
  ",  \n\n\nwhere  ",
  Cell[BoxData[
      \(z\  = \ r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\)\)]],
  "  and  ",
  Cell[BoxData[
      \(0 < \[Phi] \[LessEqual] 2  \[Pi]\)]],
  ".  Loosely speaking, suppose that for some branch of the logarithm, the \
composite function ",
  Cell[BoxData[
      \(log\_\[Alpha]\ \((f \((z)\))\)\)]],
  " were analytic in a simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " containing the contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".  This would imply that ",
  Cell[BoxData[
      \(log\_\[Alpha]\ \((f \((z)\))\)\)]],
  " is an antiderivative of the function ",
  Cell[BoxData[
      \(\(f' \((z)\)\)\/\(f \((z)\)\)\)]],
  " for all ",
  Cell[BoxData[
      \(z\ \[Epsilon]\ D\)]],
  ".  Theorems 6.9 and 8.8 would then tell us that, as ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " winds around the curve ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", the quantity ",
  Cell[BoxData[
      \(log\_\[Alpha]\ \((f \((z)\))\)\ \  = \ \ ln | 
          f \((z)\) | \ \(+\ \ \[ImaginaryI]\)\ arg\_\[Alpha]\ f \((z)\)\)]],
  " would change by ",
  Cell[BoxData[
      \(2  \[Pi]\ \[ImaginaryI] \((Z\_f - P\_f)\)\)]],
  ".  Since ",
  Cell[BoxData[
      \(2  \[Pi]\ \[ImaginaryI] \((Z\_f - P\_f)\)\)]],
  " is purely imaginary, this result tells us that ",
  Cell[BoxData[
      \(arg\_\[Alpha]\ f \((z)\)\)]],
  " would change by ",
  Cell[BoxData[
      \(2  \[Pi]\ \[ImaginaryI] \((Z\_f - P\_f)\)\)]],
  " radians.  In other words, as ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " winds around ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", the integral ",
  Cell[BoxData[
      \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \(\[Integral]\_C\ \(\(f' \((z)\)\)\
\/\(f \((z)\)\)\) \[DifferentialD]z\)\)]],
  " would count how many times the curve ",
  Cell[BoxData[
      \(f \((C)\)\)]],
  " winds around the origin."
}], "Text"],

Cell[TextData[{
  "\tUnfortunately, we can't always claim that ",
  Cell[BoxData[
      \(log\_\[Alpha]\ \((f \((z)\))\)\)]],
  " is an antiderivative of the function ",
  Cell[BoxData[
      \(\(f' \((z)\)\)\/\(f \((z)\)\)\)]],
  " for all ",
  Cell[BoxData[
      \(z\ \[Epsilon]\ D\)]],
  ".  If it were, the Cauchy-Goursat theorem would imply that ",
  Cell[BoxData[
      \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \(\[Integral]\_C\ \(\(f' \((z)\)\)\
\/\(f \((z)\)\)\) \[DifferentialD]z\)\  = \ 0\)]],
  ".  Nevertheless, the heuristics that we gave - indicating that ",
  Cell[BoxData[
      \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \(\[Integral]\_C\ \(\(f' \((z)\)\)\
\/\(f \((z)\)\)\) \[DifferentialD]z\)\)]],
  " counts how many times the curve ",
  Cell[BoxData[
      \(f \((C)\)\)]],
  " winds around the origin - still hold true, as shown in the book."
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 8.10",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/rouchetheorem/\
RoucheTheoremFigures/mat0810.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The points ",
  Cell[BoxData[
      \(z\_k\)]],
  " on the contour ",
  Cell[BoxData[
      \(C\)]],
  " that winds around ",
  Cell[BoxData[
      \(\(z\^*\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 8.11",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/rouchetheorem/\
RoucheTheoremFigures/mat0811.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The points ",
  Cell[BoxData[
      \(w\_k\)]],
  " on the contour ",
  Cell[BoxData[
      \(f \((C)\)\)]],
  " that winds around ",
  Cell[BoxData[
      \(0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 8.25.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The image of the circle ",
  Cell[BoxData[
      \(\(C\_2\) \((0)\)\)]],
  " under ",
  Cell[BoxData[
      \(f \((z)\)\  = \ z\^2 + z\)],
    AspectRatioFixed->True],
  " is the curve ",
  Cell[BoxData[
      \({\((x, 
            y)\) = \((4  cos\ 2  t + 2  cos\ t, 
              4  sin\ 2  t + 2  sin\ t)\) : \ 
            0 \[LessEqual] t \[LessEqual] 2  \[Pi]}\)]],
  "shown in Figure 8.12.  \nNote that the image curve  ",
  Cell[BoxData[
      \(f \((\(C\_2\) \((0)\))\)\)]],
  "  winds twice around the origin. We check this by computing\n\n\t\t\t",
  Cell[BoxData[
      \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \(\[Integral]\_\(\(C\_2\%+\) \((0)\
\)\)\ \(\(f' \((z)\)\)\/\(f \((z)\)\)\) \[DifferentialD]z\)\ \  = \ \ \
\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \(\[Integral]\_\(\(C\_2\%+\) \((0)\)\)\ \(\
\(2  z + 1\)\/\(z\^2 + z\)\) \[DifferentialD]z\)\)]],
  ". \n\nThe residues of the integrand are at ",
  StyleBox["0",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["-1",
    FontFamily->"Courier New"],
  ". Thus \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \(\[Integral]\_\(\(C\_2\%+\) \
\((0)\)\)\ \(\(2  z + 1\)\/\(z\^2 + 
                    z\)\) \[DifferentialD]z\)\ \  = \ \ Res[\(2  z + 1\)\/\(z\
\^2 + z\), 0]\  + \ 
          Res[\(2  z + 1\)\/\(z\^2 + z\), 1]\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(\(=\)\(\ \ \)\(1\  + \ 1\ \  = \ \ 2\)\)\)}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008E0000cR000`400?l0
0000o`00003oo`3ooooo0?oooaL0oooo003o0?ooool0oooo5`3oool00?l0
ooooo`3ooolG0?ooo`00o`3ooooo0?oooaL0oooo003o0?ooool0oooo5`3o
ool00<P0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`21
0?ooo`00b03oool00`000000oooo0?ooo`360?ooo`030000003oool0003o
0140003oL03oool00<P0oooo00<000000?ooo`3oool0`@3oool70000oa80
oooo20000?mX0?ooo`00b03oool00`000000oooo0?ooo`2m0?ooo`@0003o
1@3oool00`000000oooo0?ooo`0I0?ooo`@0003oI03oool00<P0oooo00<0
00000?ooo`3oool0^03oool50000o`T0oooo00<000000?ooo`3oool07@3o
ool30000of40oooo00380?ooo`030000003oool0oooo0;D0oooo0`000?l>
0?ooo`030000003oool0oooo0200oooo0`000?mN0?ooo`00b03oool00`00
0000oooo0?ooo`2c0?ooo`80003o4@3oool00`000000oooo0?ooo`0S0?oo
o`<0003oF`3oool00<40oooo100000030?ooo`030000003oool0oooo0;00
oooo0`000?lC0?ooo`030000003oool0oooo02H0oooo0`000?mH0?ooo`00
`@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:h0oooo
0P000?lF0?ooo`030000003oool0oooo02T0oooo0P000?mF0?ooo`00_P3o
oolF0000oj<0oooo0P000?lH0?ooo`030000003oool0oooo02/0oooo0P00
0?mD0?ooo`00^03oool60000o`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`H0003oV`3oool2
0000oaX0oooo00<000000?ooo`3oool0;@3oool20000oe80oooo002d0?oo
o`@0003o2@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00l0oooo10000?nE0?ooo`80003o703oool00`000000oooo0?ooo`0_
0?ooo`80003oD03oool00;00oooo10000?l>0?ooo`800000103oool00`00
0000oooo0?ooo`0C0?ooo`80003oT@3oool20000oah0oooo00<000000?oo
o`3oool0<@3oool20000odh0oooo002^0?ooo`80003o603oool00`000000
oooo0?ooo`0E0?ooo`@0003oR`3oool20000ob00oooo00<000000?ooo`3o
ool0<`3oool20000od`0oooo002/0?ooo`80003o6P3oool00`000000oooo
0?ooo`0I0?ooo`80003oR03oool00`000?l0oooo0?ooo`0P0?ooo`030000
003oool0oooo03D0oooo0P000?m:0?ooo`00Z03oool40000oa`0oooo00<0
00000?ooo`3oool06`3oool40000oh<0oooo00<0003o0?ooo`3oool08@3o
ool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo04L0oooo002V
0?ooo`80003o803oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0
oooo07l0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?ooo`0h
0?ooo`80003oA`3oool00:@0oooo0P000?lR0?ooo`030000003oool0oooo
0200oooo0P000?mm0?ooo`80003o9@3oool00`000000oooo0?ooo`0j0?oo
o`030000o`3oool0oooo04@0oooo002R0?ooo`80003o903oool00`000000
oooo0?ooo`0R0?ooo`80003oNP3oool00`000?l0oooo0?ooo`0U0?ooo`03
0000003oool0oooo03/0oooo0P000?m40?ooo`00X03oool20000obH0oooo
00<000000?ooo`3oool0903oool20000ogL0oooo00<0003o0?ooo`3oool0
9P3oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo0440oooo
002O0?ooo`030000o`3oool0oooo02H0oooo00<000000?ooo`3oool09P3o
ool20000og@0oooo00<0003o0?ooo`3oool09`3oool00`000000oooo0?oo
o`0n0?ooo`030000o`3oool0oooo0400oooo002M0?ooo`80003o:@3oool0
0`000000oooo0?ooo`0X0?ooo`80003oL@3oool00`000?l0oooo0?ooo`0X
0?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool0?`3oool0
09/0oooo0P000?l[0?ooo`030000003oool0oooo02X0oooo00<0003o0?oo
o`3oool0K@3oool00`000?l0oooo0?ooo`0Y0?ooo`030000003oool0oooo
0400oooo00<0003o0?ooo`3oool0?P3oool009T0oooo0P000?l]0?ooo`03
0000003oool0oooo02/0oooo0P000?m[0?ooo`80003o9P3oool3000000<0
oooo00<000000?ooo`3oool0@@3oool20000och0oooo002H0?ooo`030000
o`3oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool20000ofP0oooo
00<0003o0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo04<0oooo00<0003o0?ooo`3oool0>`3oool009L0oooo00<0
003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`030000o`3o
ool0oooo06D0oooo00<0003o0?ooo`3oool09@3oool5000000<0oooo0P00
00150?ooo`030000o`3oool0oooo03X0oooo002F0?ooo`030000o`3oool0
oooo02l0oooo00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`1S
0?ooo`030000o`3oool0oooo0200oooo100000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?oo
o`0i0?ooo`00U03oool20000oc80oooo00<000000?ooo`3oool0<03oool2
0000of80oooo00<0003o0?ooo`3oool0:03oool00`000000oooo00000004
0?ooo`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool0>03oool0
09<0oooo00<0003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?oo
o`80003oG`3oool00`000?l0oooo0?ooo`0Z0?ooo`800000103oool00`00
0000oooo0?ooo`170?ooo`030000o`3oool0oooo03L0oooo002B0?ooo`03
0000o`3oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool00`000?l0
oooo0?ooo`1L0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3o
ool0B03oool00`000?l0oooo0?ooo`0f0?ooo`00T@3oool00`000?l0oooo
0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<0003o0?ooo`3oool0
F`3oool00`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo04P0oooo
00<0003o0?ooo`3oool0=P3oool008l0oooo0P000?lg0?ooo`030000003o
ool0oooo03D0oooo0P000?mJ0?ooo`030000o`3oool0oooo0380oooo00<0
00000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`0e0?ooo`00SP3oool0
0`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<0003o
0?ooo`3oool0EP3oool00`000?l0oooo0?ooo`0c0?ooo`030000003oool0
oooo04X0oooo00<0003o0?ooo`3oool0=03oool008d0oooo00<0003o0?oo
o`3oool0>03oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo
05@0oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`1;0?oo
o`030000o`3oool0oooo03<0oooo002<0?ooo`030000o`3oool0oooo03T0
oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`1B0?ooo`03
0000o`3oool0oooo03D0oooo00<000000?ooo`3oool0C03oool00`000?l0
oooo0?ooo`0b0?ooo`00R`3oool00`000?l0oooo0?ooo`0j0?ooo`030000
003oool0oooo03X0oooo00<0003o0?ooo`3oool0D@3oool00`000?l0oooo
0?ooo`0e0?ooo`030000003oool0oooo04d0oooo00<0003o0?ooo`3oool0
<@3oool008X0oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?oo
o`0k0?ooo`030000o`3oool0oooo04l0oooo00<0003o0?ooo`3oool0=P3o
ool00`000000oooo0?ooo`1=0?ooo`030000o`3oool0oooo0340oooo002:
0?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0?03oool0
0`000?l0oooo0?ooo`1>0?ooo`030000o`3oool0oooo03H0oooo00<00000
0?ooo`3oool0CP3oool00`000?l0oooo0?ooo`0`0?ooo`00R@3oool00`00
0?l0oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<0003o0?oo
o`3oool0C@3oool00`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo
04l0oooo00<0003o0?ooo`3oool0;`3oool008P0oooo00<0003o0?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo04`0
oooo00<0003o0?ooo`3oool0=`3oool00`000000oooo0?ooo`1@0?ooo`03
0000o`3oool0oooo02h0oooo00270?ooo`030000o`3oool0oooo03h0oooo
00<000000?ooo`3oool0?P3oool00`000?l0oooo0?ooo`1:0?ooo`030000
o`3oool0oooo0340oooo0P0000050?ooo`030000003oool0oooo0500oooo
00<0003o0?ooo`3oool0;P3oool008H0oooo00<0003o0?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo04X0oooo00<0
003o0?ooo`3oool0<03oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0540oooo00<0003o0?ooo`3oool0;@3oool008H0oooo00<0
003o0?ooo`3oool0?`3oool00`000000oooo0?ooo`0o0?ooo`030000o`3o
ool0oooo04P0oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?oo
o`030?ooo`800000D`3oool00`000?l0oooo0?ooo`0/0?ooo`00Q@3oool0
0`000?l0oooo0?ooo`100?ooo`030000003oool0oooo0400oooo0P000?m7
0?ooo`030000o`3oool0oooo02`0oooo100000050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0DP3oool00`000?l0oooo0?ooo`0/
0?ooo`00Q03oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo
0440oooo00<0003o0?ooo`3oool0A@3oool00`000?l0oooo0?ooo`0b0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0D`3oool0
0`000?l0oooo0?ooo`0[0?ooo`00Q03oool00`000?l0oooo0?ooo`110?oo
o`030000003oool0oooo0480oooo00<0003o0?ooo`3oool0@`3oool00`00
0?l0oooo0?ooo`0d0?ooo`8000001@3oool00`000000oooo0?ooo`1C0?oo
o`030000o`3oool0oooo02/0oooo00230?ooo`030000o`3oool0oooo0480
oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`130?ooo`03
0000o`3oool0oooo03/0oooo00<000000?ooo`3oool0E03oool00`000?l0
oooo0?ooo`0Z0?ooo`00PP3oool00`000?l0oooo0?ooo`130?ooo`030000
003oool0oooo04<0oooo00<0003o0?ooo`3oool0@@3oool00`000?l0oooo
0?ooo`0l0?ooo`030000003oool0oooo05@0oooo00<0003o0?ooo`3oool0
:P3oool00840oooo00<0003o0?ooo`3oool0?@3oool500000080oooo00<0
00000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`110?ooo`030000o`3o
ool0oooo02H0oooo4P000?l40?ooo`030000003oool0oooo05D0oooo00<0
003o0?ooo`3oool0:@3oool00840oooo00<0003o0?ooo`3oool0?`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo04@0oooo00<0003o
0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0T0?ooo`<0003o4P3oool3
0000o`030?ooo`000000oooo05H0oooo00<0003o0?ooo`3oool0:@3oool0
0800oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`020?oo
o`800000AP3oool00`000?l0oooo0?ooo`0n0?ooo`030000o`3oool0oooo
0200oooo10000?lH0?ooo`<0003oE`3oool00`000?l0oooo0?ooo`0X0?oo
o`00O`3oool00`000?l0oooo0?ooo`0i0?ooo`@00000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3o
ool0?@3oool00`000?l0oooo0?ooo`0N0?ooo`<0003o7@3oool00`000000
oooo0000o`030000oe<0oooo00<0003o0?ooo`3oool0:03oool007l0oooo
00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo04H0oooo00<0003o0?ooo`3oool0?03oool00`000?l0oooo
0?ooo`0L0?ooo`80003o803oool00`000000oooo0?ooo`030?ooo`80003o
DP3oool00`000?l0oooo0?ooo`0W0?ooo`00OP3oool00`000?l0oooo0?oo
o`110?ooo`800000103oool00`000000oooo0?ooo`160?ooo`030000o`3o
ool0oooo03/0oooo00<0003o0?ooo`3oool06`3oool20000ob80oooo00<0
00000?ooo`3oool01@3oool20000oe00oooo00<0003o0?ooo`3oool09`3o
ool007h0oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`17
0?ooo`030000o`3oool0oooo03X0oooo00<0003o0?ooo`3oool06@3oool2
0000ob@0oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`1>
0?ooo`030000o`3oool0oooo02H0oooo001m0?ooo`030000o`3oool0oooo
04P0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0j0?oo
o`030000o`3oool0oooo01P0oooo00<0003o0?ooo`3oool0903oool00`00
0000oooo0?ooo`080?ooo`80003oCP3oool00`000?l0oooo0?ooo`0V0?oo
o`00O@3oool00`000?l0oooo0?ooo`180?ooo`030000003oool0oooo04P0
oooo00<0003o0?ooo`3oool0>03oool00`000?l0oooo0?ooo`0G0?ooo`80
003o9`3oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo04`0
oooo00<0003o0?ooo`3oool09@3oool007`0oooo00<0003o0?ooo`3oool0
B@3oool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo03P0oooo
00<0003o0?ooo`3oool05@3oool20000ob40oooo100000040?ooo`030000
003oool0oooo00/0oooo0P000?m<0?ooo`030000o`3oool0oooo02D0oooo
001l0?ooo`030000o`3oool0oooo04T0oooo00<000000?ooo`3oool0B@3o
ool00`000?l0oooo0?ooo`0g0?ooo`030000o`3oool0oooo01<0oooo0P00
0?lS0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`190?ooo`030000o`3oool0oooo02D0oooo001l
0?ooo`030000o`3oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool0
0`000?l0oooo0?ooo`0g0?ooo`030000o`3oool0oooo0180oooo00<0003o
0?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`8000003`3oool0
0`000?l0oooo0?ooo`190?ooo`030000o`3oool0oooo02@0oooo001l0?oo
o`030000o`3oool0oooo04T0oooo00<000000?ooo`3oool0BP3oool00`00
0?l0oooo0?ooo`0e0?ooo`030000o`3oool0oooo0180oooo00<0003o0?oo
o`3oool07P3oool4000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0?0?ooo`80003oB@3oool00`000?l0oooo0?ooo`0T0?oo
o`00N`3oool00`000?l0oooo0?ooo`1:0?ooo`030000003oool0oooo04X0
oooo00<0003o0?ooo`3oool0=@3oool00`000?l0oooo0?ooo`0@0?ooo`80
003o9`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0140oooo00<0003o0?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0S0?oo
o`00N`3oool00`000?l0oooo0?ooo`1:0?ooo`030000003oool0oooo04/0
oooo00<0003o0?ooo`3oool0=03oool00`000?l0oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo02P0oooo0P0000050?ooo`030000003oool0oooo0180
oooo00<0003o0?ooo`3oool0AP3oool00`000?l0oooo0?ooo`0S0?ooo`00
NP3oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo
00<0003o0?ooo`3oool0=03oool00`000?l0oooo0?ooo`0>0?ooo`030000
o`3oool0oooo0300oooo00<000000?ooo`3oool04`3oool00`000?l0oooo
0?ooo`150?ooo`030000o`3oool0oooo02<0oooo001i0?ooo`030000o`3o
ool0oooo04`0oooo00<000000?ooo`3oool0B`3oool00`000?l0oooo0?oo
o`0d0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo04D0oooo00<0
003o0?ooo`3oool08P3oool007T0oooo00<0003o0?ooo`3oool0C03oool0
0`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo03<0oooo00<0003o
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0a0?ooo`030000003oool0
oooo01@0oooo00<0003o0?ooo`3oool0A@3oool00`000?l0oooo0?ooo`0R
0?ooo`00N@3oool00`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo
04`0oooo00<0003o0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`0<0?oo
o`030000o`3oool0oooo0380oooo00<000000?ooo`3oool05@3oool00`00
0?l0oooo0?ooo`150?ooo`030000o`3oool0oooo0240oooo001i0?ooo`03
0000o`3oool0oooo04`0oooo00<000000?ooo`3oool0C@3oool00`000?l0
oooo0?ooo`0a0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo04@0
oooo00<0003o0?ooo`3oool08@3oool007P0oooo00<0003o0?ooo`3oool0
C@3oool00`000000oooo0?ooo`1=0?ooo`030000o`3oool0oooo0340oooo
00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0c0?ooo`030000
003oool0oooo01H0oooo00<0003o0?ooo`3oool0A03oool00`000?l0oooo
0?ooo`0Q0?ooo`00N03oool00`000?l0oooo0?ooo`1=0?ooo`030000003o
ool0oooo04d0oooo00<0003o0?ooo`3oool0<@3oool00`000?l0oooo0?oo
o`0;0?ooo`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool05`3o
ool00`000?l0oooo0?ooo`130?ooo`030000o`3oool0oooo0240oooo001h
0?ooo`030000o`3oool0oooo04d0oooo00<000000?ooo`3oool0C@3oool0
0`000?l0oooo0?ooo`0a0?ooo`030000o`3oool0oooo00X0oooo00<0003o
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0G0?ooo`030000o`3oool0
oooo04@0oooo00<0003o0?ooo`3oool0803oool007P0oooo00<0003o0?oo
o`3oool0C@3oool00`000000oooo0?ooo`1>0?ooo`030000o`3oool0oooo
0300oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0f0?oo
o`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool0@`3oool00`00
0?l0oooo0?ooo`0P0?ooo`00M`3oool00`000?l0oooo0?ooo`1>0?ooo`03
0000003oool0oooo04h0oooo00<0003o0?ooo`3oool0<03oool00`000?l0
oooo0?ooo`080?ooo`030000o`3oool0oooo03L0oooo00<000000?ooo`3o
ool0603oool00`000?l0oooo0?ooo`130?ooo`030000o`3oool0oooo0200
oooo001g0?ooo`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool0
CP3oool00`000?l0oooo0?ooo`0`0?ooo`030000o`3oool0oooo00P0oooo
00<0003o0?ooo`3oool0;`3oool5000000<0oooo00<000000?ooo`3oool0
6@3oool00`000?l0oooo0?ooo`120?ooo`030000o`3oool0oooo0200oooo
001g0?ooo`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool0CP3o
ool00`000?l0oooo0?ooo`0`0?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01X0oooo00<0003o0?ooo`3oool0@@3oool00`000?l0oooo0?oo
o`0P0?ooo`00M`3oool00`000?l0oooo0?ooo`1>0?ooo`030000003oool0
oooo04l0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool00`3oool2
000001`0oooo00<0003o0?ooo`3oool0@@3oool00`000?l0oooo0?ooo`0O
0?ooo`00MP3oool00`000?l0oooo0?ooo`1?0?ooo`030000003oool0oooo
04l0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo02`0oooo100000040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`110?oo
o`030000o`3oool0oooo01l0oooo001f0?ooo`030000o`3oool0oooo04l0
oooo00<000000?ooo`3oool0C`3oool00`000?l0oooo0?ooo`0_0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0=03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3o
ool0@@3oool00`000?l0oooo0?ooo`0O0?ooo`00MP3oool00`000?l0oooo
0?ooo`1?0?ooo`030000003oool0oooo04l0oooo00<0003o0?ooo`3oool0
;`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03@0oooo
0P0000050?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0
@03oool00`000?l0oooo0?ooo`0O0?ooo`00MP3oool00`000?l0oooo0?oo
o`1?0?ooo`030000003oool0oooo04l0oooo00<0003o0?ooo`3oool0;`3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03/0oooo00<0
00000?ooo`3oool0703oool00`000?l0oooo0?ooo`100?ooo`030000o`3o
ool0oooo01l0oooo001f0?ooo`030000o`3oool0oooo04l0oooo00<00000
0?ooo`3oool0C`3oool00`000?l0oooo0?ooo`0_0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`0L
0?ooo`030000o`3oool0oooo0400oooo00<0003o0?ooo`3oool07`3oool0
07H0oooo00<0003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`1?0?oo
o`030000o`3oool0oooo02l0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0l0?ooo`030000003oool0oooo01d0oooo00<0003o0?oo
o`3oool0@03oool00`000?l0oooo0?ooo`0N0?ooo`00MP3oool010000?l0
000000000000000V0?ooo`D000008`3oool00`000000oooo0?ooo`0U0?oo
o`D00000903oool2000000030000o`000000oooo02h0oooo00<0003o0?oo
o`3oool00P3oool00`000?l000000000000=0?ooo`8000003@3oool40000
00d0oooo1@00000;0?ooo`030000003oool0oooo00/0oooo1@00000<0?oo
o`04000000000?l00000000000d0oooo0P00000@0?ooo`<000003@3oool2
000000l0oooo00<0003o0?ooo`3oool07P3oool007H0oooo00<0003o0?oo
o`3oool0:@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0903oool00`000000oooo0000o`0`0?oo
o`030000o`3oool0oooo0080oooo00<0003o0000003oool0303oool01000
0000oooo0?ooo`00000<0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00`0oooo00<000000000o`3oool03@3oool010000000oooo0?ooo`00
000@0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool00000
3P3oool00`000?l0oooo0?ooo`0N0?ooo`00MP3oool00`000?l000000?oo
o`0Y0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0U0?ooo`03000000000?l0oooo02l0oooo00<0
003o0?ooo`3oool00P0000000`000?l000000000000>0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo1@00
000?0?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool07P3o
ool00700oooo100000001@3oool0003o0?ooo`3oool000000240oooo1000
00040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo02/0oooo1000
00001P000?l0oooo000000000?l0oooo000000L0oooo100000050?ooo`03
0000003oool0oooo00@0oooo100000040?ooo`030000003oool0oooo00H0
oooo100000040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000o`000000oooo00l0
oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00000>0?oo
o`8000003`3oool00`000?l0oooo0?ooo`0N0?ooo`00M@3oool01@000?l0
00000?ooo`3oool0000002P0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo02@0oooo00@000000?oo
o`000?l00000<03oool01P000?l0oooo0?ooo`000?l0oooo000000d0oooo
00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00000?0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`04000000000?l0oooo000000`0oooo00@00000
0?ooo`3oool000003P3oool00`000000oooo0000000>0?ooo`030000003o
ool0oooo00h0oooo00<0003o0?ooo`3oool07P3oool007D0oooo00@0003o
0?ooo`0000000000:03oool2000002D0oooo00<000000?ooo`3oool09P3o
ool2000002L0oooo00<000000000o`3oool0<03oool010000?l0oooo0?oo
o`000?l2000000h0oooo0P00000>0?ooo`8000003`3oool2000000d0oooo
00<000000?ooo`3oool0303oool2000000l0oooo00<0003o0000003oool0
3@3oool200000100oooo0P00000>0?ooo`<000003P3oool00`000?l0oooo
0?ooo`0N0?ooo`00M@3oool00`000?l0oooo0?ooo`1@0?ooo`030000003o
ool0oooo0500oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0000
o`110?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool0?`3o
ool00`000?l0oooo0?ooo`0N0?ooo`00M@3oool00`000?l0oooo0?ooo`1?
0?ooo`<0o`00D@3oool00`000?l0oooo0?ooo`0_0?ooo`030000o`3oool0
003o0440oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0o
0?ooo`030000o`3oool0oooo01h0oooo001e0?ooo`030000o`3oool0oooo
04h0oooo1@3o001@0?ooo`030000o`3oool0oooo00`0oooo0P0000000`3o
ool000000000000N0?ooo`80003o@P3oool00`000000oooo0?ooo`0N0?oo
o`030000o`3oool0oooo03l0oooo00<0003o0?ooo`3oool03P3oool40000
00`0oooo001e0?ooo`030000o`3oool0oooo04d0oooo1`3o001?0?ooo`03
0000o`3oool0oooo00d0oooo00<000000?ooo`000000803oool00`000?l0
oooo0?ooo`100?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3o
ool0?`3oool00`000?l0oooo0?ooo`0=0?ooo`040000003oool0oooo0000
00d0oooo001]0?ooo`P0000000<0003o000000000000C@0000070?l004l0
000000<0003o0000000000001`0000070?ooo`030000003oool0oooo01L0
oooo200000000`000?l000000000001Q000000030000o`000000000003l0
000000<0003o0000000000001`0000060?ooo`040000003oool0oooo0000
00d0oooo001e0?ooo`030000o`3oool0oooo02L0oooo00<000000?ooo`3o
ool08`3oool70?l002H0oooo00<000000?ooo`3oool09P3oool00`000?l0
oooo0?ooo`0<0?ooo`80000000<0oooo0000000000007P3oool20000oa00
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<0003o0?ooo`3oool0303oool2000000030?ooo`000000000000d0
oooo001e0?ooo`030000o`3oool0oooo04h0oooo1@3o001@0?ooo`030000
o`3oool0oooo02l0oooo00<0003o0?ooo`000?l0@@3oool00`000000oooo
0?ooo`0N0?ooo`030000o`3oool0oooo03l0oooo00<0003o0?ooo`3oool0
7P3oool007D0oooo00<0003o0?ooo`3oool0C`3oool30?l000/0oooo00<0
00000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0_0?ooo`030000o`3o
ool0003o0440oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?oo
o`0o0?ooo`030000o`3oool0oooo01h0oooo001e0?ooo`030000o`3oool0
oooo0500oooo00<000000?ooo`3oool02@3oool00`000000oooo00000014
0?ooo`030000o`3oool0oooo02l0oooo00<0003o0?ooo`000?l0@@3oool0
0`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo03l0oooo00<0003o
0?ooo`3oool07P3oool007D0oooo00<0003o0?ooo`3oool0D03oool00`00
0000oooo0?ooo`020?ooo`D000000P3oool00`000000oooo000000140?oo
o`030000o`3oool0oooo02l0oooo00<0003o0?ooo`000?l0@@3oool00`00
0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo03l0oooo00<0003o0?oo
o`3oool07P3oool007D0oooo00<0003o0?ooo`3oool0D03oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`000000A03oool00`000?l0oooo0?ooo`0_0?ooo`040000o`3oool0oooo
0000od00oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`10
0?ooo`030000o`3oool0oooo01h0oooo001e0?ooo`030000o`3oool0oooo
0500oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0000004@0oooo00<0003o0?ooo`3oool0;`3oool01000
0?l0oooo0?ooo`000?m00?ooo`030000003oool0oooo01d0oooo00<0003o
0?ooo`3oool0@03oool00`000?l0oooo0?ooo`0N0?ooo`00MP3oool00`00
0?l0oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`130?ooo`030000o`3oool0oooo
02l0oooo00@0003o0?ooo`3oool0003o@03oool00`000000oooo0?ooo`0M
0?ooo`030000o`3oool0oooo0400oooo00<0003o0?ooo`3oool07P3oool0
07H0oooo00<0003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo000004T0oooo00<0003o0?ooo`3oool0;P3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03d0oooo00<00000
0?ooo`3oool07@3oool00`000?l0oooo0?ooo`100?ooo`030000o`3oool0
oooo01h0oooo001f0?ooo`030000o`3oool0oooo04l0oooo00<000000?oo
o`3oool00`3oool5000004P0oooo00<0003o0?ooo`3oool0;P3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03d0oooo00<000000?oo
o`3oool0703oool00`000?l0oooo0?ooo`110?ooo`030000o`3oool0oooo
01h0oooo001f0?ooo`030000o`3oool0oooo04l0oooo00<000000?ooo`3o
ool0C`3oool00`000?l0oooo0?ooo`0_0?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`0L0?ooo`03
0000o`3oool0oooo0400oooo00<0003o0?ooo`3oool07`3oool007H0oooo
00<0003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`1?0?ooo`030000
o`3oool0oooo02l0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0l0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0
@03oool00`000?l0oooo0?ooo`0O0?ooo`00MP3oool00`000?l0oooo0?oo
o`1?0?ooo`030000003oool0oooo04l0oooo00<0003o0?ooo`3oool0;`3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03/0oooo00<0
00000?ooo`3oool06`3oool00`000?l0oooo0?ooo`110?ooo`030000o`3o
ool0oooo01l0oooo001f0?ooo`030000o`3oool0oooo04l0oooo00<00000
0?ooo`3oool0C`3oool00`000?l0oooo0?ooo`0_0?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0K
0?ooo`030000o`3oool0oooo0440oooo00<0003o0?ooo`3oool07`3oool0
07H0oooo00<0003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`1?0?oo
o`030000o`3oool0oooo02l0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0b0?ooo`D000000`3oool00`000000oooo0?ooo`0K0?oo
o`030000o`3oool0oooo0440oooo00<0003o0?ooo`3oool07`3oool007L0
oooo00<0003o0?ooo`3oool0CP3oool00`000000oooo0?ooo`1?0?ooo`03
0000o`3oool0oooo02l0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0c0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool06P3oool00`000?l0oooo0?ooo`120?ooo`030000o`3oool0oooo01l0
oooo001g0?ooo`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool0
CP3oool00`000?l0oooo0?ooo`0`0?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`030?ooo`800000
6`3oool00`000?l0oooo0?ooo`120?ooo`030000o`3oool0oooo01l0oooo
001g0?ooo`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool0CP3o
ool00`000?l0oooo0?ooo`0`0?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01T0oooo00<0003o0?ooo`3oool0@P3oool00`000?l0oooo0?oo
o`0P0?ooo`00M`3oool00`000?l0oooo0?ooo`1>0?ooo`030000003oool0
oooo04h0oooo00<0003o0?ooo`3oool0<03oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo0480oooo00<0003o
0?ooo`3oool0803oool007P0oooo00<0003o0?ooo`3oool0C@3oool00`00
0000oooo0?ooo`1>0?ooo`030000o`3oool0oooo0300oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0_0?ooo`8000001@3oool00`00
0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo04<0oooo00<0003o0?oo
o`3oool0803oool007P0oooo00<0003o0?ooo`3oool0C@3oool00`000000
oooo0?ooo`1=0?ooo`030000o`3oool0oooo0340oooo00<0003o0?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0f0?ooo`030000003oool0oooo01P0
oooo00<0003o0?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0P0?ooo`00
N03oool00`000?l0oooo0?ooo`1=0?ooo`030000003oool0oooo04d0oooo
00<0003o0?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0:0?ooo`030000
o`3oool0oooo03D0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo
0?ooo`140?ooo`030000o`3oool0oooo0200oooo001h0?ooo`030000o`3o
ool0oooo04d0oooo00<000000?ooo`3oool0C@3oool00`000?l0oooo0?oo
o`0a0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0=03o
ool00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo04<0oooo00<0
003o0?ooo`3oool08@3oool007T0oooo00<0003o0?ooo`3oool0C03oool0
0`000000oooo0?ooo`1=0?ooo`030000o`3oool0oooo0340oooo00<0003o
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0c0?ooo`030000003oool0
oooo01H0oooo00<0003o0?ooo`3oool0A03oool00`000?l0oooo0?ooo`0Q
0?ooo`00N@3oool00`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo
04`0oooo00<0003o0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`0;0?oo
o`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool05@3oool00`00
0?l0oooo0?ooo`150?ooo`030000o`3oool0oooo0240oooo001i0?ooo`03
0000o`3oool0oooo04`0oooo00<000000?ooo`3oool0C03oool00`000?l0
oooo0?ooo`0c0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo04D0
oooo00<0003o0?ooo`3oool08@3oool007T0oooo00<0003o0?ooo`3oool0
C03oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo03@0oooo
00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0a0?ooo`030000
003oool0oooo01@0oooo00<0003o0?ooo`3oool0A@3oool00`000?l0oooo
0?ooo`0R0?ooo`00NP3oool00`000?l0oooo0?ooo`1;0?ooo`030000003o
ool0oooo04/0oooo00<0003o0?ooo`3oool0=03oool00`000?l0oooo0?oo
o`0>0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`160?ooo`030000o`3oool0oooo0280oooo001j
0?ooo`030000o`3oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool0
0`000?l0oooo0?ooo`0d0?ooo`030000o`3oool0oooo00l0oooo00<0003o
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0B0?ooo`030000o`3oool0
oooo04H0oooo00<0003o0?ooo`3oool08`3oool007/0oooo00<0003o0?oo
o`3oool0BP3oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo
03@0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0^0?oo
o`030000003oool0oooo0140oooo00<0003o0?ooo`3oool0A`3oool00`00
0?l0oooo0?ooo`0S0?ooo`00N`3oool00`000?l0oooo0?ooo`1:0?ooo`03
0000003oool0oooo04X0oooo00<0003o0?ooo`3oool0=P3oool00`000?l0
oooo0?ooo`0@0?ooo`80003o9P3oool4000000@0oooo00<000000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`170?ooo`030000o`3oool0oooo02<0
oooo001l0?ooo`030000o`3oool0oooo04T0oooo00<000000?ooo`3oool0
BP3oool00`000?l0oooo0?ooo`0f0?ooo`030000o`3oool0oooo0180oooo
00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0100oooo00<0003o0?ooo`3oool0A`3oool00`000?l0oooo
0?ooo`0T0?ooo`00O03oool00`000?l0oooo0?ooo`190?ooo`030000003o
ool0oooo04T0oooo00<0003o0?ooo`3oool0=`3oool00`000?l0oooo0?oo
o`0C0?ooo`030000o`3oool0oooo02<0oooo00<000000?ooo`3oool0103o
ool200000100oooo00<0003o0?ooo`3oool0B03oool00`000?l0oooo0?oo
o`0T0?ooo`00O03oool00`000?l0oooo0?ooo`190?ooo`030000003oool0
oooo04T0oooo00<0003o0?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0D
0?ooo`030000o`3oool0oooo02<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0=0?ooo`80003oB`3oool00`000?l0oooo0?ooo`0T
0?ooo`00O03oool00`000?l0oooo0?ooo`190?ooo`030000003oool0oooo
04P0oooo00<0003o0?ooo`3oool0>03oool00`000?l0oooo0?ooo`0E0?oo
o`80003o8@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00`0oooo00<0003o0?ooo`3oool0BP3oool00`000?l0oooo0?ooo`0U
0?ooo`00O@3oool00`000?l0oooo0?ooo`180?ooo`030000003oool0oooo
04P0oooo00<0003o0?ooo`3oool0>@3oool00`000?l0oooo0?ooo`0F0?oo
o`030000o`3oool0oooo01l0oooo0P0000050?ooo`030000003oool0oooo
00X0oooo0P000?m=0?ooo`030000o`3oool0oooo02D0oooo001m0?ooo`03
0000o`3oool0oooo04P0oooo00<000000?ooo`3oool0A`3oool00`000?l0
oooo0?ooo`0j0?ooo`030000o`3oool0oooo01L0oooo0P000?lV0?ooo`03
0000003oool0oooo00T0oooo00<0003o0?ooo`3oool0C03oool00`000?l0
oooo0?ooo`0V0?ooo`00OP3oool00`000?l0oooo0?ooo`170?ooo`030000
003oool0oooo04L0oooo00<0003o0?ooo`3oool0>`3oool00`000?l0oooo
0?ooo`0H0?ooo`80003o903oool00`000000oooo0?ooo`070?ooo`80003o
C`3oool00`000?l0oooo0?ooo`0V0?ooo`00OP3oool00`000?l0oooo0?oo
o`100?ooo`D000000P3oool00`000000oooo0?ooo`160?ooo`030000o`3o
ool0oooo03`0oooo00<0003o0?ooo`3oool06P3oool20000ob80oooo00<0
00000?ooo`3oool01@3oool20000oe40oooo00<0003o0?ooo`3oool09P3o
ool007l0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool0?03oool0
0`000?l0oooo0?ooo`0L0?ooo`<0003o7`3oool00`000000oooo0?ooo`03
0?ooo`80003oDP3oool00`000?l0oooo0?ooo`0W0?ooo`00P03oool00`00
0?l0oooo0?ooo`100?ooo`030000003oool0oooo0080oooo0P0000160?oo
o`030000o`3oool0oooo03d0oooo00<0003o0?ooo`3oool07`3oool30000
oa`0oooo00@000000?ooo`3oool0oooo0P000?mD0?ooo`030000o`3oool0
oooo02L0oooo00200?ooo`030000o`3oool0oooo0400oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`140?ooo`030000o`3oool0oooo
03l0oooo00<0003o0?ooo`3oool08@3oool30000oaT0oooo00@000000000
o`000?l0003oE@3oool00`000?l0oooo0?ooo`0X0?ooo`00P@3oool00`00
0?l0oooo0?ooo`0o0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0A03oool00`000?l0oooo0?ooo`0o0?ooo`030000o`3oool0oooo
02@0oooo1@000?l?0?ooo`H0003oF03oool00`000?l0oooo0?ooo`0X0?oo
o`00P@3oool00`000?l0oooo0?ooo`0n0?ooo`800000103oool00`000000
oooo0?ooo`130?ooo`030000o`3oool0oooo0400oooo00<0003o0?ooo`3o
ool0:@3oool?0000o`D0oooo00<000000?ooo`3oool0E@3oool00`000?l0
oooo0?ooo`0Y0?ooo`00PP3oool00`000?l0oooo0?ooo`130?ooo`030000
003oool0oooo04<0oooo00<0003o0?ooo`3oool0@@3oool00`000?l0oooo
0?ooo`0l0?ooo`030000003oool0oooo05D0oooo00<0003o0?ooo`3oool0
:@3oool008<0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?oo
o`120?ooo`030000o`3oool0oooo0480oooo00<0003o0?ooo`3oool0?03o
ool00`000000oooo0?ooo`1D0?ooo`030000o`3oool0oooo02X0oooo0024
0?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0@P3oool0
0`000?l0oooo0?ooo`130?ooo`030000o`3oool0oooo03/0oooo00<00000
0?ooo`3oool0D`3oool00`000?l0oooo0?ooo`0[0?ooo`00Q@3oool00`00
0?l0oooo0?ooo`100?ooo`030000003oool0oooo0440oooo00<0003o0?oo
o`3oool0A@3oool00`000?l0oooo0?ooo`0c0?ooo`8000001@3oool00`00
0000oooo0?ooo`1C0?ooo`030000o`3oool0oooo02/0oooo00250?ooo`03
0000o`3oool0oooo0400oooo00<000000?ooo`3oool0@03oool00`000?l0
oooo0?ooo`160?ooo`030000o`3oool0oooo0380oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1B0?ooo`030000o`3oool0oooo
02`0oooo00260?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3o
ool0?`3oool00`000?l0oooo0?ooo`180?ooo`030000o`3oool0oooo03<0
oooo00<000000?ooo`3oool00`3oool2000005<0oooo00<0003o0?ooo`3o
ool0;03oool008H0oooo00<0003o0?ooo`3oool0?`3oool00`000000oooo
0?ooo`0n0?ooo`030000o`3oool0oooo04T0oooo00<0003o0?ooo`3oool0
=03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0540oooo
00<0003o0?ooo`3oool0;@3oool008L0oooo00<0003o0?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo04X0oooo00<0
003o0?ooo`3oool0<03oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0500oooo00<0003o0?ooo`3oool0;P3oool008P0oooo0P00
0?ln0?ooo`030000003oool0oooo03d0oooo00<0003o0?ooo`3oool0C03o
ool00`000?l0oooo0?ooo`0`0?ooo`8000001@3oool00`000000oooo0?oo
o`1?0?ooo`030000o`3oool0oooo02l0oooo00290?ooo`030000o`3oool0
oooo03`0oooo00<000000?ooo`3oool0?03oool00`000?l0oooo0?ooo`1=
0?ooo`030000o`3oool0oooo03L0oooo00<000000?ooo`3oool0C`3oool0
0`000?l0oooo0?ooo`0_0?ooo`00RP3oool00`000?l0oooo0?ooo`0k0?oo
o`030000003oool0oooo03`0oooo00<0003o0?ooo`3oool0CP3oool00`00
0?l0oooo0?ooo`0f0?ooo`030000003oool0oooo04h0oooo00<0003o0?oo
o`3oool0<03oool008/0oooo00<0003o0?ooo`3oool0>P3oool00`000000
oooo0?ooo`0j0?ooo`80003oD@3oool00`000?l0oooo0?ooo`0f0?ooo`03
0000003oool0oooo04d0oooo00<0003o0?ooo`3oool0<@3oool008`0oooo
00<0003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`0i0?ooo`030000
o`3oool0oooo0580oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo
0?ooo`1<0?ooo`030000o`3oool0oooo0380oooo002=0?ooo`030000o`3o
ool0oooo03P0oooo00<000000?ooo`3oool0>03oool00`000?l0oooo0?oo
o`1C0?ooo`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0C03o
ool00`000?l0oooo0?ooo`0b0?ooo`00SP3oool00`000?l0oooo0?ooo`0g
0?ooo`030000003oool0oooo03L0oooo00<0003o0?ooo`3oool0E@3oool0
0`000?l0oooo0?ooo`0d0?ooo`030000003oool0oooo04/0oooo00<0003o
0?ooo`3oool0<`3oool008l0oooo00<0003o0?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0f0?ooo`030000o`3oool0oooo05L0oooo00<0003o0?oo
o`3oool0<`3oool00`000000oooo0?ooo`1:0?ooo`030000o`3oool0oooo
03@0oooo002@0?ooo`030000o`3oool0oooo03D0oooo00<000000?ooo`3o
ool0=P3oool00`000?l0oooo0?ooo`1H0?ooo`030000o`3oool0oooo0380
oooo00<000000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`0e0?ooo`00
T@3oool00`000?l0oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo
0P000?mL0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0
B03oool00`000?l0oooo0?ooo`0f0?ooo`00TP3oool00`000?l0oooo0?oo
o`0c0?ooo`030000003oool0oooo03<0oooo00<0003o0?ooo`3oool0G@3o
ool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo04L0oooo00<0
003o0?ooo`3oool0=`3oool009<0oooo00<0003o0?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0c0?ooo`030000o`3oool0oooo05h0oooo00<0003o
0?ooo`3oool0:@3oool3000000<0oooo00<000000?ooo`3oool0AP3oool0
0`000?l0oooo0?ooo`0h0?ooo`00U03oool00`000?l0oooo0?ooo`0a0?oo
o`030000003oool0oooo0340oooo0P000?mR0?ooo`030000o`3oool0oooo
02T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`150?oo
o`030000o`3oool0oooo03T0oooo002E0?ooo`80003o<@3oool00`000000
oooo0?ooo`0_0?ooo`80003oI@3oool00`000?l0oooo0?ooo`0U0?ooo`D0
00000`3oool2000004D0oooo00<0003o0?ooo`3oool0>P3oool009L0oooo
0P000?l_0?ooo`030000003oool0oooo02h0oooo00<0003o0?ooo`3oool0
IP3oool00`000?l0oooo0?ooo`0T0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0k0?ooo`00
V03oool00`000?l0oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo
00<0003o0?ooo`3oool0J03oool00`000?l0oooo0?ooo`0T0?ooo`030000
003oool0000000@0oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo
0?ooo`0l0?ooo`00V@3oool00`000?l0oooo0?ooo`0/0?ooo`030000003o
ool0oooo02`0oooo00<0003o0?ooo`3oool0JP3oool00`000?l0oooo0?oo
o`0T0?ooo`800000103oool00`000000oooo0?ooo`110?ooo`030000o`3o
ool0oooo03d0oooo002J0?ooo`80003o;03oool00`000000oooo0?ooo`0Z
0?ooo`80003oK@3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003oool0
oooo03l0oooo0P000?m00?ooo`00W03oool20000obX0oooo00<000000?oo
o`3oool0:@3oool00`000?l0oooo0?ooo`1^0?ooo`030000o`3oool0oooo
02T0oooo00<000000?ooo`3oool0?P3oool00`000?l0oooo0?ooo`100?oo
o`00WP3oool20000obP0oooo00<000000?ooo`3oool09`3oool20000og80
oooo00<0003o0?ooo`3oool0:03oool00`000000oooo0?ooo`0m0?ooo`03
0000o`3oool0oooo0440oooo002P0?ooo`030000o`3oool0oooo02D0oooo
00<000000?ooo`3oool09@3oool20000ogD0oooo00<0003o0?ooo`3oool0
9`3oool00`000000oooo0?ooo`0k0?ooo`80003oA03oool00:40oooo0P00
0?lU0?ooo`030000003oool0oooo02<0oooo0P000?mh0?ooo`80003o9`3o
ool00`000000oooo0?ooo`0j0?ooo`030000o`3oool0oooo04@0oooo002S
0?ooo`80003o8`3oool00`000000oooo0?ooo`0Q0?ooo`80003oO03oool0
0`000?l0oooo0?ooo`0T0?ooo`030000003oool0oooo03T0oooo00<0003o
0?ooo`3oool0A@3oool00:D0oooo0P000?lQ0?ooo`030000003oool0oooo
01l0oooo0P000?mo0?ooo`030000o`3oool0oooo02<0oooo00<000000?oo
o`3oool0=`3oool20000odP0oooo002W0?ooo`@0003o7@3oool00`000000
oooo0?ooo`0L0?ooo`<0003oPP3oool20000ob<0oooo00<000000?ooo`3o
ool0=P3oool00`000?l0oooo0?ooo`180?ooo`00Z`3oool20000oa/0oooo
00<000000?ooo`3oool06P3oool20000ohL0oooo00<0003o0?ooo`3oool0
803oool00`000000oooo0?ooo`0d0?ooo`80003oB`3oool00:d0oooo1000
0?lG0?ooo`030000003oool0oooo01H0oooo10000?n:0?ooo`80003o803o
ool00`000000oooo0?ooo`0b0?ooo`80003oC@3oool00;40oooo10000?lC
0?ooo`030000003oool0oooo0180oooo10000?n@0?ooo`80003o7P3oool0
0`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo04d0oooo002e0?oo
o`@0003o203oool4000000<0oooo00<000000?ooo`3oool03P3oool40000
oiH0oooo0P000?lE0?ooo`8000001@3oool00`000000oooo0?ooo`0_0?oo
o`80003oD03oool00;T0oooo1P000?l20?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01`3oool70000oi`0oooo0P000?lB0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0;@3oool20000
oe80oooo002o0?oooa<0003oY@3oool20000oa<0oooo00<000000?ooo`3o
ool00P3oool2000002`0oooo0P000?mD0?ooo`00``3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0:h0oooo0`000?l>0?ooo`800000
1@3oool00`000000oooo0?ooo`0Y0?ooo`80003oEP3oool00<40oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`2a0?ooo`<0003o
2`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02H0oooo
0`000?mH0?ooo`00`P3oool2000000@0oooo00<000000?ooo`3oool0]03o
ool30000o`P0oooo0`0000040?ooo`030000003oool0oooo02@0oooo0P00
0?mK0?ooo`00b03oool00`000000oooo0?ooo`2g0?ooo`80003o3@3oool0
0`000000oooo0?ooo`0P0?ooo`@0003oG@3oool00<P0oooo00<000000?oo
o`3oool0^@3oool40000o`T0oooo00<000000?ooo`3oool0703oool40000
of40oooo00380?ooo`030000003oool0oooo0;d0oooo1@000?l40?ooo`03
0000003oool0oooo01L0oooo1@000?mU0?ooo`00b03oool00`000000oooo
0?ooo`320?ooo`L0003o4@3oool60000ofX0oooo00380?ooo`030000003o
ool0oooo0<H0oooo00<000000?ooo`3oool04@000?m`0?ooo`00o`3ooooo
0?oooaL0oooo003o0?ooool0oooo5`3oool00?l0ooooo`3ooolG0?ooo`00
o`3ooooo0?oooaL0oooo003o0?ooool0oooo5`3oool00?l0ooooo`3ooolG
0?ooo`00o`3ooooo0?oooaL0oooo00360?ooo`800000o`3ooom>0?ooo`00
a`3oool00`000000oooo0?ooo`3o0?oood`0oooo00380?ooo`030000003o
ool0oooo0<D0oooo0P0000230?ooo`00a`3oool00`000000oooo00000036
0?ooo`800000P`3oool00<H0oooo00@000000?ooo`3oool00000a@3oool0
10000000oooo0?ooo`0000220?ooo`00a@3oool3000000030?ooo`000000
00000<<0oooo0P0000020?ooo`800000P@3oool00?l0ooooo`3ooolG0?oo
o`00o`3ooooo0?oooaL0oooo003o0?ooool0oooo5`3oool00?l0ooooo`3o
oolG0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{533, 206},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 8.12",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/rouchetheorem/\
RoucheTheoremFigures/mat0812.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The image curve  ",
  Cell[BoxData[
      \(f \((\(C\_2\) \((0)\))\)\)]],
  "  under  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ z\^2 + z\)\)],
    AspectRatioFixed->True],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.25.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "We consider the function  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ z\^2 + z\)],
    AspectRatioFixed->True],
  "  and evaluate the integral  ",
  Cell[BoxData[
      \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \(\[Integral]\_C\ \(\(f' \((z)\)\)\
\/\(f \((z)\)\)\) \[DifferentialD]z\) = \ N\)]],
  ",\nwhere ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is the unit circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 1\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(z = 0; \ Remove[z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, \[Theta]];\)\ \), "\n", 
    \(\(f[z_]\  = \ z\^2 + z;\)\ \), "\n", 
    \(\(z[\[Theta]_]\  = \ 
        2  \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\);\)\ \), "\n", 
    \(\(F[\[Theta]_]\  = \[Integral]\(\(f'\)[z[\[Theta]]]\/f[
                  z[\[Theta]]]\) \(z'\)[\[Theta]] \[DifferentialD]\[Theta];\)\
\ \), "\n", 
    \(\(val\  = \ \[Integral]\_0\%\(2  \[Pi]\)\(\(f'\)[z[\[Theta]]]\/f[
                  z[\[Theta]]]\) \(z'\)[\[Theta]] \[DifferentialD]\[Theta];\)\
\ \), "\n", 
    \(\(Print["\<              f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<              z[\[Theta]] = \>", z[\[Theta]]];\)\ \), "\n", 
    \(\(Print["\<           f[z[\[Theta]]] = \>", 
        f[z[\[Theta]]]];\)\ \), "\n", 
    \(\(Print["\<             z'[\[Theta]] = \>", \(z'\)[\[Theta]]];\)\ \), "\
\n", 
    \(\(Print[\*"\"\<   \!\(\(f'\)[z[\[Theta]]]\/f[z[\[Theta]]]\) \
z'[\[Theta]] = \>\"", \(f'\)[z[\[Theta]]]\/f[z[\[Theta]]]\ \(z'\)[\[Theta]]];\
\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<F[\[Theta]] = \[Integral]\!\(\(f'\)[z[\[Theta]]]\/f[z[\
\[Theta]]]\)z'[\[Theta]]\[DifferentialD]\[Theta] = \>\"", 
        F[\[Theta]]];\)\ \), "\n", 
    \(\(Print["\<F[2\[Pi]] = \>", F[2  \[Pi]], "\<,    F[0] = \>", 
        F[0]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<\[Integral]\>"\+0\%\(2  \[Pi]\), \
\*"\"\<\!\(\(f'\)[z[\[Theta]]]\/f[z[\[Theta]]]\)z'[\[Theta]]\[DifferentialD]\
\[Theta] = \>\"", F[2  \[Pi]], "\< - \>", F[0], "\< = \>", 
        F[2  \[Pi]] - F[0]];\)\ \), "\n", 
    \(\(Print["\<\[Integral]\>"\+0\%\(2  \[Pi]\), \
\*"\"\<\!\(\(f'\)[z[\[Theta]]]\/f[z[\[Theta]]]\)z'[\[Theta]]\[DifferentialD]\
\[Theta] = \>\"", val];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Integral]\>"\+0\%\(2  \[Pi]\), \
\*"\"\<\!\(\(f'\)[z[\[Theta]]]\/f[z[\[Theta]]]\)z'[\[Theta]]\[DifferentialD]\
\[Theta] = \>\"", ComplexExpand[val]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dot = 
        Graphics[{Red, PointSize[0.03], 
            Point[{0, 0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(center = 
        Graphics[{Text[\*"\"\<\!\(z\_0\)\>\"", {0, 0 + 0.1}, {\(-1\), 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 2]}];\)\ \), "\n", 
    \(\(Show[center, contour, dot, 
        PlotRange \[Rule] {{\(-2.2\), 2.2}, {\(-2.2\), 2.2}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(Print[\*"\"\<\!\(\[ContourIntegral]\+C\) \>\"", \
\(f'\)[z[\[Theta]]]\/f[z[\[Theta]]], "\< \[DifferentialD]z = \>", 
      ComplexExpand[val]]\), "\[IndentingNewLine]", 
    \(\(Print["\<The contour is the circle C: |z| = 2,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<with positive orientation.\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The desired integral is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(1\/\(2  \[Pi]\[ImaginaryI]\)\) \
\!\(\[ContourIntegral]\+C\) \!\(\(f'\)[z[\[Theta]]]\/f[z[\[Theta]]]\) \
\[DifferentialD]z = \>\"", \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
          ComplexExpand[val], "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<which is the winding number for the curve C.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[{Re[f[z[\[Theta]]]], Im[f[z[\[Theta]]]]}, {\[Theta], 
          0, 2  \[Pi]}, PlotRange \[Rule] {{\(-4.5\), 6.5}, {\(-5.5\), 5.5}}, 
        PlotStyle \[Rule] Blue, 
        Ticks \[Rule] {Range[\(-5\), 5, 1], 
            Range[\(-4\), 6, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image curve f(C) of the circle C:|z| = 2\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<under the mapping  w = f[z] = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<winds around the origin in the w-plane N = 2 times.\>"]\), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tFinally, we note that if ",
  Cell[BoxData[
      \(g \((z)\) = f \((z)\) - a\)]],
  ", then ",
  Cell[BoxData[
      \(g' \((z)\) = f \((z)\)\)]],
  ", and thus we can generalize what we've just said to compute how many \
times the curve ",
  Cell[BoxData[
      \(f \((C)\)\)]],
  " winds around the point ",
  StyleBox["a",
    FontFamily->"Courier New"],
  ". Theorem 8.9 summarizes our discussion."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 8.9 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Winding Number",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/WindingNumberContour.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is meromorphic in the simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  If ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a simple closed, positively oriented contour in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " such that for  ",
  Cell[BoxData[
      \(z \[Element] C, f \((z)\) \[NotEqual] 0\)]],
  " and ",
  Cell[BoxData[
      \(f \((z)\) \[NotEqual] \[Infinity]\)]],
  ", then  \n\n\t\t\t",
  Cell[BoxData[
      \(W \((f \((C)\), 
            a)\)\ \  = \ \ \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \
\(\[Integral]\_C\ \(\(f' \((z)\)\)\/\(f \((z)\) - 
                    a\)\) \[DifferentialD]z\)\)]],
  ",  \n\nknown as the winding number of ",
  Cell[BoxData[
      \(f \((C)\)\)]],
  " about ",
  StyleBox["a",
    FontFamily->"Courier New"],
  ", counts the number of times the curve ",
  Cell[BoxData[
      \(f \((C)\)\)]],
  " winds around the point ",
  StyleBox["a",
    FontFamily->"Courier New"],
  ".  If ",
  Cell[BoxData[
      \(a = 0\)]],
  ", the integral counts the number of times the curve ",
  Cell[BoxData[
      \(f \((C)\)\)]],
  " winds around the origin."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 8.9 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark 8.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Letting ",
  Cell[BoxData[
      \(f \((z)\) = z\)],
    AspectRatioFixed->True],
  " in Theorem 8.9 gives \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(W \((C, a)\)\), "  ", "=", "  ", 
        RowBox[{\(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \(\[Integral]\_C\ \
\(1\/\(z - a\)\) \[DifferentialD]z\)\), "  ", "=", "  ", 
          RowBox[{"{", GridBox[{
                {\(\(1\)\(,\)\), 
                  RowBox[{
                    RowBox[{
                      StyleBox["if",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], " ", "a", " ", 
                      StyleBox["lies",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], 
                      StyleBox[" ",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], 
                      StyleBox["inside",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], " ", "C"}], 
                    StyleBox[" ",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox["   ",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox["or",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], " "}]},
                {\(\(0\)\(,\)\), 
                  RowBox[{
                    RowBox[{
                      StyleBox["if",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], " ", "a", " ", 
                      StyleBox["lies",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], 
                      StyleBox[" ",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], 
                      StyleBox["outside",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], " ", "C"}], 
                    StyleBox[" ",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], 
                    StyleBox["      ",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}]}]}
                }], 
            StyleBox["}",
              FontColor->GrayLevel[1]]}]}]}]],
    AspectRatioFixed->True],
  "  \n\nwhich counts the number of times the curve ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " winds around the point ",
  StyleBox["a",
    FontFamily->"Courier New"],
  ".  If ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is not a simple closed curve, but crosses itself perhaps several times, \
we can show (but omit the proof) that ",
  Cell[BoxData[
      \(W \((C, a)\)\)],
    AspectRatioFixed->True],
  " still gives the number of times the curve ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " winds around the point ",
  StyleBox["a",
    FontFamily->"Courier New"],
  ". Thus winding number is indeed an appropriate term."
}], "Text"],

Cell["\<\
\tWe close this section with a result that will help us gain information \
about the location of the zeros and poles of meromorphic functions.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 8.10 (Rouche's Theorem).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " are meromorphic functions defined in the simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", that ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a simply closed contour in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", and that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " have no zeros or poles for ",
  Cell[BoxData[
      \(z \[Element] C\)]],
  ".  If the strict inequality ",
  Cell[BoxData[
      \(\(\(|\)\(f \((z)\) + 
          g \((z)\)\)\(|\)\(\(<\)\(\(|\)\(f \((z)\)\)\(|\)\(+\(\(|\)\(g \((z)\
\)\)\(|\)\)\)\)\)\)\)]],
  "  holds for all ",
  Cell[BoxData[
      \(z \[Element] C\)]],
  " , then  ",
  Cell[BoxData[
      \(Z\_f - P\_f = Z\_g - P\_g\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Proof of Theorem 8.10",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[" is in the book.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Corollary 8.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " are analytic functions defined in the simply connected domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", that ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a simple closed contour in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", and that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " have no zeros for ",
  Cell[BoxData[
      \(z \[Element] C\)]],
  ".  If the strict inequality  ",
  Cell[BoxData[
      \(\(\(|\)\(f \((z)\) + 
          g \((z)\)\)\(|\)\(\(<\)\(\(|\)\(f \((z)\)\)\(|\)\(+\(\(|\)\(g \((z)\
\)\)\(|\)\)\)\)\)\)\)]],
  "  holds for all ",
  Cell[BoxData[
      \(z \[Element] C\)]],
  ", then ",
  Cell[BoxData[
      \(Z\_f = Z\_g\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Proof of Corollary 8.2",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[" is in the book.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark 8.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Theorem 8.10 is usually stated with the requirement that ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " satisfy the condition  ",
  Cell[BoxData[
      \(\(\(|\)\(f \((z)\) + 
          g \((z)\)\)\(|\)\(\(<\)\(\(|\)\(g \((z)\)\)\(|\)\)\)\)\)]],
  ",  for  ",
  Cell[BoxData[
      \(z \[Element] C\)]],
  ".  The improved theorem that we gave was discovered by Irving Glicksberg \
(see the American Mathematical Monthly, 83 (1976), pp. 186-187). The weaker \
version is adequate for most purposes, however, as the following examples \
illustrate."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 8.26.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that al four zeros of the polynomial  ",
  Cell[BoxData[
      \(g \((z)\) = z\^4 - 7  z - 1\)]],
  "  lie in the disk  ",
  Cell[BoxData[
      \(\(D\_2\) \((0)\) = {z : \(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(2\)\)\)}\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009N0000cR000`400?l0
0000o`00003oo`3ooooo0?ooof00oooo003o0?ooool0ooooH03oool00?l0
ooooo`3ooomP0?ooo`00o`3ooooo0?ooof00oooo003o0?ooool0ooooH03o
ool00?l0ooooo`3ooomP0?ooo`00o`3oooo/0?ooo`030000003oool0oooo
0700oooo003o0?oooc80oooo1000002f0?ooo`030000003oool0oooo0700
oooo003o0?oooc80oooo00<000000?ooo`3oool0/03oool4000000<0oooo
00<000000?ooo`3oool0L03oool00:@0oooo1000002:0?ooo`030000003o
ool0oooo0:l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1`0?ooo`00Y03oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo0:`0oooo4`000?mY0?ooo`00Y@3oool00`000000oooo0?ooo`290?oo
o`040000003oool0oooo00000:L0oooo1P000?l40?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01`3oool60000of<0oooo002V0?oo
o`030000003oool0oooo08T0oooo0P00002T0?ooo`@0003o203oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00d0oooo1@000?mN
0?ooo`00Y03oool010000000oooo0?ooo`00003o0?ooob`0oooo1@000?l=
0?ooo`800000103oool00`000000oooo0?ooo`0B0?ooo`@0003oFP3oool0
0:D0oooo0P0000230?ooo`P0000000<0oooo0000000000001P00002F0?oo
o`80003o603oool00`000000oooo0?ooo`0F0?ooo`80003oF03oool00?l0
oooocP3oool40000oaX0oooo00<000000?ooo`3oool0603oool40000oe@0
oooo002Q0?ooo`@0000000<0oooo0000000000000P00003o0?ooob80oooo
0P000?lN0?ooo`030000003oool0oooo01`0oooo0P000?mB0?ooo`00j@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08<0oooo1000
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0AP3o
ool20000ob00oooo00<000000?ooo`3oool07P3oool20000oe00oooo003Z
0?ooo`040000003oool0oooo000008H0oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`0000170?ooo`80003o8P3oool00`000000oooo
0?ooo`0P0?ooo`80003oCP3oool00>/0oooo00<000000?ooo`000000@03o
ool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000A@3o
ool20000ob@0oooo00<000000?ooo`3oool08P3oool20000od`0oooo003[
0?ooo`030000003oool0000003l0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`00000m0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`000000@`3oool20000obH0oooo00<000000?ooo`3oool0
903oool20000odX0oooo002S0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0?`3oool500000400oooo00<000000?ooo`3oool0103o
ool00`000000oooo0000000k0?ooo`040000003oool0oooo000000@0oooo
1@0000100?ooo`80003o:03oool00`000000oooo0?ooo`0V0?ooo`80003o
B03oool00:@0oooo00@000000?ooo`3oool00000R03oool00`000000oooo
0?ooo`030?ooo`030000003oool0000003`0oooo0P0000190?ooo`030000
o`3oool0oooo02P0oooo00<000000?ooo`3oool0:03oool20000odH0oooo
002U0?ooo`030000003oool0000008D0oooo00@000000?ooo`3oool00000
103oool5000008@0oooo0P000?l30?ooo`80o`009P3oool00`000000oooo
0?ooo`0Z0?ooo`030000o`3oool0oooo04<0oooo002U0?ooo`030000003o
ool0000008H0oooo0P00002<0?ooo`80003o103oool40?l002D0oooo00<0
00000?ooo`3oool0:`3oool20000od<0oooo002T0?ooo`D00000o`3ooolB
0?ooo`80003o1@3oool60?l002@0oooo00<000000?ooo`3oool0;@3oool2
0000od40oooo003o0?oookT0oooo0P000?l70?ooo`H0o`00903oool00`00
0000oooo0?ooo`0_0?ooo`80003o?`3oool00?l0oooo^03oool00`000?l0
oooo0?ooo`080?ooo`@0o`009@3oool00`000000oooo0?ooo`0a0?ooo`03
0000o`3oool0oooo03`0oooo001O0?ooool000007@00000l0?ooo`030000
o`3oool0oooo00T0oooo0P3o00080?ooo`D000006@3oool00`000000oooo
0?ooo`0b0?ooo`030000o`3oool0oooo03/0oooo001O0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0>03o
ool20000oaP0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0c0?ooo`030000o`3oool0oooo03X0oooo001O0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0=P3oool2
0000oa80oooo1@0000030?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0=03oool20000ocX0oooo001O0?ooo`030000003oool0oooo
0?l0ooooD@3oool00`000?l0oooo0?ooo`0C0?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0f
0?ooo`030000o`3oool0oooo03L0oooo001O0?ooo`030000003oool0oooo
0?l0ooooD03oool00`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0g0?oo
o`030000o`3oool0oooo03H0oooo001O0?ooo`030000003oool0oooo0?l0
ooooC`3oool00`000?l0oooo0?ooo`0G0?ooo`040000003oool0oooo0?oo
o`8000006`3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo
03D0oooo001O0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000?l0
oooo0?ooo`0F0?ooo`040000003oool0oooo000001l0oooo00<000000?oo
o`3oool0>@3oool00`000?l0oooo0?ooo`0d0?ooo`00G`3oool00`000000
oooo0?ooo`3o0?ooodd0oooo00<0003o0?ooo`3oool05`3oool5000001h0
oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0c0?ooo`00
G`3oool00`000000oooo0?ooo`3o0?oood`0oooo00<0003o0?ooo`3oool0
>`3oool00`000000oooo0?ooo`0k0?ooo`030000o`3oool0oooo0380oooo
001O0?ooo`030000003oool0oooo0?l0ooooB`3oool00`000?l0oooo0?oo
o`0l0?ooo`030000003oool0oooo03`0oooo00<0003o0?ooo`3oool0<@3o
ool005l0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`030000o`3oool0
oooo03d0oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0`
0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<0003o0?oo
o`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo
02l0oooo001O0?ooo`030000003oool0oooo0?l0ooooB03oool00`000?l0
oooo0?ooo`0o0?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3o
ool0;P3oool005l0oooo00<000000?ooo`3oool0o`3ooom70?ooo`030000
o`3oool0oooo0400oooo00<000000?ooo`3oool0@03oool00`000?l0oooo
0?ooo`0]0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooodH0oooo00<0
003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`030000o`3o
ool0oooo02d0oooo001O0?ooo`030000003oool0oooo0?l0ooooAP3oool0
0`000?l0oooo0?ooo`110?ooo`030000003oool0oooo0440oooo00<0003o
0?ooo`3oool0;03oool005l0oooo00<000000?ooo`3oool0o`3ooom50?oo
o`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0@P3oool00`00
0?l0oooo0?ooo`0[0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oood@0
oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`130?ooo`03
0000o`3oool0oooo02X0oooo001O0?ooo`030000003oool0oooo0?l0oooo
@`3oool00`000?l0oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo
00<0003o0?ooo`3oool0:@3oool005l0oooo00<000000?ooo`3oool0o`3o
oom20?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool0A03o
ool00`000?l0oooo0?ooo`0Y0?ooo`00G`3oool00`000000oooo0?ooo`3o
0?oood80oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`15
0?ooo`030000o`3oool0oooo02P0oooo001O0?ooo`030000003oool0oooo
0?l0oooo@@3oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo
04D0oooo00<0003o0?ooo`3oool0:03oool005l0oooo00<000000?ooo`3o
ool0o`3ooom10?ooo`030000o`3oool0oooo04H0oooo00<000000?ooo`3o
ool0AP3oool00`000?l0oooo0?ooo`0W0?ooo`00G`3oool00`000000oooo
0?ooo`3o0?oood00oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo
0?ooo`160?ooo`030000o`3oool0oooo02L0oooo001O0?ooo`030000003o
ool0oooo0?l0oooo@03oool00`000?l0oooo0?ooo`100?ooo`D000000P3o
ool00`000000oooo0?ooo`170?ooo`030000o`3oool0oooo02H0oooo001O
0?ooo`030000003oool0oooo0?l0oooo?`3oool00`000?l0oooo0?ooo`13
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A`3oool0
0`000?l0oooo0?ooo`0V0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oo
och0oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`020?oo
o`800000B@3oool00`000?l0oooo0?ooo`0U0?ooo`00G`3oool00`000000
oooo0?ooo`3o0?oooch0oooo00<0003o0?ooo`3oool0?03oool4000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`190?ooo`03
0000o`3oool0oooo02@0oooo001O0?ooo`030000003oool0oooo0?l0oooo
?@3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`0T0?ooo`00G`3o
ool00`000000oooo0?ooo`3o0?ooocd0oooo00<0003o0?ooo`3oool0A03o
ool2000000@0oooo00<000000?ooo`3oool0BP3oool00`000?l0oooo0?oo
o`0S0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oooc`0oooo00<0003o
0?ooo`3oool0B`3oool00`000000oooo0?ooo`1:0?ooo`030000o`3oool0
oooo02<0oooo001O0?ooo`030000003oool0oooo0?l0oooo?03oool00`00
0?l0oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<0003o0?oo
o`3oool08P3oool005l0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`03
0000o`3oool0oooo04`0oooo00<000000?ooo`3oool0B`3oool00`000?l0
oooo0?ooo`0R0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oooc/0oooo
00<0003o0?ooo`3oool0C03oool00`000000oooo0?ooo`1<0?ooo`030000
o`3oool0oooo0240oooo001O0?ooo`030000003oool0oooo0?l0oooo>P3o
ool00`000?l0oooo0?ooo`1=0?ooo`030000003oool0oooo04`0oooo00<0
003o0?ooo`3oool08@3oool005l0oooo00<000000?ooo`3oool0o`3ooolj
0?ooo`030000o`3oool0oooo04d0oooo00<000000?ooo`3oool0C@3oool0
0`000?l0oooo0?ooo`0P0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oo
ocT0oooo00<0003o0?ooo`3oool0CP3oool00`000000oooo0?ooo`1=0?oo
o`030000o`3oool0oooo0200oooo001O0?ooo`030000003oool0oooo0?l0
oooo>@3oool00`000?l0oooo0?ooo`1>0?ooo`030000003oool0oooo04h0
oooo00<0003o0?ooo`3oool07`3oool005l0oooo00<000000?ooo`3oool0
o`3ooolh0?ooo`030000o`3oool0oooo04l0oooo00<000000?ooo`3oool0
CP3oool00`000?l0oooo0?ooo`0O0?ooo`00G`3oool00`000000oooo0?oo
o`3o0?ooocP0oooo00<0003o0?ooo`3oool0C`3oool00`000000oooo0?oo
o`1?0?ooo`030000o`3oool0oooo01h0oooo001O0?ooo`030000003oool0
oooo0?l0oooo>03oool00`000?l0oooo0?ooo`1?0?ooo`030000003oool0
oooo04l0oooo00<0003o0?ooo`3oool07P3oool005T0oooo0`0000030?oo
o`030000003oool0oooo0?l0oooo>03oool00`000?l0oooo0?ooo`1?0?oo
o`030000003oool0oooo0500oooo00<0003o0?ooo`3oool07@3oool005X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooocL0
oooo00<0003o0?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`03
0000o`3oool0oooo01d0oooo001G0?ooo`D000000`3oool300000?l0oooo
=`3oool00`000?l0oooo0?ooo`1@0?ooo`030000003oool0oooo0500oooo
00<0003o0?ooo`3oool07@3oool005L0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`3o0?ooocH0oooo00<0003o0?ooo`3oool0
D@3oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo01d0oooo
001H0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0o`3o
oolf0?ooo`030000o`3oool0oooo0540oooo00<000000?ooo`3oool0D@3o
ool00`000?l0oooo0?ooo`0L0?ooo`00F@3oool2000000@0oooo00<00000
0?ooo`3oool0o`3ooolf0?ooo`030000o`3oool0oooo0540oooo00<00000
0?ooo`3oool0D@3oool00`000?l0oooo0?ooo`0L0?ooo`00G`3oool00`00
0000oooo0?ooo`3o0?ooocH0oooo00<0003o0?ooo`3oool0D@3oool00`00
0000oooo0?ooo`1A0?ooo`030000o`3oool0oooo01`0oooo001O0?ooo`03
0000003oool0oooo0?l0oooo=P3oool00`000?l0oooo0?ooo`1A0?ooo`03
0000003oool0oooo0540oooo00<0003o0?ooo`3oool0703oool005l0oooo
00<000000?ooo`3oool0o`3ooole0?ooo`030000o`3oool0oooo0580oooo
00<000000?ooo`3oool0D@3oool00`000?l0oooo0?ooo`0L0?ooo`00G`3o
ool00`000000oooo0?ooo`3o0?ooocD0oooo00<0003o0?ooo`3oool0DP3o
ool00`000000oooo0?ooo`1B0?ooo`030000o`3oool0oooo01/0oooo001O
0?ooo`030000003oool0oooo0?l0oooo=@3oool00`000?l0oooo0?ooo`1B
0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool06`3oool0
05l0oooo00<000000?ooo`3oool0o`3ooole0?ooo`030000o`3oool0oooo
0580oooo00<000000?ooo`3oool0DP3oool00`000?l0oooo0?ooo`0K0?oo
o`00G`3oool00`000000oooo0?ooo`3o0?oooc@0oooo00<0003o0?ooo`3o
ool0D`3oool00`000000oooo0?ooo`1B0?ooo`030000o`3oool0oooo01/0
oooo001O0?ooo`030000003oool0oooo0?l0oooo=03oool00`000?l0oooo
0?ooo`1C0?ooo`030000003oool0oooo05<0oooo00<0003o0?ooo`3oool0
6P3oool005l0oooo00<000000?ooo`3oool0o`3ooold0?ooo`030000o`3o
ool0oooo05<0oooo00<000000?ooo`3oool0D`3oool00`000?l0oooo0?oo
o`0J0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oooc@0oooo00<0003o
0?ooo`3oool0D`3oool00`000000oooo0?ooo`1C0?ooo`030000o`3oool0
oooo01X0oooo001O0?ooo`030000003oool0oooo0?l0oooo=03oool00`00
0?l0oooo0?ooo`1C0?ooo`030000003oool0oooo05<0oooo00<0003o0?oo
o`3oool06P3oool005l0oooo00<000000?ooo`3oool0o`3ooold0?ooo`03
0000o`3oool0oooo05<0oooo00<000000?ooo`3oool0D`3oool00`000?l0
oooo0?ooo`0J0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oooc<0oooo
00<0003o0000000000000P00000X0?ooo`D000009@3oool00`000000oooo
0?ooo`0W0?ooo`D000009P3oool010000000003o00000000000J0?ooo`00
G`3oool00`000000oooo0?ooo`3o0?oooc<0oooo00<0003o0000003oool0
;03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0000o`0K0?ooo`00G`3o
ool00`000000oooo0?ooo`3o0?oooc<0oooo00<0003o0?ooo`000000;03o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool09`3oool00`000000003o0?ooo`0J0?ooo`00G`3oool0
0`000000oooo0?ooo`3o0?ooobh0oooo100000001@3oool0003o0?ooo`3o
ool0000002<0oooo100000040?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000o`3o
ool0oooo01T0oooo001O0?ooo`030000003oool0oooo0?l0oooo<`3oool0
1@000?l000000?ooo`3oool0000002X0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02H0oooo00@0
00000?ooo`000?l000006P3oool005l0oooo00<000000?ooo`3oool0o`3o
oolc0?ooo`040000o`3oool00000000002X0oooo0P00000W0?ooo`030000
003oool0oooo02P0oooo0P00000Y0?ooo`03000000000?l0oooo01X0oooo
001O0?ooo`030000003oool0oooo0?l0oooo<`3oool00`000?l0oooo0?oo
o`1D0?ooo`030000003oool0oooo05@0oooo00<0003o0?ooo`3oool06@3o
ool005l0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`030000o`3oool0
oooo05@0oooo00<000000?ooo`3oool0E03oool00`000?l0oooo0?ooo`0I
0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oooc<0oooo00<0003o0?oo
o`3oool0C@3oool20?l000D0oooo00<000000?ooo`3oool0DP3oool20?l0
00030000o`3oool0oooo00P0oooo0P0000000`3oool000000000000<0?oo
o`00G`3oool00`000000oooo0?ooo`3o0?oooc<0oooo00<0003o0?ooo`3o
ool0C03oool40?l000@0oooo00<000000?ooo`3oool0D@3oool30?l00003
0000o`3oool0oooo00T0oooo00<000000?ooo`0000003@3oool005l0oooo
00<000000?ooo`3oool0o`3oool_0?ooo`@0000000<0003o000000000000
B`0000060?l005H00000103o00000`000?l0o`0000000002000000P0oooo
00<000000?ooo`3oool0303oool005l0oooo00<000000?ooo`3oool0o`3o
oolc0?ooo`030000o`3oool0oooo02T0oooo00<000000?ooo`3oool07`3o
ool60?l000<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0T0?ooo`@0o`0000<0003o0?l0003oool0203oool2000000030?ooo`00
0000000000`0oooo001O0?ooo`030000003oool0oooo0?l0oooo<`3oool0
0`000?l0oooo0?ooo`1<0?ooo`@0o`00103oool00`000000oooo0?ooo`1A
0?ooo`<0o`0000<0003o0?ooo`3oool06@3oool005l0oooo00<000000?oo
o`3oool0o`3ooolc0?ooo`030000o`3oool0oooo04L0oooo0P0000040?oo
o`80o`001@3oool00`000000oooo0?ooo`1;0?ooo`<00000103oool20?l0
00030000o`3oool0oooo01T0oooo001O0?ooo`030000003oool0oooo0?l0
oooo<`3oool00`000?l0oooo0?ooo`190?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`050?ooo`03
0000o`3oool0oooo01T0oooo001O0?ooo`030000003oool0oooo0?l0oooo
<`3oool00`000?l0oooo0?ooo`100?ooo`D000000`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo04<0oooo1@0000020?ooo`@00000
1P3oool00`000?l0oooo0?ooo`0I0?ooo`00G`3oool00`000000oooo0?oo
o`3o0?oooc<0oooo00<0003o0?ooo`3oool0@@3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
A03oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000L0
oooo00<0003o0?ooo`3oool06@3oool005l0oooo00<000000?ooo`3oool0
o`3ooolc0?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0000000:0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool00`3oool2000000L0oooo00<0003o0?ooo`3oool0
6@3oool005l0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`030000o`3o
ool0oooo04<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo01T0oooo001O
0?ooo`030000003oool0oooo0?l0oooo<`3oool00`000?l0oooo0?ooo`11
0?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool0A03o
ool010000000oooo0?ooo`00000<0?ooo`030000o`3oool0oooo01T0oooo
001O0?ooo`030000003oool0oooo0?l0oooo<`3oool00`000?l0oooo0?oo
o`110?ooo`D000003P3oool00`000000oooo0?ooo`140?ooo`D000002P3o
ool00`000?l0oooo0?ooo`0J0?ooo`00G`3oool00`000000oooo0?ooo`3o
0?oooc@0oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`1C
0?ooo`030000o`3oool0oooo01X0oooo001O0?ooo`030000003oool0oooo
0?l0oooo=03oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo
05<0oooo00<0003o0?ooo`3oool06P3oool005l0oooo00<000000?ooo`3o
ool0o`3ooold0?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3o
ool0D`3oool00`000?l0oooo0?ooo`0J0?ooo`00G`3oool00`000000oooo
0?ooo`3o0?oooc@0oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo
0?ooo`1C0?ooo`030000o`3oool0oooo01X0oooo001O0?ooo`030000003o
ool0oooo0?l0oooo=03oool00`000?l0oooo0?ooo`1C0?ooo`030000003o
ool0oooo05<0oooo00<0003o0?ooo`3oool06P3oool005P0oooo0P000005
0?ooo`030000003oool0oooo0?l0oooo=03oool00`000?l0oooo0?ooo`1C
0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool06`3oool0
05L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o
0?ooocD0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`1B
0?ooo`030000o`3oool0oooo01/0oooo001G0?ooo`040000003oool0oooo
000000@0oooo0`00003o0?ooocD0oooo00<0003o0?ooo`3oool0DP3oool0
0`000000oooo0?ooo`1B0?ooo`030000o`3oool0oooo01/0oooo001H0?oo
o`8000001@3oool00`000000oooo0?ooo`3o0?ooocD0oooo00<0003o0?oo
o`3oool0DP3oool00`000000oooo0?ooo`1B0?ooo`030000o`3oool0oooo
01/0oooo001G0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0o`3ooole0?ooo`030000o`3oool0oooo0580oooo00<000000?oo
o`3oool0D@3oool00`000?l0oooo0?ooo`0L0?ooo`00F03oool2000000D0
oooo00<000000?ooo`3oool0o`3ooolf0?ooo`030000o`3oool0oooo0540
oooo00<000000?ooo`3oool0D@3oool00`000?l0oooo0?ooo`0L0?ooo`00
G`3oool00`000000oooo0?ooo`3o0?ooocH0oooo00<0003o0?ooo`3oool0
D@3oool00`000000oooo0?ooo`1A0?ooo`030000o`3oool0oooo01`0oooo
001O0?ooo`030000003oool0oooo0?l0oooo=P3oool00`000?l0oooo0?oo
o`1A0?ooo`030000003oool0oooo0540oooo00<0003o0?ooo`3oool0703o
ool005l0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`030000o`3oool0
oooo0540oooo00<000000?ooo`3oool0D@3oool00`000?l0oooo0?ooo`0L
0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooocH0oooo00<0003o0?oo
o`3oool0D@3oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo
01d0oooo001O0?ooo`030000003oool0oooo0?l0oooo=`3oool00`000?l0
oooo0?ooo`1@0?ooo`030000003oool0oooo0500oooo00<0003o0?ooo`3o
ool07@3oool005l0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`030000
o`3oool0oooo0500oooo00<000000?ooo`3oool0D03oool00`000?l0oooo
0?ooo`0M0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooocP0oooo00<0
003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`1@0?ooo`030000o`3o
ool0oooo01d0oooo001O0?ooo`030000003oool0oooo0?l0oooo>03oool0
0`000?l0oooo0?ooo`1?0?ooo`030000003oool0oooo04l0oooo00<0003o
0?ooo`3oool07P3oool005l0oooo00<000000?ooo`3oool0o`3ooolh0?oo
o`030000o`3oool0oooo04l0oooo00<000000?ooo`3oool0C`3oool00`00
0?l0oooo0?ooo`0N0?ooo`00G`3oool00`000000oooo0?ooo`3o0?ooocP0
oooo00<0003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`1>0?ooo`03
0000o`3oool0oooo01l0oooo001O0?ooo`030000003oool0oooo0?l0oooo
>@3oool00`000?l0oooo0?ooo`1>0?ooo`030000003oool0oooo04h0oooo
00<0003o0?ooo`3oool07`3oool005l0oooo00<000000?ooo`3oool0o`3o
ooli0?ooo`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool0C@3o
ool00`000?l0oooo0?ooo`0P0?ooo`00G`3oool00`000000oooo0?ooo`3o
0?ooocX0oooo00<0003o0?ooo`3oool0C@3oool00`000000oooo0?ooo`1=
0?ooo`030000o`3oool0oooo0200oooo001O0?ooo`030000003oool0oooo
0?l0oooo>P3oool00`000?l0oooo0?ooo`1=0?ooo`030000003oool0oooo
04`0oooo00<0003o0?ooo`3oool08@3oool005l0oooo00<000000?ooo`3o
ool0o`3ooolk0?ooo`030000o`3oool0oooo04`0oooo00<000000?ooo`3o
ool0C03oool00`000?l0oooo0?ooo`0Q0?ooo`00G`3oool00`000000oooo
0?ooo`3o0?oooc/0oooo00<0003o0?ooo`3oool0C03oool00`000000oooo
0?ooo`1;0?ooo`030000o`3oool0oooo0280oooo001O0?ooo`030000003o
ool0oooo0?l0oooo?03oool00`000?l0oooo0?ooo`1;0?ooo`030000003o
ool0oooo04/0oooo00<0003o0?ooo`3oool08P3oool005l0oooo00<00000
0?ooo`3oool0o`3oooll0?ooo`030000o`3oool0oooo04/0oooo00<00000
0?ooo`3oool0BP3oool00`000?l0oooo0?ooo`0S0?ooo`00G`3oool00`00
0000oooo0?ooo`3o0?ooocd0oooo00<0003o0?ooo`3oool0BP3oool00`00
0000oooo0?ooo`1:0?ooo`030000o`3oool0oooo02<0oooo001O0?ooo`03
0000003oool0oooo0?l0oooo?@3oool00`000?l0oooo0?ooo`1:0?ooo`03
0000003oool0oooo04T0oooo00<0003o0?ooo`3oool0903oool005l0oooo
00<000000?ooo`3oool0o`3oooln0?ooo`030000o`3oool0oooo0480oooo
1@0000020?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3oool0
903oool005l0oooo00<000000?ooo`3oool0o`3oooln0?ooo`030000o`3o
ool0oooo04@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`180?ooo`030000o`3oool0oooo02D0oooo001O0?ooo`030000003oool0
oooo0?l0oooo?`3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0
oooo0080oooo0P0000190?ooo`030000o`3oool0oooo02D0oooo001O0?oo
o`030000003oool0oooo0?l0oooo@03oool00`000?l0oooo0?ooo`120?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0A`3oool00`00
0?l0oooo0?ooo`0V0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oood00
oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo04H0oooo00<0003o0?ooo`3oool09`3oool005l0oooo
00<000000?ooo`3oool0o`3ooom10?ooo`030000o`3oool0oooo0400oooo
0P0000040?ooo`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool0
9`3oool005l0oooo00<000000?ooo`3oool0o`3ooom10?ooo`030000o`3o
ool0oooo04H0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?oo
o`0X0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oood80oooo00<0003o
0?ooo`3oool0A@3oool00`000000oooo0?ooo`150?ooo`030000o`3oool0
oooo02P0oooo001O0?ooo`030000003oool0oooo0?l0oooo@P3oool00`00
0?l0oooo0?ooo`150?ooo`030000003oool0oooo04@0oooo00<0003o0?oo
o`3oool0:@3oool005l0oooo00<000000?ooo`3oool0o`3ooom30?ooo`03
0000o`3oool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`000?l0
oooo0?ooo`0Y0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oood@0oooo
00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`130?ooo`030000
o`3oool0oooo02X0oooo001O0?ooo`030000003oool0oooo0?l0ooooA@3o
ool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo0480oooo00<0
003o0?ooo`3oool0:`3oool005l0oooo00<000000?ooo`3oool0o`3ooom6
0?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0@@3oool0
0`000?l0oooo0?ooo`0/0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oo
odH0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`100?oo
o`030000o`3oool0oooo02d0oooo001O0?ooo`030000003oool0oooo0?l0
ooooA`3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo0400
oooo00<0003o0?ooo`3oool0;@3oool005l0oooo00<000000?ooo`3oool0
o`3ooom80?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0
?`3oool00`000?l0oooo0?ooo`0^0?ooo`00G`3oool00`000000oooo0?oo
o`3o0?ooodT0oooo00<0003o0?ooo`3oool0?P3oool00`000000oooo0?oo
o`0n0?ooo`030000o`3oool0oooo02l0oooo001A0?ooo`D0000000<0oooo
0000000000000P0000040?ooo`030000003oool0oooo0?l0ooooBP3oool0
0`000?l0oooo0?ooo`0m0?ooo`030000003oool0oooo03d0oooo00<0003o
0?ooo`3oool0<03oool005<0oooo00D000000?ooo`3oool0oooo00000007
0?ooo`030000003oool0oooo0?l0ooooB`3oool00`000?l0oooo0?ooo`0l
0?ooo`030000003oool0oooo03`0oooo00<0003o0?ooo`3oool0<@3oool0
05<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`<00000o`3ooom<0?ooo`030000o`3oool0oooo03/0oooo00<000000?oo
o`3oool0>`3oool00`000?l0oooo0?ooo`0b0?ooo`00D`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0o`3ooom=0?ooo`030000o`3oool0oooo01d0oooo0`00000J0?ooo`03
0000003oool0oooo03X0oooo00<0003o0?ooo`3oool0<`3oool005<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000o`3oool0oooo01`0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0i0?ooo`03
0000o`3oool0oooo03@0oooo001B0?ooo`800000103oool2000000D0oooo
00<000000?ooo`3oool0o`3ooom?0?ooo`030000o`3oool0oooo01@0oooo
1@0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
>03oool00`000?l0oooo0?ooo`0e0?ooo`00G`3oool00`000000oooo0?oo
o`3o0?oooe00oooo00<0003o0?ooo`3oool0503oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
=`3oool00`000?l0oooo0?ooo`0f0?ooo`00G`3oool00`000000oooo0?oo
o`3o0?oooe40oooo00<0003o0?ooo`3oool0503oool00`000000oooo0?oo
o`020?ooo`030000003oool0000001X0oooo00<000000?ooo`3oool0=P3o
ool00`000?l0oooo0?ooo`0g0?ooo`00G`3oool00`000000oooo0?ooo`3o
0?oooe80oooo00<0003o0?ooo`3oool0503oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=@3oool0
0`000?l0oooo0?ooo`0h0?ooo`00G`3oool00`000000oooo0?ooo`3o0?oo
oe<0oooo0P000?lB0?ooo`040000003oool0oooo000001l0oooo00<00000
0?ooo`3oool0<`3oool20000oc/0oooo001O0?ooo`030000003oool0oooo
0?l0ooooE@3oool00`000?l0oooo0?ooo`0?0?ooo`D000007P3oool00`00
0000oooo0?ooo`0b0?ooo`030000o`3oool0oooo03/0oooo001O0?ooo`03
0000003oool0oooo0?l0ooooEP3oool00`000?l0oooo0?ooo`090?ooo`80
o`009P3oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo03`0
oooo001O0?ooo`030000003oool0oooo0?l0ooooE`3oool00`000?l0oooo
0?ooo`070?ooo`@0o`009@3oool00`000000oooo0?ooo`0`0?ooo`030000
o`3oool0oooo03d0oooo001O0?ooo`030000003oool0oooo07`0oooo7P00
0?nm0?ooo`80003o1P3oool60?l002@0oooo00<000000?ooo`3oool0;P3o
ool20000od00oooo001O0?ooo`030000003oool0oooo0740oooo2`000?lN
0?ooo`/0003o]03oool20000o`@0oooo1P3o000T0?ooo`030000003oool0
oooo02`0oooo0P000?m20?ooo`00G`3oool00`000000oooo0?ooo`1[0?oo
o`H0003o=03oool60000ok00oooo0P000?l30?ooo`@0o`009@3oool00`00
0000oooo0?ooo`0Z0?ooo`80003oA03oool005l0oooo00<000000?ooo`3o
ool0IP3oool50000od00oooo1P000?n/0?ooo`80003o0P3oool20?l002H0
oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`140?ooo`00
G`3oool00`000000oooo0?ooo`1P0?ooo`H0003oB`3oool60000ojP0oooo
00<0003o0?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`80003o
A`3oool005l0oooo00<000000?ooo`3oool0F`3oool50000oeL0oooo1@00
0?nT0?ooo`80003o9`3oool00`000000oooo0?ooo`0U0?ooo`80003oB@3o
ool005l0oooo00<000000?ooo`3oool0E`3oool40000of40oooo10000?nR
0?ooo`80003o9@3oool00`000000oooo0?ooo`0S0?ooo`80003oB`3oool0
05l0oooo00<000000?ooo`3oool0D`3oool40000ofT0oooo10000?nP0?oo
o`80003o8`3oool00`000000oooo0?ooo`0Q0?ooo`80003oC@3oool005l0
oooo00<000000?ooo`3oool0C`3oool40000og40oooo10000?nN0?ooo`80
003o8@3oool00`000000oooo0?ooo`0O0?ooo`80003oC`3oool005l0oooo
00<000000?ooo`3oool0B`3oool40000ogT0oooo10000?nL0?ooo`80003o
7`3oool00`000000oooo0?ooo`0M0?ooo`80003oD@3oool005l0oooo00<0
00000?ooo`3oool0A`3oool40000oh40oooo10000?nJ0?ooo`@0003o6`3o
ool00`000000oooo0?ooo`0I0?ooo`@0003oD`3oool005l0oooo00<00000
0?ooo`3oool0@`3oool40000ohT0oooo0`000?nK0?ooo`80003o6@3oool0
0`000000oooo0?ooo`0G0?ooo`80003oE`3oool005l0oooo00<000000?oo
o`3oool0?`3oool40000oi00oooo10000?nI0?ooo`D0003o503oool00`00
0000oooo0?ooo`0B0?ooo`D0003oF@3oool005l0oooo00<000000?ooo`3o
ool0>`3oool40000oiP0oooo10000?nJ0?ooo`@0003o2@3oool4000000<0
oooo00<000000?ooo`3oool03P3oool40000oeh0oooo001O0?ooo`030000
003oool0oooo03H0oooo1@000?nP0?ooo`D0003oV@3oool60000o`<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`H0003o
HP3oool005l0oooo00<000000?ooo`3oool0<03oool60000ojX0oooo1P00
0?nI0?oooaD0003oJ03oool005l0oooo00<000000?ooo`3oool0:P3oool6
0000okH0oooo1P000?nH0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0L03oool005l0oooo00<000000?ooo`3oool0903oool60000
ol80oooo1P000?n@0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0L03oool005l0oooo00<000000?ooo`3oool07`3oool50000
olh0oooo1@000?n<0?ooo`800000103oool00`000000oooo0?ooo`1`0?oo
o`00G`3oool00`000000oooo0?ooo`0I0?ooo`H0003of03oool70000oh/0
oooo00<000000?ooo`3oool0L03oool005l0oooo00<000000?ooo`3oool0
4`3oool60000onD0oooo1P000?oh0?ooo`00G`3ooooo003o01d00?l0h`3o
ool005l0oooo00<000000?ooo`3oool0o`3oooom0?ooo`00G`3oool00`00
0000oooo0?ooo`3o0?ooood0oooo001O0?ooo`030000003oool0oooo0?l0
ooooo@3oool005l0oooo00<000000?ooo`3oool0o`3oooom0?ooo`00G`3o
ool00`000000oooo0?ooo`3o0?ooood0oooo001O0?ooo`030000003oool0
oooo0?l0ooooR03oool2000007<0oooo001O0?ooo`030000003oool0oooo
0?l0ooooR@3oool00`000000oooo0?ooo`1a0?ooo`00G`3oool00`000000
oooo0?ooo`3o0?ooohX0oooo00<000000?ooo`3oool0L03oool00540oooo
1@000000103oool000000000000000050?ooo`030000003oool0oooo0?l0
ooooR@3oool00`000000oooo0000001a0?ooo`00D`3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`3o0?ooohP0oooo00@000000?ooo`3oool00000L@3oool005<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080ooooo`3o000M0?l006d0oooo0`0000000`3oool000000000001`0?oo
o`00D`3oool010000000oooo0?ooo`3oool3000000D0oooo00<000000?oo
o`3oool0o`3oooom0?ooo`00D`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oooom0?ooo`00
DP3oool2000000@0oooo0`0000040?ooo`030000003oool0oooo0?l0oooo
o@3oool00?l0ooooo`3ooomP0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{606, 206},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  Let  ",
  Cell[BoxData[
      \(f \((z)\) = \(-\ z\^4\)\)]],
  ".  Then  ",
  Cell[BoxData[
      \(f \((z)\) + g \((z)\) = \(-7\) z - 1\)]],
  ",  and at points on the circle  ",
  Cell[BoxData[
      \(\(C\_2\) \((0)\) = {z : \(\(|\)\(z\)\(|\)\) = \ 2}\)]],
  "  we have the relation  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(\(\(|\)\(f \((z)\) + 
                g \((z)\)\)\(|\)\)\ \  = \ \ \(\(|\)\(\(-7\) z\  - \ 
                1\)\(|\)\)\), " ", 
          StyleBox[",",
            FontColor->GrayLevel[1]], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          "                                  ", \(\(\[LessEqual]\)\(\ \ \
\)\(\(|\)\(\(-7\) z\)\(|\)\(\ \)\(+\ \(\(|\)\(-1\)\(|\)\)\)\)\), "  ", 
          StyleBox[",",
            FontColor->GrayLevel[1]], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          "                                  ", \(\(=\)\(\ \ \)\(7 | 
                z | \(+\ \ 1\)\ \  = \ \ 7\[Cross]2 + 1\)\)}], "  ", 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"                                  ", 
        RowBox[{\(\(=\)\(\ \ \)\(15\)\), "  ", 
          StyleBox[",",
            FontColor->GrayLevel[1]], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          "                                  ", \(\(\(<\)\(\ \ \)\(16\)\)\ \ \
\  = \ \ \(\(\(|\)\(\ \)\(z\^4\)\(|\)\)\ \  = \ \ \(\(|\)\(-\ 
                  z\^4\)\(|\)\)\)\), "  ", 
          StyleBox[",",
            FontColor->GrayLevel[1]], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          "                                  ", \(\(=\)\(\ \ \)\(\(|\)\(f \
\((z)\)\)\(|\)\)\), "  ", 
          StyleBox[",",
            FontColor->GrayLevel[1]]}]}]}]],
  "    \n\nOf course, if  ",
  Cell[BoxData[
      \(\(\(|\)\(f \((z)\) + 
          g \((z)\)\)\(|\)\(\ \)\(\(<\)\(\ \)\(\(|\)\(f \
\((z)\)\)\(|\)\)\)\)\)]],
  ",  then as we indicated in Remark 8.5 we certainly have  ",
  Cell[BoxData[
      \(\(\(|\)\(f \((z)\) + 
          g \((z)\)\)\(|\)\(\ \)\(\(<\)\(\ \)\(\(|\)\(f \
\((z)\)\)\(|\)\(+\(\(|\)\(g \((z)\)\)\(|\)\)\)\)\)\)\)]],
  ",  so that the conditions for applying Corollary 8.2 are satisfied on the \
circle ",
  Cell[BoxData[
      \(\(C\_2\) \((0)\)\)]],
  ".  The function ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has a zero of order 4 at the origin, so ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " must have four zeros inside ",
  Cell[BoxData[
      \(\(D\_2\) \((0)\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.26.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the functions  ",
  Cell[BoxData[
      \(f[z_] = \(z\^4\ \ and\ \ g[z] = z\^4 - 7  z - 1\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(Z = \(z = 0\); \ Remove[z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = z\^4;\)\ \), "\[IndentingNewLine]", 
    \(\(g[z_] = z\^4 - 7  z - 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[z] = \>", g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Show that at points on the circle ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = 2\)]],
  " we have the relation ",
  Cell[BoxData[
      \(\(\(|\)\(f \((z)\) - 
            g \((z)\)\)\(|\)\)\  = \(\(\(|\)\(7  z + 
              1\)\(|\)\(\ \)\(\(\[LessEqual]\)\(\(|\)\(7  z\)\(|\)\(+\ 
                  1\)\)\)\)\  = \(7 \((2)\) + 
              1 = \(15 < 16 = \(\(|\)\(f \((z)\)\)\(|\)\)\)\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{Abs[
            f[2  \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)] - 
              g[2  \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]], 
          Abs[f[2  \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]]}, \
{\[Theta], 0, 2  \[Pi]}, PlotRange \[Rule] {{0, 2  \[Pi]}, {0, 16.3}}, 
        PlotStyle \[Rule] {Blue, Red}, 
        Ticks \[Rule] {Range[0, 2  \[Pi], \[Pi]\/2], 
            Range[0, 16, 4]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The graphs of\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|f[2\!\(\[ExponentialE]\^\(\[ImaginaryI]\\\ \
\[Theta]\)\)]| = \>\"", 
        Abs[f[2  \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]], "\< = \>", 
        ComplexExpand[
          Abs[f[2  \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]], 
          TargetFunctions \[Rule] {Im, Re}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|f[2\!\(\[ExponentialE]\^\(\[ImaginaryI]\\\ \
\[Theta]\)\)]] - g[2\!\(\[ExponentialE]\^\(\[ImaginaryI]\\\ \[Theta]\)\)]| = \
\>\"", Abs[
          f[2  \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)] - 
            g[2  \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<for  0 \[LessEqual] \[Theta] \[LessEqual] 2\[Pi].\>"];\)\ \
\)}], "Input"],

Cell[TextData[{
  "The function  f(z)  has a zero of order  4  at the origin, and the \
hypothesis of Rouche's Theorem holds true for the circle ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = 2\)]],
  ".  Therefore,  g(z)  has four zeros inside ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = 2\)]],
  ".  \n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can verify this by using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find the zeros of  f(z)  and  g(z)."
}], "Text"],

Cell[BoxData[{
    \(\(solset1 = Solve[f[z] \[Equal] 0, z];\)\ \), "\n", 
    \(\(solset2 = NSolve[g[z] \[Equal] 0, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The zeros of f[z] = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The zeros of g[z] = \>", 
        g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Find out which zeros of g(z) lie inside the circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<The zeros of g[z] = \>", g[z]];\)\ \), "\n", 
    \(\(Z\_1\  = \ 
        ReplaceAll[z, 
          solset2\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]\
;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        ReplaceAll[z, 
          solset2\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)]\
;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2];\)\ \), "\n", 
    \(\(Z\_3\  = \ 
        ReplaceAll[z, 
          solset2\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)]\
;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3];\)\ \), "\n", 
    \(\(Z\_4\  = \ 
        ReplaceAll[z, 
          solset2\_\(\(\[LeftDoubleBracket]\)\(4\)\(\[RightDoubleBracket]\)\)]\
;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", 
        Z\_4];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_2], Im[Z\_2]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_3], Im[Z\_3]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_4], Im[Z\_4]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] + 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] - 0.1}, {\(-1\), 
                0}], Text[\*"\"\<\!\(z\_3\)\>\"", {Re[Z\_3], 
                Im[Z\_3] + 0.1}, {1, 0}], 
            Text[\*"\"\<\!\(z\_4\)\>\"", {Re[Z\_4], Im[Z\_4] + 0.1}, {1, 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 2]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-2.1\), 2.1}, {\(-2.1\), 2.1}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The zeros of g[z] = \>", 
        g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<, Is |\>", 
        Z\_1, "\<| < 2 ? \>", N[Abs[Z\_1]] < 2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<, Is |\>", 
        Z\_2, "\<| < 2 ? \>", N[Abs[Z\_2]] < 2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3, "\<, Is |\>", 
        Z\_3, "\<| < 2 ? \>", N[Abs[Z\_3]] < 2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", Z\_4, "\<, Is |\>", 
        Z\_4, "\<| < 2 ? \>", 
        N[Abs[Z\_4]] < 2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Therefore,  g(z)  has four zeros inside ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = 2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.27.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the polynomial  ",
  Cell[BoxData[
      \(g \((z)\) = z\^4 - 7  z - 1\)]],
  "  has one zero in the disk  ",
  Cell[BoxData[
      \(\(D\_1\) \((0)\) = {z : \(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\)\)\)}\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009N0000cR000`400?l0
0000o`00003oo`3ooooo0?ooof00oooo003o0?ooool0ooooH03oool00?l0
ooooo`3ooomP0?ooo`00o`3ooooo0?ooof00oooo003o0?ooool0ooooH03o
ool00?l0ooooo`3ooomP0?ooo`00o`3oooo/0?ooo`030000003oool0oooo
0700oooo003o0?ooobl0oooo1000002i0?ooo`030000003oool0oooo0700
oooo003o0?ooobl0oooo00<000000?ooo`3oool0/`3oool4000000<0oooo
00<000000?ooo`3oool0L03oool00:00oooo1000002;0?ooo`030000003o
ool0oooo0;80oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1`0?ooo`00X03oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0;80oooo00<000000?ooo`3oool00`3oool200000740oooo002Q0?oo
o`030000003oool0oooo08X0oooo00@000000?ooo`3oool00000[03oool4
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1`
0?ooo`00XP3oool00`000000oooo0?ooo`2:0?ooo`800000/`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0700oooo002P0?oo
o`040000003oool0oooo00000?l0oooo@P3oool2000000@0oooo00<00000
0?ooo`3oool0L03oool00:40oooo0P0000250?ooo`h0000000<0oooo0000
00000000/P3oool00`000000oooo0?ooo`1`0?ooo`00o`3oooo/0?ooo`03
0000003oool0oooo0700oooo002N0?ooo`P00000o`3ooom60?ooo`030000
003oool0oooo0700oooo003V0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0P`3oool4000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0700oooo003W
0?ooo`040000003oool0oooo000008H0oooo00<000000?ooo`3oool01P3o
ool010000000oooo0?ooo`00001]0?ooo`030000003oool0oooo0700oooo
003X0?ooo`030000003oool000000400oooo0P0000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`060?ooo`030000003oool0000006d0oooo00<000000?ooo`3oool0L03o
ool00>P0oooo00<000000?ooo`000000?`3oool010000000oooo0?ooo`00
00050?ooo`040000003oool0oooo000003`0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0000001]0?ooo`030000003oool0oooo0700oooo
002O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03o
ool500000400oooo00<000000?ooo`3oool01@3oool00`000000oooo0000
000j0?ooo`040000003oool0oooo000000D0oooo1@00001/0?ooo`030000
003oool0oooo0700oooo002P0?ooo`040000003oool0oooo000008T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0000000k0?ooo`800000
M`3oool00`000000oooo0?ooo`1`0?ooo`00X@3oool00`000000oooo0000
00260?ooo`040000003oool0oooo000000D0oooo1@00002;0?ooo`80o`00
9P3oool00`000000oooo0?ooo`1`0?ooo`00X@3oool00`000000oooo0000
00270?ooo`800000U@3oool40?l002D0oooo00<000000?ooo`3oool0L03o
ool00:00oooo1@00003o0?oooad0oooo1P3o000T0?ooo`030000003oool0
oooo0700oooo003o0?oool80oooo1P3o000T0?ooo`030000003oool0oooo
0700oooo003o0?oool<0oooo103o000U0?ooo`030000003oool0oooo0700
oooo003o0?oool@0oooo0P3o00080?ooo`D000006@3oool00`000000oooo
0?ooo`1`0?ooo`00F`3ooooo000001h00000E`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0700oooo001K0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0C@3oool5
000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1`
0?ooo`00F`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo04h0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0700oooo001K0?oo
o`030000003oool0oooo0?l0ooooK03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0L03oool005/0
oooo00<000000?ooo`3oool0o`3ooom]0?ooo`040000003oool0oooo0?oo
o`8000006`3oool00`000000oooo0?ooo`1`0?ooo`00F`3oool00`000000
oooo0?ooo`3o0?ooof/0oooo00@000000?ooo`3oool000007`3oool00`00
0000oooo0?ooo`1`0?ooo`00F`3oool00`000000oooo0?ooo`3o0?ooof/0
oooo1@00000N0?ooo`030000003oool0oooo0700oooo001K0?ooo`030000
003oool0oooo0?l0ooooSP3oool00`000000oooo0?ooo`1`0?ooo`00F`3o
ool00`000000oooo0?ooo`3o0?ooohh0oooo00<000000?ooo`3oool0L03o
ool005/0oooo00<000000?ooo`3oool0o`3ooon>0?ooo`030000003oool0
oooo0700oooo001K0?ooo`030000003oool0oooo0?l0ooooSP3oool00`00
0000oooo0?ooo`1`0?ooo`00F`3oool00`000000oooo0?ooo`3o0?ooohh0
oooo00<000000?ooo`3oool0L03oool005/0oooo00<000000?ooo`3oool0
o`3ooon>0?ooo`030000003oool0oooo0700oooo001K0?ooo`030000003o
ool0oooo0?l0ooooSP3oool00`000000oooo0?ooo`1`0?ooo`00F`3oool0
0`000000oooo0?ooo`3o0?ooohh0oooo00<000000?ooo`3oool0L03oool0
05/0oooo00<000000?ooo`3oool0o`3ooon>0?ooo`030000003oool0oooo
0700oooo001K0?ooo`030000003oool0oooo0?l0ooooSP3oool00`000000
oooo0?ooo`1`0?ooo`00F`3oool00`000000oooo0?ooo`3o0?ooohh0oooo
00<000000?ooo`3oool0L03oool005/0oooo00<000000?ooo`3oool0o`3o
oon>0?ooo`030000003oool0oooo0700oooo001C0?ooo`D000000`3oool0
0`000000oooo0?ooo`3o0?ooohh0oooo00<000000?ooo`3oool0L03oool0
05D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oo
ohh0oooo00<000000?ooo`3oool0L03oool005D0oooo00<000000?ooo`3o
ool00`3ooooo0?l001h0o`00L`3oool00`000000oooo0?ooo`1`0?ooo`00
E@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo
SP3oool00`000000oooo0?ooo`1`0?ooo`00E@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0?l0ooooQ`3oool500000080oooo00<0
00000?ooo`3oool0L03oool005@0oooo0P0000050?ooo`030000003oool0
oooo0?l0ooooR@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0700oooo001K0?ooo`030000003oool0oooo0?l0ooooQP3ooolA0000
ofX0oooo001K0?ooo`030000003oool0oooo0?l0ooooP@3oool00`000000
003o0000o`020000o`<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`@0003oIP3oool005/0oooo00<000000?ooo`3oool0
o`3ooon00?ooo`80003o1`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00X0oooo0P000?mT0?ooo`00F`3oool00`000000oooo0?oo
o`3o0?ooog`0oooo10000?l80?ooo`800000103oool00`000000oooo0?oo
o`0<0?ooo`@0003oH03oool005/0oooo00<000000?ooo`3oool0o`3ooomj
0?ooo`80003o4P3oool00`000000oooo0?ooo`0@0?ooo`80003oGP3oool0
05/0oooo00<000000?ooo`3oool0o`3ooomh0?ooo`80003o503oool00`00
0000oooo0?ooo`0B0?ooo`80003oG03oool005/0oooo00<000000?ooo`3o
ool0o`3ooomf0?ooo`80003o5P3oool00`000000oooo0?ooo`0D0?ooo`80
003oFP3oool005/0oooo00<000000?ooo`3oool0o`3ooome0?ooo`030000
o`3oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000?l0oooo
0?ooo`1H0?ooo`00F`3oool00`000000oooo0?ooo`3o0?ooogD0oooo00<0
003o0?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000o`3o
ool0oooo05L0oooo001K0?ooo`030000003oool0oooo0?l0ooooL`3oool2
0000oaT0oooo00<000000?ooo`3oool05`3oool20000oeL0oooo001K0?oo
o`030000003oool0oooo0?l0ooooL@3oool20000oa/0oooo00<000000?oo
o`3oool06@3oool20000oeD0oooo001K0?ooo`030000003oool0oooo0?l0
ooooL03oool00`000?l0oooo0?ooo`0K0?ooo`030000003oool0oooo01X0
oooo00<0003o0?ooo`3oool0D`3oool005/0oooo00<000000?ooo`3oool0
o`3ooom`0?ooo`030000o`3oool0oooo01/0oooo00<000000?ooo`3oool0
6`3oool00`000?l0oooo0?ooo`1B0?ooo`00F`3oool00`000000oooo0?oo
o`3o0?ooofh0oooo0P000?lN0?ooo`030000003oool0oooo01`0oooo0P00
0?mB0?ooo`00F`3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<0003o
0?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0
oooo0500oooo001C0?ooo`@00000103oool00`000000oooo0?ooo`3o0?oo
ofd0oooo00<0003o0?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?oo
o`030000o`3oool0oooo04l0oooo001C0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0o`3ooom/0?ooo`030000o`3oool0oooo01l0
oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`1>0?ooo`00
E03oool00`000000oooo0?ooo`040?ooo`<00000o`3ooom[0?ooo`030000
o`3oool0oooo0200oooo00<000000?ooo`3oool0803oool00`000?l0oooo
0?ooo`1=0?ooo`00E@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0?l0ooooJP3oool00`000?l0oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0200oooo00<0003o0?ooo`3oool0C@3oool005<0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooofT0oooo00<0
003o0?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3o
ool0oooo04`0oooo001D0?ooo`8000001@3oool00`000000oooo0?ooo`3o
0?ooofT0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?ooo`0R
0?ooo`030000o`3oool0oooo04/0oooo001K0?ooo`030000003oool0oooo
0?l0ooooJ03oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo
0280oooo00<0003o0?ooo`3oool0B`3oool005/0oooo00<000000?ooo`3o
ool0o`3ooomX0?ooo`030000o`3oool0oooo02<0oooo00<000000?ooo`3o
ool08`3oool00`000?l0oooo0?ooo`1:0?ooo`00F`3oool00`000000oooo
0?ooo`3o0?ooofL0oooo00<0003o0?ooo`3oool0903oool00`000000oooo
0?ooo`0S0?ooo`030000o`3oool0oooo04X0oooo001K0?ooo`030000003o
ool0oooo0?l0ooooI`3oool00`000?l0oooo0?ooo`0T0?ooo`030000003o
ool0oooo02@0oooo00<0003o0?ooo`3oool0B@3oool005/0oooo00<00000
0?ooo`3oool0o`3ooomV0?ooo`030000o`3oool0oooo02D0oooo00<00000
0?ooo`3oool0903oool00`000?l0oooo0?ooo`190?ooo`00F`3oool00`00
0000oooo0?ooo`3o0?ooofH0oooo00<0003o0?ooo`3oool09@3oool00`00
0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo04P0oooo001K0?ooo`03
0000003oool0oooo0?l0ooooI@3oool00`000?l0oooo0?ooo`0V0?ooo`03
0000003oool0oooo02D0oooo00<0003o0?ooo`3oool0B03oool005/0oooo
00<000000?ooo`3oool0o`3ooomU0?ooo`030000o`3oool0oooo02H0oooo
00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`170?ooo`00F`3o
ool00`000000oooo0?ooo`3o0?ooof@0oooo00<0003o0?ooo`3oool09`3o
ool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo04L0oooo001K
0?ooo`030000003oool0oooo0?l0ooooI03oool00`000?l0oooo0?ooo`0W
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0AP3oool0
05/0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`030000o`3oool0oooo
02L0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`160?oo
o`00F`3oool00`000000oooo0?ooo`3o0?ooof@0oooo00<0003o0?ooo`3o
ool09`3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo04H0
oooo001K0?ooo`030000003oool0oooo0?l0oooo>03oool4000002L0oooo
00<0003o0000000000000`00000U0?ooo`030000003oool0oooo02L0oooo
00<0003o0000000000000P00000V0?ooo`@000006P3oool005/0oooo00<0
00000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo02P0oooo00@0
003o0?ooo`3oool000009`3oool00`000000oooo0?ooo`0X0?ooo`030000
o`000000oooo02L0oooo00<000000?ooo`3oool06`3oool005/0oooo00<0
00000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo02L0oooo00@0
003o0?ooo`3oool000009`3oool00`000000oooo0?ooo`0X0?ooo`030000
o`000000oooo02P0oooo00<000000?ooo`3oool06P3oool005@0oooo0P00
00050?ooo`030000003oool0oooo0?l0oooo<P3oool4000000@0oooo00<0
00000?ooo`3oool08@3oool4000000050?ooo`000?l0oooo0?ooo`000000
9`3oool00`000000oooo0?ooo`0X0?ooo`030000o`000000oooo02T0oooo
00<000000?ooo`3oool06@3oool005<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`3o0?ooocP0oooo00@000000?ooo`3oool0
00009`3oool010000?l0oooo0?ooo`00000W0?ooo`030000003oool0oooo
02P0oooo00<0003o0000003oool09`3oool010000000oooo0?ooo`00000J
0?ooo`00E@3oool00`000000oooo0?ooo`030?ooo`<00000o`3oooli0?oo
o`800000:03oool010000?l0oooo00000000000W0?ooo`030000003oool0
oooo02P0oooo00<0003o0000003oool0:03oool2000001/0oooo001F0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooomS0?oo
o`030000o`3oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`00
0?l0oooo0?ooo`150?ooo`00D`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0?l0ooooH`3oool00`000?l0oooo0?ooo`0X0?oo
o`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0A@3oool005@0
oooo0P0000050?ooo`030000003oool0oooo0?l0ooooH`3oool00`000?l0
oooo0?ooo`0Q0?ooo`80o`001@3oool00`000000oooo0?ooo`0X0?ooo`03
0000o`3oool0oooo02L0oooo0P3o000;0?ooo`80000000<0oooo00000000
0000303oool005/0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`030000
o`3oool0oooo0200oooo103o00040?ooo`030000003oool0oooo02P0oooo
00<0003o0?ooo`3oool09P3oool40?l000/0oooo00<000000?ooo`000000
3@3oool005/0oooo00<000000?ooo`3oool0o`3ooolc0?oooc00000000<0
003o0000000000007`0000060?l002l0000000<0003o0000000000009000
00060?l000<00000203oool00`000000oooo0?ooo`0<0?ooo`00F`3oool0
0`000000oooo0?ooo`3o0?ooocL0oooo00<000000?ooo`3oool0:@3oool0
0`000?l0oooo0?ooo`0O0?ooo`H0o`000`3oool00`000000oooo0?ooo`0X
0?ooo`030000o`000000oooo02D0oooo1P3o00090?ooo`80000000<0oooo
000000000000303oool005/0oooo00<000000?ooo`3oool0o`3ooomS0?oo
o`030000o`3oool0oooo0200oooo103o00040?ooo`030000003oool0oooo
02P0oooo00<0003o0?ooo`3oool09P3oool40?l001/0oooo001K0?ooo`03
0000003oool0oooo0?l0ooooH`3oool00`000?l0oooo0?ooo`0K0?ooo`80
0000103oool20?l000D0oooo00<000000?ooo`3oool0:03oool00`000?l0
oooo0?ooo`0R0?ooo`<000000P3oool20?l001`0oooo001K0?ooo`030000
003oool0oooo0?l0ooooH`3oool00`000?l0oooo0?ooo`0M0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo
0?ooo`0S0?ooo`030000003oool0oooo01l0oooo001K0?ooo`030000003o
ool0oooo0?l0ooooH`3oool00`000?l0oooo0?ooo`0D0?ooo`D000000`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02P0oooo00<0
003o0?ooo`3oool06@3oool5000000<0oooo1000000P0?ooo`00F`3oool0
0`000000oooo0?ooo`3o0?ooof<0oooo00<0003o0?ooo`3oool05@3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0J0?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`0000008@3oool005/0oooo00<0
00000?ooo`3oool0o`3ooomS0?ooo`030000o`3oool0oooo01H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0000000:0?ooo`030000003o
ool0oooo02P0oooo00<0003o0?ooo`3oool06`3oool00`000000oooo0?oo
o`040?ooo`8000008@3oool005/0oooo00<000000?ooo`3oool0o`3ooomS
0?ooo`030000o`3oool0oooo01L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02P0oooo00<0003o
0?ooo`3oool0703oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01l0oooo001K0?ooo`030000003oool0oooo0?l0ooooH`3oool00`00
0?l0oooo0?ooo`0E0?ooo`040000003oool0oooo000000l0oooo00<00000
0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0J0?ooo`040000003oool0
oooo000002L0oooo001K0?ooo`030000003oool0oooo0?l0ooooH`3oool0
0`000?l0oooo0?ooo`0E0?ooo`D000003P3oool00`000000oooo0?ooo`0W
0?ooo`030000o`3oool0oooo01/0oooo1@00000V0?ooo`00F`3oool00`00
0000oooo0?ooo`3o0?ooof@0oooo00<0003o0?ooo`3oool09`3oool00`00
0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo04H0oooo001K0?ooo`03
0000003oool0oooo0?l0ooooI03oool00`000?l0oooo0?ooo`0W0?ooo`03
0000003oool0oooo02L0oooo00<0003o0?ooo`3oool0AP3oool005/0oooo
00<000000?ooo`3oool0o`3ooomT0?ooo`030000o`3oool0oooo02L0oooo
00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`160?ooo`00F`3o
ool00`000000oooo0?ooo`3o0?ooof@0oooo00<0003o0?ooo`3oool09`3o
ool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo04L0oooo001E
0?ooo`<000000`3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<0003o
0?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0
oooo04L0oooo001F0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0o`3ooomU0?ooo`030000o`3oool0oooo02H0oooo00<000000?oo
o`3oool09@3oool00`000?l0oooo0?ooo`180?ooo`00D`3oool5000000<0
oooo0`00003o0?ooofH0oooo00<0003o0?ooo`3oool09@3oool00`000000
oooo0?ooo`0U0?ooo`030000o`3oool0oooo04P0oooo001C0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3ooomV0?ooo`03
0000o`3oool0oooo02D0oooo00<000000?ooo`3oool0903oool00`000?l0
oooo0?ooo`190?ooo`00E03oool00`000000oooo000000040?ooo`030000
003oool0oooo0?l0ooooI`3oool00`000?l0oooo0?ooo`0T0?ooo`030000
003oool0oooo02@0oooo00<0003o0?ooo`3oool0B@3oool005D0oooo0P00
00040?ooo`030000003oool0oooo0?l0ooooI`3oool00`000?l0oooo0?oo
o`0T0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool0BP3o
ool005/0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`030000o`3oool0
oooo02<0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`1:
0?ooo`00F`3oool00`000000oooo0?ooo`3o0?ooofP0oooo00<0003o0?oo
o`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo
04/0oooo001K0?ooo`030000003oool0oooo0?l0ooooJ@3oool00`000?l0
oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3o
ool0B`3oool005/0oooo00<000000?ooo`3oool0o`3ooomY0?ooo`030000
o`3oool0oooo0280oooo00<000000?ooo`3oool08@3oool00`000?l0oooo
0?ooo`1<0?ooo`00F`3oool00`000000oooo0?ooo`3o0?ooofX0oooo00<0
003o0?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3o
ool0oooo04`0oooo001K0?ooo`030000003oool0oooo0?l0ooooJ`3oool0
0`000?l0oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<0003o
0?ooo`3oool0C@3oool005/0oooo00<000000?ooo`3oool0o`3ooom/0?oo
o`030000o`3oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`00
0?l0oooo0?ooo`1>0?ooo`00F`3oool00`000000oooo0?ooo`3o0?ooofd0
oooo00<0003o0?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`03
0000o`3oool0oooo04l0oooo001K0?ooo`030000003oool0oooo0?l0oooo
K@3oool00`000?l0oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo
00<0003o0?ooo`3oool0D03oool005/0oooo00<000000?ooo`3oool0o`3o
oom^0?ooo`030000o`3oool0oooo01d0oooo00<000000?ooo`3oool07@3o
ool00`000?l0oooo0?ooo`1@0?ooo`00F`3oool00`000000oooo0?ooo`3o
0?ooofl0oooo0P000?lM0?ooo`030000003oool0oooo01/0oooo0P000?mC
0?ooo`00F`3oool00`000000oooo0?ooo`3o0?ooog00oooo00<0003o0?oo
o`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo
05<0oooo001K0?ooo`030000003oool0oooo0?l0ooooL@3oool00`000?l0
oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<0003o0?ooo`3o
ool0D`3oool005/0oooo00<000000?ooo`3oool0o`3ooomb0?ooo`80003o
6P3oool00`000000oooo0?ooo`0H0?ooo`80003oEP3oool005/0oooo00<0
00000?ooo`3oool0o`3ooomd0?ooo`80003o603oool00`000000oooo0?oo
o`0F0?ooo`80003oF03oool005/0oooo00<000000?ooo`3oool0o`3ooome
0?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool05@3oool0
0`000?l0oooo0?ooo`1H0?ooo`00E03oool2000000D0oooo00<000000?oo
o`3oool0o`3ooomf0?ooo`030000o`3oool0oooo01D0oooo00<000000?oo
o`3oool05@3oool00`000?l0oooo0?ooo`1H0?ooo`00D`3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0ooooM`3oool20000
oaD0oooo00<000000?ooo`3oool04`3oool20000oe/0oooo001F0?ooo`03
0000003oool0oooo0080oooo0`00003o0?ooogT0oooo0P000?lC0?ooo`03
0000003oool0oooo0140oooo0P000?mM0?ooo`00E03oool2000000D0oooo
00<000000?ooo`3oool0o`3ooomk0?ooo`80003o4@3oool00`000000oooo
0?ooo`0?0?ooo`80003oG`3oool005@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`3o0?ooogd0oooo10000?l=0?ooo`030000003o
ool0oooo00/0oooo10000?mQ0?ooo`00E03oool3000000@0oooo00<00000
0?ooo`3oool0o`3ooon10?ooo`@0003o0P3oool500000080oooo00<00000
0?ooo`3oool01`3oool40000ofD0oooo001K0?ooo`030000003oool0oooo
0?l0ooooQ@3ooolC0000ofT0oooo001K0?ooo`030000003oool0oooo0?l0
ooooR@3oool00`000000oooo0?ooo`020?ooo`800000L@3oool005/0oooo
00<000000?ooo`3oool0o`3ooon90?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0L03oool005/0oooo00<000000?ooo`3oool0o`3o
oon90?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0L03o
ool005/0oooo00<000000?ooo`3oool0o`3ooon80?ooo`800000103oool0
0`000000oooo0?ooo`1`0?ooo`00F`3oool00`000000oooo0?ooo`3o0?oo
ohh0oooo00<000000?ooo`3oool0L03oool005/0oooo00<000000?ooo`3o
ool0o`3ooon>0?ooo`030000003oool0oooo0700oooo001K0?ooo`030000
003oool0oooo0?l0ooooSP3oool00`000000oooo0?ooo`1`0?ooo`00F`3o
ool00`000000oooo0?ooo`3o0?ooohh0oooo00<000000?ooo`3oool0L03o
ool005/0oooo00<000000?ooo`3oool0o`3ooon>0?ooo`030000003oool0
oooo0700oooo001K0?ooo`030000003oool0oooo0?l0ooooSP3oool00`00
0000oooo0?ooo`1`0?ooo`00F`3oool00`000000oooo0?ooo`3o0?ooohh0
oooo00<000000?ooo`3oool0L03oool005/0oooo00<000000?ooo`3oool0
o`3ooon>0?ooo`030000003oool0oooo0700oooo001K0?ooo`030000003o
ool0oooo0?l0ooooSP3oool00`000000oooo0?ooo`1`0?ooo`00F`3oool0
0`000000oooo0?ooo`3o0?ooohh0oooo00<000000?ooo`3oool0L03oool0
05<0oooo0`0000050?ooo`030000003oool0oooo0?l0ooooSP3oool00`00
0000oooo0?ooo`1`0?ooo`00D`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0?l0ooooSP3oool00`000000oooo0?ooo`1`0?oo
o`00D`3oool010000000oooo0?ooo`0000040?ooool00?l07P00o`1c0?oo
o`030000003oool0oooo0700oooo001C0?ooo`<000001@3oool00`000000
oooo0?ooo`1j0?ooo`P0003o503oool40000oo<0oooo00<000000?ooo`3o
ool0L03oool005@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1f0?ooo`@0003o803oool60000om00oooo0`00000J0?ooo`030000
003oool0oooo0700oooo001D0?ooo`<00000103oool00`000000oooo0?oo
o`1c0?ooo`<0003o:P3oool50000ol/0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`1`0?ooo`00F`3oool00`000000oooo0?ooo`1`
0?ooo`<0003o<P3oool30000ol40oooo1@0000030?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0L03oool005/0oooo00<000000?oo
o`3oool0K@3oool30000ocP0oooo0`000?no0?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1`
0?ooo`00F`3oool00`000000oooo0?ooo`1Z0?ooo`<0003o?P3oool30000
okd0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000J0?oo
o`030000003oool0oooo0700oooo001K0?ooo`030000003oool0oooo06L0
oooo0`000?m40?ooo`<0003o^`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0L03oool005/0oooo
00<000000?ooo`3oool0I03oool30000odX0oooo0P000?ng0?ooo`040000
003oool0oooo000001l0oooo00<000000?ooo`3oool0L03oool005/0oooo
00<000000?ooo`3oool0HP3oool20000odl0oooo0P000?ne0?ooo`D00000
7P3oool00`000000oooo0?ooo`1`0?ooo`00F`3oool00`000000oooo0?oo
o`1O0?ooo`<0003oD`3oool30000ojd0oooo0P3o000V0?ooo`030000003o
ool0oooo0700oooo001K0?ooo`030000003oool0oooo05d0oooo0P000?mI
0?ooo`80003oZP3oool40?l002D0oooo00<000000?ooo`3oool0L03oool0
05/0oooo00<000000?ooo`3oool0F`3oool20000oed0oooo0`000?nV0?oo
o`H0o`00903oool00`000000oooo0?ooo`1`0?ooo`00F`3oool00`000000
oooo0?ooo`1I0?ooo`80003oHP3oool20000oj@0oooo1P3o000T0?ooo`03
0000003oool0oooo0700oooo001K0?ooo`030000003oool0oooo05L0oooo
0P000?mV0?ooo`80003oX`3oool40?l002D0oooo00<000000?ooo`3oool0
L03oool005/0oooo00<000000?ooo`3oool0E@3oool20000ofX0oooo0`00
0?nQ0?ooo`80o`009P3oool00`000000oooo0?ooo`1`0?ooo`00F`3oool0
0`000000oooo0?ooo`1C0?ooo`80003oK`3oool20000olL0oooo00<00000
0?ooo`3oool0L03oool005/0oooo00<000000?ooo`3oool0D03oool30000
og<0oooo0P000?o50?ooo`030000003oool0oooo0700oooo001K0?ooo`03
0000003oool0oooo04h0oooo0P000?mh0?ooo`80003o``3oool00`000000
oooo0?ooo`1`0?ooo`00E@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo04/0oooo0`000?ml0?ooo`80003o`@3oool00`000000oooo
0?ooo`1`0?ooo`00E@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo04P0oooo0`000?n10?ooo`80003o_`3oool00`000000oooo0?oo
o`1`0?ooo`00E@3oool00`000000oooo0?ooo`030?ooo`<00000AP3oool2
0000ohH0oooo0P000?nm0?ooo`030000003oool0oooo0700oooo001F0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0A03oool20000
ohX0oooo0P000?nk0?ooo`030000003oool0oooo0700oooo001C0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0@P3oool20000
ohh0oooo0`000?nh0?ooo`030000003oool0oooo0700oooo001C0?ooo`@0
0000103oool00`000000oooo0?ooo`100?ooo`80003oT`3oool20000okH0
oooo00<000000?ooo`3oool0L03oool005/0oooo00<000000?ooo`3oool0
?P3oool20000oiL0oooo0P000?n]0?ooo`@000000`3oool00`000000oooo
0?ooo`1`0?ooo`00F`3oool00`000000oooo0?ooo`0l0?ooo`80003oV`3o
ool20000oj/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1`0?ooo`00F`3oool00`000000oooo0?ooo`0j0?ooo`80003oW`3oool2
0000ojX0oooo00<000000?ooo`3oool00`3oool200000740oooo001K0?oo
o`030000003oool0oooo03P0oooo0P000?nS0?ooo`<0003oZ03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0700oooo001K0?ooo`03
0000003oool0oooo03H0oooo0P000?nX0?ooo`80003oY03oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0700oooo001K0?ooo`03
0000003oool0oooo03<0oooo0`000?n/0?ooo`80003oX`3oool2000000@0
oooo00<000000?ooo`3oool0L03oool005/0oooo00<000000?ooo`3oool0
<03oool30000ok40oooo0`000?nV0?ooo`030000003oool0oooo0700oooo
001K0?ooo`030000003oool0oooo02h0oooo0P000?ng0?ooo`80003oo`3o
oolH0?ooo`00F`3oool00`000000oooo0?ooo`0[0?ooo`<0003o^`3oool3
0000ool0oooo5@3oool005/0oooo00<000000?ooo`3oool09`3oool40000
ol40oooo0`000?oo0?oooa80oooo001K0?ooo`030000003oool0oooo02<0
oooo10000?o80?ooo`<0003oo`3oool?0?ooo`00F`3oool00`000000oooo
0?ooo`0P0?ooo`<0003oc`3oool30000ool0oooo303oool005/0oooo00<0
00000?ooo`3oool07@3oool30000omD0oooo10000?oo0?ooo`P0oooo001K
0?ooo`030000003oool0oooo01X0oooo0`000?oL0?ooo`D0003oo`3oool3
0?ooo`00F`3oool00`000000oooo0?ooo`0G0?ooo`<0003oi03oool30000
ohX0oooo0P00001c0?ooo`00E03oool2000000D0oooo00<000000?ooo`3o
ool04`3oool40000onX0oooo10000?n70?ooo`030000003oool0oooo0740
oooo001C0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool02`3oool80000oo80oooo20000?n00?ooo`030000003oool0oooo0700
oooo001C0?ooo`040000003oool0oooo000000@0oooo3P000?oo0?ooo`<0
oooo3@000?mb0?ooo`030000003oool000000740oooo001D0?ooo`800000
1@3oool00`000000oooo0?ooo`3o0?oooh`0oooo00@000000?ooo`3oool0
0000L@3oool005<0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`3o0?oooh/0oooo0`0000000`3oool000000000001`0?ooo`00
E03oool2000000D0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo
001K0?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`00F`3oool0
0`000000oooo0?ooo`3o0?ooool0oooo0P3oool005/0oooo00<000000?oo
o`3oool0o`3ooooo0?ooo`80oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{606, 206},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  Let ",
  Cell[BoxData[
      \(f \((z)\) = 7  z + 1\)]],
  ",  then  ",
  Cell[BoxData[
      \(f \((z)\) + g \((z)\) = z\^4\)]],
  ".  At points on the circle  ",
  Cell[BoxData[
      \(\(C\_1\) \((0)\) = {z : \(\(|\)\(z\)\(|\)\) = \ 1}\)]],
  "  we have the relation  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(\(\(|\)\(f \((z)\) + 
              g \((z)\)\)\(|\)\)\ \  = \ \ \(\(\(|\)\(z\^4\)\(|\)\)\ \ \ \
\[IndentingNewLine]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \  = \ \ 1\)\), "  ", 
        StyleBox[",",
          FontColor->GrayLevel[1]], "\[IndentingNewLine]", " ", 
        "\[IndentingNewLine]", 
        "                                  ", \(\(<\)\(\ \ \)\(6\)\), "   ", 
        StyleBox[",",
          FontColor->GrayLevel[1]], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        "                                  ", \(\(=\)\(\ \ \)\(7\ \  - \ \ 1\ \
\  = \ \ \(\(|\)\(7  z\)\(|\)\(\ \)\(-\ \(\(|\)\(1\)\(|\)\)\)\)\)\), " ", 
        StyleBox[",",
          FontColor->GrayLevel[1]], " ", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        "                                  ", \(\(\[LessEqual]\)\(\ \ \)\(\(|\
\)\(7  z\  - \ 1\)\(|\)\)\), "  ", 
        StyleBox[",",
          FontColor->GrayLevel[1]], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        "                                  ", \(\(=\)\(\ \ \)\(\(|\)\(f \((z)\
\)\)\(|\)\)\), "  ", 
        StyleBox[",",
          FontColor->GrayLevel[1]]}]]],
  "  \n\nThe function ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " has one zero at the point ",
  Cell[BoxData[
      \(\(-\(1\/7\)\)\)]],
  " in the disk ",
  Cell[BoxData[
      \(\(D\_1\) \((0)\)\)]],
  ", and the hypotheses of Corollary 8.2 hold on the circle ",
  Cell[BoxData[
      \(\(C\_1\) \((0)\)\)]],
  ".  Therefore ",
  StyleBox["g(z)",
    FontFamily->"Courier New"],
  " has one zero inside ",
  Cell[BoxData[
      \(\(D\_1\) \((0)\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Explore ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Solution 8.27.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  "Enter the functions  ",
  Cell[BoxData[
      \(f[z_] = \(\(-7\) z - 1\ \ and\ \ g[z] = z\^4 - 7  z - 1\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(Z = \(z = 0\); \ Remove[z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = \(-7\) z - 1;\)\ \), "\[IndentingNewLine]", 
    \(\(g[z_] = z\^4 - 7  z - 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[z] = \>", g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Show that at points on the circle ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = 1\)]],
  " we have the relation ",
  Cell[BoxData[
      \(\(\(|\)\(f \((z)\) - 
            g \((z)\)\)\(|\)\)\  = \(\(\(|\)\(7  z + 
              1\)\(|\)\(\ \)\(\(\[LessEqual]\)\(\(|\)\(7  z\)\(|\)\(+\ 
                  1\)\)\)\)\  = \(7 \((2)\) + 
              1 = \(15 < 16 = \(\(|\)\(f \((z)\)\)\(|\)\)\)\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{Abs[
            f[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)] - 
              g[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]], 
          Abs[f[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]]}, {\[Theta], 
          0, 2  \[Pi]}, PlotRange \[Rule] {{0, 2  \[Pi]}, {0, 8.3}}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[0, 2  \[Pi], \[Pi]\/2], 
            Range[0, 16, 4]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The graphs of\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|f[\!\(\[ExponentialE]\^\(\[ImaginaryI]\\\ \
\[Theta]\)\)]| = \>\"", 
        Abs[f[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]], "\< = \>", 
        FullSimplify[
          ComplexExpand[Abs[f[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]], 
            TargetFunctions \[Rule] {Im, 
                Re}]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|f[\!\(\[ExponentialE]\^\(\[ImaginaryI]\\\ \[Theta]\)\)] \
- g[\!\(\[ExponentialE]\^\(\[ImaginaryI]\\\ \[Theta]\)\)]| = \>\"", 
        Abs[f[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)] - 
            g[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]], "\< = \>", 
        ComplexExpand[
          Abs[f[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)] - 
              g[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]], 
          TargetFunctions \[Rule] {Im, Re}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<for  0 \[LessEqual] \[Theta] \[LessEqual] 2\[Pi].\>"];\)\ \
\)}], "Input"],

Cell[TextData[{
  "The function  f(z)  has a zero at ",
  Cell[BoxData[
      \(z = \(-1\)\/7\)]],
  "  in the unit disk ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ",  and the hypothesis of Rouche's Theorem holds true for the circle ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = 1\)]],
  ".  Therefore,  g(z)  has one zero inside ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = 1\)]],
  ".  \n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can verify this by using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find the zeros of  f(z)  and  g(z)."
}], "Text"],

Cell[BoxData[{
    \(\(solset1 = Solve[f[z] \[Equal] 0, z];\)\ \), "\n", 
    \(\(solset2 = NSolve[g[z] \[Equal] 0, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The zeros of f[z] = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The zeros of g[z] = \>", 
        g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Find out which zeros of g(z) lie inside the circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<The zeros of g[z] = \>", g[z]];\)\ \), "\n", 
    \(\(Z\_1\  = \ 
        ReplaceAll[z, 
          solset2\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]\
;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1];\)\ \), "\n", 
    \(\(Z\_2\  = \ 
        ReplaceAll[z, 
          solset2\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)]\
;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2];\)\ \), "\n", 
    \(\(Z\_3\  = \ 
        ReplaceAll[z, 
          solset2\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)]\
;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3];\)\ \), "\n", 
    \(\(Z\_4\  = \ 
        ReplaceAll[z, 
          solset2\_\(\(\[LeftDoubleBracket]\)\(4\)\(\[RightDoubleBracket]\)\)]\
;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", 
        Z\_4];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{{Red, PointSize[0.03], Point[{Re[Z\_1], Im[Z\_1]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_2], Im[Z\_2]}]}, {Red, 
              PointSize[0.03], Point[{Re[Z\_3], Im[Z\_3]}]}, {Red, 
              PointSize[0.03], 
              Point[{Re[Z\_4], Im[Z\_4]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(centers = 
        Graphics[{Text[\*"\"\<\!\(z\_1\)\>\"", {Re[Z\_1], 
                Im[Z\_1] + 0.1}, {\(-1\), 0}], 
            Text[\*"\"\<\!\(z\_2\)\>\"", {Re[Z\_2], Im[Z\_2] - 0.1}, {\(-1\), 
                0}], Text[\*"\"\<\!\(z\_3\)\>\"", {Re[Z\_3], 
                Im[Z\_3] + 0.1}, {1, 0}], 
            Text[\*"\"\<\!\(z\_4\)\>\"", {Re[Z\_4], Im[Z\_4] + 0.1}, {1, 
                0}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(contour\  = \ Graphics[{Blue, Circle[{0, 0}, 1]}];\)\ \), "\n", 
    \(\(Show[dots, centers, contour, 
        PlotRange \[Rule] {{\(-2.1\), 2.1}, {\(-2.1\), 2.1}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The zeros of g[z] = \>", 
        g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", Z\_1, "\<, Is |\>", 
        Z\_1, "\<| < 1 ? \>", N[Abs[Z\_1]] < 1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", Z\_2, "\<, Is |\>", 
        Z\_2, "\<| < 1 ? \>", N[Abs[Z\_2]] < 1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", Z\_3, "\<, Is |\>", 
        Z\_3, "\<| < 1 ? \>", N[Abs[Z\_3]] < 1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(z\_4\) = \>\"", Z\_4, "\<, Is |\>", 
        Z\_4, "\<| < 1 ? \>", 
        N[Abs[Z\_4]] < 1];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Therefore,  g(z)  has one zero inside ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Argument Principle",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/ArgumentPrincipleBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Rouche's Theorem",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/RoucheTheoremBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{980, 632},
WindowMargins->{{6, Automatic}, {Automatic, 1}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[7471, 246, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[9202, 312, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[63025, 1423, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[72153, 1668, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[73973, 1741, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 147144, 3190}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 148, 3, 33, "Text"],
Cell[2253, 67, 210, 4, 52, "Text"],
Cell[2466, 73, 793, 25, 52, "Text"],
Cell[3262, 100, 796, 23, 152, "Text"],
Cell[4061, 125, 1166, 34, 114, "Text"],
Cell[5230, 161, 1807, 64, 136, "Text"],

Cell[CellGroupData[{
Cell[7062, 229, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[7210, 235, 258, 9, 33, "Text",
  Evaluatable->False],
Cell[7471, 246, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[7831, 258, 935, 33, 114, "Text"],

Cell[CellGroupData[{
Cell[8791, 295, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[8939, 301, 260, 9, 33, "Text",
  Evaluatable->False],
Cell[9202, 312, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[9562, 324, 2041, 63, 97, "Text"],
Cell[11606, 389, 2422, 72, 236, "Text"],
Cell[14031, 463, 867, 22, 84, "Text"],
Cell[14901, 487, 551, 22, 33, "Text"],
Cell[15455, 511, 552, 22, 33, "Text"],
Cell[16010, 535, 1691, 45, 221, "Text",
  Evaluatable->False],
Cell[17704, 582, 37140, 612, 220, 37026, 608, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[54847, 1196, 570, 20, 33, "Text"],

Cell[CellGroupData[{
Cell[55442, 1220, 196, 7, 33, "Text"],
Cell[55641, 1229, 522, 18, 60, "Text",
  Evaluatable->False],
Cell[56166, 1249, 4424, 82, 969, "Input"]
}, Closed]],
Cell[60605, 1334, 436, 15, 49, "Text"],
Cell[61044, 1351, 1631, 56, 155, "Text"],

Cell[CellGroupData[{
Cell[62700, 1411, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[62848, 1417, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[63025, 1423, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[63385, 1435, 7094, 165, 135, "Text"],
Cell[70482, 1602, 166, 3, 33, "Text"],
Cell[70651, 1607, 1067, 40, 52, "Text"],

Cell[CellGroupData[{
Cell[71743, 1651, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[71891, 1657, 259, 9, 33, "Text",
  Evaluatable->False],
Cell[72153, 1668, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[72513, 1680, 1024, 40, 49, "Text"],

Cell[CellGroupData[{
Cell[73562, 1724, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[73710, 1730, 260, 9, 33, "Text",
  Evaluatable->False],
Cell[73973, 1741, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[74333, 1753, 739, 21, 68, "Text"],
Cell[75075, 1776, 395, 13, 33, "Text",
  Evaluatable->False],
Cell[75473, 1791, 26973, 445, 220, 26859, 441, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[102449, 2238, 2578, 66, 316, "Text"],

Cell[CellGroupData[{
Cell[105052, 2308, 196, 7, 33, "Text"],
Cell[105251, 2317, 141, 5, 33, "Text"],
Cell[105395, 2324, 404, 7, 150, "Input"],
Cell[105802, 2333, 444, 12, 33, "Text"],
Cell[106249, 2347, 1409, 25, 188, "Input"],
Cell[107661, 2374, 538, 16, 71, "Text"],
Cell[108202, 2392, 513, 10, 170, "Input"],
Cell[108718, 2404, 198, 7, 33, "Text",
  Evaluatable->False],
Cell[108919, 2413, 2868, 56, 470, "Input"],
Cell[111790, 2471, 182, 7, 33, "Text",
  Evaluatable->False]
}, Closed]],
Cell[111987, 2481, 389, 13, 30, "Text",
  Evaluatable->False],
Cell[112379, 2496, 23313, 385, 220, 23199, 381, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[135695, 2883, 2027, 56, 300, "Text"],

Cell[CellGroupData[{
Cell[137747, 2943, 196, 7, 33, "Text"],
Cell[137946, 2952, 149, 5, 33, "Text"],
Cell[138098, 2959, 412, 7, 150, "Input"],
Cell[138513, 2968, 444, 12, 33, "Text"],
Cell[138960, 2982, 1629, 28, 188, "Input"],
Cell[140592, 3012, 655, 21, 93, "Text"],
Cell[141250, 3035, 513, 10, 170, "Input"],
Cell[141766, 3047, 198, 7, 33, "Text",
  Evaluatable->False],
Cell[141967, 3056, 2868, 56, 470, "Input"],
Cell[144838, 3114, 180, 7, 33, "Text",
  Evaluatable->False]
}, Closed]],
Cell[145033, 3124, 290, 7, 30, "Text"],
Cell[145326, 3133, 328, 11, 33, "Text"],
Cell[145657, 3146, 315, 10, 33, "Text"],
Cell[145975, 3158, 257, 5, 33, "Text"],
Cell[146235, 3165, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

