(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    219697,       5734]*)
(*NotebookOutlinePosition[    221331,       5788]*)
(*  CellTagsIndexPosition[    221254,       5782]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 9  z-transforms and applications",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Overview",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\n\n\tThe ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transform is useful for the manipulation of discrete data sequences and \
has acquired a new significance in the formulation and analysis of \
discrete-time systems.  It is used extensively today in the areas of applied \
mathematics, digital signal processing, control theory, population science, \
economics.  These discrete models are solved with difference equations in a \
manner that is analogous to solving continuous models with differential \
equations.  The role played by the z-transform in the solution of difference \
equations corresponds to that played by the Laplace transforms in the \
solution of differential equations. "
}], "Text"],

Cell[TextData[StyleBox["9.1  The  z-transform",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tThe function notation for sequences is used in the study and application \
of z-transforms.  Consider a function  ",
  Cell[BoxData[
      \(x[t]\)]],
  "  defined for  ",
  Cell[BoxData[
      \(t \[GreaterEqual] 0\)]],
  "  that is sampled at times  ",
  Cell[BoxData[
      RowBox[{\(t = T\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "T", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(2  T\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(3  T\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  ",  where  ",
  Cell[BoxData[
      \(T\)]],
  "  is the sampling period (or rate).   We can write the sample as a \
sequence using the notation  ",
  Cell[BoxData[
      \({x\_n = x[n\ T]}\_\(n = 0\)\%\[Infinity]\)]],
  ".  Without loss of generality we will set  ",
  Cell[BoxData[
      \(T = 1\)]],
  "  and consider real sequences such as,  ",
  Cell[BoxData[
      \({x\_n\  = \ x[n]}\_\(n = 0\)\%\[Infinity]\)]],
  ".  The definition of the z-transform involves an infinite series of the \
reciprocals  ",
  Cell[BoxData[
      \(z\^\(-n\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 9.1 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["z-transform",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Z-Transform.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[")",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Given the sequence  ",
  Cell[BoxData[
      \({x\_n\  = \ x[n]}\_\(n = 0\)\%\[Infinity]\)]],
  "  the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transform is defined as follows \n\n",
  StyleBox["(9-1)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(X \((z)\)\ \  = \ \ \(\[GothicCapitalZ][{x\_n}\_\(n = \
0\)\%\[Infinity]]\ \  = \ \ \(\[Sum]\+\(n = 0\)\%\[Infinity] x\_n\ z\^\(-n\)\ \
\  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\ x[n]\ z\^\(-n\)\)\)\)]],
  ",  \n\nwhich is a series involving powers of  ",
  Cell[BoxData[
      \(1\/z\)]],
  ".  \n\n",
  StyleBox["Remark 9.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transform is defined at points ",
  Cell[BoxData[
      \(z \[Element] \[DoubleStruckCapitalC]\)]],
  " where the Laurent series ",
  StyleBox["(9-1)",
    FontColor->RGBColor[0, 0, 1]],
  " converges.  The ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transform region of convergence (ROC) for the Laurent series is chosen to \
be \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(\[GreaterEqual]\)\(\ \)\(R\)\)\)\)]],
  ",    where    ",
  Cell[BoxData[
      \(R\ \  = \ \ lim\ sup\ \@\(\(|\)\(x\_n\)\(|\)\)\%n\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 9.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The sequence notation  ",
  Cell[BoxData[
      \({x\_n}\_\(n = 0\)\%\[Infinity]\)]],
  "  is used in mathematics to study difference equations and the function \
notation  ",
  Cell[BoxData[
      \({x[n]}\_\(n = 0\)\%\[Infinity]\)]],
  "  is used by engineers for signal processing.  It's a good idea to know \
both notations.  \n",
  StyleBox["Remark 9.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  In the applications, the sequence  ",
  Cell[BoxData[
      \({x\_n\  = \ x[n]}\_\(n = 0\)\%\[Infinity]\)]],
  "  will be used for inputs and the sequence  ",
  Cell[BoxData[
      \({y\_n\  = \ y[n]}\_\(n = 0\)\%\[Infinity]\)]],
  "  will be used for outputs.  We will also use the notations \n\n\t\t\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][
          x\_n]\ \  = \ \ \(\[GothicCapitalZ][
            x[n]]\ \  = \ \ X \((z)\)\)\)]],
  ",  and  \n\n\t\t\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][
          y\_n]\ \  = \ \ \(\[GothicCapitalZ][
            y[n]]\ \  = \ \ Y \((z)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 9.1 (Inverse z-transform)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   Let  ",
  Cell[BoxData[
      \(X \((z)\)\)],
    AspectRatioFixed->True],
  "  be the",
  " ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-",
  "transform of the sequence  ",
  Cell[BoxData[
      \({x\_n\  = \ x[n]}\_\(n = 0\)\%\[Infinity]\)]],
  "  defined in the region  ",
  Cell[BoxData[
      \(\(\(R\)\(<\)\) | z | \)]],
  ".  Then ",
  Cell[BoxData[
      \(x\_n\)]],
  " is given by the formula  \n\n",
  StyleBox["(9-2)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(x\_n\ \  = \ \ \(x[
            n]\ \  = \ \ \(\(\[GothicCapitalZ]\^\(-1\)\)[
              X \((z)\)]\ \  = \ \ \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \(\
\[ClockwiseContourIntegral]\+C\ \ X \((z)\) \(z\^\(n - 
                        1\)\) \[DifferentialD]z\)\)\)\)]],
  ",  \n\t\t\nwhere ",
  Cell[BoxData[
      \(C\)]],
  " is any positively oriented simple closed curve that lies in the region  \
",
  Cell[BoxData[
      \(\(\(R\)\(<\)\) | z | \)]],
  "  and winds around the origin.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 9.1 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["9.1.1  Admissible form of a z-transform",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tFormulas for  ",
  Cell[BoxData[
      \(X \((z)\)\)],
    AspectRatioFixed->True],
  " do not arise in a vacuum.  In an introductory course they are expressed \
as linear combinations of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transforms corresponding to elementary functions such as  \n\t\n\t\t\t",
  Cell[BoxData[
      RowBox[{"S", " ", "=", " ", 
        RowBox[{"{", 
          RowBox[{
            StyleBox[\(\[Delta][n]\),
              FontColor->GrayLevel[0]], 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}], 
          StyleBox["}",
            FontColor->GrayLevel[1]]}]}]]],
  Cell[BoxData[
      RowBox[{\(u[n]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  " ",
  Cell[BoxData[
      RowBox[{\(b\^n\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  " ",
  Cell[BoxData[
      RowBox[{\(\[ExponentialE]\^\(a\ n\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  " ",
  Cell[BoxData[
      RowBox[{"n", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  " ",
  Cell[BoxData[
      RowBox[{\(n\^2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  " ",
  Cell[BoxData[
      RowBox[{\(n\^m\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  " ",
  Cell[BoxData[
      RowBox[{\(n\ b\^n\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  " ",
  Cell[BoxData[
      RowBox[{\(n\ \[ExponentialE]\^\(a\ n\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  " ",
  Cell[BoxData[
      \(\(b\^n\) Sin[a\ n]\)]],
  Cell[BoxData[
      StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]]],
  " ",
  Cell[BoxData[
      RowBox[{\(\(b\^n\) Cos[a\ n]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  " ",
  Cell[BoxData[
      RowBox[{\(Sinh[a\ n]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  " ",
  Cell[BoxData[
      RowBox[{\(Cosh[a\ n]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  Cell[BoxData[
      RowBox[{
        StyleBox["{",
          FontColor->GrayLevel[1]], 
        StyleBox[\(\(etc\)\(.\)\),
          FontColor->GrayLevel[0]], 
        StyleBox[" ",
          FontColor->GrayLevel[0]], "}"}]]],
  ".   \n\nIn Table 9.1, we will see that the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transform of each function in  ",
  Cell[BoxData[
      \(S\)]],
  "  is a rational function of the complex variable  ",
  Cell[BoxData[
      \(z\)],
    AspectRatioFixed->True],
  ".  It can be shown that a linear combination of rational functions is a \
rational function.  Therefore, for the examples and applications considered \
in this book we can restrict the",
  " ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-",
  "transforms to be rational functions.  This restriction is emphasized this \
in the following definition."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 9.2 (Admissible z-transform)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Given the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transform  ",
  Cell[BoxData[
      \(X \((z)\) = \ \[Sum]\+\(n = 0\)\%\[Infinity]\ x[n]\ z\^\(-n\)\)]],
  "  we say that ",
  Cell[BoxData[
      \(X \((z)\)\)],
    AspectRatioFixed->True],
  " is an admissible ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transform, provided that it is a rational function, that is  \n\n",
  StyleBox["(9-3)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(X \((z)\)\  = \ \(\(P \((z)\)\)\/\(Q \((z)\)\) = \ \(\(b\_0 + \
\(b\_1\) z\^1 + \(b\_2\) z\^2 +  ... \) + \(b\_\(p - 1\)\) z\^\(p - 1\) + \(b\
\_p\) z\^p\)\/\(\(a\_0 + \(a\_1\) z\^1 + \(a\_2\) z\^2 +  ... \) + \(a\_\(q - \
1\)\) z\^\(q - 1\) + \(a\_q\) z\^q\)\)\)]],
  ", \n\nwhere ",
  Cell[BoxData[
      RowBox[{"P", \((z)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "Q", \((z)\)}]]],
  ", are polynomials of degree ",
  Cell[BoxData[
      RowBox[{"p", " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "q"}]]],
  ", respectively.  \n\n\tFrom our knowledge of rational functions, we see \
that an admissible ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transform is defined everywhere in the complex plane except at a finite \
number of isolated singularities that are poles and occur at the points where \
 ",
  Cell[BoxData[
      \(Q \((z)\) = 0\)],
    AspectRatioFixed->True],
  ".  The Laurent series expansion in  ",
  StyleBox["(9-1)",
    FontColor->RGBColor[0, 0, 1]],
  " can be obtained by a partial fraction manipulation and followed by \
geometric series expansions in powers of ",
  Cell[BoxData[
      \(1\/z\)]],
  ".  However, the signal feature of formula ",
  StyleBox["(9-3)",
    FontColor->RGBColor[0, 0, 1]],
  " is the calculation of the inverse ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transform via residues.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 9.2 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Cauchy's Residue Theorem",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ResidueTheorem.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[")",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  D  be a simply connected domain, and let  C  be a simple closed \
positively oriented contour that lies in  D.  If  f(z)  is analytic inside  C \
 and on  C,  except at the points  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_k\)}]]],
  "  that lie inside  C,  then  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) \(\[Integral]\_C\ 
            f \((z)\) \[DifferentialD]z\)\), "  ", "=", "  ", 
        RowBox[{\(\[Sum]\+\(j = 1\)\%k\), " ", 
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(z\_j\)}], "]"}]}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 9.2 is in the book (see Theorem \
8.1).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Corollary 9.1 (Inverse z-transform)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   Let  ",
  Cell[BoxData[
      \(X \((z)\)\)],
    AspectRatioFixed->True],
  "  be the",
  " ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-",
  "transform of the sequence ",
  Cell[BoxData[
      \({x\_n}\)]],
  ".  Then ",
  Cell[BoxData[
      \(x\_n\)]],
  " is given by the formula  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(x\_n\), "  ", "=", "  ", 
        RowBox[{\(x[n]\), "  ", "=", "  ", 
          
          RowBox[{\(\(\[GothicCapitalZ]\^\(-1\)\)[X \((z)\)]\), "  ", "=", 
            "   ", 
            RowBox[{\(\[Sum]\+\(j = 1\)\%k\), 
              RowBox[{"Res", "[", 
                RowBox[{\(X \((z)\) z\^\(n - 1\)\), 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(z\_j\)}], "]"}]}]}]}]}]]],
  ".  \n\nwhere  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_k\)}]]],
  "  are the poles of  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ X \((z)\) z\^\(n - 1\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Corollary 9.2 (Inverse z-transform)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   Let  ",
  Cell[BoxData[
      \(X \((z)\)\)],
    AspectRatioFixed->True],
  "  be the",
  " ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-",
  "transform of the sequence.  If   ",
  Cell[BoxData[
      \(X \((z)\)\)],
    AspectRatioFixed->True],
  "  has simple poles at the points  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_k\)}]]],
  "  then  ",
  Cell[BoxData[
      \(x\_n\)]],
  " is given by the formula  \n\n\t\t\t",
  Cell[BoxData[
      \(x\_n\  = \ \(x[
            n]\  = \ \(\(\[GothicCapitalZ]\^\(-1\)\)[
              X \((z)\)]\  = \ \ \[Sum]\+\(j = 1\)\%k\((\ 
                lim\+\(z\  \[Rule] \ z\_j\)\ \ \((z - z\_j)\) X \((z)\) 
                    z\^\(n - 1\)\ )\)\)\)\)]],
  ".  \n"
}], "Text"],

Cell[TextData[{
  StyleBox["Example 9.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Find the",
    FontFamily->"Times New Roman"],
  " ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-",
  "transform of the",
  StyleBox[" unit pulse or impulse sequence   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(x\_n\), "  ", "=", "  ", 
        RowBox[{\(\[Delta][n]\), "  ", "=", "  ", 
          RowBox[{"{", GridBox[{
                {"1", 
                  RowBox[{
                    RowBox[{
                      StyleBox["for",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], 
                      StyleBox[
                        RowBox[{"  ", 
                          StyleBox[" ",
                            FontWeight->"Plain"]}]], "n"}], "=", "0"}]},
                {"0", 
                  StyleBox[\(\(otherwise\)\(\ \ \ \)\),
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}
                }], 
            StyleBox["}",
              FontColor->GrayLevel[1]]}]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Solution 9.1.  This follows trivially from Equation ",
  StyleBox["(9-1)",
    FontColor->RGBColor[0, 0, 1]],
  "\t  \n\n\t\t\t",
  Cell[BoxData[
      \(X \((z)\)\ \  = \ \ \(\[GothicCapitalZ][
            x\_n]\ \  = \ \ \ \(\[Sum]\+\(n = 0\)\%\[Infinity] x\_n\ \
z\^\(-n\)\ \  = \ \ \(1 + \[Sum]\+\(n = 1\)\%\[Infinity]\ 
                  0  z\^\(-n\)\ \  = \ \ 1\)\)\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(x[n_] = KroneckerDelta[n];\)\ \), "\[IndentingNewLine]", 
    \(\(X[z_]\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\ 
          x[n]\ z\^\(-n\);\)\), "\[IndentingNewLine]", 
    \(\(pts = Table[{n, x[n]}, {n, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[pts, PlotStyle \[Rule] {PointSize[0.02], Red}, 
        PlotRange \[Rule] {{0, 10.5}, {0, 1.1}}, AspectRatio \[Rule] 1\/3, 
        Ticks \[Rule] {Range[0, 10, 1], 
            Range[0, 1, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    \!\(x\_n\) = \>\"", 
        x[n]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \>\"", 
        Append[\(Transpose[pts]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), "\<...\>"]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Form the series\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     X[z] = 1 +  \!\(\[Sum]\+\(n = 1\)\%\[Infinity]\) \!\
\(x\_n\) \!\(z\^\(-n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     X[z] = 1 +  \!\(\[Sum]\+\(n = 1\)\%\[Infinity]\) 0 \
\!\(z\^\(-n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which is the z-transform\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \[GothicCapitalZ][\!\(x\_n\)] = \>\"", 
        ZTransform[x[n], n, z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<     \[GothicCapitalZ][ \>", x[n], "\< ] = \>", 
        ZTransform[x[n], n, z]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can easily find the inverse of  X[z]."
}], "Text"],

Cell[BoxData[{
    \(\(X[z_] = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = InverseZTransform[X[z], z, n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  X[z] = \>", X[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(x\_n\)  = \!\(\[GothicCapitalZ]\^\(-1\)\)[X[z]] = \
\!\(\[GothicCapitalZ]\^\(-1\)\)[\>\"", X[z], "\<] = \>", 
        x[n]];\)\ \), "\[IndentingNewLine]", 
    \(\(pts = Table[{n, x[n]}, {n, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \>\"", 
        Append[\(Transpose[pts]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), "\<...\>"]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  The",
    FontFamily->"Times New Roman"],
  " ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-",
  "transform of the",
  StyleBox[" unit-step sequence   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(x\_n\), "  ", "=", "  ", 
        RowBox[{\(u[n]\), "  ", "=", "  ", 
          RowBox[{"{", GridBox[{
                {"1", 
                  RowBox[{
                    RowBox[{
                      StyleBox["for",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], 
                      StyleBox[
                        RowBox[{
                          StyleBox[" ",
                            FontFamily->"Times New Roman",
                            FontSize->12,
                            FontSlant->"Plain",
                            FontColor->GrayLevel[0],
                            FontVariations->{"Underline"->False,
                            "StrikeThrough"->False}], "  "}]], "n"}], 
                    "\[GreaterEqual]", "0"}]},
                {"0", 
                  RowBox[{
                    RowBox[{
                      StyleBox["for",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], 
                      StyleBox[
                        RowBox[{
                          StyleBox["   ",
                            FontFamily->"Times New Roman",
                            FontSize->12,
                            FontSlant->"Plain",
                            FontColor->GrayLevel[0],
                            FontVariations->{"Underline"->False,
                            "StrikeThrough"->False}], 
                          StyleBox[" ",
                            FontFamily->"Times New Roman",
                            FontSize->12,
                            FontWeight->"Plain",
                            FontSlant->"Plain",
                            FontColor->GrayLevel[0],
                            FontVariations->{"Underline"->False,
                            "StrikeThrough"->False}]}]], 
                      StyleBox["n",
                        FontFamily->"Courier New"]}], 
                    StyleBox["<",
                      FontFamily->"Courier New"], 
                    StyleBox["0",
                      FontFamily->"Courier New"]}]}
                }], 
            StyleBox["}",
              FontColor->GrayLevel[1]]}]}]}]]],
  "  is   ",
  Cell[BoxData[
      \(X \((z)\) = z\/\(z\  - \ 1\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Solution 9.2.  From Equation ",
  StyleBox["(9-1)",
    FontColor->RGBColor[0, 0, 1]],
  "\t  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(X \((z)\)\ \  = \ \ \ \(\[Sum]\+\(n = 0\)\%\[Infinity] x\_n\ \
z\^\(-n\)\ \  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity] z\^\(-n\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\((z\^\(-1\))\)\^n\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1\/\(1 - z\^\(-1\)\)\ \  = \ \
\ z\/\(z - 1\)\)\)\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(x[n_] = UnitStep[n];\)\ \), "\[IndentingNewLine]", 
    \(\(X[z_]\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\ 
          x[n]\ z\^\(-n\);\)\), "\[IndentingNewLine]", 
    \(\(pts = Table[{n, x[n]}, {n, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[pts, PlotStyle \[Rule] {PointSize[0.02], Red}, 
        PlotRange \[Rule] {{0, 10.5}, {0, 1.1}}, AspectRatio \[Rule] 1\/3, 
        Ticks \[Rule] {Range[0, 10, 1], 
            Range[0, 1, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    \!\(x\_n\) = \>\"", 
        x[n]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< {\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \
\>\"", Append[\(Transpose[pts]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), "\<...\>"]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Form the series\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    X[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\) 1 \
\!\(z\^\(-n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    X[z] = \>", 
        1\/\(1 - z\^\(-1\)\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which is the z-transform\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<    \[GothicCapitalZ][{\>", 
        1, \*"\"\<\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)] = \>\"", 
        ZTransform[x[n], n, z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    \[GothicCapitalZ][ \>", x[n], "\< ] = \>", 
        ZTransform[x[n], n, z]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "We can use residues to find the inverse.\n\n\t\t",
  Cell[BoxData[
      \(f \((z)\)\  = \ \(z\^\(n - 1\)\) z\/\(z - 1\)\)]],
  " \n\t\t\n\t\t",
  Cell[BoxData[
      \(x\_n\  = \ \(Res[f \((z)\), 1]\  = \ \(z\^\(n - 1\)\) 
            z\/\(z - 1\)\)\)]],
  " "
}], "Text"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can find the inverse of  X[z]  using residues."
}], "Text"],

Cell[BoxData[{
    \(\(X[z_] = z\/\(z - 1\);\)\ \ \), "\[IndentingNewLine]", 
    \(InverseViaResidues\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \>\"", 
        Append[Table[s[n], {n, 0, 9}], "\<...\>"]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(X[z_] = z\/\(z - 1\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(ZResidue[z\_1, 1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<      \!\(x\_n\) = \>\"", 
        lim\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \
\>\"", Append[Table[lim, {n, 0, 9}], "\<...\>"]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "The",
  " ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-",
  "transform of the sequence",
  StyleBox["   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(\(x\_n\)\(\ \)\(=\)\)\)]],
  "  ",
  Cell[BoxData[
      \(b\^n\)]],
  "   is   ",
  Cell[BoxData[
      \(X \((z)\) = z\/\(z\  - \ b\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Solution 9.3.  From Definition 9.1 \n\n\t\t\t",
  Cell[BoxData[{
      \(X \((z)\)\ \  = \ \ \(\[Sum]\+\(n = 0\)\%\[Infinity]\( x\_n\) 
              z\^\(-n\)\ \  = \ \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\( b\^n\) 
              z\^\(-n\)\)\ \[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \ \)\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\((b\^n\/z\^n)\)\ \  = \ \ \[Sum]\+\(n = \
0\)\%\[Infinity]\((b\/z)\)\^n\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1\/\(1 - b\/z\)\ \  = \ \ \
z\/\(z\  - \ b\)\)\)\)}]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[b];\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = b\^n;\)\ \), "\[IndentingNewLine]", 
    \(\(X[z_]\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\ 
          x[n]\ z\^\(-n\);\)\), "\[IndentingNewLine]", 
    \(\(pts = Table[{n, x[n]}, {n, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \
\>\"", Append[\(Transpose[pts]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), "\<...\>"]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Form the series\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     X[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\) \>\"", 
        x[n], \*"\"\< \!\(z\^\(-n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", 
        1/\((1 - b\/z)\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which is the z-transform\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[GothicCapitalZ][{\>", 
        x[n], \*"\"\<\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)] = \>\"", 
        ZTransform[x[n], n, z]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "We can explore the situation when  ",
  Cell[BoxData[
      \(b = 4\/5\)]],
  "  and  ",
  Cell[BoxData[
      \(b = 6\/5\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(b = 4\/5;\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = b\^n;\)\ \), "\[IndentingNewLine]", 
    \(\(pts = Table[{n, x[n]}, {n, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[pts, PlotRange \[Rule] {{0, 10}, {\(-0.01\), 1}}, 
        PlotStyle \[Rule] {PointSize[0.02], Red}, 
        Ticks \[Rule] {Range[0, 10, 1], 
            Range[0, 1, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \
\>\"", Append[\(Transpose[pts]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), "\<...\>"]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Form the series\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     X[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\) \>\"", 
        x[n], \*"\"\< \!\(z\^\(-n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", 
        1/\((1 - b\/z)\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which is the z-transform\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", ZTransform[x[n], n, z]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(b = 6\/5;\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = b\^n;\)\ \), "\[IndentingNewLine]", 
    \(\(pts = Table[{n, x[n]}, {n, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[pts, PlotRange \[Rule] {{0, 10}, {\(-0.01\), 7}}, 
        PlotStyle \[Rule] {PointSize[0.02], Red}, 
        Ticks \[Rule] {Range[0, 10, 1], 
            Range[0, 10, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \
\>\"", Append[\(Transpose[pts]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), "\<...\>"]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Form the series\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     X[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\) \>\"", 
        x[n], \*"\"\< \!\(z\^\(-n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", 
        1/\((1 - b\/z)\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which is the z-transform\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", ZTransform[x[n], n, z]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can find the inverse of  X[z]  using residues."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[b];\)\), "\[IndentingNewLine]", 
    \(\(X[z_] = z\/\(z - b\);\)\ \ \), "\[IndentingNewLine]", 
    \(InverseViaResidues\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \>\"", 
        Append[Table[s[n], {n, 0, 9}], "\<...\>"]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Clear[b];\)\), "\[IndentingNewLine]", 
    \(\(X[z_] = z\/\(z - b\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(ZResidue[z\_1, 1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<      \!\(x\_n\) = \>\"", 
        lim\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \
\>\"", Append[Table[lim, {n, 0, 9}], "\<...\>"]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "The",
  " ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-",
  "transform of the",
  StyleBox[" exponential sequence   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x\_n\  = \ \[ExponentialE]\^\(a\ n\)\)]],
  "   is   ",
  Cell[BoxData[
      \(X \((z)\) = z\/\(z - \[ExponentialE]\^a\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Solution 9.4.  From Definition 9.1  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(X \((z)\)\ \  = \ \ \(\[Sum]\+\(n = 0\)\%\[Infinity]\( x\_n\) 
              z\^\(-n\)\ \  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\( \
\[ExponentialE]\^\(a\ n\)\) z\^\(-n\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\((\[ExponentialE]\^\(a\ n\)\/z\^n)\)\ \  = \ \ \[Sum]\+\(n = \
0\)\%\[Infinity]\((\[ExponentialE]\^a\/z)\)\^n\)\)\(\ \)\(\[IndentingNewLine]\
\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1\/\(1 - \
\[ExponentialE]\^a\/z\)\ \  = \ \ z\/\(z - \[ExponentialE]\^a\)\)\)\)}]],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a];\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = \[ExponentialE]\^\(a\ n\);\)\ \), "\[IndentingNewLine]", 
    \(\(X[z_]\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\ 
          x[n]\ z\^\(-n\);\)\), "\[IndentingNewLine]", 
    \(\(pts = Table[{n, x[n]}, {n, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   {\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \
\>\"", Append[\(Transpose[pts]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), "\<...\>"]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Form the series\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<      X[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\) \>\"", 
        x[n], \*"\"\< \!\(z\^\(-n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<      X[z] = \>", 
        1/\((1 - \[ExponentialE]\^\(a\ n\)\/z)\)\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<      X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which is the z-transform\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[GothicCapitalZ][{\>", 
        x[n], \*"\"\<\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)] = \>\"", 
        ZTransform[x[n], n, z]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "We can explore the situation when  ",
  Cell[BoxData[
      \(a = \(-\(1\/10\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(a = 1\/10\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(a = \(-1\)\/10;\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = \[ExponentialE]\^\(a\ n\);\)\ \), "\[IndentingNewLine]", 
    \(\(X[z_]\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\ 
          x[n]\ z\^\(-n\);\)\), "\[IndentingNewLine]", 
    \(\(pts = Table[{n, x[n]}, {n, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[pts, PlotRange \[Rule] {{0, 10}, {\(-0.01\), 1}}, 
        PlotStyle \[Rule] {PointSize[0.02], Red}, 
        Ticks \[Rule] {Range[0, 10, 1], 
            Range[0, 1, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \
\>\"", Append[\(Transpose[pts]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), "\<...\>"]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Form the series\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     X[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\) \>\"", 
        x[n], \*"\"\< \!\(z\^\(-n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", 
        1/\((1 - \[ExponentialE]\^\(a\ n\)\/z)\)\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which is the z-transform\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", ZTransform[x[n], n, z]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(a = 1\/10;\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = \[ExponentialE]\^\(a\ n\);\)\ \), "\[IndentingNewLine]", 
    \(\(X[z_]\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\ 
          x[n]\ z\^\(-n\);\)\), "\[IndentingNewLine]", 
    \(\(pts = Table[{n, x[n]}, {n, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[pts, PlotRange \[Rule] {{0, 10}, {\(-0.01\), 3}}, 
        PlotStyle \[Rule] {PointSize[0.02], Red}, 
        Ticks \[Rule] {Range[0, 10, 1], 
            Range[0, 3, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \
\>\"", Append[\(Transpose[pts]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), "\<...\>"]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Form the series\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     X[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\) \>\"", 
        x[n], \*"\"\< \!\(z\^\(-n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", 
        1/\((1 - \[ExponentialE]\^\(a\ n\)\/z)\)\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which is the z-transform\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", ZTransform[x[n], n, z]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can find the inverse of  X[z]  using residues."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[a];\)\), "\[IndentingNewLine]", 
    \(\(X[z_] = 
        z\/\(z - \[ExponentialE]\^a\);\)\ \ \), "\[IndentingNewLine]", 
    \(InverseViaResidues\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \>\"", 
        Append[Table[s[n], {n, 0, 9}], "\<...\>"]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Clear[a];\)\), "\[IndentingNewLine]", 
    \(\(X[z_] = 
        z\/\(z - \[ExponentialE]\^a\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(ZResidue[z\_1, 1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<      \!\(x\_n\) = \>\"", 
        lim\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<      \!\(x\_n\) = \>\"", 
        PowerExpand[lim]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \
\>\"", Append[Table[lim, {n, 0, 9}], "\<...\>"]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["9.1.2  Properties of the z-transform",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tGiven that   ",
  Cell[BoxData[
      \(\[GothicCapitalZ][x\_n]\  = \ \(\[GothicCapitalZ][x[n]]\  = \ 
          X \((z)\)\)\)]],
  "   and   ",
  Cell[BoxData[
      \(\[GothicCapitalZ][y\_n]\  = \ \(\[GothicCapitalZ][y[n]]\  = \ 
          Y \((z)\)\)\)]],
  ".  We have the following properties: \n\t\n",
  StyleBox["(i)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["    ",
    FontWeight->"Bold"],
  "Linearity.\t\t\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][
          c\_1\ x\_n + \(c\_2\) y\_n]\ \  = \ \ \(\[GothicCapitalZ][
            c\_1\ x[n] + \(c\_2\) y[n]]\ \  = \ \ c\_1\ X \((z)\) + \(c\_2\) 
              Y \((z)\)\)\)]],
  ".  \n\n",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["   ",
    FontWeight->"Bold"],
  "Delay Shift.\t\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][x[n - N] u[n - N]]\ \  = \ \ X \((z)\) 
          z\^\(-N\)\)]],
  ".  \n\n",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Advance Shift.\t\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][
          x[n + N]]\ \  = \ \ z\^N\ \((\(X \((z)\)\  - \ x[0]\  - \ 
                  x[1] z\^\(-1\)\  - \ x[2] z\^\(-2\) -  ... \) - \ 
              x[N - 1] z\^\(\(-N\) + 1\))\)\)]],
  ",   or\n\n\t\t\t\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][
          x\_\(n + N\)]\ \  = \ \ z\^N\ \((\(X \((z)\)\  - \ 
                  x\_0\  - \ \(x\_1\) z\^\(-1\)\  - \ \(x\_2\) 
                    z\^\(-2\) -  ... \) - \ \(x\_\(N - 1\)\) 
                z\^\(\(-N\) + 1\))\)\)]],
  "\n\n",
  StyleBox["(iv)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["   ",
    FontWeight->"Bold"],
  "Multiplication by ",
  Cell[BoxData[
      \(n\)]],
  ".\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][
          n\ x\_n]\ \  = \ \ \(\[GothicCapitalZ][
            n\ x[n]]\  = \ \(-\ z\)\ \(d\/dz\) X \((z)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 9.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  T",
    FontFamily->"Times New Roman"],
  "he",
  " ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-",
  "transform of the ",
  StyleBox["sequence   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x\_n\  = \ cos \((a\ n)\)\)]],
  "   is   ",
  Cell[BoxData[
      \(X \((z)\)\  = \ \(z\ \((z - cos \((a)\))\)\)\/\(z\^2 - 2\ z\ cos \
\((a)\) + 1\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Solution 9.5.\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[GothicCapitalZ][
          x\_n]\ \  = \ \ \(\[GothicCapitalZ][
            cos \((a\ n)\)]\ \  = \ \ \[GothicCapitalZ][\(1\/2\) \
\[ExponentialE]\^\(\[ImaginaryI]\ a\ n\) + \(1\/2\) \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ a\ n\)]\)\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(1\/2\) \
\[GothicCapitalZ][\[ExponentialE]\^\(\[ImaginaryI]\ a\ n\)] + \(1\/2\) \
\[GothicCapitalZ][\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ a\ n\)]\ \  = \ \ \
\(1\/2\) z\/\(z\  - \ \[ExponentialE]\^\(\[ImaginaryI]\ a\)\) + \(1\/2\) 
              z\/\(z\  - \ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ a\)\)\)\)\(\
\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(1\/2\) \((\(z \((z\  \
- \ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ a\))\)\)\/\(\((z\  - \ \
\[ExponentialE]\^\(\[ImaginaryI]\ a\))\) \((z\  - \ \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ a\))\)\)\  + \ \(z \((z\  - \ \[ExponentialE]\^\(\
\[ImaginaryI]\ a\))\)\)\/\(\((z\  - \ \[ExponentialE]\^\(\[ImaginaryI]\ \
a\))\) \((z\  - \ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ a\))\)\)\ )\)\)\)\(\n\
\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \)\(\(z\ \((2\ z - \
\[ExponentialE]\^\(\[ImaginaryI]\ a\) - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\
\ a\))\)\)\/\(2\ \((z\  - \ \[ExponentialE]\^\(\[ImaginaryI]\ a\))\) \((z\  - \
\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ a\))\)\)\ \  = \ \ \(z\ \((z - \(\
\[ExponentialE]\^\(\[ImaginaryI]\ a\) + \[ExponentialE]\^\(\(-\[ImaginaryI]\)\
\ a\)\)\/2)\)\)\/\(\((z\  - \ \[ExponentialE]\^\(\[ImaginaryI]\ a\))\) \((z\  \
- \ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ a\))\)\)\)\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(z\ \((z - cos \((a)\))\
\)\)\/\(\((z\  - \ \[ExponentialE]\^\(\[ImaginaryI]\ a\))\) \((z\  - \ \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ a\))\)\)\ \  = \ \ \(z\ \((z - cos \
\((a)\))\)\)\/\(z\^2 - 2\ z\ cos \((a)\) + 1\)\)\)\)}]],
  "    \n\n",
  StyleBox["Remark 9.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  When using the residue theorem to compute inverse",
  " ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-",
  "transforms, the complex form is preferred, i. e. \n\n\t\t\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][
          x\_n]\ \  = \ \ \(z\ \((2\ z - \[ExponentialE]\^\(\[ImaginaryI]\ \
a\) - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ a\))\)\)\/\(2\ \((z\  - \ \
\[ExponentialE]\^\(\[ImaginaryI]\ a\))\) \((z\  - \ \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ a\))\)\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a];\)\ \), "\n", 
    \(\(x[n_] = Cos[a\ n];\)\ \), "\n", 
    \(\(X[z_] = ZTransform[\ x[n], n, z];\)\ \), "\n", 
    \(\(X3[z_] = X[z];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(x\_n\)  = \>\"", 
        x[n]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(x\_n\)  = \!\(1\/2\)(\!\(\[ExponentialE]\^\(\
\[ImaginaryI]\\\ a\\\ n\)\) + \!\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\\\ \
a\\\ n\)\))\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(zt1 = 
        ZTransform[\[ExponentialE]\^\(\[ImaginaryI]\ a\ n\), n, 
          z];\)\), "\[IndentingNewLine]", 
    \(\(num1 = Numerator[zt1];\)\ \), "\[IndentingNewLine]", 
    \(\(den1 = Denominator[zt1];\)\ \), "\[IndentingNewLine]", 
    \(\(zt2 = 
        ZTransform[\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ a\ n\), n, 
          z];\)\), "\[IndentingNewLine]", 
    \(\(num2 = 
        Numerator[
            zt2]/\[ExponentialE]\^\(\[ImaginaryI]\ a\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(den2 = 
        FullSimplify[
          Denominator[
              zt2]/\[ExponentialE]\^\(\[ImaginaryI]\ a\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(zt2\  = num2/den2;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X[z] = \>", \(1\/2\) \((zt1 + 
              zt2)\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X[z] = \>", \(1\/2\) \((\(num1\ den2 + num2\ den1\)\/\(den1\ \
den2\))\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X[z] = \>", \(1\/2\) \((Simplify[num1\ den2 + num2\ \
den1]\/\(den1\ den2\))\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X[z] = \>", 
        Simplify[\(1\/2\) \((ComplexExpand[num1\ den2 + num2\ \
den1]\/ComplexExpand[den1\ den2])\)\ ]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which is the z-transform\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[GothicCapitalZ][{\>", 
        x[n], \*"\"\<\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)] = \>\"", 
        X[z]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Some more details.\n\nWe could sum the z-transforms of  ",
  Cell[BoxData[
      \(x[n] = \(1\/2\) \[ExponentialE]\^\(\[ImaginaryI]\ a\ n\)\)]],
  "  and  ",
  Cell[BoxData[
      \(x[n] = \(1\/2\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ a\ n\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[a];\)\), "\[IndentingNewLine]", 
    \(\(x[
          n_] = \(1\/2\) \[ExponentialE]\^\(\[ImaginaryI]\ a\ n\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(X[z_]\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\ 
          x[n]\ z\^\(-n\);\)\), "\[IndentingNewLine]", 
    \(\(X1[z_]\  = X[z];\)\), "\[IndentingNewLine]", 
    \(\(pts = Table[{n, x[n]}, {n, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[\(Transpose[pts]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), "\<...\>"]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Form the series\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  X[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\) \>\"", 
        x[n], \*"\"\< \!\(z\^\(-n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  X[z] = \>", \(1\/2\)/\((1 - \[ExponentialE]\^\(\
\[ImaginaryI]\ a\)\/z)\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which is the z-transform\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[GothicCapitalZ][{\>", 
        x[n], \*"\"\<\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)] = \>\"", 
        X[z]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Clear[a];\)\), "\[IndentingNewLine]", 
    \(\(x[
          n_] = \(1\/2\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ a\ n\);\)\ \
\), "\[IndentingNewLine]", 
    \(\(X[z_]\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\ 
          x[n]\ z\^\(-n\);\)\), "\[IndentingNewLine]", 
    \(\(X2[z_]\  = X[z];\)\), "\[IndentingNewLine]", 
    \(\(pts = Table[{n, x[n]}, {n, 0, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[\(Transpose[pts]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), "\<...\>"]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Form the series\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  X[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\) \>\"", 
        x[n], \*"\"\< \!\(z\^\(-n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  X[z] = \>", \(1\/2\)/\((1 - \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ a\)\/z)\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which is the z-transform\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[GothicCapitalZ][{\>", 
        x[n], \*"\"\<\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)] = \>\"", 
        X[z]\ ];\)\ \)}], "Input"],

Cell["Now we can add the above two results.", "Text"],

Cell[BoxData[{
    \(\(Print["\<\[GothicCapitalZ][{\>", 
        Cos[a\ n], \*"\"\<\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)] = \
\[GothicCapitalZ][{\>\"", \(1\/2\) \[ExponentialE]\^\(\[ImaginaryI]\ a\ n\), \
\*"\"\<\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)] + \[GothicCapitalZ][{\>\"", \
\(1\/2\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ a\ n\), \*"\"\<\!\(\(}\_\(n = \
0\)\%\[Infinity]\)\)]\>\""\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[GothicCapitalZ][{\>", 
        Cos[a\ n], \*"\"\<\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)] = \>\"", 
        X1[z] + X2[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[GothicCapitalZ][{\>", 
        Cos[a\ n], \*"\"\<\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)] = \>\"", 
        Together[X1[z] + X2[z]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which agrees with our previous computation\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[GothicCapitalZ][{\>", 
        Cos[a\ n], \*"\"\<\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)] = \>\"", 
        X3[z]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "We can explore the situation when  ",
  Cell[BoxData[
      \(a = \[Pi]\/6\)]],
  "  and  ",
  Cell[BoxData[
      \(a = \[Pi]\/4\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(a = \[Pi]\/6;\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = Cos[a\ n];\)\ \), "\[IndentingNewLine]", 
    \(\(X[z_]\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\ 
          x[n]\ z\^\(-n\);\)\), "\[IndentingNewLine]", 
    \(\(pts = Table[{n, x[n]}, {n, 0, 12}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[pts, PlotRange \[Rule] {{0, 12}, All}, 
        PlotStyle \[Rule] {PointSize[0.02], Red}, 
        Ticks \[Rule] {Range[0, 12, 1], 
            Range[\(-1\), 1, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \>\"", 
        Append[\(Transpose[pts]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), "\<...\>"]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Form the series\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  X[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\) \>\"", 
        x[n], \*"\"\< \!\(z\^\(-n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which is the z-transform\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[GothicCapitalZ][{\>", 
        x[n], \*"\"\<\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)] = \>\"", 
        X[z]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(a = \[Pi]\/4;\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = Cos[a\ n];\)\ \), "\[IndentingNewLine]", 
    \(\(X[z_]\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\ 
          x[n]\ z\^\(-n\);\)\), "\[IndentingNewLine]", 
    \(\(pts = Table[{n, x[n]}, {n, 0, 12}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[pts, PlotRange \[Rule] {{0, 12}, All}, 
        PlotStyle \[Rule] {PointSize[0.02], Red}, 
        Ticks \[Rule] {Range[0, 12, 1], 
            Range[\(-1\), 1, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \>\"", 
        Append[\(Transpose[pts]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), "\<...\>"]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Form the series\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  X[z] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\) \>\"", 
        x[n], \*"\"\< \!\(z\^\(-n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which is the z-transform\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[GothicCapitalZ][{\>", 
        x[n], \*"\"\<\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)] = \>\"", 
        X[z]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can find the inverse of  X[z]  using residues."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[a];\)\), "\[IndentingNewLine]", 
    \(\(X[
          z_] = \(z\ \((1 + \[ExponentialE]\^\(2\ \[ImaginaryI]\ a\) - 2\ \
\[ExponentialE]\^\(\[ImaginaryI]\ a\)\ z)\)\)\/\(2\ \((\[ExponentialE]\^\(\
\[ImaginaryI]\ a\) - z)\)\ \((\(-1\) + \[ExponentialE]\^\(\[ImaginaryI]\ a\)\ \
z)\)\);\)\ \ \), "\[IndentingNewLine]", 
    \(InverseViaResidues\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \>\"", 
        Append[Table[
            s[n], {n, 0, 9}], "\<...\>"]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(s[n_] = 
        FullSimplify[MapAll[PowerExpand, s[n]]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \>\"", 
        Append[Table[s[n], {n, 0, 9}], "\<...\>"]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(X[
          z_] = \(z\ \((1 + \[ExponentialE]\^\(2\ \[ImaginaryI]\ a\) - 2\ \
\[ExponentialE]\^\(\[ImaginaryI]\ a\)\ z)\)\)\/\(2\ \((\[ExponentialE]\^\(\
\[ImaginaryI]\ a\) - z)\)\ \((\(-1\) + \[ExponentialE]\^\(\[ImaginaryI]\ a\)\ \
z)\)\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(lim1 = 
        PowerExpand[\ ZResidue[z\_1, 1]\ ];\)\), "\[IndentingNewLine]", 
    \(\(lim2 = 
        PowerExpand[\ ZResidue[z\_2, 1]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<      \!\(x\_n\) = \>\"", 
        lim1 + lim2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \
\>\"", Append[
          Table[lim1 + lim2, {n, 0, 
              9}], "\<...\>"]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<      \!\(x\_n\) = \>\"", 
        FullSimplify[lim1 + lim2]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \
\>\"", Append[
          Table[FullSimplify[lim1 + lim2], {n, 0, 
              9}], "\<...\>"]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "We are really done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can find the let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " find the inverse of  X[z]."
}], "Text"],

Cell[BoxData[{
    \(\(X[
          z_] = \(z\ \((1 + \[ExponentialE]\^\(2\ \[ImaginaryI]\ a\) - 2\ \
\[ExponentialE]\^\(\[ImaginaryI]\ a\)\ z)\)\)\/\(2\ \((\[ExponentialE]\^\(\
\[ImaginaryI]\ a\) - z)\)\ \((\(-1\) + \[ExponentialE]\^\(\[ImaginaryI]\ a\)\ \
z)\)\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<   a = \>", a\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = InverseZTransform[X[z], z, n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n] = \>", x[n]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = 
        Simplify[ComplexExpand[x[n]], 
          n \[Element] Integers];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n] = \>", x[n]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = 
        ComplexExpand[
          CoefficientList[Normal[Series[X[z], {z, \[Infinity], 9}]], 
            1\/z]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n] = \>", x[n]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(X[
          z_] = \(z\ \((z - Cos[a])\)\)\/\(z\^2 - 2\ z\ Cos[a] + 1\);\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<   a = \>", a\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = InverseZTransform[X[z], z, n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n] = \>", x[n]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = 
        Simplify[ComplexExpand[x[n]], 
          n \[Element] Integers];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n] = \>", x[n]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = 
        ComplexExpand[
          CoefficientList[Normal[Series[X[z], {z, \[Infinity], 9}]], 
            1\/z]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n] = \>", x[n]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x[n] = \>", TrigReduce[x[n]]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["9.1.3  Table of z-transforms",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  \n\n\tWe list the following table of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transforms.  It can also be used to find the inverse z-transform.   \n\t\n\
\t\t\t",
  Cell[BoxData[GridBox[{
          {"  ", 
            StyleBox["Sequence",
              FontWeight->"Bold"], 
            StyleBox[\(z - transform\),
              FontWeight->"Bold"]},
          {"1", \(\[Delta][n]\), "1"},
          {"2", \(u[n]\), \(z\/\(z\  - \ 1\)\)},
          {"3", \(b\^n\), \(z\/\(z\  - \ b\)\)},
          {"4", \(\(b\^\(n - 1\)\) u[n - 1]\), \(1\/\(z\  - \ b\)\)},
          {
            "5", \(\[ExponentialE]\^\(a\ n\)\), \(z\/\(z\  - \ \
\[ExponentialE]\^a\)\)},
          {"6", "n", \(z\/\((z\  - \ 1)\)\^2\)},
          {"7", \(n\^2\), \(\(z\ \((z\  + \ 1)\)\)\/\((z\  - \ 1)\)\^3\)},
          {"8", \(b\^n\ n\), \(\(b\ z\)\/\((z\  - \ b)\)\^2\)},
          {
            "9", \(\[ExponentialE]\^\(a\ n\)\ n\), \(\(z\ \
\[ExponentialE]\^a\)\/\((z\  - \ \[ExponentialE]\^a)\)\^2\)},
          {
            "10", \(sin \((a\ n)\)\), \(\(sin \((a)\) z\)\/\(z\^2 - 
                  2  cos \((a)\) z\  + 1\)\)},
          {
            "11", \(b\^n\ sin \((a\ n)\)\), \(\(\(sin\) \((a)\) \(b\)\(\ \
\)\(z\)\(\ \)\)\/\(z\^2 - 2  cos \((a)\)\ b\ z\  + b\^2\)\)},
          {
            "12", \(cos \((a\ n)\)\), \(\(z\ \((z - 
                      cos \((a)\))\)\)\/\(z\^2 - 2  cos \((a)\)\ z\  + 
                  1\)\)},
          {
            "13", \(b\^n\ cos \((a\ n)\)\), \(\(z\ \((z - 
                      b\ cos \((a)\))\)\)\/\(z\^2 - 2  cos \((a)\)\ b\ z\  + 
                  b\^2\)\)}
          },
        GridFrame->True,
        RowLines->True,
        ColumnLines->True]]],
  "  \n\t\n\t\t\t",
  StyleBox["Table 9.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  " ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-",
  "transforms of some common sequences. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(fun = {KroneckerDelta[n], UnitStep[n], 
          b\^n, \[ExponentialE]\^\(a\ n\), n, n\^2, n\^3, n\ b\^n, 
          n\ \[ExponentialE]\^\(a\ n\), \@n, Sin[a\ n], \(b\^n\) Sin[a\ n], 
          n\ Sin[a\ n], Cos[a\ n], \(b\^n\) Cos[a\ n], 
          n\ Cos[a\ n]};\)\), "\[IndentingNewLine]", 
    \(\(trz = ZTransform[fun, n, z];\)\), "\[IndentingNewLine]", 
    \(Print[
      TableForm[Transpose[{fun, trz}], 
        TableHeadings \[Rule] {Automatic, {"\<sequence\>", \
"\<z-transform\>"}}\ ]\ ]\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 9.3 (Residues at Poles)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 1]],
  "\n",
  StyleBox["(i)",
    FontColor->RGBColor[0, 0, 1]],
  "  \tIf ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " has a simple pole at  ",
  Cell[BoxData[
      \(z\_0\)]],
  ",  then the residue is   \n\n\t\t\t",
  Cell[BoxData[
      \(Res[f \((z)\), 
          z\_0]\ \  = \ \ lim\+\(z\  \[Rule] \ z\_0\)\((z - z\_0)\) 
            f \((z)\)\)]],
  ".  \n\n",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  "  \tIf ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " has a pole of order ",
  Cell[BoxData[
      \(2\)]],
  " at  ",
  Cell[BoxData[
      \(z\_0\)]],
  ",  then the residue is   \n\n\t\t\t",
  Cell[BoxData[
      \(Res[f \((z)\), 
          z\_0]\ \  = \ \ lim\+\(z\  \[Rule] \ z\_0\)\(d\/dz\) \((\(\((z - 
                        z\_0)\)\^2\) f \((z)\))\)\)]],
  ".  \n\n",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  "  \tIf ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " has a pole of order ",
  Cell[BoxData[
      \(3\)]],
  " at  ",
  Cell[BoxData[
      \(z\_0\)]],
  ",  then the residue is   \n\n\t\t\t",
  Cell[BoxData[
      \(Res[f \((z)\), 
          z\_0]\ \  = \ \ \(1\/\(2!\)\) \(lim\+\(z\  \[Rule] \ \
z\_0\)\(d\^2\/dz\^2\) \((\(\((z - z\_0)\)\^3\) f \((z)\))\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 9.3 is in the book (see Theorem \
8.2).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Subroutines for finding the inverse z-transform",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\(InverseViaResidues := 
        Module[\ {}, \[IndentingNewLine]x[n_] = 
            InverseZTransform[X[z], z, n]; \ \[IndentingNewLine]S[z_] = 
            Series[X[z], {z, \[Infinity], 
                9}]; \ \[IndentingNewLine]Print["\<Given the z-transform\>"]; \
\ \[IndentingNewLine]Print["\<   X[z] = \>", 
            X[z]\ ]; \ \[IndentingNewLine]Print["\<   X[z] = \>", 
            S[z]\ ]; \ \[IndentingNewLine]Print["\<The sequence is\>"]; \ \
\[IndentingNewLine]Print[\*"\"\<{\!\(x\_n\)\!\(\(}\_\(n = \
0\)\%\[Infinity]\)\)  = \>\"", 
            Append[CoefficientList[Normal[S[z]], 
                1\/z], "\<...\>"]\ ]; \ \[IndentingNewLine]Print["\<Using \
residues\>"]; \ \[IndentingNewLine]Print["\<   X[z] = \>", 
            X[z]\ ]; \ \[IndentingNewLine]zsolve = 
            Solve[Denominator[Together[X[z]]] \[Equal] 0, 
              z]; \ \[IndentingNewLine]zsolve = 
            Union[zsolve]; \ \[IndentingNewLine]z\_2 = \(z\_1 = 
              zsolve\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\)\); \[IndentingNewLine]If[\ 
            Length[zsolve] \[Equal] 2, 
            z\_2 = zsolve\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\
\[RightDoubleBracket]\)\)\ ]; \[IndentingNewLine]If[
            z\_1 =!= 
              z\_2, \[IndentingNewLine]Print["\<The poles are\>"]; \
\[IndentingNewLine]s[n_] = 
              Residue[X[z] z\^\(n - 1\), {z, z\_1}] + 
                Residue[
                  X[z] z\^\(n - 1\), {z, 
                    z\_2}]; \[IndentingNewLine]Print[\*"\"\<     \!\(z\_1\) = \
\>\"", z\_1\ ]; \[IndentingNewLine]Print[\*"\"\<     \!\(z\_2\) = \>\"", 
              z\_2\ ]; \[IndentingNewLine]Print["\<The solution is\>"]; \
\[IndentingNewLine]Print[\*"\"\<     \!\(x\_n\) =  \!\(1\/\(2\\\ \[Pi]\\\ \
\[ImaginaryI]\)\)\>\"", "\<\[ClockwiseContourIntegral]\>"\+C, "\<(\>", 
              X[z]\ z\^\(n - 1\), "\<) \[DifferentialD]z\>"]; \ \
\[IndentingNewLine]Print[\*"\"\<     \!\(x\_n\) = Residue[X[z]\!\(z\^\(n - \
1\)\),{z,\!\(z\_1\)}] + Residue[X[z]\!\(z\^\(n - 1\)\),{z,\!\(z\_2\)}] \
\>\""]; \ \[IndentingNewLine]Print[\*"\"\<     \!\(x\_n\) = Residue[X[z]\!\(z\
\^\(n - 1\)\),{z,\>\"", 
              z\_1, \*"\"\<}] + Residue[X[z]\!\(z\^\(n - 1\)\),{z,\>\"", 
              
              z\_2, "\<}] \>"]; \ \[IndentingNewLine]Print[\*"\"\<     \
\!\(x\_n\) = Residue[\>\"", X[z] z\^\(n - 1\), "\<,{z,\>", 
              z\_1, "\<}] + Residue[\>", X[z] z\^\(n - 1\), "\<,{z,\>", 
              z\_2, "\<}]\>"]; \ \[IndentingNewLine]Print[\*"\"\<     \
\!\(x\_n\) = (\>\"", Residue[X[z] z\^\(n - 1\), {z, z\_1}], "\<) + (\>", 
              Residue[X[z] z\^\(n - 1\), {z, 
                  z\_2}], "\<)\>"\ ]; \ \[IndentingNewLine]Print[\*"\"\<     \
\!\(x\_n\) = \>\"", s[n]\ ];\ \ ]; \[IndentingNewLine]If[
            z\_1 \[Equal] 
              z\_2, \[IndentingNewLine]Print["\<The pole is\>"]; \
\[IndentingNewLine]s[n_] = 
              Residue[X[z] \(\(z\)\(\ \)\)\^\(n - 1\), {z, 
                  z\_1}]; \[IndentingNewLine]Print[\*"\"\<     \!\(z\_1\) = \
\>\"", z\_1\ ]; \[IndentingNewLine]Print[\*"\"\<     \!\(x\_n\) =  \!\(1\/\(2\
\\\ \[Pi]\\\ \[ImaginaryI]\)\)\>\"", "\<\[ClockwiseContourIntegral]\>"\+C, \
"\<(\>", X[
                  z]\ z\^\(n - 1\), "\<) \[DifferentialD]z\>"]; \ \
\[IndentingNewLine]Print[\*"\"\<     \!\(x\_n\) = Residue[X[z]\!\(\(\(z\)\(\\\
\ \)\)\^\(n - 1\)\),{z,\!\(z\_1\)}]\>\""]; \ \[IndentingNewLine]Print[\*"\"\< \
    \!\(x\_n\) = Residue[X[z]\!\(\(\(z\)\(\\\ \)\)\^\(n - 1\)\),{z,\>\"", 
              z\_1, "\<}]\>"]; \ \[IndentingNewLine]Print[\*"\"\<     \
\!\(x\_n\) = Residue[\>\"", X[z] z\^\(n - 1\), "\<,{z,\>", 
              z\_1, "\<}]\>"]; \ \[IndentingNewLine]Print[\*"\"\<     \
\!\(x\_n\) = \>\"", s[n]\ ];\ \ ];\ ];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ZResidue[Z0_, m_] := 
        Module[{}, \[IndentingNewLine]Z\_0 = Z0; \[IndentingNewLine]Clear[
            f]; \[IndentingNewLine]f[z_] = \(z\^\(n - 1\)\) 
              X[z]; \[IndentingNewLine]If[
            m \[Equal] 1, \[IndentingNewLine]lim\  = \ 
              Limit[\ \((z - Z\_0)\) f[z], 
                z \[Rule] 
                  Z\_0\ ]; \[IndentingNewLine]Print["\<     X[z] = \>", 
              X[z]\ ]; \ \[IndentingNewLine]Print["\<     f[z] = \>", 
              f[z]\ ]; \ \[IndentingNewLine]Print[\*"\"\<       \!\(z\_0\) = \
\>\"", Z\_0\ ]; \ \[IndentingNewLine]Print[\*"\"\<Res[f,\!\(z\_0\)] = \>\"", \
"\<lim\>"\_\*"\"\<z\[Rule]\!\(z\_0\)\>\"", \*"\"\< (z-\!\(z\_0\))f[z]\>\""]; \
\ \[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), \
"\< (z-\>", Z\_0, "\<)f[z]\>"]; \ \[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), \
"\< (z-\>", Z\_0, "\<)\>", f[z]\ ]; \ \[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), \
"\< \>", \((z - Z\_0)\) f[z]\ ]; \ \[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), \
"\< \>", Simplify[\((z - Z\_0)\) 
                  f[z]]\ ]; \ \[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", lim\ ];\ ]; \[IndentingNewLine]If[
            m \[Equal] 2, \[IndentingNewLine]lim\  = \ 
              Limit[Simplify[\[PartialD]\_z\((\(\((z - Z\_0)\)\^2\) f[z])\)], 
                z \[Rule] 
                  Z\_0\ ]; \[IndentingNewLine]Print["\<     X[z] = \>", 
              X[z]\ ]; \ \[IndentingNewLine]Print["\<     f[z] = \>", 
              f[z]\ ]; \ \[IndentingNewLine]Print[\*"\"\<       \!\(z\_0\) = \
\>\"", Z\_0\ ]; \ \[IndentingNewLine]Print[\*"\"\<Res[f,\!\(z\_0\)] = \>\"", \
"\<lim\>"\_\*"\"\<z\[Rule]\!\(z\_0\)\>\"", \*"\"\< \!\(\[PartialD]\_z\)((z-\!\
\(z\_0\)\!\(\()\^2\)\)f[z]\>\""]; \ \[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), \
\*"\"\< \!\(\[PartialD]\_z\)((z-\>\"", 
              
              Z\_0, \*"\"\<\!\(\()\^2\)\)f[z]\>\""]; \ \
\[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), \
\*"\"\< \!\(\[PartialD]\_z\)((z-\>\"", Z\_0, \*"\"\<\!\(\()\^2\)\)\>\"", 
              f[z]\ ]; \ \[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), \
\*"\"\< \!\(\[PartialD]\_z\)(\>\"", \(\((z - Z\_0)\)\^2\) 
                f[z], "\<)\>"\ ]; \ \[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), \
\*"\"\< \!\(\[PartialD]\_z\)(\>\"", 
              Simplify[\(\((z - Z\_0)\)\^2\) 
                  f[z]], "\<)\>"\ ]; \ \[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), \
"\< \>", Simplify[\[PartialD]\_z\((\(\((z - Z\_0)\)\^2\) 
                      f[z])\)]\ ]; \ \[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", lim\ ];\ ]; \[IndentingNewLine]If[
            m \[Equal] 3, \[IndentingNewLine]lim\  = \ 
              Limit[Simplify[\(1\/\(2!\)\) \[PartialD]\_\(z, z\)\((\(\((z - 
                                  Z\_0)\)\^3\) f[z])\)], 
                z \[Rule] 
                  Z\_0\ ]; \[IndentingNewLine]Print["\<     X[z] = \>", 
              X[z]\ ]; \ \[IndentingNewLine]Print["\<     f[z] = \>", 
              f[z]\ ]; \ \[IndentingNewLine]Print[\*"\"\<       \!\(z\_0\) = \
\>\"", Z\_0\ ]; \ \[IndentingNewLine]Print[\*"\"\<Res[f,\!\(z\_0\)] = \>\"", \
"\<lim\>"\_\*"\"\<z\[Rule]\!\(z\_0\)\>\"", \*"\"\< \!\(1\/\(2!\)\)\!\(\
\[PartialD]\_\(z, z\)\)((z-\!\(z\_0\)\!\(\()\^3\)\)f[z]\>\""]; \ \
\[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), \
\*"\"\< \!\(1\/\(2!\)\)\!\(\[PartialD]\_\(z, z\)\)((z-\>\"", 
              Z\_0, \*"\"\<\!\(\()\^3\)\)f[z]\>\""]; \ \
\[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), \
\*"\"\< \!\(1\/\(2!\)\)\!\(\[PartialD]\_\(z, z\)\)((z-\>\"", 
              Z\_0, \*"\"\<\!\(\()\^3\)\)\>\"", 
              f[z]\ ]; \ \[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), \
\*"\"\< \!\(1\/\(2!\)\)\!\(\[PartialD]\_\(z, z\)\)(\>\"", \(\((z - 
                        Z\_0)\)\^3\) 
                f[z], "\<)\>"\ ]; \ \[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), \
\*"\"\< \!\(1\/\(2!\)\)\!\(\[PartialD]\_\(z, z\)\)(\>\"", 
              Simplify[\(\((z - Z\_0)\)\^3\) 
                  f[z]], "\<)\>"\ ]; \ \[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), \
\*"\"\< \!\(1\/\(2!\)\)\!\(\[PartialD]\_z\)(\>\"", 
              Simplify[\[PartialD]\_z\ \((\(\((z - Z\_0)\)\^3\) 
                      f[z])\)], "\<)\>"\ ]; \ \
\[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), \
"\< \>", \(1\/\(2!\)\) 
                Simplify[\[PartialD]\_\(z, z\)\((\(\((z - Z\_0)\)\^3\) 
                        f[z])\)]\ ]; \ \[IndentingNewLine]Print["\<Res[f,\>", 
              Z\_0, "\<] = \>", lim\ ];\ ]; \[IndentingNewLine]Return[\ 
            lim\ ];\ ];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Find t",
    FontFamily->"Times New Roman"],
  "he inverse z-transform   ",
  Cell[BoxData[
      \(x\_n\ \  = \ \ \(x[
            n]\ \  = \ \ \(\[GothicCapitalZ]\^\(-1\)\)[\(2  z\)\/\(2  z - \
1\)]\)\)]],
  ".   Use (a) series, (b) table of z-transforms, (c) residues.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Solution 9.6 (a).  Method of series.  \n\n\tExpand  ",
  Cell[BoxData[
      \(X \((z)\)\  = \ \(2  z\)\/\(2  z - 1\)\)]],
  " in a series involving powers of ",
  Cell[BoxData[
      \(1\/z\)]],
  ".  \n\t\n\t\t",
  Cell[BoxData[
      \(X \((z)\)\  = \ \(z\/\(z\  - 1\/\(\(\ \)\(2\)\)\)\  = \ \(1\/\(1\  - \
\ \(1\/\(\(\ \)\(2\)\)\) z\^\(-1\)\)\  = \ \(\[Sum]\+\(n = \
0\)\%\[Infinity]\((\(1\/\(\(\ \)\(2\)\)\) z\^\(-1\))\)\^n\  = \ \[Sum]\+\(n = \
0\)\%\[Infinity]\( 1\/2\^n\) z\^\(-n\)\)\)\)\)]],
  " \n\t\t\nThe sequence of coefficients in the Laurent series is what we \
desire, and we see that  \n\n\t\t",
  Cell[BoxData[
      \(x\_n\  = \ \(x[n]\  = \ 1\/2\^n\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Solution 9.6 (b).  Writing  ",
  Cell[BoxData[
      \(X \((z)\)\  = \ z\/\(z\  - 1\/\(\(\ \)\(2\)\)\)\)]],
  "  we identify  ",
  Cell[BoxData[
      \(b = 1\/\(\(\ \)\(2\)\)\)]],
  "  and use line 3 in the Table 9.1 to obtain \n\n\t\t",
  Cell[BoxData[
      \(x\_n\  = \ \(x[n]\  = \ \(b\^n\  = \ 1\/2\^n\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Solution 9.6 (c).  Writing  ",
  Cell[BoxData[
      \(X \((z)\)\  = \ z\/\(z\  - 1\/\(\(\ \)\(2\)\)\)\)]],
  "  we see that  ",
  Cell[BoxData[
      \(X \((z)\)\)]],
  "  has a simple pole at  ",
  Cell[BoxData[
      \(z\_0\  = \ 1\/\(\(\ \)\(2\)\)\)]],
  ".  Using the Corollary 9.1 for finding the inverse z-transform we obtain  \
\n\n\t\t",
  Cell[BoxData[
      RowBox[{\(x\_n\), " ", "=", " ", 
        RowBox[{\(x[n]\), " ", "=", "  ", 
          RowBox[{
            RowBox[{"Res", "[", 
              RowBox[{\(X \((z)\) z\^\(n - 1\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(z\_0\)}], "]"}], " ", "=", "  ",
             
            RowBox[{
              RowBox[{"Res", "[", 
                
                RowBox[{\(\(z\/\(z\  - 1\/\(\(\ \)\(2\)\)\)\) z\^\(n - 1\)\), 
                  
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(1\/\(\(\ \)\(2\)\)\)}], "]"}],
               " ", "=", "  ", 
              RowBox[{"Res", "[", 
                RowBox[{\(z\^n\/\(z\  - 1\/\(\(\ \)\(2\)\)\)\), 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(1\/\(\(\ \)\(2\)\)\)}], 
                "]"}]}]}]}]}]]],
  " \n\t\t\nUsing  the function  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ X \((z)\) z\^\(n - 1\)\)]],
  "  and value  ",
  Cell[BoxData[
      \(z\_0\  = \ 1\/\(\(\ \)\(2\)\)\)]],
  "  in Corollary 9.2 we get  \n\t\t\n\t\t",
  Cell[BoxData[
      \(x\_n\  = \ \(x[
            n]\  = \ \ \(lim\+\(z\  \[Rule] \ z\_0\)\((z - z\_0)\) 
                f \((z)\)\  = \ \ \(lim\+\(z\  \[Rule] 1\/\(\(\ \
\)\(2\)\)\)\((z - 1\/\(\(\ \)\(2\)\))\) 
                  z\^n\/\(z\  - 1\/\(\(\ \)\(2\)\)\)\  = \ \(lim\+\(z\  \
\[Rule] 1\/\(\(\ \)\(2\)\)\)\ z\^n\  = \ 1\/2\^n\)\)\)\)\)]],
  ".   "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(X[z_]\  = \ \(2  z\)\/\(2  z - 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(S[z_] = 
        Series[X[z], {z, \[Infinity], 9}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   X[z] = \>", S[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The sequence is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \
\>\"", Append[
          CoefficientList[Normal[S[z]], 
            1\/z], "\<...\>"]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{x[n]\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \>\"", 
        Append[CoefficientList[Normal[S[z]], 
            1\/z], "\<...\>"]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Z\_0 = 1\/\(\(\ \)\(2\)\);\)\), "\[IndentingNewLine]", 
    \(\(Clear[f];\)\), "\[IndentingNewLine]", 
    \(\(f[z_] = \(z\^\(n - 1\)\) X[z];\)\), "\[IndentingNewLine]", 
    \(\(lim\  = \ 
        Limit[\ \((z - Z\_0)\) f[z], 
          z \[Rule] Z\_0\ ];\)\), "\[IndentingNewLine]", 
    \(\(s[n_] = lim;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<     X[z] = \>", X[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<     f[z] = \>", f[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<       \!\(z\_0\) = \>\"", 
        Z\_0\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[f,\!\(z\_0\)] = \>\"", \
"\<lim\>"\_\*"\"\<z\[Rule]\!\(z\_0\)\>\"", \*"\"\< \
(z-\!\(z\_0\))f[z]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", 
        Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), "\< \
(z-\>", Z\_0, "\<)f[z]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", 
        Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), "\< \
(z-\>", Z\_0, "\<)\>", f[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", 
        Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), "\< \
\>", \((z - Z\_0)\) f[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", 
        Z\_0, "\<] = \>", "\<lim\>"\_"\<z\[Rule]\>", "\<\>"\_\(Z\_0\), "\< \
\>", Simplify[\((z - Z\_0)\) f[z]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Res[f,\>", Z\_0, "\<] = \>", 
        lim\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The sequence is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<      \!\(x\_n\) = Res[f,\>\"", Z\_0, "\<] = \>", 
        lim\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \
\>\"", Append[
          Table[s[n], {n, 0, 
              9}], "\<...\>"]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{x[n]\!\(\(}\_\(n = 0\)\%\[Infinity]\)\) = \>\"", 
        Append[Table[s[n], {n, 0, 9}], "\<...\>"]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell["\<\
\tThe following two theorems about z-transforms are useful in finding the \
solution to a difference equation.  \
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 9.4 (Shifted Sequences & Initial Conditions)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Define the sequence ",
  Cell[BoxData[
      \({x[n] = x\_n}\_\(n = 0\)\%\[Infinity]\)]],
  " and let  ",
  Cell[BoxData[
      \(X \((z)\) = \(\[GothicCapitalZ][
            x[n]] = \(\[GothicCapitalZ][
              x\_n] = \[Sum]\+\(n = 0\)\%\[Infinity] x\_n\ z\^\(-n\)\)\)\)]],
  "  be its z-transform.  Then \n\n\t",
  StyleBox["(i)  \t",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][
          x[n + 1]]\ \  = \ \ \(\[GothicCapitalZ][
            x\_\(n + 1\)]\ \  = \ \ z\ \((X \((z)\)\  - \ x\_0)\)\)\)]],
  "  \n\n\t",
  StyleBox["(ii) \t",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][
          x[n + 2]]\ \  = \ \ \(\[GothicCapitalZ][
            x\_\(n + 2\)]\ \  = \ \ z\^2\ \((X \((z)\)\  - \ 
                x\_0\  - \ \(x\_1\) z\^\(-1\))\)\)\)]],
  "   \n\n\t",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][
          x[n + 3]]\ \  = \ \ \(\[GothicCapitalZ][
            x\_\(n + 3\)]\ \  = \ \ z\^3\ \((X \((z)\)\  - \ 
                x\_0\  - \ \(x\_1\) z\^\(-1\)\  - \ \(x\_2\) 
                  z\^\(-2\))\)\)\)]],
  "   "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 9.5 (Convolution)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \({x\_n}\_\(n = 0\)\%\[Infinity]\)]],
  "  and  ",
  Cell[BoxData[
      \({y\_n}\_\(n = 0\)\%\[Infinity]\)]],
  "  be sequences with z-transforms  ",
  Cell[BoxData[
      RowBox[{"X", \((z)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "Y", \((z)\)}]]],
  ", respectively.  Then  \n\n\t\t\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][x\_n*y\_n]\  = \ \ X \((z)\) Y \((z)\)\)]],
  "  \n\t\t\nwhere the operation  ",
  Cell[BoxData[
      \(x\_n*y\_n\)]],
  "  is defined as the convolution sum  ",
  Cell[BoxData[
      \(\[Sum]\+\(i = 0\)\%n\( x\_i\) y\_\(n - i\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 9.5 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["9.1.4  Properties of the z-transform",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe following properties of z-transforms listed in Table 9.2 are \
well known in the field of digital signal analysis.  The reader will be asked \
to prove some of these properties in the exercises.  \n\t\n\t\t\t",
  Cell[BoxData[GridBox[{
          {" ", " ", 
            StyleBox["Sequence",
              FontWeight->"Bold"], 
            StyleBox[\(z - transform\),
              FontWeight->"Bold"]},
          {
            " ", \(\(definition\)\(\ \)\), \(x\_n = 
              x[n]\), \(X \((z)\)\  = \ \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                      x\_n\) z\^\(-n\)\)},
          {"1", "addition", \(x\_n + y\_n\), \(X \((z)\) + Y \((z)\)\)},
          {"2", \(constant\ multiple\), \(c\ x\_n\), \(c\ X \((z)\)\)},
          {
            "3", \(\(\ \)\(linearity\)\), \(c\ x\_n + 
              d\ y\_n\), \(c\ X \((z)\) + d\ Y \((z)\)\)},
          {
            "4", \(delayed\ unit\ step\), \(u[
              n - m]\), \(z\^\(1 - m\)\/\(z - 1\)\)},
          {
            "5", \(time\ delay\ 1\ tap\), \(\(x\_\(n - 1\)\) 
              u[n - 1]\), \(\(1\/z\) X \((z)\)\)},
          {
            "6", \(time\ delayed\ shift\), \(\(x\_\(n - m\)\) 
              u[n - m]\), \(\(z\^\(-m\)\) X \((z)\)\)},
          {
            "7", \(forward\ 1\ tap\), \(x\_\(n + 
                  1\)\), \(z\ \((X \((z)\)\  - \ x\_0)\)\)},
          {
            "8", \(forward\ 2\ taps\), \(x\_\(n + 
                  2\)\), \(z\^2\ \((X \((z)\)\  - \ 
                  x\_0\  - \ \(x\_1\) z\^\(-1\))\)\)},
          {
            "9", \(\(\ \)\(time\ forward\)\), \(x\_\(n + 
                  m\)\), \(\(z\^m\) \((X \((z)\) - \[Sum]\+\(i = 0\)\%\(m - 1\
\)\(x\_i\) z\^\(-i\))\)\)},
          {
            "10", \(\(\ \)\(complex\ translation\)\), \
\(\(\[ExponentialE]\^\(a\ n\)\) 
              x\_n\), \(X \((z\ \[ExponentialE]\^\(-a\))\)\)},
          {"11", \(frequency\ scale\), \(b\^n\ x\_n\), \(X \((z\/b)\)\)},
          {
            "12", \(\(differentiation\)\(\ \)\), \(n\ x\_n\), \(\(-\ 
                z\)\ X' \((z)\)\)},
          {"13", 
            "integration", \(\(1\/n\) 
              x\_n\), \(-\(\[Integral]\(\(X \((z)\)\)\/z\) \
\[DifferentialD]z\)\)},
          {
            "14", \(integration\ shift\), \(\(1\/\(n + m\)\) 
              x\_n\), \(\(-\ 
                z\^\(-m\)\) \(\[Integral]\(\(X \((z)\)\)\/z\^\(m + 1\)\) \
\[DifferentialD]z\)\)},
          {
            "15", \(\(discrete\)\(\ \)\(time\)\(\ \)\(convolution\)\(\ \)\), \
\(x\_n*y\_n = \[Sum]\+\(i = 0\)\%n\( x\_i\) y\_\(n - i\)\), \(X \((z)\) 
              Y \((z)\)\)},
          {
            "16", \(\(\ \)\(convolution\ with\ \ y\_n \[Equal] 
              1\)\), \(\[Sum]\+\(i = 0\)\%n x\_i\), \(z\/\(z - 1\)\ X \((z)\)\
\)},
          {
            "17", \(\(\ \)\(initial\ time\)\), \(x\_0\), \(lim\+\(z \[Rule] \
\[Infinity]\)\ X \((z)\)\)},
          {
            "18", \(\(final\)\(\ \)\(value\)\(\ \)\), \(lim\+\(n \[Rule] \
\[Infinity]\)\ x\_n\), \(lim\+\(z \[Rule] 1\)\ \((z - 1)\) X \((z)\)\)}
          },
        GridFrame->True,
        RowLines->True,
        ColumnLines->True]]],
  "  \n\t\n\t\t\t",
  StyleBox["Table 9.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Some properties of the z-transform. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Print["\<Differentiation property\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<        X(z) = \[GothicCapitalZ][{\!\(a\^n\)}] = \>\"", 
        ZTransform[a\^n, n, z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<       X'(z) = \>", \[PartialD]\_z\ 
          ZTransform[a\^n, n, z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<    -z X'(z) = \>", \(-z\)\ Together[\[PartialD]\_z\ 
              ZTransform[a\^n, n, z]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<    -z X'(z) = \>", \ 
        Simplify[\(-z\)\ \[PartialD]\_z\ 
              ZTransform[a\^n, n, z]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \[GothicCapitalZ][n \!\(a\^n\)] = \>\"", 
        ZTransform[n\ a\^n, n, z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \[GothicCapitalZ][n \!\(a\^n\)] = -z X'(z) ?\>\""\ \
];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ZTransform[n\ a\^n, n, z]\  \[Equal] \ 
          Simplify[\(-z\)\ \[PartialD]\_z\ 
                ZTransform[a\^n, n, z]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[b];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Frequency scale\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<X(z) = \[GothicCapitalZ][{n}] = \>", 
        ZTransform[n, n, z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Replace  z \[Rule] \!\(z\/b\)\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<         X(\!\(z\/b\)) = \>\"", 
        ReplaceAll[ZTransform[n\ , n, z], 
          z \[Rule] z\/b]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<         X(\!\(z\/b\)) = \>\"", 
        Together[
          ReplaceAll[ZTransform[n\ , n, z], 
            z \[Rule] z\/b]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \[GothicCapitalZ][{\!\(b\^n\) n}] = \>\"", 
        ZTransform[b\^n\ n, n, z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \[GothicCapitalZ][{\!\(b\^n\) n}] = X(\!\(z\/b\)) ?\
\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ZTransform[b\^n\ n, n, z] \[Equal] 
          Together[
            ReplaceAll[ZTransform[n\ , n, z], 
              z \[Rule] z\/b]]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given   ",
  Cell[BoxData[
      \(w\_n\  = \ \(x[n]\  = \ n + 1\)\)]],
  ".   Use convolution to show that the z-transform is  ",
  Cell[BoxData[
      \(W \((z)\)\  = \ z\^2\/\((z\  - \ 1)\)\^2\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Solution 9.7.\n\n\tLet both  ",
  Cell[BoxData[
      RowBox[{\(x\_n\), "=", 
        RowBox[{
          RowBox[{"1", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(y\_n\)}], "=", "1"}]}]]],
  "  be the unit step sequence, and both  ",
  Cell[BoxData[
      \(X \((z)\) = z\/\((z - 1)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(Y \((z)\) = z\/\((z - 1)\)\)]],
  ".  Then  \n\t\n\t\t\t",
  Cell[BoxData[
      \(W \((z)\)\  = \ \(X \((z)\) 
            Y \((z)\)\  = \ \ \(\(z\/\((z - 1)\)\) 
              z\/\((z - 1)\)\ \  = \ \ \ z\^2\/\((z\  - \ 1)\)\^2\)\)\)]],
  ",  \n\nso that  ",
  Cell[BoxData[
      \(w\_n\)]],
  "  is given by the convolution  \n\n\t\t\t",
  Cell[BoxData[
      \(w\_n\ \  = \ \ \(x\_n*
            y\_n\ \  = \ \ \(\[Sum]\+\(i = 0\)\%n\( x\_i\) 
                y\_\(n - i\)\ \  = \ \ \(\[Sum]\+\(i = 0\)\%n\ 1\  = \ 
              n + 1\)\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["9.1.5  Application to signal processing",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tDigital signal processing often involves the design of finite \
impulse response (FIR) filters.  A simple 3-point FIR filter can be described \
as\n\t\n",
  StyleBox["(9-4)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(y[n]\ \  = \ \ x[n]\  + \ a\ x[n - 1]\  + \ b\ x[n - 2]\)]],
  ".  \n\nHere, we choose real coefficients ",
  Cell[BoxData[
      RowBox[{"a", " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "b"}]]],
  " so that the homogeneous difference equation  \n\n",
  StyleBox["(9-5)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(x[n]\  + \ a\ x[n - 1]\  + \ b\ x[n - 2]\ \  = \ \ 0\)]],
  "  \n\nhas solutions  ",
  Cell[BoxData[
      RowBox[{\(x[n]\), "=", 
        RowBox[{
          RowBox[{"cos", \((\[Omega]\ \[Pi]\ n)\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(x[n]\)}], 
          "=", \(sin \((\[Omega]\ \[Pi]\ n)\)\)}]}]]],
  ".  That is, if the linear combination  ",
  Cell[BoxData[
      \(x[n] = \(c\_1\) cos \((\[Omega]\ \[Pi]\ n)\) + 
          c\_2\ sin \((\[Omega]\ \[Pi]\ n)\)\)]],
  "  is input on the right side of the FIR filter equation, the output ",
  Cell[BoxData[
      \(y[n]\)]],
  " on the left side of the equation will be zero.  "
}], "Text"],

Cell[TextData[{
  "\tApplying the time delay property to the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transforms of each term in ",
  StyleBox["(9-4)",
    FontColor->RGBColor[0, 0, 1]],
  ", we obtain  ",
  Cell[BoxData[
      \(X \((z)\)\  + \ 
          a\ X \((z)\) z\^\(-1\)\  + \ \ b\ X \((z)\) z\^\(-2\)\  = \ 
        Y \((z)\)\)]],
  ".  Factoring, we get \n\n",
  StyleBox["(9-6)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(X \((z)\) \((1 + a\ z\^\(-1\) + b\ z\^\(-2\))\)\ \  = \ \ X \((z)\) 
          H \((z)\)\)]],
  ",  where \n\n",
  StyleBox["(9-7)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(H \((z)\)\ \  = \ \ 1 + a\ z\^\(-1\) + b\ z\^\(-2\)\)]],
  " \n\nrepresents the filter transfer function.  Now, in order for the \
filter to suppress the inputs ",
  Cell[BoxData[
      RowBox[{"cos", \((\[Omega]\ \[Pi]\ n)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", 
        "sin", \((\[Omega]\ \[Pi]\ n)\)}]]],
  ", we must have \n\n\t\t\t",
  Cell[BoxData[
      \(1 + a\ z\^\(-1\) + 
          b\ z\^\(-2\)\  = \ \(\((1 - \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Omega]\ \[Pi]\)\ z\^\(-1\))\) \((1 - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\[Omega]\ \[Pi]\)\ z\^\(-1\))\)\  = \ \(z\^\(-2\)\) \((z - \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ \[Pi]\))\) \((z - \[ExponentialE]\
\^\(\(-\[ImaginaryI]\)\ \[Omega]\ \[Pi]\))\)\)\)]],
  "  \n\nand an easy calculation reveals that  \n\n\t\t\t",
  Cell[BoxData[
      \(a\  = \ \(\(-\((\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ \[Pi]\) \
+ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ \[Pi]\))\)\)\  = \ \(-2\) 
            Cos[\[Omega]\ \[Pi]]\)\)]],
  ",   and \n\n\t\t\t",
  Cell[BoxData[
      \(b\  = \ \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ \[Pi]\)\) \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ \[Pi]\)\  = \ 1\)\)]],
  ". \n\nA complete discussion of this process is given in Section 9.3 of \
this chapter. "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 9.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox["(FIR filter design)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  StyleBox["Use residues to find the inverse",
    FontFamily->"Times New Roman"],
  " ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-",
  StyleBox["transform   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x[n]\)]],
  " ",
  StyleBox["  of   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(X \((z)\)\  = \ \(1\/\(1 - \(\@2\) z\^\(-1\) + z\^\(-2\)\)\  = 
          1\/\(\((1 - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\ z\^\(-1\))\
\) \((1 - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\)\ \
z\^\(-1\))\)\)\)\)]],
  StyleBox[".  \nThen, write down the FIR filter equation that suppresses ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x[n]\)]],
  ".",
  StyleBox["  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Writing  ",
  Cell[BoxData[
      \(X \((z)\)\  = \ 
        z\^2\/\(\((z - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\))\) \((z - \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\))\)\)\)]],
  "  we see that  ",
  Cell[BoxData[
      \(X \((z)\)\)]],
  "  has simple poles at  ",
  Cell[BoxData[
      \(z\_1\  = \ \(\[ExponentialE]\^\(\[ImaginaryI]\ \
\[Pi]/4\)\ \ and\ \ z\_2\  = \ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\
\)\)\)]],
  ".  Using the Corollaries 9.1 and 9.2 we compute the residues    \n\n\t\t\t\
",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"Res", "[", 
            RowBox[{\(X \((z)\) z\^\(n - 1\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(z\_1\)}], "]"}], " ", "=", "  ", 
          RowBox[{"Res", "[", 
            
            RowBox[{\(z\^\(n + 1\)\/\(\((z - \[ExponentialE]\^\(\[ImaginaryI]\
\ \[Pi]/4\))\) \((z - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\))\)\)\),
               
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                
                "StrikeThrough"->
                  False}], \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\)}], 
            "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{\(\(=\)\(\ \ \)\(lim\+\(z\  \[Rule] \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Pi]/4\)\)z\^\(n + 1\)\/\(z - \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ \[Pi]/4\)\)\  = \ \(1\/\(\[ExponentialE]\^\(\[ImaginaryI]\ \
\[Pi]/4\) - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\)\)\) \((\
\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\))\)\^\(n + 1\)\)\), 
        "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", \(\(=\)\(\ \)\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \
\[Pi]/4\)\/\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\) - \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\)\)\) \((\[ExponentialE]\^\(\
\[ImaginaryI]\ \[Pi]/4\))\)\^n\  = \ \((1\/2 - \[ImaginaryI]\/2)\) \
\[ExponentialE]\^\(\[ImaginaryI]\ n\ \[Pi]/4\)\)\)}]],
  " "
}], "Text"],

Cell[TextData[{
  "The residue at the pole  ",
  Cell[BoxData[
      \(z\_2\  = \ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\)\)]],
  "  is computed similarly.\n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"Res", "[", 
            RowBox[{\(X \((z)\) z\^\(n - 1\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(z\_2\)}], "]"}], " ", "=", "  ", 
          RowBox[{"Res", "[", 
            
            RowBox[{\(z\^\(n + 1\)\/\(\((z - \[ExponentialE]\^\(\[ImaginaryI]\
\ \[Pi]/4\))\) \((z - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\))\)\)\),
               
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                
                "StrikeThrough"->
                  False}], \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/
                      4\)\)}], "]"}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{\(\(=\)\(\ \ \)\(lim\+\(z\  \[Rule] \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ \[Pi]/4\)\)z\^\(n + 1\)\/\(z - \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Pi]/4\)\)\  = \ \(1\/\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\
\ \[Pi]/4\) - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\)\) \((\
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\))\)\^\(n + 1\)\)\), 
        "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", \(\(=\)\(\ \)\(\(\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ \[Pi]/4\)\/\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\[Pi]/4\) - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\)\) \
\((\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\))\)\^n\  = \ \((1\/2 + \
\[ImaginaryI]\/2)\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ n\ \
\[Pi]/4\)\)\)}]],
  " "
}], "Text"],

Cell[TextData[{
  "Therefore, the sequence  ",
  Cell[BoxData[
      \(x[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[X \((z)\)]\)]],
  "  is \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(x[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[
            z\^2\/\(\((z - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\))\) \
\((z - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\))\)\)]\), 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"           ", 
        RowBox[{"=", " ", 
          RowBox[{
            RowBox[{"Res", "[", 
              RowBox[{\(X \((z)\) z\^\(n - 1\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(z\_1\)}], "]"}], " ", "+", " ", 
            
            RowBox[{"Res", "[", 
              RowBox[{\(X \((z)\) z\^\(n - 1\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(z\_2\)}], "]"}]}]}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "           ", \(\(=\)\(\ \)\(\((1\/2 - \[ImaginaryI]\/2)\) \
\[ExponentialE]\^\(\[ImaginaryI]\ n\ \[Pi]/4\) + \((1\/2 + \
\[ImaginaryI]\/2)\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ n\ \[Pi]/4\)\)\), 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "           ", \(\(=\)\(\ \)\(cos \((\(\[Pi]\/4\) n)\)\  + \ 
            sin \((\(\[Pi]\/4\) n)\)\)\)}]}]],
  "  "
}], "Text"],

Cell[TextData[{
  "The following complex calculation can be used to find the coefficients of \
the FIR filter equation\n\n\t\t",
  Cell[BoxData[{
      \(\(\(\((1 - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\ z\^\(-1\))\) \
\((1 - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\)\ z\^\(-1\))\) = \ 
        1 - \((\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\) + \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\))\) 
            z\^\(-1\) + \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\ \(\
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\)\) 
            z\^\(-2\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1 - \((\(1 + \
\[ImaginaryI]\)\/\@2 + \(1 - \[ImaginaryI]\)\/\@2)\) 
            z\^\(-1\) + \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\ \(\
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\)\) z\^\(-2\)\)\)\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1\  - \ \
\(\@2\) z\^\(-1\)\  + \ z\^\(-2\)\)\)\)}]],
  "\n\t\nHence the FIR filter equation is  ",
  Cell[BoxData[
      \(y[n]\  = \ K \((x[n]\  - \ \@2\ x[n - 1]\  + \ x[n - 2])\)\)]],
  "  where ",
  Cell[BoxData[
      \(K\)]],
  " is a constant gain factor.   \n\n",
  StyleBox["Remark 9.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We leave it as an exercises to substitute  ",
  Cell[BoxData[
      RowBox[{\(x[n]\), " ", "=", " ", 
        RowBox[{"cos", \((\(\[Pi]\/4\) n)\), "  ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", 
          "sin", \((\(\[Pi]\/4\) n)\)}]}]]],
  "  into the right hand side and verify that the output ",
  Cell[BoxData[
      \(y[n]\)]],
  " becomes identically zero.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(filter\  = \ 
        y[n]\  \[Equal] \ 
          x[n] - \@2\ x[n - 1] + x[n - 2];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The FIR filter is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = Cos[\(n\ \[Pi]\)\/4];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  x[n] = \>", x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-1] = \>", x[n - 1], "\< = \>", \ 
        TrigExpand[x[n - 1]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-2] = \>", x[n - 2], "\< = \>", \ 
        TrigExpand[x[n - 2]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute into the filter and get\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ Simplify[filter]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(filter\  = \ 
        y[n]\  \[Equal] \ 
          x[n] - \@2\ x[n - 1] + x[n - 2];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The FIR filter is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = Sin[\(n\ \[Pi]\)\/4];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  x[n] = \>", x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-1] = \>", x[n - 1], "\< = \>", \ 
        TrigExpand[x[n - 1]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-2] = \>", x[n - 2], "\< = \>", \ 
        TrigExpand[x[n - 2]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute into the filter and get\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ Simplify[filter]\ ];\)\)}], "Input"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can explore the effect of using the input sequences \n\n",
  Cell[BoxData[
      \(\(\(x[n] = \(Sin[\(\(m\ \[Pi]\)\/100\) n]\ \ \ for\ \ \ \ m\  = \ 
          10\)\)\(,\)\(18\)\(,\)\(22\)\(,\)\(23\)\(,\)\(24\)\(,\)\(25\)\(\ \)\
\)\)]],
  "\n\nand using the filter  ",
  Cell[BoxData[
      \(y[n]\  = \ x[n] - \@2\ x[n - 1] + x[n - 2]\)]],
  " to compute the output sequence. \n\nWe expect that the signals become \
more attenuated as ",
  Cell[BoxData[
      \(\(m\ \[Pi]\)\/100 \[Rule] \[Pi]\/4\)]],
  ".  \n\nFor this illustration the sequences are defined for all integers n, \
but we will learn in the Section 9.3 that digital filters require that  ",
  Cell[BoxData[
      \(x\_n = \(x[n]\  = \ 0\)\)]],
  " for  ",
  Cell[BoxData[
      \(n < 0\)]],
  ".  "
}], "Text"],

Cell[BoxData[
    \(\(\(FilterIt\  := 
        Module[\ {}, \[IndentingNewLine]y[n_]\  = \ 
            x[n] - \@2\ x[n - 1] + x[n - 2]; \ \ \[IndentingNewLine]T = \ 
            N[Table[i, {i, 0, 21}]]; \[IndentingNewLine]X\  = \ 
            N[Table[x[i], {i, 0, 21}]]; \[IndentingNewLine]TX\  = \ 
            Transpose[{T, X}]; \[IndentingNewLine]g1 = 
            ListPlot[TX, PlotStyle \[Rule] {PointSize[0.02], Red}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Y\  = \ 
            N[Table[y[i], {i, 0, 21}]]; \[IndentingNewLine]TY\  = \ 
            Transpose[{T, Y}]; \[IndentingNewLine]g2 = 
            ListPlot[TY, PlotStyle \[Rule] {PointSize[0.02], Blue}, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[g1, 
            g2, PlotRange \[Rule] {{0, 22}, {\(-1\), 1}}, 
            Ticks \[Rule] {Range[0, 20, 5], Range[\(-1\), 1, 0.25]}, 
            DisplayFunction \[Rule] $DisplayFunction]; \
\[IndentingNewLine]Print["\<Red   x[n] = \>", 
            x[n]\ \ ]; \[IndentingNewLine]Print[\*"\"\<      y[n] = x[n]-\!\(\
\@2\) x[n-1]+x[n-2]\>\""\ \ ]; \[IndentingNewLine]Print["\<Blue  y[n] = \>", 
            y[n]\ \ ];\[IndentingNewLine]];\)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[BoxData[{
    \(\(x[n_] = Sin[\(\(10  \[Pi]\)\/100\) n];\)\), "\[IndentingNewLine]", 
    \(FilterIt\)}], "Input"],

Cell[BoxData[{
    \(\(x[n_] = Sin[\(\(18  \[Pi]\)\/100\) n];\)\), "\[IndentingNewLine]", 
    \(FilterIt\)}], "Input"],

Cell[BoxData[{
    \(\(x[n_] = Sin[\(\(22  \[Pi]\)\/100\) n];\)\), "\[IndentingNewLine]", 
    \(FilterIt\)}], "Input"],

Cell[BoxData[{
    \(\(x[n_] = Sin[\(\(23  \[Pi]\)\/100\) n];\)\), "\[IndentingNewLine]", 
    \(FilterIt\)}], "Input"],

Cell[BoxData[{
    \(\(x[n_] = Sin[\(\(24  \[Pi]\)\/100\) n];\)\), "\[IndentingNewLine]", 
    \(FilterIt\)}], "Input"],

Cell[BoxData[{
    \(\(x[n_] = Sin[\(\(25  \[Pi]\)\/100\) n];\)\), "\[IndentingNewLine]", 
    \(FilterIt\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["9.1.6  First Order Difference Equations",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\t",
    FontFamily->"Times New Roman"],
  "The solution of difference equations is analogous to the solution of \
differential equations.  ",
  StyleBox["Consider the first order homogeneous ",
    FontFamily->"Times New Roman"],
  "equation  ",
  StyleBox["\n\n\t\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 1]\ \  - \ \ a\ y[n]\ \  = \ \ 0\)]],
  " ",
  StyleBox["\n\nwhere ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(a\)]],
  " ",
  StyleBox["is a constant.  The following method is often used.\n\n",
    FontFamily->"Times New Roman"],
  StyleBox["Trial solution method.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\tUse the trial solution   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n] = c\_1\ r\^n\)]],
  ",   and substitute it into the above equation and get   ",
  Cell[BoxData[
      \(\(c\_1\) r\^\(n + 1\)\  - \ a\ \(c\_1\) r\^n\ \  = \ \ 0\)]],
  ".  Then divide through by ",
  Cell[BoxData[
      \(r\^n\)]],
  " \n\nand simplify to obtain  ",
  Cell[BoxData[
      \(r = a\)]],
  ".  The general solution to the difference equation is\n\n\t\t\t",
  Cell[BoxData[
      \(y[n]\  = \ c\_1\ a\^n\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman"],
  "Familiar models of difference equations are given in the table below.   \n\
\t\n\t\t\t",
  Cell[BoxData[GridBox[{
          {
            StyleBox["Model",
              FontWeight->"Bold"], 
            StyleBox[\(Difference\ Equation\),
              FontWeight->"Bold"], 
            StyleBox[\(S  olution\),
              FontWeight->"Bold"]},
          {
            RowBox[{"\[IndentingNewLine]", 
              RowBox[{
                StyleBox[\(Exponential\ growth\ or\ decay\),
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                "\[IndentingNewLine]"}]}], \(\(\[IndentingNewLine]\)\(\ \
\)\(\(y[n + 1]\  = \ \((1 + r)\)\ y[n]\)\(\ \)\(\[IndentingNewLine]\)
            \)\), \(\(\[IndentingNewLine]\)\(\ \)\(\(y[
                n]\  = \ \(y\_0\) \((1 + r)\)\^n\)\(\ \)\(\[IndentingNewLine]\
\)
            \)\)},
          {
            RowBox[{"\[IndentingNewLine]", 
              RowBox[{
                StyleBox[\(Newton' s\ law\ of\ cooling\),
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                "\[IndentingNewLine]"}]}], \(\(\[IndentingNewLine]\)\(\(y[
                n + 1] = a\ L + \((1 - a)\)\ y[n]\)\(\[IndentingNewLine]\)
            \)\), \(\(\[IndentingNewLine]\)\(\(y[
                n] = \(y\_0\) \((1 - a)\)\^n + 
                L \((1 - \((1 - a)\)\^n)\)\)\(\[IndentingNewLine]\)
            \)\)},
          {
            RowBox[{"\[IndentingNewLine]", 
              RowBox[{
                StyleBox[\(Repeated\ dosage\ drug\ level\),
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                "\[IndentingNewLine]"}]}], \(\(\[IndentingNewLine]\)\(\ \
\)\(\(y[n + 1]\  = \ a\ y[n] + b\)\(\ \)\(\[IndentingNewLine]\)
            \)\), \(\(\[IndentingNewLine]\)\(\ \)\(\(y[
                n]\  = \ \ y\_0\ a\^n\  + \(a\^n\  - \ 1\)\/\(a\  - \ 1\)\ \
b\)\(\ \)\(\[IndentingNewLine]\)
            \)\)},
          {
            RowBox[{"\[IndentingNewLine]", 
              StyleBox[\(Value\ of\ an\ annuity\ due\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}], 
            RowBox[{"\[IndentingNewLine]", 
              
              RowBox[{\(y[n + 1] = \((1 + r)\) \((\ y[n] + P)\)\), 
                "\[IndentingNewLine]", "           ", 
                RowBox[{
                  RowBox[{
                    StyleBox["where",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "  ", \(y[0]\)}], "=", 
                  "0"}]}]}], \(\(\[IndentingNewLine]\)\(\(y[
                n]\  = \ \ \(\(\(\ \)\(\((1 + r)\)\^\(1 + n\)\  - \ 
                        1\)\)\/r\) P\  - \ P\)\(\[IndentingNewLine]\)
            \)\)}
          },
        GridFrame->True,
        RowLines->True,
        ColumnLines->True]]],
  "   \n\n\t\t\t",
  StyleBox["Table 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Some examples of first order linear difference equations. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(i)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The exponential growth or decay model  \n\n\t",
  Cell[BoxData[
      \(y[n + 1]\  = \ \((1 + r)\)\ y[n]\)]],
  "    has the solution  \n\n\t",
  Cell[BoxData[
      \(y[n] \[Rule] \((1 + r)\)\^n\ y\_0\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]y = 0; \ Remove[y]; \ Clear[a, n, y];\ \), "\n", 
    \(\(DE\  = \ 
        y[n + 1]\  \[Equal] \ \((1 + r)\)\ y[
              n];\)\ \), "\[IndentingNewLine]", 
    \(\(IC = y[0] \[Equal] y\_0;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<DiscreteMath`RSolve`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(sol\  = \ RSolve[{DE, IC}, y[n], n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the difference equation\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\ DE\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<With the initial condition\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\ IC\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", \ 
        sol\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\[RightDoubleBracket]\)\)\
\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["(ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Newton's law of heating and cooling model  \n\n\t",
  Cell[BoxData[
      \(y[n + 1]\  = \ a\ L + \((1 - a)\)\ y[n]\)]],
  "    has the solution  \n\n\t",
  Cell[BoxData[
      \(y[n]\  = \ \(y\_0\) \((1 - a)\)\^n\  + 
          L \((1 - \((1 - a)\)\^n)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(y = 0; \ Remove[y]; \ Clear[a, n, y];\ \), "\n", 
    \(\(DE\  = \ 
        y[n + 1]\  \[Equal] \ 
          a\ L + \((1 - a)\)\ y[n];\)\ \), "\[IndentingNewLine]", 
    \(\(IC = y[0] \[Equal] y\_0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<DiscreteMath`RSolve`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(sol\  = \ RSolve[{DE, IC}, y[n], n];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the difference equation\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\ DE\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<With the initial condition\>"];\)\ \ \), \
"\[IndentingNewLine]", 
    \(\(Print[\ IC\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", \ 
        sol\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\[RightDoubleBracket]\)\)\
\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", \ \ FullSimplify[
          sol\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\[RightDoubleBracket]\)\
\)\ ]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["(iii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The repeated dosage drug level model  \n\n\t",
  Cell[BoxData[
      \(y[n + 1]\  = \ a\ y[n] + b\)]],
  "    has the solution  \n\n\t",
  Cell[BoxData[
      \(y[n]\  = \ y\_0\ a\^n\  + \(1\/\(a - 1\)\) \((a\^n - 1)\)\ b\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(y = 0; \ Remove[y]; \ Clear[a, b, n, y];\ \), "\n", 
    \(\(DE\  = \ 
        y[n + 1]\  \[Equal] \ a\ y[n] + b;\)\), "\[IndentingNewLine]", 
    \(\(IC = y[0] \[Equal] y\_0;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<DiscreteMath`RSolve`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(sol\  = \ RSolve[{DE, IC}, y[n], n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the difference equation\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\ DE\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<With the initial condition\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\ IC\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", \ 
        sol\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\[RightDoubleBracket]\)\)\
\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", \ 
        Collect[sol\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\), y\_0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["(iv)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The value of an annuity due is the future value of all payments.  It is \
the sum of the compounded amounts for all payments.   It is given by the \
formula  \n\n\t",
  Cell[BoxData[
      \(y[
          n]\  = \ \(P\ \((1 + r)\) + P\ \((1 + r)\)\^2 + 
              P\ \((1 + r)\)\^3 +  ... \) + P\ \((1 + r)\)\^\(n - 1\) + 
          P\ \((1 + r)\)\^n\)]],
  "  \n\t\n\t",
  Cell[BoxData[
      \(y[n]\  = \ \(P\ \((\((1 + r)\)\^\(1 + n\) - 1)\)\)\/r - P\)]],
  " "
}], "Text"],

Cell["We can sum the series directly and get", "Text"],

Cell[BoxData[{
    \(\(sol = \[Sum]\+\(k = 1\)\%n 
            P \((1 + r)\)\^k;\)\ \), "\[IndentingNewLine]", 
    \(\(sol = MapAll[FullSimplify, sol];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = \!\(\[Sum]\+\(k = 1\)\%n\) \
P(1+r\!\(\()\^k\)\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", sol\ ];\)\), "\[IndentingNewLine]", 
    \(\(sol = 
        MapAll[FullSimplify, Together[sol + P]] - 
          P;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", sol\ ];\)\)}], "Input"],

Cell[TextData[{
  "When written as a difference equation we have \n\t\n\t\t",
  Cell[BoxData[
      \(y[n + 1]\  = \ \(\((1 + r)\) \((\ y[n] + P)\)\ \ \ with\ \ \ y[0] = 
          0\)\)]],
  "  \n\t\tor\n\t\t",
  Cell[BoxData[
      \(y[
          n + 1]\  = \ \(\((1 + r)\)\ y[n] + \((1 + r)\) 
              P\ \ \ with\ \ \ y[0] = 0\)\)]],
  "  \n\nThis is a special case of the repeated dosage drug level model with  \
",
  Cell[BoxData[
      \(y\_0 = 0, a \[Rule] 1 + r, \ and\ \ \ b \[Rule] \((1 + r)\) P\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[{
      \(y[
          n]\ \  = \ \ y\_0\ a\^n\ \  + \ \(1\/\(a - 1\)\) \((a\^n - 
                1)\)\ b\n\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(0\ a\^n\ \  + \ \(1\/\(1 + r - 
                  1\)\) \((\((1 + r)\)\^n - 1)\)\ \((1 + r)\) 
            P\)\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(1\/r\) \((\((1 + r)\)\^n - 
              1)\)\ \((1 + r)\) P\)\)\n\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(1\/r\) \((\(\((1 + 
                        r)\)\^n\) \((1 + r)\) P - \((1 + r)\) 
                P)\)\)\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(1\/r\) \((\(\((1 + 
                        r)\)\^\(n + 1\)\) P - P - r\ P)\)\)\)\n\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(1\/r\) \((\(\((1 + 
                        r)\)\^\(n + 1\)\) P - P - 
              r\ P)\)\)\)\[IndentingNewLine]\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(1\/r\) 
            P \((\((1 + r)\)\^\(n + 1\) - 1)\)\  - \ \(1\/r\) r\ P\)\)\n\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(P \((\((1 + r)\)\^\(n + 1\) \
- 1)\)\)\/r\  - \ \ P\)\)\)}]],
  "  "
}], "Text"],

Cell[BoxData[{
    \(\(sol\  = \ 
        ReplaceAll[\(y\_0\) 
              a\^n\  + \(1\/\(a - 1\)\) \((a\^n - 1)\)\ b, {y\_0 \[Rule] 0, 
            a \[Rule] 1 + r, 
            b \[Rule] \((1 + r)\) P}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", sol\ ];\)\), "\[IndentingNewLine]", 
    \(\(sol = 
        MapAll[FullSimplify, Together[sol + P]] - 
          P;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", sol\ ];\)\)}], "Input"],

Cell[TextData[{
  "And ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can solve the difference equation."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[y];\)\), "\[IndentingNewLine]", 
    \(\(DEeqn = 
        y[n + 1] \[Equal] \((1 + r)\)\ y[n] + \((1 + r)\) 
              P;\)\ \), "\[IndentingNewLine]", 
    \(\(IC = y[0] \[Equal] 0;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<DiscreteMath`RSolve`\>"];\)\), "\n", 
    \(\(solset = 
        RSolve[{DEeqn, y[0] \[Equal] 0}, y[n], 
          n];\)\ \), "\[IndentingNewLine]", 
    \(\(sol = 
        MapAll[FullSimplify, 
            Together[
              solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\) + P]] - P;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the difference equation\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\ DEeqn\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ IC\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1\)\(\[RightDoubleBracket]\)\)\
\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", sol\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["9.1.7  Methods for Solving First Order Difference Equations",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\t",
  StyleBox["Consider the first order linear constant coefficient difference \
equation",
    FontFamily->"Times New Roman"],
  " (LCCDE)  \n\n\t\t\t",
  Cell[BoxData[
      \(y[n + 1]\ \  - \ \ a\ y[n]\ \  = \ \ x[n]\)]],
  "  with the initial condition   ",
  Cell[BoxData[
      \(y[0] = \ y\_0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Trial solution method.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tFirst, solve the homogeneous equation   ",
  Cell[BoxData[
      \(y\_h[n + 1]\  - \ a\ y\_h[n]\  = \ 0\)]],
  "  and get   ",
  Cell[BoxData[
      \(y\_h[n] = \ \(c\_1\) a\^n\)]],
  ".   Then use a trial solution that is appropriate for the sequence ",
  Cell[BoxData[
      \(x[n]\)]],
  " on the right side of the equation and solve to obtain a particular \
solution  ",
  Cell[BoxData[
      \(y\_p[n]\)]],
  ".   Then the general solution is  \n\t\t\n\t\t\t",
  Cell[BoxData[
      \(y[n]\ \  = \ \ y\_h[n]\ \  + \ \ y\_p[n]\)]],
  ". \n\nThe shortcoming of this method is that an extensive list of \
appropriate trial solutions must be available.  Details can be found in \
difference equations textbooks.  We will emphasize techniques that use the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transform.  "
}], "Text"],

Cell[TextData[{
  StyleBox["z-transform method.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n",
  StyleBox["(i)",
    FontColor->RGBColor[0, 0, 1]],
  "\tUse the time forward property  ",
  Cell[BoxData[
      \(\[GothicCapitalZ][y[n + 1]]\  = \ z\ \((Y \((z)\) - y\_0)\)\)]],
  "  and take the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transform of each term and get\n\n\t\t\t",
  Cell[BoxData[
      \(z\ \((Y \((z)\) - 
                y\_0)\)\ \  - \ \ a\ Y \((z)\)\ \  = \ \ X \((z)\)\)]],
  "\n\t\n",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  "\tSolve the equation in (i) for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  ". \n\n",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  "\tUse partial fractions to expand  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  "  in a sum of terms, and look up the inverse ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transform(s) using Table 1, to get \n\n\t\t\t",
  Cell[BoxData[
      \(y[n]\ \  = \ \ \(\[GothicCapitalZ]\^\(-1\)\)[Y \((z)\)]\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Residue method.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tPerform steps (i) and (ii) of the above ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transform method.  Then find the solution using the formula \n\n",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      RowBox[{\(y[n]\), "  ", "=", "  ", 
        RowBox[{\(\(\[GothicCapitalZ]\^\(-1\)\)[Y \((z)\)]\), "  ", "=", 
          "   ", 
          RowBox[{\(\[Sum]\+\(i = 1\)\%k\), 
            RowBox[{"Res", "[", 
              RowBox[{\(Y \((z)\) z\^\(n - 1\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(z\_i\)}], "]"}]}]}]}]]],
  ".  \n\nwhere  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_k\)}]]],
  "  are the poles of   ",
  Cell[BoxData[
      \(f \((z)\)\  = \ Y \((z)\) z\^\(n - 1\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Convolution method.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n",
  StyleBox["(i)",
    FontColor->RGBColor[0, 0, 1]],
  "\tSolve the homogeneous equation   ",
  Cell[BoxData[
      \(y\_h[n + 1]\  - \ a\ y\_h[n]\  = \ 0\)]],
  "   and get   ",
  Cell[BoxData[
      \(y\_h[n] = \ \(c\_1\) a\^n\)]],
  ".  \n\n",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  "\tUse the transfer function   ",
  Cell[BoxData[
      \(H \((z)\)\  = \ 1\/\(1\  - \ a\ z\^\(-1\)\)\)]],
  "  \n\n\tand construct the unit-sample response   ",
  Cell[BoxData[
      \(h[n]\  = \ \(\(\[GothicCapitalZ]\^\(-1\)\)[H \((z)\)]\  = \ 
          a\^n\)\)]],
  ". \n\n",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  "\tConstruct the particular solution   ",
  Cell[BoxData[
      \(y\_p[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[X \((z)\) H \((z)\)]\)]],
  ",    \n\n\tin convolution form   ",
  Cell[BoxData[
      \(y\_p[
          n]\  = \ \(\[Sum]\+\(i = 0\)\%n\ 
            x[n - i] h[i]\  = \ \[Sum]\+\(i = 0\)\%n\ x[n - i] a\^i\)\)]],
  ".  \n\n",
  StyleBox["(iv)",
    FontColor->RGBColor[0, 0, 1]],
  "\tThe general solution to the nonhomogeneous difference equation is  \n\n\t\
\t\t",
  Cell[BoxData[
      \(y[
          n]\ \  = \ \ \(y\_h[n]\  + \ 
            y\_p[n]\ \  = \ \ \(c\_1\) a\^n\ \  + \ \ \[Sum]\+\(i = 0\)\%n\ 
              x[n - i] a\^i\)\)]],
  ".\n\n ",
  StyleBox["(v) ",
    FontColor->RGBColor[0, 0, 1]],
  "\tThe constant  ",
  Cell[BoxData[
      \(c\_1\  = \ y\_0 - x[0]\)]],
  "  will produce the proper initial condition  ",
  Cell[BoxData[
      \(y[0] = \ y\_0\)]],
  ".  Therefore, \n \n \t\t\t",
  Cell[BoxData[
      \(y[
          n]\ \  = \ \ \((y\_0 - x[0])\) a\^n\ \  + \ \ \[Sum]\+\(i = 0\)\%n\ 
            x[n - i] a\^i\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 9.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The particular solution  ",
  Cell[BoxData[
      \(y\_p[n]\)]],
  "  obtained by using convolution has the initial condition  \n\n\t\t\t",
  Cell[BoxData[{
      \(y\_p[
          0]\ \  = \ \ \(\[Sum]\+\(i = 0\)\%0 x[0 - i] h[i]\ \  = \ \ x[0] 
            h[0]\)\ \ \[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(x[0]\)\)\)}]],
  "   "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 9.9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve the difference equation  ",
  Cell[BoxData[
      \(y[n + 1]\  - 2  y[n]\  = \ 3\^n\)]],
  "  with initial condition  ",
  Cell[BoxData[
      \(y[0] = 2\)]],
  ". \n",
  StyleBox["9 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transform and Tables 9.1 - 9.2 to find the solution. \n",
  StyleBox["9 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use residues to find the solution. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Solution 9.9 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Take the z-transform of both sides  \n\n\t\t\t",
  Cell[BoxData[
      \(z\ \((Y \((z)\)\  - \ 2)\)\  - \ 
          2\ Y \((z)\)\  = \ \(\(\ \)\(z\)\)\/\(z - 3\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  "  and get  ",
  Cell[BoxData[
      \(Y \((z)\) = \(2\ z\^2 - 5\ z\)\/\(\((z - 2)\)\ \((z - 3)\)\)\)]],
  ".  Then expand and obtain \n\n\t\t\t",
  Cell[BoxData[
      \(Y \((z)\)\  = \ 2\  + \ 2\/\(z - 2\)\  + \ 3\/\(z - 3\)\)]]
}], "Text"],

Cell[TextData[{
  "Find the inverse z-transform of each term \n\n\t\t\t",
  Cell[BoxData[{
      \(y[
          n]\ \  = \ \ \(\[GothicCapitalZ]\^\(-1\)\)[
            2]\ \  + \ \ \(\[GothicCapitalZ]\^\(-1\)\)[
            2\/\(z - 2\)]\ \  + \ \ \(\[GothicCapitalZ]\^\(-1\)\)[
            3\/\(z - 3\)]\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(2\ \[Delta][
              n]\ \  + \ \ 2\^n\ \[Delta][n - 1]\ \  + \ \ 3\^n\ \[Delta][
              n - 1]\)\)\)}]],
  "   \n\nWhen  ",
  Cell[BoxData[
      \(n = 0\)]],
  "  we get  ",
  Cell[BoxData[
      \(y[0]\  = \ \(2 + 0 + 0\  = \ 2\)\)]],
  ",  and when ",
  Cell[BoxData[
      \(n \[GreaterEqual] 1\)]],
  " the expression for ",
  Cell[BoxData[
      \(y[n]\)]],
  " simplifies to be \n\n\t\t\t",
  Cell[BoxData[
      \(y[n]\  = \ 2\^n + 3\^n\)]],
  " "
}], "Text"],

Cell[TextData[{
  StyleBox["Solution 9.9 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Start with the formula ",
  Cell[BoxData[
      \(Y \((z)\) = \(2\ z\^2 - 5\ z\)\/\(\((z - 2)\)\ \((z - 3)\)\)\)]],
  "  in part (a).  Then use the Corollaries 9.1 and 9.2 and residues to find  \
",
  Cell[BoxData[
      \(\(\[GothicCapitalZ]\^\(-1\)\)[Y \((z)\)]\)]],
  ".  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(y[n]\), "  ", "=", "  ", 
          
          RowBox[{\(\(\[GothicCapitalZ]\^\(-1\)\)[Y \((z)\)]\), " ", "=", " ",
             
            RowBox[{
              RowBox[{"Res", "[", 
                RowBox[{\(Y \((z)\) z\^\(n - 1\)\), 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "2"}], "]"}], " ", "+", " ", 
              RowBox[{"Res", "[", 
                RowBox[{\(Y \((z)\) z\^\(n - 1\)\), 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "3"}], "]"}]}]}]}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"           ", 
        RowBox[{"=", "  ", 
          RowBox[{
            RowBox[{"Res", "[", 
              
              RowBox[{\(\(\(2\ z\^2 - 5\ z\)\/\(\((z - 2)\)\ \((z - 3)\)\)\) 
                  z\^\(n - 1\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "2"}], "]"}], " ", "+", " ", 
            RowBox[{"Res", "[", 
              
              RowBox[{\(\(\(2\ z\^2 - 5\ z\)\/\(\((z - 2)\)\ \((z - 3)\)\)\) 
                  z\^\(n - 1\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "3"}], "]"}]}]}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "           ", \(\(=\)\(\ \ \)\(lim\+\(z\  \[Rule] \ 2\)\((z - 
                    2)\) \(\(2\ z\^2 - 5\ z\)\/\(\((z - 2)\)\ \((z - 3)\)\)\) 
                z\^\(n - 1\)\ \  + \ \ lim\+\(z\  \[Rule] \ 3\)\((z - 
                    3)\) \(\(2\ z\^2 - 5\ z\)\/\(\((z - 2)\)\ \((z - 3)\)\)\) 
                z\^\(n - 1\)\)\), "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        "           ", \(\(=\)\(\ \ \)\(lim\+\(z\  \[Rule] \ 2\)\(\(2\ z\^2 - 
                      5\ z\)\/\(z - 3\)\) 
                z\^\(n - 1\)\ \  + \ \ lim\+\(z\  \[Rule] \ 3\)\(\(2\ z\^2 - 
                      5\ z\)\/\(z - 2\)\) z\^\(n - 1\)\)\), 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "           ", \(\(=\)\(\ \ \)\(\(\(-2\)\/\(\(\ \)\(-1\)\)\) 
              2\^\(n - 1\)\ \  + \ \ \(3\/1\) 3\^\(n - 1\)\)\), "  ", 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "           ", \(\(=\)\(\ \ \)\(\(2\^n\)\(\ \ \)\(+\)\(\ \ \)\(3\^n\)\
\(\ \ \ \)\)\)}]}]],
  "  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["9.9 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Use the z-transform and tables to find the solution. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[n, x, X, y, Y];\)\), "\[IndentingNewLine]", 
    \(\(y\_0\  = \ 2;\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = 3\^n;\)\), "\[IndentingNewLine]", 
    \(\(DE\  = \ 
        y[n + 1]\  - 2  y[n] \[Equal] \ x[n];\)\), "\[IndentingNewLine]", 
    \(\(IC\  = \ y[0] \[Equal] y\_0;\)\), "\[IndentingNewLine]", 
    \(\(X[z_] = \ ZTransform[x[n], n, z];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the difference equation\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\ DE\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<With initial condition\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_0\) = \>\"", \ 
        IC\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Here we have\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<X[z] = \[GothicCapitalZ][\!\(y\_n\)] = \
\[GothicCapitalZ][\>\"", x[n], "\<] = \>", 
        X[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Taking the z-transforms we have\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<z (Y[z] - \!\(y\_0\)) - 2 Y[z] = X[z]\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<z (Y[z] - (\>", y\_0, "\<)) - 2 Y[z] = \>", \ 
        X[z]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[Y];\)\), "\[IndentingNewLine]", 
    \(\(eqn = 
        z\ \((Y[z]\  - 2)\)\  - 2  Y[z] \[Equal] \ \ ZTransform[3\^n, n, 
            z];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ eqn\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve for Y[z]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Y[
          z_]\  = \(Solve[eqn, Y[z]]\)\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\
\(\[RightDoubleBracket]\)\);\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y[z] = \>", Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Y[z_]\  = Together[Y[z]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y[z] = \>", Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Y[z_]\  = Apart[Y[z]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y[z] = \>", Y[z]\ ];\)\)}], "Input"],

Cell["Find the inverse z-transformations.", "Text"],

Cell[BoxData[{
    \(\(y[n_]\  = \ 
        InverseZTransform[Y[z], z, n];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = \!\(\[GothicCapitalZ]\^\(-1\)\)[Y[z]] = \!\(\
\[GothicCapitalZ]\^\(-1\)\)[\>\"", 
        Y[z], "\<]\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\)}], "Input"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We could investigate each of the terms. "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<     \>", \*"\"\<\!\(\[GothicCapitalZ]\^\(-1\)\)[\>\"", 
        2, "\<] = \>", 
        InverseZTransform[2, z, n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[GothicCapitalZ]\^\(-1\)\)[\>\"", 
        3\/\(z - 3\), "\<] = \>", 
        InverseZTransform[3\/\(z - 3\), z, 
          n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[GothicCapitalZ]\^\(-1\)\)[\>\"", 
        2\/\(z - 2\), "\<] = \>", 
        InverseZTransform[2\/\(z - 2\), z, n]\ ];\)\)}], "Input"],

Cell["\<\
The KroneckerDelta and UnitStep[n-1] factors might give us some concern so we \
will check them out when n=0.\
\>", "Text"],

Cell[BoxData[{
    \(\(Print["\<2 KroneckerDelta[0] = \>", 
        2\ KroneckerDelta[0]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(2\^0\) UnitStep[0-1] = \>\"", 
        2\^0\ UnitStep[0 - 1]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(3\^0\) UnitStep[0-1] = \>\"", 
        3\^0\ UnitStep[0 - 1]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<2 KroneckerDelta[0]+\!\(2\^0\) UnitStep[0-1]+\!\(3\^0\) \
UnitStep[0-1] = \>\"", 
        2\ KroneckerDelta[0] + 2\^0\ UnitStep[0 - 1] + 
          3\^0\ UnitStep[0 - 1]];\)\)}], "Input"],

Cell[TextData[{
  "So the computation is correct when n=0.   When ",
  Cell[BoxData[
      \(n \[GreaterEqual] 0\)]],
  " we have ",
  Cell[BoxData[
      \(KroneckerDelta[n] = 0\)]],
  ".  \n\nTherefore the following form of the solution would also be valid."
}], "Text"],

Cell[BoxData[{
    \(\(y2[n_] = 
        FullSimplify[
          2\ KroneckerDelta[n] + 2\^n\ UnitStep[\(-1\) + n] + 
            3\^n\ UnitStep[\(-1\) + n], 
          n \[GreaterEqual] 0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y2[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<{y[n]} = \>", 
        Append[Table[
            y2[n], {n, 0, 7}], "\<...\>"]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Which is the same as\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<{y[n]} = \>", 
        Append[Table[
            y[n], {n, 0, 7}], "\<...\>"]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["9.9 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Use residues to find the solution. "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\<Res[Y[z]\!\(z\^\(n - 1\)\)\!\(\*
StyleBox[\",\",\nFontFamily->\"Times New Roman\",\nFontSize->12,\n\
FontWeight->\"Plain\",\nFontSlant->\"Plain\",\nFontColor->GrayLevel[0],\n\
FontVariations->{\"Underline\"->False,\n\"StrikeThrough\"->False}]\)2] = \
\!\(lim\+\(z \[Rule] 2\)\) \>\"", 
          ",", \(Together[\((z - 2)\) Y[z]] z\^\(n - 1\)\), ",", 
          "\"\< = \>\"", 
          ",", \(Limit[\((z - 2)\) Y[z] z\^\(n - 1\), z \[Rule] 2]\)}], " ", 
        "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\<Res[Y[z]\!\(z\^\(n - 1\)\)\!\(\*
StyleBox[\",\",\nFontFamily->\"Times New Roman\",\nFontSize->12,\n\
FontWeight->\"Plain\",\nFontSlant->\"Plain\",\nFontColor->GrayLevel[0],\n\
FontVariations->{\"Underline\"->False,\n\"StrikeThrough\"->False}]\)3] = \
\!\(lim\+\(z \[Rule] 3\)\) \>\"", 
          ",", \(Together[\((z - 3)\) Y[z] z\^\(n - 1\)]\), ",", 
          "\"\< = \>\"", 
          ",", \(Limit[\((z - 3)\) Y[z] z\^\(n - 1\), z \[Rule] 3]\)}], " ", 
        "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", "\"\<y[n] = Res[Y[z]\!\(z\^\(n - 1\)\)\!\(\*
StyleBox[\",\",\nFontFamily->\"Times New Roman\",\nFontSize->12,\n\
FontWeight->\"Plain\",\nFontSlant->\"Plain\",\nFontColor->GrayLevel[0],\n\
FontVariations->{\"Underline\"->False,\n\"StrikeThrough\"->False}]\)2] + \
Res[Y[z]\!\(z\^\(n - 1\)\)\!\(\*
StyleBox[\",\",\nFontFamily->\"Times New Roman\",\nFontSize->12,\n\
FontWeight->\"Plain\",\nFontSlant->\"Plain\",\nFontColor->GrayLevel[0],\n\
FontVariations->{\"Underline\"->False,\n\"StrikeThrough\"->False}]\)3]\>\"", 
        "]"}], ";"}], "\[IndentingNewLine]", \(Print["\<y[n] = \>", 
        Limit[\((z - 2)\) Y[z] z\^\(n - 1\), z \[Rule] 2] + 
          Limit[\((z - 3)\) Y[z] z\^\(n - 1\), z \[Rule] 3]\ ];\)}], "Input"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We could let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " solve the difference equation with",
  StyleBox[" RSolve",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<DiscreteMath`RSolve`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Clear[y];\)\), "\n", 
    \(\(IC\  = \ y[0] \[Equal] 2;\)\), "\[IndentingNewLine]", 
    \(\(DE\  = \ 
        y[n + 1]\  - 2  y[n] \[Equal] \ 3\^n;\)\), "\[IndentingNewLine]", 
    \(\(solset = RSolve[{DE, IC}, y[n], n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the difference equation\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\ DE\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<With initial condition\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ IC\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1\)\(\[RightDoubleBracket]\)\)\
\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve the difference equation  ",
  Cell[BoxData[
      \(y[n + 1]\  - 2  y[n]\  = \ n\)]],
  "  with initial condition  ",
  Cell[BoxData[
      \(y[0] = 1\)]],
  ". \n",
  StyleBox["9.10 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transform and Tables 9.1 - 9.2 to find the solution. \n",
  StyleBox["9.10 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use residues to find the solution. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Solution 9.10 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Take the z-transform of both sides  \n\n\t\t\t",
  Cell[BoxData[
      \(z\ \((Y \((z)\)\  - \ 1)\)\  - \ 2\ Y \((z)\)\  = \ 
        z\/\((z - 1)\)\^2\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  "  and get  ",
  Cell[BoxData[
      \(Y \((z)\) = \(z\^3 - 2\ z\^2 + 2\ z\)\/\(\(\((z - 1)\)\^2\) \((z - 2)\
\)\)\)]],
  ".  Then expand and obtain \n\n\t\t\t",
  Cell[BoxData[
      \(Y \((z)\)\  = \ 
        1\  - \ 1\/\((z - 1)\)\^2\  - \ 2\/\(z - 1\)\  + \ 4\/\(z - 2\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Find the inverse z-transform of each term \n\n\t\t\t",
  Cell[BoxData[{
      \(y[
          n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[
            1]\  - \ \(\[GothicCapitalZ]\^\(-1\)\)[
            1\/\((z - 1)\)\^2]\  - \ \(\[GothicCapitalZ]\^\(-1\)\)[
            2\/\(z - 1\)]\  + \ \(\[GothicCapitalZ]\^\(-1\)\)[
            4\/\(z - 2\)]\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(y[n]\  = \ \[Delta][n]\ \  - \ \((n - 1)\)\ \[Delta][n - 1]\  - \ 
          2\ \[Delta][n - 1]\  + \ 4*\(2\^\(n - 1\)\) \[Delta][n - 1]\)}]],
  " \n\nWhen  ",
  Cell[BoxData[
      \(n = 0\)]],
  "  we get  ",
  Cell[BoxData[
      \(y[0]\  = \ \(1 + 0 + 0\  + 0\  = \ 1\)\)]],
  ",  and when ",
  Cell[BoxData[
      \(n \[GreaterEqual] 1\)]],
  " the expression for ",
  Cell[BoxData[
      \(y[n]\)]],
  " simplifies to be \n\n\t\t\t",
  Cell[BoxData[
      \(y[n]\  = \ \(-1\) - n\  + \ 2\^\(n + 1\)\)]],
  " "
}], "Text"],

Cell[TextData[{
  StyleBox["Solution 9.10 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Start with the formula ",
  Cell[BoxData[
      \(Y \((z)\) = \(z\^3 - 2\ z\^2 + 2\ z\)\/\(\(\((z - 1)\)\^2\) \((z - 2)\
\)\)\)]],
  "  in part (a).  Then use the Corollaries 9.1 and 9.2 and residues to find  \
",
  Cell[BoxData[
      \(\(\[GothicCapitalZ]\^\(-1\)\)[Y \((z)\)]\)]],
  ".  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(y[n]\), "  ", "=", "  ", 
          
          RowBox[{\(\(\[GothicCapitalZ]\^\(-1\)\)[Y \((z)\)]\), " ", "=", " ",
             
            RowBox[{
              RowBox[{"Res", "[", 
                RowBox[{\(Y \((z)\) z\^\(n - 1\)\), 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "1"}], "]"}], " ", "+", " ", 
              RowBox[{"Res", "[", 
                RowBox[{\(Y \((z)\) z\^\(n - 1\)\), 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "2"}], "]"}]}]}]}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{\(y[n]\), " ", "=", "  ", 
          RowBox[{
            RowBox[{"Res", "[", 
              
              RowBox[{\(\(\(z\^3 - 2\ z\^2 + 
                        2\ z\)\/\(\(\((z - 1)\)\^2\) \((z - 2)\)\)\) 
                  z\^\(n - 1\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "1"}], "]"}], " ", "+", " ", 
            RowBox[{"Res", "[", 
              
              RowBox[{\(\(\(z\^3 - 2\ z\^2 + 
                        2\ z\)\/\(\(\((z - 1)\)\^2\) \((z - 2)\)\)\) 
                  z\^\(n - 1\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "2"}], "]"}]}]}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{\(y[
            n]\  = \ \ lim\+\(z\  \[Rule] \ 1\)\(d\/dz\) \((\(\((z - 
                            1)\)\^2\) \(\(z\^3 - 2\ z\^2 + 
                          2\ z\)\/\(\(\((z - 1)\)\^2\) \((z - 2)\)\)\) 
                    z\^\(n - 1\))\)\ \  + \ \ lim\+\(z\  \[Rule] \ 2\)\((z - 
                    2)\) \(\(z\^3 - 2\ z\^2 + 
                      2\ z\)\/\(\(\((z - 1)\)\^2\) \((z - 2)\)\)\) 
                z\^\(n - 1\)\), "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{\(y[
            n]\  = \ \ lim\+\(z\  \[Rule] \ 1\)\(d\/dz\) \((\(\(z\^3 - 
                          2\ z\^2 + 2\ z\)\/\((z - 2)\)\) 
                    z\^\(n - 1\)\ )\)\  + \ \ lim\+\(z\  \[Rule] \ \
2\)\(\(z\^3 - 2\ z\^2 + 2\ z\)\/\((z - 1)\)\^2\) z\^\(n - 1\)\), 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{\(y[
            n]\  = \ \ lim\+\(z\  \[Rule] \ 1\)\((\(\(\((n + 1)\)\ z\^3 - 
                        4\ \((n + 1)\)\ z\^2 + \((6\ n + 2)\)\ z - 
                        4\ n\)\/\((z - 2)\)\^2\) 
                  z\^\(n - 1\)\ )\)\ \  + \ \ \(4\/1\) 2\^\(n - 1\)\), 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{\(y[
            n]\  = \ \ \(\(\((n + 1)\) - 4\ \((n + 1)\) + \((6\ n + 2)\) - 
                    4  n\)\/\(\(\ \)\(1\)\)\) 1\^\(n - 1\)\ \  + \ \ \(4\/1\) 
              2\^\(n - 1\)\), "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", \(y[
          n]\  = \ \ \(\(-\ 
            1\)\(\ \ \)\(-\)\(\ \ \)\(n\)\(\ \ \)\(+\)\(\ \ \)\(2\^\(n + 
                1\)\)\(\ \ \ \)\)\)}]],
  "    "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["9.10 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Use the z-transform and tables to find the solution. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[n, x, X, y, Y];\)\), "\[IndentingNewLine]", 
    \(\(y\_0\  = \ 1;\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = n;\)\), "\[IndentingNewLine]", 
    \(\(DE\  = \ 
        y[n + 1]\  - 2  y[n] \[Equal] \ x[n];\)\), "\[IndentingNewLine]", 
    \(\(IC\  = \ y[0] \[Equal] y\_0;\)\), "\[IndentingNewLine]", 
    \(\(X[z_] = \ ZTransform[x[n], n, z];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the difference equation\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\ DE\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<With initial condition\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_0\) = \>\"", \ 
        IC\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Here we have\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<X[z] = \[GothicCapitalZ][\!\(y\_n\)] = \
\[GothicCapitalZ][\>\"", x[n], "\<] = \>", 
        X[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Taking the z-transforms we have\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<z (Y[z] - \!\(y\_0\)) - 2 Y[z] = X[z]\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<z (Y[z] - (\>", y\_0, "\<)) - 2 Y[z] = \>", \ 
        X[z]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[Y];\)\), "\[IndentingNewLine]", 
    \(\(eqn = 
        z\ \((Y[z]\  - 1)\)\  - 2  Y[z] \[Equal] \ \ ZTransform[n, n, 
            z];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ eqn\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve for Y[z]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Y[
          z_]\  = \(Solve[eqn, Y[z]]\)\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\
\(\[RightDoubleBracket]\)\);\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y[z] = \>", Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Y[z_]\  = Together[Y[z]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y[z] = \>", Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Y[z_]\  = Apart[Y[z]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y[z] = \>", Y[z]\ ];\)\)}], "Input"],

Cell["Find the inverse z-transformations.", "Text"],

Cell[BoxData[{
    \(\(y[n_]\  = \ 
        InverseZTransform[Y[z], z, n];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = \!\(\[GothicCapitalZ]\^\(-1\)\)[Y[z]] = \!\(\
\[GothicCapitalZ]\^\(-1\)\)[\>\"", 
        Y[z], "\<]\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\)}], "Input"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We could investigate each of the terms. "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<     \>", \*"\"\<\!\(\[GothicCapitalZ]\^\(-1\)\)[\>\"", 
        1, "\<] = \>", 
        InverseZTransform[1, z, n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[GothicCapitalZ]\^\(-1\)\)[\>\"", \(-1\)\/\((z - 1)\
\)\^2, "\<] = \>", 
        InverseZTransform[\(-1\)\/\((z - 1)\)\^2, z, 
          n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[GothicCapitalZ]\^\(-1\)\)[\>\"", \(-2\)\/\(z - \
1\), "\<] = \>", 
        InverseZTransform[\(-2\)\/\(z - 1\), z, 
          n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[GothicCapitalZ]\^\(-1\)\)[\>\"", 
        4\/\(z - 2\), "\<] = \>", 
        InverseZTransform[4\/\(z - 2\), z, n]\ ];\)\)}], "Input"],

Cell["\<\
The KroneckerDelta and UnitStep[n-1] factors might give us some concern so we \
will check them out when n=0.\
\>", "Text"],

Cell[BoxData[{
    \(\(Print["\<KroneckerDelta[0] = \>", 
        KroneckerDelta[0]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<(0-1) UnitStep[0-1] = \>", \((0 - 1)\)\ UnitStep[
            0 - 1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<2 UnitStep[0-1] = \>", 
        2\ UnitStep[0 - 1]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(2\^\(0 + 1\)\) UnitStep[0-1] = \>\"", 
        2\^\(0 + 1\)\ UnitStep[0 - 1]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<KroneckerDelta[0]-(0-1) UnitStep[0-1]-2 UnitStep[0-1]+\!\
\(2\^\(n + 1\)\) UnitStep[0-1] = \>\"", 
        KroneckerDelta[0] - \((0 - 1)\)\ UnitStep[0 - 1] - 
          2\ UnitStep[0 - 1] + 2\^\(n + 1\)\ UnitStep[0 - 1]];\)\)}], "Input"],

Cell[TextData[{
  "So the computation is correct when n=0.   When ",
  Cell[BoxData[
      \(n \[GreaterEqual] 0\)]],
  " we have ",
  Cell[BoxData[
      \(KroneckerDelta[n] = 0\)]],
  ".  \n\nTherefore the following form of the solution would also be valid."
}], "Text"],

Cell[BoxData[{
    \(\(y2[n_] = 
        FullSimplify[
          KroneckerDelta[n] - 2\ UnitStep[\(-1\) + n] + 
            2\^\(1 + n\)\ UnitStep[\(-1\) + n] - \((\(-1\) + 
                  n)\)\ UnitStep[\(-1\) + n], 
          n \[GreaterEqual] 0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y2[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<{y[n]} = \>", 
        Append[Table[
            y2[n], {n, 0, 7}], "\<...\>"]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Which is the same as\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<{y[n]} = \>", 
        Append[Table[
            y[n], {n, 0, 7}], "\<...\>"]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["9.10 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Use residues to find the solution. "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\<Res[Y[z]\!\(z\^\(n - 1\)\)\!\(\*
StyleBox[\",\",\nFontFamily->\"Times New Roman\",\nFontSize->12,\n\
FontWeight->\"Plain\",\nFontSlant->\"Plain\",\nFontColor->GrayLevel[0],\n\
FontVariations->{\"Underline\"->False,\n\"StrikeThrough\"->False}]\)1] = \
\!\(lim\+\(z \[Rule] 2\)\) \>\"", ",", "\"\<\!\(d\/dz\)\>\"", 
          ",", \(Simplify[\((\(\((z - 1)\)\^2\) Y[z] z\^\(n - 1\))\)]\)}], 
        "  ", "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\<Res[Y[z]\!\(z\^\(n - 1\)\)\!\(\*
StyleBox[\",\",\nFontFamily->\"Times New Roman\",\nFontSize->12,\n\
FontWeight->\"Plain\",\nFontSlant->\"Plain\",\nFontColor->GrayLevel[0],\n\
FontVariations->{\"Underline\"->False,\n\"StrikeThrough\"->False}]\)1] = \
\!\(lim\+\(z \[Rule] 2\)\) \>\"", 
          ",", \(Simplify[\[PartialD]\_z\ \((\(\((z - 1)\)\^2\) Y[z] 
                  z\^\(n - 1\))\)]\), ",", "\"\< = \>\"", 
          ",", \(Limit[
            Simplify[\[PartialD]\_z\ \((\(\((z - 1)\)\^2\) Y[z] 
                    z\^\(n - 1\))\)], z \[Rule] 1]\)}], " ", "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\<Res[Y[z]\!\(z\^\(n - 1\)\)\!\(\*
StyleBox[\",\",\nFontFamily->\"Times New Roman\",\nFontSize->12,\n\
FontWeight->\"Plain\",\nFontSlant->\"Plain\",\nFontColor->GrayLevel[0],\n\
FontVariations->{\"Underline\"->False,\n\"StrikeThrough\"->False}]\)2] = \
\!\(lim\+\(z \[Rule] 3\)\) \>\"", 
          ",", \(Together[\((z - 2)\) Y[z] z\^\(n - 1\)]\), ",", 
          "\"\< = \>\"", 
          ",", \(Limit[\((z - 2)\) Y[z] z\^\(n - 1\), z \[Rule] 2]\)}], " ", 
        "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", "\"\<y[n] = Res[Y[z]\!\(z\^\(n - 1\)\)\!\(\*
StyleBox[\",\",\nFontFamily->\"Times New Roman\",\nFontSize->12,\n\
FontWeight->\"Plain\",\nFontSlant->\"Plain\",\nFontColor->GrayLevel[0],\n\
FontVariations->{\"Underline\"->False,\n\"StrikeThrough\"->False}]\)1] + \
Res[Y[z]\!\(z\^\(n - 1\)\)\!\(\*
StyleBox[\",\",\nFontFamily->\"Times New Roman\",\nFontSize->12,\n\
FontWeight->\"Plain\",\nFontSlant->\"Plain\",\nFontColor->GrayLevel[0],\n\
FontVariations->{\"Underline\"->False,\n\"StrikeThrough\"->False}]\)2]\>\"", 
        "]"}], ";"}], "\[IndentingNewLine]", \(Print["\<y[n] = \>", 
        Limit[Simplify[\[PartialD]\_z\ \((\(\((z - 1)\)\^2\) Y[z] 
                    z\^\(n - 1\))\)], z \[Rule] 1] + 
          Limit[\((z - 2)\) Y[z] z\^\(n - 1\), z \[Rule] 2]\ ];\)}], "Input"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We could let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " solve the difference equation with",
  StyleBox[" RSolve",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<DiscreteMath`RSolve`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Clear[y];\)\), "\n", 
    \(\(IC\  = \ y[0] \[Equal] 1;\)\), "\[IndentingNewLine]", 
    \(\(DE\  = \ 
        y[n + 1]\  - 2  y[n] \[Equal] \ n;\)\), "\[IndentingNewLine]", 
    \(\(solset = RSolve[{DE, IC}, y[n], n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the difference equation\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\ DE\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<With initial condition\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ IC\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1\)\(\[RightDoubleBracket]\)\)\
\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given the repeated dosage drug level model  ",
  Cell[BoxData[
      \(y[n + 1]\  = \ a\ y[n] + b\)]],
  " with the initial condition  ",
  Cell[BoxData[
      \(y[0] = y\_0\)]],
  ". ",
  StyleBox["\n9.11 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the trial solution method.  \n",
  StyleBox["9.11 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-transforms to find the solution. \n",
  StyleBox["9.11 (c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use residues to find the solution. \n",
  StyleBox["9.11 (d).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use convolution to find the solution. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox["Solution 9.11 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tThe first step is to solve the homogeneous equation  ",
  Cell[BoxData[
      \(y\_h[n + 1]\  - \ a\ y\_h[n]\  = \ 0\)]],
  ".  The trial solution is  ",
  Cell[BoxData[
      \(y\_h[n] = r\^n\)]],
  ", and substitution produces  ",
  Cell[BoxData[
      \(r\^\(n + 1\) - a\ r\^n = 0\)]],
  ", from which we obtain the characteristic equation  ",
  Cell[BoxData[
      \(r - a = 0\)]],
  ".  The root is  ",
  Cell[BoxData[
      \(r = a\)]],
  "  and the homogeneous solution is  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(y\_h[n]\  = \ c\_1\ a\^n\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "The second step is to find a particular solution to the nonhomogeneous \
equation  \n\n\t\t\t",
  Cell[BoxData[
      \(y\_p[n + 1]\  - \ a\ y\_p[n]\  = \ b\)]],
  ".  \n\nSince the right hand side is a constant, we try  ",
  Cell[BoxData[
      \(y\_p[n] = c\)]],
  ",  and substitution produces  ",
  Cell[BoxData[
      \(c\  - \ a\ c\  = \ b\)]],
  ", hence ",
  Cell[BoxData[
      \(c\  = b\/\(1 - a\)\)]],
  ".  The general solution is \n\n\t\t\t",
  Cell[BoxData[{
      \(y[n]\ \  = \ \ y\_h[n] + y\_p[n]\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(y[n]\ \  = \ \ c\_1\ a\^n + b\/\(1 - a\)\)}]],
  "\n\nThen  ",
  Cell[BoxData[
      \(y[0]\  = \ \(c\_1\ a\^0 + b\/\(1 - a\)\  = \ y\_0\)\)]],
  " can be solved for  ",
  Cell[BoxData[
      \(c\_1\  = \ b\/\(a - 1\) + y\_0\)]],
  ".   Substituting this in the previous expression for ",
  Cell[BoxData[
      \(y[n]\)]],
  " yields  \n\n\t\t\t",
  Cell[BoxData[{
      \(y[
          n]\ \  = \ \ \((b\/\(a - 1\) + 
                y\_0)\)\ a\^n\ \  - \ \ b\/\(a - 1\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(y[
          n]\ \  = \ \ \(y\_0\) a\^n\ \  + \ \ 1\/\(a - 1\)\ \(a\^n\) 
            b\ \  - \ \ \(1\/\(a - 1\)\) b\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(y[
          n]\ \  = \ \ \(y\_0\) 
            a\^n\ \  + \ \ \(1\/\(a - 1\)\) \((a\^n - 1)\) b\)}]],
  "   "
}], "Text"],

Cell[TextData[StyleBox["Solution 9.11 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tStart with the difference equation  ",
  Cell[BoxData[
      \(y[n + 1]\  = \ a\ y[n] + b\)]],
  ".  Take the z-transform of both sides  \n\n\t\t\t",
  Cell[BoxData[
      \(z\ \((Y \((z)\)\  - \ y\_0)\)\  = \ 
        a\ Y \((z)\) + b \(\(\ \)\(z\)\)\/\(z - 1\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  "  and get  ",
  Cell[BoxData[
      \(Y \((z)\)\  = \ \(b\ z - z\ y\_0 + z\^2\ y\_0\)\/\(\((z - 1)\)\ \((z \
- a)\)\)\)]],
  ".  Then expand and obtain \n\n\t\t\t",
  Cell[BoxData[
      \(Y \((z)\)\  = \ \(y\_0\) \((z\/\(z - a\))\) + \(\(a\ b\)\/\(a - 
                  1\)\) \((1\/\(z - a\))\) - \(b\/\(a - 
                  1\)\) \((1\/\(z - 1\))\)\)]]
}], "Text"],

Cell[TextData[{
  "Find the inverse z-transform of each term \n\n\t\t\t",
  Cell[BoxData[{
      \(y[
          n]\ \  = \ \ \(y\_0\) \(\[GothicCapitalZ]\^\(-1\)\)[
              z\/\(z - a\)]\  + \ \(\(a\ b\)\/\(a - 
                  1\)\) \(\[GothicCapitalZ]\^\(-1\)\)[
              1\/\(z - a\)]\  - \ \(b\/\(a - 
                  1\)\) \(\[GothicCapitalZ]\^\(-1\)\)[
              1\/\(z - 1\)]\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(y[
          n]\ \  = \ \ \(y\_0\) \((a\^n)\)\ \  + \ \(\(a\ b\)\/\(a - 
                  1\)\) \((\(a\^\(n - 1\)\) 
                u[n - 1])\)\  - \ \(b\/\(a - 1\)\) \((u[n - 1])\)\)}]],
  "  \n\nWhen  ",
  Cell[BoxData[
      \(n = 0\)]],
  "  we get  ",
  Cell[BoxData[
      \(y[0]\  = \ \(\(y\_0\) \((a\^0)\) + 0 - 0 = y\_0\)\)]],
  ",  and when ",
  Cell[BoxData[
      \(n \[GreaterEqual] 1\)]],
  " the expression for ",
  Cell[BoxData[
      \(y[n]\)]],
  " simplifies to be \n\n\t\t\t",
  Cell[BoxData[
      \(y[
          n]\  = \ \(y\_0\) 
            a\^n\  + \(\(\(a\^n\)\(-\)\(1\)\(\ \)\)\/\(a - 1\)\) b\)]],
  " "
}], "Text"],

Cell[TextData[StyleBox["Solution 11 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tStart with the formula for the z-transform that we found in part (b):  \
",
  Cell[BoxData[
      \(Y \((z)\)\  = \ \(b\ z - z\ y\_0 + z\^2\ y\_0\)\/\(\((z - 1)\)\ \((z \
- a)\)\)\)]],
  ".  Then use the Corollary and residues to find  ",
  Cell[BoxData[
      \(\(\[GothicCapitalZ]\^\(-1\)\)[Y \((z)\)]\)]],
  ".  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(y[n]\), "  ", "=", "  ", 
          
          RowBox[{\(\(\[GothicCapitalZ]\^\(-1\)\)[Y \((z)\)]\), " ", "=", " ",
             
            RowBox[{
              RowBox[{"Res", "[", 
                RowBox[{\(Y \((z)\) z\^\(n - 1\)\), 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "1"}], "]"}], " ", "+", " ", 
              RowBox[{"Res", "[", 
                RowBox[{\(Y \((z)\) z\^\(n - 1\)\), 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "a"}], "]"}]}]}]}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"           ", 
        RowBox[{"=", "  ", 
          RowBox[{
            RowBox[{"Res", "[", 
              
              RowBox[{\(\(\(b\ z - z\ y\_0 + 
                        z\^2\ y\_0\)\/\(\((z - 1)\)\ \((z - a)\)\)\) 
                  z\^\(n - 1\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "1"}], "]"}], " ", "+", " ", 
            RowBox[{"Res", "[", 
              
              RowBox[{\(\(\(b\ z - z\ y\_0 + 
                        z\^2\ y\_0\)\/\(\((z - 1)\)\ \((z - a)\)\)\) 
                  z\^\(n - 1\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "a"}], "]"}]}]}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "           ", \(\(=\)\(\ \ \)\(lim\+\(z\  \[Rule] \ 1\)\ \ \((z - 
                    1)\) X \((z)\) 
                z\^\(n - 1\)\ \  + \ \ lim\+\(z\  \[Rule] \ a\)\ \ \((z - 
                    a)\) X \((z)\) z\^\(n - 1\)\)\), "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        "           ", \(\(=\)\(\ \ \)\(lim\+\(z\  \[Rule] \ 1\)\ \ \((z - 
                    1)\) \(\(b\ z - z\ y\_0 + 
                      z\^2\ y\_0\)\/\(\((z - 1)\)\ \((z - a)\)\)\) 
                z\^\(n - 1\)\ \  + \ \ lim\+\(z\  \[Rule] \ a\)\ \ \(\(b\ z - 
                      z\ y\_0 + z\^2\ y\_0\)\/\(\((z - 1)\)\ \((z - a)\)\)\) 
                X \((z)\) z\^\(n - 1\)\)\), "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        "           ", \(\(=\)\(\ \ \)\(lim\+\(z\  \[Rule] \ 1\)\ \ \(\(b\ z \
- z\ y\_0 + z\^2\ y\_0\)\/\(\(\ \)\(z - a\)\)\) 
                z\^\(n - 1\)\ \  + \ \ lim\+\(z\  \[Rule] \ a\)\ \ \(\(b\ z - 
                      z\ y\_0 + z\^2\ y\_0\)\/\(z - 1\)\) z\^\(n - 1\)\)\), 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "           ", \(\(=\)\(\ \ \)\(\(\(b - \ y\_0 + 
                    y\_0\)\/\(\(\ \)\(1 - a\)\)\) 
              1\^\(n - 1\)\ \  + \ \ \(\(b\ a - 
                    a\ y\_0 + \(a\^2\) y\_0\)\/\(a - 1\)\) a\^\(n - 1\)\)\), 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "           ", \(\(=\)\(\ \ \)\(b\/\(1 - a\)\ \  + \ \ \(a\^\(\(-1\) \
+ n\)\ \((a\ b - a\ y\_0 + a\^2\ y\_0)\)\)\/\(\(-1\) + a\)\)\), "  ", 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "           ", \(\(=\)\(\ \ \)\(\(y\_0\) 
              a\^n\ \ \  + \ \ \(\(\(\(a\^n\)\(-\)\(1\)\(\ \)\)\/\(a - 
                    1\)\) \(b\)\(\ \ \)\)\)\)}]}]],
  "    "
}], "Text"],

Cell[TextData[StyleBox["Solution 9.11 (d).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "The solution to the homogeneous equation  ",
  Cell[BoxData[
      \(y\_h[n + 1]\  - \ a\ y\_h[n]\  = \ 0\)]],
  "   is   ",
  Cell[BoxData[
      \(y\_h[n]\  = \ \(c\_1\) a\^n\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "The transfer function is  ",
  Cell[BoxData[
      \(H \((z)\) = 1\/\(1\  - \ a\ z\^\(-1\)\)\)]],
  "  and the unit-sample response is   ",
  Cell[BoxData[
      \(h[n]\  = \ \(\(\[GothicCapitalZ]\^\(-1\)\)[H \((z)\)]\  = \ 
          a\^n\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "The input sequence is  ",
  Cell[BoxData[
      \(x[n] = b\)]],
  "  and it's z-transform is   ",
  Cell[BoxData[
      \(X \((z)\) = \(b\ z\)\/\(z - 1\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The particular solution is calculated with the formula  ",
  Cell[BoxData[
      \(y\_p[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[X \((z)\) H \((z)\)]\)]],
  "  as follows: \n\n\t\t\t",
  Cell[BoxData[{
      \(y\_p[
          n]\  = \ \ \(\[GothicCapitalZ]\^\(-1\)\)[\((\(b\ z\)\/\(z - 1\))\) \
\((1\/\(1\  - \ a\ z\^\(-1\)\))\)]\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(\(\[GothicCapitalZ]\^\(-1\)\)[
          b\  - \ b\/\(\((\(-1\) + a)\)\ \((\(-1\) + z)\)\)\  + \ \(a\^2\ b\)\
\/\(\((\(-1\) + a)\)\ \((\(-a\) + z)\)\)]\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(b\ \[Delta][
              n]\  - \ \(b\/\(a - 1\)\) 
            u[n - 1]\  + \ \(\(a\^\(1 + n\)\ b\)\/\(a - 1\)\) 
            u[n - 1]\)\)\)}]],
  "\n\nwhich can be simplified to obtain  \n\n\t\t\t",
  Cell[BoxData[
      \(y\_p[n]\  = \ \(\((a\^\(1 + n\) - 1)\)\ b\)\/\(a - 1\)\)]],
  " "
}], "Text"],

Cell[TextData[{
  "In convolution form  ",
  Cell[BoxData[
      \(y\_p[
          n]\  = \ \(x[n]*
            h[n]\  = \ \[Sum]\+\(i = 0\)\%n x[n - i] h[i]\)\)]],
  "  and we have \n\n\t\t\t",
  Cell[BoxData[
      \(y\_p[
          n]\  = \ \(\[Sum]\+\(i = 0\)\%n\ 
            b\ a\^i\  = \ \(\((a\^\(1 + n\) - 1)\)\ b\)\/\(a - 1\)\)\)]]
}], "Text"],

Cell[TextData[{
  "The particular solution  ",
  Cell[BoxData[
      \(y\_p[n]\)]],
  "  obtained by using convolution has the initial condition  ",
  Cell[BoxData[
      \(y\_p[
          0]\  = \ \(\[Sum]\+\(i = 0\)\%0 x[0 - i] h[i]\  = \ \(x[0] 
              h[0]\  = \ \(x[0]\  = \ b\)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "The total solution to the nonhomogeneous difference equation is  \n\n\t\t\t\
",
  Cell[BoxData[{
      \(y[
          n]\ \  = \ \ \(y\_h[n] + 
            y\_p[n]\ \  = \ \ \(c\_1\) a\^n\ \  + \ \ \[Sum]\+\(i = 0\)\%n\ 
              b\ a\^i\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(\(c\_1\) 
            a\^n\)\(\ \ \)\(+\)\(\ \ \)\(\(\((a\^\(1 + n\) - 1)\)\ b\)\/\(a - 
                1\)\)\(\ \)\)\)\)}]],
  "  \n"
}], "Text"],

Cell[TextData[{
  "Now we compute  ",
  Cell[BoxData[
      \(y\_0\  = \ \(y[
            0]\  = \ \(\(c\_1\) 
                a\^0\  + \ \(\((a - 1)\)\ b\)\/\(a - 1\)\  = \ 
            c\_1\  + \ b\)\)\)]],
  ",  and solve for the constant  ",
  Cell[BoxData[
      \(c\_1\  = \ y\_0 - \ b\)]],
  "  which will produce the proper initial condition.  Therefore, \n \n \t\t\t\
",
  Cell[BoxData[
      \(y[
          n]\  = \ \((y\_0 - b)\) 
            a\^n\  + \ \(\((a\^\(1 + n\) - 1)\)\ b\)\/\(a - 1\)\)]],
  ",  \n \n which can be manipulated to yield   ",
  Cell[BoxData[
      \(y[
          n]\  = \ \(y\_0\) 
            a\^n + \ \(\(a\^n\)\(-\)\(1\)\(\ \)\)\/\(a - 1\)\ b\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\t",
  "An illustration of the dosage model using the parameters",
  " ",
  Cell[BoxData[
      RowBox[{\(a = 4\/5\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(b = 1\)}]]],
  " and initial condition  ",
  Cell[BoxData[
      \(y[0] = \(y\_0 = 0\)\)]],
  " is shown in Figure 1 below. "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006=0000]b000`400?l0
0000o`00003oo`3ooon>0?ooo`00o`3ooon>0?ooo`00o`3ooon>0?ooo`00
o`3ooon>0?ooo`00o`3ooon>0?ooo`00o`3ooon>0?ooo`00o`3ooon>0?oo
o`00_03oool2000003D0oooo1@0000020?ooo`800000<@3oool500000080
oooo0P00000b0?ooo`@000000`3oool2000001`0oooo002k0?ooo`040000
003oool0oooo000003H0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0300oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`00000K0?ooo`00_P3oool00`000000oooo0?ooo`0d
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001/0oooo
002l0?ooo`800000=`3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`800000
=03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool06@3oool00;`0oooo00<000000?ooo`3oool0=P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0340oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000K0?ooo`00_03oool30000
03D0oooo0P0000040?ooo`800000<P3oool2000000@0oooo0`00000b0?oo
o`800000103oool2000001`0oooo00220?ooo`030000003oool0oooo0?l0
oooo2@3oool00880oooo00<000000?ooo`3oool0o`3oool90?ooo`00PP3o
ool00`000000oooo0?ooo`3o0?ooo`T0oooo00220?ooo`030000003oool0
oooo0?D0oooo0P0000020?ooo`8000003@3oool00880oooo0P3o003g0?oo
o`040000003oool0oooo000000h0oooo001n0?ooo`<00000103o003]0000
00T0oooo00@000000?ooo`3oool000003P3oool00840oooo103o000h0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo00X0oooo1000000?0?oo
o`00PP3oool20?l00?l0oooo2P3oool00880oooo00<000000?ooo`3oool0
o`3oool90?ooo`00PP3oool00`000000oooo0?ooo`3o0?ooo`T0oooo0022
0?ooo`030000003oool0oooo0?l0oooo2@3oool00880oooo00<000000?oo
o`3oool0o`3oool90?ooo`00PP3oool00`000000oooo0?ooo`3o0?ooo`T0
oooo00220?ooo`030000003oool0oooo0?l0oooo2@3oool00880oooo00<0
00000?ooo`3oool0o`3oool90?ooo`00PP3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo00220?ooo`030000003oool0oooo0?l0oooo2@3oool00880
oooo00<000000?ooo`3oool0o`3oool90?ooo`00PP3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo00220?ooo`030000003oool0oooo0?l0oooo2@3o
ool00880oooo00<000000?ooo`3oool0o`3oool90?ooo`00PP3oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo00220?ooo`030000003oool0oooo0?l0
oooo2@3oool00880oooo00<000000?ooo`3oool0o`3oool90?ooo`00PP3o
ool00`000000oooo0?ooo`3o0?ooo`T0oooo00220?ooo`030000003oool0
oooo0?l0oooo2@3oool00880oooo00<000000?ooo`3oool0o`3oool90?oo
o`00PP3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00220?ooo`030000
003oool0oooo0?l0oooo2@3oool00880oooo00<000000?ooo`3oool0o`3o
ool90?ooo`00PP3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00220?oo
o`030000003oool0oooo0?l0oooo2@3oool007X0oooo1@0000030?ooo`03
0000003oool0oooo0?l0oooo2@3oool007`0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`80o`00oP3oool007`0oooo00<0
00000?ooo`3oool00`3oool3000000L0oooo103o003m0?ooo`00O03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo103o003m
0?ooo`00O03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00P0oooo0P3o003n0?ooo`00N`3oool2000000D0oooo00<000000?ooo`3o
ool0o`3oool90?ooo`00PP3oool00`000000oooo0?ooo`3o0?ooo`T0oooo
00220?ooo`030000003oool0oooo0?l0oooo2@3oool00880oooo00<00000
0?ooo`3oool0o`3oool90?ooo`00PP3oool00`000000oooo0?ooo`3o0?oo
o`T0oooo00220?ooo`030000003oool0oooo0?l0oooo2@3oool00880oooo
00<000000?ooo`3oool0o`3oool90?ooo`00PP3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo00220?ooo`030000003oool0oooo0?l0oooo2@3oool0
0880oooo00<000000?ooo`3oool0o`3oool90?ooo`00PP3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo00220?ooo`030000003oool0oooo0?l0oooo
2@3oool00880oooo00<000000?ooo`3oool0o`3oool90?ooo`00PP3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo00220?ooo`030000003oool0oooo
0?l0oooo2@3oool00880oooo00<000000?ooo`3oool0o`3oool90?ooo`00
PP3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00220?ooo`030000003o
ool0oooo0?l0oooo2@3oool00880oooo00<000000?ooo`3oool0o`3oool9
0?ooo`00PP3oool00`000000oooo0?ooo`0D0?ooo`80o`00lP3oool00880
oooo00<000000?ooo`3oool04`3oool40?l00?40oooo00220?ooo`030000
003oool0oooo01<0oooo103o003a0?ooo`00PP3oool00`000000oooo0?oo
o`0D0?ooo`80o`00lP3oool00880oooo00<000000?ooo`3oool0o`3oool9
0?ooo`00NP3oool4000000@0oooo00<000000?ooo`3oool0o`3oool90?oo
o`00NP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0
oooo2@3oool007/0oooo00<000000?ooo`3oool0103oool300000?l0oooo
2@3oool007`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo001j0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`00N`3oool2000000D0oooo00<00000
0?ooo`3oool0o`3oool90?ooo`00PP3oool00`000000oooo0?ooo`3o0?oo
o`T0oooo00220?ooo`030000003oool0oooo0?l0oooo2@3oool00880oooo
00<000000?ooo`3oool0o`3oool90?ooo`00PP3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo00220?ooo`030000003oool0oooo0?l0oooo2@3oool0
0880oooo00<000000?ooo`3oool0o`3oool90?ooo`00PP3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo00220?ooo`030000003oool0oooo0?l0oooo
2@3oool00880oooo00<000000?ooo`3oool0803oool20?l00>H0oooo0022
0?ooo`030000003oool0oooo01l0oooo103o003U0?ooo`00PP3oool00`00
0000oooo0?ooo`0O0?ooo`@0o`00i@3oool00880oooo00<000000?ooo`3o
ool0803oool20?l00>H0oooo00220?ooo`030000003oool0oooo0?l0oooo
2@3oool00880oooo00<000000?ooo`3oool0o`3oool90?ooo`00PP3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo00220?ooo`030000003oool0oooo
0?l0oooo2@3oool00880oooo00<000000?ooo`3oool0o`3oool90?ooo`00
PP3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00220?ooo`030000003o
ool0oooo0?l0oooo2@3oool00880oooo00<000000?ooo`3oool0o`3oool9
0?ooo`00PP3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00220?ooo`03
0000003oool0oooo0?l0oooo2@3oool00880oooo00<000000?ooo`3oool0
o`3oool90?ooo`00N`3oool2000000D0oooo00<000000?ooo`3oool0:`3o
ool20?l00=/0oooo001j0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0:P3oool40?l00=X0oooo001l0?ooo`030000003oool0
oooo00<0oooo0`00000Z0?ooo`@0o`00fP3oool007d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0[0?ooo`80o`00f`3oool007X0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?oo
o`T0oooo001k0?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`T0
oooo00220?ooo`030000003oool0oooo0?l0oooo2@3oool00880oooo00<0
00000?ooo`3oool0o`3oool90?ooo`00PP3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo00220?ooo`030000003oool0oooo0?l0oooo2@3oool00880
oooo00<000000?ooo`3oool0o`3oool90?ooo`00PP3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo00220?ooo`030000003oool0oooo03L0oooo0P3o
003?0?ooo`00PP3oool00`000000oooo0?ooo`0f0?ooo`@0o`00cP3oool0
0880oooo00<000000?ooo`3oool0=P3oool40?l00<h0oooo00220?ooo`03
0000003oool0oooo03L0oooo0P3o003?0?ooo`00PP3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo00220?ooo`030000003oool0oooo0?l0oooo2@3o
ool00880oooo00<000000?ooo`3oool0o`3oool90?ooo`00PP3oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo00220?ooo`030000003oool0oooo0?l0
oooo2@3oool00880oooo00<000000?ooo`3oool0@`3oool20?l00<<0oooo
00220?ooo`030000003oool0oooo0480oooo103o00320?ooo`00PP3oool0
0`000000oooo0?ooo`120?ooo`@0o`00`P3oool00880oooo00<000000?oo
o`3oool0@`3oool20?l00<<0oooo00220?ooo`030000003oool0oooo0?l0
oooo2@3oool00880oooo00<000000?ooo`3oool0o`3oool90?ooo`00PP3o
ool00`000000oooo0?ooo`3o0?ooo`T0oooo00220?ooo`030000003oool0
oooo0?l0oooo2@3oool00880oooo00<000000?ooo`3oool0C`3oool20?l0
0;L0oooo001l0?ooo`<000000`3oool00`000000oooo0?ooo`1>0?ooo`@0
o`00]P3oool007d0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1>0?ooo`@0o`00]P3oool007X0oooo1@0000030?ooo`<00000C`3o
ool20?l00;L0oooo001j0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`00N`3oool00`000000oooo00000004
0?ooo`030000003oool0oooo0?l0oooo2@3oool007`0oooo0P0000040?oo
o`030000003oool0oooo05X0oooo0P3o002/0?ooo`00PP3oool00`000000
oooo0?ooo`1I0?ooo`@0o`00Z`3oool00880oooo00<000000?ooo`3oool0
F@3oool40?l00:/0oooo00220?ooo`030000003oool0oooo05X0oooo0P3o
002/0?ooo`00PP3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00220?oo
o`030000003oool0oooo06H0oooo0P3o002P0?ooo`00PP3oool00`000000
oooo0?ooo`1U0?ooo`@0o`00W`3oool00880oooo00<000000?ooo`3oool0
I@3oool40?l009l0oooo00220?ooo`030000003oool0oooo06H0oooo0P3o
002P0?ooo`00PP3oool00`000000oooo0?ooo`1b0?ooo`80o`00U03oool0
0880oooo00<000000?ooo`3oool0L@3oool40?l009<0oooo00220?ooo`03
0000003oool0oooo0740oooo103o002C0?ooo`00PP3oool00`000000oooo
0?ooo`1b0?ooo`80o`002@3oool20?l008T0oooo00220?ooo`030000003o
ool0oooo07`0oooo103o00280?ooo`00PP3oool00`000000oooo0?ooo`1l
0?ooo`@0o`00R03oool00880oooo00<000000?ooo`3oool0O@3oool20?l0
00X0oooo0P3o001m0?ooo`00PP3oool00`000000oooo0?ooo`280?ooo`@0
o`00O03oool00880oooo00<000000?ooo`3oool0R03oool40?l000T0oooo
0P3o001a0?ooo`00PP3oool00`000000oooo0?ooo`290?ooo`80o`002@3o
ool40?l000T0oooo0P3o001U0?ooo`00PP3oool00`000000oooo0?ooo`2D
0?ooo`@0o`00203oool40?l006@0oooo00220?ooo`030000003oool0oooo
09D0oooo0P3o00090?ooo`@0o`00203oool20?l005X0oooo00220?ooo`03
0000003oool0oooo0:40oooo0P3o00080?ooo`@0o`002@3oool20?l000X0
oooo0P3o00120?ooo`00PP3oool00`000000oooo0?ooo`2[0?ooo`@0o`00
203oool40?l000P0oooo103o00080?ooo`80o`00=`3oool00880oooo00<0
00000?ooo`3oool0[03oool20?l000T0oooo103o00080?ooo`@0o`001`3o
ool40?l000T0oooo0P3o000:0?ooo`80o`007`3oool007/0oooo0P000005
0?ooo`030000003oool0oooo0;P0oooo0P3o000:0?ooo`80o`00203oool4
0?l000P0oooo103o00080?ooo`@0o`007P3oool007X0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3?0?ooo`80o`002@3oool4
0?l000P0oooo103o000N0?ooo`00O@3oool00`000000oooo0?ooo`020?oo
o`<00000f`3oool20?l000X0oooo0P3o000O0?ooo`00N`3oool200000?l0
oooo4@3oool007/0oooo00<000000?ooo`3oool0o`3oool@0?ooo`00N`3o
ool300000?l0oooo403oool00?l0ooooSP3oool00?l0ooooSP3oool00?l0
ooooSP3oool00?l0ooooSP3oool00?l0ooooSP3oool007P0oooo0P000006
0?ooo`800000203oool200000?l0oooo0P3oool007T0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0?l0oooo001j0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P0000020?ooo`8000000P3oool00`000000oooo0?ooo`3o0?ooo`00
N@3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool000000?l0oooo0P3oool007P0
oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo0000003o0?ooo`80oooo001g
0?ooo`<0000000<0oooo0000000000000`3oool00`000000oooo0?ooo`04
000000@0oooo00<000000?ooo`3oool0o`3oool00800oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`3o0?ooo`00P03oool2000000P0
oooo0P00003o0?ooo`80oooo003o0?ooohh0oooo003o0?ooohh0oooo0000
\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{397, 183},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\tFigure 9.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The solution to ",
  Cell[BoxData[
      \(y[n + 1] = \(5\/4\) y[n] + 1\)]],
  " with ",
  Cell[BoxData[
      \(y[0] = \(y\_0 = 0\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.11 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Start with the difference equation  ",
  Cell[BoxData[
      \(y[n + 1]\  = \ a\ y[n] + b\)]],
  ".   The first step is to solve the homogeneous equation  ",
  Cell[BoxData[
      \(y\_h[n + 1]\  - \ a\ y\_h[n]\  = \ 0\)]],
  ".  Use the trial solution  ",
  Cell[BoxData[
      \(y\_h[n] = r\^n\)]],
  ", and construct the homogeneous solution."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[n, x, X, y, Y];\)\), "\[IndentingNewLine]", 
    \(\(HDE\  = \ y[n + 1]\  - a\ y[n] \[Equal] \ 0;\)\), "\n", 
    \(\(eqn1 = ReplaceAll[\ HDE, y[n_] \[Rule] c\_1\ r\^n];\)\), "\n", 
    \(\(solset1 = Solve[eqn1, r];\)\), "\n", 
    \(\(y\_h[n_] = 
        ReplaceAll[\(c\_1\) r\^n, 
          r \[Rule] 
            solset1\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the homogeneous equation\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\ HDE\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Substitute y[n] \[Rule] \!\(c\_1\) \
\!\(r\^n\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<And obtain the equation\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ eqn1\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve and get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        r \[Rule] 
          solset1\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<The homogeneous solution is\>"]\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_h\)[n] = \>\"" 
          y\_h[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The second step is to find a particular solution ",
  Cell[BoxData[
      \(y\_p[n]\)]],
  " to the nonhomogeneous equation  ",
  Cell[BoxData[
      \(y\_p[n + 1]\  - \ a\ y\_p[n]\  = \ b\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(DE\  = \ y[n + 1]\  - a\ y[n] \[Equal] b;\)\), "\n", 
    \(\(eqn2 = ReplaceAll[\ DE, y[n_] \[Rule] c];\)\), "\n", 
    \(\(solset2 = Solve[eqn2, c];\)\), "\n", 
    \(\(y\_p[n_] = 
        ReplaceAll[c, 
          c \[Rule] 
            solset2\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the homogeneous equation\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\ HDE\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute y[n] \[Rule] c\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<And obtain the equation\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ eqn2\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve and get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        c \[Rule] 
          solset2\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<The particular solution is\>"]\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_p\)[n] = \>\"", 
        y\_p[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The general solution is  ",
  Cell[BoxData[
      \(y[n]\ \  = \ \ y\_h[n] + y\_p[n]\)]]
}], "Text"],

Cell[BoxData[{
    \(\(y\_g[n_]\  = \ y\_h[n]\  + \ y\_p[n];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n]  =  \!\(y\_h\)[n] + \!\(y\_p\)[n] = \>\"", 
        y\_g[n]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Then solve for the initial condition  ",
  Cell[BoxData[
      \(y[0]\  = \ y\_0\)]],
  ".   "
}], "Text"],

Cell[BoxData[{
    \(\(eqn3 = y\_g[0] \[Equal] y\_0;\)\), "\[IndentingNewLine]", 
    \(\(solset3\  = \ 
        Solve[y\_g[0] \[Equal] y\_0, c\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ eqn3\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ 
        solset3\_\(\(\[LeftDoubleBracket]\)\(1, \
1\)\(\[RightDoubleBracket]\)\)\ ];\)\), "\[IndentingNewLine]", 
    \(Print["\<The general solution is\>"]\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n]  =  \!\(y\_h\)[n] + \!\(y\_p\)[n] = \>\"", 
        y\_g[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(y[n_]\  = \ 
        ReplaceAll[y\_g[n], 
          solset3\_\(\(\[LeftDoubleBracket]\)\(1, \
1\)\(\[RightDoubleBracket]\)\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n]  =  \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n]  =  \>", Collect[y[n], \ y\_0]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Which can be written in the desired form   ",
  Cell[BoxData[
      \(y[
          n]\ \  = \ \ \(y\_0\) 
            a\^n\ \  + \ \ \(\(\(a\^n\)\(-\)\(1\)\(\ \)\)\/\(a - 1\)\) b\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.11 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Start with the difference equation  ",
  Cell[BoxData[
      \(y[n + 1]\  = \ a\ y[n] + b\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(y = 0; \ Remove[y]; \ Clear[a, b, n, y];\), "\[IndentingNewLine]", 
    \(\(DE\  = \ 
        y[n + 1]\  \[Equal] \ a\ y[n] + b;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the difference equation\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\ DE\ ];\)\)}], "Input"],

Cell["Take the z-transform of both sides.", "Text"],

Cell[BoxData[{
    \(\(Clear[Y];\)\ \), "\[IndentingNewLine]", 
    \(\(eqn\  = \ 
        z\ \((Y[z]\  - \ y\_0)\)\  \[Equal] \ 
          a\ Y[z] + b  z\/\(z - 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ DE\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The z-transform is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ eqn\ ];\)\)}], "Input"],

Cell[TextData[{
  "Solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  "  and get  ",
  Cell[BoxData[
      \(Y \((z)\)\  = \ \(b\ z - z\ y\_0 + z\^2\ y\_0\)\/\(\((z - 1)\)\ \((z \
- a)\)\)\)]],
  ".  Then expand and obtain "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[Y];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ DE\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The z-transform is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ eqn\ ];\)\), "\[IndentingNewLine]", 
    \(\(solset = 
        MapAll[Together, 
          Solve[z\ \((Y[z]\  - \ y\_0)\) \[Equal] 
              a\ Y[z] + b \(\(\ \)\(z\)\)\/\(z - 1\), 
            Y[z]\ ]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve for Y[z]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Y[z_] = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y[z] = \>", Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Y[z_] = MapAll[Apart, Y[z]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y[z] = \>", Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Y[z_] = \(y\_0\) z\/\(\(-a\) + z\) + 
          Apart[\(b\ z\)\/\(\((\(-1\) + z)\)\ \((\(-a\) + z)\)\)];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Y[z] = \>", Y[z]\ ];\)\)}], "Input"],

Cell["Find the inverse z-transform.", "Text"],

Cell[BoxData[{
    \(\(y[n_]\  = \ 
        InverseZTransform[Y[z], z, n];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = \!\(\[GothicCapitalZ]\^\(-1\)\)[Y[z]] = \!\(\
\[GothicCapitalZ]\^\(-1\)\)[\>\"", 
        Y[z], "\<]\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", 
        Collect[FullSimplify[y[n]], y\_0]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Which can be written in the desired form   ",
  Cell[BoxData[
      \(y[
          n]\ \  = \ \ \(y\_0\) 
            a\^n\ \  + \ \ \(\(\(a\^n\)\(-\)\(1\)\(\ \)\)\/\(a - 1\)\) b\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.11 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Start with the formula for the z-transform that we found in part (b):  ",
  Cell[BoxData[
      \(Y \((z)\)\  = \ \(b\ z - z\ y\_0 + z\^2\ y\_0\)\/\(\((z - 1)\)\ \((z \
- a)\)\)\)]],
  ".  Then use the Corollary and residues to find  ",
  Cell[BoxData[
      \(\(\[GothicCapitalZ]\^\(-1\)\)[Y \((z)\)]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(y[n_] = 
        Residue[\(\(b\ z - z\ y\_0 + 
                    z\^2\ y\_0\)\/\(\((z - 1)\)\ \((z - a)\)\)\) 
              z\^\(n - 1\), {z, 1}] + 
          Residue[\(\(b\ z - z\ y\_0 + 
                    z\^2\ y\_0\)\/\(\((z - 1)\)\ \((z - a)\)\)\) 
              z\^\(n - 1\), {z, a}];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[\!\(\(b\\\ z - z\\\ y\_0 + z\^2\\\ y\_0\)\/\(\((z - \
1)\)\\\ \((z - a)\)\)\)\!\(z\^\(n - 1\)\),1] = \>\"", 
        Residue[\(\(b\ z - z\ y\_0 + 
                  z\^2\ y\_0\)\/\(\((z - 1)\)\ \((z - a)\)\)\) 
            z\^\(n - 1\), {z, 1}]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[\!\(\(b\\\ z - z\\\ y\_0 + z\^2\\\ y\_0\)\/\(\((z - \
1)\)\\\ \((z - a)\)\)\)\!\(z\^\(n - 1\)\),a] = \>\"", 
        Residue[\(\(b\ z - z\ y\_0 + 
                  z\^2\ y\_0\)\/\(\((z - 1)\)\ \((z - a)\)\)\) 
            z\^\(n - 1\), {z, a}]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = Res[\!\(\(b\\\ z - z\\\ y\_0 + z\^2\\\ y\_0\)\/\(\
\((z - 1)\)\\\ \((z - a)\)\)\)\!\(z\^\(n - 1\)\),1] + Res[\!\(\(b\\\ z - z\\\ \
y\_0 + z\^2\\\ y\_0\)\/\(\((z - 1)\)\\\ \((z - a)\)\)\)\!\(z\^\(n - \
1\)\),a]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", 
        Collect[FullSimplify[y[n]], y\_0]\ ];\)\)}], "Input"],

Cell[BoxData[{\(y[n_] = 
        Residue[\(\(b\ z - z\ y\_0 + 
                    z\^2\ y\_0\)\/\(\((z - 1)\)\ \((z - a)\)\)\) 
              z\^\(n - 1\), {z, 1}] + 
          Residue[\(\(b\ z - z\ y\_0 + 
                    z\^2\ y\_0\)\/\(\((z - 1)\)\ \((z - a)\)\)\) 
              z\^\(n - 1\), {z, a}];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\<Res[Y[z]\!\(z\^\(n - 1\)\)\!\(\*
StyleBox[\",\",\nFontFamily->\"Times New Roman\",\nFontSize->12,\n\
FontWeight->\"Plain\",\nFontSlant->\"Plain\",\nFontColor->GrayLevel[0],\n\
FontVariations->{\"Underline\"->False,\n\"StrikeThrough\"->False}]\)1] = \
\!\(lim\+\(z \[Rule] 2\)\) \>\"", 
          ",", \(Together[\((z - 1)\) Y[z]] z\^\(n - 1\)\), ",", 
          "\"\< = \>\"", 
          ",", \(Limit[\((z - 1)\) Y[z] z\^\(n - 1\), z \[Rule] 1]\)}], " ", 
        "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\<Res[Y[z]\!\(z\^\(n - 1\)\)\!\(\*
StyleBox[\",\",\nFontFamily->\"Times New Roman\",\nFontSize->12,\n\
FontWeight->\"Plain\",\nFontSlant->\"Plain\",\nFontColor->GrayLevel[0],\n\
FontVariations->{\"Underline\"->False,\n\"StrikeThrough\"->False}]\)a] = \
\!\(lim\+\(z \[Rule] 3\)\) \>\"", 
          ",", \(Together[\((z - a)\) Y[z] z\^\(n - 1\)]\), ",", 
          "\"\< = \>\"", 
          ",", \(Limit[\((z - a)\) Y[z] z\^\(n - 1\), z \[Rule] a]\)}], " ", 
        "]"}], ";"}], "\[IndentingNewLine]", \(Print["\<y[n] = \>", 
        Limit[\((z - 1)\) Y[z] z\^\(n - 1\), z \[Rule] 1] + 
          Limit[\((z - a)\) Y[z] z\^\(n - 1\), 
            z \[Rule] a]\ ];\), "\[IndentingNewLine]", \(Print["\<y[n] = \>", 
        y[n]\ ];\), "\[IndentingNewLine]", \(Print["\<y[n] = \>", 
        Collect[FullSimplify[y[n]], y\_0]\ ];\)}], "Input"],

Cell[TextData[{
  "Which can be written in the desired form   ",
  Cell[BoxData[
      \(y[
          n]\ \  = \ \ \(y\_0\) 
            a\^n\ \  + \ \ \(\(\(a\^n\)\(-\)\(1\)\(\ \)\)\/\(a - 1\)\) b\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.11 (d).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "The solution to the homogeneous equation  ",
  Cell[BoxData[
      \(y\_h[n + 1]\  - \ a\ y\_h[n]\  = \ 0\)]],
  "   is   ",
  Cell[BoxData[
      \(y\_h[n]\  = \ \(c\_1\) a\^n\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(y\_h[n_]\  = \ \(c\_1\) a\^n;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Solve \!\(y\_h\)[n+1] - a \!\(y\_h\)[n] = 0\>\""];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(y\_h\)[n] = \>\"", 
        y\_h[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Verify it\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_h\)[n+1] = \>\"", 
        y\_h[n + 1]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_h\)[n+1] - a \!\(y\_h\)[n] = \>\"", \ 
        y\_h[n + 1], "\< - \>", a\ , "\< \>", 
        y\_h[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_h\)[n+1] - a \!\(y\_h\)[n] = \>\"", \ 
        y\_h[n + 1], "\< - \>", a\ y\_h[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_h\)[n+1] - a \!\(y\_h\)[n] = \>\"", \ 
        y\_h[n + 1] - \ a\ y\_h[n]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The transfer function is  ",
  Cell[BoxData[
      \(H \((z)\) = 1\/\(1\  - \ a\ z\^\(-1\)\)\)]],
  "  and the unit-sample response is   ",
  Cell[BoxData[
      \(h[n]\  = \ \(\(\[GothicCapitalZ]\^\(-1\)\) \((H \((z)\))\)\  = \ 
          a\^n\)\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(H[z_] = 1\/\(1 - a\ z\^\(-1\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(h[n_] = InverseZTransform[H[z], z, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The transfer function H(z) = \>", 
        H \((z)\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Unit-sample response  h[n] = \>", h[n]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "The input sequence is  ",
  Cell[BoxData[
      \(x[n] = b\)]],
  "  and it's z-transform is   ",
  Cell[BoxData[
      \(X \((z)\) = \(b\ z\)\/\(z - 1\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(x[n_] = b;\)\), "\n", 
    \(\(X[z_] = ZTransform[x[n], n, z];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The input sequence  x[n] = \>", 
        x[n]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<It's  z-transform   X[z] = \>", X[z]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "The particular solution is calculated with the formula  ",
  Cell[BoxData[
      \(y\_p[
          n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\) \((X \((z)\) 
              H \((z)\))\)\)]],
  "  as follows: "
}], "Text"],

Cell[BoxData[{
    \(\(Y[z_] = X[z] H[z];\)\), "\[IndentingNewLine]", 
    \(\(y\_p[n_]\  = \ 
        InverseZTransform[Y[z], z, n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The particular solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(y\_p\)[n] = \
\!\(\[GothicCapitalZ]\^\(-1\)\)(Y[z])\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(y\_p\)[n] = \
\!\(\[GothicCapitalZ]\^\(-1\)\)(X[z]H[z])\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(y\_p\)[n] = \!\(\[GothicCapitalZ]\^\(-1\)\)(\>\"", 
        X[z], H[z], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(y\_p\)[n] = \!\(\[GothicCapitalZ]\^\(-1\)\)(\>\"", 
        X[z] H[z], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(y\_p\)[n] = \>\"", 
        y\_p[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_p\)[n]} = \>\"", 
        Table[y\_p[n], {n, 0, 9}]\ ];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Details",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(y\_p\)[n] = \!\(\[GothicCapitalZ]\^\(-1\)\)(\>\"", 
        Y[z], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Y[z_] = Apart[Y[z]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(y\_p\)[n] = \!\(\[GothicCapitalZ]\^\(-1\)\)(\>\"", 
        Y[z], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(y\_p\)[n] = \!\(\[GothicCapitalZ]\^\(-1\)\)(\>\"", \
\(Y[z]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), \
\*"\"\<) + \!\(\[GothicCapitalZ]\^\(-1\)\)(\>\"", \(Y[z]\)\_\(\(\
\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\), \*"\"\<) + \!\(\
\[GothicCapitalZ]\^\(-1\)\)(\>\"", \
\(Y[z]\)\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\), \
"\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(y\_p[n_]\  = \ 
        InverseZTransform[\(Y[z]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\), z, n] + 
          InverseZTransform[\(Y[z]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), z, n] + 
          InverseZTransform[\(Y[z]\)\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\), z, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(y\_p\)[n] = \>\"", 
        y\_p[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(y\_p[0]\  = \ y\_p[0];\)\), "\[IndentingNewLine]", 
    \(\(y\_p[n_]\  = \ 
        FullSimplify[y\_p[n], n > 1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(y\_p\)[0] = \>\"", 
        y\_p[0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(y\_p\)[n] = \>\"", 
        y\_p[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(y\_p[n_]\  = \ 
        ReplaceAll[y\_p[n], 
          KroneckerDelta[n] \[Rule] 0];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(y\_p\)[0] = \>\"", 
        y\_p[0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(y\_p\)[n] = \>\"", y\_p[n]\ ];\)\)}], "Input"]
}, Open  ]],

Cell[TextData[{
  "In convolution form  ",
  Cell[BoxData[
      \(y\_p[
          n]\  = \ \(x[n]*
            h[n]\  = \ \[Sum]\+\(i = 0\)\%n x[n - i] h[i]\)\)]],
  "  and we have \n\n\t\t",
  Cell[BoxData[
      \(y\_p[
          n]\  = \ \(\[Sum]\+\(i = 0\)\%n\ 
            b\ a\^i\  = \ \(\((a\^\(1 + n\) - 1)\)\ b\)\/\(a - 1\)\)\)]]
}], "Text"],

Cell[BoxData[{
    \(\(yp[
          n_] = \[Sum]\+\(i = 0\)\%n x[n - i] 
            h[i];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_p\)[n] = \!\(\[Sum]\+\(i = \
0\)\%n\)x[n-i]h[i]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_p\)[n] = \!\(\[Sum]\+\(i = 0\)\%n\)\>\"", "\< \
\>", x[n - i], h[i]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_p\)[n] = \>\"", yp[n]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The particular solution  ",
  Cell[BoxData[
      \(y\_p[n]\)]],
  "  obtained by using convolution has the initial condition  ",
  Cell[BoxData[
      \(y\_p[
          0]\  = \ \(\[Sum]\+\(i = 0\)\%0 x[0 - i] h[i]\  = \ \(x[0] 
              h[0]\  = \ \(x[0]\  = \ b\)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "The total solution to the nonhomogeneous difference equation is  \n\n\t\t\
",
  Cell[BoxData[
      \(y[
          n]\  = \ \(y\_h[n] + 
            y\_p[n]\  = \ \(c\_1\) a\^n\  + \ \[Sum]\+\(i = 0\)\%n\ 
              b\ a\^i\)\)]],
  "  \n\n\t\t",
  Cell[BoxData[
      \(y[
          n]\  = \ \(c\_1\) 
            a\^n\  + \ \(\((a\^\(1 + n\) - 1)\)\ b\)\/\(a - 1\)\)]],
  "  "
}], "Text"],

Cell[BoxData[{
    \(\(y[n_] = y\_p[n] + y\_h[n];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_p\)[n] = \>\"", 
        y\_p[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_h\)[n] = \>\"", 
        y\_h[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< y[n] = \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Now we compute  ",
  Cell[BoxData[
      \(y\_0\  = \ \(y[
            0]\  = \ \(\(c\_1\) 
                a\^0\  + \ \(\((a - 1)\)\ b\)\/\(a - 1\)\  = \ 
            c\_1\  + \ b\)\)\)]],
  ",  and solve for the constant  ",
  Cell[BoxData[
      \(c\_1\  = \ y\_0 - \ b\)]],
  "  which will produce the proper initial condition.  Therefore, \n \n \t\t\
",
  Cell[BoxData[
      \(y[
          n]\  = \ \((y\_0 - b)\) 
            a\^n\  + \ \(\((a\^\(1 + n\) - 1)\)\ b\)\/\(a - 1\)\)]],
  ",  \n \n which can be arranged to yield   ",
  Cell[BoxData[
      \(y[
          n]\  = \ \(y\_0\) 
            a\^n + \ \(\(a\^n\)\(-\)\(1\)\(\ \)\)\/\(a - 1\)\ b\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(y[n_] = y\_p[n] + y\_h[n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< y[n] = \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(solset = Solve[y[0] \[Equal] y\_0, c\_1];\)\), "\n", 
    \(\(Print["\<Substitute  \>", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
1\)\(\[RightDoubleBracket]\)\)];\)\), "\n", 
    \(\(y[n_] = 
        ReplaceAll[y[n], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\), "\n", 
    \(\(Print["\< y[n] = \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(y[n_] = 
        Collect[Simplify[Together[y[n]]], y\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< y[n] = \>", y[n]\ ];\)\)}], "Input"],

Cell[TextData[{
  "We can explore the situation when  ",
  Cell[BoxData[
      \(y\_0 = 0\)]],
  ",  ",
  Cell[BoxData[
      \(a = 4\/5\)]],
  "  and  ",
  Cell[BoxData[
      \(b = 1\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(y\_0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(a = 4\/5;\)\), "\[IndentingNewLine]", 
    \(\(b = 1;\)\), "\[IndentingNewLine]", 
    \(\(y[
          n_] = \(y\_0\) a\^n\  + \(\(\(a\^n\)\(-\)\(1\)\(\ \)\)\/\(a - 1\)\) 
            b;\)\ \), "\[IndentingNewLine]", 
    \(\(m0 = 20;\)\), "\[IndentingNewLine]", 
    \(\(Y1\  = \ N[Table[y[i], {i, 0, m0}]];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Figure1 = 
        ListPlot[Y1pts, PlotJoined \[Rule] False, 
          PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Figure1 = 
        Show[Figure1, 
          PlotRange \[Rule] {{\(-0.4\), m0 + 0.4}, {\(-0.15\), 5}}, 
          Ticks \[Rule] {Range[0, m0, 5], Range[0, 5, 1]}, 
          AxesLabel \[Rule] {"\<n\>", "\<y[n]\>"}, 
          DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", Expand[y[n]]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Figure 9.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The solution to ",
  Cell[BoxData[
      \(y[n + 1] = \(5\/4\) y[n] + 1\)]],
  " with ",
  Cell[BoxData[
      \(y[0] = \(y\_0 = 0\)\)]],
  "."
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["The z-Transform",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ZTransformBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Nyquist Stability Criterion",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/NyquistStabilityBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{996, 633},
WindowMargins->{{Automatic, 7}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageHeaderLines->{Inherited, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {36, 54}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->False},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[9524, 298, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[20685, 651, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[72603, 1952, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[92813, 2410, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 220744, 5762}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 130, 2, 33, "Text"],
Cell[2235, 66, 820, 16, 128, "Text"],
Cell[3058, 84, 111, 2, 33, "Text"],
Cell[3172, 88, 2004, 61, 71, "Text"],
Cell[5179, 151, 1697, 54, 188, "Text"],
Cell[6879, 207, 1150, 33, 147, "Text"],
Cell[8032, 242, 1142, 40, 119, "Text"],

Cell[CellGroupData[{
Cell[9199, 286, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[9347, 292, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[9524, 298, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[9884, 310, 5759, 188, 182, "Text"],
Cell[15646, 500, 2471, 72, 219, "Text"],
Cell[18120, 574, 2195, 60, 94, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20340, 638, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[20488, 644, 194, 5, 33, "Text",
  Evaluatable->False],
Cell[20685, 651, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[21045, 663, 2164, 68, 110, "Text"],
Cell[23212, 733, 1684, 55, 94, "Text"],
Cell[24899, 790, 1539, 43, 43, "Text"],
Cell[26441, 835, 417, 11, 71, "Text"],

Cell[CellGroupData[{
Cell[26883, 850, 111, 2, 33, "Text"],
Cell[26997, 854, 1701, 26, 415, "Input"],
Cell[28701, 882, 176, 6, 71, "Text"],
Cell[28880, 890, 676, 10, 132, "Input"]
}, Closed]],
Cell[29571, 903, 3060, 77, 40, "Text"],
Cell[32634, 982, 639, 16, 154, "Text"],

Cell[CellGroupData[{
Cell[33298, 1002, 111, 2, 33, "Text"],
Cell[33412, 1006, 1681, 27, 406, "Input"],
Cell[35096, 1035, 292, 9, 115, "Text"],
Cell[35391, 1046, 185, 6, 71, "Text"],
Cell[35579, 1054, 279, 4, 81, "Input"],
Cell[35861, 1060, 372, 6, 101, "Input"]
}, Closed]],
Cell[36248, 1069, 497, 23, 34, "Text"],
Cell[36748, 1094, 640, 13, 164, "Text"],

Cell[CellGroupData[{
Cell[37413, 1111, 111, 2, 33, "Text"],
Cell[37527, 1115, 1212, 19, 311, "Input"],
Cell[38742, 1136, 163, 8, 36, "Text"],
Cell[38908, 1146, 1306, 20, 321, "Input"],
Cell[40217, 1168, 1307, 20, 321, "Input"],
Cell[41527, 1190, 185, 6, 71, "Text"],
Cell[41715, 1198, 326, 5, 102, "Input"],
Cell[42044, 1205, 419, 7, 122, "Input"]
}, Closed]],
Cell[42478, 1215, 493, 20, 33, "Text"],
Cell[42974, 1237, 746, 15, 165, "Text"],

Cell[CellGroupData[{
Cell[43745, 1256, 111, 2, 33, "Text"],
Cell[43859, 1260, 1263, 20, 312, "Input"],
Cell[45125, 1282, 174, 8, 36, "Text"],
Cell[45302, 1292, 1468, 23, 365, "Input"],
Cell[46773, 1317, 1463, 23, 365, "Input"],
Cell[48239, 1342, 185, 6, 71, "Text"],
Cell[48427, 1350, 352, 6, 102, "Input"],
Cell[48782, 1358, 553, 10, 142, "Input"]
}, Closed]],
Cell[49350, 1371, 2030, 64, 261, "Text"],
Cell[51383, 1437, 509, 21, 38, "Text"],
Cell[51895, 1460, 2695, 53, 365, "Text"],

Cell[CellGroupData[{
Cell[54615, 1517, 111, 2, 33, "Text"],
Cell[54729, 1521, 2005, 41, 489, "Input"],
Cell[56737, 1564, 287, 8, 74, "Text"],
Cell[57027, 1574, 1338, 22, 357, "Input"],
Cell[58368, 1598, 1348, 22, 357, "Input"],
Cell[59719, 1622, 53, 0, 33, "Text"],
Cell[59775, 1624, 1019, 17, 123, "Input"],
Cell[60797, 1643, 171, 8, 36, "Text"],
Cell[60971, 1653, 1387, 22, 328, "Input"],
Cell[62361, 1677, 1387, 22, 328, "Input"],
Cell[63751, 1701, 185, 6, 71, "Text"],
Cell[63939, 1709, 818, 14, 155, "Input"],
Cell[64760, 1725, 1077, 21, 173, "Input"],
Cell[65840, 1748, 248, 9, 71, "Text"],
Cell[66091, 1759, 981, 18, 227, "Input"],
Cell[67075, 1779, 892, 17, 239, "Input"]
}, Closed]],
Cell[67982, 1799, 2104, 58, 490, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[70111, 1861, 101, 2, 33, "Text"],
Cell[70215, 1865, 539, 10, 94, "Input"]
}, Closed]],
Cell[70769, 1878, 1464, 57, 265, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[72258, 1939, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[72406, 1945, 194, 5, 33, "Text",
  Evaluatable->False],
Cell[72603, 1952, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{
Cell[72985, 1966, 137, 2, 30, "Text"],
Cell[73125, 1970, 3836, 65, 772, "Input",
  InitializationCell->True],
Cell[76964, 2037, 5684, 90, 960, "Input",
  InitializationCell->True]
}, Closed]],
Cell[82663, 2130, 402, 12, 34, "Text"],

Cell[CellGroupData[{
Cell[83090, 2146, 103, 2, 33, "Text"],
Cell[83196, 2150, 714, 18, 201, "Text"],
Cell[83913, 2170, 354, 11, 84, "Text"],
Cell[84270, 2183, 2633, 67, 180, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[86940, 2255, 111, 2, 30, "Text"],
Cell[87054, 2259, 817, 14, 210, "Input"],
Cell[87874, 2275, 2106, 38, 408, "Input"]
}, Closed]],
Cell[89995, 2316, 136, 3, 30, "Text"],
Cell[90134, 2321, 1347, 40, 147, "Text"],
Cell[91484, 2363, 979, 31, 109, "Text"],

Cell[CellGroupData[{
Cell[92488, 2398, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[92636, 2404, 174, 4, 33, "Text",
  Evaluatable->False],
Cell[92813, 2410, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[93173, 2422, 3465, 84, 567, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[96663, 2510, 101, 2, 33, "Text"],
Cell[96767, 2514, 1058, 18, 170, "Input"],
Cell[97828, 2534, 1098, 22, 246, "Input"]
}, Closed]],
Cell[98941, 2559, 327, 11, 36, "Text"],
Cell[99271, 2572, 1186, 35, 196, "Text"],
Cell[100460, 2609, 1882, 51, 242, "Text"],
Cell[102345, 2662, 2220, 57, 337, "Text"],
Cell[104568, 2721, 986, 34, 62, "Text"],

Cell[CellGroupData[{
Cell[105579, 2759, 103, 2, 33, "Text"],
Cell[105685, 2763, 2458, 57, 182, "Text"],
Cell[108146, 2822, 2133, 48, 174, "Text"],
Cell[110282, 2872, 1887, 44, 203, "Text"],
Cell[112172, 2918, 2144, 48, 232, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[114353, 2971, 111, 2, 30, "Text"],
Cell[114467, 2975, 949, 17, 264, "Input"],
Cell[115419, 2994, 949, 17, 264, "Input"],
Cell[116371, 3013, 903, 25, 227, "Text"],
Cell[117277, 3040, 1252, 20, 317, "Input"],
Cell[118532, 3062, 119, 2, 63, "Input"],
Cell[118654, 3066, 119, 2, 63, "Input"],
Cell[118776, 3070, 119, 2, 63, "Input"],
Cell[118898, 3074, 119, 2, 63, "Input"],
Cell[119020, 3078, 119, 2, 63, "Input"],
Cell[119142, 3082, 119, 2, 63, "Input"]
}, Closed]],
Cell[119276, 3087, 1415, 44, 296, "Text"],
Cell[120694, 3133, 4210, 101, 365, "Text"],

Cell[CellGroupData[{
Cell[124929, 3238, 101, 2, 33, "Text"],
Cell[125033, 3242, 324, 11, 109, "Text"],
Cell[125360, 3255, 882, 17, 250, "Input"],
Cell[126245, 3274, 379, 12, 109, "Text"],
Cell[126627, 3288, 1047, 20, 250, "Input"],
Cell[127677, 3310, 346, 11, 112, "Text"],
Cell[128026, 3323, 1005, 19, 250, "Input"],
Cell[129034, 3344, 578, 16, 115, "Text"],
Cell[129615, 3362, 54, 0, 33, "Text"],
Cell[129672, 3364, 521, 10, 174, "Input"],
Cell[130196, 3376, 536, 15, 147, "Text"],
Cell[130735, 3393, 1327, 26, 343, "Text"],
Cell[132065, 3421, 464, 10, 103, "Input"],
Cell[132532, 3433, 129, 5, 33, "Text"],
Cell[132664, 3440, 1038, 23, 250, "Input"]
}, Closed]],
Cell[133717, 3466, 516, 16, 106, "Text"],
Cell[134236, 3484, 957, 26, 185, "Text"],
Cell[135196, 3512, 1068, 35, 223, "Text"],
Cell[136267, 3549, 1985, 57, 149, "Text"],
Cell[138255, 3608, 1838, 59, 385, "Text"],
Cell[140096, 3669, 507, 14, 108, "Text"],
Cell[140606, 3685, 621, 22, 71, "Text"],

Cell[CellGroupData[{
Cell[141252, 3711, 103, 2, 33, "Text"],
Cell[141358, 3715, 297, 9, 74, "Text"],
Cell[141658, 3726, 316, 10, 80, "Text"],
Cell[141977, 3738, 879, 27, 188, "Text"],
Cell[142859, 3767, 3825, 89, 298, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[146721, 3861, 111, 2, 30, "Text"],
Cell[146835, 3865, 169, 5, 33, "Text"],
Cell[147007, 3872, 1195, 23, 310, "Input"],
Cell[148205, 3897, 773, 14, 211, "Input"],
Cell[148981, 3913, 51, 0, 33, "Text"],
Cell[149035, 3915, 322, 6, 71, "Input"],
Cell[149360, 3923, 176, 6, 71, "Text"],
Cell[149539, 3931, 528, 10, 98, "Input"],
Cell[150070, 3943, 133, 3, 33, "Text"],
Cell[150206, 3948, 562, 10, 93, "Input"],
Cell[150771, 3960, 272, 8, 71, "Text"],
Cell[151046, 3970, 704, 15, 150, "Input"],
Cell[151753, 3987, 151, 5, 33, "Text"],
Cell[151907, 3994, 1910, 34, 107, "Input"],
Cell[153820, 4030, 303, 12, 71, "Text"],
Cell[154126, 4044, 778, 15, 230, "Input"]
}, Closed]],
Cell[154919, 4062, 625, 22, 68, "Text"],

Cell[CellGroupData[{
Cell[155569, 4088, 104, 2, 33, "Text"],
Cell[155676, 4092, 287, 9, 76, "Text"],
Cell[155966, 4103, 373, 13, 82, "Text"],
Cell[156342, 4118, 942, 27, 190, "Text"],
Cell[157287, 4147, 4442, 101, 349, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[161766, 4253, 112, 2, 30, "Text"],
Cell[161881, 4257, 170, 5, 33, "Text"],
Cell[162054, 4264, 1192, 23, 310, "Input"],
Cell[163249, 4289, 770, 14, 211, "Input"],
Cell[164022, 4305, 51, 0, 33, "Text"],
Cell[164076, 4307, 322, 6, 71, "Input"],
Cell[164401, 4315, 176, 6, 71, "Text"],
Cell[164580, 4323, 730, 14, 134, "Input"],
Cell[165313, 4339, 133, 3, 33, "Text"],
Cell[165449, 4344, 722, 12, 133, "Input"],
Cell[166174, 4358, 272, 8, 71, "Text"],
Cell[166449, 4368, 766, 16, 151, "Input"],
Cell[167218, 4386, 152, 5, 33, "Text"],
Cell[167373, 4393, 2583, 46, 141, "Input"],
Cell[169959, 4441, 303, 12, 71, "Text"],
Cell[170265, 4455, 775, 15, 230, "Input"]
}, Closed]],
Cell[171055, 4473, 874, 30, 106, "Text"],

Cell[CellGroupData[{
Cell[171954, 4507, 104, 2, 33, "Text"],
Cell[172061, 4511, 108, 2, 33, "Text"],
Cell[172172, 4515, 602, 20, 90, "Text"],
Cell[172777, 4537, 1420, 42, 360, "Text"],
Cell[174200, 4581, 108, 2, 33, "Text"],
Cell[174311, 4585, 306, 9, 74, "Text"],
Cell[174620, 4596, 444, 13, 81, "Text"],
Cell[175067, 4611, 1100, 32, 196, "Text"],
Cell[176170, 4645, 106, 2, 33, "Text"],
Cell[176279, 4649, 4632, 103, 403, "Text"],
Cell[180914, 4754, 108, 2, 33, "Text"],
Cell[181025, 4758, 219, 8, 33, "Text"],
Cell[181247, 4768, 284, 9, 36, "Text"],
Cell[181534, 4779, 195, 8, 36, "Text"],
Cell[181732, 4789, 1009, 23, 250, "Text"],
Cell[182744, 4814, 353, 11, 77, "Text"],
Cell[183100, 4827, 319, 10, 33, "Text"],
Cell[183422, 4839, 506, 12, 140, "Text"],
Cell[183931, 4853, 706, 22, 121, "Text"]
}, Closed]],
Cell[184652, 4878, 548, 18, 33, "Text"],
Cell[185203, 4898, 10349, 173, 197, 10235, 169, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[195555, 5073, 267, 11, 36, "Text"],

Cell[CellGroupData[{
Cell[195847, 5088, 116, 2, 33, "Text"],
Cell[195966, 5092, 377, 11, 52, "Text"],
Cell[196346, 5105, 1236, 25, 310, "Input"],
Cell[197585, 5132, 232, 8, 33, "Text"],
Cell[197820, 5142, 1122, 23, 290, "Input"],
Cell[198945, 5167, 119, 4, 33, "Text"],
Cell[199067, 5173, 195, 3, 50, "Input"],
Cell[199265, 5178, 125, 5, 33, "Text"],
Cell[199393, 5185, 969, 18, 230, "Input"],
Cell[200365, 5205, 220, 7, 36, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[200622, 5217, 116, 2, 30, "Text"],
Cell[200741, 5221, 133, 5, 33, "Text"],
Cell[200877, 5228, 300, 6, 90, "Input"],
Cell[201180, 5236, 51, 0, 33, "Text"],
Cell[201234, 5238, 359, 7, 122, "Input"],
Cell[201596, 5247, 240, 9, 40, "Text"],
Cell[201839, 5258, 1035, 20, 278, "Input"],
Cell[202877, 5280, 45, 0, 33, "Text"],
Cell[202925, 5282, 427, 8, 91, "Input"],
Cell[203355, 5292, 220, 7, 36, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[203612, 5304, 116, 2, 30, "Text"],
Cell[203731, 5308, 345, 9, 40, "Text"],
Cell[204079, 5319, 1448, 25, 229, "Input"],
Cell[205530, 5346, 1805, 33, 165, "Input"],
Cell[207338, 5381, 220, 7, 36, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[207595, 5393, 116, 2, 30, "Text"],
Cell[207714, 5397, 219, 8, 33, "Text"],
Cell[207936, 5407, 926, 16, 190, "Input"],
Cell[208865, 5425, 289, 9, 36, "Text"],
Cell[209157, 5436, 347, 5, 103, "Input"],
Cell[209507, 5443, 195, 8, 36, "Text"],
Cell[209705, 5453, 288, 5, 90, "Input"],
Cell[209996, 5460, 233, 7, 33, "Text"],
Cell[210232, 5469, 946, 16, 194, "Input"],

Cell[CellGroupData[{
Cell[211203, 5489, 97, 2, 33, "Text"],
Cell[211303, 5493, 1884, 34, 274, "Input"]
}, Open  ]],
Cell[213202, 5530, 351, 11, 77, "Text"],
Cell[213556, 5543, 433, 8, 157, "Input"],
Cell[213992, 5553, 402, 13, 33, "Text"],
Cell[214397, 5568, 413, 14, 117, "Text"],
Cell[214813, 5584, 355, 7, 110, "Input"],
Cell[215171, 5593, 701, 22, 121, "Text"],
Cell[215875, 5617, 691, 14, 170, "Input"],
Cell[216569, 5633, 207, 11, 36, "Text"],
Cell[216779, 5646, 1167, 23, 299, "Input"],
Cell[217949, 5671, 261, 11, 36, "Text"]
}, Closed]],
Cell[218225, 5685, 290, 7, 30, "Text"],
Cell[218518, 5694, 311, 10, 33, "Text"],
Cell[218832, 5706, 336, 11, 33, "Text"],
Cell[219171, 5719, 257, 5, 33, "Text"],
Cell[219431, 5726, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

