(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    289552,       6700]*)
(*NotebookOutlinePosition[    290780,       6741]*)
(*  CellTagsIndexPosition[    290703,       6735]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[{
  StyleBox["9.2  Second Order Homogeneous Difference Equations",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\tBefore proceeding with the ",
    FontFamily->"Times New Roman"],
  StyleBox["z",
    FontFamily->"Courier New"],
  StyleBox["-transform method, we mention a heuristic method based on \
substitution of a trial solution.  Consider the second order homogeneous ",
    FontFamily->"Times New Roman"],
  "linear constant-coefficient difference equation (HLCCDE) ",
  StyleBox["\n\n",
    FontFamily->"Times New Roman"],
  StyleBox["(9-8)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\t\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\ \  = \ \ 0\)]],
  ",  ",
  StyleBox["\n\nwhere ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"a", "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "b"}]]],
  StyleBox[" are constants.  Using the trial solution  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n] = r\^n\)]],
  ",  and direct substitution into ",
  StyleBox["(9-8)",
    FontColor->RGBColor[0, 0, 1]],
  " produces the equation  ",
  Cell[BoxData[
      \(r\^\(n + 2\) - 2\ a\ r\^\(n + 1\)\  + \ b\ r\^n\  = \ 0\)]],
  ",  and dividing through by ",
  Cell[BoxData[
      \(r\^n\)]],
  " produces the characteristic polynomial  ",
  Cell[BoxData[
      \(r\^2\  - \ 2\ a\ r\  + \ b\)]],
  "  and characteristic equation \n\n",
  StyleBox["(9-9)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(r\^2\  - \ 2\ a\ r\  + \ b\ \  = \ \ 0\)]],
  ". \n\nThere are three types of solutions to ",
  StyleBox["(9-8)",
    FontColor->RGBColor[0, 0, 1]],
  " which are determined by the nature of the roots in ",
  StyleBox["(9-9)",
    FontColor->RGBColor[0, 0, 1]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["Case (i)",
    FontColor->RGBColor[0, 0, 1]],
  "  If   ",
  Cell[BoxData[
      \(b < a\^2\)]],
  "  then we have real distinct roots   ",
  Cell[BoxData[
      \(r\_1 = a - \@\(a\^2 - b\)\)]],
  "  and  ",
  Cell[BoxData[
      \(r\_2 = a + \@\(a\^2 - b\)\)]],
  ",  and  \n\n",
  StyleBox["(9-10)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(y[n]\ \  = \ \ \(c\_1\) r\_1\%n\ \  + \ \ \(c\_2\) r\_2\%n\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["Case (ii)",
    FontColor->RGBColor[0, 0, 1]],
  "  If   ",
  Cell[BoxData[
      \(b = a\^2\)]],
  "   then we have a double real root   ",
  Cell[BoxData[
      \(r = \(r\_1 = \(r\_2 = a\)\)\)]],
  ",  and  \n\n",
  StyleBox["(9-11)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(y[n]\ \  = \ \ \(c\_1\) r\^n\ \  + \ \ \(c\_2\) n\ r\^n\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["Case (iii)",
    FontColor->RGBColor[0, 0, 1]],
  "  If   ",
  Cell[BoxData[
      \(b > a\^2\)]],
  "   then we have complex roots   ",
  Cell[BoxData[
      \(r\_1 = a - \[ImaginaryI] \@\( b - a\^2\)\)]],
  "  and  ",
  Cell[BoxData[
      \(r\_2 = a + \[ImaginaryI] \@\( b - a\^2\)\)]],
  ",  and    \n\n",
  StyleBox["(9-12)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(y[n]\ \  = \ \ \(k\_1\) r\_1\%n\ \  + \ \ \(k\_2\) r\_2\%n\)]],
  ".    \n\t\n\tThe solution for case ",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  " can also be written as the following linear combination \n\t\n",
  StyleBox["(9-13)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(y[
          n]\ \  = \ \ \(c\_1\) \(r\^n\) 
            cos \((\[Phi]\ n)\)\ \  + \ \ \(c\_2\) \(r\^n\) 
            sin \((\[Phi]\ n)\)\)]],
  ",  \n\t\n\t\t\twhere  ",
  Cell[BoxData[
      \(r = \@b\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Phi] = arctan[\@\(b - a\^2\)\/a]\)]],
  ".  \n\t\n",
  StyleBox["Caution.",
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0.500008, 0.250004]],
  "  Be sure to use the value of arctan that lies in the range  ",
  Cell[BoxData[
      \(0 < \[Phi] \[LessEqual] \[Pi]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark About Stability",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tStability depends on the location of the roots of the characteristic \
polynomial.  Without loss if generality, if  ",
  Cell[BoxData[
      \(\(\(|\)\(r\_1\)\(|\)\(\(\[LessEqual]\)\(\(|\)\(r\_2\)\(|\)\(\(<\)\(1\)\
\)\)\)\)\)]],
  "  then both roots lie inside the unit circle and the solutions are \
asymptotically stable and tends to zero as  ",
  Cell[BoxData[
      \(n \[Rule] \[Infinity]\)]],
  ".   If  ",
  Cell[BoxData[
      \(r\_1 \[NotEqual] r\_2\)]],
  " and ",
  Cell[BoxData[
      \(\(\(|\)\(r\_1\)\(|\)\(\(\[LessEqual]\)\(\(|\)\(r\_2\)\(|\)\)\)\) = 
        1\)]],
  "  then a root lies on the unit circle and the solutions are stable.  If  \
",
  Cell[BoxData[
      \(r\_1 = \(r\_2 = \(\[PlusMinus]1\)\)\)]],
  "  then there is an unstable solution.  If  ",
  Cell[BoxData[
      \(\(\(1\)\(<\)\) | r\_2 | \)]],
  "  then at least one root lies outside the unit circle and there is an \
unstable solution.  "
}], "Text"],

Cell["\<\
\tThe following subroutine uses the characteristic equation to construct \
solutions to a second order homogeneous difference equation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica Subroutine (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Solution of a Difference Equation",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"],

Cell[BoxData[
    \(\(SolveDE[a0_, b0_, x0_, \[Alpha]0_, \[Beta]0_] := 
        Module[\ {}, \[IndentingNewLine]a = a0; \ 
          b = b0; \ \[Alpha] = \[Alpha]0; \ \[Beta] = \[Beta]0; \
\[IndentingNewLine]Clear[c, k, n, r, \[Rho], \[Theta], 
            y]; \ \[IndentingNewLine]x[n_] = 
            x0; \[IndentingNewLine]HLCCDE\  = \ 
            y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n] \[Equal] \ 
              ZTransform[x[n], n, z]; \ \[IndentingNewLine]CP = 
            ReplaceAll[
              HLCCDE, {y[k_] \[Rule] r\^\(k - n\)}]; \ \[IndentingNewLine]p[
              r_] = CP\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\); \ \[IndentingNewLine]solset = Solve[CP, r]; \[IndentingNewLine]r\_1 = 
            solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\); \ 
          r\_2 = solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\
\[RightDoubleBracket]\)\); \[IndentingNewLine]Print["\<The second-order \
difference equation is\>"]; \ \[IndentingNewLine]Print[
            HLCCDE]; \ \[IndentingNewLine]Print["\<\n\>", "\<The \
characteristic polynomial is\>"]; \[IndentingNewLine]Print["\<p[r] = \>", 
            p[r]\ ]; \[IndentingNewLine]Print["\<\n\>", "\<The difference \
equation has the form\>"]; \[IndentingNewLine]Print["\<b y[n] - 2 a y[n+1] + \
y[n+2] \[Equal] 0\>"]; \[IndentingNewLine]Print["\<b = \>", b, "\<,  a = \>", 
            a, \*"\"\<,  \!\(a\^2\) = \>\"", 
            a\^2\ \ ]; \[IndentingNewLine]Print["\<For this example we have  \
\>", If[b < a\^2, \*"\"\<b < \!\(a\^2\)\>\"", 
              If[b \[Equal] 
                  a\^2, \*"\"\<b = \!\(a\^2\)\>\"", \*"\"\<b > \
\!\(a\^2\)\>\""]]\ ]; \[IndentingNewLine]Print["\<\>"]; \
\[IndentingNewLine]Print["\<p[r] = \>", 
            Factor[p[r]]\ ]; \[IndentingNewLine]Print["\<The roots are \>", 
            If[b < a\^2, "\<real and distinct\>", 
              If[b \[Equal] 
                  a\^2, "\<real and equal\>", "\<complex\>"]], "\<.\>"\ ]; \
\[IndentingNewLine]Print[\*"\"\<\!\(r\_1\) = \>\"", 
            r\_1\ ]; \[IndentingNewLine]Print[\*"\"\<\!\(r\_2\) = \>\"", 
            r\_2\ ]; \[IndentingNewLine]Print["\<\n\>", "\<The general \
solution is\>"]; \[IndentingNewLine]If[r\_1 =!= r\_2, 
            y[n_] = \(c\_1\) r\_1\^n + \(c\_2\) 
                  r\_2\^n]; \[IndentingNewLine]If[r\_1 \[Equal] r\_2, 
            y[n_] = \(c\_1\) r\_1\^n + \(c\_2\) 
                  n\ r\_2\^n]; \[IndentingNewLine]Print["\<y[n] = \>", 
            If[b =!= 
                a\^2, \*"\"\<\!\(\(r\_1\%n\^\\\ \)\)\!\(c\_1\) + \
\!\(\(r\_2\%n\^\\\ \)\)\!\(c\_2\)\>\"", \*"\"\<\!\(\(r\_1\%n\^\\\ \)\)\!\(\(c\
\_1\^\\\ \)\) + \!\(\(r\_2\%n\^\\\ \)\)n \!\(c\_2\)\>\""]\ ]; \
\[IndentingNewLine]Print["\<y[n] = \>", 
            y[n], "\<\n\>"\ ]; \[IndentingNewLine]IC = {y[
                  0] \[Equal] \ \[Alpha], 
              y[1] \[Equal] \ \[Beta]}; \ \[IndentingNewLine]psol = 
            Solve[IC, {c\_1, c\_2}]; \[IndentingNewLine]y[n_] = 
            ReplaceAll[y[n], 
              psol\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
\ ]; \[IndentingNewLine]Print["\<Given the initial conditions\>"]; \
\[IndentingNewLine]Print["\<y[0] = \>", \ \[Alpha]]; \
\[IndentingNewLine]Print["\<y[1] = \>", \ \[Beta]]; \
\[IndentingNewLine]Print["\<Solve the linear system\>"]; \
\[IndentingNewLine]Print[\ 
            IC\ ]; \[IndentingNewLine]Print["\<Get\>"]; \
\[IndentingNewLine]Print[\*"\"\<\!\(c\_1\) = \>\"", \ 
            psol\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)]; \[IndentingNewLine]Print[\*"\"\<\!\(c\_2\) = \
\>\"", psol\_\(\(\[LeftDoubleBracket]\)\(1, 2, \
2\)\(\[RightDoubleBracket]\)\)]; \[IndentingNewLine]Print["\<\n\>", "\<The \
solution with these IC's is\>"]; \ \[IndentingNewLine]Print["\<y[n] = \>", 
            y[n]]; \ \[IndentingNewLine]Print["\<and\>"]; \ \
\[IndentingNewLine]Print["\<y[0] = \>", y[0]\ ]; \ \[IndentingNewLine]If[
            y[0] === Simplify[y[0]], "\<\>", \(Print["\<y[0] = \>", 
                Simplify[
                  y[0]]\ ];\)\ ]; \ \[IndentingNewLine]Print["\<y[1] = \>", 
            y[1]\ ]; \ \[IndentingNewLine]If[
            y[1] === Simplify[y[1]], "\<\>", \(Print["\<y[1] = \>", 
                Simplify[y[1]]\ ];\)\ ]; \ \[IndentingNewLine]If[
            b > a\^2, \[IndentingNewLine]\[Rho] = \@\(a\^2 + \((\@\(b - \
a\^2\))\)\^2\); \ \[Phi]\  = 
              If[a > \ 0, 
                ArcTan[\@\(b - a\^2\)\/a], \[Pi] + 
                  ArcTan[\@\(b - a\^2\)\/a]]; \ \[IndentingNewLine]s[
                n_] = \(c\_1\) \[Rho]\^n\ \ Cos[n\ \[Phi]]\  + 
                c\_2\ \[Rho]\^n\ \ Sin[
                    n\ \[Phi]]; \ \ \[IndentingNewLine]Print["\<\n\>", \
"\<Another form of the complex solution is\>"]; \ \
\[IndentingNewLine]Print[\*"\"\<y[n] = \!\(\[Rho]\^n\) Cos[\[Phi] \
n]\!\(c\_1\) + \!\(\[Rho]\^\(\(n\)\(\\\ \)\)\)Sin[\[Phi] n]\!\(c\_2\)\>\""\ \
]; \ \[IndentingNewLine]Print[\*"\"\<   \[Rho] = \!\(\@\(a\^2 + \((\@\(b - \
a\^2\))\)\^2\)\) = \>\"", \[Rho]]; \ \[IndentingNewLine]Print[\*"\"\<   \
\[Phi] = ArcTan[\!\(\@\(b - a\^2\)\/a\)] = \>\"", \[Phi]]; \ \
\[IndentingNewLine]Print["\<y[n] = \>", 
              s[n], "\<\n\>"\ ]; \ \[IndentingNewLine]IC = {s[
                    0] \[Equal] \ \[Alpha], 
                s[1] \[Equal] \ \[Beta]}; \ \[IndentingNewLine]psol = 
              Solve[IC, {c\_1, c\_2}]; \ \[IndentingNewLine]s[n_] = 
              ReplaceAll[s[n], 
                psol\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)\ ]; \ \[IndentingNewLine]Print["\<Given the initial conditions\>"]; \
\[IndentingNewLine]Print["\<y[0] = \>", \ \[Alpha]]; \ \
\[IndentingNewLine]Print["\<y[1] = \>", \ \[Beta]]; \ \
\[IndentingNewLine]Print["\<\n\>", "\<The solution with these IC's is\>"]; \ \
\ \[IndentingNewLine]Print["\<y[n] = \>", 
              s[n]]; \ \[IndentingNewLine]Print["\<and\>"]; \ \
\[IndentingNewLine]Print["\<y[0] = \>", y[0]\ ]; \ \[IndentingNewLine]If[
              y[0] === Simplify[y[0]], "\<\>", \(Print["\<y[0] = \>", 
                  Simplify[
                    y[0]]\ ];\)\ ]; \ \[IndentingNewLine]Print["\<y[1] = \>", 
              y[1]\ ]; \ \[IndentingNewLine]If[
              y[1] === Simplify[y[1]], "\<\>", \(Print["\<y[1] = \>", 
                  Simplify[y[1]]\ ];\)\ ];\ \ ];\ ];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 3\ y[n]\  = \ \ 0\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 5\)}]}]}]]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00^`3oool50000
02T0oooo1000000[0?ooo`800000;@3oool3000002X0oooo0P00000M0?oo
o`00_@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02/0
oooo00@000000?ooo`3oool00000;@3oool00`000000oooo0?ooo`0X0?oo
o`040000003oool0oooo000001`0oooo002m0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0Y0?oo
o`D00000;03oool00`000000oooo0?ooo`0J0?ooo`00_@3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0:03oool010000000oooo0?ooo`00000[0?ooo`8000007@3oool00;d0
oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`00000Z0?oo
o`040000003oool0oooo000002/0oooo00<000000?ooo`000000:`3oool0
0`000000oooo0?ooo`0L0?ooo`00_03oool2000002`0oooo0P00000/0?oo
o`800000;@3oool2000002/0oooo0`00000L0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00SP3oool30?l0
0?l0oooo0`3oool008d0oooo1@3o000Z0?ooo`<0o`00e03oool007d0oooo
400000050?l002T000001@3o002m000001H0oooo002=0?ooo`D0o`00:@3o
ool50?l002/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool06`3o
ool008h0oooo0`3o000Z0?ooo`D0o`00:P3oool30?l00:H0oooo002?0?oo
o`030000003oool0oooo02X0oooo0`3o000Z0?ooo`D0o`00Y@3oool008l0
oooo00<000000?ooo`3oool0E`3oool50?l00:D0oooo002?0?ooo`030000
003oool0oooo05L0oooo1@3o002U0?ooo`00S`3oool00`000000oooo0?oo
o`1H0?ooo`<0o`00YP3oool008l0oooo00<000000?ooo`3oool0o`3oool2
0?ooo`00S`3oool00`000000oooo0?ooo`3o0?ooo`80oooo002?0?ooo`03
0000003oool0oooo0?l0oooo0P3oool008l0oooo00<000000?ooo`3oool0
o`3oool20?ooo`00S`3oool00`000000oooo0?ooo`260?ooo`<0o`00N03o
ool008l0oooo00<000000?ooo`3oool0Q@3oool50?l007L0oooo002?0?oo
o`030000003oool0oooo08D0oooo1@3o001g0?ooo`00S`3oool00`000000
oooo0?ooo`250?ooo`D0o`00M`3oool008l0oooo00<000000?ooo`3oool0
QP3oool30?l007P0oooo002?0?ooo`030000003oool0oooo0?l0oooo0P3o
ool008l0oooo00<000000?ooo`3oool0o`3oool20?ooo`00S`3oool00`00
0000oooo0?ooo`3o0?ooo`80oooo002?0?ooo`030000003oool0oooo0?l0
oooo0P3oool008l0oooo00<000000?ooo`3oool0o`3oool20?ooo`00S`3o
ool00`000000oooo0?ooo`3o0?ooo`80oooo002?0?ooo`030000003oool0
oooo0?l0oooo0P3oool007/0oooo1@0000020?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0o`3oool20?ooo`00O@3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo0P3oool0
07d0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00P3oool300000?l0oooo0P3o
ool007d0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`3o0?ooo`80oooo001m0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0o`3oool20?ooo`00O03oool2000000@0oooo
0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`80oooo
002?0?ooo`030000003oool0oooo0?l0oooo0P3oool008l0oooo00<00000
0?ooo`3oool0o`3oool20?ooo`00S`3oool00`000000oooo0?ooo`3o0?oo
o`80oooo002?0?ooo`030000003oool0oooo0?l0oooo0P3oool008l0oooo
00<000000?ooo`3oool0o`3oool20?ooo`00S`3oool00`000000oooo0?oo
o`3o0?ooo`80oooo002?0?ooo`030000003oool0oooo0?l0oooo0P3oool0
08l0oooo00<000000?ooo`3oool0o`3oool20?ooo`00S`3oool00`000000
oooo0?ooo`3o0?ooo`80oooo002?0?ooo`030000003oool0oooo0;@0oooo
0`3o001:0?ooo`00S`3oool00`000000oooo0?ooo`2c0?ooo`D0o`00B@3o
ool008l0oooo00<000000?ooo`3oool0/`3oool50?l004T0oooo002?0?oo
o`030000003oool0oooo0;<0oooo1@3o00190?ooo`00S`3oool00`000000
oooo0?ooo`2d0?ooo`<0o`00BP3oool008l0oooo00<000000?ooo`3oool0
o`3oool20?ooo`00S`3oool00`000000oooo0?ooo`3o0?ooo`80oooo002?
0?ooo`030000003oool0oooo0?l0oooo0P3oool008l0oooo00<000000?oo
o`3oool0o`3oool20?ooo`00S`3oool00`000000oooo0?ooo`3o0?ooo`80
oooo001k0?ooo`@000000`3oool2000000@0oooo0P0000050?ooo`030000
003oool0oooo0?l0oooo0P3oool007/0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0o`3oool20?ooo`00O03oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool300000?l0oooo0P3oool007d0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`80oooo001k0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo
0P3oool007`0oooo0P0000040?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0o`3oool20?ooo`00S`3oool00`000000oooo0?ooo`3o
0?ooo`80oooo002?0?ooo`030000003oool0oooo0?l0oooo0P3oool008l0
oooo00<000000?ooo`3oool0o`3oool20?ooo`00S`3oool00`000000oooo
0?ooo`3o0?ooo`80oooo002?0?ooo`030000003oool0oooo0?l0oooo0P3o
ool008l0oooo00<000000?ooo`3oool0o`3oool20?ooo`00S`3oool00`00
0000oooo0?ooo`3o0?ooo`80oooo002?0?ooo`030000003oool0oooo0?l0
oooo0P3oool008l0oooo00<000000?ooo`3oool0o`3oool20?ooo`00S`3o
ool00`000000oooo0?ooo`3o0?ooo`80oooo002?0?ooo`030000003oool0
oooo0?l0oooo0P3oool008l0oooo00<000000?ooo`3oool0o`3oool20?oo
o`00S`3oool00`000000oooo0?ooo`3o0?ooo`80oooo002?0?ooo`030000
003oool0oooo0?l0oooo0P3oool008l0oooo00<000000?ooo`3oool0o`3o
ool20?ooo`00S`3oool00`000000oooo0?ooo`3o0?ooo`80oooo002?0?oo
o`030000003oool0oooo0?l0oooo0P3oool008l0oooo00<000000?ooo`3o
ool0o`3oool20?ooo`00S`3oool00`000000oooo0?ooo`3o0?ooo`80oooo
001l0?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003o
ool0oooo0?l0oooo0P3oool007/0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0o`3oool20?ooo`00O@3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`020?ooo`<00000o`3oool20?ooo`00OP3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`80oooo001k0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo
0P3oool007`0oooo0P0000040?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0o`3oool20?ooo`00S`3oool00`000000oooo0?ooo`3o
0?ooo`80oooo002?0?ooo`030000003oool0oooo0?l0oooo0P3oool008l0
oooo00<000000?ooo`3oool0o`3oool20?ooo`00S`3oool00`000000oooo
0?ooo`3o0?ooo`80oooo002?0?ooo`030000003oool0oooo0?l0oooo0P3o
ool008l0oooo00<000000?ooo`3oool0o`3oool20?ooo`00S`3oool00`00
0000oooo0?ooo`3o0?ooo`80oooo002?0?ooo`030000003oool0oooo0?l0
oooo0P3oool008l0oooo00<000000?ooo`3oool0o`3oool20?ooo`00S`3o
ool00`000000oooo0?ooo`3o0?ooo`80oooo002?0?ooo`030000003oool0
oooo0?l0oooo0P3oool008l0oooo00<000000?ooo`3oool0o`3oool20?oo
o`00S`3oool00`000000oooo0?ooo`3o0?ooo`80oooo002?0?ooo`030000
003oool0oooo0?l0oooo0P3oool008l0oooo00<000000?ooo`3oool0o`3o
ool20?ooo`00S`3oool00`000000oooo0?ooo`3o0?ooo`80oooo002?0?oo
o`030000003oool0oooo0?l0oooo0P3oool008l0oooo00<000000?ooo`3o
ool0o`3oool20?ooo`00S`3oool00`000000oooo0?ooo`3o0?ooo`80oooo
002?0?ooo`030000003oool0oooo0?l0oooo0P3oool007d0oooo0`000002
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0o`3oool2
0?ooo`00OP3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3o0?ooo`80oooo001k0?ooo`D0000000D0oooo0000003oool0oooo0000
00020?ooo`040000003oool0oooo000000@0oooo0`00003o0?ooo`80oooo
001k0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0?l0oooo0P3oool007`0oooo00<000000?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0o`3oool20?ooo`00O@3oool2000000<0oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`3o0?ooo`80oooo002?0?ooo`03
0000003oool0oooo0?l0oooo0P3oool008l0oooo00<000000?ooo`3oool0
o`3oool20?ooo`00S`3oool00`000000oooo0?ooo`3o0?ooo`80oooo002?
0?ooo`030000003oool0oooo0?l0oooo0P3oool008l0oooo00<000000?oo
o`3oool0o`3oool20?ooo`00S`3oool00`000000oooo0?ooo`3o0?ooo`80
oooo002?0?ooo`030000003oool0oooo0?l0oooo0P3oool008l0oooo00<0
00000?ooo`3oool0o`3oool20?ooo`00S`3oool00`000000oooo0?ooo`3o
0?ooo`80oooo002?0?ooo`030000003oool0oooo0?l0oooo0P3oool008l0
oooo00<000000?ooo`3oool0o`3oool20?ooo`00S`3oool00`000000oooo
0?ooo`3o0?ooo`80oooo002?0?ooo`030000003oool0oooo0?l0oooo0P3o
ool008l0oooo00<000000?ooo`3oool0o`3oool20?ooo`00S`3oool00`00
0000oooo0?ooo`3o0?ooo`80oooo002?0?ooo`030000003oool0oooo0>80
oooo0`3o000L0?ooo`00S`3oool00`000000oooo0?ooo`3Q0?ooo`D0o`00
6`3oool008l0oooo00<000000?ooo`3oool0h@3oool50?l001/0oooo002?
0?ooo`030000003oool0oooo0>40oooo1@3o000K0?ooo`00O03oool20000
00@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`3R0?oo
o`<0o`00703oool007/0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0o`3oool20?ooo`00OP3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool300000?l0oooo0P3oool007`0oooo0P0000030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000o`3oool90?ooo`00
O03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000o`3oool90?ooo`00O03oool3000000<0
oooo0P0000040?ooo`800000o`3oool:0?ooo`00o`3ooonD0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tThe characteristic equation  ",
  Cell[BoxData[
      \(r\^2 - 4\ r + 3\  = \ \(\((r - 1)\) \((r - 3)\)\  = \ 0\)\)]],
  "  has roots ",
  Cell[BoxData[
      \(r\_1 = \(1\ \ and\ \ r\_2 = 3\)\)]],
  "  hence the general solution is  ",
  Cell[BoxData[
      \(y[n]\  = \ c\_1\  + \ \(c\_2\) 3\^n\)]],
  ".   Use the initial conditions and form the linear system  \n\n\t\t",
  Cell[BoxData[{
      \(y[0]\  = \ \(c\_1\  + \ \(c\_2\) 1\  = \ 1\)\), 
    "\[IndentingNewLine]", 
      \(and\), "\[IndentingNewLine]", 
      \(y[1]\  = \ \(c\_1\  + \ \(c\_2\) 3\  = \ 5\)\)}]],
  "  \n\nthen solve for the constants and get  ",
  Cell[BoxData[
      \(c\_1 = \(-1\), c\_2 = 2\)]],
  ".  Hence the solution is \n\n\t\t",
  Cell[BoxData[
      \(y[n]\  = \ \(-1\)\  + \ 2*3\^n\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tTo solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 3\ y[n]\  = \ \ 0\)]],
  "  with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 5\)}]}]}]]],
  ",  we will use our ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine  ",
  Cell[BoxData[
      \(SolveDE\)]],
  "  for finding the solution to",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\ \  = \ \ 0\)]],
  ".  It will construct the characteristic polynomial and its roots.  The \
format of the subroutine call is   ",
  Cell[BoxData[
      \(SolveDE[a, b, x[n], y\_0, y\_1]\)]],
  "  with   ",
  Cell[BoxData[
      RowBox[{\(a = 2\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "b"}], "=", "3"}]}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(x[n_] = 0;\)\), "\[IndentingNewLine]", 
    \(SolveDE[2, 3, x[n], 1, 5]\)}], "Input"],

Cell[BoxData[{
    \(\(y1[n_] = \(-1\) + 2\ 3\^n;\)\), "\[IndentingNewLine]", 
    \(\(m0 = 5;\)\), "\n", 
    \(\(Y1\  = \ N[Table[y1[i], {i, 0, m0}]];\)\), "\n", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(ListPlot[Y1pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Red, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-5\), 500}}, 
        Ticks \[Rule] {Range[0, m0, 5], Range[0, 500, 100]}];\)\), "\n", 
    \(\(Print["\<y[n] = \>", y1[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y1[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.13.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 4\ y[n]\  = \ \ 0\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 5\)}]}]}]]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006L0000UB000`400?l0
0000o`00003oo`3ooonM0?ooo`00o`3ooonM0?ooo`00o`3ooonM0?ooo`00
o`3ooonM0?ooo`00o`3ooonM0?ooo`00o`3ooonM0?ooo`00/03oool50000
02<0oooo1000000V0?ooo`8000009`3oool3000002@0oooo0P00000U0?oo
o`<00000803oool00;80oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0V0?ooo`040000003oool0oooo000002L0oooo00<000000?oo
o`3oool08P3oool010000000oooo0?ooo`00000T0?ooo`040000003oool0
oooo000001l0oooo002b0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0S0?ooo`D000009P3oool0
0`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000001l0oooo002b
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000002D0oooo0P00
000U0?ooo`<00000803oool00;80oooo00<000000?ooo`3oool08`3oool0
10000000oooo0?ooo`00000U0?ooo`040000003oool0oooo000002D0oooo
00<000000?ooo`0000009@3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo01l0oooo002a0?ooo`8000009P3oool2000002L0oooo0P00
000W0?ooo`8000009@3oool3000002D0oooo0`00000O0?ooo`00o`3ooonM
0?ooo`00o`3ooonM0?ooo`00o`3ooonM0?ooo`00o`3ooonM0?ooo`00R@3o
ool30?l00?l0oooo4@3oool008P0oooo1@3o000T0?ooo`<0o`00j03oool0
07X0oooo3P0000050?l002<000001@3o003=000001X0oooo00280?ooo`D0
o`008`3oool50?l002@0oooo0`3o000W0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo01h0oooo00290?ooo`<0o`00903oool50?l002<0oooo
1@3o002o0?ooo`00RP3oool00`000000oooo0?ooo`0T0?ooo`<0o`00903o
ool50?l00;l0oooo002:0?ooo`030000003oool0oooo04/0oooo1@3o002o
0?ooo`00RP3oool00`000000oooo0?ooo`1<0?ooo`<0o`00`03oool008X0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`00RP3oool00`000000oooo
0?ooo`1e0?ooo`<0o`00U`3oool008X0oooo00<000000?ooo`3oool0M03o
ool50?l009H0oooo002:0?ooo`030000003oool0oooo07@0oooo1@3o002F
0?ooo`00RP3oool00`000000oooo0?ooo`1d0?ooo`D0o`00UP3oool008X0
oooo00<000000?ooo`3oool0M@3oool30?l009L0oooo002:0?ooo`030000
003oool0oooo0?l0oooo403oool008X0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`00RP3oool00`000000oooo0?ooo`3o0?oooa00oooo002:0?oo
o`030000003oool0oooo0?l0oooo403oool008X0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`00MP3oool500000080oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`3o0?oooa00oooo001h0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool@0?ooo`00
N03oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`020?ooo`<00000o`3oool@0?oo
o`00N03oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo09d0oooo0`3o001_0?ooo`00N03oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo09`0oooo1@3o001^0?ooo`00M`3oool2
000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`2L
0?ooo`D0o`00KP3oool008X0oooo00<000000?ooo`3oool0W03oool50?l0
06h0oooo002:0?ooo`030000003oool0oooo09d0oooo0`3o001_0?ooo`00
RP3oool00`000000oooo0?ooo`3o0?oooa00oooo002:0?ooo`030000003o
ool0oooo0?l0oooo403oool008X0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`00RP3oool00`000000oooo0?ooo`3o0?oooa00oooo002:0?ooo`03
0000003oool0oooo0?l0oooo403oool008X0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`00RP3oool00`000000oooo0?ooo`3o0?oooa00oooo002:
0?ooo`030000003oool0oooo0?l0oooo403oool008X0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`00RP3oool00`000000oooo0?ooo`3o0?oooa00
oooo002:0?ooo`030000003oool0oooo0?l0oooo403oool008X0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`00MP3oool4000000<0oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`3o0?oooa00oooo001f0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo403o
ool007L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo0`00003o0?oooa00oooo
001h0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`00MP3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`3o0?oooa00oooo001g0?ooo`800000103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo403oool008X0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`00RP3oool00`000000oooo
0?ooo`3o0?oooa00oooo002:0?ooo`030000003oool0oooo0?l0oooo403o
ool008X0oooo00<000000?ooo`3oool0o`3oool@0?ooo`00RP3oool00`00
0000oooo0?ooo`3o0?oooa00oooo002:0?ooo`030000003oool0oooo0?l0
oooo403oool008X0oooo00<000000?ooo`3oool0o`3oool@0?ooo`00RP3o
ool00`000000oooo0?ooo`3o0?oooa00oooo002:0?ooo`030000003oool0
oooo0<D0oooo0`3o00170?ooo`00RP3oool00`000000oooo0?ooo`340?oo
o`D0o`00AP3oool008X0oooo00<000000?ooo`3oool0a03oool50?l004H0
oooo002:0?ooo`030000003oool0oooo0<@0oooo1@3o00160?ooo`00RP3o
ool00`000000oooo0?ooo`350?ooo`<0o`00A`3oool007L0oooo0P000004
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`00MP3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`3o0?oooa00oooo001h0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080
oooo0`00003o0?oooa00oooo001i0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0?l0oooo403oool007H0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0o`3oool@0?ooo`00M`3oool2
000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`3o
0?oooa00oooo002:0?ooo`030000003oool0oooo0?l0oooo403oool008X0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`00RP3oool00`000000oooo
0?ooo`3o0?oooa00oooo002:0?ooo`030000003oool0oooo0?l0oooo403o
ool008X0oooo00<000000?ooo`3oool0o`3oool@0?ooo`00RP3oool00`00
0000oooo0?ooo`3o0?oooa00oooo002:0?ooo`030000003oool0oooo0?l0
oooo403oool008X0oooo00<000000?ooo`3oool0o`3oool@0?ooo`00RP3o
ool00`000000oooo0?ooo`3o0?oooa00oooo002:0?ooo`030000003oool0
oooo0?l0oooo403oool008X0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`00RP3oool00`000000oooo0?ooo`3o0?oooa00oooo002:0?ooo`030000
003oool0oooo0?l0oooo403oool008X0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`00N03oool300000080oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`3o0?oooa00oooo001i0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0?l0oooo403oool007H0oooo1@000000
1@3oool000000?ooo`3oool000000080oooo00@000000?ooo`3oool00000
103oool300000?l0oooo403oool007H0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0o`3oool@0?ooo`00M`3oool00`000000
oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3o0?oooa00oooo001h0?oo
o`8000000`3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo
0?l0oooo403oool008X0oooo00<000000?ooo`3oool0o`3oool@0?ooo`00
RP3oool00`000000oooo0?ooo`3o0?oooa00oooo002:0?ooo`030000003o
ool0oooo0?l0oooo403oool008X0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`00RP3oool00`000000oooo0?ooo`3o0?oooa00oooo002:0?ooo`03
0000003oool0oooo0?l0oooo403oool008X0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`00RP3oool00`000000oooo0?ooo`3o0?oooa00oooo002:
0?ooo`030000003oool0oooo0?l0oooo403oool008X0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`00RP3oool00`000000oooo0?ooo`3o0?oooa00
oooo002:0?ooo`030000003oool0oooo0?l0oooo403oool008X0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`00M`3oool2000000@0oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`3o0?oooa00oooo001f0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo
403oool007T0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`00003o0?oooa00
oooo001g0?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`00M`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o
0?oooa00oooo001g0?ooo`<000000`3oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo0?l0oooo403oool008X0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`00RP3oool00`000000oooo0?ooo`3o0?oooa00oooo
002:0?ooo`030000003oool0oooo0?l0oooo403oool008X0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`00RP3oool00`000000oooo0?ooo`3o0?oo
oa00oooo002:0?ooo`030000003oool0oooo0?l0oooo403oool008X0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`00RP3oool00`000000oooo0?oo
o`3o0?oooa00oooo002:0?ooo`030000003oool0oooo0?l0oooo403oool0
08X0oooo00<000000?ooo`3oool0o`3oool@0?ooo`00RP3oool00`000000
oooo0?ooo`3o0?oooa00oooo002:0?ooo`030000003oool0oooo0?l0oooo
403oool008X0oooo00<000000?ooo`3oool0o`3oool@0?ooo`00RP3oool0
0`000000oooo0?ooo`3o0?oooa00oooo001f0?ooo`<00000103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo403oool007H0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`00MP3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool300000?l0
oooo403oool007H0oooo0`0000030?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?oo
oa00oooo001g0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0?l0oooo403oool007L0oooo0`0000030?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0o`3oool@0?ooo`00RP3oool00`000000
oooo0?ooo`3o0?oooa00oooo002:0?ooo`030000003oool0oooo0?l0oooo
403oool008X0oooo00<000000?ooo`3oool0k@3oool30?l001l0oooo002:
0?ooo`030000003oool0oooo0>`0oooo1@3o000N0?ooo`00RP3oool00`00
0000oooo0?ooo`3/0?ooo`D0o`007P3oool008X0oooo00<000000?ooo`3o
ool0k03oool50?l001h0oooo002:0?ooo`030000003oool0oooo0>d0oooo
0`3o000O0?ooo`00RP3oool00`000000oooo0?ooo`3o0?oooa00oooo002:
0?ooo`030000003oool0oooo0?l0oooo403oool008X0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{412, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tThe characteristic equation  ",
  Cell[BoxData[
      \(r\^2 - 4\ r + 4\  = \ \(\((r - 2)\)\^2\  = \ 0\)\)]],
  "  has equal roots ",
  Cell[BoxData[
      \(r = \(r\_1 = \(r\_2 = 2\)\)\)]],
  "  hence the general solution is  ",
  Cell[BoxData[
      \(y[n]\  = \ \(c\_1\) 2\^n\  + \ \(c\_2\) \(2\^n\) n\)]],
  ".  Use the initial conditions and form the linear system  \n\n\t\t",
  Cell[BoxData[{
      \(\(\(y[0]\  = \ \(c\_1\  + \ \(c\_2\) 0 = 1\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(y[1]\  = \ \(\(c\_1\) 2\  + \ \(c\_2\) 2 = 5\)\)}]],
  "  \n\nthen solve for the constants and get  ",
  Cell[BoxData[
      \(c\_1 = 1, c\_2 = 3\/2\)]],
  ".  Hence the solution is \n\n\t\t",
  Cell[BoxData[
      \(y[
          n]\  = \ \(2\^n + \(3\/2\) n\ 2\^n\ \  = \ \ 2\^n + 
            3  n\ 2\^\(n - 1\)\)\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tTo solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 4\ y[n]\  = \ \ 0\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 5\)}]}]}]]],
  ",  we will use our ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine  ",
  Cell[BoxData[
      \(SolveDE\)]],
  "  for finding the solution to",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\ \  = \ \ 0\)]],
  ".  It will construct the characteristic polynomial and its roots.  The \
format of the subroutine call is   ",
  Cell[BoxData[
      \(SolveDE[a, b, x[n], y\_0, y\_1]\)]],
  "  with   ",
  Cell[BoxData[
      RowBox[{\(a = 2\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "b"}], "=", "4"}]}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(x[n_] = 0;\)\), "\[IndentingNewLine]", 
    \(SolveDE[2, 4, x[n], 1, 5]\)}], "Input"],

Cell[BoxData[{
    \(\(y1[n_] = 2\^n + 3\ 2\^\(\(-1\) + n\)\ n;\)\), "\[IndentingNewLine]", 
    \(\(m0 = 6;\)\), "\n", 
    \(\(Y1\  = \ N[Table[y1[i], {i, 0, m0}]];\)\), "\n", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(ListPlot[Y1pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Red, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-5\), 670}}, 
        Ticks \[Rule] {Range[0, m0, 5], Range[0, 600, 100]}];\)\), "\n", 
    \(\(Print["\<y[n] = \>", y1[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y1[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.14.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 5\ y[n]\  = \ \ 0\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 5\)}]}]}]]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD
0?ooo`00o`3ooonD0?ooo`00S@3oool00`000000oooo0?ooo`3o0?ooo`@0
oooo002=0?ooo`030000003oool0oooo0?l0oooo103oool008d0oooo00<0
00000?ooo`3oool0o`3oool40?ooo`00S@3oool00`000000oooo0?ooo`3K
0?ooo`<0o`009@3oool008d0oooo00<000000?ooo`3oool0fP3oool50?l0
02@0oooo002=0?ooo`030000003oool0oooo0=X0oooo1@3o000T0?ooo`00
S@3oool00`000000oooo0?ooo`3J0?ooo`D0o`00903oool008d0oooo00<0
00000?ooo`3oool0f`3oool30?l002D0oooo002=0?ooo`030000003oool0
oooo0?l0oooo103oool008d0oooo00<000000?ooo`3oool0o`3oool40?oo
o`00S@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo001e0?ooo`<00000
0P3oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo
0?ooo`3o0?ooo`@0oooo001f0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool40?oo
o`00L`3oool5000000050?ooo`000000oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0P00
003o0?ooo`D0oooo001]0?ooo`@000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0?l0oooo103oool007@0oooo00<000000?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`@0oooo001e
0?ooo`8000000`3oool2000000@0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`3o0?ooo`@0oooo002=0?ooo`030000003oool0oooo
0?l0oooo103oool008d0oooo00<000000?ooo`3oool0o`3oool40?ooo`00
S@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo002=0?ooo`030000003o
ool0oooo0?l0oooo103oool008d0oooo00<000000?ooo`3oool0o`3oool4
0?ooo`00S@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo002=0?ooo`03
0000003oool0oooo0?l0oooo103oool008d0oooo00<000000?ooo`3oool0
o`3oool40?ooo`00S@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo002=
0?ooo`030000003oool0oooo0?l0oooo103oool008d0oooo00<000000?oo
o`3oool0o`3oool40?ooo`00S@3oool00`000000oooo0?ooo`3o0?ooo`@0
oooo002=0?ooo`030000003oool0oooo0?l0oooo103oool008d0oooo00<0
00000?ooo`3oool0o`3oool40?ooo`00S@3oool00`000000oooo0?ooo`3o
0?ooo`@0oooo002=0?ooo`030000003oool0oooo0?l0oooo103oool008d0
oooo00<000000?ooo`3oool0o`3oool40?ooo`00S@3oool00`000000oooo
0?ooo`3o0?ooo`@0oooo002=0?ooo`030000003oool0oooo0?l0oooo103o
ool008d0oooo00<000000?ooo`3oool0o`3oool40?ooo`00M03oool20000
00@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?oo
o`3oool0o`3oool40?ooo`00L`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo
103oool007D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`020?ooo`800000o`3oool50?ooo`00K@3oool4000000D0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`3o0?ooo`@0oooo001c0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0o`3oool40?ooo`00M03oool2000000@0oooo0P0000040?ooo`80
0000103oool2000000D0oooo00<000000?ooo`3oool0o`3oool40?ooo`00
S@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo002=0?ooo`030000003o
ool0oooo0?l0oooo103oool008d0oooo00<000000?ooo`3oool0o`3oool4
0?ooo`00S@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo002=0?ooo`03
0000003oool0oooo0?l0oooo103oool008d0oooo00<000000?ooo`3oool0
o`3oool40?ooo`00S@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo002=
0?ooo`030000003oool0oooo0?l0oooo103oool008d0oooo00<000000?oo
o`3oool0o`3oool40?ooo`00S@3oool00`000000oooo0?ooo`3o0?ooo`@0
oooo002=0?ooo`030000003oool0oooo0?l0oooo103oool008d0oooo00<0
00000?ooo`3oool0o`3oool40?ooo`00S@3oool00`000000oooo0?ooo`3o
0?ooo`@0oooo002=0?ooo`030000003oool0oooo0?l0oooo103oool008d0
oooo00<000000?ooo`3oool0o`3oool40?ooo`00S@3oool00`000000oooo
0?ooo`3o0?ooo`@0oooo002=0?ooo`030000003oool0oooo0?l0oooo103o
ool008d0oooo00<000000?ooo`3oool0o`3oool40?ooo`00S@3oool00`00
0000oooo0?ooo`3o0?ooo`@0oooo002=0?ooo`030000003oool0oooo0?l0
oooo103oool007<0oooo100000030?ooo`800000103oool2000000@0oooo
0P0000050?ooo`030000003oool0oooo0?l0oooo103oool007<0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`3o0?ooo`@0oooo001d0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo0P00003o0?ooo`D0oooo001]
0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool40?ooo`00
L`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0?l0oooo103oool007@0oooo0P000004
0?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0?l0oooo103oool008d0oooo00<000000?ooo`3oool0o`3oool40?oo
o`00S@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo002=0?ooo`030000
003oool0oooo0?l0oooo103oool008d0oooo00<000000?ooo`3oool0o`3o
ool40?ooo`00S@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo002=0?oo
o`030000003oool0oooo0?l0oooo103oool008d0oooo00<000000?ooo`3o
ool0`P3oool30?l003h0oooo002=0?ooo`030000003oool0oooo0<40oooo
1@3o000m0?ooo`00S@3oool00`000000oooo0?ooo`310?ooo`D0o`00?@3o
ool008d0oooo00<000000?ooo`3oool0`@3oool50?l003d0oooo002=0?oo
o`030000003oool0oooo0<80oooo0`3o000n0?ooo`00S@3oool00`000000
oooo0?ooo`3o0?ooo`@0oooo002=0?ooo`030000003oool0oooo0?l0oooo
103oool008d0oooo00<000000?ooo`3oool0o`3oool40?ooo`00S@3oool0
0`000000oooo0?ooo`3o0?ooo`@0oooo002=0?ooo`030000003oool0oooo
0?l0oooo103oool008d0oooo00<000000?ooo`3oool0o`3oool40?ooo`00
S@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo002=0?ooo`030000003o
ool0oooo0?l0oooo103oool008d0oooo00<000000?ooo`3oool0o`3oool4
0?ooo`00L`3oool500000080oooo0P0000040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0o`3oool40?ooo`00M@3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3oool40?ooo`00M@3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0080oooo0P00003o0?ooo`D0
oooo001]0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool4
0?ooo`00M@3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool40?ooo`00M03o
ool2000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0o`3oool40?ooo`00S@3oool00`000000oooo0?ooo`3o
0?ooo`@0oooo002=0?ooo`030000003oool0oooo0?l0oooo103oool008d0
oooo00<000000?ooo`3oool0o`3oool40?ooo`00S@3oool00`000000oooo
0?ooo`3o0?ooo`@0oooo002=0?ooo`030000003oool0oooo0?l0oooo103o
ool008d0oooo00<000000?ooo`3oool0o`3oool40?ooo`00S@3oool00`00
0000oooo0?ooo`3o0?ooo`@0oooo002=0?ooo`030000003oool0oooo0?l0
oooo103oool008d0oooo00<000000?ooo`3oool0o`3oool40?ooo`00S@3o
ool00`000000oooo0?ooo`3o0?ooo`@0oooo002=0?ooo`030000003oool0
oooo0?l0oooo103oool008d0oooo00<000000?ooo`3oool0503oool50000
01<0oooo1000000F0?ooo`800000603oool3000001D0oooo0P00000E0?oo
o`<000005`3oool30?l001H0oooo0P00000F0?ooo`<000004`3oool50000
0080oooo0P00000:0?ooo`00S@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool010000000
oooo0?ooo`00000H0?ooo`030000003oool0oooo01<0oooo00@000000?oo
o`3oool00000503oool010000000oooo0?ooo`00000E0?ooo`D0o`00503o
ool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo01<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0
oooo002=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01@0oooo
1@00000G0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool0
00005@3oool50?l001@0oooo00@000000?ooo`3oool000005P3oool30000
01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00L0oooo002=0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
01<0oooo00@000000?ooo`3oool000005P3oool2000001D0oooo0`00000F
0?ooo`D0o`005@3oool2000001H0oooo00@000000?ooo`3oool00000503o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
1`3oool008d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0C0?ooo`040000003oool0oooo000001D0oooo00@000000?ooo`3oool0
00005P3oool00`000000oooo0000000F0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool05@3oool010000000o`000?l0003o000E0?oo
o`040000003oool0oooo000001D0oooo00@000000?ooo`3oool00000503o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
1`3oool008d0oooo00<000000?ooo`3oool05@3oool2000001H0oooo0P00
000G0?ooo`800000603oool2000001H0oooo0`00000E0?ooo`<000005@3o
ool4000001H0oooo0P00000G0?ooo`<000004`3oool2000000@0oooo0P00
000:0?ooo`00S@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo002=0?oo
o`030000003oool0oooo0?l0oooo103oool008d0oooo00<000000?ooo`3o
ool0o`3oool40?ooo`00S03oool30?l001D0oooo0`3o003/0?ooo`00R`3o
ool50?l001<0oooo1@3o000E0?ooo`<0o`005P3oool30?l004L0oooo0`3o
001`0?ooo`00P`3oool8000000D0o`004`0000050?l001@000001@3o000D
000000D0o`005@0000030?l002d000001@3o001U000000X0oooo002;0?oo
o`D0o`004`3oool50?l001@0oooo1@3o000D0?ooo`D0o`00503oool50?l0
01D0oooo0`3o000D0?ooo`D0o`005P3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0;0?ooo`00S03oool30?l001D0oooo0`3o000E0?ooo`D0
o`00503oool50?l001@0oooo1@3o000D0?ooo`D0o`004`3oool50?l001H0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool02`3oool008d0oooo
00<000000?ooo`3oool0;@3oool30?l001H0oooo0`3o000E0?ooo`D0o`00
503oool50?l001@0oooo0`3o001`0?ooo`00S@3oool00`000000oooo0?oo
o`1O0?ooo`<0o`005@3oool50?l008L0oooo002=0?ooo`030000003oool0
oooo07P0oooo0`3o00280?ooo`00S@3oool00`000000oooo0?ooo`3o0?oo
o`@0oooo002=0?ooo`030000003oool0oooo0?l0oooo103oool008d0oooo
00<000000?ooo`3oool0o`3oool40?ooo`00S@3oool00`000000oooo0?oo
o`3o0?ooo`@0oooo002=0?ooo`030000003oool0oooo0?l0oooo103oool0
08d0oooo00<000000?ooo`3oool0o`3oool40?ooo`00S@3oool00`000000
oooo0?ooo`3o0?ooo`@0oooo002=0?ooo`030000003oool0oooo0?l0oooo
103oool00?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03oool00?l0
ooooU03oool00?l0ooooU03oool00?l0ooooU03oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tThe characteristic equation  ",
  Cell[BoxData[
      \(r\^2 - 4\ r + 
          5\  = \ \(\((r - 2 + \[ImaginaryI])\) \((r - 
                2 - \[ImaginaryI])\)\  = \ 0\)\)]],
  "  has complex roots ",
  Cell[BoxData[
      \(r\_1 = 2 + \[ImaginaryI]\)]],
  " and ",
  Cell[BoxData[
      \(r\_2 = 2 - \[ImaginaryI]\)]],
  " hence the general solution is  ",
  Cell[BoxData[
      \(y[
          n]\  = \ \(c\_1\) \((2 + \[ImaginaryI])\)\^n\  + \ \(\(c\_2\) \
\(\((2 - \[ImaginaryI])\)\^n\)\(\ \)\)\)]],
  ".   Use the initial conditions and form the linear system  \n\n\t\t",
  Cell[BoxData[
      \(y[0]\  = \ \(c\_1\  + \ c\_2\  = \ 1\)\)]],
  "\n\n\t\t",
  Cell[BoxData[
      \(y[
          1]\  = \ \(\(c\_1\) \((2 + \[ImaginaryI])\)\  + \ \(c\_2\) \((2 - \
\[ImaginaryI])\)\ \  = \ 5\)\)]],
  "  \n\nthen solve for the constants and get ",
  Cell[BoxData[
      \(c\_1 = \(1 - 3\ \[ImaginaryI]\)\/2\)]],
  " and ",
  Cell[BoxData[
      \(c\_2 = \(1 + 3\ \[ImaginaryI]\)\/2\)]],
  ".  Hence the solution is \n\n\t\t",
  Cell[BoxData[
      \(y[
          n]\  = \ \(1 - 3\ \[ImaginaryI]\)\/2\ \((2 + \[ImaginaryI])\)\^n\  \
+ \ \(1 + 3\ \[ImaginaryI]\)\/2\ \((2 - \[ImaginaryI])\)\^n\)]],
  ". \n\nWe leave it for the reader to verify that this can be written as  \n\
\n\t\t",
  Cell[BoxData[
      \(y[n]\  = \ 
        5\^\(n/2\)\ cos \((arctan \((1\/2)\) n)\)\  + \ 
          3*5\^\(n/2\)\ sin \((arctan \((1\/2)\) n)\)\)]],
  ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tTo solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 5\ y[n]\  = \ \ 0\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 5\)}]}]}]]],
  ",  we will use our ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine  ",
  Cell[BoxData[
      \(SolveDE\)]],
  "  for finding the solution to",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\ \  = \ \ 0\)]],
  ".  It will construct the characteristic polynomial and its roots.  The \
format of the subroutine call is   ",
  Cell[BoxData[
      \(SolveDE[a, b, x[n], y\_0, y\_1]\)]],
  "  with   ",
  Cell[BoxData[
      RowBox[{\(a = 2\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "b"}], "=", "5"}]}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(x[n_] = 0;\)\), "\[IndentingNewLine]", 
    \(SolveDE[2, 5, x[n], 1, 5]\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to compare  ",
  Cell[BoxData[
      \(y[
          n] = \((1\/2 + \(3\ \[ImaginaryI]\)\/2)\)\ \((2 - \
\[ImaginaryI])\)\^n + \((1\/2 - \(3\ \[ImaginaryI]\)\/2)\)\ \((2 + \
\[ImaginaryI])\)\^n\)]],
  "  and  ",
  Cell[BoxData[
      \(y[n] = 
        5\^\(n/2\)\ Cos[n\ ArcTan[1\/2]] + 
          3\ 5\^\(n/2\)\ Sin[n\ ArcTan[1\/2]]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(y1[
          n_] = \((1\/2 + \(3\ \[ImaginaryI]\)\/2)\)\ \((2 - \[ImaginaryI])\)\
\^n + \((1\/2 - \(3\ \[ImaginaryI]\)\/2)\)\ \((2 + \[ImaginaryI])\)\^n;\)\), \
"\[IndentingNewLine]", 
    \(\(y2[n_] = 
        5\^\(n/2\)\ Cos[n\ ArcTan[1\/2]] + 
          3\ 5\^\(n/2\)\ Sin[n\ ArcTan[1\/2]];\)\), "\[IndentingNewLine]", 
    \(\(m0 = 10;\)\), "\n", 
    \(\(Y1\  = \ N[Table[y2[i], {i, 0, m0}]];\)\), "\n", 
    \(\(Y2\  = \ N[Table[y2[i], {i, 0, m0}]];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\n", 
    \(\(Y2pts = Transpose[{ticval, Y2}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(ListPlot[Y1pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Red, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-4500\), 500}}, 
        Ticks \[Rule] {Range[0, m0, 5], 
            Range[\(-4500\), 500, 500]}];\)\), "\n", 
    \(\(Print["\<y[n] = \>", y1[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[
            y1[n], {n, 0, 9}], "\<...\>"]\ ];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Y2pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Green, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-4500\), 500}}, 
        Ticks \[Rule] {Range[0, m0, 5], 
            Range[\(-4500\), 500, 500]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y2[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[
            y2[n], {n, 0, 9}], "\<...\>"]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[
            Simplify[y2[n]], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Higher Order Difference Equations",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\tT",
    FontFamily->"Times New Roman"],
  "he general form of a ",
  Cell[BoxData[
      \(P\^th\)]],
  " ",
  StyleBox["order linear constant coefficient difference equation",
    FontFamily->"Times New Roman"],
  " (LCCDE), is  ",
  StyleBox["\n\t\n",
    FontFamily->"Times New Roman"],
  StyleBox["(9-14)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\t\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[{
      \(\(y[n] + a\_1\ y[n - 1] + a\_2\ y[n - 2] +  ... \) + 
        a\_\(N - 1\)\ y[n - P + 1] + a\_P\ y[n - P]\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \(\(=\)\(\ \ \)\(\(b\_0\ x[n] + b\_1\ x[n - 1] + 
              b\_2\ x[n - 2] +  ... \) + b\_\(M - 1\)\ x[n - Q + 1] + 
          b\_Q\ x[n - Q]\)\)\)}]],
  StyleBox["\n\nwhere ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({a\_p}\_\(p = 1\)\%P\)]],
  StyleBox[" and ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({b\_q}\_\(q = 0\)\%Q\)]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  " The sequence ",
  Cell[BoxData[
      \({x\_n = x[n]}\_\(n = 0\)\%\[Infinity]\)]],
  " is given and the sequence ",
  Cell[BoxData[
      \({x\_n = x[n]}\_\(n = 0\)\%\[Infinity]\)]],
  " is output.  The integer  ",
  Cell[BoxData[
      \(P\)]],
  "  is the order of the difference equation.  ",
  StyleBox["The compact form of writing this difference equation is \n\n",
    FontFamily->"Times New Roman"],
  StyleBox["(9-15)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\t\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[
            n]\ \  + \ \ \[Sum]\+\(p = 1\)\%P\( a\_p\) 
              y[n - p]\ \  = \ \ \[Sum]\+\(q = 0\)\%Q\( b\_q\) x[n - q]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "This formula can be expressed in a recursive form:\n\n",
  StyleBox["(9-16)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(y[
          n]\  = \ \ \[Sum]\+\(q = 0\)\%Q\( b\_q\) 
              x[n - q]\ \  - \ \ \[Sum]\+\(p = 1\)\%P\( a\_1\) y[n - p]\)]],
  ".  \n\n\tThis form of the LCCDE explicitly shows that the present output  \
",
  Cell[BoxData[
      \(y[n]\)]],
  "  is a function of the past output values  ",
  Cell[BoxData[
      \(y[n - p]\)]],
  ",  for  ",
  Cell[BoxData[
      RowBox[{\(p = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "P"}]]],
  "; and the present input  ",
  Cell[BoxData[
      \(x[n]\)]],
  ",  and the previous inputs  ",
  Cell[BoxData[
      \(x[n - q]\)]],
  "  for  ",
  Cell[BoxData[
      RowBox[{\(q = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "Q"}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tNow we would like to emphasize the method of",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["z",
    FontFamily->"Courier New"],
  StyleBox["-",
    FontFamily->"Times New Roman"],
  "transforms for solving difference equations.  Applying the linearity and \
time delay shift property of the",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["z",
    FontFamily->"Courier New"],
  StyleBox["-",
    FontFamily->"Times New Roman"],
  "transform to equation ",
  StyleBox["(9-15)",
    FontColor->RGBColor[0, 0, 1]],
  ", we obtain \n\n",
  StyleBox["(9-17)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(Y \((z)\)\ \  + \ \ \[Sum]\+\(p = 1\)\%P\( a\_p\) Y \((z)\) 
              z\^\(-p\)\ \  = \ \ \[Sum]\+\(q = 0\)\%Q\( b\_q\) X \((z)\) 
            z\^\(-q\)\)]],
  ". \n\nThis can be rearranged as  ",
  Cell[BoxData[
      \(Y \((z)\) \((1\  + \ \[Sum]\+\(p = 1\)\%P\( a\_p\) 
                  z\^\(-p\))\)\ \  = \ \ X \((z)\) \(\[Sum]\+\(q = 0\)\%Q\( 
                  b\_q\) z\^\(-q\)\)\)]],
  "  and then solved for the quotient ",
  Cell[BoxData[
      \(H \((z)\) = \(Y \((z)\)\)\/\(X \((z)\)\)\)]],
  ".  The sequence  ",
  Cell[BoxData[
      \(h[n] = \ \(\[GothicCapitalZ]\^\(-1\)\)[H \((z)\)]\)]],
  " can be used to construct a particular solution to ",
  StyleBox["(9-14)",
    FontColor->RGBColor[0, 0, 1]],
  ", i.e.  ",
  Cell[BoxData[
      \(y\_p[n] = \(\(\[GothicCapitalZ]\^\(-1\)\)[H \((z)\) X \((z)\)] = 
          h[n]*x[n]\)\)]],
  ".  This solution can be expressed using the convolution sum, as follows:\n\
\n",
  StyleBox["(9-18)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(y\_p[n]\ \  = \ \ \[Sum]\+\(i = 0\)\%n\ h[n - i] x[i]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  This particular solution   ",
  Cell[BoxData[
      \(y\_p[n]\)]],
  " does not involve initial conditions for ",
  StyleBox["(9-14)",
    FontColor->RGBColor[0, 0, 1]],
  ".  We will illustrate how to use convolution at the end of this section.  \
"
}], "Text"],

Cell[TextData[{
  StyleBox["Difference Equations with Initial Conditions",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tOften times a difference equation involves only one input on the \
right hand side of ",
  StyleBox["(9-14)",
    FontColor->RGBColor[0, 0, 1]],
  " and we write\n\n",
  StyleBox["\t\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(y[n] + a\_1\ y[n - 1] + a\_2\ y[n - 2] +  ... \) + 
          a\_\(N - 1\)\ y[n - P + 1] + a\_P\ y[n - P]\  = \ \ x[n]\)]],
  "\n\t\t\nthen we could shift the index and use the form\n\n",
  StyleBox["\t\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(y[n + P] + a\_1\ y[n + P - 1] + a\_2\ y[n + P - 2] +  ... \) + 
          a\_\(N - 1\)\ y[P + 1] + a\_P\ y[n]\  = \ \ x[n + P]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["Consider the first order linear constant coefficient difference \
equation",
    FontFamily->"Times New Roman"],
  " (LCCDE)  \n\n",
  StyleBox["(9-19)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\  = \ \ x[n + 2]\)]],
  " \n\nwith the initial conditions  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", " ", 
        RowBox[{
          RowBox[{\(y\_0\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(y[1]\)}], "=", 
          " ", \(y\_1\)}]}]]],
  "  (and implicitly we have  ",
  Cell[BoxData[
      RowBox[{\(x[0]\), "=", " ", 
        RowBox[{
          RowBox[{\(x\_0\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(x[1]\)}], "=", 
          " ", \(x\_1\)}]}]]],
  "). "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["Step (i)",
    FontColor->RGBColor[0, 0, 1]],
  "  Using the time forward properties  \n\t\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][y[n + 1]]\  = \ \ \ z\ \((Y \((z)\) - y\_0)\)\)]],
  ", \n\t\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][
          y[n + 2]]\ \  = \ \ z\^2\ \((Y \((z)\)\  - \ 
              y\_0\  - \ \(y\_1\) z\^\(-1\))\)\)]],
  ",   \n\t\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][
          x[n + 2]]\ \  = \ \ z\^2\ \((X \((z)\)\  - \ 
              x\_0\  - \ \(x\_1\) z\^\(-1\))\)\)]],
  " \n\t\tand take the",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["z",
    FontFamily->"Courier New"],
  StyleBox["-",
    FontFamily->"Times New Roman"],
  "transform of each term and get the equation  \n\n",
  StyleBox["(9-20)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(z\^2\ \((Y \((z)\)\  - \ y\_0\  - \ \(y\_1\) z\^\(-1\))\)\  - \ 
          2  a\ z\ \((Y \((z)\) - y\_0)\) + b\ Y \((z)\)\  = \ 
        z\^2\ \((X \((z)\)\  - \ x\_0\  - \ \(x\_1\) z\^\(-1\))\)\)]],
  ". \n\t\n\t",
  StyleBox["Step (ii)",
    FontColor->RGBColor[0, 0, 1]],
  "  Solve equation ",
  StyleBox["(9-20)",
    FontColor->RGBColor[0, 0, 1]],
  " for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  ". \n\n\t",
  StyleBox["Step (iii)",
    FontColor->RGBColor[0, 0, 1]],
  "  Use partial fractions to expand  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  "  in a sum of terms, and look up the inverse",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["z",
    FontFamily->"Courier New"],
  StyleBox["-",
    FontFamily->"Times New Roman"],
  "transform(s) using Table 1, to get the solution  \n\n\t\t\t",
  Cell[BoxData[
      \(y[n]\ \  = \ \ \(\[GothicCapitalZ]\^\(-1\)\)[Y \((z)\)]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["Step (iv)",
    FontColor->RGBColor[0, 0, 1]],
  "  Alternate calculation using residues.  Perform steps ",
  StyleBox["(i)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  " listed above.  Then find  ",
  Cell[BoxData[
      \(y[n]\)]],
  "  using residues  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(y[n]\), "  ", "=", "  ", 
        RowBox[{\(\(\[GothicCapitalZ]\^\(-1\)\)[Y \((z)\)]\), "  ", "=", 
          "   ", 
          RowBox[{\(\[Sum]\+\(i = 1\)\%k\), 
            RowBox[{"Res", "[", 
              RowBox[{\(Y \((z)\) z\^\(n - 1\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(z\_i\)}], "]"}]}]}]}]]],
  ".  \n\n\t\twhere  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_k\)}]]],
  "  are the poles of  ",
  Cell[BoxData[
      \(f \((z)\)\  = \ Y \((z)\) z\^\(n - 1\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["Remark",
    FontColor->RGBColor[0, 0, 1]],
  "  The function  ",
  Cell[BoxData[
      \(f \((z)\) = Y \((z)\) z\^\(n - 1\)\)]],
  "  has real coefficients.  Hence, if , and if ",
  Cell[BoxData[
      \(z\_i\)]],
  " and ",
  Cell[BoxData[
      \(\(z\_i\)\&_\)]],
  " are poles, then we can use the computational fact: \n\n",
  StyleBox["(9-21)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(\(z\_i\)\&_\)}], "]"}], "  ", "=", 
        "   ", 
        OverscriptBox[
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(z\_i\)}], "]"}], "_"]}]]]
}], "Text"],

Cell[TextData[{
  "\tWe now show how to obtain answers to Examples 9.12-9.14 using",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["z",
    FontFamily->"Courier New"],
  StyleBox["-",
    FontFamily->"Times New Roman"],
  "transform methods. "
}], "Text"],

Cell[TextData[{
  "\tThe following subroutine uses",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["z",
    FontFamily->"Courier New"],
  StyleBox["-",
    FontFamily->"Times New Roman"],
  "transforms to construct solutions to a second order homogeneous difference \
equation."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica Subroutines (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Solution of a Difference Equation",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"],

Cell[BoxData[
    \(\(Zsolution[a0_, b0_, x0_, \[Alpha]0_, \[Beta]0_] := 
        Module[\ {}, \[IndentingNewLine]a = a0; \ 
          b = b0; \ \[Alpha] = \[Alpha]0; \ \[Beta] = \[Beta]0; \
\[IndentingNewLine]Clear[n, y, Y, z]; \[IndentingNewLine]x[n_] = 
            x0; \[IndentingNewLine]LCCDE\  = \ 
            y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n] \[Equal] \ 
              x[n + 2]; \ \[IndentingNewLine]Print["\<The second-order \
difference equation is\>"]; \ \[IndentingNewLine]Print[\ 
            LCCDE\ ]; \ \[IndentingNewLine]Print["\<Take the z-transforms of \
each term\>"]; \[IndentingNewLine]eqn1\  = 
            z\^2\ \((Y[z]\  - \ y\_0\  - \ \(y\_1\) z\^\(-1\))\)\  - \ 
                2  a \((z\ \((Y[z]\  - \ y\_0)\))\) + 
                b \((Y[z])\) \[Equal] \ \ ZTransform[x[n + 2], n, 
                z]; \[IndentingNewLine]Print[
            eqn1]; \[IndentingNewLine]Print["\<Use the initial values\>"]; \ \
\ \[IndentingNewLine]Print[\*"\"\<y[0] = \!\(y\_0\) = \>\"", \ \[Alpha]]; \
\[IndentingNewLine]Print[\*"\"\<y[1] = \!\(y\_1\) = \>\"", \ \[Beta]]; \
\[IndentingNewLine]eqn2\  = 
            ReplaceAll[
              eqn1, {y\_0 \[Rule] \[Alpha], 
                y\_1 \[Rule] \[Beta]}]; \
\[IndentingNewLine]Print["\<Substitute them and obtain\>"]; \ \ \
\[IndentingNewLine]Print[eqn2]; \[IndentingNewLine]solset = 
            Solve[eqn2, Y[z]]; \ \[IndentingNewLine]Y[z_] = 
            Together[
              solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\)]; \ \[IndentingNewLine]Print["\<Solve this equation \
for Y[z] = \[GothicCapitalZ][y[n]]\>"]; \[IndentingNewLine]Print["\<Y[z] = \
\>", Y[z]\ ]; \[IndentingNewLine]y[n_] = 
            InverseZTransform[Y[z], z, 
              n]; \[IndentingNewLine]Print["\<\>"]; \ \
\[IndentingNewLine]Print["\<Take the inverse z-transform and get the solution\
\>"]; \ \[IndentingNewLine]Print["\<\>"]; \ \
\[IndentingNewLine]Print[\*"\"\<y[n] = \!\(\[GothicCapitalZ]\^\(-1\)\)[Y[z]] \
= \!\(\[GothicCapitalZ]\^\(-1\)\)[\>\"", 
            Y[z], "\<]\>"]; \[IndentingNewLine]Print["\<y[n] = \>", 
            y[n]\ ]; \[IndentingNewLine]Print["\<\>"]; \ \
\[IndentingNewLine]Print["\<It has the desired initial conditions\>"]; \ \ \
\[IndentingNewLine]Print["\<y[0] = \>", y[0]\ ]; \ \[IndentingNewLine]If[
            y[0] === Simplify[y[0]], "\<\>", \(Print["\<y[0] = \>", 
                Simplify[
                  y[0]]\ ];\)\ ]; \ \[IndentingNewLine]Print["\<y[1] = \>", 
            y[1]\ ]; \ \[IndentingNewLine]If[
            y[1] === Simplify[y[1]], "\<\>", \(Print["\<y[1] = \>", 
                Simplify[y[1]]\ ];\)\ ];\ ];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ResidueSolution[a0_, b0_, \[Alpha]0_, \[Beta]0_] := 
        Module[\ {}, \[IndentingNewLine]a = a0; \ 
          b = b0; \ \[Alpha] = \[Alpha]0; \ \[Beta] = \[Beta]0; \
\[IndentingNewLine]Clear[n, y, Y, z]; \[IndentingNewLine]HLCCDE\  = \ 
            y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n] \[Equal] \ 
              0; \ \[IndentingNewLine]Print["\<The second-order difference \
equation is\>"]; \ \[IndentingNewLine]Print[\ 
            HLCCDE\ ]; \ \[IndentingNewLine]Print["\<Take the z-transforms of \
each term\>"]; \[IndentingNewLine]eqn1\  = 
            z\^2\ \((Y[z]\  - \ y\_0\  - \ \(y\_1\) z\^\(-1\))\)\  - \ 
                2  a \((z\ \((Y[z]\  - \ y\_0)\))\) + b \((Y[z])\) \[Equal] \ 
              0; \[IndentingNewLine]Print[
            eqn1]; \[IndentingNewLine]Print["\<Use the initial values\>"]; \ \
\ \[IndentingNewLine]Print[\*"\"\<y[0] = \!\(y\_0\) = \>\"", \ \[Alpha]]; \
\[IndentingNewLine]Print[\*"\"\<y[1] = \!\(y\_1\) = \>\"", \ \[Beta]]; \
\[IndentingNewLine]Print["\<Substitute them and obtain\>"]; \ \ \
\[IndentingNewLine]eqn2\  = 
            ReplaceAll[
              eqn1, {y\_0 \[Rule] \[Alpha], 
                y\_1 \[Rule] \[Beta]}]; \[IndentingNewLine]Print[
            eqn2]; \[IndentingNewLine]solset = 
            Solve[eqn2, Y[z]]; \ \[IndentingNewLine]Y[z_] = 
            Together[
              solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\)]; \ \[IndentingNewLine]Print["\<Solve this equation \
for Y[z] = \[GothicCapitalZ][y[n]]\>"]; \[IndentingNewLine]Print["\<   Y[z] = \
\>", Y[z]\ ]; \[IndentingNewLine]zsolve = 
            Solve[Denominator[Y[z]] \[Equal] 0, 
              z]; \ \[IndentingNewLine]z\_1 = 
            zsolve\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\); \[IndentingNewLine]z\_2 = 
            zsolve\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\
\[RightDoubleBracket]\)\); \[IndentingNewLine]If[
            z\_1 =!= 
              z\_2, \[IndentingNewLine]Print["\<The poles are\>"]; \
\[IndentingNewLine]s[n_] = 
              Residue[Y[z] \(\(z\)\(\ \)\)\^\(n - 1\), {z, z\_1}] + 
                Residue[
                  Y[z] \(\(z\)\(\ \)\)\^\(n - 1\), {z, 
                    z\_2}]; \[IndentingNewLine]Print[\*"\"\<     \!\(z\_1\) = \
\>\"", z\_1\ ]; \[IndentingNewLine]Print[\*"\"\<     \!\(z\_2\) = \>\"", 
              z\_2\ ]; \[IndentingNewLine]Print["\<The solution is\>"]; \
\[IndentingNewLine]Print[\*"\"\<     \!\(y\_n\) =  \!\(1\/\(2\\\ \[Pi]\\\ \
\[ImaginaryI]\)\)\>\"", "\<\[ClockwiseContourIntegral]\>"\+C, "\<(\>", 
              Y[z]\ z\^\(n - 1\), "\<) \[DifferentialD]z\>"]; \ \
\[IndentingNewLine]Print[\*"\"\<     \!\(y\_n\) = Res[Y[z]\!\(\(\(z\)\(\\\ \)\
\)\^\(n - 1\)\),\!\(z\_1\)] + Res[Y[z]\!\(\(\(z\)\(\\\ \)\)\^\(n - \
1\)\),\!\(z\_2\)] \>\""]; \ \[IndentingNewLine]Print[\*"\"\<     \!\(y\_n\) = \
Res[Y[z]\!\(\(\(z\)\(\\\ \)\)\^\(n - 1\)\), \>\"", 
              z\_1, \*"\"\<] + Res[Y[z]\!\(\(\(z\)\(\\\ \)\)\^\(n - 1\)\), \>\
\"", z\_2, "\<] \>"]; \ \[IndentingNewLine]Print[\*"\"\<     \!\(y\_n\) = \
Res[\>\"", Y[z] z\^\(n - 1\), "\<, \>", z\_1, "\<] + Res[\>", 
              Y[z] z\^\(n - 1\), "\<, \>", 
              z\_2, "\<]\>"]; \ \[IndentingNewLine]Print[\*"\"\<     \!\(y\_n\
\) = (\>\"", 
              Residue[Y[z] \(\(z\)\(\ \)\)\^\(n - 1\), {z, 
                  z\_1}], "\<) + (\>", 
              Residue[Y[z] \(\(z\)\(\ \)\)\^\(n - 1\), {z, 
                  z\_2}], "\<)\>"\ ]; \ \[IndentingNewLine]Print[\*"\"\<     \
\!\(y\_n\) = \>\"", s[n]\ ];\ \ ]; \[IndentingNewLine]If[
            z\_1 \[Equal] 
              z\_2, \[IndentingNewLine]Print["\<The pole is\>"]; \
\[IndentingNewLine]s[n_] = 
              Residue[Y[z] \(\(z\)\(\ \)\)\^\(n - 1\), {z, 
                  z\_1}]; \[IndentingNewLine]Print[\*"\"\<     \!\(z\_1\) = \
\>\"", z\_1\ ]; \[IndentingNewLine]Print[\*"\"\<     \!\(y\_n\) =  \!\(1\/\(2\
\\\ \[Pi]\\\ \[ImaginaryI]\)\)\>\"", "\<\[ClockwiseContourIntegral]\>"\+C, \
"\<(\>", Y[
                  z]\ z\^\(n - 1\), "\<) \[DifferentialD]z\>"]; \ \
\[IndentingNewLine]Print[\*"\"\<     \!\(y\_n\) = Res[Y[z]\!\(\(\(z\)\(\\\ \)\
\)\^\(n - 1\)\),\!\(z\_1\)]\>\""]; \ \[IndentingNewLine]Print[\*"\"\<     \
\!\(y\_n\) = Res[Y[z]\!\(\(\(z\)\(\\\ \)\)\^\(n - 1\)\), \>\"", 
              z\_1, "\<]\>"]; \ \[IndentingNewLine]Print[\*"\"\<     \!\(y\_n\
\) = Res[\>\"", Y[z] z\^\(n - 1\), \ "\<,{z,\>", 
              
              z\_1, "\<]\>"]; \ \[IndentingNewLine]Print[\*"\"\<     \!\(y\_n\
\) = \>\"", s[n]\ ];\ \ ];\[IndentingNewLine]\ ];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.15 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["z",
    FontFamily->"Courier New"],
  StyleBox["-",
    FontFamily->"Times New Roman"],
  "transform methods to solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 3\ y[n]\  = \ \ 0\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 5\)}]}]}]]],
  ".  \n\n",
  StyleBox["9.15 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["z",
    FontFamily->"Courier New"],
  StyleBox["-",
    FontFamily->"Times New Roman"],
  "transform methods to solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 3\ y[n]\  = \ \ 2\^\(n + 2\)\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 3\)}]}]}]]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:O0000UB000`400?l0
0000o`00003oo`3ooooo0?oooj40oooo003o0?ooool0ooooX@3oool00?l0
ooooo`3ooonQ0?ooo`00o`3ooooo0?oooj40oooo003o0?ooool0ooooX@3o
ool00?l0ooooo`3ooonQ0?ooo`00U`3oool5000002T0oooo1000000[0?oo
o`800000;@3oool3000002X0oooo0P00001c0?ooo`D00000:P3oool40000
02d0oooo0P00000^0?ooo`<00000;03oool2000001T0oooo002I0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:`3oool010000000
oooo0?ooo`00000]0?ooo`030000003oool0oooo02P0oooo00@000000?oo
o`3oool00000M03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo02d0oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?oo
o`0Z0?ooo`040000003oool0oooo000001P0oooo002I0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0Y0?ooo`D00000;03oool00`000000oooo0?ooo`1b0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0Z0?ooo`D00000;P3oool00`000000oooo0?ooo`0F0?ooo`00V@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool0:03oool010000000oooo0?ooo`00000[0?ooo`800000M@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0:@3oool010000000oooo0?ooo`00000]0?ooo`800000
6@3oool009T0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?oo
o`00000Z0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`00
0000:`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo02X0
oooo00@000000?ooo`3oool00000;03oool010000000oooo0?ooo`00000/
0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0603oool0
09P0oooo0P00000/0?ooo`800000;03oool2000002d0oooo0P00000[0?oo
o`<00000L`3oool2000002d0oooo0P00000^0?ooo`800000;P3oool20000
02d0oooo0`00000H0?ooo`00o`3ooooo0?oooj40oooo003o0?ooool0oooo
X@3oool00?l0ooooo`3ooonQ0?ooo`00o`3ooooo0?oooj40oooo001Z0?oo
o`<0o`00o`3oool[0?ooo`<0003oo`3oool60?ooo`00J@3oool50?l002X0
oooo0`3o003k0?ooo`D0003o:`3oool30000omH0oooo001I0?oooa000000
1@3o000Y000000D0o`00_@00000/0?oooa4000001@000?lZ000000D0003o
``00000B0?ooo`00J@3oool50?l002T0oooo1@3o000[0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0480oooo1@000?lZ0?ooo`D0003o:`3o
ool30000obh0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo01L0oooo001Z0?ooo`<0o`00:P3oool5
0?l002X0oooo0`3o003>0?ooo`<0003o:`3oool50000obX0oooo1@000?nV
0?ooo`00J`3oool00`000000oooo0?ooo`0Z0?ooo`<0o`00:P3oool50?l0
0<h0oooo00<000000?ooo`3oool0:`3oool30000ob/0oooo1@000?nV0?oo
o`00J`3oool00`000000oooo0?ooo`1G0?ooo`D0o`00cP3oool00`000000
oooo0?ooo`1I0?ooo`D0003oYP3oool006/0oooo00<000000?ooo`3oool0
E`3oool50?l00<h0oooo00<000000?ooo`3oool0FP3oool30000ojL0oooo
001[0?ooo`030000003oool0oooo05P0oooo0`3o003?0?ooo`030000003o
ool0oooo0?l0oooo1@3oool006/0oooo00<000000?ooo`3oool0o`3oool[
0?ooo`030000003oool0oooo0?l0oooo1@3oool006/0oooo00<000000?oo
o`3oool0o`3oool[0?ooo`030000003oool0oooo0?l0oooo1@3oool006/0
oooo00<000000?ooo`3oool0o`3oool[0?ooo`030000003oool0oooo08X0
oooo0`000?mg0?ooo`00J`3oool00`000000oooo0?ooo`3o0?ooob/0oooo
00<000000?ooo`3oool0R@3oool50000ogH0oooo001[0?ooo`030000003o
ool0oooo08H0oooo0`3o002Q0?ooo`030000003oool0oooo08T0oooo1@00
0?mf0?ooo`00J`3oool00`000000oooo0?ooo`250?ooo`D0o`00X03oool0
0`000000oooo0?ooo`290?ooo`D0003oMP3oool006/0oooo00<000000?oo
o`3oool0Q@3oool50?l00:00oooo00<000000?ooo`3oool0RP3oool30000
ogL0oooo001[0?ooo`030000003oool0oooo08D0oooo1@3o002P0?ooo`03
0000003oool0oooo0?l0oooo1@3oool006/0oooo00<000000?ooo`3oool0
QP3oool30?l00:40oooo00<000000?ooo`3oool0o`3oool50?ooo`00J`3o
ool00`000000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0o`3o
ool50?ooo`00J`3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<00000
0?ooo`3oool0o`3oool50?ooo`00J`3oool00`000000oooo0?ooo`3o0?oo
ob/0oooo00<000000?ooo`3oool0o`3oool50?ooo`00J`3oool00`000000
oooo0?ooo`3o0?oooaH0oooo1@0000020?ooo`800000103oool2000000H0
oooo00<000000?ooo`3oool0o`3oool50?ooo`00J`3oool00`000000oooo
0?ooo`3o0?oooaP0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`D0oooo001[0?ooo`030000003oool0oooo0?l0
oooo603oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`030?ooo`800000o`3oool6
0?ooo`00J`3oool00`000000oooo0?ooo`3o0?oooaP0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001G
0?ooo`D000000P3oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0?l0oooo603oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0?l0oooo1@3oool005T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`3o0?oooaL0oooo0P0000040?ooo`80
0000103oool2000000H0oooo00<000000?ooo`3oool0o`3oool50?ooo`00
F@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`020?ooo`<00000o`3oool[0?oo
o`030000003oool0oooo0?l0oooo1@3oool005T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<00000
0?ooo`3oool0o`3oool50?ooo`00F@3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo0?oo
o`3o0?ooo`D0oooo001H0?ooo`800000103oool2000000@0oooo0P000005
0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`3o
0?ooo`D0oooo001[0?ooo`030000003oool0oooo0?l0oooo:`3oool00`00
0000oooo0?ooo`3o0?ooo`D0oooo001[0?ooo`030000003oool0oooo0?l0
oooo:`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001[0?ooo`030000
003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo
001[0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo0?oo
o`3o0?ooo`D0oooo001[0?ooo`030000003oool0oooo0?l0oooo:`3oool0
0`000000oooo0?ooo`3o0?ooo`D0oooo001[0?ooo`030000003oool0oooo
0?l0oooo:`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001[0?ooo`03
0000003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`3o0?ooo`D0
oooo001[0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo
0?ooo`2i0?ooo`<0003oB03oool006/0oooo00<000000?ooo`3oool0o`3o
ool[0?ooo`030000003oool0oooo0;P0oooo1@000?m70?ooo`00J`3oool0
0`000000oooo0?ooo`2d0?ooo`<0o`00L`3oool00`000000oooo0?ooo`2h
0?ooo`D0003oA`3oool006/0oooo00<000000?ooo`3oool0/`3oool50?l0
0780oooo00<000000?ooo`3oool0^03oool50000odL0oooo001[0?ooo`03
0000003oool0oooo0;<0oooo1@3o001M0?ooo`@000000`3oool2000000@0
oooo0P0000060?ooo`030000003oool0oooo0;T0oooo0`000?m80?ooo`00
J`3oool00`000000oooo0?ooo`2c0?ooo`D0o`00G@3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001[0?ooo`03
0000003oool0oooo0;@0oooo0`3o001O0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000005
0?ooo`800000o`3oool60?ooo`00J`3oool00`000000oooo0?ooo`3o0?oo
oaP0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?ooo`D0oooo001[0?ooo`030000003oool0oooo0?l0oooo5P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`3o0?ooo`D0
oooo001[0?ooo`030000003oool0oooo0?l0oooo5`3oool2000000@0oooo
0P0000040?ooo`8000001P3oool00`000000oooo0?ooo`3o0?ooo`D0oooo
001[0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo0?oo
o`3o0?ooo`D0oooo001[0?ooo`030000003oool0oooo0?l0oooo:`3oool0
0`000000oooo0?ooo`3o0?ooo`D0oooo001G0?ooo`@000000`3oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo:`3oool00`00
0000oooo0?ooo`3o0?ooo`D0oooo001G0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`3o
0?ooo`D0oooo001H0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`<00000o`3o
ool[0?ooo`030000003oool0oooo0?l0oooo1@3oool005T0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooob/0oooo
00<000000?ooo`3oool0o`3oool50?ooo`00E`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`3o0?ooob/0oooo00<000000?oo
o`3oool0o`3oool50?ooo`00F03oool2000000@0oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3o
ool0o`3oool50?ooo`00J`3oool00`000000oooo0?ooo`3o0?ooob/0oooo
00<000000?ooo`3oool0o`3oool50?ooo`00J`3oool00`000000oooo0?oo
o`3o0?ooob/0oooo00<000000?ooo`3oool0o`3oool50?ooo`00J`3oool0
0`000000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0o`3oool5
0?ooo`00J`3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<000000?oo
o`3oool0o`3oool50?ooo`00J`3oool00`000000oooo0?ooo`3o0?ooob/0
oooo00<000000?ooo`3oool0o`3oool50?ooo`00J`3oool00`000000oooo
0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0o`3oool50?ooo`00J`3o
ool00`000000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0o`3o
ool50?ooo`00J`3oool00`000000oooo0?ooo`3o0?oooaL0oooo0P000004
0?ooo`800000103oool2000000H0oooo00<000000?ooo`3oool0o`3oool5
0?ooo`00J`3oool00`000000oooo0?ooo`3o0?oooaH0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0o`3oool50?ooo`00J`3o
ool00`000000oooo0?ooo`3o0?oooaP0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00`3oool200000?l0oooo1P3oool006/0oooo00<000000?ooo`3oool0
o`3ooolI0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0?l0oooo1@3oool006/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo0?l0oooo1@3o
ool006/0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`800000103oool2
000000@0oooo0P0000060?ooo`030000003oool0oooo0?l0oooo1@3oool0
06/0oooo00<000000?ooo`3oool0o`3oool[0?ooo`030000003oool0oooo
0?l0oooo1@3oool006/0oooo00<000000?ooo`3oool0o`3oool[0?ooo`03
0000003oool0oooo0?l0oooo1@3oool006/0oooo00<000000?ooo`3oool0
o`3oool[0?ooo`030000003oool0oooo0?l0oooo1@3oool006/0oooo00<0
00000?ooo`3oool0o`3oool[0?ooo`030000003oool0oooo0?l0oooo1@3o
ool006/0oooo00<000000?ooo`3oool0o`3oool[0?ooo`030000003oool0
oooo0?l0oooo1@3oool006/0oooo00<000000?ooo`3oool0o`3oool[0?oo
o`030000003oool0oooo0?l0oooo1@3oool005P0oooo0P0000040?ooo`80
0000103oool2000000D0oooo00<000000?ooo`3oool0o`3oool[0?ooo`03
0000003oool0oooo0?l0oooo1@3oool005L0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0o`3oool[0?ooo`030000003oool0
oooo0?l0oooo1@3oool005T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3o
ool300000?l0oooo:`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001J
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo
:`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001G0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo:`3oool00`00
0000oooo0?ooo`3o0?ooo`D0oooo001H0?ooo`800000103oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000
oooo0?ooo`3o0?ooo`D0oooo001[0?ooo`030000003oool0oooo0?l0oooo
:`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001[0?ooo`030000003o
ool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001[
0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`3o
0?ooo`D0oooo001[0?ooo`030000003oool0oooo0?l0oooo603oool30000
0080oooo0P0000040?ooo`8000001P3oool00`000000oooo0?ooo`3o0?oo
o`D0oooo001[0?ooo`030000003oool0oooo0?l0oooo6@3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001[0?oo
o`030000003oool0oooo0?l0oooo5P3oool5000000050?ooo`000000oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000050?ooo`800000o`3o
ool60?ooo`00J`3oool00`000000oooo0?ooo`3o0?oooaH0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool0o`3oool50?ooo`00
J`3oool00`000000oooo0?ooo`3o0?oooaL0oooo00<000000?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0o`3oool50?ooo`00J`3oool00`000000
oooo0?ooo`3o0?oooaP0oooo0P0000030?ooo`800000103oool2000000H0
oooo00<000000?ooo`3oool0o`3oool50?ooo`00J`3oool00`000000oooo
0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0o`3oool50?ooo`00J`3o
ool00`000000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0o`3o
ool50?ooo`00J`3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<00000
0?ooo`3oool0o`3oool50?ooo`00J`3oool00`000000oooo0?ooo`3o0?oo
ob/0oooo00<000000?ooo`3oool0o`3oool50?ooo`00J`3oool00`000000
oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0o`3oool50?ooo`00
J`3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00J`3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<0
00000?ooo`3oool0o`3oool50?ooo`00J`3oool00`000000oooo0?ooo`3o
0?ooob/0oooo00<000000?ooo`3oool0o`3oool50?ooo`00J`3oool00`00
0000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0o`3oool50?oo
o`00J`3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3o
ool0o`3oool50?ooo`00J`3oool00`000000oooo0?ooo`3o0?ooob/0oooo
00<000000?ooo`3oool0o`3oool50?ooo`00F@3oool300000080oooo0P00
00040?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<0
00000?ooo`3oool0o`3oool50?ooo`00FP3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0
o`3oool50?ooo`00E`3oool5000000050?ooo`000000oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000040?ooo`<00000o`3oool[0?ooo`03
0000003oool0oooo0?l0oooo1@3oool005L0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0o`3oool[0?ooo`030000003oool0
oooo0?l0oooo1@3oool005P0oooo00<000000?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0o`3ooolG0?ooo`800000103oool2000000@0oooo0P00
00060?ooo`030000003oool0oooo0?l0oooo1@3oool005T0oooo0P000003
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0o`3ooolF
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0?l0
oooo1@3oool006/0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`030?ooo`800000o`3oool60?ooo`00J`3oool00`000000
oooo0?ooo`3o0?oooaL0oooo0P0000030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`3o
0?ooo`D0oooo001[0?ooo`030000003oool0oooo0?l0oooo5`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001[
0?ooo`030000003oool0oooo0?l0oooo5`3oool3000000<0oooo0P000004
0?ooo`8000001P3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001[0?oo
o`030000003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`3o0?oo
o`D0oooo001[0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000
oooo0?ooo`3o0?ooo`D0oooo001[0?ooo`030000003oool0oooo0?l0oooo
:`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001[0?ooo`030000003o
ool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001[
0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`3o
0?ooo`D0oooo001[0?ooo`030000003oool0oooo0?l0oooo:`3oool00`00
0000oooo0?ooo`3o0?ooo`D0oooo001[0?ooo`030000003oool0oooo0?l0
oooo:`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001[0?ooo`030000
003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo
001[0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo0?oo
o`3o0?ooo`D0oooo001[0?ooo`030000003oool0oooo0?l0oooo:`3oool0
0`000000oooo0?ooo`3o0?ooo`D0oooo001[0?ooo`030000003oool0oooo
0?l0oooo:`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo001[0?ooo`03
0000003oool0oooo0>80oooo0`3o00150?ooo`030000003oool0oooo0?l0
oooo1@3oool006/0oooo00<000000?ooo`3oool0h@3oool50?l004@0oooo
00<000000?ooo`3oool0o`3oool50?ooo`00J`3oool00`000000oooo0?oo
o`3Q0?ooo`D0o`00A03oool00`000000oooo0?ooo`3o0?ooo`D0oooo001[
0?ooo`030000003oool0oooo0>40oooo1@3o00140?ooo`030000003oool0
oooo0?l0oooo1@3oool005P0oooo0P0000040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0hP3oool30?l00300oooo0`0000040?oo
o`800000103oool2000000H0oooo00<000000?ooo`3oool0o`3oool50?oo
o`00E`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`3o0?oooaH0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0j03oool30000oaT0oooo001J0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`<00000o`3ooolF0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`80
0000j03oool50000oaP0oooo001H0?ooo`8000000`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000?l0oooo7@3oool30000
00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo0>L0oooo1@000?lH0?ooo`00F03oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000o`3ooolN0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo0>L0oooo1@000?lH0?ooo`00F03oool3000000<0
oooo0P0000040?ooo`800000o`3ooolO0?ooo`<000000`3oool2000000@0
oooo0P0000060?ooo`030000003oool0oooo0>P0oooo0`000?lI0?ooo`00
o`3ooonI0?ooo`030000003oool0oooo0?l0oooo1@3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{671, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.15 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Take the z-transforms of each term  \n\n\t\t",
  Cell[BoxData[
      \(z\^2\ \((Y \((z)\) - 1 - 5\ z\^\(-1\))\)\  - \ 
          4 \((z\ \((Y \((z)\) - 1)\))\) + 3 \((Y \((z)\))\)\  = \ 0\)]]
}], "Text"],

Cell[TextData[{
  "Solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  " and get  ",
  Cell[BoxData[
      \(Y \((z)\)\  = \ \(z\^2 + z\)\/\(\((z - 1)\) \((z - 3)\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Calculate the residues for  ",
  Cell[BoxData[
      \(f \((z)\) = \(Y \((z)\) 
            z\^\(n - 1\) = \(\(z\^2 + z\)\/\(\((z - 1)\) \((z - 3)\)\)\) 
            z\^\(n - 1\)\)\)]],
  "  at the poles \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1"}], "]"}], " ", "=", 
        " ", \(lim\+\(z \[Rule] 1\)\ \(\(z\^2 + z\)\/\(z - 3\)\) 
              z\^\(n - 1\)\  = \ \(\(-1\)*1\^\(n - 1\)\  = \ \(-1\)\)\)}]]],
  "  \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "3"}], "]"}], " ", "=", 
        " ", \(lim\+\(z \[Rule] 3\)\ \(\(z\^2 + z\)\/\(z - 1\)\) 
              z\^\(n - 1\)\  = \ \(6*3\^\(\(-n\) - 1\)\  = \ 2*3\^n\)\)}]]],
  "  "
}], "Text"],

Cell[TextData[{
  "Thus the solution is  \n\n\t\t",
  Cell[BoxData[
      RowBox[{\(y[n]\), " ", "=", " ", 
        RowBox[{
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "1"}], "]"}], "+", 
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["3",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}], "]"}]}]}]]],
  ", \n\t\t\n\t\t",
  Cell[BoxData[
      \(y[n]\  = \ \(-\ 1\)\  + \ \ 2*3\^n\)]],
  "\n\nwhich agrees with the result of example 1. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.15 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Take the z-transforms of each term  \n\n\t\t",
  Cell[BoxData[
      \(z\^2\ \((Y \((z)\) - 1 - 3\ z\^\(-1\))\)\  - \ 
          4 \((z\ \((Y \((z)\) - 1)\))\) + 
          3 \((Y \((z)\))\)\  = \ \(4\ z\)\/\(z - 2\)\)]]
}], "Text"],

Cell[TextData[{
  "Solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  " and get  ",
  Cell[BoxData[
      \(Y \((z)\)\  = \ \(z\^3 - 3\ z\^2 + 6  z\)\/\(\((z - 1)\) \((z - 2)\) \
\((z - 3)\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Calculate the residues for  ",
  Cell[BoxData[
      \(f \((z)\) = \(Y \((z)\) 
            z\^\(n - 1\) = \(\(z\^3 - 3\ z\^2 + 
                  6  z\)\/\(\((z - 1)\) \((z - 2)\) \((z - 3)\)\)\) 
            z\^\(n - 1\)\)\)]],
  "  at the poles \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1"}], "]"}], " ", "=", 
        " ", \(lim\+\(z \[Rule] 1\)\ \(\(z\^3 - 3\ z\^2 + 
                    6  z\)\/\(\((z - 2)\) \((z - 3)\)\)\) 
              z\^\(n - 1\)\  = \ \(2*1\^\(n - 1\)\  = \ 2\)\)}]]],
  "  \n\t\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1"}], "]"}], " ", "=", 
        " ", \(lim\+\(z \[Rule] 2\)\ \(\(z\^3 - 3\ z\^2 + 
                    6  z\)\/\(\((z - 1)\) \((z - 3)\)\)\) 
              z\^\(n - 1\)\  = \ \(\(-\ 
                8\)*2\^\(\(-1\) + n\) = \ \(-2\^\(n + 2\)\)\)\)}]]],
  "  \n\t\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "3"}], "]"}], " ", "=", 
        " ", \(lim\+\(z \[Rule] 3\)\ \(z\^3 - 3\ z\^2 + 6  z\)\/\(\((z - 1)\) \
\((z - 2)\)\)\  = \ \(9*3\^\(\(-1\) + n\)\  = \ 3\^\(n + 1\)\)\)}]]],
  "  "
}], "Text"],

Cell[TextData[{
  "Thus the solution is  \n\n\t\t",
  Cell[BoxData[
      RowBox[{\(y[n]\), " ", "=", " ", 
        RowBox[{
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "1"}], "]"}], "+", 
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["2",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}], "]"}], "+", 
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["3",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}], "]"}]}]}]]],
  ", \n\n\t\t",
  Cell[BoxData[
      \(y[n]\  = \ 2\  - \ 2\^\(n + 2\)\  + \ 3\^\(n + 1\)\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.15 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "It is worthwhile to point out how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can do the important step using residues."
}], "Text"],

Cell[BoxData[{
    \(\(Y[
          z_]\  = \ \(z + z\^2\)\/\(3 - 4\ z + z\^2\);\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<           Y[z] = \>", Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<       Y[z]\!\(z\^\(n - 1\)\) = \>\"", 
        Y[z], \(\(z\)\(\ \)\)\^\(n - 1\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),1] = \>\"", 
        Residue[Y[z] z\^\(n - 1\), {z, 1}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),3] = \>\"", 
        Residue[Y[z] z\^\(n - 1\), {z, 3}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<          y[n] = Res[Y[z]\!\(z\^\(n - 1\)\),1] + \
Res[Y[z]\!\(z\^\(n - 1\)\),3]\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<          y[n] = \>", 
        Residue[Y[z] z\^\(n - 1\), {z, 1}] + 
          Residue[Y[z] z\^\(n - 1\), {z, 3}]\ ];\)\)}], "Input"],

Cell[TextData[{
  "\tTo solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 3\ y[n]\  = \ \(x[n] = 0\)\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 5\)}]}]}]]],
  ",  we will use our ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine  ",
  Cell[BoxData[
      \(Zsolution\)]],
  "  for finding the solution to",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\  = \ \(x[n] = \ 0\)\)]],
  ".   It will take the z-transforms of each term;  solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  ";  and it's inverse ",
  Cell[BoxData[
      \(y[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[Y[z]]\)],
    InitializationCell->True],
  ".   The format of the subroutine call is   ",
  Cell[BoxData[
      \(Zsolution[a, b, x[n], y\_0, y\_1]\)]],
  "  with   ",
  Cell[BoxData[
      RowBox[{\(a = 2\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "b"}], "=", "3"}]}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(x[n_] = 0;\)\), "\[IndentingNewLine]", 
    \(\(Zsolution[2, 3, x[n], 1, 5];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<and\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"],

Cell[TextData[{
  "\tTo solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 3\ y[n]\  = \ 0\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 5\)}]}]}]]],
  ",  we will use our ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine  ",
  Cell[BoxData[
      \(ResidueSolution\)]],
  "  for finding the solution to",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\  = \ 0\)]],
  ".   It will take the z-transforms of each term;  solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  ";  and it's inverse ",
  Cell[BoxData[
      \(y[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[Y[z]]\)],
    InitializationCell->True],
  ".   The format of the subroutine call is   ",
  Cell[BoxData[
      \(ResidueSolution[a, b, y\_0, y\_1]\)]],
  "  with   ",
  Cell[BoxData[
      RowBox[{\(a = 2\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "b"}], "=", "3"}]}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(ResidueSolution[2, 3, 1, 5];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[s[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(y1[n_] = \(-1\) + 2\ 3\^n;\)\), "\[IndentingNewLine]", 
    \(\(m0 = 5;\)\), "\n", 
    \(\(Y1\  = \ N[Table[y1[i], {i, 0, m0}]];\)\), "\n", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(ListPlot[Y1pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Red, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-5\), 500}}, 
        Ticks \[Rule] {Range[0, m0, 5], Range[0, 500, 100]}];\)\), "\n", 
    \(\(Print["\<y[n] = \>", y1[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y1[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.15 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "It is worthwhile to point out how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can do the important step using residues."
}], "Text"],

Cell[BoxData[{
    \(\(Y[
          z_]\  = \ \(6\ z - 3\ z\^2 + z\^3\)\/\(\((\(-2\) + z)\)\ \((3 - 4\ \
z + z\^2)\)\);\)\), "\[IndentingNewLine]", 
    \(\(Print["\<           Y[z] = \>", Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<       Y[z]\!\(z\^\(n - 1\)\) = \>\"", Y[z], 
        z\^\(n - 1\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<       Y[z]\!\(z\^\(n - 1\)\) = \>\"", 
        Numerator[Y[z]]\/Factor[Denominator[Y[z]]], 
        z\^\(n - 1\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),1] = \>\"", 
        Residue[Y[z] z\^\(n - 1\), {z, 1}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),2] = \>\"", 
        Residue[Y[z] z\^\(n - 1\), {z, 2}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),3] = \>\"", 
        Residue[Y[z] z\^\(n - 1\), {z, 3}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<          y[n] = Res[Y[z]\!\(z\^\(n - 1\)\),1] + \
Res[Y[z]\!\(z\^\(n - 1\)\),2] + Res[Y[z]\!\(z\^\(n - 1\)\),3]\>\""\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<          y[n] = \>", 
        Residue[Y[z] z\^\(n - 1\), {z, 1}] + 
          Residue[Y[z] z\^\(n - 1\), {z, 2}] + 
          Residue[Y[z] z\^\(n - 1\), {z, 3}]\ ];\)\)}], "Input"],

Cell[TextData[{
  "\tTo solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 3\ y[n]\  = \ \(x[n] = 2\^\(n + 2\)\)\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 3\)}]}]}]]],
  ",  we will use our ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine  ",
  Cell[BoxData[
      \(Zsolution\)]],
  "  for finding the solution to",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\  = \ x[n]\)]],
  ".   It will take the z-transforms of each term;  solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  ";  and it's inverse ",
  Cell[BoxData[
      \(y[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[Y[z]]\)],
    InitializationCell->True],
  ".   The format of the subroutine call is   ",
  Cell[BoxData[
      \(Zsolution[a, b, x[n], y\_0, y\_1]\)]],
  "  with  ",
  Cell[BoxData[
      RowBox[{\(a = 2\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "b"}], "=", "3"}]}]]],
  "  and  ",
  Cell[BoxData[
      \(x[n] = 2\^\(n + 2\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(x[n_] = 2\^\(n + 2\);\)\), "\[IndentingNewLine]", 
    \(\(Zsolution[2, 3, x[n], 1, 3];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(y1[n_] = 
        2 - 2\^\(2 + n\) + 3\^\(1 + n\);\)\), "\[IndentingNewLine]", 
    \(\(m0 = 5;\)\), "\n", 
    \(\(Y1\  = \ N[Table[y1[i], {i, 0, m0}]];\)\), "\n", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(ListPlot[Y1pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Blue, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-5\), 620}}, 
        Ticks \[Rule] {Range[0, m0, 5], Range[0, 600, 100]}];\)\), "\n", 
    \(\(Print["\<y[n] = \>", y1[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y1[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.16 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["z",
    FontFamily->"Courier New"],
  StyleBox["-",
    FontFamily->"Times New Roman"],
  "transform methods to solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 4\ y[n]\  = \ \ 0\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 5\)}]}]}]]],
  ".  \n\n",
  StyleBox["9.16 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["z",
    FontFamily->"Courier New"],
  StyleBox["-",
    FontFamily->"Times New Roman"],
  "transform methods to solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 4\ y[n]\  = \ \ 3\^n\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"2", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 3\)}]}]}]]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:O0000UB000`400?l0
0000o`00003oo`3ooooo0?oooj40oooo003o0?ooool0ooooX@3oool00?l0
ooooo`3ooonQ0?ooo`00o`3ooooo0?oooj40oooo003o0?ooool0ooooX@3o
ool00?l0ooooo`3ooonQ0?ooo`00S03oool5000002<0oooo1000000V0?oo
o`8000009`3oool3000002@0oooo0P00000U0?ooo`<00000I03oool50000
02<0oooo1000000V0?ooo`8000009`3oool3000002@0oooo0P00000V0?oo
o`<000005P3oool008h0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0V0?ooo`040000003oool0oooo000002L0oooo00<000000?oo
o`3oool08P3oool010000000oooo0?ooo`00000T0?ooo`040000003oool0
oooo000006D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo000002L0oooo00<000000?ooo`3oool0
8P3oool010000000oooo0?ooo`00000U0?ooo`040000003oool0oooo0000
01D0oooo002>0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0S0?ooo`D000009P3oool00`000000
oooo0?ooo`0R0?ooo`040000003oool0oooo000006D0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
02<0oooo1@00000V0?ooo`030000003oool0oooo02<0oooo00@000000?oo
o`3oool000005@3oool008h0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0280oooo00@000000?oo
o`3oool000009@3oool2000002D0oooo0`00001V0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0R
0?ooo`040000003oool0oooo000002D0oooo0P00000V0?ooo`<000005P3o
ool008h0oooo00<000000?ooo`3oool08`3oool010000000oooo0?ooo`00
000U0?ooo`040000003oool0oooo000002D0oooo00<000000?ooo`000000
9@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool08`3oool010000000oooo0?ooo`00000U0?ooo`04
0000003oool0oooo000002D0oooo00<000000?ooo`0000009@3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo01D0oooo002=0?ooo`80
00009P3oool2000002L0oooo0P00000W0?ooo`8000009@3oool3000002D0
oooo0`00001T0?ooo`8000009P3oool2000002L0oooo0P00000W0?ooo`80
00009@3oool3000002H0oooo0`00000E0?ooo`00o`3ooooo0?oooj40oooo
003o0?ooool0ooooX@3oool00?l0ooooo`3ooonQ0?ooo`00o`3ooooo0?oo
oj40oooo001U0?ooo`<0o`00o`3oool_0?ooo`030000003oool0oooo0?l0
oooo1`3oool006@0oooo1@3o000T0?ooo`<0o`00o`3oool50?ooo`<0003o
9P3oool30000obD0oooo0`000?ng0?ooo`00EP3oool>000000D0o`008`00
00050?l00<d000009`3oool>000000D0003o900000050000ob<000001@00
0?nV00000100oooo001T0?ooo`D0o`008`3oool50?l002@0oooo0`3o000W
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03T0oooo1@000?lT
0?ooo`D0003o8`3oool50000obD0oooo0`000?lV0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0D
0?ooo`00I@3oool30?l002@0oooo1@3o000S0?ooo`D0o`00fP3oool50000
ob@0oooo1@000?lS0?ooo`D0003o903oool50000ohd0oooo001V0?ooo`03
0000003oool0oooo02@0oooo0`3o000T0?ooo`D0o`00f`3oool30000obH0
oooo0`000?lU0?ooo`<0003o9@3oool50000ohd0oooo001V0?ooo`030000
003oool0oooo04/0oooo1@3o003M0?ooo`030000003oool0oooo07@0oooo
1@000?n=0?ooo`00IP3oool00`000000oooo0?ooo`1<0?ooo`<0o`00gP3o
ool00`000000oooo0?ooo`1e0?ooo`<0003oSP3oool006H0oooo00<00000
0?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0?l0oooo1`3oool0
06H0oooo00<000000?ooo`3oool0M@3oool30?l00;D0oooo00<000000?oo
o`3oool0o`3oool70?ooo`00IP3oool00`000000oooo0?ooo`1d0?ooo`D0
o`00]03oool00`000000oooo0?ooo`2M0?ooo`<0003oIP3oool006H0oooo
00<000000?ooo`3oool0M03oool50?l00;@0oooo00<000000?ooo`3oool0
W03oool50000ofD0oooo001V0?ooo`030000003oool0oooo07@0oooo1@3o
002d0?ooo`030000003oool0oooo09`0oooo1@000?mU0?ooo`00IP3oool0
0`000000oooo0?ooo`1e0?ooo`<0o`00]@3oool00`000000oooo0?ooo`2L
0?ooo`D0003oI@3oool006H0oooo00<000000?ooo`3oool0o`3oool^0?oo
o`030000003oool0oooo09d0oooo0`000?mV0?ooo`00IP3oool00`000000
oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool0o`3oool70?ooo`00
IP3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool0
o`3oool70?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<0
00000?ooo`3oool0o`3oool70?ooo`00IP3oool00`000000oooo0?ooo`3o
0?ooobh0oooo00<000000?ooo`3oool0o`3oool70?ooo`00DP3oool50000
0080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`3o0?oo
obh0oooo00<000000?ooo`3oool0o`3oool70?ooo`00E03oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo;P3oool0
0`000000oooo0?ooo`3o0?ooo`L0oooo001D0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo0`00003o0?ooobh0oooo00<000000?ooo`3oool0o`3o
ool70?ooo`00E03oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo09d0oooo0`3o002=0?ooo`030000003oool0oooo0?l0oooo
1`3oool005@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`2L0?ooo`D0o`00S03oool00`000000oooo0?ooo`3o0?ooo`L0
oooo001C0?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000
003oool0oooo09`0oooo1@3o002<0?ooo`030000003oool0oooo0?l0oooo
1`3oool006H0oooo00<000000?ooo`3oool0W03oool50?l008`0oooo00<0
00000?ooo`3oool0o`3oool70?ooo`00IP3oool00`000000oooo0?ooo`2M
0?ooo`<0o`00S@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?oo
o`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?oo
o`L0oooo001V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000
oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003oool0oooo0?l0oooo
;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003o
ool0oooo0?l0oooo6@3oool500000080oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003oool0
oooo0?l0oooo6`3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0?l0oooo1`3oool006H0oooo00<000000?ooo`3oool0o`3o
oolK0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00<0oooo0P00003o0?ooo`P0
oooo001V0?ooo`030000003oool0oooo0?l0oooo6`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo1`3oool006H0
oooo00<000000?ooo`3oool0o`3ooolK0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0o`3oool70?ooo`00IP3oool00`00
0000oooo0?ooo`3o0?oooaX0oooo0P0000040?ooo`800000103oool20000
00H0oooo00<000000?ooo`3oool0a@3oool30000och0oooo001V0?ooo`03
0000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`340?ooo`D0
003o?@3oool006H0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000
003oool0oooo0<@0oooo1@000?lm0?ooo`00IP3oool00`000000oooo0?oo
o`3o0?ooobh0oooo00<000000?ooo`3oool0a03oool50000ocd0oooo001B
0?ooo`@000000`3oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0?l0oooo;P3oool00`000000oooo0?ooo`350?ooo`<0003o?P3oool0
0580oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3o
ool^0?ooo`030000003oool0oooo0?l0oooo1`3oool005<0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo0`00003o0?ooobh0oooo00<000000?ooo`3oool0
o`3oool70?ooo`00E03oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0
oooo001B0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001C0?oo
o`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo
0?l0oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`03
0000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0
oooo001V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo
0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003oool0oooo0?l0oooo;P3o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003oool0
oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?oo
o`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?oo
o`L0oooo001V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000
oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003oool0oooo0?l0oooo
;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003o
ool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V
0?ooo`030000003oool0oooo0<D0oooo0`3o001U0?ooo`030000003oool0
oooo0?l0oooo1`3oool006H0oooo00<000000?ooo`3oool0a03oool50?l0
06@0oooo00<000000?ooo`3oool0o`3oool70?ooo`00IP3oool00`000000
oooo0?ooo`340?ooo`D0o`00I03oool00`000000oooo0?ooo`3o0?ooo`L0
oooo001V0?ooo`030000003oool0oooo0<@0oooo1@3o001T0?ooo`030000
003oool0oooo0?l0oooo1`3oool006H0oooo00<000000?ooo`3oool0a@3o
ool30?l006D0oooo00<000000?ooo`3oool0o`3oool70?ooo`00D`3oool2
000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`3o
0?ooobh0oooo00<000000?ooo`3oool0o`3oool70?ooo`00DP3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooobh0oooo
00<000000?ooo`3oool0o`3oool70?ooo`00E03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`<00000o`3oool^0?ooo`030000003oool0oooo0?l0
oooo1`3oool005D0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0o`3ooolI0?ooo`@000000`3oool2000000@0oooo0P0000060?oo
o`030000003oool0oooo0?l0oooo1`3oool00580oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo0?l0oooo1`3oool005<0oooo
0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
o`3ooolJ0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000050?ooo`800000o`3oool80?oo
o`00IP3oool00`000000oooo0?ooo`3o0?oooa/0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?oo
o`030000003oool0oooo0?l0oooo6@3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003o
ool0oooo0?l0oooo6P3oool2000000@0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003oool0
oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?oo
o`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?oo
o`L0oooo001V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000
oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003oool0oooo0?l0oooo
;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003o
ool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V
0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o
0?ooo`L0oooo001V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`00
0000oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003oool0oooo0?l0
oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000
003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo
001V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?oo
o`3o0?ooo`L0oooo001V0?ooo`030000003oool0oooo0?l0oooo;P3oool0
0`000000oooo0?ooo`3o0?ooo`L0oooo001D0?ooo`<000000P3oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo;P3oool00`00
0000oooo0?ooo`3o0?ooo`L0oooo001E0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o
0?ooo`L0oooo001B0?ooo`D0000000D0oooo0000003oool0oooo00000002
0?ooo`040000003oool0oooo000000@0oooo0`00003o0?ooobh0oooo00<0
00000?ooo`3oool0o`3oool70?ooo`00DP3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3o
ool0o`3oool70?ooo`00D`3oool00`000000oooo000000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool0o`3oool70?oo
o`00E03oool2000000<0oooo0P0000040?ooo`8000001@3oool00`000000
oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool0o`3oool70?ooo`00
IP3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool0
o`3oool70?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<0
00000?ooo`3oool0o`3oool70?ooo`00IP3oool00`000000oooo0?ooo`3o
0?ooobh0oooo00<000000?ooo`3oool0o`3oool70?ooo`00IP3oool00`00
0000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool0o`3oool70?oo
o`00IP3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3o
ool0o`3oool70?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooobh0oooo
00<000000?ooo`3oool0o`3oool70?ooo`00IP3oool00`000000oooo0?oo
o`3o0?ooobh0oooo00<000000?ooo`3oool0o`3oool70?ooo`00IP3oool0
0`000000oooo0?ooo`3o0?oooaX0oooo0P0000040?ooo`800000103oool2
000000H0oooo00<000000?ooo`3oool0o`3oool70?ooo`00IP3oool00`00
0000oooo0?ooo`3o0?oooaT0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0o`3oool70?ooo`00IP3oool00`000000oooo0?oo
o`3o0?oooa/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool200000?l0
oooo203oool006H0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo1`3oool006H0
oooo00<000000?ooo`3oool0o`3ooolI0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo0?l0oooo1`3oool006H0oooo00<00000
0?ooo`3oool0o`3ooolJ0?ooo`800000103oool2000000@0oooo0P000006
0?ooo`030000003oool0oooo0?l0oooo1`3oool005<0oooo0P0000040?oo
o`800000103oool2000000D0oooo00<000000?ooo`3oool0o`3oool^0?oo
o`030000003oool0oooo0?l0oooo1`3oool00580oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003o
ool0oooo0?l0oooo1`3oool005D0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
0`00003o0?ooobh0oooo00<000000?ooo`3oool0o`3oool70?ooo`00D`3o
ool2000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000
oooo0?ooo`3o0?ooo`L0oooo001C0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?oo
o`L0oooo001C0?ooo`<000000`3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0
oooo001V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo
0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003oool0oooo0?l0oooo;P3o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003oool0
oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?oo
o`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?oo
o`L0oooo001V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000
oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003oool0oooo0?l0oooo
;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003o
ool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V
0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o
0?ooo`L0oooo001V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`00
0000oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003oool0oooo0?l0
oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000
003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo
001V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?oo
o`3o0?ooo`L0oooo001V0?ooo`030000003oool0oooo0?l0oooo;P3oool0
0`000000oooo0?ooo`3o0?ooo`L0oooo001V0?ooo`030000003oool0oooo
0?l0oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001B0?ooo`<0
0000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0?l0
oooo;P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo001B0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo;P3oool0
0`000000oooo0?ooo`3o0?ooo`L0oooo001B0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`<00000o`3oool^0?ooo`030000003oool0oooo0?l0oooo
1`3oool00580oooo0`0000030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooobh0
oooo00<000000?ooo`3oool0o`3oool70?ooo`00D`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`3o0?oooa/0oooo0`0000020?oo
o`800000103oool2000000H0oooo00<000000?ooo`3oool0o`3oool70?oo
o`00D`3oool3000000<0oooo0P0000040?ooo`8000001@3oool00`000000
oooo0?ooo`3o0?oooa`0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`00IP3oool00`000000oooo0?ooo`3o0?oo
oaT0oooo1@0000001@3oool000000?ooo`3oool000000080oooo00@00000
0?ooo`3oool000001@3oool200000?l0oooo203oool006H0oooo00<00000
0?ooo`3oool0o`3ooolI0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo0>h0oooo0`000?lE0?ooo`00IP3oool00`000000oooo
0?ooo`3]0?ooo`<0o`00:@3oool00`000000oooo000000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`3]0?ooo`D0003o503oool006H0oooo00<000000?ooo`3o
ool0k03oool50?l002T0oooo0P0000030?ooo`800000103oool2000000H0
oooo00<000000?ooo`3oool0k@3oool50000oa@0oooo001V0?ooo`030000
003oool0oooo0>`0oooo1@3o000l0?ooo`030000003oool0oooo0>d0oooo
1@000?lD0?ooo`00IP3oool00`000000oooo0?ooo`3/0?ooo`D0o`00?03o
ool00`000000oooo0?ooo`3^0?ooo`<0003o5@3oool006H0oooo00<00000
0?ooo`3oool0k@3oool30?l003d0oooo00<000000?ooo`3oool0o`3oool7
0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?oo
o`3oool0o`3oool70?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooobh0
oooo00<000000?ooo`3oool0o`3oool70?ooo`00IP3oool00`000000oooo
0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool0o`3oool70?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{671, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.16 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Take the z-transforms of each term  \n\n\t\t",
  Cell[BoxData[
      \(z\^2\ \((Y \((z)\) - 1 - 5\ z\^\(-1\))\)\  - \ 
          4  z\ \((Y \((z)\) - 1)\) + 4  Y \((z)\)\  = \ 0\)]],
  " "
}], "Text"],

Cell[TextData[{
  "Solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  " and get  ",
  Cell[BoxData[
      \(Y \((z)\)\  = \ \(z\^2 + z\)\/\((z - 2)\)\^2\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Calculate the residue for  ",
  Cell[BoxData[
      \(f \((z)\) = \(Y \((z)\) 
            z\^\(n - 1\) = \(\(z\^2 + z\)\/\((z - 2)\)\^2\) 
            z\^\(n - 1\)\)\)]],
  "  at the pole\n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "2"}], "]"}], " ", 
        "=", \(lim\+\(z \[Rule] 2\)\ \(\[PartialD]\/\[PartialD]z\)[\((z\^2 + 
                  z)\) z\^\(n - 1\)]\)}]]],
  "  \n\t\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "2"}], "]"}], " ", 
        "=", \(lim\+\(z \[Rule] 2\)\ \((\((2\ z + 1)\) 
                z\^\(n - 1\)\  + \((n - 1)\) \((z + 
                    z\^2)\)\ z\^\(n - 2\))\)\)}]]],
  " \n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "2"}], "]"}], " ", 
        "=", \(5*2\^\(n - 1\) + 
            3\ \ \((n - 1)\) 2\^\(n - 1\)\ \  = \ \ 2\^n\  + \ 
            3  n\ 2\^\(n - 1\)\)}]]],
  " "
}], "Text"],

Cell[TextData[{
  "Thus the solution is  \n\n\t",
  Cell[BoxData[
      \(y[n]\  = \ 2\^n\  + \ 3  n\ 2\^\(n - 1\)\)]],
  "  \n\nwhich agrees with the result of example 2."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.16 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Take the z-transforms of each term  \n\n\t\t",
  Cell[BoxData[
      \(z\^2\ \((Y \((z)\) - 2 - 3\ z\^\(-1\))\)\  - \ 
          4 \((z\ \((Y \((z)\) - 2)\))\) + 4 \((Y \((z)\))\)\  = \ 
        4\/\(z - 3\)\)]]
}], "Text"],

Cell[TextData[{
  "Solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  " and get  ",
  Cell[BoxData[
      \(Y \((z)\)\  = \ \(2\ z\^3 - 11\ z\^2 + 16\ z\)\/\(\(\ \)\(\(\((z - 2)\
\)\^2\) \((z - 3)\)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Calculate the residue for  ",
  Cell[BoxData[
      \(f \((z)\) = \(Y \((z)\) 
            z\^\(n - 1\) = \(\(2\ z\^3 - 11\ z\^2 + 
                  16\ z\)\/\(\(\ \)\(\(\((z - 2)\)\^2\) \((z - 3)\)\)\)\) 
            z\^\(n - 1\)\)\)]],
  " at the poles \n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "2"}], "]"}], " ", 
        "=", \(lim\+\(z \[Rule] 2\)\ \([\(\[PartialD]\/\[PartialD]z\) \
\((\(\(2\ z\^3 - 11\ z\^2 + 16\ z\)\/\(\(\ \)\((z - 3)\)\)\) 
                  z\^\(n - 1\))\)]\)\)}]]],
  "  \n\t\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "2"}], "]"}], " ", 
        "=", \(lim\+\(z \[Rule] 2\)\ \(\(\(2 \((\ 
                      n + 1)\)\ z\^3 - \((17\ n + 12)\)\ z\^2 + \((49\ n + 
                        17)\)\ z - 48\ n\)\/\((z - 3)\)\^2\) \(z\^\(n - 
                  1\)\)\(\ \)\)\)}]]],
  "  \n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "2"}], "]"}], " ", 
        "=", \(\((2 - 2\ n)\) 2\^\(n - 1\)\ \  = \ \ 2\^n - 2\^n\ n\)}]]],
  " \nand\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "3"}], "]"}], " ", "=", 
        " ", \(lim\+\(z \[Rule] 3\)\ \(\(2\ z\^3 - 11\ z\^2 + 
                    16\ z\)\/\(\(\ \)\(\((z - 2)\)\^2\)\)\) 
              z\^\(n - 1\)\  = \ \(3*3\^\(\(-1\) + n\)\  = \ 3\^n\)\)}]]],
  "  "
}], "Text"],

Cell[TextData[{
  "Thus the solution is  ",
  Cell[BoxData[
      \(y[n]\  = \ 2\^n - n\ 2\^n\  + \ 3\^n\)]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.16(a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "It is worthwhile to point out how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can do the important step using residues."
}], "Text"],

Cell[BoxData[{
    \(\(Y[
          z_]\  = \ \(z + z\^2\)\/\((z - 2)\)\^2;\)\), "\[IndentingNewLine]", \

    \(\(Print["\<           Y[z] = \>", Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<       Y[z]\!\(z\^\(n - 1\)\) = \>\"", Y[z], 
        z\^\(n - 1\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),2] = \>\"", 
        Residue[Y[z] z\^\(n - 1\), {z, 2}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<          y[n] = Res[Y[z]\!\(z\^\(n - 1\)\),2]\>\""\ \
];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<          y[n] = \>", 
        Residue[Y[z] z\^\(n - 1\), {z, 2}]\ ];\)\)}], "Input"],

Cell[TextData[{
  "\tTo solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 4\ y[n]\  = \ \(x[n] = 0\)\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 5\)}]}]}]]],
  ",  we will use our ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine  ",
  Cell[BoxData[
      \(Zsolution\)]],
  "  for finding the solution to",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\  = \ \(x[n] = \ 0\)\)]],
  ".   It will take the z-transforms of each term;  solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  ";  and it's inverse ",
  Cell[BoxData[
      \(y[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[Y[z]]\)],
    InitializationCell->True],
  ".   The format of the subroutine call is   ",
  Cell[BoxData[
      \(Zsolution[a, b, x[n], y\_0, y\_1]\)]],
  "  with   ",
  Cell[BoxData[
      RowBox[{\(a = 2\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "b"}], "=", "4"}]}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(x[n_] = 0;\)\), "\[IndentingNewLine]", 
    \(\(Zsolution[2, 4, x[n], 1, 5];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"],

Cell[TextData[{
  "\tTo solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 4\ y[n]\  = 0\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 5\)}]}]}]]],
  ",  we will use our ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine  ",
  Cell[BoxData[
      \(ResidueSolution\)]],
  "  for finding the solution to",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\  = \ 0\)]],
  ".   It will take the z-transforms of each term;  solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  ";  and it's inverse ",
  Cell[BoxData[
      \(y[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[Y[z]]\)],
    InitializationCell->True],
  ".   The format of the subroutine call is   ",
  Cell[BoxData[
      \(ResidueSolution[a, b, y\_0, y\_1]\)]],
  "  with   ",
  Cell[BoxData[
      RowBox[{\(a = 2\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "b"}], "=", "4"}]}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(ResidueSolution[2, 4, 1, 5];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[s[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(y1[n_] = 2\^n + 3\ 2\^\(\(-1\) + n\)\ n;\)\), "\[IndentingNewLine]", 
    \(\(m0 = 6;\)\), "\n", 
    \(\(Y1\  = \ N[Table[y1[i], {i, 0, m0}]];\)\), "\n", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(ListPlot[Y1pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Red, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-5\), 670}}, 
        Ticks \[Rule] {Range[0, m0, 5], Range[0, 600, 100]}];\)\), "\n", 
    \(\(Print["\<y[n] = \>", y1[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y1[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.16 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "It is worthwhile to point out how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can do the important step using residues."
}], "Text"],

Cell[BoxData[{
    \(\(Y[
          z_]\  = \ \(16\ z - 11\ z\^2 + 2\ z\^3\)\/\(\((\(-3\) + z)\)\ \((4 \
- 4\ z + z\^2)\)\);\)\), "\[IndentingNewLine]", 
    \(\(Print["\<           Y[z] = \>", Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<       Y[z]\!\(z\^\(n - 1\)\) = \>\"", Y[z], 
        z\^\(n - 1\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<       Y[z]\!\(z\^\(n - 1\)\) = \>\"", 
        Numerator[Y[z]]\/Factor[Denominator[Y[z]]], 
        z\^\(n - 1\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),2] = \>\"", 
        Residue[Y[z] z\^\(n - 1\), {z, 2}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),3] = \>\"", 
        Residue[Y[z] z\^\(n - 1\), {z, 3}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<          y[n] = Res[Y[z]\!\(z\^\(n - 1\)\),2] + \
Res[Y[z]\!\(z\^\(n - 1\)\),3]\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<          y[n] = \>", 
        Residue[Y[z] z\^\(n - 1\), {z, 2}] + 
          Residue[Y[z] z\^\(n - 1\), {z, 3}]\ ];\)\)}], "Input"],

Cell[TextData[{
  "\tTo solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 4\ y[n]\  = \ \(x[n] = 3\^n\)\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"2", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 3\)}]}]}]]],
  ",  we will use our ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine  ",
  Cell[BoxData[
      \(Zsolution\)]],
  "  for finding the solution to",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\  = \ x[n]\)]],
  ".   It will take the z-transforms of each term;  solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  ";  and it's inverse ",
  Cell[BoxData[
      \(y[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[Y[z]]\)],
    InitializationCell->True],
  ".   The format of the subroutine call is   ",
  Cell[BoxData[
      \(Zsolution[a, b, x[n], y\_0, y\_1]\)]],
  "  with  ",
  Cell[BoxData[
      RowBox[{\(a = 2\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "b"}], "=", "4"}]}]]],
  "  and  ",
  Cell[BoxData[
      \(x[n] = 3\^n\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(x[n_] = 3\^n;\)\), "\[IndentingNewLine]", 
    \(\(Zsolution[2, 4, x[n], 2, 3];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(y1[n_] = 2\^n + 3\^n - 2\^n\ n;\)\), "\[IndentingNewLine]", 
    \(\(m0 = 6;\)\), "\n", 
    \(\(Y1\  = \ N[Table[y1[i], {i, 0, m0}]];\)\), "\n", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(ListPlot[Y1pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Blue, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-5\), 430}}, 
        Ticks \[Rule] {Range[0, m0, 5], Range[0, 600, 100]}];\)\), "\n", 
    \(\(Print["\<y[n] = \>", y1[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y1[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.17 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["z",
    FontFamily->"Courier New"],
  StyleBox["-",
    FontFamily->"Times New Roman"],
  "transform methods to solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 5\ y[n]\  = \ \ 0\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 5\)}]}]}]]],
  ".  \n\n",
  StyleBox["9.17 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["z",
    FontFamily->"Courier New"],
  StyleBox["-",
    FontFamily->"Times New Roman"],
  "transform methods to solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 
          5\ y[n]\  = \ \ \((1 - \[ImaginaryI])\)\^n + \((1 + \
\[ImaginaryI])\)\^n\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 0\)}]}]}]]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:O0000UB000`400?l0
0000o`00003oo`3ooooo0?oooj40oooo003o0?ooool0ooooX@3oool00?l0
ooooo`3ooonQ0?ooo`00o`3ooooo0?oooj40oooo003o0?ooool0ooooX@3o
ool00?l0ooooo`3ooonQ0?ooo`00o`3ooooo0?oooj40oooo003o0?ooool0
ooooX@3oool00?l0ooooo`3ooonQ0?ooo`00o`3ooonD0?ooo`030000003o
ool0oooo0?l0oooo2P3oool00?l0ooooU03oool00`000000oooo0?ooo`3o
0?ooo`X0oooo003o0?oooi@0oooo00<000000?ooo`3oool0`P3oool30000
od@0oooo001Y0?ooo`030000003oool0oooo0?l0oooo:03oool00`000000
oooo0?ooo`310?ooo`D0003o@`3oool006T0oooo00<000000?ooo`3oool0
o`3ooolX0?ooo`030000003oool0oooo0<40oooo1@000?m30?ooo`00J@3o
ool00`000000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0`@3o
ool50000od<0oooo001Y0?ooo`030000003oool0oooo0=/0oooo0`3o0019
0?ooo`030000003oool0oooo0<80oooo0`000?m40?ooo`00J@3oool00`00
0000oooo0?ooo`3J0?ooo`D0o`00B03oool00`000000oooo0?ooo`3o0?oo
o`X0oooo001Y0?ooo`030000003oool0oooo0=X0oooo1@3o000d0?ooo`D0
00000P3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0?l0
oooo2P3oool006T0oooo00<000000?ooo`3oool0fP3oool50?l003H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2V0?oo
o`<0003oH03oool006T0oooo00<000000?ooo`3oool0f`3oool30?l003L0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00P3oool300000:D0oooo1@000?mO
0?ooo`00J@3oool00`000000oooo0?ooo`3o0?ooo`h0oooo100000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0Y@3o
ool50000oel0oooo001Y0?ooo`030000003oool0oooo0?l0oooo5P3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0:D0oooo
1@000?mO0?ooo`00J@3oool00`000000oooo0?ooo`3o0?oooaD0oooo0P00
00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0YP3o
ool30000of00oooo001A0?ooo`<000000P3oool2000000@0oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<00000
0?ooo`3oool0o`3oool:0?ooo`00DP3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo
:03oool00`000000oooo0?ooo`3o0?ooo`X0oooo001?0?ooo`D0000000D0
oooo0000003oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000103oool200000?l0oooo:@3oool00`00
0000oooo0?ooo`3o0?ooo`X0oooo00190?ooo`@000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`3o0?ooo`X0oooo
001@0?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`030000003oool0oooo
08X0oooo0`000?ml0?ooo`00D@3oool2000000<0oooo0P0000040?ooo`80
0000103oool2000000D0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`03
0000003oool0oooo0540oooo0P00000f0?ooo`D0003o5`3oool300000580
oooo0`00000<0?ooo`00J@3oool00`000000oooo0?ooo`3o0?ooobP0oooo
00<000000?ooo`3oool0D03oool010000000oooo0?ooo`00000e0?ooo`D0
003o5`3oool010000000oooo0?ooo`00000f0?ooo`<0003o6P3oool00`00
0000oooo0?ooo`0:0?ooo`00J@3oool00`000000oooo0?ooo`3o0?ooobP0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0d0?ooo`D0
003o5`3oool010000000oooo0?ooo`00000e0?ooo`D0003o603oool30000
00/0oooo001Y0?ooo`030000003oool0oooo0?l0oooo:03oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo03@0oooo0`000?lH0?ooo`<0
0000=P3oool50000oaL0oooo00@000000?ooo`3oool000002`3oool006T0
oooo00<000000?ooo`3oool0o`3ooolX0?ooo`030000003oool0oooo0500
oooo00@000000?ooo`3oool000006@3oool30000ocH0oooo00<000000?oo
o`3oool0=@3oool50000oaL0oooo00@000000?ooo`3oool000002`3oool0
06T0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`030000003oool0oooo
0540oooo0P00000I0?ooo`D0003o=@3oool3000003H0oooo0`000?lI0?oo
o`<000002`3oool006T0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`03
0000003oool0oooo06`0oooo1@000?nH0?ooo`00J@3oool00`000000oooo
0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0D@3oool30000oaP0oooo
1@000?nH0?ooo`00J@3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<0
00000?ooo`3oool0D03oool50000oaP0oooo0`000?nI0?ooo`00J@3oool0
0`000000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0603oool3
0000oaT0oooo0`000?lI0?ooo`D0003o]03oool006T0oooo00<000000?oo
o`3oool0o`3ooolW0?ooo`<0003o603oool50000oaL0oooo1@000?lH0?oo
o`D0003o]03oool006T0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`T0
00001@000?lG000000D0003o5`0000050000oaT000000`000?n^000000L0
oooo001Y0?ooo`030000003oool0oooo0?l0oooo9P3oool50000oaL0oooo
1@000?lG0?ooo`D0003o6P3oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool02P3oool006T0oooo00<0
00000?ooo`3oool0o`3ooolV0?ooo`D0003o603oool30000oaT0oooo0`00
0?lK0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`0:0?ooo`00J@3oool00`000000oooo0?ooo`3o
0?ooobL0oooo0`000?oo0?ooo`/0oooo001Y0?ooo`030000003oool0oooo
0?l0oooo:03oool00`000000oooo0?ooo`3o0?ooo`X0oooo001Y0?ooo`03
0000003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`3o0?ooo`X0
oooo001Y0?ooo`030000003oool0oooo0?l0oooo:03oool00`000000oooo
0?ooo`3o0?ooo`X0oooo001Y0?ooo`030000003oool0oooo0?l0oooo:03o
ool00`000000oooo0?ooo`3o0?ooo`X0oooo001Y0?ooo`030000003oool0
oooo0?l0oooo:03oool00`000000oooo0?ooo`3o0?ooo`X0oooo001Y0?oo
o`030000003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`3o0?oo
o`X0oooo001@0?ooo`800000103oool2000000@0oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3o
ool0o`3oool:0?ooo`00C`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo:03o
ool00`000000oooo0?ooo`3o0?ooo`X0oooo001A0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool200000?l0
oooo:@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00190?ooo`@00000
1@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`3o
0?ooo`X0oooo001?0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`03
0000003oool0oooo0?l0oooo2P3oool00500oooo0P0000040?ooo`800000
103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo
:03oool00`000000oooo0?ooo`3o0?ooo`X0oooo001Y0?ooo`030000003o
ool0oooo0?l0oooo:03oool00`000000oooo0?ooo`3o0?ooo`X0oooo001Y
0?ooo`030000003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`3o
0?ooo`X0oooo001Y0?ooo`030000003oool0oooo0?l0oooo503oool50000
0080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`3o0?oo
o`X0oooo001Y0?ooo`030000003oool0oooo0?l0oooo5P3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo2P3oool0
06T0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo0`00003o0?ooo`X0oooo001Y0?ooo`030000003oool0
oooo0?l0oooo5P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0?l0oooo2P3oool006T0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0o`3oool:0?ooo`00J@3oool00`000000oooo0?ooo`3o0?oooaD0oooo
0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
o`3oool:0?ooo`00J@3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<0
00000?ooo`3oool0o`3oool:0?ooo`00J@3oool00`000000oooo0?ooo`3o
0?ooobP0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00J@3oool00`00
0000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0o`3oool:0?oo
o`00J@3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3o
ool0o`3oool:0?ooo`00J@3oool00`000000oooo0?ooo`3o0?ooobP0oooo
00<000000?ooo`3oool0o`3oool:0?ooo`00J@3oool00`000000oooo0?oo
o`3o0?ooobP0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00J@3oool0
0`000000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0o`3oool:
0?ooo`00J@3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<000000?oo
o`3oool0o`3oool:0?ooo`00J@3oool00`000000oooo0?ooo`3o0?ooobP0
oooo00<000000?ooo`3oool0o`3oool:0?ooo`00J@3oool00`000000oooo
0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00J@3o
ool00`000000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0o`3o
ool:0?ooo`00J@3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<00000
0?ooo`3oool0o`3oool:0?ooo`00C`3oool4000000<0oooo0P0000040?oo
o`800000103oool2000000D0oooo00<000000?ooo`3oool0o`3ooolX0?oo
o`030000003oool0oooo0?l0oooo2P3oool004l0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`3o0?ooobP0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00D03oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`80
0000o`3ooolE0?ooo`@000000`3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0?l0oooo2P3oool004T0oooo100000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3o0?oooa@0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0o`3oool:0?ooo`00C`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0?l0oooo5@3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool300000?l0oooo
2P3oool00500oooo0P0000040?ooo`800000103oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo0?l0oooo5P3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo2P3oool006T0oooo
00<000000?ooo`3oool0o`3ooolD0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0?l0oooo2P3oool006T0oooo00<000000?oo
o`3oool0o`3ooolE0?ooo`800000103oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo0?l0oooo2P3oool006T0oooo00<000000?ooo`3o
ool0o`3ooolX0?ooo`030000003oool0oooo0?l0oooo2P3oool006T0oooo
00<000000?ooo`3oool0o`3ooolX0?ooo`030000003oool0oooo0?l0oooo
2P3oool006T0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`030000003o
ool0oooo0?l0oooo2P3oool006T0oooo00<000000?ooo`3oool0o`3ooolX
0?ooo`030000003oool0oooo0?l0oooo2P3oool006T0oooo00<000000?oo
o`3oool0`P3oool30?l00680oooo00<000000?ooo`3oool0o`3oool:0?oo
o`00J@3oool00`000000oooo0?ooo`310?ooo`D0o`00H@3oool00`000000
oooo0?ooo`3o0?ooo`X0oooo001Y0?ooo`030000003oool0oooo0<40oooo
1@3o001Q0?ooo`030000003oool0oooo0?l0oooo2P3oool006T0oooo00<0
00000?ooo`3oool0`@3oool50?l00640oooo00<000000?ooo`3oool0o`3o
ool:0?ooo`00J@3oool00`000000oooo0?ooo`320?ooo`<0o`00HP3oool0
0`000000oooo0?ooo`3o0?ooo`X0oooo001Y0?ooo`030000003oool0oooo
0?l0oooo:03oool00`000000oooo0?ooo`3o0?ooo`X0oooo001Y0?ooo`03
0000003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`3o0?ooo`X0
oooo001Y0?ooo`030000003oool0oooo0?l0oooo:03oool00`000000oooo
0?ooo`3o0?ooo`X0oooo001Y0?ooo`030000003oool0oooo0?l0oooo:03o
ool00`000000oooo0?ooo`3o0?ooo`X0oooo001Y0?ooo`030000003oool0
oooo0?l0oooo:03oool00`000000oooo0?ooo`3o0?ooo`X0oooo001Y0?oo
o`030000003oool0oooo0?l0oooo5@3oool2000000@0oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo001Y0?ooo`03
0000003oool0oooo0?l0oooo503oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`3o0?ooo`X0oooo001Y0?ooo`030000003oool0
oooo0?l0oooo5P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`<00000
o`3oool:0?ooo`00J@3oool00`000000oooo0?ooo`3o0?oooaL0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool:0?ooo`00
C`3oool500000080oooo0P0000040?ooo`800000103oool2000000D0oooo
00<000000?ooo`3oool0o`3ooolD0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0?l0oooo2P3oool00540oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0?l0oooo5@3oool2000000@0oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo001A0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool20000
0?l0oooo:@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00190?ooo`@0
0000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0o`3ooolX0?ooo`030000003o
ool0oooo0?l0oooo2P3oool00540oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0
oooo:03oool00`000000oooo0?ooo`3o0?ooo`X0oooo001@0?ooo`800000
103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo
0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00J@3o
ool00`000000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0o`3o
ool:0?ooo`00J@3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<00000
0?ooo`3oool0o`3oool:0?ooo`00J@3oool00`000000oooo0?ooo`3o0?oo
obP0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00J@3oool00`000000
oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00
J@3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0
o`3oool:0?ooo`00J@3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<0
00000?ooo`3oool0o`3oool:0?ooo`00J@3oool00`000000oooo0?ooo`3o
0?ooobP0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00J@3oool00`00
0000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0o`3oool:0?oo
o`00J@3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3o
ool0o`3oool:0?ooo`00J@3oool00`000000oooo0?ooo`3o0?ooobP0oooo
00<000000?ooo`3oool0o`3oool:0?ooo`00J@3oool00`000000oooo0?oo
o`3o0?oooaH0oooo0`0000020?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0o`3oool:0?ooo`00J@3oool00`000000oooo0?ooo`1h
0?ooo`800000;`3oool30?l004@0oooo1@0000020?ooo`8000007@3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`X0oooo
001Y0?ooo`030000003oool0oooo07L0oooo00@000000?ooo`3oool00000
;@3oool50?l004D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo01L0oooo1@0000001@3oool000000?ooo`3oool00000
0080oooo00@000000?ooo`3oool00000103oool300000?l0oooo2P3oool0
06T0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0[0?oo
o`D0o`00A@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool05`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`3o0?ooo`X0oooo001Y0?ooo`030000003oool0oooo07P0oooo
0P00000^0?ooo`D0o`00A@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0603oool00`000000oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`3o0?ooo`X0oooo001Y0?ooo`030000003oool0oooo
07P0oooo00<000000?ooo`3oool0;P3oool30?l004H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01T0oooo0P000003
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0o`3oool:
0?ooo`00J@3oool00`000000oooo0?ooo`1h0?ooo`<00000MP3oool20000
00@0oooo0P00000^0?ooo`030000003oool0oooo0?l0oooo2P3oool006T0
oooo00<000000?ooo`3oool0o`3ooolX0?ooo`030000003oool0oooo0?l0
oooo2P3oool006T0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`030000
003oool0oooo0?l0oooo2P3oool006T0oooo00<000000?ooo`3oool0o`3o
oolX0?ooo`030000003oool0oooo0?l0oooo2P3oool006P0oooo0`3o000E
0?ooo`<0o`00o`3ooolA0?ooo`030000003oool0oooo0?l0oooo2P3oool0
06L0oooo1@3o000C0?ooo`D0o`005@3oool30?l001H0oooo0`3o00170?oo
o`<0o`00U03oool00`000000oooo0?ooo`3o0?ooo`X0oooo001O0?ooo`P0
00001@3o000C000000D0o`00500000050?l001@000001@3o000E000000<0
o`00;@0000050?l006D00000;P3oool00`000000oooo0?ooo`3o0?ooo`X0
oooo001W0?ooo`D0o`004`3oool50?l001@0oooo1@3o000D0?ooo`D0o`00
503oool50?l001D0oooo0`3o000D0?ooo`D0o`00H@3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo0?l0oooo2P3oool006P0oooo0`3o
000E0?ooo`<0o`005@3oool50?l001@0oooo1@3o000D0?ooo`D0o`00503o
ool50?l001<0oooo1@3o001Q0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0o`3oool:0?ooo`00J@3oool00`000000oooo0?ooo`0]
0?ooo`<0o`005P3oool30?l001D0oooo1@3o000D0?ooo`D0o`00503oool3
0?l009@0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00J@3oool00`00
0000oooo0?ooo`1O0?ooo`<0o`005@3oool50?l00:/0oooo00<000000?oo
o`3oool0o`3oool:0?ooo`00J@3oool00`000000oooo0?ooo`1h0?ooo`<0
o`00[03oool00`000000oooo0?ooo`3o0?ooo`X0oooo001Y0?ooo`030000
003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`3o0?ooo`X0oooo
001Y0?ooo`030000003oool0oooo0?l0oooo:03oool00`000000oooo0?oo
o`3o0?ooo`X0oooo001Y0?ooo`030000003oool0oooo0?l0oooo5@3oool2
000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`3o
0?ooo`X0oooo001Y0?ooo`030000003oool0oooo0?l0oooo503oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`X0oooo
001Y0?ooo`030000003oool0oooo0?l0oooo5`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool300000?l0oooo2P3oool006T0oooo00<000000?ooo`3oool0
o`3ooolE0?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool:0?oo
o`00J@3oool00`000000oooo0?ooo`3o0?oooaD0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0n`3oool30000o`/0oooo001Y0?oo
o`030000003oool0oooo0?l0oooo5@3oool3000000<0oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`3j0?ooo`D0003o2P3oool00?l0
ooooU03oool00`000000oooo0?ooo`3j0?ooo`D0003o2P3oool00?l0oooo
U03oool00`000000oooo0?ooo`3j0?ooo`D0003o2P3oool00?l0ooooU03o
ool00`000000oooo0?ooo`3k0?ooo`<0003o2`3oool00?l0ooooo`3ooonQ
0?ooo`00o`3ooooo0?oooj40oooo003o0?ooool0ooooX@3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{671, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.17 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Take the z-transforms of each term  \n\n\t\t",
  Cell[BoxData[
      \(z\^2\ \((Y \((z)\) - 1 - 5\ z\^\(-1\))\)\  - \ 
          4  z\ \((Y \((z)\) - 1)\) + 5  Y \((z)\)\  = \ 0\)]]
}], "Text"],

Cell[TextData[{
  "Solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  " and get  ",
  Cell[BoxData[
      \(Y \((z)\)\  = \ \(\(z\^2 + z\)\/\(z\^2 - 4\ z + 5\)\  = \ \(z\^2 + \
z\)\/\(\((z - 2 + \[ImaginaryI])\) \((z - 2 - \[ImaginaryI])\)\)\)\)]]
}], "Text"],

Cell[TextData[{
  "Calculate the residue for  ",
  Cell[BoxData[
      \(f \((z)\) = \(Y \((z)\) 
            z\^\(n - 1\) = \(\(z\^2 + 
                  z\)\/\(\((z - 2 + \[ImaginaryI])\) \((z - 
                      2 - \[ImaginaryI])\)\)\) z\^\(n - 1\)\)\)]],
  "  at the poles \n\t\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(2 + \[ImaginaryI]\)}], "]"}], " ", 
        "=", " ", \(lim\+\(z \[Rule] 2 + \[ImaginaryI]\)\ \((z - 
                  2 - \[ImaginaryI])\) \(\(z\^2 + 
                    z\)\/\(\((z - 2 + \[ImaginaryI])\) \((z - 
                        2 - \[ImaginaryI])\)\)\) 
              z\^\(n - 1\)\  = \ \(lim\+\(z \[Rule] 2 + \[ImaginaryI]\)\ \
\(\(z\^2 + z\)\/\((z - 2 + \[ImaginaryI])\)\) 
                z\^\(n - 1\)\  = \ \(\(\(5 - 
                      5\ \[ImaginaryI]\)\/2\) \((2 + \[ImaginaryI])\)\^\(n - \
1\)\  = \ \((\(1 - 3\ \[ImaginaryI]\)\/2)\) \((2 + \
\[ImaginaryI])\)\^n\)\)\)}]]],
  "  \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(2 - \[ImaginaryI]\)}], "]"}], " ", 
        "=", " ", \(lim\+\(z \[Rule] 2 - \[ImaginaryI]\)\ \((z - 
                  2 + \[ImaginaryI])\) \(\(z\^2 + 
                    z\)\/\(\((z - 2 + \[ImaginaryI])\) \((z - 
                        2 - \[ImaginaryI])\)\)\) 
              z\^\(n - 1\)\  = \ \(lim\+\(z \[Rule] 2 - \[ImaginaryI]\)\ \
\(\(z\^2 + z\)\/\((z - 2 - \[ImaginaryI])\)\) 
                z\^\(n - 1\)\  = \ \(\(\(5 + 
                      5\ \[ImaginaryI]\)\/2\) \((2 - \[ImaginaryI])\)\^\(n - \
1\)\  = \ \((\(1 + 3\ \[ImaginaryI]\)\/2)\) \((2 - \
\[ImaginaryI])\)\^n\)\)\)}]]],
  "  \n"
}], "Text"],

Cell[TextData[{
  "Therefore, the solution is  \n\n\t\t",
  Cell[BoxData[
      RowBox[{\(y[n]\), " ", "=", " ", 
        RowBox[{
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(2 + \[ImaginaryI]\)}], "]"}], " ",
           "+", " \[InvisibleSpace]", 
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(2 - \[ImaginaryI]\)}], 
            "]"}]}]}]]],
  "\n\n\t\t",
  Cell[BoxData[
      \(y[
          n]\  = \ \[InvisibleSpace]\(1 - 3\ \[ImaginaryI]\)\/2\ \((2 + \
\[ImaginaryI])\)\^n\  + \ \(1 + 3\ \[ImaginaryI]\)\/2\ \((2 - \
\[ImaginaryI])\)\^n\)]],
  " \n\nwhich agrees with the result of example 3. \n\nRemark.  Observe that \
",
  Cell[BoxData[
      RowBox[{\(Res[f \((z)\), 2 - \[ImaginaryI]]\), " ", "=", 
        RowBox[{
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(\(2 + \[ImaginaryI]\)\&_\)}], 
            "]"}], " ", "=", " ", 
          OverscriptBox[
            RowBox[{"Res", "[", 
              RowBox[{\(f \((z)\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                RowBox[{
                  StyleBox["2",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "+", "\[ImaginaryI]"}]}], "]"}],
             "_"]}]}]]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.17 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Take the z-transforms of each term  \n\n\t\t",
  Cell[BoxData[
      \(z\^2\ \((Y \((z)\)\  - \ 1\  - \ 0\ z\^\(-1\))\)\  - \ 
          4  z\ \((Y \((z)\)\  - \ 1)\) + 5  Y \((z)\)\  = \ 
        z\/\(z - 1 - \[ImaginaryI]\) + z\/\(z - 1 + \[ImaginaryI]\)\)]]
}], "Text"],

Cell[TextData[{
  "Solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  " and get  ",
  Cell[BoxData[
      \(Y \((z)\)\  = \ \(z\^4 - 6\ z\^3 + 12\ z\^2 - 10\ z\)\/\(\((z - 1 + \
\[ImaginaryI])\) \((z - 1 - \[ImaginaryI])\)\ \((z - 2 + \[ImaginaryI])\) \
\((z - 2 - \[ImaginaryI])\)\)\)]]
}], "Text"],

Cell[TextData[{
  "Calculate the residues for  ",
  Cell[BoxData[
      \(f \((z)\) = \(Y \((z)\) 
            z\^\(n - 1\) = \(\(z\^4 - 6\ z\^3 + 12\ z\^2 - 
                  10\ z\)\/\(\((z - 1 + \[ImaginaryI])\) \((z - 
                      1 - \[ImaginaryI])\)\ \((z - 
                      2 + \[ImaginaryI])\) \((z - 2 - \[ImaginaryI])\)\)\) 
            z\^\(n - 1\)\)\)]],
  "  at the poles \n\n\t\t",
  Cell[BoxData[
      \(Res[f \((z)\), 
          1 + \[ImaginaryI]]\  = \ \(lim\+\(z \[Rule] 1 + \[ImaginaryI]\)\ \(\
\(z\^4 - 6\ z\^3 + 12\ z\^2 - 
                    10\ z\)\/\(\((z - 1 + \[ImaginaryI])\)\ \((z - 
                        2 + \[ImaginaryI])\) \((z - 2 - \[ImaginaryI])\)\)\) 
              z\^\(n - 1\)\  = \ \(\((\(\(-1\) + 3\ \[ImaginaryI]\)\/5)\) \
\((1 + \[ImaginaryI])\)\^\(n - 1\)\  = \ \(\(1\/10\) \((2 + 
                  4\ \[ImaginaryI])\)\(\ \)\(\((1 + \[ImaginaryI])\)\^n\)\(\ \
\)\)\)\)\)]],
  "\t\t\n\n\t\t",
  Cell[BoxData[
      \(Res[f \((z)\), 
          1 - \[ImaginaryI]]\  = \ \(lim\+\(z \[Rule] 1 + \[ImaginaryI]\)\ \(\
\(z\^4 - 6\ z\^3 + 12\ z\^2 - 
                    10\ z\)\/\(\((z - 1 - \[ImaginaryI])\)\ \((z - 
                        2 + \[ImaginaryI])\) \((z - 2 - \[ImaginaryI])\)\)\) 
              z\^\(n - 1\)\  = \ \(\((\(\(-1\) - 3\ \[ImaginaryI]\)\/5)\) \
\((1 - \[ImaginaryI])\)\^\(n - 1\)\  = \ \(1\/10\) \((2 - 
                  4\ \[ImaginaryI])\)\ \((1 - \[ImaginaryI])\)\^n\)\)\)]],
  "\n\n\t\t",
  Cell[BoxData[
      \(Res[f \((z)\), 
          2 + \[ImaginaryI]]\  = \ \(lim\+\(z \[Rule] 2 + \[ImaginaryI]\)\ \(\
\(z\^4 - 6\ z\^3 + 12\ z\^2 - 
                    10\ z\)\/\(\((z - 1 + \[ImaginaryI])\) \((z - 
                        1 - \[ImaginaryI])\)\ \ \((z - 
                        2 + \[ImaginaryI])\)\)\) 
              z\^\(n - 1\)\  = \ \(\((\(2 + 11\ \[ImaginaryI]\)\/10)\) \((2 + \
\[ImaginaryI])\)\^\(n - 1\)\  = \(1\/10\) \((3 + 
                  4\ \[ImaginaryI])\)\ \((2 + \[ImaginaryI])\)\^n\)\)\)]],
  "\n\n\t\t",
  Cell[BoxData[
      \(Res[f \((z)\), 
          2 - \[ImaginaryI]]\  = \ \(lim\+\(z \[Rule] 2 - \[ImaginaryI]\)\ \(\
\(z\^4 - 6\ z\^3 + 12\ z\^2 - 
                    10\ z\)\/\(\((z - 1 + \[ImaginaryI])\) \((z - 
                        1 - \[ImaginaryI])\)\ \ \((z - 
                        2 - \[ImaginaryI])\)\)\) 
              
              z\^\(n - 1\)\  = \ \(\((\(2 - 11\ \[ImaginaryI]\)\/10)\) \((2 - \
\[ImaginaryI])\)\^\(n - 1\)\  = \ \(1\/10\) \((3 - 
                  4\ \[ImaginaryI])\)\ \((2 - \[ImaginaryI])\)\^n\)\)\)]]
}], "Text"],

Cell[TextData[{
  "Therefore, the solution is  \n\n\t\t",
  Cell[BoxData[
      RowBox[{\(y[n]\), " ", "=", " ", 
        RowBox[{
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(1 + \[ImaginaryI]\)}], "]"}], "+",
           "\[InvisibleSpace]", 
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(1 - \[ImaginaryI]\)}], "]"}], "+",
           
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(2 + \[ImaginaryI]\)}], "]"}], "+",
           
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(2 - \[ImaginaryI]\)}], 
            "]"}]}]}]]],
  "\n\n\t\t",
  Cell[BoxData[
      \(y[n]\  = \ 
        1\/10\ \((\((2 + 
                    4\ \[ImaginaryI])\)\ \((1 + \[ImaginaryI])\)\^n\  + \((2 \
- 4\ \[ImaginaryI])\)\ \((1 - \[ImaginaryI])\)\^n + \((3 + 
                    4\ \[ImaginaryI])\)\ \((2 + \[ImaginaryI])\)\^n + \((3 - 
                    4\ \[ImaginaryI])\)\ \((2 - \[ImaginaryI])\)\^n)\)\)]],
  " "
}], "Text"],

Cell[TextData[{
  "Remark.  Observe that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(1 - \[ImaginaryI]\)}], "]"}], " ", 
        "=", 
        RowBox[{
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(\(1 + \[ImaginaryI]\)\&_\)}], 
            "]"}], " ", "=", " ", 
          OverscriptBox[
            RowBox[{"Res", "[", 
              RowBox[{\(f \((z)\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(1 + \[ImaginaryI]\)}], "]"}], 
            "_"]}]}]]],
  " and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"Res", "[", 
          RowBox[{\(f \((z)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(2 - \[ImaginaryI]\)}], "]"}], " ", 
        "=", 
        RowBox[{
          RowBox[{"Res", "[", 
            RowBox[{\(f \((z)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(\(2 + \[ImaginaryI]\)\&_\)}], 
            "]"}], " ", "=", " ", 
          OverscriptBox[
            RowBox[{"Res", "[", 
              RowBox[{\(f \((z)\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                RowBox[{
                  StyleBox["2",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "+", "\[ImaginaryI]"}]}], "]"}],
             "_"]}]}]]],
  ".\n"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.17 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "It is worthwhile to point out how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can do the important step using residues."
}], "Text"],

Cell[BoxData[{
    \(\(Y[
          z_]\  = \ \(z + z\^2\)\/\(5 - 4\ z + z\^2\);\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<           Y[z] = \>", Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<       Y[z]\!\(z\^\(n - 1\)\) = \>\"", 
        Y[z], \(\(z\)\(\ \)\)\^\(n - 1\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),2-\[ImaginaryI]] = \>\"", 
        Residue[Y[z] z\^\(n - 1\), {z, 
            2 - \[ImaginaryI]}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),2+\[ImaginaryI]] = \>\"", 
        Residue[Y[z] z\^\(n - 1\), {z, 
            2 + \[ImaginaryI]}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<          y[n] = Res[Y[z]\!\(z\^\(n - 1\)\),2-\
\[ImaginaryI]] + Res[Y[z]\!\(z\^\(n - 1\)\),2+\[ImaginaryI]}]\>\""\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<          y[n] = \>", 
        Residue[Y[z] z\^\(n - 1\), {z, 2 - \[ImaginaryI]}] + 
          Residue[Y[z] z\^\(n - 1\), {z, 
              2 + \[ImaginaryI]}]\ ];\)\)}], "Input"],

Cell[TextData[{
  "\tTo solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 5\ y[n]\  = \ \(x[n] = 0\)\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 5\)}]}]}]]],
  ",  we will use our ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine  ",
  Cell[BoxData[
      \(Zsolution\)]],
  "  for finding the solution to",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\  = \ \(x[n] = \ 0\)\)]],
  ".   It will take the z-transforms of each term;  solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  ";  and it's inverse ",
  Cell[BoxData[
      \(y[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[Y[z]]\)],
    InitializationCell->True],
  ".   The format of the subroutine call is   ",
  Cell[BoxData[
      \(Zsolution[a, b, x[n], y\_0, y\_1]\)]],
  "  with   ",
  Cell[BoxData[
      RowBox[{\(a = 2\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "b"}], "=", "5"}]}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(x[n_] = 0;\)\), "\[IndentingNewLine]", 
    \(\(Zsolution[2, 5, x[n], 1, 5];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"],

Cell[TextData[{
  "\tTo solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 5\ y[n]\  = 0\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 5\)}]}]}]]],
  ",  we will use our ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine  ",
  Cell[BoxData[
      \(ResidueSolution\)]],
  "  for finding the solution to",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\  = \ 0\)]],
  ".   It will take the z-transforms of each term;  solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  ";  and it's inverse ",
  Cell[BoxData[
      \(y[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[Y[z]]\)],
    InitializationCell->True],
  ".   The format of the subroutine call is   ",
  Cell[BoxData[
      \(ResidueSolution[a, b, y\_0, y\_1]\)]],
  "  with   ",
  Cell[BoxData[
      RowBox[{\(a = 2\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "b"}], "=", "5"}]}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(ResidueSolution[2, 5, 1, 5];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[s[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to compare  ",
  Cell[BoxData[
      \(y[
          n] = \((1\/2 + \(3\ \[ImaginaryI]\)\/2)\)\ \((2 - \
\[ImaginaryI])\)\^n + \((1\/2 - \(3\ \[ImaginaryI]\)\/2)\)\ \((2 + \
\[ImaginaryI])\)\^n\)]],
  "  and  ",
  Cell[BoxData[
      \(y[n] = 
        5\^\(n/2\)\ Cos[n\ ArcTan[1\/2]] + 
          3\ 5\^\(n/2\)\ Sin[n\ ArcTan[1\/2]]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(y1[
          n_] = \((1\/2 + \(3\ \[ImaginaryI]\)\/2)\)\ \((2 - \[ImaginaryI])\)\
\^n + \((1\/2 - \(3\ \[ImaginaryI]\)\/2)\)\ \((2 + \[ImaginaryI])\)\^n;\)\), \
"\[IndentingNewLine]", 
    \(\(y2[n_] = 
        5\^\(n/2\)\ Cos[n\ ArcTan[1\/2]] + 
          3\ 5\^\(n/2\)\ Sin[n\ ArcTan[1\/2]];\)\), "\[IndentingNewLine]", 
    \(\(m0 = 10;\)\), "\n", 
    \(\(Y1\  = \ N[Table[y2[i], {i, 0, m0}]];\)\), "\n", 
    \(\(Y2\  = \ N[Table[y2[i], {i, 0, m0}]];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\n", 
    \(\(Y2pts = Transpose[{ticval, Y2}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(ListPlot[Y1pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Red, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-4500\), 500}}, 
        Ticks \[Rule] {Range[0, m0, 5], 
            Range[\(-4500\), 500, 500]}];\)\), "\n", 
    \(\(Print["\<y[n] = \>", y1[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[
            y1[n], {n, 0, 9}], "\<...\>"]\ ];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Y2pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Green, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-4500\), 500}}, 
        Ticks \[Rule] {Range[0, m0, 5], 
            Range[\(-4500\), 500, 500]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y2[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[
            y2[n], {n, 0, 9}], "\<...\>"]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[
            Simplify[y2[n]], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution  9.17 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "It is worthwhile to point out how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can do the important step using residues."
}], "Text"],

Cell[BoxData[{
    \(\(Y[
          z_]\  = \ \(\(-10\)\ z + 12\ z\^2 - 6\ z\^3 + \
z\^4\)\/\(\((\((\(-1\) - \[ImaginaryI])\) + z)\)\ \((\((\(-1\) + \
\[ImaginaryI])\) + z)\)\ \((5 - 4\ z + z\^2)\)\);\)\), "\[IndentingNewLine]", \

    \(\(Print["\<            Y[z] = \>", 
        Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<          Y[z]z  = \>", Y[z], 
        z\^\(n - 1\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<          Y[z]z  = \>", 
        Numerator[Y[z]]\/Factor[Denominator[Y[z]]], 
        z\^\(n - 1\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),1-\[ImaginaryI]] = \>\"", 
        Residue[Y[z] z\^\(n - 1\), {z, 
            1 - \[ImaginaryI]}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),1+\[ImaginaryI]] = \>\"", 
        Residue[Y[z] z\^\(n - 1\), {z, 
            1 + \[ImaginaryI]}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),2-\[ImaginaryI]] = \>\"", 
        Residue[Y[z] z\^\(n - 1\), {z, 
            2 - \[ImaginaryI]}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),2+\[ImaginaryI]] = \>\"", 
        Residue[Y[z] z\^\(n - 1\), {z, 
            2 + \[ImaginaryI]}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = Res[Y[z]\!\(z\^\(n - 1\)\),1-\[ImaginaryI]] + \
Res[Y[z]\!\(z\^\(n - 1\)\),1+\[ImaginaryI]]+Res[Y[z]\!\(z\^\(n - 1\)\),2-\
\[ImaginaryI]] + Res[Y[z]\!\(z\^\(n - 1\)\),2+\[ImaginaryI]]\>\""\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", 
        Residue[Y[z] z\^\(n - 1\), {z, 1 - \[ImaginaryI]}] + 
          Residue[Y[z] z\^\(n - 1\), {z, 1 + \[ImaginaryI]}] + 
          Residue[Y[z] z\^\(n - 1\), {z, 2 - \[ImaginaryI]}] + 
          Residue[Y[z] z\^\(n - 1\), {z, 
              2 + \[ImaginaryI]}]\ ];\)\)}], "Input"],

Cell[TextData[{
  "\tTo solve  ",
  Cell[BoxData[
      \(y[n + 2] - 4\ y[n + 1] + 
          5\ y[n]\  = \ \(x[
            n] = \((1 - \[ImaginaryI])\)\^n + \((1 + \
\[ImaginaryI])\)\^n\)\)]],
  "   with  ",
  Cell[BoxData[
      RowBox[{\(y[0]\), "=", 
        RowBox[{\(y\_0\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(y[1]\)}], 
            "=", \(y\_1 = 0\)}]}]}]]],
  ",  we will use our ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine  ",
  Cell[BoxData[
      \(Zsolution\)]],
  "  for finding the solution to",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\  = \ x[n]\)]],
  ".   It will take the z-transforms of each term;  solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  ";  and it's inverse ",
  Cell[BoxData[
      \(y[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[Y[z]]\)],
    InitializationCell->True],
  ".   The format of the subroutine call is   ",
  Cell[BoxData[
      \(Zsolution[a, b, x[n], y\_0, y\_1]\)]],
  "  with  ",
  Cell[BoxData[
      RowBox[{\(a = 2\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "b"}], "=", "5"}]}]]],
  "  and  ",
  Cell[BoxData[
      \(x[n] = \((1 - \[ImaginaryI])\)\^n + \((1 + \[ImaginaryI])\)\^n\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(x[
          n_] = \ \((1 - \[ImaginaryI])\)\^n + \((1 + \
\[ImaginaryI])\)\^n;\)\), "\[IndentingNewLine]", 
    \(\(Zsolution[2, 5, x[n], 1, 0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(y1[n_] = 
        1\/10\ \((\((2 - 
                    4\ \[ImaginaryI])\)\ \((1 - \[ImaginaryI])\)\^n + \((2 + 
                    4\ \[ImaginaryI])\)\ \((1 + \[ImaginaryI])\)\^n + \((3 - 
                    4\ \[ImaginaryI])\)\ \((2 - \[ImaginaryI])\)\^n + \((3 + 
                    4\ \[ImaginaryI])\)\ \((2 + \[ImaginaryI])\)\^n)\);\)\), \
"\[IndentingNewLine]", 
    \(\(m0 = 9;\)\), "\n", 
    \(\(Y1\  = \ N[Table[y1[i], {i, 0, m0}]];\)\), "\n", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(ListPlot[Y1pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Blue, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-150\), 530}}, 
        Ticks \[Rule] {Range[0, m0, 3], 
            Range[\(-100\), 600, 100]}];\)\), "\n", 
    \(\(Print["\<y[n] = \>", y1[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y1[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.18.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve  ",
  Cell[BoxData[
      \(y[n + 3] + y[n + 2] + y[n + 1] + y[n] = 0\)]],
  "   with  ",
  Cell[BoxData[
      \(y[0]\  = \ 2, \ y[1]\  = \ \(-2\), \ and\ \ y[2]\  = \ 0\)]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo
001c0?ooo`@00000103oool00`000000oooo0?ooo`090?ooo`<0o`00<03o
ool30?l00300oooo0`3o000a0?ooo`<0o`00<03oool30?l00300oooo0`3o
00090?ooo`00L`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00P0oooo1@3o000^0?ooo`D0o`00;P3oool50?l002l0oooo1@3o000^
0?ooo`D0o`00;P3oool50?l000P0oooo001d0?ooo`030000003oool0oooo
00@0oooo0`0000080?ooo`D0o`00;P3oool50?l002h0oooo1@3o000_0?oo
o`D0o`00;P3oool50?l002h0oooo1@3o00080?ooo`00K@3oool4000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`D0
o`00;P3oool50?l002h0oooo1@3o000_0?ooo`D0o`00;P3oool50?l002h0
oooo1@3o00080?ooo`00L`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00T0oooo0`3o000`0?ooo`<0o`00<03oool30?l00340
oooo0`3o000`0?ooo`<0o`00<03oool30?l000T0oooo001d0?ooo`800000
1@3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003o
ool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF
0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`03
0000003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0
o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k
0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?oo
o`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0
oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<0
00000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o
0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0
oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo
0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3o
ool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`00
0000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0
oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3o
ool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0
oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?oo
o`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000
003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?oo
o`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3o
ool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo
001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<00000
0?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oo
oaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo
00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?oo
o`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool0
07/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000
oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo
5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool0
0`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo
0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00
N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003o
ool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF
0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`03
0000003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0
o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k
0?ooo`030000003oool0oooo01D0oooo1000000G0?ooo`<000005@3oool3
000001P0oooo0P00000C0?ooo`D000000P3oool200000140oooo1@000000
0`3oool000000000000200000100oooo1@0000030?ooo`<000003P3oool5
000000040?ooo`000000000000000140oooo1@0000020?ooo`8000004@3o
ool4000000<0oooo0P00000C0?ooo`00N`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0503oool0
10000000oooo0?ooo`00000F0?ooo`040000003oool0oooo000001@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0100
oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000180oooo001k0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool05@3oool5000001D0oooo00@0
00000?ooo`3oool000005P3oool010000000oooo0?ooo`00000D0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool01000
0000oooo0?ooo`3oool500000100oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000B0?ooo`00N`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool0
00005P3oool3000001P0oooo0P00000E0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`3o
ool3000001<0oooo00<000000?ooo`3oool00P3oool2000001<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0100oooo
001k0?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool00000
5P3oool00`000000oooo0000000G0?ooo`030000003oool0oooo01H0oooo
00@000000?ooo`3oool00000503oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`02
0?ooo`030000003oool000000140oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000004P3oool007/0oooo00<000000?ooo`3oool0
5P3oool2000001P0oooo0P00000G0?ooo`<000005`3oool2000001@0oooo
0P0000040?ooo`8000004P3oool2000000@0oooo0P00000B0?ooo`800000
1@3oool200000100oooo0P0000040?ooo`<000004@3oool2000000@0oooo
0P00000B0?ooo`800000103oool2000001<0oooo001k0?ooo`030000003o
ool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF
0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`03
0000003oool0oooo01D0oooo0`3o000:0?ooo`<0o`00903oool30?l000X0
oooo0`3o000S0?ooo`<0o`002P3oool30?l002<0oooo0`3o000:0?ooo`<0
o`00903oool30?l000X0oooo0`3o000R0?ooo`00N`3oool00`000000oooo
0?ooo`0D0?ooo`D0o`00203oool50?l00280oooo1@3o00080?ooo`D0o`00
8@3oool50?l000P0oooo1@3o000Q0?ooo`D0o`00203oool50?l00280oooo
1@3o00080?ooo`D0o`008@3oool007H0oooo700000050?l000P000001@3o
000R000000D0o`00200000050?l0024000001@3o0008000000D0o`008@00
00050?l000P000001@3o000R000000D0o`00200000050?l001X000001`3o
ool007/0oooo00<000000?ooo`3oool0503oool50?l000P0oooo1@3o000:
0?ooo`030000003oool0oooo01D0oooo1@3o00080?ooo`D0o`002P3oool0
0`000000oooo0?ooo`0D0?ooo`D0o`00203oool50?l000X0oooo00<00000
0?ooo`3oool0503oool50?l000P0oooo1@3o000:0?ooo`030000003oool0
oooo01D0oooo1@3o00080?ooo`D0o`002P3oool00`000000oooo0?ooo`0D
0?ooo`00N`3oool00`000000oooo0?ooo`0E0?ooo`<0o`002P3oool30?l0
00/0oooo00<000000?ooo`3oool05P3oool30?l000X0oooo0`3o000;0?oo
o`030000003oool0oooo01D0oooo0`3o000:0?ooo`<0o`002`3oool00`00
0000oooo0?ooo`0E0?ooo`<0o`002P3oool30?l000/0oooo00<000000?oo
o`3oool05P3oool30?l000X0oooo0`3o000;0?ooo`030000003oool0oooo
01@0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo
00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?oo
o`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool0
07/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000
oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo
5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool0
0`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo
0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00
N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003o
ool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF
0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`03
0000003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0
o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k
0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?oo
o`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0
oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<0
00000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o
0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0
oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo
0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3o
ool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`00
0000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0
oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3o
ool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0
oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?oo
o`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000
003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?oo
o`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3o
ool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo
001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<00000
0?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oo
oaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo
00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?oo
o`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool0
07/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000
oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo
5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool0
0`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo
0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00
N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003o
ool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF
0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`03
0000003oool0oooo0?l0oooo5P3oool007<0oooo100000030?ooo`<0o`00
<03oool30?l00300oooo0`3o000a0?ooo`<0o`00<03oool30?l00300oooo
0`3o000F0?ooo`00L`3oool00`000000oooo0?ooo`030?ooo`D0o`00;P3o
ool50?l002h0oooo1@3o000_0?ooo`D0o`00;P3oool50?l002h0oooo1@3o
000E0?ooo`00M03oool00`000000oooo0?ooo`020?ooo`D0o`00;P3oool5
0?l002h0oooo1@3o000_0?ooo`D0o`00;P3oool50?l002h0oooo1@3o000E
0?ooo`00M@3oool010000000oooo0?ooo`3oool50?l002h0oooo1@3o000^
0?ooo`D0o`00;`3oool50?l002h0oooo1@3o000^0?ooo`D0o`005@3oool0
07<0oooo00@000000?ooo`3oool000000`3oool30?l00300oooo0`3o000`
0?ooo`<0o`00<@3oool30?l00300oooo0`3o000`0?ooo`<0o`005P3oool0
07@0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo5P3oool00?l0
ooooU03oool00?l0ooooU03oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Take the z-transforms of each term  \n\n\t",
  Cell[BoxData[
      \(z\^3\ \((Y \((z)\) - 2 + 2  z\^\(-1\) - 0  z\^\(-2\))\)\  + 
          z\^2\ \((Y \((z)\) - 2 + 2  z\^\(-1\))\)\  + 
          z\ \((Y \((z)\) - 2)\) + Y \((z)\) = \ 0\)]]
}], "Text"],

Cell[TextData[{
  "Solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  " and get  ",
  Cell[BoxData[
      \(Y \((z)\) = \(\(2\ z\^3\)\/\(z\^3 + z\^2 + z + 1\)\  = \ \(2  \
z\^3\)\/\(\((z + 1)\)\ \((z - \[ImaginaryI])\)\ \((z + \
\[ImaginaryI])\)\)\)\)]]
}], "Text"],

Cell[TextData[{
  "Calculate the residues for  ",
  Cell[BoxData[
      \(f \((z)\) = \(Y \((z)\) 
            z\^\(n - 1\) = \(\(2 
                   z\^3\)\/\(\((z + 
                      1)\)\ \((z - \[ImaginaryI])\)\ \((z + \
\[ImaginaryI])\)\)\) z\^\(n - 1\)\)\)]],
  "  at the poles \n\n\t",
  Cell[BoxData[
      \(Res[
          f \((z)\), \(-1\)]\  = \ \(lim\+\(z \[Rule] \(-1\)\)\ \(\(2 
                     z\^3\)\/\((z\^2 + 1)\)\) 
              z\^\(n - 1\)\  = \ \((\(-1\))\)\^n\)\)]],
  "  \n\n\t",
  Cell[BoxData[
      \(Res[
          f \((z)\), \ \[ImaginaryI]\ ]\  = \ \(lim\+\(z \[Rule] \
\[ImaginaryI]\)\ \(\(2  z\^3\)\/\(\((z + 1)\)\ \((z + \[ImaginaryI])\)\)\) 
              z\^\(n - 1\)\  = \ \((1\/2 + \[ImaginaryI]\/2)\)\ \[ImaginaryI]\
\^n\)\)]],
  "  \n\n\t",
  Cell[BoxData[
      \(Res[
          f \((z)\), \(-\[ImaginaryI]\)]\  = \ \(lim\+\(z \[Rule] \(-\
\[ImaginaryI]\)\)\ \(\(2  z\^3\)\/\(\((z + 1)\)\ \((z - \[ImaginaryI])\)\)\) 
              z\^\(n - 1\)\  = \ \((1\/2 - \[ImaginaryI]\/2)\)\ \((\(-\
\[ImaginaryI]\))\)\^n\)\)]],
  "  "
}], "Text"],

Cell[TextData[{
  "Thus the solution is  ",
  Cell[BoxData[
      \(y[
          n]\  = \ \((\(-1\))\)\^n\  + \ \((1\/2 + \[ImaginaryI]\/2)\)\ \
\[ImaginaryI]\^n\  + \ \((1\/2 - \[ImaginaryI]\/2)\)\ \
\((\(-\[ImaginaryI]\))\)\^n\)]],
  "  which can be rewritten as \n\n\t\t",
  Cell[BoxData[
      \(y[
          n]\  = \ \((\(-1\))\)\^n + \ \(1\/2\) \((\[ImaginaryI]\^n + \((\(-\
\[ImaginaryI]\))\)\^n)\)\ \  - 
          1\/\(2  \[ImaginaryI]\)\ \((\[ImaginaryI]\^n - \
\((\(-\[ImaginaryI]\))\)\^n)\)\)]],
  "\n\t\t\n\t\t",
  Cell[BoxData[
      \(y[
          n]\  = \ \[ExponentialE]\^\(\[ImaginaryI]\ n\ \[Pi]\) + \(1\/2\) \
\((\[ExponentialE]\^\(\(\[ImaginaryI]\ n\ \[Pi]\)\/2\) + \
\[ExponentialE]\^\(\(\(-\[ImaginaryI]\)\ n\ \[Pi]\)\/2\))\)\ \  - \(\(1\/\(2  \
\[ImaginaryI]\)\)\(\ \)\((\[ExponentialE]\^\(\(\[ImaginaryI]\ n\ \[Pi]\)\/2\) \
- \[ExponentialE]\^\(\(\(-\[ImaginaryI]\)\ n\ \[Pi]\)\/2\))\)\(\ \)\)\)]],
  "\n\t\t\n\t\t",
  Cell[BoxData[
      \(y[n]\  = \ 
        cos \((\[Pi]\ n)\) + cos \((\(\[Pi]\/2\) n)\) - 
          sin \((\(\[Pi]\/2\) n)\)\)]],
  "   "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  In the next section we will see that \n\n\t\t",
  Cell[BoxData[
      \(y[n]\  = \ \(1\/4\) \((x[n] + x[n - 1] + x[n - 2] + x[n - 3])\)\)]],
  "  \n\nis a moving average filter which filters out the signals ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{\(cos \((\[Pi]\ n)\)\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          " ", \(cos \((\(\(\(\ \)\(\[Pi]\)\)\/2\) n)\)\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          " ", \(and\ \ sin \((\(\[Pi]\/2\) n)\)\)}]}]]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Take the z-transforms of each term and then solve for  ",
  Cell[BoxData[
      \(Y[z]\)]],
  ".  Substitute ",
  Cell[BoxData[
      \(y\_0\  = \ 2, \ \ y\_1\  = \ \(-2\), \ \ and\ \ y\_2\  = \ 0\)]],
  "  into \n\t",
  Cell[BoxData[
      \(z\^3\ \((Y[z]\  - \ 
                y\_0\  - \ \(y\_1\) z\^\(-1\) - \ \(y\_2\) z\^\(-2\))\)\  + 
          z\^2\ \((Y[z]\  - \ y\_0\  - \ \(y\_1\) z\^\(-1\))\)\  + 
          z\ \((Y[z]\  - \ y\_0)\) + Y[z] = \ 0\)]],
  ",  and get\n\t",
  Cell[BoxData[
      \(z\^3\ \((Y[z]\  - \ 2\  + 2  z\^\(-1\) - \ 0  z\^\(-2\))\)\  + 
          z\^2\ \((Y[z]\  - \ 2\  + 2  z\^\(-1\))\)\  + 
          z\ \((Y[z]\  - \ 2)\) + Y[z] \[Equal] \ 0\)]]
}], "Text"],

Cell[BoxData[{
    \(\(Clear[Y, z];\)\), "\[IndentingNewLine]", 
    \(\(eqn\  = \ 
        z\^3\ \((Y[z]\  - \ 2\  + 2  z\^\(-1\) - \ 0  z\^\(-2\))\)\  + 
            z\^2\ \((Y[z]\  - \ 2\  + 2  z\^\(-1\))\)\  + 
            z\ \((Y[z]\  - \ 2)\) + Y[z] \[Equal] \ 
          0;\)\), "\[IndentingNewLine]", 
    \(\(Print[\ eqn\ ];\)\), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqn, Y[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Y[z_] = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\[IndentingNewLine]", 
    \(\(y[n_] = InverseZTransform[Y[z], z, n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve for Y[z] and get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y[z] = \>", Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Take the inverse z-transformation\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = \!\(\[GothicCapitalZ]\^\(-1\)\)[Y[z]] = \!\(\
\[GothicCapitalZ]\^\(-1\)\)[\>\"", 
        Y[z], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(y[n_] = 
        Simplify[ComplexExpand[y[n]], 
          n \[Element] Integers];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Compare this solution with  ",
  Cell[BoxData[
      \(y[n] = 
        Cos[n\ \[Pi]] + Cos[\(n\ \[Pi]\)\/2] - Sin[\(n\ \[Pi]\)\/2]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(y1[n_] = \((\(-1\))\)\^n + Cos[\(n\ \[Pi]\)\/2] - 
          Sin[\(n\ \[Pi]\)\/2];\)\), "\[IndentingNewLine]", 
    \(\(y2[n_] = 
        Cos[n\ \[Pi]] + Cos[\(n\ \[Pi]\)\/2] - 
          Sin[\(n\ \[Pi]\)\/2];\)\), "\[IndentingNewLine]", 
    \(\(m0 = 21;\)\), "\n", 
    \(\(Y1\  = \ N[Table[y2[i], {i, 0, m0}]];\)\), "\n", 
    \(\(Y2\  = \ N[Table[y2[i], {i, 0, m0}]];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\n", 
    \(\(Y2pts = Transpose[{ticval, Y2}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(ListPlot[Y1pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Red, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-2.1\), 2.1}}, 
        Ticks \[Rule] {Range[0, m0, 5], Range[\(-2\), 10, 2]}];\)\), "\n", 
    \(\(Print["\<y[n] = \>", y1[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Y2pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Green, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-2.1\), 2.1}}, 
        Ticks \[Rule] {Range[0, m0, 5], 
            Range[\(-2\), 10, 2]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y2[n]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Use the fact that ",
  Cell[BoxData[
      \(z\^3 + z\^2 + z + 
          1\  = \ \(\((z + 1)\) \((z\^2 + 1)\)\  = \ \((z + 
                1)\)\ \((z - \[ImaginaryI])\)\ \((z + \[ImaginaryI])\)\)\)]],
  " and write  ",
  Cell[BoxData[
      \(Y[z]\)]],
  " in the form"
}], "Text"],

Cell[BoxData[{
    \(\(Y[z_]\  = \ \(2\ z\^3\)\/\(1 + z + z\^2 + z\^3\);\)\), "\n", 
    \(\(Print["\<Y[z] = \>", Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Y[
          z_]\  = \ \(2  z\^3\)\/\(\((z + 1)\)\ \((z - \[ImaginaryI])\)\ \((z \
+ \[ImaginaryI])\)\);\)\), "\n", 
    \(\(Print["\<Y[z] = \>", Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(f[z_] = Y[z] z\^\(n - 1\);\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", Y[z], 
        z\^\(n - 1\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The solution y[n]  can be computed using residues\n\n\t",
  Cell[BoxData[
      \(Res[
          Y[z] z\^\(n - 1\), {z, \(-1\)}]\  = \ \(Limit[\(\(2 
                     z\^3\)\/\((z\^2 + 1)\)\) z\^\(n - 1\), 
            z \[Rule] \(-1\)]\  = \ \((\(-1\))\)\^n\)\)]],
  "  \n\n\t",
  Cell[BoxData[
      \(Res[
          Y[z] z\^\(n - 1\), {z, \[ImaginaryI]}]\  = \ \(Limit[\(\(2 
                     z\^3\)\/\(\((z + 1)\)\ \((z + \[ImaginaryI])\)\)\) 
              z\^\(n - 1\), 
            z \[Rule] \[ImaginaryI]]\  = \ \((1\/2 + \[ImaginaryI]\/2)\)\ \
\[ImaginaryI]\^n\)\)]],
  "  \n\n\t",
  Cell[BoxData[
      \(Res[
          Y[z] z\^\(n - 1\), {z, \(-\[ImaginaryI]\)}]\  = \ \(Limit[\(\(2 
                     z\^3\)\/\(\((z + 1)\)\ \((z - \[ImaginaryI])\)\)\) 
              z\^\(n - 1\), 
            z \[Rule] \(-\[ImaginaryI]\)]\  = \ \((1\/2 - \[ImaginaryI]\/2)\)\
\ \((\(-\[ImaginaryI]\))\)\^n\)\)]],
  "  "
}], "Text"],

Cell[BoxData[{
    \(\(y[n]\  = \ 
        Residue[Y[z] z\^\(n - 1\), {z, \(-1\)}] + 
          Residue[Y[z] z\^\(n - 1\), {z, \[ImaginaryI]}] + 
          Residue[Y[z] 
              z\^\(n - 1\), {z, \(-\[ImaginaryI]\)}];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),-1] = \>\"", 
        Residue[Y[z] 
            z\^\(n - 1\), {z, \(-1\)}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< Res[Y[z]\!\(z\^\(n - 1\)\),\[ImaginaryI]] = \>\"", 
        Residue[Y[z] 
            z\^\(n - 1\), {z, \[ImaginaryI]}]\ \ ];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),-\[ImaginaryI]] = \>\"", 
        Residue[Y[z] 
            z\^\(n - 1\), {z, \(-\[ImaginaryI]\)}]\ \ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = Res[Y[z]\!\(z\^\(n - 1\)\),-1] + \
Res[Y[z]\!\(z\^\(n - 1\)\),\[ImaginaryI]] + Res[Y[z]\!\(z\^\(n - 1\)\),-\
\[ImaginaryI]]\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The solution is  ",
  Cell[BoxData[
      \(y[
          n] = \((\(-1\))\)\^n + \((1\/2 + \[ImaginaryI]\/2)\)\ \[ImaginaryI]\
\^n + \((1\/2 - \[ImaginaryI]\/2)\)\ \((\(-\[ImaginaryI]\))\)\^n\)]],
  ".  Which can be written as ",
  Cell[BoxData[
      \(y[n] = 
        Cos[n\ \[Pi]] + Cos[\(n\ \[Pi]\)\/2] - Sin[\(n\ \[Pi]\)\/2]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(y1[
          n_] = \((\(-1\))\)\^n + \((1\/2 - \[ImaginaryI]\/2)\)\ \((\(-\
\[ImaginaryI]\))\)\^n + \((1\/2 + \[ImaginaryI]\/2)\)\ \[ImaginaryI]\^n;\)\), \
"\[IndentingNewLine]", 
    \(\(y2[n_] = 
        Cos[n\ \[Pi]] + Cos[\(n\ \[Pi]\)\/2] - 
          Sin[\(n\ \[Pi]\)\/2];\)\), "\[IndentingNewLine]", 
    \(\(m0 = 21;\)\), "\n", 
    \(\(Y1\  = \ N[Table[y2[i], {i, 0, m0}]];\)\), "\n", 
    \(\(Y2\  = \ N[Table[y2[i], {i, 0, m0}]];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\n", 
    \(\(Y2pts = Transpose[{ticval, Y2}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(ListPlot[Y1pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Red, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-2.1\), 2.1}}, 
        Ticks \[Rule] {Range[0, m0, 5], Range[\(-2\), 10, 2]}];\)\), "\n", 
    \(\(Print["\<y[n] = \>", y1[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Y2pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Green, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-2.1\), 2.1}}, 
        Ticks \[Rule] {Range[0, m0, 5], 
            Range[\(-2\), 10, 2]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y2[n]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can show that the two formulas compute the same values."
}], "Text"],

Cell[BoxData[{
    \(FullSimplify[\((\(-1\))\)\^n\  + \((1\/2 + \[ImaginaryI]\/2)\)\ \
\[ImaginaryI]\^n\  + \ \((1\/2 - \[ImaginaryI]\/2)\)\ \
\((\(-\[ImaginaryI]\))\)\^n, 
      n \[Element] Integers]\), "\[IndentingNewLine]", 
    \(FullSimplify[
      Cos[n\ \[Pi]] + Cos[\(n\ \[Pi]\)\/2] - Sin[\(n\ \[Pi]\)\/2], 
      n \[Element] Integers]\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.19.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve  ",
  Cell[BoxData[
      \(y[n + 2] - \@2\ y[n + 1] + y[n] = 0\)]],
  "   with  ",
  Cell[BoxData[
      \(y[0] = \(2\ \ and\ \ y[1] = \@2\)\)]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00MP3oool00`00
0000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000003oool0oooo0?l0
oooo6`3oool007H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00MP3o
ool00`000000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000003oool0
oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0J03oool30000
ojl0oooo001f0?ooo`030000003oool0oooo06L0oooo1@000?n^0?ooo`00
MP3oool00`000000oooo0?ooo`1W0?ooo`D0003o[P3oool007H0oooo00<0
00000?ooo`3oool0I`3oool50000ojh0oooo001f0?ooo`030000003oool0
oooo06P0oooo0`000?n_0?ooo`00MP3oool00`000000oooo0?ooo`3o0?oo
oa/0oooo001f0?ooo`030000003oool0oooo0?l0oooo6`3oool007H0oooo
00<000000?ooo`3oool0o`3ooolK0?ooo`00MP3oool00`000000oooo0?oo
o`3o0?oooa/0oooo001f0?ooo`030000003oool0oooo0?l0oooo6`3oool0
07H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00MP3oool00`000000
oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000003oool0oooo0?l0oooo
6`3oool007H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00MP3oool0
0`000000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000003oool0oooo
0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00
MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000003o
ool0oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0C@3oool3
0000oc<0oooo0`000?nD0?ooo`00MP3oool00`000000oooo0?ooo`1<0?oo
o`D0003o<@3oool50000oi<0oooo001f0?ooo`030000003oool0oooo04`0
oooo1@000?la0?ooo`D0003oT`3oool007H0oooo00<000000?ooo`3oool0
C03oool50000oc40oooo1@000?nC0?ooo`00MP3oool00`000000oooo0?oo
o`1=0?ooo`<0003o<`3oool30000oi@0oooo001f0?ooo`030000003oool0
oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0o`3ooolK0?oo
o`00MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000
003oool0oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0o`3o
oolK0?ooo`00MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo001f0?oo
o`030000003oool0oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3o
ool0o`3ooolK0?ooo`00MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo
001f0?ooo`030000003oool0oooo0?l0oooo6`3oool007H0oooo00<00000
0?ooo`3oool0o`3ooolK0?ooo`00MP3oool00`000000oooo0?ooo`3o0?oo
oa/0oooo001f0?ooo`030000003oool0oooo0?l0oooo6`3oool007H0oooo
00<000000?ooo`3oool0o`3ooolK0?ooo`00MP3oool00`000000oooo0?oo
o`3o0?oooa/0oooo001f0?ooo`030000003oool0oooo0?l0oooo6`3oool0
07H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00MP3oool00`000000
oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000003oool0oooo0?l0oooo
6`3oool007H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00MP3oool0
0`000000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000003oool0oooo
0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00
MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000003o
ool0oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0o`3ooolK
0?ooo`00MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`03
0000003oool0oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0
o`3ooolK0?ooo`00MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo001f
0?ooo`030000003oool0oooo01H0oooo1@00000F0?ooo`@00000603oool2
000001X0oooo0`00000G0?ooo`800000603oool3000001X0oooo00<00000
0?ooo`3oool05`3oool2000001P0oooo0`00000F0?ooo`D000000P3oool2
000000X0oooo001f0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo
000001X0oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`00
000G0?ooo`040000003oool0oooo000001T0oooo00<000000?ooo`3oool0
5P3oool010000000oooo0?ooo`00000I0?ooo`030000003oool0oooo01H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00L0oooo001f0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01H0
oooo1@00000I0?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3o
ool000006@3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo
000001P0oooo0`00000G0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`070?ooo`00MP3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0E0?ooo`040000003oool0oooo000001P0oooo0P00
000H0?ooo`<000006`3oool00`000000oooo0?ooo`0F0?ooo`800000603o
ool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`070?ooo`00MP3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool0
00005`3oool010000000oooo0?ooo`00000H0?ooo`030000003oool00000
01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0G0?oo
o`040000003oool0oooo000001L0oooo00@000000?ooo`3oool000005`3o
ool010000000oooo0?ooo`00000G0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`070?ooo`00MP3oool00`000000oooo
0?ooo`0G0?ooo`8000006@3oool2000001T0oooo0P00000J0?ooo`800000
603oool3000001P0oooo0`00000G0?ooo`@00000603oool2000001T0oooo
0`00000F0?ooo`800000103oool2000000X0oooo001f0?ooo`030000003o
ool0oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0o`3ooolK
0?ooo`00MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`03
0000003oool0oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0
<P3oool30000ofT0oooo0`000?mY0?ooo`<0003o3@3oool007H0oooo00<0
00000?ooo`3oool0<@3oool50000ofL0oooo1@000?mW0?ooo`D0003o303o
ool006`0oooo?P0000050000ofL000001@000?mW000000D0003o0`000009
0?ooo`00MP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
01H0oooo1@000?lH0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0F0?ooo`D0003o603oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool05P3oool50000o``0oooo001f0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool05`3oool30000oaT0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0
oooo0`000?lI0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0G0?ooo`<0003o3@3oool007H0oooo
00<000000?ooo`3oool0o`3ooolK0?ooo`00MP3oool00`000000oooo0?oo
o`3o0?oooa/0oooo001f0?ooo`030000003oool0oooo0?l0oooo6`3oool0
07H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00MP3oool00`000000
oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000003oool0oooo0?l0oooo
6`3oool007H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00MP3oool0
0`000000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000003oool0oooo
0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00
MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000003o
ool0oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0o`3ooolK
0?ooo`00MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`03
0000003oool0oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0
o`3ooolK0?ooo`00MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo001f
0?ooo`030000003oool0oooo0?l0oooo6`3oool007H0oooo00<000000?oo
o`3oool0o`3ooolK0?ooo`00MP3oool00`000000oooo0?ooo`3o0?oooa/0
oooo001f0?ooo`030000003oool0oooo0?l0oooo6`3oool007H0oooo00<0
00000?ooo`3oool0o`3ooolK0?ooo`00MP3oool00`000000oooo0?ooo`3o
0?oooa/0oooo001f0?ooo`030000003oool0oooo0?l0oooo6`3oool007H0
oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00MP3oool00`000000oooo
0?ooo`3o0?oooa/0oooo001f0?ooo`030000003oool0oooo0?l0oooo6`3o
ool007H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00MP3oool00`00
0000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000003oool0oooo0?l0
oooo6`3oool007H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00MP3o
ool00`000000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000003oool0
oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0o`3ooolK0?oo
o`00MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000
003oool0oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0o`3o
oolK0?ooo`00MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo001f0?oo
o`030000003oool0oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3o
ool0o`3ooolK0?ooo`00MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo
001f0?ooo`030000003oool0oooo01L0oooo0`000?nO0?ooo`<0003o<`3o
ool30000obP0oooo001f0?ooo`030000003oool0oooo01H0oooo1@000?nM
0?ooo`D0003o<@3oool50000obL0oooo001f0?ooo`030000003oool0oooo
01H0oooo1@000?nM0?ooo`D0003o<@3oool50000obL0oooo001f0?ooo`03
0000003oool0oooo01H0oooo1@000?nM0?ooo`D0003o<@3oool50000obL0
oooo001f0?ooo`030000003oool0oooo01L0oooo0`000?nO0?ooo`<0003o
<`3oool30000obP0oooo001f0?ooo`030000003oool0oooo0?l0oooo6`3o
ool007H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00MP3oool00`00
0000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000003oool0oooo0?l0
oooo6`3oool007H0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00MP3o
ool00`000000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000003oool0
oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0o`3ooolK0?oo
o`00MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo001f0?ooo`030000
003oool0oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3oool0o`3o
oolK0?ooo`00MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo001f0?oo
o`030000003oool0oooo0?l0oooo6`3oool007H0oooo00<000000?ooo`3o
ool0o`3ooolK0?ooo`00M@3oool30000omD0oooo0`000?m30?ooo`00M03o
ool50000om<0oooo1@000?m20?ooo`00M03oool50000om<0oooo1@000?m2
0?ooo`00M03oool50000om<0oooo1@000?m20?ooo`00M@3oool30000omD0
oooo0`000?m30?ooo`00MP3oool00`000000oooo0?ooo`3o0?oooa/0oooo
001f0?ooo`030000003oool0oooo0?l0oooo6`3oool007H0oooo00<00000
0?ooo`3oool0o`3ooolK0?ooo`00MP3oool00`000000oooo0?ooo`3o0?oo
oa/0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Take the z-transforms of each term and get\n\n",
  Cell[BoxData[
      \(\(\(\t\t\)\(z\^2\ \((Y \((z)\) - \ 
                2\  - \ \(\@2\) z\^\(-1\))\)\  - \(\@2\) 
            z\ \((Y \((z)\)\  - \ 2)\) + Y \((z)\)\  = \ 0\)\)\)]]
}], "Text"],

Cell[TextData[{
  "Solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  "  and get  ",
  Cell[BoxData[
      \(Y \((z)\)\  = \ \(\(2\ z\^2 - \@2\ z\)\/\(z\^2 - \@2\ z + 1\)\  = \ \
\(2\ z\^2 - \@2\ z\)\/\(\((z - \(1\  + \ \[ImaginaryI]\)\/\@2)\)\ \((z - \(1\ \
 - \ \[ImaginaryI]\)\/\@2)\)\)\)\)]],
  " "
}], "Text"],

Cell[TextData[{
  "Calculate the residues for  ",
  Cell[BoxData[
      \(f \((z)\) = Y \((z)\) z\^\(n - 1\)\)]],
  "  at the poles  ",
  Cell[BoxData[
      \(\(1\  + \ \[ImaginaryI]\)\/\@2\)]],
  "  and  ",
  Cell[BoxData[
      \(\(1\  - \[ImaginaryI]\)\/\@2\)]],
  "\n\n\t\t",
  Cell[BoxData[
      \(Res[
          f \((z)\), \(1\  + \ \[ImaginaryI]\)\/\@2]\  = \ \(lim\+\(z \[Rule] \
\(1\  + \ \[ImaginaryI]\)\/\@2\)\(\(2\ z\^2 - \@2\ z\)\/\(\(\ \)\((z - \(1\  \
- \ \[ImaginaryI]\)\/\@2)\)\)\) 
              z\^\(n - 1\) = \ \(\(\(1 + \[ImaginaryI]\)\/\@2\) \((\(1 + \
\[ImaginaryI]\)\/\@2)\)\^\(n - 1\)\  = \ \((\(1 + \
\[ImaginaryI]\)\/\@2)\)\^n\)\)\)]],
  " \n\nSimilarly,  ",
  Cell[BoxData[
      \(Res[
          f \((z)\), \(1\  - \[ImaginaryI]\)\/\@2]\  = \ \((\(1 - \
\[ImaginaryI]\)\/\@2)\)\^n\)]],
  ".  Therefore, the solution is \n\n\t\t",
  Cell[BoxData[
      \(y[
          n]\  = \((\(1 + \[ImaginaryI]\)\/\@2)\)\^n + \((\(1 - \[ImaginaryI]\
\)\/\@2)\)\^n\)]],
  ", \nwhich can be written as \n\n\t\t",
  Cell[BoxData[
      \(y[
          n] = \(\((\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\))\)\^n\  + \((\
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\))\)\^n\  = \ \
\(\[ExponentialE]\^\(\[ImaginaryI]\ n\ \[Pi]/4\)\  + \ \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ n\ \[Pi]/4\)\  = 2  cos \((\(\[Pi]\/4\) n)\)\)\)\)]],
  "  \n\n\t\t",
  Cell[BoxData[
      \(y[n] = 2  cos \((\(\[Pi]\/4\) n)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Remark.  The solution can also be obtained by applying the z-transform \
identity with ",
  Cell[BoxData[
      \(a = \[Pi]\/4\)]],
  "that was proven in example 5 of the first section of this chapter to get  \
\n\n\t\t",
  Cell[BoxData[
      \(\[GothicCapitalZ][
          cos \((\[Pi]\/4\ n)\)] = \ \(z\^2 - cos \((\[Pi]\/4)\) z\)\/\(z\^2 \
- 2  cos \((\[Pi]\/4)\)\ z\  + 1\)\)]],
  ",  \nthen we have\n\t\t",
  Cell[BoxData[
      \(y[
          n]\  = \ \(\(\[GothicCapitalZ]\^\(-1\)\)[\(2  z\^2 - \(\@2\) \
z\)\/\(z\^2 - \@2\ z\  + 1\)] = \(\(\[GothicCapitalZ]\^\(-1\)\)[\(2  z\^2 - 2 \
 cos \((\[Pi]\/4)\) z\)\/\(z\^2 - 2  cos \((\[Pi]\/4)\)\ z\  + 1\)] = 
            2  cos \((\[Pi]\/4\ n)\)\)\)\)]],
  ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "It is worthwhile to point out how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can do the important step using residues."
}], "Text"],

Cell[BoxData[{
    \(\(Y[
          z_]\  = \ \(\@2\ z - 2\ z\^2\)\/\(\(-1\) + \@2\ z - z\^2\);\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<              Y[z] = \>", 
        Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<            Y[z]z  = \>", Y[z], 
        z\^\(n - 1\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),\!\(\(1 - \
\[ImaginaryI]\)\/\@2\)] = \>\"", 
        Residue[Y[z] 
            z\^\(n - 1\), {z, \(1 - \[ImaginaryI]\)\/\@2}]\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Res[Y[z]\!\(z\^\(n - 1\)\),\!\(\(1 + \
\[ImaginaryI]\)\/\@2\)] = \>\"", 
        Residue[Y[z] 
            z\^\(n - 1\), {z, \(1 + \[ImaginaryI]\)\/\@2}]\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<              y[n] = Res[Y[z]\!\(z\^\(n - 1\)\),\!\(\(1 \
- \[ImaginaryI]\)\/\@2\)] + Res[Y[z]\!\(z\^\(n - 1\)\),\!\(\(1 + \
\[ImaginaryI]\)\/\@2\)}]\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<              y[n] = \>", 
        Residue[Y[z] z\^\(n - 1\), {z, \(1 - \[ImaginaryI]\)\/\@2}] + 
          Residue[Y[z] 
              z\^\(n - 1\), {z, \(1 + \[ImaginaryI]\)\/\@2}]\ ];\)\)}], \
"Input"],

Cell[TextData[{
  "\tTo solve  ",
  Cell[BoxData[
      \(y[n + 2] - \@2\ y[n + 1] + y[n]\  = \ \(x[n]\  = \ 0\)\)]],
  "   with  ",
  Cell[BoxData[
      \(y\_0 = \(y[0] = \(2\ \ and\ \ y\_1 = \(y[1] = \@2\)\)\)\)]],
  ",  we will use our ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine  ",
  Cell[BoxData[
      \(Zsolution\)]],
  "  for finding the solution to",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\  = \ \(x[n] = \ 0\)\)]],
  ".   It will take the z-transforms of each term;  solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  ";  and it's inverse ",
  Cell[BoxData[
      \(y[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[Y[z]]\)],
    InitializationCell->True],
  ".   The format of the subroutine call is   ",
  Cell[BoxData[
      \(Zsolution[a, b, x[n], y\_0, y\_1]\)]],
  "  with   ",
  Cell[BoxData[
      RowBox[{\(a = \@2\/2\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "b"}], "=", "1"}]}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(x[n_] = 0;\)\), "\[IndentingNewLine]", 
    \(\(Zsolution[\@2\/2, 1, x[n], 2, \@2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[
            y[n], {n, 0, 9}], "\<...\>"]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which agrees with\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(y2[n_] = 2  Cos[\(\[Pi]\/4\) n];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y2[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(y1[n_] = 
        2\^\(\(-n\)/2\)\ \((\((1 - \[ImaginaryI])\)\^n + \((1 + \
\[ImaginaryI])\)\^n)\);\)\), "\[IndentingNewLine]", 
    \(\(y2[n_] = 2\ Cos[\(n\ \[Pi]\)\/4];\)\), "\[IndentingNewLine]", 
    \(\(m0 = 10;\)\), "\n", 
    \(\(Y1\  = \ N[Table[y2[i], {i, 0, m0}]];\)\), "\n", 
    \(\(Y2\  = \ N[Table[y2[i], {i, 0, m0}]];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\n", 
    \(\(Y2pts = Transpose[{ticval, Y2}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(ListPlot[Y1pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Blue, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-2.2\), 2.2}}, 
        Ticks \[Rule] {Range[0, m0, 5], 
            Range[\(-4500\), 500, 500]}];\)\), "\n", 
    \(\(Print["\<y[n] = \>", y1[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[
            y1[n], {n, 0, 9}], "\<...\>"]\ ];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Y2pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Green, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-2.2\), 2.2}}, 
        Ticks \[Rule] {Range[0, m0, 5], 
            Range[\(-4500\), 500, 500]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y2[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y2[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"],

Cell[TextData[{
  "\tTo solve  ",
  Cell[BoxData[
      \(y[n + 2] - \@2\ y[n + 1] + y[n]\  = \ 0\)]],
  "   with  ",
  Cell[BoxData[
      \(y\_0 = \(y[0] = \(2\ \ and\ \ y\_1 = \(y[1] = \@2\)\)\)\)]],
  ",  we will use our ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine  ",
  Cell[BoxData[
      \(ResidueSolution\)]],
  "  for finding the solution to",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[n + 2]\  - \ 2  a\ y[n + 1]\  + \ b\ y[n]\  = \ 0\)]],
  ".   It will take the z-transforms of each term;  solve for  ",
  Cell[BoxData[
      \(Y \((z)\)\)]],
  ";  and it's inverse ",
  Cell[BoxData[
      \(y[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[Y[z]]\)],
    InitializationCell->True],
  ".   The format of the subroutine call is   ",
  Cell[BoxData[
      \(ResidueSolution[a, b, y\_0, y\_1]\)]],
  "  with   ",
  Cell[BoxData[
      RowBox[{\(a = \@2\/2\), ",", " ", 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "b"}], "=", "1"}]}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(ResidueSolution[\@2\/2, 1, 2, \@2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[
            s[n], {n, 0, 9}], "\<...\>"]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which agrees with\>"];\)\), "\[IndentingNewLine]", 
    \(\(y[n_] = 2  Cos[\(\[Pi]\/4\) n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Convolution for Solving a Non-homogeneous Equation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n",
  StyleBox["(i)",
    FontColor->RGBColor[0, 0, 1]],
  "\tSolve the homogeneous equation   ",
  Cell[BoxData[
      \(y\_h[n + 2]\  - \ 2  a\ y\_h[n + 1]\  + \ b\ y\_h[n]\ \  = \ \ 0\)]],
  "   and get  ",
  Cell[BoxData[
      \(y\_h[n]\)]],
  ".  \n\n",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  "\tUse the transfer function   ",
  Cell[BoxData[
      \(H \((z)\)\ \  = \ 
        1\/\(1\  - \ 2  a\ z\^\(-1\)\  + \ b\ z\^\(-2\)\)\)]],
  ".    \n\n",
  StyleBox["(iii)",
    FontColor->RGBColor[0, 0, 1]],
  "\tConstruct the particular solution using convolution  \n\n\t",
  Cell[BoxData[
      \(y\_p[n]\ \  = \ \ \ \(\[GothicCapitalZ]\^\(-1\)\)[
          H \((z)\) X \((z)\)]\)]],
  ",   or\n\n\t",
  Cell[BoxData[
      \(y\_p[n]\ \  = \ \ \ \[Sum]\+\(i = 0\)\%n\ h[i] x[n - i]\)]],
  ".  \n\n",
  StyleBox["(iv)",
    FontColor->RGBColor[0, 0, 1]],
  "\tThe total solution to the nonhomogeneous difference equation is  \n\n\t\t\
",
  Cell[BoxData[
      \(y[n]\ \  = \ \ y\_h[n]\ \  + \ \ y\_p[n]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 9.20 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the general solution to  ",
  Cell[BoxData[
      \(y[n + 2] - 2\/3\ \@2\ y[n + 1] + 4\/9\ y[n]\  = \ 0\)]],
  ". \n\n",
  StyleBox["9.20 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the general solution to  ",
  Cell[BoxData[
      \(y[n + 2] - 2\/3\ \@2\ y[n + 1] + 4\/9\ y[n]\  = \ 
        cos \((\(\[Pi]\/4\) n)\)\)]],
  ".   "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00M@3oool300000?l0oooo703oool007H0oooo00<0
00000?ooo`3oool0o`3ooolK0?ooo`00L`3oool5000000<0oooo0`00003o
0?oooaH0oooo001]0?ooo`@000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0?l0oooo5P3oool007@0oooo00<000000?oo
o`000000103oool00`000000oooo0?ooo`3o0?oooaH0oooo001e0?ooo`80
0000103oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000
003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?oo
o`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3o
ool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`0T0?ooo`<0o`00
kP3oool007/0oooo00<000000?ooo`3oool08`3oool50?l00>d0oooo001k
0?ooo`030000003oool0oooo02<0oooo1@3o003]0?ooo`00N`3oool00`00
0000oooo0?ooo`0S0?ooo`D0o`00k@3oool007/0oooo00<000000?ooo`3o
ool0903oool30?l00>h0oooo001k0?ooo`030000003oool0oooo0?l0oooo
5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool0
0`000000oooo0?ooo`3o0?oooaH0oooo001c0?ooo`@00000103oool00`00
0000oooo0?ooo`3o0?oooaH0oooo001c0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00M03oool00`000000oooo
0?ooo`040?ooo`<00000<@3oool30?l00>40oooo001]0?ooo`@00000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0300oooo1@3o
003P0?ooo`00L`3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0300oooo1@3o003P0?ooo`00M03oool2000000D0oooo00<00000
0?ooo`3oool0<03oool50?l00>00oooo001k0?ooo`030000003oool0oooo
0340oooo0`3o003Q0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0
oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<0
00000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`0n
0?ooo`800000?@3oool500000080oooo0P00000i0?ooo`D000000P3oool2
000003X0oooo100000030?ooo`8000002P3oool007/0oooo00<000000?oo
o`3oool0?@3oool010000000oooo0?ooo`00000n0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0h0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000002@3oool007/0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0l0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000T0oooo001k0?ooo`03
0000003oool0oooo03h0oooo0P00000o0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
0080oooo0P00000l0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`070?ooo`00N`3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo03h0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0i0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000002@3oool007/0oooo00<000000?ooo`3oool0?P3o
ool3000003d0oooo0P0000040?ooo`800000>P3oool2000000@0oooo0`00
000j0?ooo`800000103oool2000000X0oooo001k0?ooo`030000003oool0
oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool05P3oool30?l0
05X0oooo0`3o002O0?ooo`00N`3oool00`000000oooo0?ooo`0E0?ooo`D0
o`00F03oool50?l000X0oooo0`3o002A0?ooo`00N`3oool00`000000oooo
0?ooo`0E0?ooo`D0o`00C03oool30?l000T0oooo1@3o00090?ooo`D0o`00
?P3oool30?l004l0oooo001k0?ooo`030000003oool0oooo01D0oooo1@3o
001;0?ooo`D0o`00203oool50?l000T0oooo1@3o00090?ooo`<0o`002P3o
ool30?l000X0oooo0`3o000;0?ooo`<0o`002@3oool50?l000T0oooo0`3o
000:0?ooo`<0o`002`3oool30?l000X0oooo0`3o000:0?ooo`<0o`003@3o
ool007P0oooo700000030?l002D000000`3o000T000000D0o`002@000003
0?l000X000001@3o0008000000D0o`00200000050?l000P000001@3o0009
000000D0o`00200000050?l000P000001@3o0008000000D0o`002@000005
0?l000P000001@3o0008000000D0o`0000<000000?ooo`3oool02@3oool0
07/0oooo00<000000?ooo`3oool0?@3oool50?l002<0oooo1@3o000G0?oo
o`<0o`002@3oool50?l000P0oooo1@3o00080?ooo`D0o`002@3oool50?l0
00P0oooo1@3o00080?ooo`D0o`00203oool50?l000T0oooo1@3o00080?oo
o`D0o`00203oool50?l000`0oooo001k0?ooo`030000003oool0oooo03d0
oooo1@3o000T0?ooo`<0o`006@3oool00`000000oooo0?ooo`080?ooo`D0
o`00203oool50?l000P0oooo1@3o00090?ooo`D0o`002@3oool30?l000T0
oooo1@3o00080?ooo`D0o`002@3oool50?l000P0oooo1@3o00080?ooo`D0
o`00303oool007/0oooo00<000000?ooo`3oool0?@3oool50?l004`0oooo
0`3o000:0?ooo`<0o`002P3oool30?l000/0oooo0`3o000G0?ooo`<0o`00
2P3oool30?l000/0oooo0`3o000:0?ooo`<0o`002P3oool30?l000d0oooo
001k0?ooo`030000003oool0oooo03h0oooo0`3o000H0?ooo`<0o`00^@3o
ool007/0oooo00<000000?ooo`3oool0F03oool50?l00;P0oooo001k0?oo
o`030000003oool0oooo05P0oooo1@3o002h0?ooo`00N`3oool00`000000
oooo0?ooo`1;0?ooo`<0o`002P3oool50?l00;P0oooo001k0?ooo`030000
003oool0oooo04X0oooo1@3o000:0?ooo`<0o`00^@3oool007/0oooo00<0
00000?ooo`3oool0BP3oool50?l00<H0oooo001k0?ooo`030000003oool0
oooo04X0oooo1@3o00360?ooo`00N`3oool00`000000oooo0?ooo`1;0?oo
o`<0o`00a`3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00
N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003o
ool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF
0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001c0?ooo`@0
0000103oool00`000000oooo0?ooo`3o0?oooaH0oooo001c0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00M03o
ool00`000000oooo0?ooo`040?ooo`<00000o`3ooolF0?ooo`00M@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo5P3oool0
07<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o
0?oooaH0oooo001d0?ooo`8000001@3oool00`000000oooo0?ooo`3o0?oo
oaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo
00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?oo
o`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool0
07/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000
oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo
5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool0
0`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo
0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00
N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003o
ool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF
0?ooo`00M@3oool3000000<0oooo00<000000?ooo`3oool0o`3ooolF0?oo
o`00MP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0
oooo5P3oool007<0oooo1@0000030?ooo`<00000o`3ooolF0?ooo`00L`3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo
5P3oool007@0oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`3o0?oooaH0oooo001e0?ooo`800000103oool00`000000oooo0?ooo`3o
0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0
oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo
0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3o
ool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`00
0000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0
oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3o
ool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0
oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?oo
o`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000
003oool0oooo0?l0oooo5P3oool007<0oooo0`0000050?ooo`030000003o
ool0oooo0?l0oooo5P3oool007<0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`3o0?oooaH0oooo001c0?ooo`040000003oool0
oooo000000@0oooo0`0000090?ooo`<0o`00o`3oool:0?ooo`00L`3oool3
000000D0oooo00<000000?ooo`3oool0203oool50?l00?l0oooo2@3oool0
07@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?oo
o`D0o`00o`3oool90?ooo`00M03oool3000000@0oooo00<000000?ooo`3o
ool0203oool50?l00?l0oooo2@3oool007/0oooo00<000000?ooo`3oool0
2@3oool30?l00?l0oooo2P3oool007/0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?oo
o`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3o
ool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo
001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<00000
0?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oo
oaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo
00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?oo
o`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool0
07@0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo5P3oool007<0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?oo
oaH0oooo001c0?ooo`040000003oool0oooo000000@0oooo0`00003o0?oo
oaH0oooo001d0?ooo`8000001@3oool00`000000oooo0?ooo`3o0?oooaH0
oooo001c0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0o`3ooolF0?ooo`00M03oool2000000D0oooo00<000000?ooo`3oool0
o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k
0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?oo
o`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0
oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<0
00000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o
0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0
oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo
0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3o
ool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`00
0000oooo0?ooo`3o0?oooaH0oooo001]0?ooo`D000000P3oool2000000@0
oooo0`3o003o0?oooaL0oooo001_0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`050?l00?l0oooo5P3oool006l0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0
o`00o`3ooolF0?ooo`00K`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool01@3o003o0?oooaH0oooo001_0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool30?l0
0?l0oooo5`3oool006h0oooo0P0000040?ooo`800000o`3ooolN0?ooo`00
o`3ooonD0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\tFigure 9.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  A typical solution to  ",
  Cell[BoxData[
      \(y[n + 2] - 2\/3\ \@2\ y[n + 1] + 4\/9\ y[n]\  = \ 0\)]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000]b000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00M@3oool3
00000?l0oooo703oool007H0oooo00<000000?ooo`3oool0o`3ooolK0?oo
o`00L`3oool5000000<0oooo0`00003o0?oooaH0oooo001]0?ooo`@00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0
oooo5P3oool007@0oooo00<000000?ooo`000000103oool00`000000oooo
0?ooo`3o0?oooaH0oooo001e0?ooo`800000103oool00`000000oooo0?oo
o`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool0
07/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000
oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo
5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool0
0`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo
0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00
N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003o
ool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF
0?ooo`00N`3oool00`000000oooo0?ooo`1;0?ooo`<0003oa`3oool007/0
oooo00<000000?ooo`3oool0BP3oool50000og@0oooo0`000?m?0?ooo`00
N`3oool00`000000oooo0?ooo`1:0?ooo`D0003oL`3oool50000odh0oooo
001k0?ooo`030000003oool0oooo04X0oooo1@000?mc0?ooo`D0003oCP3o
ool007/0oooo00<000000?ooo`3oool0B`3oool30000o`/0oooo0`000?mV
0?ooo`D0003oCP3oool007/0oooo00<000000?ooo`3oool0F03oool50000
oeT0oooo0`000?l:0?ooo`<0003oC`3oool007<0oooo100000040?ooo`03
0000003oool0oooo05P0oooo1@000?mH0?ooo`D0003oF`3oool007<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1H0?ooo`D0003o
F03oool50000oe/0oooo001d0?ooo`030000003oool0oooo00@0oooo0`00
000n0?ooo`<0003o603oool30000oeT0oooo1@000?mK0?ooo`00K@3oool4
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0m
0?ooo`D0003oM03oool30000oe`0oooo001c0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0?@3oool50000om<0oooo001d0?oo
o`8000001@3oool00`000000oooo0?ooo`0m0?ooo`D0003od`3oool007/0
oooo00<000000?ooo`3oool0?P3oool30000om@0oooo001k0?ooo`030000
003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0d03o
ool30000od80oooo001k0?ooo`030000003oool0oooo0<l0oooo1@000?m1
0?ooo`00N`3oool00`000000oooo0?ooo`3?0?ooo`D0003o@@3oool007/0
oooo00<000000?ooo`3oool0c`3oool50000od40oooo001k0?ooo`030000
003oool0oooo06H0oooo0`000?mW0?ooo`<0003o@P3oool007/0oooo00<0
00000?ooo`3oool0I@3oool50000oj/0oooo001k0?ooo`030000003oool0
oooo03h0oooo0P00000U0?ooo`D0003o4`3oool500000080oooo0P00000i
0?ooo`D000000P3oool2000003X0oooo100000030?ooo`8000002P3oool0
07/0oooo00<000000?ooo`3oool0?@3oool010000000oooo0?ooo`00000T
0?ooo`D0003o5@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0>03oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000T0oooo001k0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool08`3oool30000oaH0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000002@3oool007/0oooo00<000000?ooo`3o
ool0<@3oool30000o`X0oooo0P00000o0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
0080oooo0P00000l0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`070?ooo`00N`3oool00`000000oooo0?ooo`0`0?oo
o`D0003o2@3oool00`000000oooo0?ooo`0n0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0O0?ooo`<0003o5P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`00N`3o
ool00`000000oooo0?ooo`0`0?ooo`D0003o2@3oool3000003d0oooo0P00
00040?ooo`8000008@3oool50000oa@0oooo0P0000040?ooo`<00000>P3o
ool2000000@0oooo0P00000:0?ooo`00N`3oool00`000000oooo0?ooo`0`
0?ooo`D0003oLP3oool50000ofT0oooo001k0?ooo`030000003oool0oooo
0340oooo0`000?mc0?ooo`D0003oJ@3oool007/0oooo00<000000?ooo`3o
ool0Z03oool30000ofX0oooo001k0?ooo`030000003oool0oooo0?l0oooo
5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool0
0`000000oooo0?ooo`3o0?oooaH0oooo001h0?ooool000004@00000;0?oo
o`00N`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00/0oooo001k0?ooo`030000003oool0oooo0?l0oooo
5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool0
0`000000oooo0?ooo`3M0?ooo`<0003o=@3oool007/0oooo00<000000?oo
o`3oool0g03oool50000oc@0oooo001k0?ooo`030000003oool0oooo0=`0
oooo1@000?ld0?ooo`00N`3oool00`000000oooo0?ooo`1c0?ooo`<0003o
IP3oool50000oc@0oooo001k0?ooo`030000003oool0oooo0780oooo1@00
0?mV0?ooo`<0003o=@3oool007/0oooo00<000000?ooo`3oool0LP3oool5
0000oih0oooo001k0?ooo`030000003oool0oooo0780oooo1@000?nN0?oo
o`00N`3oool00`000000oooo0?ooo`1c0?ooo`<0003oW`3oool007/0oooo
00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?oo
o`2K0?ooo`<0003oM`3oool007/0oooo00<000000?ooo`3oool0903oool3
0000og<0oooo1@000?mV0?ooo`<0003o3@3oool007/0oooo00<000000?oo
o`3oool08`3oool50000og80oooo1@000?mU0?ooo`D0003o303oool007/0
oooo00<000000?ooo`3oool08`3oool50000og80oooo1@000?mU0?ooo`D0
003o303oool007/0oooo00<000000?ooo`3oool08`3oool50000og<0oooo
0`000?mV0?ooo`D0003o303oool007/0oooo00<000000?ooo`3oool0903o
ool30000omh0oooo0`000?l=0?ooo`00N`3oool00`000000oooo0?ooo`3o
0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007<0
oooo100000040?ooo`030000003oool0oooo0?l0oooo5P3oool007<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3[0?ooo`<0003o
9`3oool007@0oooo00<000000?ooo`3oool0103oool300000840oooo0`00
0?mV0?ooo`D0003o9P3oool007D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`200?ooo`D0003oI@3oool50000obH0oooo001c0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0P03oool5
0000ofD0oooo1@000?lV0?ooo`00M03oool2000000D0oooo00<000000?oo
o`3oool0P03oool50000o`T0oooo0`000?mJ0?ooo`<0003o9`3oool007/0
oooo00<000000?ooo`3oool0P@3oool30000o`T0oooo1@000?mV0?ooo`<0
003o6P3oool007/0oooo00<000000?ooo`3oool0S@3oool50000ofD0oooo
1@000?lI0?ooo`00N`3oool00`000000oooo0?ooo`2=0?ooo`D0003oI@3o
ool50000oaT0oooo001k0?ooo`030000003oool0oooo08h0oooo0`000?mV
0?ooo`D0003o6@3oool007/0oooo00<000000?ooo`3oool0n03oool30000
oaX0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo
00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?oo
o`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool0
07/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000
oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo
5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool0
0`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo
0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00
N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003o
ool0oooo0?l0oooo5P3oool007D0oooo0`0000030?ooo`030000003oool0
oooo0?l0oooo5P3oool007H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`3o0?oooaH0oooo001c0?ooo`D000000`3oool300000?l0
oooo5P3oool007<0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`0F0?ooo`<0003oo03oool007@0oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`0E0?ooo`D0003on`3oool007D0oooo0P00
00040?ooo`030000003oool0oooo01D0oooo1@000?ok0?ooo`00N`3oool0
0`000000oooo0?ooo`0E0?ooo`D0003on`3oool007/0oooo00<000000?oo
o`3oool05P3oool30000oo`0oooo001k0?ooo`030000003oool0oooo0?l0
oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3o
ool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0
oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?oo
o`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000
003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?oo
o`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3o
ool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo
001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<00000
0?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oo
oaH0oooo001c0?ooo`<000001@3oool00`000000oooo0?ooo`3o0?oooaH0
oooo001c0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0o`3ooolF0?ooo`00L`3oool010000000oooo0?ooo`0000040?ooo`<0
0000o`3ooolF0?ooo`00L`3oool3000000D0oooo00<000000?ooo`3oool0
o`3ooolF0?ooo`00M03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0?l0oooo5P3oool007@0oooo0`0000040?ooo`030000003oool0
oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?oo
o`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000
003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?oo
o`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3o
ool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo
001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo00<00000
0?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?ooo`3o0?oo
oaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3oool007/0oooo
00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`000000oooo0?oo
o`090?ooo`<0003oo`3oool:0?ooo`00N`3oool00`000000oooo0?ooo`08
0?ooo`D0003oo`3oool90?ooo`00N`3oool00`000000oooo0?ooo`080?oo
o`D0003oo`3oool90?ooo`00N`3oool00`000000oooo0?ooo`080?ooo`D0
003oo`3oool90?ooo`00N`3oool00`000000oooo0?ooo`090?ooo`<0003o
o`3oool:0?ooo`00M03oool2000000D0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`00L`3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0?l0oooo5P3oool007<0oooo00@000000?ooo`3oool00000103o
ool300000?l0oooo5P3oool007@0oooo0P0000050?ooo`030000003oool0
oooo0?l0oooo5P3oool007<0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`3o0?oooaH0oooo001d0?ooo`8000001@3oool00`00
0000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0
oooo5P3oool007X0oooo0`000?oo0?oooaL0oooo001i0?ooo`D0003oo`3o
oolF0?ooo`00N@3oool50000ool0oooo5P3oool007T0oooo1@000?oo0?oo
oaH0oooo001j0?ooo`<0003oo`3ooolG0?ooo`00N`3oool00`000000oooo
0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0oooo5P3o
ool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3oool00`00
0000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0oooo0?l0
oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`00N`3o
ool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000003oool0
oooo0?l0oooo5P3oool007/0oooo00<000000?ooo`3oool0o`3ooolF0?oo
o`00N`3oool00`000000oooo0?ooo`3o0?oooaH0oooo001k0?ooo`030000
003oool0oooo0?l0oooo5P3oool006d0oooo1@0000020?ooo`8000001@3o
ool00`000000oooo0?ooo`3o0?oooaH0oooo001_0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0?l0oooo5P3oool006l0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo0`00003o0?oooaH0oooo001_
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0?l0oooo5P3oool006l0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3ooolF0?ooo`00KP3oool2000000@0oooo0P000005
0?ooo`030000003oool0oooo0?l0oooo5P3oool00?l0ooooU03oool00?l0
ooooU03oool00?l0ooooU03oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 183},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\tFigure 9.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  A typical solution to  ",
  Cell[BoxData[
      \(y[n + 2] - 2\/3\ \@2\ y[n + 1] + 4\/9\ y[n]\  = \ 
        cos \((\(\[Pi]\/4\) n)\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.20 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tThe homogeneous difference equation has the form  ",
  StyleBox["(9-8)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" with ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(a = \(\@2\/3\ \ and\ \ b = 4\/9\)\)]],
  " and  ",
  Cell[BoxData[
      \(b > a\^2\)]],
  " so that the solution are complex and have the form  \n\n\t\t",
  Cell[BoxData[
      \(y\_h[
          n]\  = \ \(c\_1\) \(r\^n\) 
            cos \((\[Phi]\ n\ )\)\  + \ \(c\_2\) \(r\^n\) 
            sin \((\[Phi]\ n)\)\)]],
  ",  \n\nwhere  ",
  Cell[BoxData[
      \(r = \(\@b = \(\@\(4\/9\) = 2\/3\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Phi] = \(arctan \((\@\(b - a\^2\)\/a)\) = \(arctan \((\@\((4\/9 - \
\((\@2\/3)\)\^2)\)/\((\@2\/3)\))\)\  = \(arctan \((1)\) = \[Pi]\/4\)\)\)\)]],
  ".  Hence, the general homogeneous solution is  \n\n\t\t",
  Cell[BoxData[
      \(y\_h[
          n]\  = \ \(c\_1\) \(\((2\/3)\)\^n\) 
            Cos \((\[Pi]\/4\ n\ )\)\  + \ \(c\_2\) \(\((2\/3)\)\^n\) 
            sin \((\[Pi]\/4\ n)\)\)]],
  ". \n\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The homogeneous solution is transient and and will decay to ",
  Cell[BoxData[
      \(0\)]],
  " as ",
  Cell[BoxData[
      \(n \[Rule] \[Infinity]\)]],
  ", i.e.  ",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ y\_h[n] = 0\)]],
  ".  An illustration using ",
  Cell[BoxData[
      RowBox[{\(c\_1\), "=", 
        RowBox[{
          RowBox[{"10", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(c\_2\)}], "=", "5"}]}]]],
  " is shown in figure 2 below. \n\n",
  StyleBox["Typo.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Please note that there is a typo in the book which mistakenly stated \
that the homogeneous solution involves ",
  Cell[BoxData[
      \(\[Pi]\/3\ n\)]],
  ".  We apologize for this inconvenience. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.20 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tThe transfer function is seen to be  ",
  Cell[BoxData[
      \(H \((z)\)\  = \ \(1\/\(z\^2 - \(2\/3\) \(\@2\) z + 4\/9\)\  = \ 
          1/\((\((z - \(2\/3\) \(1\  + \ \[ImaginaryI]\)\/\@2)\)\ \((z - \
\(2\/3\) \(1\  - \ \[ImaginaryI]\)\/\@2)\))\)\)\)]],
  " .  Using the z-transform ",
  Cell[BoxData[
      \(\[GothicCapitalZ][
          cos \((\[Pi]\/4\ n)\)] = \ \(\(z\^2 - cos \((\[Pi]\/4)\) \
z\)\/\(z\^2 - 2  cos \((\[Pi]\/4)\)\ z\  + 1\)\  = \ \(\(z\^2 - \
z/\@2\)\/\(z\^2 - \@2\ z + 1\) = \((z\^2 - \(1\/\@2\) 
                    z)\)/\((\((z - \(1\  + \ \[ImaginaryI]\)\/\@2)\)\ \((z - \
\(1\  - \ \[ImaginaryI]\)\/\@2)\))\)\)\)\)]],
  " in example 8 and the fact that  ",
  Cell[BoxData[
      \(H \((z)\) = \(Y \((z)\)\)\/\(X \((z)\)\)\)]],
  " we can write the z-transform ",
  Cell[BoxData[
      \(Y[z]\)]],
  "using convolution   \n\n\t\t",
  Cell[BoxData[
      \(Y \((z)\)\  = \ \(H \((z)\) 
            X \((z)\)\  = \ \(z\^2 - z/\@2\)\/\(\((z - \(2\/3\) \(1\  + \ \
\[ImaginaryI]\)\/\@2)\)\ \((z - \(2\/3\) \(1\  - \ \[ImaginaryI]\)\/\@2)\) \
\((z - \(1\  + \ \[ImaginaryI]\)\/\@2)\)\ \((z - \(1\  - \ \
\[ImaginaryI]\)\/\@2)\)\)\)\)]],
  "  "
}], "Text"],

Cell[TextData[{
  "Residue calculus can again be used to find the solution, but the details \
are tedious.  Let us announce that the following computations hold true  \n\n\
\t",
  Cell[BoxData[
      \(Residue[f \((z)\), \(2\/3\) \(1\  + \ \[ImaginaryI]\)\/\@2] + 
          Residue[f \((z)\), \(2\/3\) \(1\  - \ \[ImaginaryI]\)\/\@2]\  = \ 
        18\/13\ \((2\/3)\)\^n\ cos \((\(\(\(\ \)\(\[Pi]\)\)\/4\) 
                n)\)\  - \ \(63\/26\) \((2\/3)\)\^n\ sin \((\(\(\(\ \)\(\[Pi]\
\)\)\/4\) n)\)\)]],
  " \n\nwhich is part of the homogeneous solution.  And the steady state or \
particular part of the solution is  \n\n\t",
  Cell[BoxData[
      \(y\_p[
          n]\  = \ \(Residue[f \((z)\), \(1\  + \ \[ImaginaryI]\)\/\@2] + 
            Residue[f \((z)\), \(1\  - \ \[ImaginaryI]\)\/\@2]\  = \ \
\(-\(18\/13\)\)\ cos \((\(\[Pi]\/4\) n)\)\  + \ 
            27\/13\ sin \((\(\[Pi]\/4\) n)\)\)\)]],
  " \n\nTherefore, the general solution to part (b) is \n\n\t\t",
  Cell[BoxData[
      \(y[
          n]\  = \ \(y\_h[n] + 
            y\_p[n]\  = \ \(c\_1\) \(\((2\/3)\)\^n\) 
              cos \((\[Pi]\/4\ n\ )\) + \(c\_2\) \(\((2\/3)\)\^n\) 
              sin \((\[Pi]\/4\ n)\)\  - \ 18\/13\ cos \((\(\[Pi]\/4\) n)\) + 
            27\/13\ sin \((\(\[Pi]\/4\) n)\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tFor applications, it is useful to determine the limiting amplitude of  \
",
  Cell[BoxData[
      \(y[n]\)]],
  ".  We need to simplify ",
  Cell[BoxData[
      \(y\_p[n]\)]],
  " in a form that displays it's amplitude and to do this we apply to the \
trigonometric identity (also known as the ",
  ButtonBox["harmonic addition theorem",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/HarmonicAdditionTheorem.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  ")  \n\n\t\t",
  Cell[BoxData[
      \(a\ \ cos \((\[Theta])\)\  + \ 
          b\ sin \((\[Theta])\)\  = \ \(\@\(a\^2 + b\^2\)\) 
          cos \((\[Theta] + arctan \((\(-b\)\/a)\))\)\)]],
  ".  \n\nTherefore, the steady state solution is \n\n\t\t",
  Cell[BoxData[
      \(y\_p[
          n]\  = \(\(\@\(\((\(-\ \(18\/13\)\))\)\^2 + \((27\/13)\)\^2\)\) 
            Cos \((\[Pi]\/4 + 
                arctan \((\(-\(27\/13\)\)\/\(-\ \(18\/13\)\))\))\)\ \  = \ \ \
\(\(9\)\(\ \)\)\/\@13\ cos \((\(\[Pi]\/4\) n + arctan \((3\/2)\))\)\)\)]],
  "\n\t\t\nand the output signal ",
  Cell[BoxData[
      \(y[n]\)]],
  " tends to this limit as ",
  Cell[BoxData[
      \(n \[Rule] \[Infinity]\)]],
  ",  i.e.  ",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ y[n] = y\_h[n]\)]],
  ".  Loosely speaking, for large values of  ",
  Cell[BoxData[
      \(n\)]],
  "  the values of the input signal  ",
  Cell[BoxData[
      \(x[n] = cos \((\(\(\(\ \)\(\[Pi]\)\)\/4\) n)\)\)]],
  "  are amplified by the factor  ",
  Cell[BoxData[
      \(\(\(9\)\(\ \)\)\/\@13\  = \ 2.49615\)]],
  " to produce the values of the output signal  ",
  Cell[BoxData[
      \(y[n]\)]],
  ".    An illustration using ",
  Cell[BoxData[
      RowBox[{\(c\_1\), "=", 
        RowBox[{
          RowBox[{"10", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(c\_2\)}], "=", "5"}]}]]],
  " is shown in figure 3 below. "
}], "Text"],

Cell[TextData[{
  StyleBox["Typo.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Please note that there is a typo in the book which mistakenly stated \
that the homogeneous solution involves ",
  Cell[BoxData[
      \(\[Pi]\/3\ n\)]],
  ".  We apologize for this inconvenience. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.20 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Use the initial conditions  ",
  Cell[BoxData[
      \(y[0] = \(1\ \ and\ \ y[1] = \@2\/3\)\)]],
  "  and get the solution  ",
  Cell[BoxData[
      \(y[n]\  = \ \(\((2\/3)\)\^n\) Cos \((\[Pi]\/4\ n\ )\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(x[n_] = 0;\)\), "\[IndentingNewLine]", 
    \(\(SolveDE[\@2\/3, 4\/9, x[n], 1, \@2\/3];\)\)}], "Input"],

Cell[TextData[{
  "Use the initial conditions  ",
  Cell[BoxData[
      \(y[0] = \(0\ \ and\ \ y[1] = \@2\/3\)\)]],
  "  and get the solution  ",
  Cell[BoxData[
      \(y[n]\  = \ \(\((2\/3)\)\^n\) Sin \((\[Pi]\/4\ n\ )\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(x[n_] = 0;\)\), "\[IndentingNewLine]", 
    \(\(SolveDE[\@2\/3, 4\/9, x[n], 0, \@2\/3];\)\)}], "Input"],

Cell["\<\
The above derivation can also be accomplished using z-transforms.\
\>", "Text"],

Cell[BoxData[{
    \(\(x[n_] = 0;\)\), "\[IndentingNewLine]", 
    \(\(Zsolution[\@2\/3, 4\/9, x[n], 
        1, \@2\/3];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[
            y[n], {n, 0, 9}], "\<...\>"]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which agrees with\>"];\)\), "\[IndentingNewLine]", 
    \(\(y[n_] = \(\((2\/3)\)\^n\) 
          Cos[\(\[Pi]\/4\) n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(x[n_] = 0;\)\), "\[IndentingNewLine]", 
    \(\(Zsolution[\@2\/3, 4\/9, x[n], 
        0, \@2\/3];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[
            y[n], {n, 0, 9}], "\<...\>"]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Which agrees with\>"];\)\), "\[IndentingNewLine]", 
    \(\(y[n_] = \(\((2\/3)\)\^n\) 
          Sin[\(\[Pi]\/4\) n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(y\_n\)\!\(\(}\_\(n = 0\)\%\[Infinity]\)\)  = \>\"", 
        Append[Table[y[n], {n, 0, 9}], "\<...\>"]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Form the linear combination  ",
  Cell[BoxData[
      \(y\_h[
          n]\  = \ \(c\_1\) \(\((2\/3)\)\^n\) 
            Cos \((\[Pi]\/4\ n\ )\)\  + \ \(c\_2\) \(\((2\/3)\)\^n\) 
            sin \((\[Pi]\/4\ n)\)\)]],
  "  and substitute it into the difference equation\n\n\t\t",
  Cell[BoxData[
      \(y\_h[n + 2] - 2\/3\ \@2\ y\_h[n + 1] + 4\/9\ y\_h[n]\ \  = \ \ 0\)]]
}], "Text"],

Cell[BoxData[{
    \(\(y\_h[n_] = \(c\_1\) \(\((2\/3)\)\^n\) Cos[\[Pi]\/4\ n\ ]\  + 
          c\_2\ \(\((2\/3)\)\^n\) 
            Sin[\[Pi]\/4\ n];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(y\_h\)[n] = \>\"", 
        y\_h[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_h\)[n+1] = \>\"", 
        y\_h[n + 1]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_h\)[n+1] = \>\"", 
        TrigExpand[y\_h[n + 1]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_h\)[n+2] = \>\"", 
        y\_h[n + 2]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_h\)[n+2] = \>\"", 
        TrigExpand[y\_h[n + 2]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<         \!\(y\_h\)[n] = \>\"", 
        y\_h[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<-\!\(2\/3\)\!\(\@2\)\!\(y\_h\)[n+1] = \>\"", \(-\(2\/3\)\
\) \(\@2\) TrigExpand[y\_h[n + 1]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(4\/9\)\!\(y\_h\)[n+2] = \>\"", \(4\/9\) 
          TrigExpand[y\_h[n + 2]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Now add up the three terms\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_h\)[n+2]-\!\(2\/3\) \!\(\@2\) \
\!\(y\_h\)[n+1]+\!\(4\/9\) \!\(y\_h\)[n]\>\""\ ];\)\), "\[IndentingNewLine]", \

    \(\(Print["\<    =    \>", 
        y\_h[n + 2] - 2\/3\ \@2\ y\_h[n + 1] + 
          4\/9\ y\_h[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_h\)[n+2]-\!\(2\/3\) \!\(\@2\) \
\!\(y\_h\)[n+1]+\!\(4\/9\) \!\(y\_h\)[n] = \>\"", 
        Expand[y\_h[n + 2] - 2\/3\ \@2\ y\_h[n + 1] + 
            4\/9\ y\_h[n]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(y\_h\)[n+2]-\!\(2\/3\) \!\(\@2\) \
\!\(y\_h\)[n+1]+\!\(4\/9\) \!\(y\_h\)[n] = \>\"", 
        TrigExpand[
          y\_h[n + 2] - 2\/3\ \@2\ y\_h[n + 1] + 
            4\/9\ y\_h[n]]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The following graph is shows the solution for the choice of constants ",
  Cell[BoxData[
      RowBox[{\(c\_1\), "=", 
        RowBox[{
          RowBox[{"10", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(c\_2\)}], "=", "5"}]}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(y[n_] = 
        10 \(\((2\/3)\)\^n\) Cos[\[Pi]\/3\ n\ ]\  + 
          5\ \(\((2\/3)\)\^n\) 
            Sin[\[Pi]\/3\ n];\)\ \), "\[IndentingNewLine]", 
    \(\(m0 = 20;\)\), "\[IndentingNewLine]", 
    \(\(Y1\  = \ N[Table[y[i], {i, 0, m0}]];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ListPlot[Y1pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Red, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.2\), m0 + 0.2}, {\(-4\), 10.25}}, 
        Ticks \[Rule] {Range[0, m0, 5], 
            Range[\(-4\), 10, 2]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[0] = \>", y[0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[1] = \>", y[1]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Figure 9.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  A typical solution to  ",
  Cell[BoxData[
      \(y[n + 2] - 2\/3\ \@2\ y[n + 1] + 4\/9\ y[n]\  = \ 0\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.20 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
The important step in the solution is the computation of a particular \
solution residues. \
\>", "Text"],

Cell[BoxData[{
    \(\(Y[
          z_]\  = \ \(z\^2 - z/\@2\)\/\(\((z - \(2\/3\) \(1\  + \ \
\[ImaginaryI]\)\/\@2)\)\ \((z - \(2\/3\) \(1\  - \ \[ImaginaryI]\)\/\@2)\) \
\((z - \(1\  + \ \[ImaginaryI]\)\/\@2)\)\ \((z - \(1\  - \ \
\[ImaginaryI]\)\/\@2)\)\);\)\), "\[IndentingNewLine]", 
    \(\(y1[n_] = 
        Residue[Y[z] 
              z\^\(n - 1\), {z, \(2\/3\) \(1\  + \ \[ImaginaryI]\)\/\@2}] + 
          Residue[Y[z] 
              z\^\(n - 1\), {z, \(2\/3\) \(1\  - \ \
\[ImaginaryI]\)\/\@2}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y[z] = \>", Y[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y1[n]\ ];\)\)}], "Input"],

Cell[TextData[{
  "To show that this is equivalent to  ",
  Cell[BoxData[
      \(y[n] = 
        18\/13\ \((2\/3)\)\^n\ Cos[\(\(\(\ \)\(\[Pi]\)\)\/4\) 
                n]\  - \ \(63\/26\) \((2\/3)\)\^n\ Sin[\(\(\(\ \
\)\(\[Pi]\)\)\/4\) n]\)]],
  ",  we shall resort to comparing their graphs.  Also note that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will expand the fractions in the printout, i.e.  ",
  Cell[BoxData[
      \(18\/13\ \((2\/3)\)\^n\ \  = \ 1\/13\ 2\^\(1 + n\)\ 3\^\(2 - n\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\(-\ \(63\/26\)\) \((2\/3)\)\^n\ \  = \ \ \(-\(7\/13\)\)\ 2\^\(\(-1\) \
+ n\)\ 3\^\(2 - n\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Y[
          z_]\  = \ \(z\^2 - z/\@2\)\/\(\((z - \(2\/3\) \(1\  + \ \
\[ImaginaryI]\)\/\@2)\)\ \((z - \(2\/3\) \(1\  - \ \[ImaginaryI]\)\/\@2)\) \
\((z - \(1\  + \ \[ImaginaryI]\)\/\@2)\)\ \((z - \(1\  - \ \
\[ImaginaryI]\)\/\@2)\)\);\)\), "\[IndentingNewLine]", 
    \(\(y1[n_] = 
        Residue[Y[
                z] \(\(z\)\(\ \)\)\^\(n - 1\), {z, \(2\/3\) \(1\  + \ \
\[ImaginaryI]\)\/\@2}] + 
          Residue[Y[
                z] \(\(z\)\(\ \)\)\^\(n - 1\), {z, \(2\/3\) \(1\  - \ \
\[ImaginaryI]\)\/\@2}];\)\), "\[IndentingNewLine]", 
    \(\(y2[n_] = 
        18\/13\ \((2\/3)\)\^n\ Cos[\(\(\(\ \)\(\[Pi]\)\)\/4\) 
                n]\  - \ \(63\/26\) \((2\/3)\)\^n\ Sin[\(\(\(\ \
\)\(\[Pi]\)\)\/4\) n];\)\), "\[IndentingNewLine]", 
    \(\(m0 = 21;\)\), "\n", 
    \(\(Y1\  = \ N[Table[y2[i], {i, 0, m0}]];\)\), "\n", 
    \(\(Y2\  = \ N[Table[y2[i], {i, 0, m0}]];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\n", 
    \(\(Y2pts = Transpose[{ticval, Y2}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(ListPlot[Y1pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Red, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-1.13\), 1.45}}, 
        Ticks \[Rule] {Range[0, m0, 5], Range[\(-2\), 10, 2]}];\)\), "\n", 
    \(\(Print["\<y[n] = \>", y1[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Y2pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Green, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.4\), m0 + 0.15}, {\(-1.13\), 1.45}}, 
        Ticks \[Rule] {Range[0, m0, 5], 
            Range[\(-2\), 10, 2]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y2[n]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The following graph is shows the solution to  ",
  Cell[BoxData[
      \(y[n + 2] - 2\/3\ \@2\ y[n + 1] + 4\/9\ y[n]\  = \ 
        cos \((\(\[Pi]\/4\) n)\)\)]],
  "  for the choice of constants ",
  Cell[BoxData[
      RowBox[{\(c\_1\), "=", 
        RowBox[{
          RowBox[{"10", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(c\_2\)}], "=", "5"}]}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(y[n_] = 
        10 \(\((2\/3)\)\^n\) Cos[\[Pi]\/4\ n\ ]\  + 
          5\ \(\((2\/3)\)\^n\) 
            Sin[\[Pi]\/4\ n] + \(\(9\)\(\ \)\)\/\@13\ Cos[\(\[Pi]\/4\) n + 
                ArcTan[\(-2\), \(-3\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(m0 = 20;\)\), "\[IndentingNewLine]", 
    \(\(Y1\  = \ N[Table[y[i], {i, 0, m0}]];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(Y1pts = Transpose[{ticval, Y1}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ListPlot[Y1pts, PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {Blue, PointSize[0.02]}, 
        PlotRange \[Rule] {{\(-0.2\), m0 + 0.2}, {\(-4\), 10.25}}, 
        Ticks \[Rule] {Range[0, m0, 5], 
            Range[\(-4\), 10, 2]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[n] = \>", y[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[0] = \>", y[0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[1] = \>", y[1]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Figure 9.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  A typical solution to ",
  Cell[BoxData[
      \(y[n + 2] - 2\/3\ \@2\ y[n + 1] + 4\/9\ y[n]\  = \ 
        cos \((\(\[Pi]\/4\) n)\)\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["The z-Transform",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ZTransformBib.html"], None},
  
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1017, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageHeaderLines->{Inherited, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {36, 54}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 290582, 6727}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 2126, 63, 261, "Text"],
Cell[4231, 127, 492, 20, 71, "Text"],
Cell[4726, 149, 424, 17, 71, "Text"],
Cell[5153, 168, 1306, 45, 232, "Text"],
Cell[6462, 215, 1060, 29, 109, "Text"],
Cell[7525, 246, 159, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[7709, 253, 384, 11, 33, "Text"],
Cell[8096, 266, 6392, 107, 1416, "Input",
  InitializationCell->True]
}, Closed]],
Cell[14503, 376, 727, 23, 30, "Text"],
Cell[15233, 401, 9185, 153, 163, 9071, 149, "GraphicsData", "Bitmap", "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[24443, 558, 104, 2, 33, "Text"],
Cell[24550, 562, 815, 23, 202, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[25402, 590, 112, 2, 30, "Text"],
Cell[25517, 594, 1553, 48, 71, "Text"],
Cell[27073, 644, 108, 2, 50, "Input"],
Cell[27184, 648, 838, 14, 230, "Input"]
}, Closed]],
Cell[28037, 665, 727, 23, 30, "Text"],
Cell[28767, 690, 9885, 165, 163, 9771, 161, "GraphicsData", "Bitmap", "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[38677, 859, 104, 2, 33, "Text"],
Cell[38784, 863, 880, 24, 208, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[39701, 892, 112, 2, 30, "Text"],
Cell[39816, 896, 1554, 48, 71, "Text"],
Cell[41373, 946, 108, 2, 50, "Input"],
Cell[41484, 950, 852, 14, 230, "Input"]
}, Closed]],
Cell[42351, 967, 727, 23, 30, "Text"],
Cell[43081, 992, 10641, 177, 163, 10527, 173, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[53747, 1173, 104, 2, 33, "Text"],
Cell[53854, 1177, 1478, 43, 289, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[55369, 1225, 112, 2, 30, "Text"],
Cell[55484, 1229, 1554, 48, 71, "Text"],
Cell[57041, 1279, 108, 2, 50, "Input"],
Cell[57152, 1283, 437, 16, 36, "Text"],
Cell[57592, 1301, 2061, 37, 438, "Input"]
}, Closed]],
Cell[59668, 1341, 1904, 58, 239, "Text"],
Cell[61575, 1401, 2412, 77, 128, "Text"],
Cell[63990, 1480, 1791, 53, 190, "Text"],
Cell[65784, 1535, 364, 12, 33, "Text"],
Cell[66151, 1549, 849, 22, 185, "Text"],
Cell[67003, 1573, 1335, 40, 109, "Text"],
Cell[68341, 1615, 1808, 58, 261, "Text"],
Cell[70152, 1675, 2008, 60, 111, "Text"],
Cell[72163, 1737, 1323, 41, 71, "Text"],
Cell[73489, 1780, 272, 9, 33, "Text"],
Cell[73764, 1791, 307, 10, 33, "Text"],

Cell[CellGroupData[{
Cell[74096, 1805, 385, 11, 33, "Text"],
Cell[74484, 1818, 2702, 46, 654, "Input",
  InitializationCell->True],
Cell[77189, 1866, 4624, 78, 940, "Input",
  InitializationCell->True]
}, Closed]],
Cell[81828, 1947, 1807, 59, 68, "Text"],
Cell[83638, 2008, 17233, 285, 163, 17119, 281, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[100896, 2297, 108, 2, 33, "Text"],
Cell[101007, 2301, 222, 5, 71, "Text"],
Cell[101232, 2308, 193, 8, 39, "Text"],
Cell[101428, 2318, 1388, 37, 123, "Text"],
Cell[102819, 2357, 1384, 37, 147, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[104240, 2399, 108, 2, 30, "Text"],
Cell[104351, 2403, 251, 6, 74, "Text"],
Cell[104605, 2411, 220, 9, 39, "Text"],
Cell[104828, 2422, 2146, 56, 171, "Text"],
Cell[106977, 2480, 2061, 55, 109, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[109075, 2540, 116, 2, 30, "Text"],
Cell[109194, 2544, 166, 5, 33, "Text"],
Cell[109363, 2551, 889, 15, 171, "Input"],
Cell[110255, 2568, 1748, 54, 71, "Text"],
Cell[112006, 2624, 334, 5, 90, "Input"],
Cell[112343, 2631, 1730, 54, 71, "Text"],
Cell[114076, 2687, 283, 4, 70, "Input"],
Cell[114362, 2693, 838, 14, 230, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[115237, 2712, 116, 2, 30, "Text"],
Cell[115356, 2716, 166, 5, 33, "Text"],
Cell[115525, 2723, 1299, 22, 231, "Input"],
Cell[116827, 2747, 1810, 57, 71, "Text"],
Cell[118640, 2806, 342, 5, 90, "Input"],
Cell[118985, 2813, 863, 15, 230, "Input"]
}, Closed]],
Cell[119863, 2831, 1799, 59, 68, "Text"],
Cell[121665, 2892, 17298, 286, 163, 17184, 282, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[138988, 3182, 108, 2, 33, "Text"],
Cell[139099, 3186, 219, 6, 71, "Text"],
Cell[139321, 3194, 181, 8, 39, "Text"],
Cell[139505, 3204, 1916, 54, 156, "Text"],
Cell[141424, 3260, 184, 5, 109, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[141645, 3270, 108, 2, 30, "Text"],
Cell[141756, 3274, 242, 6, 74, "Text"],
Cell[142001, 3282, 231, 9, 39, "Text"],
Cell[142235, 3293, 2692, 71, 210, "Text"],
Cell[144930, 3366, 120, 4, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[145087, 3375, 115, 2, 30, "Text"],
Cell[145205, 3379, 166, 5, 33, "Text"],
Cell[145374, 3386, 653, 12, 153, "Input"],
Cell[146030, 3400, 1748, 54, 71, "Text"],
Cell[147781, 3456, 331, 5, 90, "Input"],
Cell[148115, 3463, 1728, 54, 71, "Text"],
Cell[149846, 3519, 283, 4, 70, "Input"],
Cell[150132, 3525, 852, 14, 230, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[151021, 3544, 116, 2, 30, "Text"],
Cell[151140, 3548, 166, 5, 33, "Text"],
Cell[151309, 3555, 1085, 18, 210, "Input"],
Cell[152397, 3575, 1794, 57, 71, "Text"],
Cell[154194, 3634, 334, 5, 90, "Input"],
Cell[154531, 3641, 844, 14, 230, "Input"]
}, Closed]],
Cell[155390, 3658, 1863, 61, 68, "Text"],
Cell[157256, 3721, 17786, 294, 163, 17672, 290, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[175067, 4019, 108, 2, 33, "Text"],
Cell[175178, 4023, 212, 5, 71, "Text"],
Cell[175393, 4030, 263, 8, 39, "Text"],
Cell[175659, 4040, 2314, 54, 146, "Text"],
Cell[177976, 4096, 2725, 71, 188, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[180738, 4172, 108, 2, 30, "Text"],
Cell[180849, 4176, 291, 6, 75, "Text"],
Cell[181143, 4184, 303, 9, 39, "Text"],
Cell[181449, 4195, 2574, 53, 215, "Text"],
Cell[184026, 4250, 2260, 58, 112, "Text"],
Cell[186289, 4310, 3235, 87, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[189561, 4402, 116, 2, 30, "Text"],
Cell[189680, 4406, 166, 5, 33, "Text"],
Cell[189849, 4413, 1053, 19, 171, "Input"],
Cell[190905, 4434, 1748, 54, 71, "Text"],
Cell[192656, 4490, 331, 5, 90, "Input"],
Cell[192990, 4497, 1728, 54, 71, "Text"],
Cell[194721, 4553, 283, 4, 70, "Input"],
Cell[195007, 4559, 437, 16, 36, "Text"],
Cell[195447, 4577, 2061, 37, 438, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[197545, 4619, 117, 2, 30, "Text"],
Cell[197665, 4623, 166, 5, 33, "Text"],
Cell[197834, 4630, 1858, 34, 273, "Input"],
Cell[199695, 4666, 1922, 60, 71, "Text"],
Cell[201620, 4728, 400, 7, 90, "Input"],
Cell[202023, 4737, 1178, 21, 243, "Input"]
}, Closed]],
Cell[203216, 4761, 309, 11, 30, "Text"],
Cell[203528, 4774, 10442, 174, 163, 10328, 170, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[213995, 4952, 104, 2, 33, "Text"],
Cell[214102, 4956, 271, 6, 71, "Text"],
Cell[214376, 4964, 269, 9, 39, "Text"],
Cell[214648, 4975, 1090, 29, 172, "Text"],
Cell[215741, 5006, 1094, 28, 167, "Text"],
Cell[216838, 5036, 1083, 29, 115, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[217958, 5070, 112, 2, 30, "Text"],
Cell[218073, 5074, 713, 18, 71, "Text"],
Cell[218789, 5094, 1265, 24, 272, "Input"],
Cell[220057, 5120, 172, 6, 36, "Text"],
Cell[220232, 5128, 1303, 23, 332, "Input"],
Cell[221538, 5153, 302, 10, 33, "Text"],
Cell[221843, 5165, 551, 10, 187, "Input"],
Cell[222397, 5177, 958, 24, 166, "Text"],
Cell[223358, 5203, 1069, 22, 155, "Input"],
Cell[224430, 5227, 370, 11, 36, "Text"],
Cell[224803, 5240, 1372, 25, 336, "Input"],
Cell[226178, 5267, 140, 4, 33, "Text"],
Cell[226321, 5273, 359, 7, 75, "Input"]
}, Closed]],
Cell[226695, 5283, 280, 11, 30, "Text"],
Cell[226978, 5296, 8836, 148, 163, 8722, 144, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[235839, 5448, 104, 2, 33, "Text"],
Cell[235946, 5452, 264, 6, 70, "Text"],
Cell[236213, 5460, 318, 10, 67, "Text"],
Cell[236534, 5472, 1446, 40, 324, "Text"],
Cell[237983, 5514, 747, 19, 143, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[238767, 5538, 112, 2, 30, "Text"],
Cell[238882, 5542, 166, 5, 33, "Text"],
Cell[239051, 5549, 1171, 25, 268, "Input"],
Cell[240225, 5576, 1338, 42, 80, "Text"],
Cell[241566, 5620, 774, 12, 223, "Input"],
Cell[242343, 5634, 1737, 30, 402, "Input"],
Cell[244083, 5666, 1316, 42, 80, "Text"],
Cell[245402, 5710, 724, 11, 202, "Input"]
}, Closed]],
Cell[246141, 5724, 1190, 38, 300, "Text"],
Cell[247334, 5764, 492, 16, 77, "Text"],
Cell[247829, 5782, 9511, 159, 163, 9397, 155, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[257343, 5943, 238, 8, 36, "Text"],
Cell[257584, 5953, 10808, 180, 197, 10694, 176, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[268395, 6135, 270, 9, 36, "Text"],

Cell[CellGroupData[{
Cell[268690, 6148, 108, 2, 33, "Text"],
Cell[268801, 6152, 2179, 65, 270, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[271017, 6222, 108, 2, 30, "Text"],
Cell[271128, 6226, 1199, 28, 187, "Text"],
Cell[272330, 6256, 1302, 27, 246, "Text"],
Cell[273635, 6285, 2167, 62, 259, "Text"],
Cell[275805, 6349, 310, 9, 36, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[276152, 6363, 116, 2, 30, "Text"],
Cell[276271, 6367, 245, 8, 42, "Text"],
Cell[276519, 6377, 126, 2, 69, "Input"],
Cell[276648, 6381, 245, 8, 42, "Text"],
Cell[276896, 6391, 126, 2, 69, "Input"],
Cell[277025, 6395, 89, 2, 33, "Text"],
Cell[277117, 6399, 813, 14, 225, "Input"],
Cell[277933, 6415, 813, 14, 225, "Input"],
Cell[278749, 6431, 403, 10, 77, "Text"],
Cell[279155, 6443, 2156, 40, 486, "Input"],
Cell[281314, 6485, 537, 15, 33, "Text"],
Cell[281854, 6502, 954, 17, 243, "Input"],
Cell[282811, 6521, 232, 8, 36, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[283080, 6534, 116, 2, 30, "Text"],
Cell[283199, 6538, 115, 3, 33, "Text"],
Cell[283317, 6543, 656, 13, 152, "Input"],
Cell[283976, 6558, 667, 18, 58, "Text"],
Cell[284646, 6578, 1812, 34, 406, "Input"],
Cell[286461, 6614, 662, 19, 36, "Text"],
Cell[287126, 6635, 1042, 18, 250, "Input"],
Cell[288171, 6655, 263, 9, 36, "Text"]
}, Closed]],
Cell[288449, 6667, 290, 7, 30, "Text"],
Cell[288742, 6676, 281, 7, 33, "Text"],
Cell[289026, 6685, 257, 5, 33, "Text"],
Cell[289286, 6692, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

