(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    538717,      11017]*)
(*NotebookOutlinePosition[    540044,      11061]*)
(*  CellTagsIndexPosition[    539966,      11055]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[{
  StyleBox["9.3.1  Introduction to Filtering",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tIn the field of signal processing the design of digital signal \
filters involves the process of suppressing certain frequencies and boosting \
others.  A simplified filter model is\n\n",
  StyleBox["(9-22)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t ",
  Cell[BoxData[
      \(y[n] + a\_1\ y[n - 1] + a\_2\ y[n - 2]\ \  = \ \ b\_0\ x[n] + 
          b\_1\ x[n - 1] + b\_2\ x[n - 2] + b\_3\ x[n - 3]\)]],
  ", \n\nwhere the input signal is ",
  Cell[BoxData[
      \(x\_n = x[n]\)]],
  " is modified to obtain the output signal ",
  Cell[BoxData[
      \(y\_n = y[n]\)]],
  " using the recursion formula    \n\n",
  StyleBox["(9-23)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t ",
  Cell[BoxData[
      \(y[n]\ \  = \ \ b\_0\ x[n] + b\_1\ x[n - 1] + b\_2\ x[n - 2] + 
          b\_3\ x[n - 3] - a\_1\ y[n - 1] - a\_2\ y[n - 2]\)]],
  ".  \n\nThe implementation of ",
  StyleBox["(9-23)",
    FontColor->RGBColor[0, 0, 1]],
  " is straightforward and only requires starting values, then ",
  Cell[BoxData[
      \(y\_n = y[n]\)]],
  " is obtained by simple iteration.  Since the signals must have a starting \
point, it is common to require that  ",
  Cell[BoxData[
      \(x\_n = 0\)]],
  "  and  ",
  Cell[BoxData[
      \(y\_n = 0\)]],
  "  for  ",
  Cell[BoxData[
      \(n < 0\)]],
  ".  We emphasize this concept by making the following definition.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 9.3 (Causal Sequence)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Given the the input ",
  Cell[BoxData[
      \({x\_n}\_\(n = \(-\[Infinity]\)\)\%\[Infinity]\)]],
  " and output ",
  Cell[BoxData[
      \({y\_n}\_\(n = \(-\[Infinity]\)\)\%\[Infinity]\)]],
  " sequences.  If  ",
  Cell[BoxData[
      \(x\_n = 0\)]],
  "  and  ",
  Cell[BoxData[
      \(y\_n = 0\)]],
  "  for  ",
  Cell[BoxData[
      \(n < 0\)]],
  ", the sequence is said to be causal.  "
}], "Text"],

Cell[TextData[{
  "\tGiven the causal sequence ",
  Cell[BoxData[
      \({x\_n = x[n]}\_\(n = 0\)\%\[Infinity]\)]],
  ", it is easy to calculate the solution ",
  Cell[BoxData[
      \({y\_n = y[n]}\_\(n = 0\)\%\[Infinity]\)]],
  " to ",
  StyleBox["(9-23)",
    FontColor->RGBColor[0, 0, 1]],
  ".  Use the fact that these sequences are causal: \n\n",
  StyleBox["(9-24)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      RowBox[{\(x\_\(-3\) = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(x\_\(-2\) = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{\(x\_\(-1\)\), "=", 
          RowBox[{
            RowBox[{"0", "    ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "    ", \(y\_\(-2\)\)}], "=", 
            "0"}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(y\_\(-1\) = 0\)}]]],
  ". \n\nThen compute  \n\n",
  StyleBox["(9-25)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      RowBox[{\(y\_0\ \ \  = \ \ \ \(b\_0\) x\_0\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(y\_1\ \ \  = \ \ \ b\_0\ x\_1\  + \ 
            b\_1\ x\_0\  - \ a\_1\ y\_0\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(y\_2\ \ \  = \ \ \ b\_0\ x\_2\  + \ 
            b\_1\ x\_1\  + \ b\_2\ x\_0\  - \ a\_1\ y\_1\  - \ a\_2\ y\_0\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{\(y\_3\), "   ", "=", "   ", 
          
          RowBox[{\(b\_0\ x\_3\), " ", "+", " ", \(b\_1\ x\_2\), " ", "+", 
            " ", \(b\_2\ x\_1\), " ", "+", " ", \(b\_3\ x\_0\), " ", "-", 
            " ", \(a\_1\ y\_2\), " ", "-", " ", 
            RowBox[{\(a\_2\), " ", 
              RowBox[{\(y\_1\), 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[".",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}]}]}]}]]],
  "  \n\t \nThe general iterative step is   \n\n",
  StyleBox["(9-26)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(y\_n\ \ \  = \ \ \ b\_0\ x\_n\  + \ b\_1\ x\_\(n - 1\)\  + \ 
          b\_2\ x\_\(n - 2\)\  + \ b\_3\ x\_\(n - 3\)\  - \ 
          a\_1\ y\_\(n - 1\)\  - \ a\_2\ y\_\(n - 2\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["9.3.2  The Basic Filters",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe following three simplified basic filters serve as illustrations. \
 \n\t\n",
  StyleBox["(i) Zeroing Out Filter",
    FontColor->RGBColor[0, 0, 1]],
  "  \t",
  Cell[BoxData[
      \(y[n]\ \  = \ \ b\_0\ x[n]\  + \ b\_1\ x[n - 1]\  + \ 
          b\_2\ x[n - 2]\  + \ b\_3\ x[n - 3]\)]],
  ",     (note that  ",
  Cell[BoxData[
      RowBox[{\(a\_1\), "=", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(a\_2\)}], "=", "0"}]}]]],
  ").  \n\n",
  StyleBox["(ii) Boosting Up Filter",
    FontColor->RGBColor[0, 0, 1]],
  "  \t",
  Cell[BoxData[
      \(y[n]\ \  = \ \ b\_0\ x[n]\  - \ a\_1\ y[n - 1]\  - \ 
          a\_2\ y[n - 2]\)]],
  ",     (note that  ",
  Cell[BoxData[
      RowBox[{\(b\_1 = 0\), "  ", ",", 
        RowBox[{\(b\_2\), "=", 
          RowBox[{
            RowBox[{"0", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(b\_3\)}], "=", "0"}]}]}]]],
  ").  \n\n",
  StyleBox["(iii) Combination Filter",
    FontColor->RGBColor[0, 0, 1]],
  " \t",
  Cell[BoxData[
      \(y[n]\ \  = \ \ b\_0\ x[n] + b\_1\ x[n - 1] + b\_2\ x[n - 2] + 
          b\_3\ x[n - 3] - a\_1\ y[n - 1] - a\_2\ y[n - 2]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["\tThe transfer function  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(H \((z)\)\)]],
  " ",
  StyleBox["for these model filters has the following general form \n",
    FontFamily->"Times New Roman"],
  "\n",
  StyleBox["(9-27)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(H \((z)\)\ \  = \ \ \(\(Y \((z)\)\)\/\(X \((z)\)\)\ \  = \ \ \(b\_0 + \
\(b\_1\) z\^\(-1\) + \(b\_2\) z\^\(-2\) + \(b\_3\) z\^\(-3\)\)\/\(1 + \
\(a\_1\) z\^\(-1\) + \(a\_2\) z\^\(-2\)\)\)\)]],
  ", \n\nwhere the z-transforms of the input and output sequences are ",
  Cell[BoxData[
      \(X \((z)\) = \[GothicCapitalZ][x\_n]\)]],
  " and ",
  Cell[BoxData[
      \(Y \((z)\) = \[GothicCapitalZ][y\_n]\)]],
  ", respectively.   In the previous section we mentioned that the general \
solution to a homogeneous difference equation  ",
  Cell[BoxData[
      \(y[n] + a\_1\ y[n - 1] + a\_2\ y[n - 2] = 0\)]],
  "  is stable only if the zeros of the characteristic equation lie inside \
the unit circle.  Similarly, if a filter is stable then the poles of the \
transfer function  ",
  Cell[BoxData[
      \(H \((z)\)\)]],
  "  must all lie inside the unit circle. "
}], "Text"],

Cell[TextData[{
  "\tBefore developing the general theory, we would like to investigate the \
amplitude response  ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  " when the input signal is a linear combination of  ",
  Cell[BoxData[
      \(cos \((\[Theta]\ n)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\[Theta]\ n)\)\)]],
  ".   The amplitude response for the frequency ",
  Cell[BoxData[
      \(\[Theta]\)]],
  " uses the complex unit signal ",
  Cell[BoxData[
      \(z = \[ExponentialE]\^\[ImaginaryI]\[Theta]\)]],
  ", and is defined to be \n\n",
  StyleBox["(9-28)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(A \((\[Theta])\)\  = \ \(\(|\)\(H \((\[ExponentialE]\^\[ImaginaryI]\
\[Theta])\)\)\(|\)\)\)]],
  ". \n\nThe formula for ",
  Cell[BoxData[
      \(\(\(A\) \((\[Theta])\)\(\ \)\)\)]],
  " will be rigorously explained after a few introductory examples.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 9.21.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given the filter  ",
  Cell[BoxData[
      \(y[n]\ \  = \ \ x[n] - \@2\ x[n - 1] + x[n - 2]\)]],
  ".\n\n",
  StyleBox["9.21 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that it is a zeroing out filter for the signals ",
  Cell[BoxData[
      \(cos \((\(\[Pi]\/4\) n)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\(\[Pi]\/4\) n)\)\)]],
  " and calculate the amplitude response  ",
  Cell[BoxData[
      \(A \((\[Pi]\/4)\) = A \((0.7853981633974483`)\)\)]],
  ".\n\n",
  StyleBox["9.21 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Calculate the amplitude responses ",
  Cell[BoxData[
      RowBox[{"A", \((0.10)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "A", \((0.77)\)}]]],
  " and investigate the the filtered signal for  ",
  Cell[BoxData[
      \(x[n] = \ cos \((0.10\ n)\) + sin \((0.77\ n)\)\)]],
  ".  \n\n",
  StyleBox["9.21 (c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Calculate the amplitude responses ",
  Cell[BoxData[
      RowBox[{"A", \((0.10)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "A", \((\(2  \[Pi]\)\/3)\)}]]],
  " and investigate the the filtered signal for  ",
  Cell[BoxData[
      \(x[n] = \ cos \((0.10\ n)\) + 0.20  sin \((\(2  \[Pi]\)\/3\ n)\)\)]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000550000Qb000`400?l0
0000o`00003oo`3ooom60?ooo`00o`3ooom60?ooo`00o`3ooom60?ooo`00
o`3ooom60?ooo`00o`3ooom60?ooo`00o`3ooom60?ooo`00o`3ooom60?oo
o`00o`3ooom60?ooo`00o`3oool20?ooo`<00000@@3oool00?l0oooo0`3o
ool00`000000oooo0?ooo`100?ooo`00Z`3oool3000002H0oooo1000000W
0?ooo`D00000@@3oool00:`0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0X0?ooo`040000003oool0oooo00000480oooo002Y0?oo
o`D000009`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool00000
0480oooo002Y0?ooo`040000003oool0oooo000002T0oooo00<000000?oo
o`3oool0:03oool200000480oooo002Z0?ooo`030000003oool0000002L0
oooo00@000000?ooo`3oool00000K@3oool00:/0oooo0P00000X0?ooo`80
00008@3oool<000000030?ooo`000000000000800000?03oool00?l0oooo
AP3oool00:H0oooo100000000`3oool000000000000200000280oooo1P00
00000`3oool000000000001[0?ooo`00o`3ooolZ0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0503oool00?l0oooo:`3oool01000
0000oooo0?ooo`00000G0?ooo`00n`3oool2000000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool00000
01L0oooo003j0?ooo`040000003oool0oooo000000D0oooo00@000000?oo
o`3oool00000903oool00`000000oooo0000000G0?ooo`00Z03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`0000008`3oool5000001H0oooo002Y0?ooo`04
0000003oool0oooo000002L0oooo00@000000?ooo`3oool000009@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0000003h0oooo002Z0?oo
o`030000003oool0000002P0oooo00<000000?ooo`0000008P3oool01000
0000oooo0?ooo`0000050?ooo`D00000?@3oool00:X0oooo00<000000?oo
o`000000:03oool00`000000oooo0000000S0?ooo`800000B03oool00:T0
oooo1@00000V0?ooo`D00000K03oool00?l0ooooAP3oool00800oooo:P00
00020?l008400000603oool00800oooo00<000000?ooo`3oool09P3oool3
0?l002X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01H0oooo00200?ooo`030000003oool0oooo
02D0oooo00D0o`000?ooo`3oool0oooo0?l0002H0?ooo`00P03oool00`00
0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool0U@3oool00800oooo00<000000?ooo`3oool08P3oool20?l000L0
oooo0P3o002E0?ooo`00P03oool00`000000oooo0?ooo`0Q0?ooo`030?l0
003oool0oooo00T0oooo00<0o`000?ooo`3oool0TP3oool00800oooo00<0
00000?ooo`3oool07`3oool20?l000d0oooo00<0o`000?ooo`3oool0T@3o
ool00800oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0>
0?ooo`030?l0003oool0oooo0900oooo00200?ooo`030000003oool0oooo
01d0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`2?0?oo
o`00P03oool00`000000oooo0?ooo`0K0?ooo`80o`00503oool00`3o0000
oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`0I0?ooo`80o`00
5`3oool00`3o0000oooo0?ooo`2=0?ooo`00P03oool00`000000oooo0?oo
o`0G0?ooo`80o`006P3oool20?l008d0oooo00200?ooo`030000003oool0
oooo01@0oooo0`3o000N0?ooo`030?l0003oool0oooo08X0oooo00200?oo
o`030000003oool0oooo0180oooo0P3o000R0?ooo`030?l0003oool0oooo
08T0oooo00200?ooo`030000003oool0oooo0100oooo0P3o000U0?ooo`03
0?l0003oool0oooo08P0oooo00200?ooo`030000003oool0oooo00h0oooo
0P3o000X0?ooo`030?l0003oool0oooo08L0oooo00200?ooo`030000003o
ool0oooo00X0oooo103o000[0?ooo`030?l0003oool0oooo08H0oooo0020
0?ooo`030000003oool0oooo00@0oooo1P3o000`0?ooo`030?l0003oool0
oooo08D0oooo00200?ooo`L0o`00=`3oool00`3o0000oooo0?ooo`240?oo
o`00P03oool00`000000oooo0?ooo`0l0?ooo`030?l0003oool0oooo08<0
oooo00200?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0
PP3oool00800oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo0?oo
o`210?ooo`00P03oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0
oooo0800oooo00200?ooo`030000003oool0oooo0400oooo00<0o`000?oo
o`3oool0O`3oool00800oooo00<000000?ooo`3oool0@@3oool00`3o0000
oooo0?ooo`1n0?ooo`00P03oool00`000000oooo0?ooo`120?ooo`030?l0
003oool0oooo07d0oooo00200?ooo`030000003oool0oooo04<0oooo00<0
o`000?ooo`3oool0O03oool00800oooo00<000000?ooo`3oool0A03oool0
0`3o0000oooo0?ooo`1k0?ooo`00P03oool00`000000oooo0?ooo`150?oo
o`030?l0003oool0oooo07X0oooo001h0?ooo`D000000`3oool00`000000
oooo0?ooo`160?ooo`030?l0003oool0oooo07T0oooo001j0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0A`3oool00`3o0000oooo
0?ooo`1h0?ooo`00NP3oool00`000000oooo0?ooo`030?ooo`800000B@3o
ool00`3o0000oooo0?ooo`1g0?ooo`00NP3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0M`3oool0
07X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`190?oo
o`030?l0003oool0oooo07H0oooo001i0?ooo`8000001@3oool00`000000
oooo0?ooo`1:0?ooo`030?l0003oool0oooo07D0oooo00200?ooo`030000
003oool0oooo04/0oooo00<0o`000?ooo`3oool0M03oool00800oooo00<0
00000?ooo`3oool0C03oool00`3o0000oooo0?ooo`1c0?ooo`00P03oool0
0`000000oooo0?ooo`1=0?ooo`030?l0003oool0oooo0780oooo00200?oo
o`030000003oool0oooo04h0oooo00<0o`000?ooo`3oool0L@3oool00800
oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`1`0?ooo`00
P03oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0700oooo
00200?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0K`3o
ool00800oooo00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`1^
0?ooo`00P03oool00`000000oooo0?ooo`1B0?ooo`030?l0003oool0oooo
06d0oooo00200?ooo`030000003oool0oooo05<0oooo00<0o`000?ooo`3o
ool0K03oool00800oooo00<000000?ooo`3oool0E03oool00`3o0000oooo
0?ooo`1[0?ooo`00P03oool00`000000oooo0?ooo`1E0?ooo`030?l0003o
ool0oooo06X0oooo00200?ooo`030000003oool0oooo05H0oooo00<0o`00
0?ooo`3oool0J@3oool00800oooo00<000000?ooo`3oool0EP3oool00`3o
0000oooo0?ooo`1Y0?ooo`00P03oool00`000000oooo0?ooo`1G0?ooo`03
0?l0003oool0oooo06P0oooo00200?ooo`030000003oool0oooo05P0oooo
00<0o`000?ooo`3oool0I`3oool00800oooo00<000000?ooo`3oool0F@3o
ool00`3o0000oooo0?ooo`1V0?ooo`00P03oool00`000000oooo0?ooo`1J
0?ooo`030?l0003oool0oooo06D0oooo00200?ooo`030000003oool0oooo
05/0oooo00<0o`000?ooo`3oool0I03oool00800oooo00<000000?ooo`3o
ool0G03oool00`3o0000oooo0?ooo`1S0?ooo`00P03oool00`000000oooo
0?ooo`1M0?ooo`030?l0003oool0oooo0680oooo00200?ooo`030000003o
ool0oooo05h0oooo00<0o`000?ooo`3oool0H@3oool00800oooo00<00000
0?ooo`3oool0G`3oool00`3o0000oooo0?ooo`1P0?ooo`00P03oool00`00
0000oooo0?ooo`1P0?ooo`030?l0003oool0oooo05l0oooo001h0?ooo`@0
0000103oool00`000000oooo0?ooo`1Q0?ooo`030?l0003oool0oooo05h0
oooo001h0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
HP3oool00`3o0000oooo0?ooo`1M0?ooo`00N@3oool00`000000oooo0?oo
o`040?ooo`800000I03oool00`3o0000oooo0?ooo`1L0?ooo`00NP3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo06@0oooo00<0o`00
0?ooo`3oool0F`3oool007P0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`1U0?ooo`030?l0003oool0oooo05X0oooo001i0?oo
o`8000001@3oool00`000000oooo0?ooo`1U0?ooo`030?l0003oool0oooo
05X0oooo00200?ooo`030000003oool0oooo06H0oooo00<0o`000?ooo`3o
ool0F@3oool00800oooo00<000000?ooo`3oool0I`3oool00`3o0000oooo
0?ooo`1H0?ooo`00P03oool00`000000oooo0?ooo`1X0?ooo`030?l0003o
ool0oooo05L0oooo00200?ooo`030000003oool0oooo06T0oooo00<0o`00
0?ooo`3oool0EP3oool00800oooo00<000000?ooo`3oool0JP3oool00`3o
0000oooo0?ooo`1E0?ooo`00P03oool00`000000oooo0?ooo`1[0?ooo`03
0?l0003oool0oooo05@0oooo00200?ooo`030000003oool0oooo06`0oooo
0P3o001D0?ooo`00P03oool00`000000oooo0?ooo`1^0?ooo`030?l0003o
ool0oooo0540oooo00200?ooo`030000003oool0oooo06l0oooo00<0o`00
0?ooo`3oool0D03oool00800oooo00<000000?ooo`3oool0L03oool00`3o
0000oooo0?ooo`1?0?ooo`00P03oool00`000000oooo0?ooo`1a0?ooo`03
0?l0003oool0oooo04h0oooo00200?ooo`030000003oool0oooo0780oooo
00<0o`000?ooo`3oool0C@3oool00800oooo00<000000?ooo`3oool0L`3o
ool00`3o0000oooo0?ooo`1<0?ooo`00P03oool00`000000oooo0?ooo`1d
0?ooo`030?l0003oool0oooo04/0oooo00200?ooo`030000003oool0oooo
07D0oooo00<0o`000?ooo`3oool0BP3oool00800oooo00<000000?ooo`3o
ool0MP3oool00`3o0000oooo0?ooo`190?ooo`00P03oool00`000000oooo
0?ooo`1g0?ooo`030?l0003oool0oooo04P0oooo00200?ooo`030000003o
ool0oooo07P0oooo00<0o`000?ooo`3oool0A`3oool00800oooo00<00000
0?ooo`3oool0N@3oool00`3o0000oooo0?ooo`160?ooo`00P03oool00`00
0000oooo0?ooo`1j0?ooo`80o`00AP3oool00800oooo00<000000?ooo`3o
ool0O03oool00`3o0000oooo0?ooo`130?ooo`00P03oool00`000000oooo
0?ooo`1m0?ooo`030?l0003oool0oooo0480oooo00200?ooo`030000003o
ool0oooo07h0oooo00<0o`000?ooo`3oool0@@3oool00800oooo00<00000
0?ooo`3oool0O`3oool20?l00440oooo001i0?ooo`8000001@3oool00`00
0000oooo0?ooo`210?ooo`030?l0003oool0oooo03h0oooo001h0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0PP3oool20?l0
03h0oooo001j0?ooo`030000003oool0oooo00<0oooo0P0000250?ooo`80
o`00?03oool007/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`260?ooo`030?l0003oool0oooo03T0oooo001h0?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0Q`3oool20?l003T0oooo
001i0?ooo`8000001@3oool00`000000oooo0?ooo`290?ooo`80o`00=`3o
ool00800oooo00<000000?ooo`3oool0R`3oool20?l003D0oooo00200?oo
o`030000003oool0oooo08d0oooo00<0o`000?ooo`3oool0<P3oool00800
oooo00<000000?ooo`3oool0SP3oool20?l00380oooo00200?ooo`030000
003oool0oooo0900oooo0P3o000`0?ooo`00P03oool00`000000oooo0?oo
o`2B0?ooo`80o`00;P3oool00800oooo00<000000?ooo`3oool0U03oool2
0?l002`0oooo00200?ooo`030000003oool0oooo09H0oooo103o000X0?oo
o`00P03oool00`000000oooo0?ooo`2J0?ooo`<0o`009@3oool00800oooo
00<000000?ooo`3oool0W@3oool60?l001l0oooo00200?ooo`030000003o
ool0oooo0:<0oooo1`3o000H0?ooo`00P03oool00`000000oooo0?ooo`32
0?ooo`00P03oool00`000000oooo0?ooo`320?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{325, 135},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Figure 9.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "The amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\) = \(\(|\)\(1 - \ \(\@2\) z\^\(-1\) + 
            z\^\(-2\)\)\(|\)\)\)]],
  " for  ",
  Cell[BoxData[
      \(y[n] = x[n] - \@2\ x[n - 1] + x[n - 2]\)]],
  ". "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009T0000S2000`400?l0
0000o`00003oo`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0
ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3o
ool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0
ooooIP3oool005H0oooo1000003o0?ooo`H0oooo0P0000040?ooo`800000
0`3oool300000?L0oooo001F0?ooo`030000003oool0oooo0?l0oooo1P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000?H0
oooo001G0?ooo`030000003oool0oooo00@0oooo0`00003m0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool30000
0>l0oooo001@0?ooo`@00000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0?L0oooo100000020?ooo`040000003oool0oooo0000
00P0oooo0`0000050?ooo`030000003oool0oooo06L0oooo1@3o00230?oo
o`00EP3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
06L0oooo00<0o`000?ooo`3oool0T`3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3oool2
0?l00080oooo0`000?l40?l007l0oooo001G0?ooo`8000001@3oool00`00
0000oooo0?ooo`1U0?ooo`<0o`00UP3oool2000000X0oooo0`0000040?oo
o`030000003oool0oooo06<0oooo00<0003o0?l000000?l00`000?l70?oo
o`80o`0000<0003o0?ooo`3oool0NP3oool005h0oooo00<000000?ooo`3o
ool0I03oool0103o0000oooo0?ooo`3o002Y0?ooo`030000003oool0oooo
0600oooo0P000?l20?l000h0oooo0P3o00030000ogP0oooo001N0?ooo`03
0000003oool0oooo06@0oooo00D0o`000?ooo`3oool0oooo0?l0002X0?oo
o`030000003oool0oooo05h0oooo0P000?l20?l00180oooo0`3o00030000
ogD0oooo001N0?ooo`030000003oool0oooo06<0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`2V0?ooo`030000003oool0oooo05d0
oooo00<0003o0?l0003o00005`3oool30?l00080003oL`3oool005h0oooo
00<000000?ooo`3oool0H`3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo0:H0oooo00<000000?ooo`3oool0F`3oool20000o`030?l0
003oool0oooo01X0oooo0`3o00000`000?l0oooo0?ooo`1_0?ooo`00GP3o
ool00`000000oooo0?ooo`1S0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool0YP3oool00`000000oooo0?ooo`1I0?ooo`80003o0P3o
000P0?ooo`@0o`00KP3oool005h0oooo00<000000?ooo`3oool0H`3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo01H0oooo00<0o`00
0?ooo`3oool0S03oool00`000000oooo0?ooo`1G0?ooo`80003o0P3o000U
0?ooo`030000o`3o0000o`0006`0oooo001N0?ooo`030000003oool0oooo
0680oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0D0?oo
o`<0o`00SP3oool00`000000oooo0?ooo`1F0?ooo`030000o`3o0000o`00
02P0oooo00<0003o0?ooo`3o0000J`3oool005h0oooo00<000000?ooo`3o
ool0HP3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01<0
oooo00D0o`000?ooo`3oool0oooo0?l0002=0?ooo`030000003oool0oooo
05D0oooo0P3o000[0?ooo`040000o`3oool0o`000?l006T0oooo001N0?oo
o`030000003oool0oooo04/0oooo0P3o000E0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool04`3oool01@3o0000oooo0?ooo`3oool0
o`0008d0oooo00<000000?ooo`3oool0D`3oool20?l002h0oooo0P000?l0
0`3oool0o`000?ooo`1W0?ooo`00GP3oool00`000000oooo0?ooo`180?oo
o`<0o`0000<0oooo0?l0003oool0503oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`2;0?ooo`030000003oool0oooo0540oooo0P3o00000`00
0?l0oooo0?ooo`0_0?ooo`80003o00<0o`000?ooo`3oool0I@3oool005h0
oooo00<000000?ooo`3oool0B03oool01@3o0000oooo0?ooo`3oool0o`00
01@0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0A0?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`1?0?ooo`80o`000P000?ld0?ooo`030000o`3o0000oooo
06D0oooo001N0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo08X0oooo00<000000?ooo`3oool0CP3oool00`3o0000
003o0000o`0g0?ooo`030000o`3o0000oooo06@0oooo001N0?ooo`030000
003oool0oooo04L0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`0A0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo08X0oooo
00<000000?ooo`3oool0C@3oool00`3o0000003o0?ooo`0i0?ooo`030000
o`3o0000oooo06<0oooo001N0?ooo`030000003oool0oooo04L0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo00H0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo08X0oooo00<000000?ooo`3oool0C03o
ool00`3o0000003o0?ooo`0k0?ooo`030000o`3o0000oooo0680oooo001N
0?ooo`030000003oool0oooo04L0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00P0oooo00<0o`00
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo08T0oooo00<000000?ooo`3oool0B`3oool00`3o0000oooo0000o`0m
0?ooo`030000o`3o0000oooo0640oooo001N0?ooo`030000003oool0oooo
04L0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0?0?oo
o`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool03`3oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo07H0oooo0P0000040?oo
o`800000103oool2000000D0oooo00<000000?ooo`3oool0BP3oool00`3o
0000oooo0000o`100?ooo`030?l0003oool0oooo05l0oooo001N0?ooo`03
0000003oool0oooo04L0oooo00<0o`000?ooo`3oool0103oool00`3o0000
oooo0?ooo`0?0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo07D0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo04T0oooo00<0o`000?ooo`000?l0@P3oool0
0`3o0000oooo0?ooo`1N0?ooo`00GP3oool00`000000oooo0?ooo`170?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool03`3oool00`3o
0000oooo0?ooo`080?ooo`030?l0003oool0oooo00h0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`1d0?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool00`3oool3000004P0oooo00<0o`00
0000o`000?l0@`3oool00`3o0000oooo0?ooo`1N0?ooo`00GP3oool00`00
0000oooo0?ooo`160?ooo`030?l0003oool0oooo00D0oooo00<0o`000?oo
o`3oool03`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo
00h0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`1^0?oo
o`@000000P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0A`3oool00`3o0000003o0?ooo`15
0?ooo`030?l0003oool0oooo05d0oooo001N0?ooo`030000003oool0oooo
04H0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool03@3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo07@0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo04L0oooo00<0o`000?ooo`3oool0A@3oool00`3o0000003o0?oo
o`1M0?ooo`00GP3oool00`000000oooo0?ooo`160?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`1e0?ooo`8000002P3oool2000000D0oooo00<00000
0?ooo`3oool0AP3oool00`3o0000oooo0?ooo`170?ooo`030?l000000?l0
oooo05`0oooo001N0?ooo`030000003oool0oooo04H0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo
00X0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0oooo08P0oooo00<000000?ooo`3oool0A@3oool00`00
0?l0o`000?ooo`190?ooo`030?l000000?l0oooo05/0oooo001F0?ooo`D0
00000`3oool00`000000oooo0?ooo`160?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool02@3oool00`3o0000
oooo0?ooo`270?ooo`030000003oool0oooo04@0oooo00<0003o0?l0003o
ool0BP3oool00`3o0000oooo0000o`1K0?ooo`00F03oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo04H0oooo00<0o`000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00X0oooo
00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0oooo08L0oooo00<000000?ooo`3oool0@`3oool00`000?l0o`00
0?ooo`1<0?ooo`030?l0003oool0003o05X0oooo001H0?ooo`030000003o
ool0oooo00<0oooo0`0000150?ooo`030?l0003oool0oooo00P0oooo00<0
o`000?ooo`3oool0303oool0103o0000oooo0?ooo`3oool90000o`030?l0
003oool0oooo00`0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0D0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0
@P3oool00`000?l0o`000?ooo`1>0?ooo`030?l0003oool0003o05T0oooo
001@0?ooo`@00000103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo04D0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?oo
o`0<0?ooo`@0003o2@3oool70000o`P0oooo00<0o`000?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0C0?ooo`80o`00LP3oool00`000000oooo0?oo
o`110?ooo`030000o`3oool0o`000500oooo00<0o`000?ooo`000?l0F03o
ool005P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`15
0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool3
0000o`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00`3oool4
0000o`@0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0B
0?ooo`030?l0003oool0o`000780oooo00<000000?ooo`3oool0@03oool0
0`000?l0oooo0?l0001B0?ooo`80o`0000<0003o0?ooo`3oool0E@3oool0
05L0oooo0P0000050?ooo`030000003oool0oooo04D0oooo00<0o`000?oo
o`3oool0203oool00`3o0000oooo0?ooo`050?ooo`@0003o0P3oool00`3o
0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00L0oooo0`000?l00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0140oooo00D0o`000?oo
o`3oool0oooo0?l0001a0?ooo`030000003oool0oooo01X0oooo1@000002
0?ooo`8000006@3oool3000000040000o`3oool0o`000?ooo`8000006`3o
ool2000000@0oooo0P00000K0?ooo`<000000P3oool2000000d0oooo00<0
o`000000o`3oool02P3oool2000000@0oooo0P00000I0?ooo`<00000103o
ool200000240oooo001N0?ooo`030000003oool0oooo04D0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`030?ooo`80003o1P3oool0
0`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo0P000?l;
0?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`1_0?ooo`030000003oool0oooo01`0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00L0
00000?ooo`3oool0003o0?l0003oool000000080oooo00<000000?ooo`3o
ool05`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000001/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00P0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000H0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000803oool005h0oooo00<000000?oo
o`3oool0A03oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo
0080003o203oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00X0oooo00@0o`000?ooo`000?l0003o2@3oool00`3o0000oooo0?ooo`0@
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0G0?ooo`03000000000?l0o`000080oooo00@0
00000?ooo`3oool000006`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool05P3oool5000000050?ooo`000000oooo0?oo
o`0000003P3oool00`3o0000oooo0?ooo`0:0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000200oooo001N0?ooo`030000003o
ool0oooo02d0oooo103o000C0?ooo`030?l0003oool0oooo00X0oooo00<0
o`000?ooo`000?l02P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00T0oooo00@0o`000?ooo`3oool0oooo0P000?l80?ooo`030?l0
003oool0oooo00l0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`1_0?ooo`030000003oool0oooo01`0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo01L0oooo00<0003o0?l0003o
ool00P3oool010000000oooo0?ooo`00000L0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000l0oooo00<0o`000?ooo`3oool0
1`3oool2000000<0oooo00@000000?ooo`3oool00000603oool3000000<0
oooo00@000000?ooo`3oool00000803oool005h0oooo00<000000?ooo`3o
ool0;@3oool0103o0000oooo0?ooo`3o000C0?ooo`030?l0003oool0oooo
00X0oooo0P000?l;0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?oo
o`3oool02@3oool00`3o0000oooo0?ooo`030?ooo`80003o1P3oool00`3o
0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool0KP3oool00`000000oooo0?ooo`0L0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0F0?ooo`040000o`3o0000
oooo00000080oooo00@000000?ooo`3oool000006@3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000001T0oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`00000@0?ooo`80o`001`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000001T0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000P0?ooo`00GP3o
ool00`000000oooo0?ooo`0]0?ooo`050?l0003oool0oooo0?ooo`3o0000
4P3oool00`3o0000oooo0?ooo`070?ooo`<0003o00<0o`000?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00T0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00h0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`1^0?ooo`030000003oool0oooo01/0oooo0P0000040?ooo`800000
6@3oool00`3o00000000000000040?ooo`8000006`3oool2000000@0oooo
0P00000K0?ooo`8000000`3oool200000180oooo00<0003o0?l0003o0000
1@3oool3000000<0oooo0P00000J0?ooo`<000000`3oool200000240oooo
001N0?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00D0oooo0P00
0?l30?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo0P00
0?l30?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`1^0?ooo`030000003oool0oooo03/0oooo00<0
003o0?l0003oool0G`3oool00`000?l0oooo0?l0001?0?ooo`00GP3oool0
0`000000oooo0?ooo`0/0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool0403oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool2
0000o`030?ooo`3o0000oooo00l0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`1^0?ooo`030000003oool0oooo03X0oooo00<0003o
0?l0003oool0H@3oool00`000?l0o`000?ooo`1>0?ooo`00GP3oool00`00
0000oooo0?ooo`0/0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool03`3oool00`3o0000oooo0?ooo`030?ooo`80003o1`3oool00`3o
0000oooo0?ooo`080?ooo`030?l0003oool0oooo00l0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`0;0?ooo`80003o403oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo06d0oooo00<000000?oo
o`3oool0>@3oool00`000?l0o`000?ooo`1S0?ooo`030000o`3o0000oooo
04d0oooo001N0?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0<0?ooo`030?l000000?l0oooo00d0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`1]0?ooo`030000003oool0oooo03P0
oooo0P3o001U0?ooo`030000o`3oool0o`0004d0oooo001N0?ooo`030000
003oool0oooo02/0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0>0?ooo`030?l0003oool0oooo0080003o2P3oool00`3o0000oooo
0?ooo`080?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`0=0?ooo`030?l000000?l0003o00`0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`1]0?ooo`030000
003oool0oooo03L0oooo00<0o`000?ooo`3oool0IP3oool00`000?l0oooo
0?l000100?ooo`8000000P3oool2000000H0oooo001N0?ooo`030000003o
ool0oooo02/0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`0>0?ooo`030?l0003oool0003o00`0oooo00<0o`000?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`020000o`X0oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`1]0?ooocT0000000<0
o`00000000000000J00000000`000?l0o`000000000h000000P0oooo00@0
00000?ooo`3oool000001`3oool005h0oooo00<000000?ooo`3oool0:`3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00d0oooo0P00
0?l>0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0403o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00h0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo00<0o`000?ooo`3oool0K@3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool06@3oool00`000?l0o`000?ooo`030?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool05`3oool010000000oooo0?oo
o`0000070?ooo`00GP3oool00`000000oooo0?ooo`0[0?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool02`3oool20000o`030?l0003o
ool0oooo00d0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0@0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`1/0?ooo`030000003o
ool0oooo03@0oooo00<0o`000000o`3oool0J`3oool00`000?l0o`000?oo
o`0n0?ooo`@00000203oool005h0oooo00<000000?ooo`3oool06P3oool5
00000080oooo0P0000080?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool4000000030000o`3oool0o`00008000003P3oool0
0`3o0000oooo0?ooo`060?ooo`040?l0003oool0oooo0?ooo`800000103o
ool2000000P0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`080?ooo`<000000P3oool00`000000o`000?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool0103o0000oooo0000
000000040?ooo`8000006@3oool3000000@0oooo0P0000130?ooo`030000
003oool0oooo03<0oooo00<0o`000000o`3oool0K@3oool00`000?l0o`00
0?ooo`190?ooo`00GP3oool00`000000oooo0?ooo`0L0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool010000000oooo
0?ooo`000?l20?ooo`040?l0003oool0oooo000000d0oooo00<0o`000?oo
o`3oool01P3oool0103o0000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0oooo00T0oooo00L000000?ooo`3oool00000
0?ooo`3o0000000000H0oooo0P000?l40?ooo`030?l0003oool0oooo00P0
oooo00D0o`000000003oool0oooo000000020?ooo`040000003oool0oooo
000001P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000120?ooo`030000003oool0oooo0340oooo0P3o00000`000?l0oooo
0?ooo`1^0?ooo`030000o`3o0000oooo04P0oooo001N0?ooo`030000003o
ool0oooo01`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`03000000000?l0oooo0080oooo00@0o`000?ooo`3oool0
00003@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`D0000000D0oooo0000003oool0oooo0?l000080?ooo`050000o`3oool0
oooo0?ooo`3o00002P3oool01@3o0000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool00000603oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000480oooo00<000000?ooo`3oool0<03oool0
0`3o0000oooo0000o`1b0?ooo`030000o`3o0000oooo04L0oooo001N0?oo
o`030000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`000000oooo0080oooo00@0o`00
0?ooo`3oool000003P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0?l0
00T0oooo00@0003o0?ooo`3oool0o`002P3oool0103o0000oooo00000000
00030?ooo`040000003oool0oooo000000`0oooo00<0o`000?ooo`3oool0
2@3oool3000000<0oooo00@000000?ooo`3oool00000@P3oool00`000000
oooo0?ooo`0_0?ooo`030?l0003oool0003o07@0oooo00<0o`000?ooo`3o
ool0AP3oool005h0oooo00<000000?ooo`3oool0703oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3o
ool000000P3oool0103o0000oooo0?ooo`00000>0?ooo`030?l0003oool0
oooo00@0oooo00D0o`000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo00P0oooo00<000000?ooo`000000
0P3oool010000000oooo0?ooo`3o000:0?ooo`80003o00<0o`000?ooo`3o
ool0203oool00`3o0000oooo000000040?ooo`040000003oool0oooo0000
00/0oooo0P3o000<0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000@P3oool00`000000oooo0?ooo`0_0?ooo`030?l000000?l0
oooo07D0oooo00<0o`000?ooo`3oool0A@3oool005h0oooo00<000000?oo
o`3oool06`3oool2000000@0oooo0P0000070?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool0103oool010000?l0oooo000000000003
0?ooo`030?l000000000000000l0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`020?ooo`800000103oool2000000P0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`8000000`3oool2
000000030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo00000002000000<0oooo0P00000<0?ooo`030?l0003oool0
o`0000/0oooo0`0000030?ooo`800000@`3oool00`000000oooo0?ooo`0^
0?ooo`030?l000000?l0oooo07L0oooo00<0o`000?ooo`3oool0A03oool0
05h0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0D0?oo
o`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool00P3oool20000
o`H0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?oo
o`000?l02@3oool00`3o0000oooo0?ooo`0B0?ooo`040?l0003oool0oooo
0?l005H0oooo00<000000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`1h
0?ooo`030?l0003oool0oooo04<0oooo001N0?ooo`030000003oool0oooo
0180oooo0P3o000E0?ooo`030?l0003oool0oooo00T0oooo00@0o`000?oo
o`000?l0003o203oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool0203oool0
103o0000oooo0?ooo`000?l90?ooo`030?l0003oool0oooo0140oooo00@0
o`000?ooo`3oool0o`00EP3oool00`000000oooo0?ooo`0]0?ooo`030?l0
00000?l0oooo07T0oooo00<0o`000000o`3oool0@`3oool005h0oooo00<0
00000?ooo`3oool04@3oool00`3o0000oooo0?l0000E0?ooo`030?l0003o
ool0oooo00T0oooo00<0o`000000o`3oool02@3oool00`3o0000oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0503o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0180oooo00<0
o`000?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool0003o00P0oooo
00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo05<0oooo00<000000?ooo`3oool0;03oool00`3o0000003o
0?ooo`1k0?ooo`030?l000000?l0oooo0480oooo001N0?ooo`030000003o
ool0oooo0140oooo00@0o`000?ooo`3oool0o`00503oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo01D0oooo
00D0o`000?ooo`3oool0oooo0?l0000D0?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo0100oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0U0?ooo`8000000P3oool2000002P0oooo00<000000?ooo`3o
ool0;03oool00`3o0000oooo0?ooo`1l0?ooo`030?l000000?l0oooo0440
oooo001N0?ooo`030000003oool0oooo0140oooo00@0o`000?ooo`3oool0
o`00503oool00`3o0000oooo0?ooo`080?ooo`030000o`3o0000oooo00X0
oooo00<0o`000?ooo`3oool04@3oool01@3o0000oooo0?ooo`3oool0o`00
01T0oooo00@0o`000?ooo`3oool0o`00503oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo00@0oooo0P000?l50?ooo`030?l0003oool0
oooo00l0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0U
0?ooo`040000003oool0oooo000002T0oooo00<000000?ooo`3oool0:`3o
ool00`3o0000oooo0?ooo`1n0?ooo`030?l000000?l0oooo0400oooo001N
0?oooa<0000000<0o`000000000000000P0000000`3o000000000000000A
000000030?l000000000000000L0000000<0003o0000003o00002P000000
0`3o000000000000000C000000040?l00000000000000?l001X000000P3o
000E000000030?l000000000000000L0000000<0o`000000000000001P00
00000`000?l0000000000002000000030?l000000000000000l0000000<0
o`00000000000000100000000`3o000000000000000E000000030?l00000
0000000000D00000203oool010000000oooo0?ooo`00000Y0?ooo`030000
003oool0oooo02/0oooo00<0o`000?ooo`3oool0O`3oool00`3o0000003o
0?ooo`0o0?ooo`00GP3oool00`000000oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo0P000?l20?ooo`030?l0003o
ool0oooo00P0oooo00<0o`000000003oool04`3oool0103o0000oooo0?l0
003o000:0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0
3P3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool20000o`80oooo00<0o`000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`80o`00
3@3oool4000002X0oooo00<000000?ooo`3oool0:P3oool00`3o0000oooo
0?ooo`200?ooo`030?l0003oool0003o03l0oooo001N0?ooo`030000003o
ool0oooo00l0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0@0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo01<0oooo0P3o
000d0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?l0000@0?ooo`030?l0003oool0oooo00D0oooo00<0
o`000?ooo`3oool0503oool0103o0000oooo0?ooo`3o000j0?ooo`030000
003oool0oooo02T0oooo00<0o`000?ooo`3oool0PP3oool00`3o0000oooo
0000o`0n0?ooo`00GP3oool00`000000oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`190?ooo`030?l0003oool0oooo00D0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?l0000?0?ooo`030?l0003o
ool0oooo00H0oooo00<0o`000?ooo`3oool04`3oool01@3o0000oooo0?oo
o`3oool0o`0003T0oooo00<000000?ooo`3oool09`3oool00`000?l0o`00
0?ooo`250?ooo`030?l000000?l0oooo03d0oooo001N0?ooo`030000003o
ool0oooo00l0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`0?0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo04T0oooo00<0
o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
0000oooo00h0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0C0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0V0?ooo`030000o`3o0000oooo08L0oooo00<0
o`000000o`3oool0?03oool005h0oooo00<000000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00l0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`05
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo01<0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0S0?ooo`800000103oool2
000000@0oooo0P0000050?ooo`050000003oool0oooo0?ooo`3o00008`3o
ool00`000?l0o`000?ooo`290?ooo`030?l000000?l0oooo03/0oooo001N
0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0080003o2@3oool0
0`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo04/0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`0=0?ooo`030?l000000?l0
oooo00d0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0B
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool08P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo
00D000000?ooo`3oool0oooo0?l0000R0?ooo`030000o`3o0000oooo08/0
oooo00<0o`000000o`3oool0>P3oool005h0oooo00<000000?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00d0oooo
00@0o`000?ooo`3oool0003o2`3oool00`3o0000oooo0?ooo`060?ooo`03
0?l0003oool0oooo04/0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0>0?ooo`040?l0003oool0003o0000o``0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool08@3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo00<0oooo0`0000000`3oool0o`000?ooo`0Q
0?ooo`030?l0003oool0oooo08`0oooo0P3o000j0?ooo`00GP3oool00`00
0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool03@3oool00`3o0000oooo0000o`0=0?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool0B`3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo00h0oooo00D0o`000?ooo`3oool0oooo0000o`0:
0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0240oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`3o00008@3oool00`000?l0o`000?ooo`2?0?ooo`030?l0
003oool0oooo03L0oooo001N0?ooo`030000003oool0oooo00h0oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0=0?ooo`80003o3P3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo04/0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0?0?ooo`040?l0003o
ool0oooo0?ooo`80003o203oool00`3o0000oooo0?ooo`080?ooo`030?l0
003oool0oooo0140oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0Q0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000103oool010000000oooo0?ooo`3oool20?l001l0oooo00<0003o
0?l0003oool0T@3oool20?l003L0oooo001N0?ooo`030000003oool0oooo
00d0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3o0000oooo00h0oooo00<0o`000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`1<0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool03`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0@0?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool08P3oool20000
00X0oooo0P0000050?ooo`040000003oool0oooo0?ooo`80o`007@3oool2
0000o`030?l0003oool0oooo0980oooo00<0003o0?l0003o0000=@3oool0
05h0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o00003`3oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo04`0oooo00D0o`000?oo
o`3oool0oooo0?l0000B0?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0
oooo0100oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0e
0?ooo`040000003oool0oooo0?ooo`80o`00703oool00`000?l0o`000?l0
002G0?ooo`030000o`3o0000oooo03<0oooo001N0?ooo`030000003oool0
oooo00d0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`09
0?ooo`040000o`3oool0oooo0?l00100oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`1=0?ooo`050?l0003oool0oooo0?ooo`3o0000
4P3oool00`3o0000oooo0?ooo`050?ooo`80003o103oool00`3o0000oooo
0?ooo`080?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`0e0?ooo`060000003oool0oooo0?l0003o
ool0o`006`3oool00`000?l0o`000?ooo`2I0?ooo`030000o`3o0000oooo
0380oooo001N0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`080?ooo`040000o`3oool0oooo0?l0
0140oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`1>0?oo
o`030?l0003oool0o`0001<0oooo00<0o`000?ooo`3oool01`3oool01@00
0?l0oooo0?ooo`3oool0o`0000X0oooo00<0o`000?ooo`3oool0403oool0
0`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo03@0oooo00H00000
0?ooo`3oool0o`000?ooo`3o000J0?ooo`80o`00W03oool00`000?l0o`00
0?ooo`0a0?ooo`00GP3oool00`000000oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool20000o`<0oooo00<0
o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo04h0oooo00<0o`000?ooo`3o00004`3oool00`3o0000oooo0?oo
o`080?ooo`80003o00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0?0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0=03o
ool01P000000oooo0?ooo`3o0000oooo0?l001P0oooo0P3o002O0?ooo`03
0000o`3o0000oooo0300oooo001N0?ooo`030000003oool0oooo00d0oooo
00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?ooo`80003o
1@3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`0C0?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
=03oool01P000000oooo0?ooo`3o0000oooo0?l001H0oooo0P3o00000`00
0?l0oooo0?ooo`2O0?ooo`030000o`3o0000o`0002l0oooo001N0?ooo`03
0000003oool0oooo00d0oooo00<0o`000?ooo`3oool02@3oool0103o0000
oooo0?ooo`3oool20000o`L0oooo00<0o`000?ooo`3oool0403oool01@3o
0000oooo0?ooo`3oool0o`000580oooo00<0o`000?ooo`3oool04`3oool0
0`3o0000oooo0?ooo`090?ooo`030?l000000?l0oooo00X0oooo00<0o`00
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo03@0oooo00H000000?ooo`3oool0o`000?ooo`3o000E0?ooo`030?l0
003oool0003o0:<0oooo0P000?l00`3o0000oooo0?ooo`0/0?ooo`00GP3o
ool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo00@0
o`000?ooo`3oool0003o2@3oool00`3o0000oooo0?ooo`0A0?ooo`040?l0
003oool0oooo0?l006P0oooo00<0o`000?ooo`3oool02@3oool00`3o0000
oooo0000o`0:0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0d0?ooo`040000003oool0oooo0?l0
0080oooo00<0o`000?ooo`3oool0403oool20?l000030?ooo`000?l0oooo
0:D0oooo00<0003o0?l0003oool0;03oool005h0oooo00<000000?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0:0?ooo`030?l000000?l0003o00X0
oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?l0001Y0?ooo`03
0?l0003oool0oooo00T0oooo00@0o`000?ooo`3oool0003o2@3oool00`3o
0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool0=03oool010000000oooo0?ooo`3o00020?ooo`030?l0003oool0
oooo00l0oooo00@0o`000?ooo`000?l0003oZ03oool00`000?l0o`000?oo
o`0[0?ooo`00GP3oool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0C
0?ooo`80o`00J@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0
oooo0080oooo0P000?l80?ooo`030?l0003oool0oooo00d0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`0c0?ooo`040000003oool0
oooo0?l00080oooo00<0o`000?ooo`3oool03@3oool20?l00080003o[03o
ool00`3o0000oooo0?ooo`0Y0?ooo`00GP3oool00`000000oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00P0oooo0P000?l00`3oool0o`000?ooo`09
0?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool0J@3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo0`000?l5
0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0c0?ooo`040000003oool0oooo0?l00080oooo00<0
o`000?ooo`3oool0303oool00`3o0000003o0000o`2_0?ooo`030?l00000
0?l0oooo02P0oooo001N0?ooo`030000003oool0oooo00`0oooo00<0o`00
0?ooo`3oool01P3oool20000o`<0oooo00<0o`000?ooo`3oool0203oool0
0`3o0000oooo0?ooo`1o0?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool20000o`<0oooo00<0o`000?ooo`3oool0303oool0
0`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo03<0oooo00@00000
0?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l00000
0?l0oooo0;40oooo0P3o00000`000?l0oooo0?ooo`0U0?ooo`00GP3oool0
0`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00@0oooo0P000?l5
0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0O`3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo0P000?l0
0`3oool0o`000?ooo`0=0?ooo`030?l0003oool0oooo03l0oooo00@00000
0?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`090?ooo`80o`0000<0
003o0?ooo`3oool0/`3oool00`3o0000003o0000o`0U0?ooo`00GP3oool0
0`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo0P000?l7
0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0O`3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00/0oooo0`000?l=
0?ooo`030?l0003oool0oooo03l0oooo00@000000?ooo`3oool0o`000P3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3o0000003o0;P0oooo00@0
o`000?ooo`000?l0003o8`3oool005h0oooo00<000000?ooo`3oool02`3o
ool00`3o0000oooo0000o`030000o`T0oooo00<0o`000?ooo`3oool0203o
ool00`3o0000oooo0?ooo`1o0?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool0303oool0103o0000oooo0000o`000?l:0?ooo`030?l0
003oool0oooo0400oooo00<000000?ooo`3o0000103oool00`3o0000oooo
0?ooo`030?ooo`80003o0P3o002k0?ooo`030?l0003oool0oooo00<0003o
2`3oool20?l001<0oooo001N0?ooo`030000003oool0oooo00X0oooo0`00
0?l=0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0P03o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00h0oooo00<0
o`000?ooo`3oool00P000?l80?ooo`030?l0003oool0oooo0400oooo00<0
00000?ooo`3o0000103oool00`3o0000oooo0000o`030000o`030?ooo`3o
0000oooo0;d0oooo0P3o00030?ooo`@0003o1`3o000E0?ooo`00EP3oool5
000000<0oooo00<000000?ooo`3oool01P3oool40000o`030?ooo`3o0000
oooo00h0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`21
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`020?ooo`<0003o1@3oool00`3o0000oooo0?ooo`0]
0?ooo`800000103oool2000000<0oooo0`0000050?ooo`030000003oool0
o`0000@0oooo00<0o`000000o`3oool00P3oool20?l00<40oooo1`3o0009
0000oa<0oooo001H0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool30000o`D0oooo00<0o`000?ooo`3oool03@3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo0840oooo00<0o`000?oo
o`3oool01@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00D0oooo1P000?l80?ooo`D0003o8@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o0000103o
ool50?l00>H0oooo001H0?ooo`030000003oool0oooo00<0oooo1P000?l8
0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`210?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l000000?l0
003o00H0003o9P3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000@0oooo0P0000000`3o0000oooo0?ooo`3]0?ooo`00F03o
ool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo00/0oooo00<0
o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo0840oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0;@3o
ool010000000oooo0?ooo`0000080?ooo`<000001@3oool00`000000oooo
0?l0003_0?ooo`00F03oool00`000000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00X0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo0880oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00T0oooo00<0
o`000?ooo`3oool0;@3oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3o0000k`3oool005L0oooo0P00
00050?ooo`030000003o0000oooo00X0oooo00<0o`000?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0880oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo00T0oooo00<0o`000?ooo`3oool0;P3oool2000000X0oooo0`00
00040?ooo`030000003oool0o`000>l0oooo001N0?ooo`030000003o0000
oooo00X0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo08<0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00P0oooo00<0o`00
0?ooo`3oool0@@3oool00`000000oooo0?l0003_0?ooo`00GP3oool00`00
0000o`000?ooo`0:0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`230?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0oooo0440oooo00<000000?ooo`3o0000k`3oool005h0
oooo00<000000?l0003oool02P3oool00`3o0000oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0Q03oool01@3o0000
oooo0?ooo`3oool0o`0001<0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`120?ooo`030000003oool0o`000>l0oooo001N0?ooo`03
0000003o0000oooo00T0oooo00<0o`000?ooo`3oool0403oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo08@0oooo00@0o`000?ooo`3o
ool0o`00503oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
0480oooo00<000000?ooo`3o0000k`3oool005h0oooo00<000000?ooo`3o
00002@3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool0Q@3oool0103o0000oooo0?ooo`3o000D0?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0@P3oool00`00
0000oooo0?l0003_0?ooo`00GP3oool00`000000oooo0?l000090?ooo`03
0?l0003oool0oooo0140oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`260?ooo`80o`005@3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo0480oooo00<000000?l0003oool0k`3oool005h0oooo
00<000000?ooo`3o00002@3oool00`3o0000oooo0?ooo`0A0?ooo`050?l0
003oool0oooo0?ooo`3o0000R@3oool00`3o0000oooo0?ooo`0D0?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0@P3oool00`000000
o`000?ooo`3_0?ooo`00GP3oool00`000000oooo0?l000090?ooo`030?l0
003oool0oooo0180oooo00@0o`000?ooo`3oool0o`00X@3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo0480oooo00<000000?l0003o
ool0k`3oool005h0oooo00@000000?ooo`3oool0o`001`3oool00`3o0000
oooo0?ooo`0C0?ooo`030?l0003oool0o`000:80oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`130?ooo`030000003o0000oooo0>l0
oooo001N0?ooo`040000003oool0oooo0?l000L0oooo00<0o`000?ooo`3o
ool0503oool20?l00:80oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`130?ooo`030000003o0000oooo0>l0oooo001N0?ooo`040000
003oool0oooo0?l000L0oooo00<0o`000?ooo`3oool0503oool00`3o0000
oooo0?ooo`2Q0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3o
ool0@`3oool00`000000o`000?ooo`3_0?ooo`00GP3oool010000000oooo
0?ooo`3o00070?ooo`030?l0003oool0oooo0;P0oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`130?ooo`030000003o0000oooo0>l0
oooo001N0?ooo`040000003oool0oooo0?l000L0oooo00<0o`000?ooo`3o
ool0^@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo04<0
oooo00<000000?l0003oool0k`3oool005h0oooo00D000000?ooo`3oool0
oooo0?l000050?ooo`030?l0003oool0oooo0;X0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`130?ooo`030000003o0000oooo0>l0
oooo001N0?ooo`050000003oool0oooo0?ooo`3o00001@3oool00`3o0000
oooo0?ooo`2j0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0<@3oool2000000@0oooo0P0000030?ooo`<000001@3oool00`000000
o`000?ooo`3_0?ooo`00GP3oool01@000000oooo0?ooo`3oool0o`0000D0
oooo00<0o`000?ooo`3oool0^`3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo0300oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`030?ooo`030000003o0000oooo0>l0oooo001N0?ooo`05
0000003oool0oooo0?ooo`3o00001@3oool00`3o0000oooo0?ooo`2k0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0<03oool01000
0000oooo0?ooo`0000090?ooo`<00000103oool00`000000o`000000003_
0?ooo`00GP3oool00`000000oooo0?ooo`020?ooo`050?l0003oool0oooo
0?ooo`3o0000_`3oool01@3o0000oooo0?ooo`3oool0o`000380oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`03
0?l0003oool0oooo0>l0oooo001N0?ooo`030000003oool0oooo0080oooo
00D0o`000?ooo`3oool0oooo0?l0002o0?ooo`040?l0003oool0oooo0?l0
03<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00040?ooo`030?l0003oool0oooo0>l0oooo001N0?ooo`030000003oool0
oooo0080oooo00@0o`000?ooo`3oool0o`00`03oool00`3o0000oooo0?l0
000e0?ooo`8000002P3oool3000000@0oooo00<0o`000?ooo`3oool0k`3o
ool005h0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?l00031
0?ooo`80o`00B03oool00`3o0000oooo0?ooo`3_0?ooo`00EP3oool40000
00@0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?l000310?oo
o`030?l0003oool0oooo04L0oooo00<0o`000?ooo`3oool0k`3oool005H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0?l0003oool0oooo0?l0oooo2`3oool00`3o0000oooo0?ooo`3_0?ooo`00
E`3oool00`000000oooo0?ooo`040?ooo`<00000103oool00`3o0000oooo
0?ooo`3o0?ooo`/0oooo00<0o`000?ooo`3oool0k`3oool005P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`/0oooo001F0?ooo`040000003oool0
oooo00000?l0ooooo`3oool<0?ooo`00E`3oool200000?l0ooooo`3oool=
0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo
o`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool0
05/0oooo0P0000080?ooo`800000o`3oool10?ooo`8000001P3oool20000
00P0oooo0P00003Y0?ooo`00F`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0?l0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0>L0oooo001B0?ooo`800000
00<0oooo000000000000103oool00`000000oooo0?ooo`0200000080oooo
0P0000020?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo008000000P3oool200000080oooo
00<000000?ooo`3oool0i`3oool005<0oooo00<000000?ooo`0000001@3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo0000003o0?ooo`80oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000003Y
0?ooo`00E03oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000?l0oooo0@3o
ool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool000000>T0oooo001B0?ooo`80
000000<0oooo000000000000103oool00`000000oooo0?ooo`04000000@0
oooo00<000000?ooo`3oool0o@3oool3000000030?ooo`000000000000<0
oooo00<000000?ooo`3oool0100000040?ooo`030000003oool0oooo0>L0
oooo001K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
o`3oool70?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
i`3oool005/0oooo0P0000080?ooo`800000o`3oool90?ooo`800000203o
ool200000>T0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?oo
o`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{612, 140},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Figure 9.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The input  ",
  Cell[BoxData[
      \(x[n] = cos \((0.10  n)\) + sin \((0.77  n)\)\)]],
  "  and output  ",
  Cell[BoxData[
      \(y[n]\)]],
  "."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009T0000S2000`400?l0
0000o`00003oo`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0
ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3o
ool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo001R0?ooo`03
0000003oool0oooo0?l0ooooo`3oool10?ooo`00HP3oool00`000000oooo
0?ooo`3o0?ooo`H0oooo1@00003e0?ooo`00HP3oool00`000000oooo0?oo
o`1/0?ooo`030?l0003oool0oooo09P0oooo00<000000?ooo`3oool0m@3o
ool00680oooo00<000000?ooo`3oool0HP3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo09P0oooo00<000000?ooo`3oool00`3oool3
00000>l0oooo001R0?ooo`030000003oool0oooo0680oooo00<0o`000?oo
o`3oool01`3oool20?l00940oooo100000040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0JP3oool00`3o0000oooo0?ooo`220?oo
o`00HP3oool00`000000oooo0?ooo`1R0?ooo`80o`001`3oool00`3o0000
oooo0?l000090?ooo`030?l0003oool0oooo08d0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1Z0?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool0M`3oool00680oooo00<000000?ooo`3oool0
H@3oool00`3o0000oooo0?l000070?ooo`040?l0003oool0oooo0?l000P0
oooo00<0o`000?ooo`3oool0S03oool2000000D0oooo00<000000?ooo`3o
ool0H03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool0M`3oool00680oooo00<000000?ooo`3oool0
H@3oool0103o0000oooo0?ooo`3o00060?ooo`040?l0003oool0oooo0?l0
00L0oooo00<0o`000?ooo`3o0000U03oool00`000000oooo0?ooo`1P0?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`3o
0000oooo0?ooo`1g0?ooo`00F`3oool500000080oooo00<000000?ooo`3o
ool0F03oool00`3o0000oooo0?ooo`060?ooo`040?l0003oool0oooo0?l0
00H0oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`030?l0003oool0
o`0009@0oooo00<000000?ooo`3oool0H03oool00`3o0000oooo0?ooo`06
0?ooo`80o`002@3oool20?l007T0oooo001M0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0F03oool00`3o0000oooo0?ooo`060?oo
o`050?l0003oool0oooo0?ooo`3o00001@3oool01@3o0000oooo0?ooo`3o
ool0o`0000H0oooo00<0o`000?ooo`3o0000U03oool00`000000oooo0?oo
o`1P0?ooo`030?l0003oool0oooo00H0oooo0P3o00090?ooo`80o`002@3o
ool00`3o0000oooo0?ooo`1]0?ooo`00G@3oool00`000000oooo0?ooo`02
0?ooo`<00000F03oool20?l000H0oooo00@0o`000?ooo`3oool0oooo3P00
0?l40?ooo`030?l0003oool0o`0009@0oooo00<000000?ooo`3oool0EP3o
ool00`3o0000oooo0?ooo`060?ooo`80o`00203oool00`3o0000oooo0?l0
00080?ooo`80o`002@3oool00`3o0000oooo0?ooo`1]0?ooo`00E@3oool4
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1G
0?ooo`030?l0003oool0o`0000H0oooo00H0o`000000o`000?l0003o0?oo
o`3o00040?ooo`030?l0003oool0oooo00<0oooo00H0o`000?ooo`000?l0
003o0?ooo`3o00030?ooo`030?l0003oool0oooo00D0oooo00<0o`000?oo
o`3oool0R@3oool00`000000oooo0?ooo`1F0?ooo`030?l0003oool0oooo
00H0oooo0P3o00080?ooo`030?l0003oool0o`0000P0oooo0P3o00090?oo
o`030?l0003oool0oooo06d0oooo001M0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0E`3oool0103o0000oooo0?ooo`3o00030?oo
o`<0003o1@3oool01@3o0000oooo0?ooo`3oool0o`0000H0oooo00<0o`00
0?ooo`3oool00P000?l30?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3oool0R@3oool00`000000oooo0?ooo`1F0?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3o00001`3oool00`3o0000oooo0?l00008
0?ooo`80o`00203oool20?l006l0oooo001L0?ooo`800000103oool00`00
0000oooo0?ooo`1G0?ooo`050?l0003oool0oooo0?l0003oool00P000?l2
0?ooo`030?l0003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l0
00060?ooo`050?l0003oool0oooo0?ooo`3o00000P000?l00`3oool0o`00
0?ooo`060?ooo`80o`00RP3oool00`000000oooo0?ooo`1F0?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3o00001`3oool00`3o0000oooo
0?l000080?ooo`030?l0003oool0o`0000L0oooo0P3o001_0?ooo`00HP3o
ool00`000000oooo0?ooo`1G0?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool00`3o0000oooo0?ooo`040?ooo`040?l0003oool0oooo0?l000H0
oooo00@0o`000?ooo`3oool0o`000`3oool20000o`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3o0000RP3oool00`000000oooo0?ooo`1F0?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o00001`3oool00`3o
0000oooo0?l000070?ooo`040?l0003oool0oooo0?l000L0oooo0P3o001_
0?ooo`00HP3oool00`000000oooo0?ooo`1G0?ooo`050?l0003oool0003o
0000o`3o00000`3oool00`3o0000oooo0?ooo`050?ooo`040?l0003oool0
oooo0?l000L0oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0o`0008X0oooo00<000000?ooo`3oool0E@3o
ool20?l000P0oooo00<0o`000?ooo`3o00001`3oool00`3o0000oooo0?l0
00070?ooo`040?l0003oool0oooo0?l000L0oooo0P3o00090?ooo`030?l0
003oool0oooo06<0oooo001R0?ooo`030000003oool0oooo05H0oooo00<0
o`000?ooo`000?l00`3oool0103o0000oooo0?ooo`3o00080?ooo`80o`00
203oool00`3o0000oooo0?l000050?ooo`030?l000000?l0003o00<0oooo
00@0o`000?ooo`3oool0o`00R@3oool00`000000oooo0?ooo`1E0?ooo`80
o`00203oool00`3o0000oooo0?l000060?ooo`040?l0003oool0oooo0?l0
00L0oooo00@0o`000?ooo`3oool0o`001`3oool20?l000T0oooo00<0o`00
0?ooo`3oool0H`3oool00680oooo00<000000?ooo`3oool0C@3oool00`3o
0000oooo0?ooo`060?ooo`030?l000000?l0oooo00<0oooo00@0o`000?oo
o`3oool0o`00203oool20?l000P0oooo00<0o`000?ooo`3o00001P3oool0
1P3o0000oooo0000o`000?l0oooo0?l00080oooo00<0o`000?ooo`3oool0
Q`3oool00`000000oooo0?ooo`1<0?ooo`030?l0003oool0oooo00H0oooo
0P3o00080?ooo`030?l0003oool0o`0000H0oooo00@0o`000?ooo`3oool0
o`001`3oool0103o0000oooo0?ooo`3o00060?ooo`030?l0003oool0o`00
00T0oooo00<0o`000?ooo`3oool0H`3oool00680oooo00<000000?ooo`3o
ool0C@3oool20?l000H0oooo0P000?l60?ooo`030?l0003oool0o`0000T0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`04
0?l0003oool0oooo0?ooo`80003o0P3oool00`3o0000oooo0?ooo`270?oo
o`030000003oool0oooo04`0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?l000060?ooo`040?l0003oool0oooo0?l000H0oooo00@0o`00
0?ooo`3oool0o`001`3oool0103o0000oooo0?ooo`3o00060?ooo`040?l0
003oool0oooo0?l000P0oooo00<0o`000?ooo`3oool0H`3oool00680oooo
00<000000?ooo`3oool0C@3oool00`3o0000oooo0?l000040?ooo`030000
o`3oool0o`0000H0oooo0P3o000D0?ooo`030?l0003oool0oooo00H0oooo
00H0o`000?ooo`3oool0o`000?ooo`000?l20?ooo`030?l0003oool0oooo
08H0oooo00<000000?ooo`3oool0C03oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0o`0000H0oooo00@0o`000?ooo`3oool0o`001P3oool0
103o0000oooo0?ooo`3o00060?ooo`050?l0003oool0oooo0?ooo`3o0000
1P3oool0103o0000oooo0?ooo`3o00070?ooo`80o`00I@3oool00680oooo
00<000000?ooo`3oool0C@3oool00`3o0000oooo0?l000030?ooo`030000
o`3oool0o`0000P0oooo00<0o`000?ooo`3oool06`3oool0103o0000oooo
0?ooo`3o00020?ooo`030000o`3oool0o`0008P0oooo00<000000?ooo`3o
ool0C03oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0o`0000H0
oooo00@0o`000?ooo`3oool0o`001P3oool0103o0000oooo0?ooo`3o0006
0?ooo`050?l0003oool0oooo0?ooo`3o00001P3oool0103o0000oooo0?oo
o`3o00070?ooo`80o`00I@3oool00680oooo00<000000?ooo`3oool0C03o
ool01`3o0000oooo0?ooo`3oool0o`000?ooo`000?l00P3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo01/0oooo00@0o`000?ooo`3o
ool0o`000`3oool00`000?l0o`000?ooo`060?ooo`030?l0003oool0oooo
07h0oooo00<000000?ooo`3oool0B`3oool20?l000P0oooo00<0o`000?oo
o`3o00001P3oool0103o0000oooo0?ooo`3o00060?ooo`040?l0003oool0
oooo0?l000H0oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`040?l0
003oool0oooo0?l000L0oooo0P3o001U0?ooo`00HP3oool00`000000oooo
0?ooo`1<0?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0
oooo0?l0000W0?ooo`030?l0003oool0o`0000@0oooo00<0003o0?l0003o
ool01@3oool00`3o0000oooo0?ooo`1n0?ooo`030000003oool0oooo04/0
oooo0P3o00080?ooo`030?l0003oool0o`0000H0oooo00@0o`000?ooo`3o
ool0o`001P3oool01@3o0000oooo0?ooo`3oool0o`0000D0oooo00D0o`00
0?ooo`3oool0oooo0?l000060?ooo`040?l0003oool0oooo0?l000L0oooo
00<0o`000?ooo`3o0000I03oool00680oooo00<000000?ooo`3oool0C03o
ool01`3o0000oooo0?ooo`3oool0003o0?ooo`3o00000P3oool00`3o0000
oooo0?ooo`0U0?ooo`80o`001P3oool00`000?l0oooo0?ooo`030?ooo`80
o`00P03oool00`000000oooo0?ooo`1;0?ooo`80o`001`3oool0103o0000
oooo0?ooo`3o00060?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool0
1@3o0000oooo0?ooo`3oool0o`0000D0oooo00D0o`000?ooo`3oool0oooo
0?l000050?ooo`050?l0003oool0oooo0?ooo`3o00001`3oool00`3o0000
oooo0?l000080?ooo`030?l0003oool0oooo05T0oooo001R0?ooo`030000
003oool0oooo04`0oooo00@0o`000?ooo`000?l0003o0P3oool0103o0000
oooo0?ooo`3o000X0?ooo`030?l0003oool0oooo00@0oooo00<0o`000000
o`3oool00`3oool00`3o0000oooo0?l0001o0?ooo`030000003oool0oooo
04/0oooo0P3o00070?ooo`040?l0003oool0oooo0?l000H0oooo00D0o`00
0?ooo`3oool0oooo0?l000040?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0o`0000D0oooo
00D0o`000?ooo`3oool0oooo0?l000070?ooo`030?l0003oool0o`0000P0
oooo00<0o`000?ooo`3oool0F@3oool00680oooo00<000000?ooo`3oool0
C03oool00`3o0000003o0?ooo`040?ooo`80o`00:@3oool00`3o0000oooo
0?ooo`050?ooo`030?l000000?l0oooo0080oooo00<0o`000?ooo`3o0000
O`3oool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3o00001P3oool0103o0000oooo0?ooo`3o00060?ooo`05
0?l0003oool0oooo0?ooo`3o0000103oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`3o00001`3oool0
0`3o0000oooo0?l000080?ooo`030?l0003oool0oooo05T0oooo001R0?oo
o`030000003oool0oooo04`0oooo00<0003o0?ooo`3oool0103oool20?l0
0340oooo00D0o`000?ooo`000?l0oooo0?l000020?ooo`030?l0003oool0
oooo07d0oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0o`0000H0oooo00@0o`000?ooo`3oool0o`001@3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool00`3oool01@3o0000oooo0?oo
o`3oool0o`0000H0oooo00@0o`000?ooo`3oool0o`00203oool00`3o0000
oooo0?ooo`1I0?ooo`00HP3oool00`000000oooo0?ooo`1;0?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0;`3oool01@3o0000oooo
0?ooo`000?l0o`000080oooo00<0o`000?ooo`3oool0O@3oool00`000000
oooo0?ooo`110?ooo`030?l0003oool0oooo00H0oooo00@0o`000?ooo`3o
ool0o`001P3oool0103o0000oooo0?ooo`3o00050?ooo`030?l0003oool0
oooo0080oooo00@0o`000?ooo`3oool0oooo3@000?l30?ooo`030?l0003o
ool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`040?l0
003oool0oooo0?l000L0oooo0P3o001K0?ooo`00HP3oool00`000000oooo
0?ooo`1;0?ooo`030000o`3oool0oooo03P0oooo00D0o`000?ooo`3oool0
oooo0000o`030?ooo`030?l0003oool0oooo07`0oooo00<000000?ooo`3o
ool0@@3oool00`3o0000oooo0?ooo`060?ooo`040?l0003oool0oooo0?l0
00H0oooo00@0o`000?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`02
0?ooo`060?l000000?l0003o0000o`3oool0o`00103oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0003o00<0003o103oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool0
o`001`3oool20?l005/0oooo001R0?ooo`030000003oool0oooo04<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0o`000?ooo`0j0?ooo`050?l0
003oool0oooo0?l000000?l00P3oool00`3o0000oooo0?ooo`1Y0?ooo`80
0000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0440
oooo00<0o`000?ooo`3oool01P3oool0103o0000oooo0?ooo`3o00060?oo
o`040?l0003oool0oooo0?l000D0oooo00<0o`000?ooo`000?l00`000?l4
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`030?ooo`<0003o00<0oooo0?l0003oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`040?l0003oool0oooo0?l000L0oooo0P3o
001K0?ooo`00HP3oool00`000000oooo0?ooo`130?ooo`80o`00103oool0
0`000?l0oooo0?l0000k0?ooo`030?l0003oool0o`000080oooo00<0003o
0?ooo`3o0000JP3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0@03oool20?l000P0oooo
00@0o`000?ooo`3oool0o`001P3oool0103o0000oooo0?ooo`3o00050?oo
o`80003o0`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo0080003o103oool00`3o0000oooo0?ooo`040?oo
o`040?l0003oool0oooo0?l000L0oooo00<0o`000?ooo`3o0000FP3oool0
0500oooo0P0000040?ooo`800000103oool2000000@0oooo00<000000?oo
o`3oool0@`3oool20?l000<0oooo00@0003o0?ooo`3oool0o`00>`3oool0
0`3o0000oooo0?l000030?ooo`030000o`3o0000oooo06T0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`<00000@03o
ool00`3o0000oooo0?l000070?ooo`040?l0003oool0oooo0?l000D0oooo
00D0o`000?ooo`3oool0oooo0?l000030?ooo`80003o00<0o`000?ooo`3o
ool00P3oool01@3o0000oooo0?ooo`3oool0o`0000D0oooo00D0o`000?oo
o`3oool0oooo0?l000060?ooo`050?l0003oool0oooo0?ooo`3o00000P00
0?l20?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool0o`00
1`3oool00`3o0000oooo0?l0001J0?ooo`00C`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0@P3oool01P3o0000oooo0?ooo`3o0000oooo0000o`<0oooo00<0o`00
0?ooo`3oool0>@3oool00`3o0000oooo0?l000030?ooo`030000o`3oool0
o`0006<0oooo100000020?ooo`040000003oool0oooo000000T0oooo0P00
00050?ooo`030000003oool0oooo0400oooo00<0o`000?ooo`3o00001`3o
ool0103o0000oooo0?ooo`3o00050?ooo`050?l0003oool0oooo0?ooo`3o
00000`000?l20?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3o
ool0oooo0?l000050?ooo`050?l0003oool0oooo0?ooo`3o00001P3oool0
1@3o0000oooo0?ooo`3oool0o`000080oooo0P000?l00`3o0000oooo0?oo
o`040?ooo`040?l0003oool0oooo0?l000L0oooo00<0o`000?ooo`3o0000
2@3oool00`3o0000oooo0?ooo`1>0?ooo`00C`3oool010000000oooo0?oo
o`00000;0?ooo`040000003oool0oooo0?ooo`<00000@P3oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool0>P3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3o0000oooo06P0oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0400oooo00<0o`000?ooo`3o00001`3oool0103o0000oooo0?ooo`3o
00050?ooo`030?l0003oool0oooo0080003o00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o0000
1P3oool0103o0000oooo0?ooo`3o00060?ooo`050?l0003oool0oooo0?oo
o`3o0000103oool20000o`@0oooo00D0o`000?ooo`3oool0oooo0?l00006
0?ooo`040?l0003oool0oooo0?l000T0oooo00<0o`000?ooo`3oool0CP3o
ool004T0oooo100000020?ooo`040000003oool0oooo000000T0oooo0P00
00040?ooo`030000003oool0oooo0480oooo00H0o`000?ooo`3oool0003o
0?ooo`3o00020?ooo`030?l0003oool0oooo03/0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0640
oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`100?ooo`03
0?l0003oool0o`0000H0oooo00D0o`000?ooo`3oool0oooo0?l000050?oo
o`030?l000000?l0003o0080oooo00D0o`000?ooo`3oool0oooo0?l00005
0?ooo`050?l0003oool0oooo0?ooo`3o00001P3oool0103o0000oooo0?oo
o`3o00060?ooo`040?l0003oool0oooo0?l000H0oooo00<0o`000000o`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0
oooo00@0o`000?ooo`3oool0o`002@3oool00`3o0000oooo0?ooo`1>0?oo
o`00C`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0@P3oool00`3o0000oooo0000o`030?oo
o`030?l0003oool0o`0004@0oooo00<0o`000000o`3oool0103oool00`3o
0000oooo0?ooo`1d0?ooo`030000003oool0oooo03L0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?l000060?ooo`050?l0003oool0oooo
0?ooo`3o00001@3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`3o00001P3oool0103o0000oooo0?ooo`3o00060?ooo`040?l0
003oool0oooo0?l000H0oooo00@0o`000?ooo`3oool0o`001P3oool01P3o
0000oooo0000o`000?l0oooo0?l000@0oooo00<0o`000?ooo`3oool00`3o
ool0103o0000oooo0?ooo`3o00080?ooo`80o`00D03oool00500oooo0P00
000:0?ooo`<000000`3oool00`000000oooo0?ooo`120?ooo`030?l0003o
ool0003o00@0oooo0P3o00150?ooo`030?l000000?l0oooo0080oooo0P3o
001f0?ooo`030000003oool0oooo03L0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?l000060?ooo`050?l0003oool0oooo0?ooo`3o0000
103oool00`000?l0o`000?ooo`030?ooo`050?l0003oool0oooo0?ooo`3o
00001P3oool0103o0000oooo0?ooo`3o00060?ooo`040?l0003oool0oooo
0?l000H0oooo00@0o`000?ooo`3oool0o`001P3oool0103o0000oooo0?oo
o`3oool20000o`@0oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo
0?ooo`3o00080?ooo`80o`00D03oool00680oooo00<000000?ooo`3oool0
@@3oool00`3o0000oooo0000o`060?ooo`030?l0003oool0oooo04<0oooo
00<0o`000?ooo`000?l00P3oool00`3o0000oooo0?l0001e0?ooo`030000
003oool0oooo03L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?l000060?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool20000o`03
0?ooo`3o0000oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l000060?oo
o`040?l0003oool0oooo0?l000H0oooo00@0o`000?ooo`3oool0o`001P3o
ool0103o0000oooo0?ooo`3o00060?ooo`030?l0003oool0oooo0080oooo
00<0o`000000o`000?l00P3oool00`3o0000oooo0?ooo`030?ooo`040?l0
003oool0oooo0?l000P0oooo0P3o001@0?ooo`00HP3oool00`000000oooo
0?ooo`110?ooo`030?l000000?l0oooo04`0oooo00P0o`000?ooo`3oool0
003o0?ooo`3o0000oooo0?l007D0oooo00<000000?ooo`3oool0=`3oool0
0`3o0000oooo0?ooo`060?ooo`030?l0003oool0o`0000H0oooo00L0o`00
0?ooo`3oool0oooo0?l0003oool0003o00<0oooo00<0o`000?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0o`0000H0oooo00@0o`000?ooo`3o
ool0o`001P3oool0103o0000oooo0?ooo`3o00060?ooo`040?l0003oool0
oooo0?l000H0oooo00<0o`000?ooo`3oool00P3oool01P3o0000oooo0?oo
o`000?l0oooo0?l000D0oooo00@0o`000?ooo`3oool0o`00203oool20?l0
0500oooo001R0?ooo`030000003oool0oooo0440oooo00<0003o0?ooo`3o
ool0C@3oool01`3o0000oooo0?ooo`000?l0o`000?ooo`3o0000M@3oool0
0`000000oooo0?ooo`0g0?ooo`030?l0003oool0oooo00D0oooo00@0o`00
0?ooo`3oool0o`001P3oool0103o0000oooo0?ooo`3oool20000o`<0oooo
00<0o`000?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0o`0000H0
oooo00<0o`000?ooo`3o00001`3oool00`3o0000oooo0?l000070?ooo`04
0?l0003oool0oooo0?l000H0oooo00D0o`000?ooo`3oool0oooo0?l00004
0?ooo`030000o`3o0000oooo00@0oooo00@0o`000?ooo`3oool0o`00203o
ool20?l00500oooo001R0?ooo`030000003oool0oooo0400oooo00<0003o
0?l0003oool0CP3oool0103o0000oooo0?ooo`000?l20?ooo`030?l0003o
ool0oooo07<0oooo00<000000?ooo`3oool0=P3oool20?l000L0oooo00@0
o`000?ooo`3oool0o`001@3oool01`3o0000oooo0?ooo`3oool0003o0?oo
o`3o00000`3oool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo
0?l000L0oooo00<0o`000?ooo`3o00001`3oool00`3o0000oooo0?l00007
0?ooo`040?l0003oool0oooo0?l000H0oooo00D0o`000?ooo`3oool0oooo
0?l000050?ooo`80003o0`3oool01@3o0000oooo0?ooo`3oool0o`0000L0
oooo00<0o`000?ooo`3o0000D03oool00680oooo00<000000?ooo`3oool0
?`3oool00`000?l0oooo0?l0001?0?ooo`050?l0003oool0oooo0?l00000
0?l00P3oool00`3o0000oooo0?ooo`1b0?ooo`030000003oool0oooo03H0
oooo00<0o`000?ooo`3o00001P3oool0103o0000oooo0?ooo`3o00050?oo
o`040?l0003oool0oooo0000o`80oooo00D0o`000?ooo`3oool0oooo0?l0
00050?ooo`040?l0003oool0oooo0?l000L0oooo00<0o`000?ooo`3o0000
1`3oool00`3o0000oooo0?l000070?ooo`030?l0003oool0o`0000L0oooo
00D0o`000?ooo`3oool0oooo0?l000050?ooo`030?l0003oool0003o0080
oooo00D0o`000?ooo`3oool0oooo0?l000070?ooo`040?l0003oool0oooo
0?l004l0oooo001R0?ooo`030000003oool0oooo03P0oooo00<0o`000?oo
o`3oool00`3oool010000?l0oooo0?ooo`3o001@0?ooo`070?l0003oool0
o`000?ooo`000?l0oooo0?l0001d0?ooo`030000003oool0oooo03H0oooo
00<0o`000?ooo`3o00001P3oool01@3o0000oooo0?ooo`3oool0o`0000@0
oooo00<0o`000000o`000?l00`3oool01@3o0000oooo0?ooo`3oool0o`00
00D0oooo00@0o`000?ooo`3oool0o`001`3oool00`3o0000oooo0?l00007
0?ooo`030?l0003oool0o`0000L0oooo00<0o`000?ooo`3o00001`3oool0
1@3o0000oooo0?ooo`3oool0o`0000D0oooo00<0o`000?ooo`3oool00P00
0?l00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00@0
o`000?ooo`3oool0o`00203oool00`3o0000oooo0?ooo`140?ooo`00HP3o
ool00`000000oooo0?ooo`0h0?ooo`80o`00103oool00`000?l0oooo0?l0
001A0?ooo`030?l0003oool0o`000080oooo00<0003o0?l0003oool0L`3o
ool00`000000oooo0?ooo`0f0?ooo`030?l0003oool0o`0000H0oooo00D0
o`000?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo00<0oooo
00D0o`000?ooo`3oool0oooo0?l000050?ooo`040?l0003oool0oooo0?l0
00L0oooo00<0o`000?ooo`3o00001`3oool00`3o0000oooo0?l000070?oo
o`030?l0003oool0o`0000L0oooo00D0o`000?ooo`3oool0oooo0?l00005
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`040?ooo`040?l0003oool0oooo0?l000P0oooo00<0
o`000?ooo`3oool0A03oool00680oooo00<000000?ooo`3oool0>03oool0
0`3o0000oooo0?l000020?ooo`040000o`3oool0oooo0?l00540oooo0P3o
00030?ooo`030000o`3o0000oooo07<0oooo00<000000?ooo`3oool0;@3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0o`0000H0oooo00D0
o`000?ooo`3oool0oooo0?l000030?ooo`030000o`3o0000oooo00@0oooo
00D0o`000?ooo`3oool0oooo0?l000050?ooo`040?l0003oool0oooo0?l0
00L0oooo00<0o`000?ooo`3o00001`3oool00`3o0000oooo0?l000070?oo
o`030?l0003oool0o`0000L0oooo00@0o`000?ooo`3oool0o`001P3oool0
0`3o0000oooo0?ooo`020?ooo`030?l000000?l0oooo0080oooo00<0o`00
0?ooo`3oool0103oool0103o0000oooo0?ooo`3o00080?ooo`030?l0003o
ool0oooo04@0oooo001R0?ooo`030000003oool0oooo03P0oooo00H0o`00
0?ooo`3oool0o`000?ooo`000?l20?ooo`030?l0003oool0oooo0500oooo
00<0o`000?ooo`3oool00P3oool00`000?l0o`000?ooo`1b0?ooo`050000
003oool0oooo0?ooo`3o0000:`3oool00`3o0000oooo0?ooo`060?ooo`03
0?l0003oool0o`0000H0oooo00D0o`000?ooo`3oool0oooo0?l000020?oo
o`030000o`3oool0o`0000D0oooo00@0o`000?ooo`3oool0o`001P3oool0
103o0000oooo0?ooo`3o00070?ooo`030?l0003oool0o`0000P0oooo0P3o
00080?ooo`80o`001`3oool0103o0000oooo0?ooo`3o00060?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`000?l00P3oool00`3o0000oooo
0?ooo`030?ooo`050?l0003oool0oooo0?ooo`3o00001`3oool20?l004H0
oooo001R0?ooo`030000003oool0oooo01/0oooo1@0000020?ooo`800000
4`3oool00`3o0000oooo0?ooo`020?ooo`060000o`3oool000000000003o
000000000`3oool2000001X0oooo0P0000040?ooo`800000703oool30000
0080oooo0P0000070?ooo`030?l0003oool0oooo0080oooo00<0003o0?l0
003oool0303oool2000000@0oooo0P00000J0?ooo`<00000103oool20000
03/0oooo00D000000?ooo`3oool0oooo0?l0000[0?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3o00001P3oool01`3o0000oooo0?ooo`3o
ool0o`000?ooo`000?l00P3oool00`3o0000oooo0?ooo`030?ooo`040?l0
003oool0oooo0?l000H0oooo00<0o`000?ooo`3o00002@3oool20?l000P0
oooo0P3o00080?ooo`80o`001`3oool0103o0000oooo0?ooo`3o00070?oo
o`050?l0003oool0oooo0?ooo`3o00000P3oool00`000?l0oooo0?l00005
0?ooo`050?l0003oool0oooo0?ooo`3o00001`3oool20?l004H0oooo001R
0?ooo`030000003oool0oooo01d0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0100oooo00X0o`000?ooo`3oool0oooo
0000o`3oool0o`000000003oool0o`000`3oool010000000oooo0?ooo`00
000H0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000703oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00X0oooo00<0003o0?ooo`3oool02P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000001T0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000j0?ooo`050000003oool0oooo0?oo
o`3o0000:`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0o`00
00H0oooo00H0o`000?ooo`3oool0oooo0?l000000?l30?ooo`030?l0003o
ool0oooo00<0oooo00@0o`000?ooo`3oool0o`001P3oool00`3o0000oooo
0?l000090?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool20?l000L0oooo00@0o`000?ooo`3oool0o`001`3oool0103o0000
oooo0?ooo`3o00040?ooo`030000o`3o0000oooo00@0oooo00D0o`000?oo
o`3oool0oooo0?l000070?ooo`80o`00AP3oool00680oooo00<000000?oo
o`3oool07@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0403oool0103o0000oooo0?ooo`000?l20?ooo`030?l0003o
ool0o`0000@0oooo00@000000?ooo`3oool000006P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool05`3oool500000005
0?ooo`000000oooo0?ooo`000000303oool00`3o0000003o0?ooo`040?oo
o`030?l0003oool0oooo00H0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0G0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000>P3oool01@000000oooo0?ooo`3oool0o`0001P0
oooo1@0000020?ooo`8000002P3oool00`3o0000oooo0?ooo`050?ooo`04
0?l0003oool0oooo0?l000<0oooo0P000000103o000000000?ooo`3oool2
0000o`040000003oool0oooo0?l000H0oooo00@0o`000?ooo`3oool0o`00
1`3oool20?l000D0oooo0P0000020?ooo`040?l0003oool00000000000H0
oooo00<0o`000?ooo`3oool01`3oool20?l000L0oooo00D0o`000?ooo`00
0000o`00000000020?ooo`8000000P3oool0103o0000oooo0?ooo`3o0005
0?ooo`80003o103oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo0P00
0000103oool0o`000?l0003oool2000001T0oooo0`0000040?ooo`800000
8@3oool00680oooo00<000000?ooo`3oool07@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0403oool0103o0000oooo
0?ooo`000?l30?ooo`80o`0000D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo01T0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0G0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000003@3oool00`3o0000003o0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo0P0000030?ooo`040000003oool0oooo000001T0
oooo0`0000030?ooo`040000003oool0oooo000003X0oooo00@000000?oo
o`3oool0oooo0P3o000I0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`060?ooo`80o`001`3oool0103o0000oooo0?oo
o`3o00030?ooo`030000003oool0o`000080oooo00L0003o0000003o0000
oooo0000003oool0o`0000H0oooo00@0o`000?ooo`3oool0o`001`3oool2
0?l000@0oooo00L000000?ooo`3oool000000?ooo`3o000000000080oooo
00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00@0o`000?ooo`3oool0o`000P3oool01P000000
oooo0?ooo`000000oooo0?l00080oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`3o00000`3o
ool010000000oooo0?ooo`0000020?l000040000003oool0oooo000001P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000P
0?ooo`00HP3oool00`000000oooo0?ooo`0M0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0
003o00@0oooo00@000000?l0003oool000000P3oool010000000oooo0?oo
o`00000H0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000006P3oool00`000000oooo000000020?ooo`040000003oool0oooo
000000d0oooo00<0o`000?ooo`000?l00P3oool00`3o0000oooo0?l00005
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000006P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000003X0oooo
00@000000?ooo`3oool0oooo0P3o000I0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`060?ooo`80o`001`3oool0103o
0000oooo0?ooo`3o00040?ooo`0;0000003o0000oooo0000o`3oool00000
0?l0003oool000000?ooo`3o00001P3oool0103o0000oooo0?ooo`3o0007
0?ooo`80o`001P3oool01@000000oooo0?ooo`3o000000000080oooo00<0
00000?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo00<000000?l0003o00000P0000001`3oool000000?oo
o`3oool000000?ooo`3o00000P3oool00`3o0000oooo0?ooo`030?ooo`06
0?l0003oool0oooo0000o`3oool0o`00103oool00`3o0000oooo0?ooo`04
0?ooo`040?l0003oool0o`0000000080oooo00<000000?ooo`3oool05P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000200
oooo001R0?ooo`030000003oool0oooo01`0oooo0P0000040?ooo`800000
4`3oool00`3o0000003o0?ooo`050?ooo`800000103oool2000001X0oooo
0P0000040?ooo`800000703oool2000000<0oooo0P00000>0?ooo`080?l0
003oool0oooo0000o`3oool0o`000?ooo`3o00050?ooo`<000000`3oool2
000001/0oooo0`0000030?ooo`800000>`3oool010000000oooo0?ooo`3o
ool20?l001T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00H0oooo0P3o00070?ooo`040?l0003oool0oooo0?l000D0
oooo00X0o`000000o`3oool0oooo0000003o0000oooo0000003oool0o`00
1P3oool0103o0000oooo0?ooo`3o00070?ooo`80o`001`3oool010000000
oooo0?l0000000020?ooo`030000003oool0oooo00d0oooo00<0o`000?oo
o`3oool01P3oool010000000o`000?l0000000020?ooo`060000003oool0
oooo0000003oool0o`000P3oool00`3o0000oooo0?ooo`030?ooo`060?l0
003oool0oooo0?ooo`000?l0o`00103oool00`3o0000oooo0?ooo`020?oo
o`80000000@0o`000?ooo`3oool0o`000P3oool00`000000oooo0?ooo`03
0?ooo`030?l0003oool0oooo0100oooo0`0000030?ooo`040000003oool0
oooo00000200oooo001R0?ooo`030000003oool0oooo03L0oooo00<0003o
0?ooo`3oool0H@3oool01`3o0000oooo0?ooo`000?l0o`000?ooo`3o0000
J`3oool010000000oooo0?ooo`3oool20?l001T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00H0oooo00<0o`000?oo
o`3o00001P3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00@00000
0?ooo`000?l000000P3oool01P000000o`000?ooo`000000oooo0?l000H0
oooo00<0o`000?ooo`3o0000203oool00`3o0000oooo0?ooo`030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000003`3oool0
0`3o0000oooo0?ooo`070?ooo`80o`0000@000000?ooo`3oool000000P3o
ool00`000000oooo0?l000020?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00<000000?ooo`3o00000P3oool0103o0000oooo0?oo
o`0000050?ooo`030?l0003oool0oooo0140oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000P0?ooo`00HP3oool00`000000oooo
0?ooo`0f0?ooo`030000o`3oool0oooo0680oooo00D0o`000?ooo`3oool0
003o0?l000020?ooo`030?l0003oool0oooo06P0oooo00@000000?ooo`3o
ool0oooo0P3o000H0?ooo`800000103oool2000000030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3o00001P3oool01@3o0000oooo0?ooo`3oool0
o`0000<0oooo00<0003o0?l0003oool00`3oool01@000000o`000?ooo`3o
ool0o`0000H0oooo00<0o`000?ooo`3o0000203oool00`3o0000oooo0?oo
o`040?ooo`800000103oool2000001X0oooo0P3o000010000000oooo0?oo
o`3oool200000080oooo00@0o`000?ooo`3oool0o`001@3oool00`3o0000
oooo0?ooo`020?ooo`030?l000000?l0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool2000000040?l0003oool0oooo0?l0008000001P3oool00`3o
0000oooo0?ooo`0A0?ooo`<000000`3oool200000240oooo001R0?ooo`03
0000003oool0oooo03H0oooo00<0003o0?ooo`3oool0HP3oool01@3o0000
oooo0?ooo`3o0000003o0080oooo00<0o`000?ooo`3oool0J03oool01P00
0000oooo0?ooo`3o0000oooo0?l00200oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?l000060?ooo`050?l0003oool0oooo0?ooo`3o0000
0P3oool00`000?l0oooo0?l000050?ooo`040?l0003oool0oooo0?l000L0
oooo0P3o00080?ooo`030?l0003oool0oooo02H0oooo0P3o00080?ooo`03
0?l0003oool0o`0000L0oooo00H0o`000?ooo`3oool0oooo0?l0003oool2
0000o`030?ooo`3o0000oooo00D0oooo00@0o`000?ooo`3oool0o`00203o
ool00`3o0000oooo0?ooo`0j0?ooo`00HP3oool00`000000oooo0?ooo`0e
0?ooo`030000o`3o0000oooo06<0oooo00D0o`000?ooo`3oool0o`000000
o`020?ooo`030?l0003oool0oooo0480oooo0P0000020?ooo`800000803o
ool01P000000oooo0?ooo`3o0000oooo0?l00200oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?l000060?ooo`070?l0003oool0oooo0?oo
o`3o0000oooo0000o`020?ooo`030?l0003oool0oooo00<0oooo00@0o`00
0?ooo`3oool0o`001`3oool20?l000P0oooo00<0o`000?ooo`3oool09P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0o`0000L0oooo00D0
o`000?ooo`3oool0oooo0?l000030?ooo`030000o`3o0000oooo00@0oooo
00D0o`000?ooo`3oool0oooo0?l000070?ooo`80o`00?03oool00680oooo
00<000000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0o`0006D0oooo00L0o`000?ooo`3o0000oooo0000o`3oool0o`00
04D0oooo00@000000?ooo`3oool000008@3oool01P000000oooo0?ooo`3o
0000oooo0?l00200oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?l000060?ooo`060?l0003oool0oooo0?ooo`3o0000003o0`3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0o`0000P0oooo0P3o000a0?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o00001`3oool0103o
0000oooo0?ooo`3o00050?ooo`030000o`3oool0oooo00<0oooo00D0o`00
0?ooo`3oool0oooo0?l000070?ooo`80o`00?03oool00680oooo<@000002
0?l000<0000000@0003o000000000000o`00I@0000000`3o000000000?l0
0002000000030000o`000000o`0003`00000203oool010000000oooo0?oo
o`00000Q0?ooo`040000003oool0oooo0?l00080oooo00<0o`000?ooo`3o
ool0703oool20?l000P0oooo00<0o`000?ooo`3o00001@3oool0103o0000
oooo0?ooo`3oool20000o`<0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?l000080?ooo`80o`00<@3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0o`0000L0oooo00@0o`000?ooo`3oool0o`001@3oool0
0`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`3o00001`3o
ool20?l00300oooo0P0000020?ooo`8000001P3oool00680oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`80o`000`3oool0
10000?l0oooo0?ooo`3o000<0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0A0?ooo`80o`00103o
ool00`000?l0o`000?ooo`060?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool05P3oool400000280oooo00@000000?ooo`3oool0o`00
0P3oool00`3o0000oooo0?ooo`0L0?ooo`80o`001`3oool0103o0000oooo
0?ooo`3o00050?ooo`060?l0003oool0oooo0000o`3oool0o`000`3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0o`0000P0oooo00<0o`00
0?ooo`3oool0>`3oool20?l000L0oooo00@0o`000?ooo`3oool0o`001P3o
ool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o0000
1`3oool20?l000T0oooo00<0o`000?ooo`3oool09@3oool010000000oooo
0?ooo`0000070?ooo`00HP3oool00`000000oooo0?ooo`0]0?ooo`060?l0
003oool0oooo0?l0003oool0003o0`3oool00`3o0000oooo0?ooo`1T0?oo
o`030?l0003oool0oooo0080oooo00<0003o0?l0003oool0J03oool30000
00040?l00000000000000?l001h000000P3o0007000000040?l000000000
00000?l000D0000000<0o`00000000000?l00P0000001@3o000000000000
00000000o`0000H0000000<0o`000000003o0000200000000`3o00000000
0000000k00000080o`001`000000103o000000000000003o000600000003
0?l000000?l000000080000000D0o`0000000000000000000?l000070000
0080o`002@0000000`3o000000000000000M000000P0oooo00@000000?oo
o`3oool000001`3oool00680oooo00<000000?ooo`3oool0;@3oool01@3o
0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool0I@3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3o0000oooo06L0oooo00@00000
0?ooo`3oool0o`000P3oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3o00070?ooo`040?l0003o
ool0oooo0?l000D0oooo00<0o`000000o`3oool00P3oool01@3o0000oooo
0?ooo`3oool0o`0000<0oooo00H000000?ooo`3oool0o`000?ooo`3o0008
0?ooo`030?l0003oool0oooo0180oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`040?ooo`80o`001`3oool0103o0000oooo0?ooo`3o
00060?ooo`050?l0003oool0003o0?ooo`3o00000`3oool00`000000o`00
0?ooo`060?ooo`030?l0003oool0o`0000P0oooo00<0o`000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0F0?ooo`@00000203oool00680oooo00<0
00000?ooo`3oool0;@3oool01P3o0000oooo0?ooo`000?l0oooo0?l00080
oooo00<0o`000?ooo`3oool0K03oool00`000?l0oooo0?ooo`1V0?ooo`04
0000003oool0oooo0?l00080oooo00<0o`000?ooo`3oool04`3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0o`0000H0oooo00@0o`000?oo
o`3oool0o`001@3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`3o00001P3oool00`3o0000oooo0?l000080?ooo`030?l0003o
ool0oooo03/0oooo00<0o`000?ooo`3oool01P3oool0103o0000oooo0?oo
o`3o00060?ooo`050?l0003oool0oooo0000o`3o0000103oool00`3o0000
oooo0?ooo`040?ooo`040?l0003oool0oooo0?l000P0oooo00<0o`000?oo
o`3oool0<03oool00680oooo00<000000?ooo`3oool0;@3oool0103o0000
oooo0?ooo`000?l20?ooo`<0o`00KP3oool00`3o0000003o0?ooo`040?oo
o`030?l0003oool0oooo05l0oooo00@000000?ooo`3oool0o`000P3oool0
0`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3o00001P3oool0103o0000oooo0?ooo`3o00040?ooo`030000o`3o
0000oooo00@0oooo00@0o`000?ooo`3oool0o`001P3oool00`3o0000oooo
0?l000160?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o0000
1`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3o
ool0103oool0103o0000oooo0?ooo`3o00070?ooo`80o`00<P3oool00680
oooo00<000000?ooo`3oool0;@3oool00`3o0000oooo0000o`050?ooo`03
0?l0003oool0oooo06`0oooo00<0o`000000o`3oool0103oool00`3o0000
oooo0?ooo`1O0?ooo`040000003oool0oooo0?l00080oooo00<0o`000?oo
o`3oool04`3oool00`3o0000oooo0?ooo`050?ooo`040?l0003oool0oooo
0?l000H0oooo00@0o`000?ooo`3oool0o`000P3oool20000o`030?ooo`3o
0000oooo00@0oooo00@0o`000?ooo`3oool0o`001P3oool00`3o0000oooo
0?l000160?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o0000
1`3oool01P3o0000oooo0?ooo`3oool0o`000000o`<0oooo00<0o`000?oo
o`3oool0103oool0103o0000oooo0?ooo`3o00070?ooo`80o`00<P3oool0
0680oooo00<000000?ooo`3oool0;03oool0103o0000oooo0?ooo`000?me
0?ooo`030?l000000?l0oooo0080oooo0P3o001Q0?ooo`040000003oool0
oooo0?l00080oooo00<0o`000?ooo`3oool04P3oool20?l000L0oooo00@0
o`000?ooo`3oool0o`001P3oool01P3o0000oooo0?ooo`3o0000oooo0000
o`<0oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo0?ooo`3o0007
0?ooo`80o`00AP3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
o`0000L0oooo00H0o`000?ooo`3oool0oooo0?l0003oool20000o`030?oo
o`3o0000oooo00D0oooo00@0o`000?ooo`3oool0o`001`3oool20?l000X0
oooo00<0o`000?ooo`3oool09@3oool00680oooo00<000000?ooo`3oool0
;03oool00`3o0000oooo0000o`1f0?ooo`030?l0003oool0003o0080oooo
00<0o`000?ooo`3o0000H03oool010000000oooo0?ooo`3o00030?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool20?l000L0
oooo00@0o`000?ooo`3oool0o`001P3oool01@3o0000oooo0?ooo`3o0000
003o00<0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?l00008
0?ooo`030?l0003oool0oooo04h0oooo00<0o`000?ooo`3o00001`3oool0
1@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0003o0?l0003oool01@3o
ool0103o0000oooo0?ooo`3o00070?ooo`030?l0003oool0o`0000T0oooo
00<0o`000?ooo`3oool09@3oool00680oooo00<000000?ooo`3oool0;03o
ool00`3o0000003o0?ooo`1f0?ooo`080?l0003oool0oooo0000o`3oool0
o`000?ooo`3o001P0?ooo`040000003oool0oooo0?l000<0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`80o`001`3oool0
103o0000oooo0?ooo`3o00060?ooo`040?l0003oool0oooo0000o`@0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?l000080?ooo`030?l0
003oool0oooo04l0oooo0P3o00070?ooo`040?l0003oool0oooo0?l000D0
oooo00<0003o0?ooo`3oool0103oool0103o0000oooo0?ooo`3o00070?oo
o`030?l0003oool0o`0000T0oooo00<0o`000?ooo`3oool09@3oool00680
oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`1f0?ooo`05
0?l0003oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`1N0?oo
o`040000003oool0oooo0?l000<0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`80o`001`3oool0103o0000oooo0?ooo`3o
00050?ooo`060?l0003oool0oooo0000o`3oool0o`000`3oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0o`0000P0oooo00<0o`000?ooo`3o
ool0C`3oool20?l000L0oooo00@0o`000?ooo`3oool0o`001P3oool00`00
0?l0oooo0?ooo`030?ooo`040?l0003oool0oooo0?l000L0oooo00<0o`00
0?ooo`3o0000203oool20?l000T0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`0A0?ooo`00HP3oool00`000000oooo0?ooo`0[0?oo
o`030000o`3o0000oooo07P0oooo00@0o`000?ooo`3oool0003o0P3oool0
0`3o0000oooo0?ooo`1N0?ooo`040000003oool0oooo0?l000<0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0o`0000H0oooo00@0o`000?ooo`3oool0o`001@3oool00`3o0000oooo
0000o`020?ooo`050?l0003oool0oooo0?ooo`3o00001P3oool00`3o0000
oooo0?l000080?ooo`030?l0003oool0oooo04l0oooo0P3o00070?ooo`04
0?l0003oool0oooo0?l000H0oooo00<0o`000000o`3oool00P3oool01@3o
0000oooo0?ooo`3oool0o`0000L0oooo00<0o`000?ooo`3o0000203oool2
0?l000T0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0A
0?ooo`00HP3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0o`00
07T0oooo00D0o`000?ooo`3oool0o`000000o`020?ooo`030?l0003oool0
oooo05d0oooo00@000000?ooo`3oool0o`000`3oool00`3o0000oooo0?oo
o`060?ooo`80o`002@3oool00`3o0000oooo0?l000060?ooo`040?l0003o
ool0oooo0?l000D0oooo00<0o`000000o`3oool00P3oool01@3o0000oooo
0?ooo`3oool0o`0000H0oooo00<0o`000?ooo`3o0000203oool00`3o0000
oooo0?ooo`1?0?ooo`030?l0003oool0oooo00H0oooo00@0o`000?ooo`3o
ool0o`001P3oool00`3o0000oooo0000o`020?ooo`050?l0003oool0oooo
0?ooo`3o00001P3oool0103o0000oooo0?ooo`3o00080?ooo`80o`002@3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0140oooo001R
0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?l0001j0?ooo`030?l0003oool0o`000080oooo00<0003o
0?ooo`3o0000G`3oool010000000oooo0?ooo`3o00030?ooo`030?l0003o
ool0oooo00H0oooo0P3o00080?ooo`040?l0003oool0oooo0?l000D0oooo
00D0o`000?ooo`3oool0oooo0?l000050?ooo`030?l000000?l0oooo0080
oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`030?l0003oool0o`00
05X0oooo00<0o`000?ooo`3oool01P3oool0103o0000oooo0?ooo`3o0006
0?ooo`030?l0003oool0oooo0080003o00D0o`000?ooo`3oool0oooo0?l0
00060?ooo`040?l0003oool0oooo0?l000P0oooo0P3o00080?ooo`80o`00
2@3oool00`3o0000oooo0?ooo`0A0?ooo`00HP3oool00`000000oooo0?oo
o`0S0?ooo`80o`00103oool00`000?l0oooo0?l0001j0?ooo`030?l0003o
ool0o`0000<0oooo00<0003o0?l0003oool0GP3oool00`000000oooo0?l0
00040?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o00001`3o
ool0103o0000oooo0?ooo`3o00050?ooo`050?l0003oool0oooo0?ooo`3o
00001@3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?oo
o`3o00001P3oool00`3o0000oooo0?l0001J0?ooo`030?l0003oool0oooo
00H0oooo00@0o`000?ooo`3oool0o`001P3oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o00001P3oool0103o0000oooo0?oo
o`3o00080?ooo`80o`00203oool20?l000P0oooo00<0o`000?ooo`3oool0
4P3oool00680oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?l0
00020?ooo`040000o`3oool0oooo0?l007/0oooo0P3o00030?ooo`030000
o`3o0000oooo05h0oooo00<000000?ooo`3o0000103oool00`3o0000oooo
0?ooo`060?ooo`030?l0003oool0o`0000L0oooo00@0o`000?ooo`3oool0
o`001@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo0P000?l00`3o
0000oooo0?ooo`020?ooo`040?l0003oool0oooo0?l000L0oooo00<0o`00
0?ooo`3o0000FP3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
o`0000L0oooo00<0o`000?ooo`3oool00P3oool01@3o0000003o0?ooo`3o
ool0o`0000H0oooo00@0o`000?ooo`3oool0o`00203oool20?l000P0oooo
0P3o00080?ooo`030?l0003oool0oooo0180oooo001R0?ooo`030000003o
ool0oooo02<0oooo00H0o`000?ooo`3oool0o`000?ooo`000?l20?ooo`03
0?l0003oool0oooo07T0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
o`000?ooo`1M0?ooo`030000003oool0o`0000@0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?l000070?ooo`040?l0003oool0oooo0?l0
00D0oooo00H0o`000?ooo`3oool0oooo0?l0003oool20000o`80oooo00<0
o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`3o00080?ooo`80o`00
H`3oool00`3o0000oooo0?l000070?ooo`030?l0003oool0oooo0080oooo
00D0o`000?ooo`000?l0oooo0?l000060?ooo`040?l0003oool0oooo0?l0
00L0oooo00@0o`000?ooo`3oool0o`001`3oool20?l000P0oooo00<0o`00
0?ooo`3oool04P3oool00680oooo00<000000?ooo`3oool08P3oool00`3o
0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000N`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo05`0oooo00<00000
0?ooo`3o0000103oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
o`0000L0oooo00@0o`000?ooo`3oool0o`001@3oool01P3o0000oooo0?oo
o`3oool0o`000000o`@0oooo00<0o`000?ooo`3oool00P3oool0103o0000
oooo0?ooo`3o00080?ooo`030?l0003oool0oooo06<0oooo0P3o00070?oo
o`050?l0003oool0oooo0?ooo`3o00000`3oool00`000?l0o`000?ooo`05
0?ooo`040?l0003oool0oooo0?l000L0oooo00@0o`000?ooo`3oool0o`00
1`3oool20?l000P0oooo00<0o`000?ooo`3oool04P3oool00680oooo00<0
00000?ooo`3oool08P3oool02@3o0000oooo0?ooo`3oool0003o0?ooo`3o
0000oooo0?l000230?ooo`030?l000000?l0oooo00@0oooo00<0o`000?oo
o`3oool0E@3oool00`000000oooo0?l000040?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3o00001`3oool0103o0000oooo0?ooo`3o0005
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?oo
o`030?ooo`040?l0003oool0oooo0?l000P0oooo00<0o`000?ooo`3oool0
H`3oool20?l000L0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`03
0000o`3oool0oooo00@0oooo00@0o`000?ooo`3oool0o`001`3oool0103o
0000oooo0?ooo`3o00070?ooo`030?l0003oool0o`0000L0oooo00<0o`00
0?ooo`3oool04P3oool00680oooo00<000000?ooo`3oool08P3oool0103o
0000oooo0?ooo`000?l30?ooo`80o`00Q03oool00`3o0000003o0?ooo`03
0?ooo`030?l0003oool0oooo05D0oooo00<000000?ooo`3o00001@3oool0
0`3o0000oooo0?ooo`050?ooo`030?l0003oool0o`0000H0oooo00D0o`00
0?ooo`3oool0oooo0?l000040?ooo`070?l0003oool0oooo0?ooo`000?l0
oooo0?l000030?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3o
ool0o`00203oool00`3o0000oooo0?ooo`1S0?ooo`80o`001`3oool01@3o
0000oooo0?ooo`3oool0o`0000D0oooo00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0o`0000L0oooo00@0o`000?ooo`3oool0o`00
1P3oool0103o0000oooo0?ooo`3o00070?ooo`030?l0003oool0oooo0180
oooo001R0?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`000?l0
1@3oool00`3o0000oooo0?ooo`220?ooo`030?l000000?l0oooo0080oooo
00<0o`000?ooo`3o0000EP3oool00`000000oooo0?l000050?ooo`030?l0
003oool0oooo00@0oooo00@0o`000?ooo`3oool0o`001P3oool01@3o0000
oooo0?ooo`3oool0o`0000@0oooo00@0o`000?ooo`3oool0003o0P3oool0
1@3o0000oooo0?ooo`3oool0o`0000D0oooo00@0o`000?ooo`3oool0o`00
203oool00`3o0000oooo0?ooo`1S0?ooo`80o`001`3oool01@3o0000oooo
0?ooo`3oool0o`0000D0oooo00<0o`000000o`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3o
ool0o`001P3oool0103o0000oooo0?ooo`3o00070?ooo`030?l0003oool0
oooo0180oooo001@0?ooo`800000103oool2000000@0oooo0P0000040?oo
o`030000003oool0oooo0280oooo00<0o`000000o`3oool0RP3oool00`3o
0000oooo0000o`020?ooo`030?l0003oool0o`0005H0oooo00<000000?oo
o`3o00001@3oool00`3o0000oooo0?ooo`040?ooo`040?l0003oool0oooo
0?l000H0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`030?l00000
0?l0003o00<0oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`030?l0
003oool0o`0000T0oooo00<0o`000?ooo`3oool0H`3oool20?l000L0oooo
00D0o`000?ooo`3oool0oooo0?l000050?ooo`060?l0003oool0003o0000
o`3oool0o`00103oool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0
oooo0?ooo`3o00001P3oool0103o0000oooo0?ooo`3o00070?ooo`030?l0
003oool0oooo0180oooo001?0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0R0?ooo`03
0000o`3oool0oooo08/0oooo00L0o`000?ooo`000?l0oooo0?l0003oool0
o`0005H0oooo00<000000?ooo`3o00001@3oool00`3o0000oooo0?ooo`04
0?ooo`040?l0003oool0oooo0?l000H0oooo00D0o`000?ooo`3oool0oooo
0?l000040?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0
oooo0?l000050?ooo`030?l0003oool0o`0006l0oooo00<0o`000?ooo`3o
ool01P3oool0103o0000oooo0?ooo`3o00060?ooo`040?l0003oool0oooo
0?ooo`80003o103oool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0
oooo0?ooo`3o00001P3oool0103o0000oooo0?ooo`3o00060?ooo`030?l0
003oool0oooo01<0oooo001?0?ooo`040000003oool0oooo000000/0oooo
00@000000?ooo`3oool0oooo0`00000Q0?ooo`030000o`3oool0oooo08`0
oooo00D0o`000?ooo`3oool0003o0?l000020?ooo`030?l0003oool0oooo
05<0oooo00<000000?ooo`3o00001@3oool00`3o0000oooo0?ooo`040?oo
o`040?l0003oool0oooo0?l000H0oooo00D0o`000?ooo`3oool0oooo0?l0
00020?ooo`80003o00<0o`000?ooo`3oool00`3oool01@3o0000oooo0?oo
o`3oool0o`0000D0oooo00<0o`000?ooo`3o0000K`3oool00`3o0000oooo
0?ooo`060?ooo`040?l0003oool0oooo0?l000H0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000003o0?ooo`020?ooo`030?l0003oool0oooo00<0
oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`040?l0003oool0oooo
0?l000H0oooo00<0o`000?ooo`3oool04`3oool004l0oooo00@000000?oo
o`3oool000002@3oool2000000@0oooo00<000000?ooo`3oool06@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo08`0oooo00@0o`00
0?ooo`3oool0003o0`3oool00`3o0000oooo0?ooo`1C0?ooo`030000003o
ool0o`0000D0oooo00<0o`000?ooo`3oool0103oool0103o0000oooo0?oo
o`3o00060?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0000o`020?oo
o`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool0o`001`3oool2
0?l006l0oooo00<0o`000?ooo`3oool01P3oool0103o0000oooo0?ooo`3o
00060?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`000?l00P3o
ool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`3o0000
1P3oool0103o0000oooo0?ooo`3o00060?ooo`030?l0003oool0oooo01<0
oooo001?0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0I0?ooo`80o`001@3oool00`000?l0
o`000?ooo`2=0?ooo`050?l0003oool0oooo0?l000000?l00`3oool00`3o
0000oooo0?ooo`1B0?ooo`030000003oool0o`0000D0oooo00<0o`000?oo
o`3oool0103oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0o`00
0?ooo`3oool00P3oool20000o`<0oooo00<0o`000?ooo`3oool00`3oool0
103o0000oooo0?ooo`3o00070?ooo`80o`00K`3oool00`3o0000oooo0?oo
o`060?ooo`040?l0003oool0oooo0?l000H0oooo00D0o`000?ooo`3oool0
oooo0?l000030?ooo`030000o`3oool0o`0000D0oooo00D0o`000?ooo`3o
ool0oooo0?l000050?ooo`050?l0003oool0oooo0?ooo`3o00001P3oool0
0`3o0000oooo0?ooo`0C0?ooo`00D03oool2000000X0oooo0`0000030?oo
o`030000003oool0oooo01T0oooo00<0o`000?ooo`3o00000`3oool00`00
0?l0oooo0?l0002?0?ooo`050?l0003oool0o`000?ooo`000?l00P3oool0
0`3o0000oooo0?ooo`1B0?ooo`030000003oool0o`0000D0oooo00<0o`00
0?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00L0
o`000?ooo`3oool0oooo0000o`3oool0o`0000<0oooo00<0o`000?ooo`3o
ool00`3oool0103o0000oooo0?ooo`3o00070?ooo`80o`00N@3oool00`3o
0000oooo0?l000060?ooo`050?l0003oool0oooo0?ooo`3o0000103oool2
0000o`D0oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`050?l0003o
ool0oooo0?ooo`3o00001P3oool00`3o0000oooo0?ooo`0C0?ooo`00HP3o
ool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0o`000080oooo00@0
003o0?ooo`3oool0o`00S`3oool00`3o0000oooo0?l000020?ooo`030000
o`3oool0o`0005@0oooo00<000000?ooo`3o00001@3oool00`3o0000oooo
0?ooo`040?ooo`050?l0003oool0oooo0?ooo`3o0000103oool0103o0000
oooo0000o`000?l20?ooo`040?l0003oool0oooo0?l000H0oooo00@0o`00
0?ooo`3oool0o`001`3oool20?l007T0oooo0P3o00070?ooo`050?l0003o
ool0oooo0?ooo`3o00001@3oool00`3o0000003o0000o`020?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool01@3o0000oooo
0?ooo`3oool0o`0000H0oooo00<0o`000?ooo`3oool04`3oool00680oooo
00<000000?ooo`3oool0603oool01`3o0000oooo0?ooo`3oool0o`000?oo
o`000?l00P3oool00`3o0000oooo0?ooo`2=0?ooo`80o`00103oool20000
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0=`3oool20000
00@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?l000050?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`80003o103oool0103o0000oooo0?ooo`3o0006
0?ooo`040?l0003oool0oooo0?l000L0oooo00<0o`000?ooo`3oool0N03o
ool20?l000L0oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`030?l0
003oool0oooo0080003o00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`030?ooo`050?l0003oool0oooo0?ooo`3o00001P3oool00`3o0000
oooo0?ooo`0C0?ooo`00HP3oool00`000000oooo0?ooo`0H0?ooo`030?l0
003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0002@0?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`0f0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?l000050?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0000o`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool0o`001P3o
ool0103o0000oooo0?ooo`3o00070?ooo`030?l0003oool0oooo07P0oooo
0P3o00070?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool00`3o0000
oooo0?ooo`020?ooo`80003o0`3oool00`3o0000oooo0?ooo`030?ooo`05
0?l0003oool0oooo0?ooo`3o00001P3oool00`3o0000oooo0?ooo`0C0?oo
o`00HP3oool00`000000oooo0?ooo`0H0?ooo`090?l0003oool0oooo0?oo
o`000?l0oooo0?l0003oool0o`000940oooo00<0o`000?ooo`3oool0103o
ool00`3o0000003o0?ooo`030?ooo`030?l0003oool0o`0003L0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`800000
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo0080oooo00<0o`000000o`000?l00P3oool00`3o0000oooo
0?ooo`030?ooo`040?l0003oool0oooo0?l000H0oooo00@0o`000?ooo`3o
ool0o`001`3oool00`3o0000oooo0?ooo`1h0?ooo`80o`001`3oool0103o
0000oooo0?ooo`3o00060?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`000?l00P000?l00`3o0000oooo0?ooo`030?ooo`050?l0003oool0
oooo0?ooo`3o00001@3oool00`3o0000oooo0?ooo`0D0?ooo`00HP3oool0
0`000000oooo0?ooo`0H0?ooo`040?l0003oool0003o0000o`80oooo00<0
o`000?ooo`3o0000V03oool00`3o0000003o0?ooo`030?ooo`030?l0003o
ool0o`0003L0oooo00@000000?ooo`3oool000002@3oool2000000D0oooo
00<000000?ooo`3o00001@3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0003o00<0003o103oool00`3o0000oooo0?ooo`030?ooo`040?l0
003oool0oooo0?l000H0oooo00<0o`000?ooo`3o0000203oool00`3o0000
oooo0?ooo`1h0?ooo`80o`001`3oool0103o0000oooo0?ooo`3o00060?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool20000
o`<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo01@0oooo001R0?ooo`030000003oool0oooo01P0
oooo00<0o`000000o`3oool0103oool20?l009T0oooo00<0o`000000o`3o
ool00P3oool00`3o0000oooo0?l0000g0?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0103oool00`000000o`000?ooo`050?oo
o`030?l0003oool0oooo0080oooo0`000?l30?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo0?ooo`3o0006
0?ooo`030?l0003oool0o`0008<0oooo00<0o`000?ooo`3oool01P3oool0
103o0000oooo0?ooo`3o00070?ooo`050?l0003oool0oooo0?ooo`3o0000
1@3oool01@3o0000003o0000o`3oool0o`0000@0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0D0?ooo`00HP3oool00`000000oooo
0?ooo`0?0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`2G0?ooo`050?l0003oool0003o0?ooo`3o
00000P3oool00`3o0000oooo0?ooo`0f0?ooo`8000002P3oool3000000@0
oooo00<000000?l0003oool01@3oool00`3o0000003o0000o`020000o`03
0?ooo`3o0000oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l000060?oo
o`040?l0003oool0oooo0?l000L0oooo0P3o00230?ooo`030?l0003oool0
oooo00H0oooo00@0o`000?ooo`3oool0o`001`3oool0103o0000oooo0?oo
o`3o00060?ooo`030?l0003oool0oooo00L0003o1@3oool00`3o0000oooo
0?ooo`0D0?ooo`00HP3oool00`000000oooo0?ooo`0?0?ooo`80o`001P3o
ool00`000?l0oooo0?ooo`2P0?ooo`050?l0003oool0oooo0000o`3o0000
0`3oool00`3o0000oooo0?ooo`180?ooo`030000003o0000oooo00@0oooo
0P000?l00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00D0o`000?ooo`3oool0oooo0?l000060?ooo`040?l0003oool0oooo0?l0
00L0oooo0P3o00230?ooo`030?l0003oool0oooo00H0oooo00@0o`000?oo
o`3oool0o`001`3oool0103o0000oooo0?ooo`3o00060?ooo`050?l0003o
ool0oooo0?ooo`3o00001@3oool90000oa<0oooo001R0?ooo`030000003o
ool0oooo00l0oooo0P3o00060?ooo`030000o`3oool0oooo0:00oooo00@0
o`000?ooo`3oool0oooo0P000?l20?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3oool0@03oool00`000000o`000?ooo`060?ooo`050?l0
003oool0oooo0?ooo`3o00001@3oool01@3o0000oooo0?ooo`3oool0o`00
00H0oooo00<0o`000?ooo`3o0000203oool20?l008d0oooo00<0o`000?oo
o`3o00001`3oool0103o0000oooo0?ooo`3o00060?ooo`050?l0003oool0
oooo0?ooo`3o00001@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo01@0oooo001R0?ooo`030000003oool0oooo00h0oooo00@0o`00
0?ooo`3oool0o`00103oool00`000?l0o`000?ooo`2R0?ooo`080?l0003o
ool0oooo0?l0003oool0003o0?ooo`3o00070?ooo`030?l0003oool0oooo
0400oooo00<000000?l0003oool01P3oool01@3o0000oooo0?ooo`3oool0
o`0000D0oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`030?l0003o
ool0o`0000P0oooo0P3o002=0?ooo`80o`00203oool0103o0000oooo0?oo
o`3o00060?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo01@0oooo001R0?ooo`030000
003oool0oooo00h0oooo00@0o`000?ooo`3oool0o`000P3oool20000o`03
0?ooo`3o0000oooo0:80oooo00<0o`000?ooo`3o00000`3oool00`000?l0
o`000?ooo`060?ooo`80o`004`3oool00`3o0000oooo0?ooo`0[0?ooo`03
0000003o0000oooo00H0oooo00D0o`000?ooo`3oool0oooo0?l000060?oo
o`040?l0003oool0oooo0?l000H0oooo00<0o`000?ooo`3o0000203oool0
0`3o0000oooo0?ooo`2<0?ooo`80o`00203oool0103o0000oooo0?ooo`3o
00060?ooo`040?l0003oool0oooo0?l000H0oooo00D0o`000?ooo`3oool0
oooo0?l0000G0?ooo`00HP3oool00`000000oooo0?ooo`040?ooo`030?l0
003oool0oooo00L0oooo00@0o`000?ooo`3oool0oooo0P000?l30?ooo`03
0?l0003oool0oooo0:40oooo00<0o`000?ooo`3o0000103oool00`000?l0
o`000?ooo`040?ooo`030?l0003oool0o`0000P0oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0[0?ooo`030000003o0000oooo00H0
oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`040?l0003oool0oooo
0?l000H0oooo00<0o`000?ooo`3o0000203oool00`3o0000oooo0?ooo`2<
0?ooo`80o`00203oool0103o0000oooo0?ooo`3o00060?ooo`040?l0003o
ool0oooo0?l000H0oooo00D0o`000?ooo`3oool0oooo0?l0000G0?ooo`00
HP3oool00`000000oooo0?ooo`040?ooo`80o`00203oool01P3o0000oooo
0?ooo`000?l0oooo0?l000<0oooo00<0o`000?ooo`3oool0X@3oool00`3o
0000oooo0?l000050?ooo`030000o`3oool0oooo00<0oooo00@0o`000?oo
o`3oool0o`001`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0
oooo02/0oooo00<000000?l0003oool01P3oool01@3o0000oooo0?ooo`3o
ool0o`0000H0oooo00@0o`000?ooo`3oool0o`001P3oool00`3o0000oooo
0?l000080?ooo`030?l0003oool0oooo08`0oooo0P3o00080?ooo`040?l0
003oool0oooo0?l000H0oooo00@0o`000?ooo`3oool0o`001P3oool01@3o
0000oooo0?ooo`3oool0o`0001L0oooo001R0?ooo`030000003oool0oooo
00@0oooo0P3o00070?ooo`040?l0003oool0oooo0000o`80oooo00D0o`00
0?ooo`3oool0oooo0?l0002T0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000000o`000?l00`3oool0103o0000oooo0?ooo`3o00070?ooo`80o`00
203oool00`3o0000oooo0?ooo`0/0?ooo`030000003o0000oooo00H0oooo
00D0o`000?ooo`3oool0oooo0?l000060?ooo`040?l0003oool0oooo0?l0
00L0oooo0P3o00080?ooo`030?l0003oool0oooo08`0oooo0P3o00080?oo
o`030?l0003oool0o`0000L0oooo00@0o`000?ooo`3oool0o`001P3oool0
1@3o0000oooo0?ooo`3oool0o`0001L0oooo001R0?ooo`030000003oool0
oooo00<0oooo00@0o`000?ooo`3oool0o`001P3oool00`3o0000oooo0000
o`040?ooo`030?l0003oool0o`000:D0oooo00<0o`000?ooo`3oool01@3o
ool01P3o0000oooo0000o`000?l0oooo0?l00080oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?l000080?ooo`030?l0003oool0oooo02`0
oooo00<000000?l0003oool01P3oool0103o0000oooo0?ooo`3o00070?oo
o`030?l0003oool0o`0000P0oooo0P3o002G0?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3o00001`3oool0103o0000oooo0?ooo`3o0006
0?ooo`050?l0003oool0oooo0?ooo`3o00005`3oool00680oooo00<00000
0?ooo`3oool00`3oool0103o0000oooo0?ooo`3o00060?ooo`80003o1P3o
ool20?l00:d0oooo00@0o`000?ooo`3oool0oooo0P000?l30?ooo`030?l0
003oool0oooo00<0oooo00@0o`000?ooo`3oool0o`001`3oool00`3o0000
oooo0?ooo`0/0?ooo`030000003o0000oooo00H0oooo00@0o`000?ooo`3o
ool0o`001`3oool00`3o0000oooo0?l000080?ooo`80o`00U`3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0o`0000L0oooo00@0o`000?oo
o`3oool0o`001P3oool01@3o0000oooo0?ooo`3oool0o`0001L0oooo001R
0?ooo`030000003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l0
00030?ooo`80003o00<0o`000?ooo`3oool01@3oool20?l00:h0oooo00H0
o`000?ooo`3oool0o`000?ooo`000?l20?ooo`030?l0003oool0oooo00<0
oooo00@0o`000?ooo`3oool0o`001`3oool00`3o0000oooo0?ooo`0/0?oo
o`030000003o0000oooo00H0oooo00@0o`000?ooo`3oool0o`001`3oool0
0`3o0000oooo0?l000080?ooo`030?l0003oool0oooo09H0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?l000070?ooo`040?l0003oool0
oooo0?l000H0oooo00@0o`000?ooo`3oool0o`00603oool00680oooo00<0
00000?ooo`3oool00`3oool01P3o0000oooo0?ooo`3oool0o`000?ooo`80
003o0P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0:`0
oooo00@0o`000?ooo`3oool0o`000P3oool20000o`030?ooo`3o0000oooo
00<0oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`030?l0003oool0
oooo02d0oooo00<000000?l0003oool01P3oool0103o0000oooo0?ooo`3o
00070?ooo`030?l0003oool0o`0000P0oooo00<0o`000?ooo`3oool0X@3o
ool20?l000L0oooo00<0o`000?ooo`3o00001`3oool0103o0000oooo0?oo
o`3o000H0?ooo`00F`3oool500000080oooo00<000000?ooo`3oool00`3o
ool0103o0000oooo0?ooo`3oool20000o`<0oooo00<0o`000?ooo`3oool0
]P3oool0103o0000oooo0?ooo`3o00040?ooo`<0003o0`3oool01@3o0000
oooo0?ooo`3oool0o`0000D0oooo00<0o`000?ooo`3oool0;@3oool00`00
0000o`000?ooo`060?ooo`040?l0003oool0oooo0?l000L0oooo00<0o`00
0?ooo`3o0000203oool00`3o0000oooo0?ooo`2Q0?ooo`80o`001`3oool0
0`3o0000oooo0?l000070?ooo`040?l0003oool0oooo0?l001P0oooo001M
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`000?l0
0`3oool0o`000?ooo`020?ooo`030?l0003oool0oooo0;L0oooo00<0o`00
0?ooo`3o00001@3oool00`3o0000oooo0000o`050000o`80oooo00<0o`00
0?ooo`000?l01@000?l]0?ooo`030000003o0000oooo00H0oooo00@0o`00
0?ooo`3oool0o`001`3oool00`3o0000oooo0?l000080?ooo`030?l0003o
ool0oooo0:40oooo0P3o00070?ooo`030?l0003oool0o`0000L0oooo00@0
o`000?ooo`3oool0o`00603oool005d0oooo00<000000?ooo`3oool00P3o
ool30000o`80oooo00<0o`000?ooo`3oool0103oool0103o0000oooo0?oo
o`3o002i0?ooo`80o`001`3oool0103o0000oooo0?ooo`3o00030?ooo`@0
003o0`3oool00`3o0000oooo0?ooo`0]0?ooo`030000003o0000oooo00H0
oooo00<0o`000?ooo`3o0000203oool00`3o0000oooo0?l000080?ooo`03
0?l0003oool0oooo0:40oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?l000070?ooo`040?l0003oool0oooo0?l001P0oooo001M0?ooo`03
0000003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`040?ooo`040?l0003oool0oooo0?l00;X0oooo00<0o`000?oo
o`3oool01@3oool0103o0000oooo0?ooo`3o00050?ooo`050?l0003oool0
oooo0?ooo`3o0000<03oool00`000000o`000?ooo`060?ooo`030?l0003o
ool0o`0000T0oooo0P3o002/0?ooo`030?l0003oool0oooo00L0oooo0P3o
00070?ooo`040?l0003oool0oooo0?l001P0oooo001M0?ooo`030000003o
ool0oooo0080oooo00<000000?l0003oool00P3oool00`3o0000oooo0?oo
o`050?ooo`80o`00^`3oool00`3o0000oooo0?ooo`050?ooo`040?l0003o
ool0oooo0?l000H0oooo00@0o`000?ooo`3oool0o`00<03oool00`3o0000
oooo0?ooo`070?ooo`80o`002@3oool00`3o0000oooo0?ooo`2[0?ooo`03
0?l0003oool0oooo00L0oooo0P3o00070?ooo`030?l0003oool0o`0001T0
oooo001L0?ooo`800000103oool00`000000o`000?ooo`020?ooo`030?l0
003oool0oooo00D0oooo0P3o00340?ooo`030?l0003oool0o`0000H0oooo
00@0o`000?ooo`3oool0o`00<03oool00`3o0000oooo0?ooo`070?ooo`80
o`002@3oool00`3o0000oooo0?ooo`2[0?ooo`030?l0003oool0oooo00L0
oooo0P3o00080?ooo`80o`006@3oool00680oooo00<000000?ooo`3o0000
0P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0<80oooo
00<0o`000?ooo`3o00001`3oool00`3o0000oooo0?l0000`0?ooo`030?l0
003oool0oooo00L0oooo0P3o00090?ooo`030?l0003oool0oooo0;D0oooo
0P3o00080?ooo`80o`006@3oool00680oooo00<000000?ooo`3o00000P3o
ool00`3o0000oooo0?ooo`3;0?ooo`80o`00203oool20?l00340oooo00<0
o`000?ooo`3oool01`3oool20?l000T0oooo00<0o`000?ooo`3oool0]@3o
ool00`3o0000oooo0?ooo`070?ooo`80o`006@3oool00680oooo00<00000
0?ooo`3oool00P3o003?0?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo00P0oooo00<0o`000?ooo`3oool0]@3oool00`3o0000oooo0?ooo`07
0?ooo`80o`006@3oool00680oooo00<000000?ooo`3oool00P3o003?0?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0;`3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo0<00oooo00<0o`000?oo
o`3oool01`3oool20?l001T0oooo001R0?ooo`050000003oool0oooo0?oo
o`3o0000o`3oool40?ooo`D000000`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo0<00oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`0H0?ooo`00HP3oool00`000000oooo0?ooo`3o0?ooo`P0
oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo0<X0oooo00<0o`000?ooo`3oool0603oool00?l0oooo
K@3oool00`000000oooo0?ooo`030?ooo`030?l00000000000000=@0oooo
00<0o`000?ooo`3oool0603oool00?l0ooooK@3oool00`000000oooo0?oo
o`3e0?ooo`00o`3ooom]0?ooo`030000003oool0oooo0?D0oooo003o0?oo
of`0oooo0P00003g0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0oooo
IP3oool00?l0ooooo`3ooomV0?ooo`00G`3oool2000000P0oooo0P00003o
0?ooooX0oooo001O0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0o`3ooooh0?ooo`00EP3oool2000000030?ooo`000000000000@0
oooo00<000000?ooo`3oool00P0000020?ooo`8000000P3oool00`000000
oooo0?ooo`3j0?ooo`8000001P3oool2000000P0oooo0P00003Y0?ooo`00
E`3oool00`000000oooo000000050?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool000000?d0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0>L0oooo001H0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000oP3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo008000000P3oool2
00000080oooo00<000000?ooo`3oool0i`3oool005H0oooo0P0000000`3o
ool00000000000040?ooo`030000003oool0oooo00@00000103oool00`00
0000oooo0?ooo`3k0?ooo`030000003oool0000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000j@3o
ool005l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3j
0?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`000000j@3oool005l0oooo
0P0000080?ooo`800000n`3oool3000000030?ooo`000000000000<0oooo
00<000000?ooo`3oool0100000040?ooo`030000003oool0oooo0>L0oooo
003o0?ooog00oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`3W0?ooo`00o`3ooom`0?ooo`800000203oool200000>T0oooo003o0?oo
ool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{612, 140},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Figure 9.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The input ",
  Cell[BoxData[
      \(x[n] = cos \((0.10  n)\) + 0.20  sin \((\(2  \[Pi]\)\/3\ n)\)\)]],
  " and output  ",
  Cell[BoxData[
      \(y[n]\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["9.21 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  In Section 9.2, Example 9.19, we established that the difference \
equation  ",
  Cell[BoxData[
      \(x[n + 2] - \@2\ x[n + 1] + x[n] = 0\)]],
  "  with initial conditions  ",
  Cell[BoxData[
      RowBox[{\(x[0]\), "=", 
        RowBox[{
          RowBox[{"2", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(x[1]\)}], "=", \(\@2\)}]}]]],
  "  has the solution  ",
  Cell[BoxData[
      \(x[n] = 2  cos \((\(\[Pi]\/4\) n)\)\)]],
  ".  Thus ",
  Cell[BoxData[
      \(cos \((\(\[Pi]\/4\) \((n + 2)\))\)\)]],
  " is a solution to  ",
  Cell[BoxData[
      \(x[n] - \@2\ x[n - 1] + x[n - 2] = 0\)]],
  " and so are the signals ",
  Cell[BoxData[
      RowBox[{"cos", \((\(\[Pi]\/4\) n)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "sin", \((\(\[Pi]\/4\) n)\)}]]],
  ".  This can also be proven by direct substitution of  ",
  Cell[BoxData[
      \(x[n] = cos \((\(\[Pi]\/4\) n)\)\)]],
  ", and using the trigonometric identities  ",
  Cell[BoxData[
      \(x[
          n - 1] = \(cos \((\(\[Pi]\/4\) 
                  n - \[Pi]\/4)\) = \(1\/\@2\) \((cos \((\(\[Pi]\/4\) n)\) + 
                sin \((\(\[Pi]\/4\) n)\))\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(x[n - 2] = \(cos \((\(\[Pi]\/4\) n - \[Pi]\/2)\) = 
          sin \((\(\[Pi]\/4\) n)\)\)\)]],
  ".  An easy calculation shows that  \n\n\t\t\t",
  Cell[BoxData[{
      \(y[n]\ \  = \ \ x[n] - \@2\ x[n - 1] + x[n - 2]\ \), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(cos \((\(\[Pi]\/4\) 
                n)\) - \(\@2\) \((\(1\/\@2\) \((cos \((\(\[Pi]\/4\) n)\) + 
                    sin \((\(\[Pi]\/4\) n)\))\))\) + \ 
          sin \((\(\[Pi]\/4\) n)\)\)\)\ \), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(0\)\)\)}]],
  "  \n\t\nTesting  ",
  Cell[BoxData[
      \(x[n] = sin \((\(\[Pi]\/4\) n)\)\)]],
  "  is similar. "
}], "Text"],

Cell[TextData[{
  "\tFor this filter, the amplitude response is  ",
  Cell[BoxData[
      \(A \((\[Theta])\) = \(\(|\)\(H \((\[ExponentialE]\^\[ImaginaryI]\
\[Theta])\)\)\(|\)\)\)]],
  "  where  ",
  Cell[BoxData[
      \(H \((z)\) = \ 1 - \(\@2\) z\^\(-1\) + z\^\(-2\)\)]],
  "  is the transfer function.  Calculation reveals that \n\n\t\t\t",
  Cell[BoxData[
      \(A \((\[Pi]\/4)\)\ \  = \ \ \(\(\(|\)\(H \((\[ExponentialE]\^\(\
\[ImaginaryI]\ \[Pi]/4\))\)\)\(|\)\)\  = \ \(\(|\)\(1 - \ \(\@2\) \((\
\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\))\)\^\(-1\) + \((\[ExponentialE]\^\
\(\[ImaginaryI]\ \[Pi]/4\))\)\^\(-2\)\)\(|\)\)\)\)]],
  "\n\n\t\t\t",
  Cell[BoxData[
      \(A \((\[Pi]\/4)\)\ \  = \ \ \(1 - \ \(\@2\) \((\(1 + \[ImaginaryI]\)\/\
\@2)\)\^\(-1\) + \((\(1 + \[ImaginaryI]\)\/\@2)\)\^\(-2\)\ \  = \ \ 1 - \ \
\(\@2\) \((\(1 - \[ImaginaryI]\)\/\@2)\) - \[ImaginaryI]\)\)]],
  " \n\n\t\t\t",
  Cell[BoxData[
      \(A \((\[Pi]\/4)\)\ \  = \ \ 0\)]],
  " \n\nThe graph of   ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  "  is given in Figure 9.4. "
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 9.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "The amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\) = \(\(|\)\(1 - \ \(\@2\) z\^\(-1\) + 
            z\^\(-2\)\)\(|\)\)\)]],
  " for  ",
  Cell[BoxData[
      \(y[n] = x[n] - \@2\ x[n - 1] + x[n - 2]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Notice that there is a zero amplitude response at   ",
  Cell[BoxData[
      \(\[Theta]\  = \[Pi]\/4\)]],
  "  and that the amplitude response increases for values of  ",
  Cell[BoxData[
      \(\(\(\[Theta]\)\(\ \)\)\)]],
  " in the interval ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(\[Pi]\/4\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "\[Pi]"}], "]"}]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["9.21 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Calculate the amplitude responses ",
  Cell[BoxData[
      RowBox[{"A", \((0.10)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "A", \((0.77)\)}]]],
  " and investigate the the filtered signal for  ",
  Cell[BoxData[
      \(x[n] = \ cos \((0.10\ n)\) + sin \((0.77\ n)\)\)]],
  ".  \n\n\t\t\t",
  Cell[BoxData[
      \(A \((0.10)\)\ \  = \ \ \(\(|\)\(1 - \ \(\@2\) \
\((\[ExponentialE]\^\(0.10  \[ImaginaryI]\))\)\^\(-1\) + \((\[ExponentialE]\^\
\(0.10  \[ImaginaryI]\))\)\^\(-2\)\)\(|\)\)\)]],
  "  \t\n\t\t\t\n\t\t\t",
  Cell[BoxData[
      \(A \((0.10)\)\ \  = \ \ \(\(\(|\)\(0.5729182\[InvisibleSpace] - 
              0.0574835589950729`\ \[ImaginaryI]\)\(|\)\)\ \
\[IndentingNewLine]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  = \ \ \ \
0.5757948\)\)]],
  "  \n\t\t\n\t\t\tand\n\n\t\t\t",
  Cell[BoxData[
      \(A \((0.77)\)\ \  = \ \ \(\(|\)\(1 - \ \(\@2\) \
\((\[ExponentialE]\^\(0.77  \[ImaginaryI]\))\)\^\(-1\) + \((\[ExponentialE]\^\
\(0.77  \[ImaginaryI]\))\)\^\(-2\)\)\(|\)\)\)]],
  "  \t\t\n\t\t\n\t\t\t",
  Cell[BoxData[
      \(A \((0.77)\)\ \  = \ \ \(\(\(|\)\(0.015512453546319582`\
\[InvisibleSpace] - 
              0.015041934892840225`\ \[ImaginaryI]\)\(|\)\)\ \
\[IndentingNewLine]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  = \ \ \
0.02160777684879144`\)\)]],
  "  "
}], "Text"],

Cell[TextData[{
  "From the above calculations we expect that components ",
  Cell[BoxData[
      RowBox[{"cos", \((0.10\ n)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "cos", \((0.77\ n)\)}]]],
  "  of the signal are attenuated by the factors  ",
  Cell[BoxData[
      \(A \((0.10)\) = 0.5757948\)]],
  ",  and  ",
  Cell[BoxData[
      \(A \((0.77)\) = 0.0216078\)]],
  ",  respectively.  Hence the filter almost eliminates the signal component \
",
  Cell[BoxData[
      \(cos \((0.77\ n)\)\)]],
  " which is close to the \"zero-out\" frequency  ",
  Cell[BoxData[
      \(0.7853981633974483` = \[Pi]\/4\)]],
  ".  The Figure 9.5 illustrates the situation. "
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 9.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The input  ",
  Cell[BoxData[
      \(x[n] = cos \((0.10  n)\) + sin \((0.77  n)\)\)]],
  "  and output  ",
  Cell[BoxData[
      \(y[n]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["9.21 (c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Calculate the amplitude responses ",
  Cell[BoxData[
      RowBox[{"A", \((0.10)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "A", \((\(2  \[Pi]\)\/3)\)}]]],
  " and investigate the the filtered signal for  ",
  Cell[BoxData[
      \(x[n] = \ cos \((0.10\ n)\) + 0.20  sin \((\(2  \[Pi]\)\/3\ n)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "In part (b) we found ",
  Cell[BoxData[
      \(A \((0.10)\) = 0.5757948\)]],
  " and now we make the calculation \n\n\t\t\t",
  Cell[BoxData[
      \(A \((\(2  \[Pi]\)\/3)\)\ \  = \ \ \(\(|\)\(1 - \ \(\@2\) \((\
\[ExponentialE]\^\(\[ImaginaryI]\ 2  \[Pi]/3\))\)\^\(-1\) + \
\((\[ExponentialE]\^\(\[ImaginaryI]\ 2  \[Pi]/3\))\)\^\(-2\)\)\(|\)\)\)]],
  "  \t\n\t\t\n\t\t\t",
  Cell[BoxData[
      \(A \((\(2  \[Pi]\)\/3)\)\ \  = \ \ \(\(|\)\(1 - \(\@2\) \((\(-\(1\/2\)\
\) - \(\[ImaginaryI]\ \@3\)\/2)\) - 
            1\/2 + \(\[ImaginaryI]\ \@3\)\/2\)\(|\)\)\)]],
  "  \t\n\t\t\n\t\t\t",
  Cell[BoxData[
      \(A \((\(2  \[Pi]\)\/3)\)\ \  = \ \ \(\(\(|\)\(\(1 + \@2 + \
\[ImaginaryI]\ \((\@3 + \@6)\)\)\/2\)\(|\)\)\ \[IndentingNewLine]\
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \  = \ \ 2.24650723546738`\)\)]],
  "  "
}], "Text"],

Cell[TextData[{
  "We expect that components ",
  Cell[BoxData[
      RowBox[{"cos", \((0.10\ n)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "0.20", 
        "sin", \((\(2  \[Pi]\)\/3\ n)\)}]]],
  "  of the input signal are attenuated by ",
  Cell[BoxData[
      \(A \((0.10)\) = 0.5757948\)]],
  ", and amplified by  ",
  Cell[BoxData[
      \(A \((\(2  \[Pi]\)\/3)\) = 2.24650723546738`\)]],
  ", respectively.  The Figure 9.6 illustrates the situation. "
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 9.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The input ",
  Cell[BoxData[
      \(x[n] = cos \((0.10  n)\) + 0.20  sin \((\(2  \[Pi]\)\/3\ n)\)\)]],
  " and output  ",
  Cell[BoxData[
      \(y[n]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Background for the z-transform and its application for solving difference \
equations can be found in the book.\n\n",
  StyleBox[ButtonBox["Complex Analysis for Mathematics and Engineering",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["9.21.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given the recursion formula  ",
  Cell[BoxData[
      \(y[n]\ \  = \ \ x[n] - \@2\ x[n - 1] + x[n - 2]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["9.21 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   ",
  "Show that it is a zeroing out filter for the signals ",
  Cell[BoxData[
      \(cos \((\(\[Pi]\/4\) n)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\(\[Pi]\/4\) n)\)\)]],
  " and calculate the amplitude response  ",
  Cell[BoxData[
      \(A \((\[Pi]\/4)\) = A \((0.7853981633974483`)\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(filter\  = \ 
        y[n]\  \[Equal] \ 
          x[n] - \@2\ x[n - 1] + x[n - 2];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The FIR filter is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", \ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = Cos[\(n\ \[Pi]\)\/4];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  x[n] = \>", x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-1] = \>", x[n - 1], "\< = \>", \ 
        TrigExpand[x[n - 1]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-2] = \>", x[n - 2], "\< = \>", \ 
        TrigExpand[x[n - 2]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute into the filter and get\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<  \>", \*"\"\<y[n] == x[n] - \!\(\@2\)x[n-1] + x[n-2]\>\""];\
\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", \ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  y[n] == \>", x[n], \*"\"\< - \!\(\@2\)(\>\"", 
        TrigExpand[x[n - 1]], "\<) + (\>", 
        TrigExpand[x[n - 2]], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  y[n] == \>", x[n], "\< - (\>", 
        TrigExpand[\(\@2\) x[n - 1]], "\<) + (\>", 
        TrigExpand[x[n - 2]], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", \ Simplify[filter]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(filter\  = \ 
        y[n]\  \[Equal] \ 
          x[n] - \@2\ x[n - 1] + x[n - 2];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The FIR filter is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", \ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = Sin[\(n\ \[Pi]\)\/4];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  x[n] = \>", x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-1] = \>", x[n - 1], "\< = \>", \ 
        TrigExpand[x[n - 1]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-2] = \>", x[n - 2], "\< = \>", \ 
        TrigExpand[x[n - 2]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute into the filter and get\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<  \>", \*"\"\<y[n] == x[n] - \!\(\@2\)x[n-1] + x[n-2]\>\""];\
\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", \ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  y[n] == \>", x[n], \*"\"\< - \!\(\@2\)(\>\"", 
        TrigExpand[x[n - 1]], "\<) + (\>", 
        TrigExpand[x[n - 2]], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  y[n] == \>", x[n], "\< - (\>", 
        TrigExpand[\(\@2\) x[n - 1]], "\<) + (\>", 
        TrigExpand[x[n - 2]], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", \ Simplify[filter]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(H[z_] = 1 - \ \(\@2\) z\^\(-1\) + z\^\(-2\);\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(graph1 = 
        Plot[Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]], {\[Theta], 
            0, \[Pi]}, PlotRange \[Rule] {{0, \[Pi]}, {0, 3.5}}, 
          Ticks \[Rule] {Range[0, \[Pi], \[Pi]\/4], Range[0, 3.5, 1]}, 
          PlotStyle \[Rule] Red];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< A[\[Theta]] =  |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(\[Pi]\/4\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]  \[Pi]\/4\)\)]| = \>\"", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\/4\)]]];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<The amplitude response for the filter\>"];\)\), "\n", 
    \(\(Print[\*"\"\<y[n+2] = x[n] - \!\(\@2\)x[n-1] + x[n-2]\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Where the transfer function is\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\< H[z] = \>", H[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<H[\!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)] = \>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Figure 9.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "The amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\) = \(\(|\)\(1 - \ \(\@2\) z\^\(-1\) + 
            z\^\(-2\)\)\(|\)\)\)]],
  " for  ",
  Cell[BoxData[
      \(y[n] = x[n] - \@2\ x[n - 1] + x[n - 2]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["9.21 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Calculate the amplitude responses ",
  Cell[BoxData[
      RowBox[{"A", \((0.10)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "A", \((0.77)\)}]]],
  " and investigate the the filtered signal for  ",
  Cell[BoxData[
      \(x[n] = \ cos \((0.10\ n)\) + sin \((0.77\ n)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Show[graph1, 
        Ticks \[Rule] {{0.1, 0.77, \[Pi]\/2, \[Pi]}, 
            Range[0, 3.5, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[0.10] = |H[\!\(\[ExponentialE]\^\(0.10  \
\[ImaginaryI]\)\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\(10\/100\) \[ImaginaryI]\)], "\<|\>"\ ];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[0.10] = |H[\!\(\[ExponentialE]\^\(0.10  \
\[ImaginaryI]\)\)]| = |\>\"", 
        H[\[ExponentialE]\^\(0.10  \[ImaginaryI]\)], "\<|\>"\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[0.10] = |H[\!\(\[ExponentialE]\^\(0.10  \
\[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(0.10  \[ImaginaryI]\)]]\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<And\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[0.77] = |H[\!\(\[ExponentialE]\^\(0.77  \
\[ImaginaryI]\)\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\(77\/100\) \[ImaginaryI]\)], "\<|\>"\ ];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[0.77] = |H[\!\(\[ExponentialE]\^\(0.77  \
\[ImaginaryI]\)\)]| = |\>\"", 
        H[\[ExponentialE]\^\(0.77  \[ImaginaryI]\)], "\<|\>"\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[0.77] = |H[\!\(\[ExponentialE]\^\(0.77  \
\[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(0.77  \[ImaginaryI]\)]]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = Cos[0.10\ n] + Sin[0.77\ n];\)\ \), "\[IndentingNewLine]", 
    \(\(m0 = 65;\)\), "\[IndentingNewLine]", 
    \(\(X1\  = \ N[Table[Cos[0.10\ i], {i, 0, m0}]];\)\), "\n", 
    \(\(X2\  = \ 
        N[Table[Cos[0.10\ i] + Sin[0.77\ i], {i, 0, 
              m0}]];\)\), "\[IndentingNewLine]", 
    \(\(X1 = Join[Table[0, {i, 1, 9}], X1];\)\), "\[IndentingNewLine]", 
    \(\(X2 = Join[Table[0, {i, 1, 9}], X2];\)\), "\n", 
    \(\(Y2 = \(Y1 = Table[0, {i, 0, m0 + 9}]\);\)\), "\n", 
    \(\(For[i = 10, 
        i \[LessEqual] 
          m0 + 10, \(i++\), \[IndentingNewLine]Y1\_\(\(\[LeftDoubleBracket]\)\
\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X1\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  - \(\@2\) 
                  X1\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\)\  + 
                X1\_\(\(\[LeftDoubleBracket]\)\(i - \
2\)\(\[RightDoubleBracket]\)\)\ )\)\ ]; \ \[IndentingNewLine]Y2\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X2\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  - \(\@2\) 
                  X2\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\)\  + 
                X2\_\(\(\[LeftDoubleBracket]\)\(i - \
2\)\(\[RightDoubleBracket]\)\)\ )\)\ ];\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(X1pts = 
        Transpose[{ticval, 
            Take[X1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(X2pts = 
        Transpose[{ticval, 
            Take[X2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1pts = 
        Transpose[{ticval, 
            Take[Y1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y2pts = 
        Transpose[{ticval, 
            Take[Y2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ListPlot[X1pts, PlotJoined \[Rule] True, PlotStyle \[Rule] {Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ListPlot[X2pts, PlotJoined \[Rule] True, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{0, m0}, {\(-2\), 2}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<n\>", "\<x[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Input signal x[n] = \>", 
        x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        ListPlot[Take[Y1pts, \(-64\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] {Blue}, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr4 = 
        ListPlot[Take[Y2pts, \(-66\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] Red, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr4, PlotRange \[Rule] {{0, m0}, {\(-0.6\), 1.0}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-0.6\), 1.2, 0.3]}, 
        AxesLabel \[Rule] {"\<n\>", "\<y[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Output signal y[n] = x[n] - \!\(\@2\)x[n-1] + \
x[n-2]\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The  amplitude  responses\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Low  frequency:  A[0.10] = \
|H[\!\(\[ExponentialE]\^\(0.10  \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(0.10  \[ImaginaryI]\)]]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<High frequency:  A[0.77] = \
|H[\!\(\[ExponentialE]\^\(0.77  \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(0.77  \[ImaginaryI]\)]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Figure 9.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "The amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\) = \(\(|\)\(1 - \ \(\@2\) z\^\(-1\) + 
            z\^\(-2\)\)\(|\)\)\)]],
  " for  ",
  Cell[BoxData[
      \(y[n] = x[n] - \@2\ x[n - 1] + x[n - 2]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["9.21 (c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   ",
  "Calculate the amplitude responses ",
  Cell[BoxData[
      RowBox[{"A", \((0.10)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "A", \((\(2  \[Pi]\)\/3)\)}]]],
  " and investigate the the filtered signal for  ",
  Cell[BoxData[
      \(x[n] = \ cos \((0.10\ n)\) + 0.20  sin \((\(2  \[Pi]\)\/3\ n)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Show[graph1, 
        Ticks \[Rule] {{0.1, \(2  \[Pi]\)\/3, \[Pi]}, 
            Range[0, 3.5, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[0.10] = |H[\!\(\[ExponentialE]\^\(0.10  \
\[ImaginaryI]\)\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\(10\/100\) \[ImaginaryI]\)], "\<|\>"\ ];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[0.10] = |H[\!\(\[ExponentialE]\^\(0.10  \
\[ImaginaryI]\)\)]| = |\>\"", 
        H[\[ExponentialE]\^\(0.10  \[ImaginaryI]\)], "\<|\>"\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[0.10] = |H[\!\(\[ExponentialE]\^\(0.10  \
\[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(0.10  \[ImaginaryI]\)]]\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<And\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(\(2  \[Pi]\)\/3\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]2\[Pi]/3\)\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ 2  \[Pi]/3\)], "\<| = \>", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ 2  \[Pi]/3\)]]\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(\(2  \[Pi]\)\/3\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]2\[Pi]/3\)\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ 2.  \[Pi]/3\)], "\<| \>"\ ];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(\(2  \[Pi]\)\/3\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]2\[Pi]/3\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ 2.  \[Pi]/3\)]]\ ];\)\ \)}], \
"Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = 
        Cos[0.10  n] + 
          0.20  Sin[\(2  \[Pi]\)\/3\ n];\)\ \), "\[IndentingNewLine]", 
    \(\(m0 = 65;\)\), "\[IndentingNewLine]", 
    \(\(X1\  = \ N[Table[Cos[0.10\ i], {i, 0, m0}]];\)\), "\n", 
    \(\(X2\  = \ 
        N[Table[Cos[0.10\ i] + 0.20  Sin[\(2  \[Pi]\)\/3\ i], {i, 0, 
              m0}]];\)\), "\[IndentingNewLine]", 
    \(\(X1 = Join[Table[0, {i, 1, 9}], X1];\)\), "\[IndentingNewLine]", 
    \(\(X2 = Join[Table[0, {i, 1, 9}], X2];\)\), "\n", 
    \(\(Y2 = \(Y1 = Table[0, {i, 0, m0 + 9}]\);\)\), "\n", 
    \(\(For[i = 10, 
        i \[LessEqual] 
          m0 + 10, \(i++\), \[IndentingNewLine]Y1\_\(\(\[LeftDoubleBracket]\)\
\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X1\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  - \(\@2\) 
                  X1\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\)\  + 
                X1\_\(\(\[LeftDoubleBracket]\)\(i - \
2\)\(\[RightDoubleBracket]\)\)\ )\)\ ]; \ \[IndentingNewLine]Y2\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X2\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  - \(\@2\) 
                  X2\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\)\  + 
                X2\_\(\(\[LeftDoubleBracket]\)\(i - \
2\)\(\[RightDoubleBracket]\)\)\ )\)\ ];\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(X1pts = 
        Transpose[{ticval, 
            Take[X1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(X2pts = 
        Transpose[{ticval, 
            Take[X2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1pts = 
        Transpose[{ticval, 
            Take[Y1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y2pts = 
        Transpose[{ticval, 
            Take[Y2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ListPlot[X1pts, PlotJoined \[Rule] True, PlotStyle \[Rule] {Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ListPlot[X2pts, PlotJoined \[Rule] True, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{0, m0}, {\(-1.2\), 1.2}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 0.5]}, 
        AxesLabel \[Rule] {"\<n\>", "\<x[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Input signal x[n] = \>", 
        x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        ListPlot[Take[Y1pts, \(-64\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] {Blue}, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr4 = 
        ListPlot[Y2pts, PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] Red, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr4, PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 0.5]}, 
        AxesLabel \[Rule] {"\<n\>", "\<y[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Output signal y[n] = x[n] - \!\(\@2\)x[n-1] + \
x[n-2]\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The  amplitude  responses\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Low  frequency:  A[0.10] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]0  .10\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(0.10  \[ImaginaryI]\)]]\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<High frequency:  A[\!\(\(2  \[Pi]\)\/3\)] = |H[\!\(\
\[ExponentialE]\^\(\[ImaginaryI]2\[Pi]/3\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ 2.  \[Pi]/3\)]]\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<       0.20\[Cross]A[\!\(\(2  \[Pi]\)\/3\)] = 0.20\
\[Cross]|H[\!\(\[ExponentialE]\^\(\[ImaginaryI]2\[Pi]/3\)\)]| =  \>\"", 
        0.20  Abs[
            H[\[ExponentialE]\^\(\[ImaginaryI]\ 2.  \[Pi]/3\)]]\ ];\)\ \)}], \
"Input"],

Cell[TextData[{
  StyleBox["Figure 9.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The input ",
  Cell[BoxData[
      \(x[n] = cos \((0.10  n)\) + 0.20  sin \((\(2  \[Pi]\)\/3\ n)\)\)]],
  " and output  ",
  Cell[BoxData[
      \(y[n]\)]],
  "."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.22.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given the filter  ",
  Cell[BoxData[
      \(y[n]\ \  = \ \ x[n] + 2\/3\ \@2\ y[n - 1] - 4\/9\ y[n - 2]\)]],
  ".\n\n",
  StyleBox["9.22 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that it is a boosting up filter for the signals ",
  Cell[BoxData[
      \(cos \((\(\[Pi]\/4\) n)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\(\[Pi]\/4\) n)\)\)]],
  " and calculate the amplitude response  ",
  Cell[BoxData[
      \(A \((\[Pi]\/4)\)\)]],
  ".\n\n",
  StyleBox["9.22 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Calculate the amplitude responses ",
  Cell[BoxData[
      RowBox[{"A", \((\[Pi]\/8)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "A", \((2.60)\)}]]],
  " and investigate the the filtered signal for  ",
  Cell[BoxData[
      \(x[n] = \ 
        cos \((\[Pi]\/8\ n)\) + sin \((\[Pi]\/4\ n)\) + 
          sin \((2.60\ n)\)\)]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000550000Qb000`400?l0
0000o`00003oo`3ooom60?ooo`00o`3ooom60?ooo`00o`3ooom60?ooo`00
o`3ooom60?ooo`00o`3ooom60?ooo`00o`3ooom60?ooo`00o`3ooom60?oo
o`00o`3ooom60?ooo`00o03oool3000004H0oooo003m0?ooo`030000003o
ool0oooo04D0oooo002b0?ooo`<00000803oool400000240oooo1@000016
0?ooo`00/`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0280oooo00@000000?ooo`3oool00000A`3oool00;00oooo1@00000Q0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`000000A`3oool00;00
oooo00@000000?ooo`3oool000008`3oool00`000000oooo0?ooo`0R0?oo
o`800000A`3oool00;40oooo00<000000?ooo`0000008@3oool010000000
oooo0?ooo`00001/0?ooo`00/P3oool200000280oooo0P00000K0?ooo``0
000000<0oooo0000000000000P0000110?ooo`00o`3ooom60?ooo`00[P3o
ool8000001d0oooo2000001Z0?ooo`00o`3ooolN0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0803oool00?l0oooo7`3oool01000
0000oooo0?ooo`00000S0?ooo`00mP3oool2000000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool00000
02<0oooo003e0?ooo`040000003oool0oooo000000D0oooo00@000000?oo
o`3oool000007@3oool00`000000oooo0000000S0?ooo`00[`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`000000703oool500000280oooo002`0?ooo`04
0000003oool0oooo00000240oooo00@000000?ooo`3oool000007`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0000004<0oooo002a0?oo
o`030000003oool000000280oooo00<000000?ooo`000000703oool01000
0000oooo0?ooo`0000050?ooo`D00000@P3oool00;40oooo00<000000?oo
o`0000008P3oool00`000000oooo0000000M0?ooo`800000C@3oool00;00
oooo1@00000P0?ooo`D00000C@3oool3000001/0oooo003o0?ooobL0oooo
00D000000?ooo`3oool0oooo0000000J0?ooo`00SP3ooonC000000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`00SP3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo00<0oooo1P00000I0?ooo`00SP3oool00`000000oooo0?ooo`2F
0?ooo`050000003oool0oooo0?ooo`0000006@3oool008h0oooo00<00000
0?ooo`3oool0U`3oool3000001X0oooo002>0?ooo`030000003oool0oooo
0;@0oooo002>0?ooo`030000003oool0oooo0;@0oooo002>0?ooo`030000
003oool0oooo0;@0oooo002>0?ooo`030000003oool0oooo0;@0oooo002>
0?ooo`030000003oool0oooo0;@0oooo002>0?ooo`030000003oool0oooo
0;@0oooo002>0?ooo`030000003oool0oooo0;@0oooo002>0?ooo`030000
003oool0oooo0;@0oooo002>0?ooo`030000003oool0oooo0;@0oooo002>
0?ooo`030000003oool0oooo0;@0oooo002>0?ooo`030000003oool0oooo
08P0oooo203o000T0?ooo`00O03oool2000000@0oooo0P0000040?ooo`80
0000103oool00`000000oooo0?ooo`1i0?ooo`l0o`00;03oool007/0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo06l0oooo2P3o000k0?ooo`00N`3oool010000000
oooo0?ooo`00000;0?ooo`040000003oool0oooo0?ooo`800000JP3oool6
0?l004D0oooo001k0?ooo`040000003oool0oooo000000T0oooo0P000004
0?ooo`030000003oool0oooo06@0oooo1@3o001;0?ooo`00N`3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0H@3oool30?l00500oooo001l0?ooo`8000002P3oool30000
00<0oooo00<000000?ooo`3oool0GP3oool30?l005<0oooo002>0?ooo`03
0000003oool0oooo05/0oooo0`3o001F0?ooo`00SP3oool00`000000oooo
0?ooo`1H0?ooo`<0o`00F@3oool008h0oooo00<000000?ooo`3oool0E03o
ool40?l005`0oooo002>0?ooo`030000003oool0oooo0580oooo0P3o001P
0?ooo`00SP3oool00`000000oooo0?ooo`1@0?ooo`80o`00HP3oool008h0
oooo00<000000?ooo`3oool0CP3oool20?l006@0oooo002>0?ooo`030000
003oool0oooo04`0oooo0P3o001V0?ooo`00SP3oool00`000000oooo0?oo
o`1:0?ooo`80o`00J03oool008h0oooo00<000000?ooo`3oool0B@3oool0
0`3o0000oooo0?ooo`1X0?ooo`00SP3oool00`000000oooo0?ooo`170?oo
o`80o`00J`3oool008h0oooo00<000000?ooo`3oool0AP3oool00`3o0000
oooo0?ooo`1[0?ooo`00SP3oool00`000000oooo0?ooo`150?ooo`030?l0
003oool0oooo06`0oooo00270?ooo`D000000P3oool00`000000oooo0?oo
o`140?ooo`030?l0003oool0oooo06d0oooo00290?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`1^
0?ooo`00R@3oool00`000000oooo0?ooo`020?ooo`800000@`3oool00`3o
0000oooo0?ooo`1_0?ooo`00R@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0440oooo00<0o`000?ooo`3oool0L03oool008T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030?l0
003oool0oooo0740oooo00280?ooo`800000103oool00`000000oooo0?oo
o`0o0?ooo`030?l0003oool0oooo0780oooo002>0?ooo`030000003oool0
oooo03h0oooo00<0o`000?ooo`3oool0L`3oool008h0oooo00<000000?oo
o`3oool0?@3oool00`3o0000oooo0?ooo`1d0?ooo`00SP3oool00`000000
oooo0?ooo`0m0?ooo`030?l0003oool0oooo07@0oooo002>0?ooo`030000
003oool0oooo03`0oooo00<0o`000?ooo`3oool0M@3oool008h0oooo00<0
00000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`1f0?ooo`00SP3oool0
0`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo07L0oooo002>0?oo
o`030000003oool0oooo03T0oooo00<0o`000?ooo`3oool0N03oool008h0
oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`1h0?ooo`00
SP3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo07T0oooo
002>0?ooo`030000003oool0oooo03L0oooo00<0o`000?ooo`3oool0NP3o
ool008h0oooo00<000000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`1j
0?ooo`00N`3oool500000080oooo0P0000040?ooo`800000103oool00`00
0000oooo0?ooo`0f0?ooo`030?l0003oool0oooo07/0oooo001m0?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`0e0?ooo`030?l0003oool0oooo07`0oooo001m0?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`3oool0oooo0P00000f0?oo
o`030?l0003oool0oooo07`0oooo001m0?ooo`030000003oool0oooo00P0
oooo0P0000040?ooo`030000003oool0oooo03@0oooo00<0o`000?ooo`3o
ool0O@3oool007d0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo03<0oooo00<0o`000?ooo`3oool0
OP3oool007`0oooo0P00000:0?ooo`<000000`3oool00`000000oooo0?oo
o`0c0?ooo`030?l0003oool0oooo07h0oooo002>0?ooo`030000003oool0
oooo0380oooo00<0o`000?ooo`3oool0O`3oool008h0oooo00<000000?oo
o`3oool0<P3oool00`3o0000oooo0?ooo`1o0?ooo`00SP3oool00`000000
oooo0?ooo`0a0?ooo`030?l0003oool0oooo0800oooo002>0?ooo`030000
003oool0oooo0340oooo00<0o`000?ooo`3oool0P03oool008h0oooo00<0
00000?ooo`3oool0<03oool00`3o0000oooo0?ooo`210?ooo`00SP3oool0
0`000000oooo0?ooo`0`0?ooo`030?l0003oool0oooo0840oooo002>0?oo
o`030000003oool0oooo02l0oooo00<0o`000?ooo`3oool0PP3oool008h0
oooo00<000000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`220?ooo`00
SP3oool00`000000oooo0?ooo`0^0?ooo`030?l0003oool0oooo08<0oooo
002>0?ooo`030000003oool0oooo02h0oooo00<0o`000?ooo`3oool0P`3o
ool008h0oooo00<000000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`24
0?ooo`00Q`3oool4000000<0oooo00<000000?ooo`3oool0;@3oool00`3o
0000oooo0?ooo`240?ooo`00Q`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo02`0oooo00<0o`000?ooo`3oool0Q@3oool008P0oooo
00<000000?ooo`3oool00`3oool40?l002/0oooo00<0o`000?ooo`3oool0
Q@3oool008T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?l002L0oooo00<0o`000?ooo`3oool0QP3oool008L0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`<0o`00903o
ool00`3o0000oooo0?ooo`260?ooo`00R03oool2000000@0oooo00<00000
0?ooo`3oool01`3oool20?l00240oooo00<0o`000?ooo`3oool0Q`3oool0
08h0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0N0?oo
o`030?l0003oool0oooo08L0oooo002>0?ooo`030000003oool0oooo00X0
oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`280?ooo`00
SP3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo01/0oooo
00<0o`000?ooo`3oool0R03oool008h0oooo00<000000?ooo`3oool0303o
ool20?l001X0oooo00<0o`000?ooo`3oool0R@3oool008h0oooo00<00000
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0
oooo08T0oooo002>0?ooo`030000003oool0oooo00l0oooo00<0o`000?oo
o`3oool05@3oool00`3o0000oooo0?ooo`2:0?ooo`00SP3oool00`000000
oooo0?ooo`0@0?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3o
ool0RP3oool008h0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0B0?ooo`030?l0003oool0oooo08/0oooo002>0?ooo`030000003o
ool0oooo0180oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?oo
o`2<0?ooo`00SP3oool00`000000oooo0?ooo`0C0?ooo`030?l0003oool0
oooo00l0oooo00<0o`000?ooo`3oool0S03oool008h0oooo00<000000?oo
o`3oool0503oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo
08d0oooo002>0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`2>0?ooo`00N`3oool4000000<0oooo
0P0000040?ooo`800000103oool00`000000oooo0?ooo`0F0?ooo`80o`00
2`3oool00`3o0000oooo0?ooo`2>0?ooo`00N`3oool00`000000oooo0?oo
o`090?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
603oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo08l0oooo
001l0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool0oooo
0P00000J0?ooo`80o`001P3oool00`3o0000oooo0?ooo`2@0?ooo`00O@3o
ool00`000000oooo0?ooo`080?ooo`800000103oool00`000000oooo0?oo
o`0K0?ooo`H0o`00T`3oool007/0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;@0oooo001l
0?ooo`8000002P3oool3000000<0oooo00<000000?ooo`3oool0]03oool0
0?l0ooooAP3oool00?l0ooooAP3oool00?l0ooooAP3oool00?l0ooooAP3o
ool00?l0ooooAP3oool00?l0ooooAP3oool008`0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`2]0?ooo`00R`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0:`0oooo00230?ooo`80000000<0
oooo0000000000000P3oool00`000000oooo0?ooo`020?ooo`<000001@3o
ool00`000000oooo0?ooo`2[0?ooo`00P`3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0Z`3oool008@0oooo0`00
00030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool000000:d0oooo00240?ooo`030000003oool0000000<0oooo
00@000000?ooo`3oool0oooo1P0000030?ooo`030000003oool0oooo0:/0
oooo00250?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`040000003oool0oooo00000:h0oooo00240?ooo`80
00001P3oool010000000oooo0?ooo`3oool300000080oooo00<000000?oo
o`3oool0[@3oool00?l0ooooAP3oool00?l0ooooAP3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{325, 135},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Figure 9.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "The amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\) = \(\(|\)\(1\/\(1 - 
                2\/3\ \(\@2\) z\^\(-1\) + \(4\/9\) z\^\(-2\)\)\)\(|\)\)\)]],
  " for  ",
  Cell[BoxData[
      \(y[n] = x[n] + \(2\/3\) \(\@2\) y[n - 1] - \(4\/9\) y[n - 2]\)]],
  ". "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000::0000UB000`400?l0
0000o`00003oo`3ooooo0?oooh`0oooo003o0?ooool0ooooS03oool00?l0
ooooo`3ooon<0?ooo`00o`3ooooo0?oooh`0oooo003o0?ooool0ooooS03o
ool005X0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`030000003oool0
oooo0?l0oooo3@3oool005X0oooo00<000000?ooo`3oool0o`3ooolO0?oo
o`030000003oool0oooo03@0oooo00<0o`000?ooo`3oool0e@3oool005X0
oooo00<000000?ooo`3oool0o`3ooolO0?ooo`030000003oool0oooo03@0
oooo00<0o`000?ooo`3oool0e@3oool005X0oooo00<000000?ooo`3oool0
o`3ooolO0?ooo`030000003oool0oooo03<0oooo00<0o`000?ooo`3o0000
eP3oool005X0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`030000003o
ool0oooo03<0oooo00<0o`000?ooo`3o0000eP3oool005X0oooo00<00000
0?ooo`3oool0=03oool00`3o0000oooo0?ooo`3W0?ooo`030000003oool0
oooo0380oooo00@0o`000?ooo`3oool0o`00eP3oool005X0oooo00<00000
0?ooo`3oool0=03oool00`3o0000oooo0?ooo`3W0?ooo`030000003oool0
oooo0380oooo00D0o`000?ooo`000?l0oooo0?l0001i0?ooo`030000o`3o
ool0oooo05T0oooo001J0?ooo`030000003oool0oooo03<0oooo0P3o003Y
0?ooo`030000003oool0oooo0380oooo00D0o`000000o`3oool0003o0?l0
001h0?ooo`030000o`3oool0003o05X0oooo001J0?ooo`030000003oool0
oooo03<0oooo0P3o003Y0?ooo`030000003oool0oooo0340oooo00H0o`00
0?ooo`000?l0oooo0000o`3o001h0?ooo`030000o`3o0000003o05X0oooo
001B0?ooo`@00000103oool00`000000oooo0?ooo`0b0?ooo`030?l0003o
ool0o`000>T0oooo00<000000?ooo`3oool0<@3oool00`3o0000003o0?oo
o`020?ooo`030000o`3o0000oooo07D0oooo00<0003o0?l0003oool00P3o
001I0?ooo`00DP3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0380oooo00@0o`000?ooo`3oool0o`00hP3oool3000000<0oooo00<0
00000?ooo`3oool0<@3oool00`3o0000003o0?ooo`030?ooo`030?l0003o
ool0oooo07@0oooo00<0003o0?l0003oool00P3oool20?l005L0oooo001C
0?ooo`030000003oool0oooo00@0oooo0`00000a0?ooo`050?l0003oool0
oooo0?ooo`3o0000JP3oool00`3o0000oooo0?ooo`1f0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0<03oool00`3o0000003o0?oo
o`040?ooo`030?l0003oool0oooo07<0oooo00<0003o0?l0003oool0103o
ool00`000?l0o`000?l0001E0?ooo`00C03oool4000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0a0?ooo`050?l0003oool0
oooo0?ooo`3o0000JP3oool00`3o0000oooo0?ooo`1c0?ooo`D000000`3o
ool300000300oooo00<0o`000?ooo`3oool0103oool00`3o0000003o0?oo
o`1b0?ooo`030000o`3o0000oooo00D0oooo00<0003o0?ooo`3oool00P3o
001C0?ooo`00DP3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0300oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`1X0?ooo`80o`00KP3oool400000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0_0?ooo`030?l000000?l0oooo00H0oooo
00<0o`000?ooo`3oool0L@3oool00`000?l0o`000?ooo`060?ooo`040000
o`3oool0oooo0?l005<0oooo001C0?ooo`8000001@3oool00`000000oooo
0?ooo`0`0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
J03oool20?l007D0oooo00<000000?ooo`000000103oool00`000000oooo
0?ooo`0_0?ooo`030?l0003oool0oooo00H0oooo00<0o`000000o`3oool0
L03oool00`000?l0o`000?ooo`080?ooo`030000o`3oool0o`0005<0oooo
001J0?ooo`030000003oool0oooo02l0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`1X0?ooo`80o`00MP3oool2000000@0oooo00<0
00000?ooo`3oool0;P3oool00`000?l0o`000?ooo`070?ooo`030?l0003o
ool0003o06l0oooo00<0003o0?l0003oool02P3oool00`000?l0oooo0?l0
001B0?ooo`00FP3oool00`000000oooo0?ooo`0_0?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool0J03oool00`3o0000oooo0?l0001k
0?ooo`030000003oool0oooo02h0oooo00<0o`000?ooo`3oool0203oool0
0`3o0000003o0?ooo`1^0?ooo`030000o`3o0000oooo00X0oooo00<0003o
0?ooo`3o0000DP3oool005X0oooo00<000000?ooo`3oool0;P3oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo06L0oooo00@0o`000?oo
o`3oool0o`00N`3oool00`000000oooo0?ooo`0]0?ooo`030000o`3o0000
oooo00T0oooo00<0o`000?ooo`000?l0K@3oool00`000?l0o`000?ooo`0<
0?ooo`030000o`3o0000oooo0540oooo001J0?ooo`030000003oool0oooo
02h0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`1V0?oo
o`040?l0003oool0oooo0?l000d0oooo00<0o`000?ooo`3oool0J`3oool0
0`000000oooo0?ooo`0]0?ooo`030000o`3o0000oooo00T0oooo00<0o`00
0?ooo`000?l0K@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o0000
oooo0540oooo001J0?ooo`030000003oool0oooo02`0oooo0P000?l80?oo
o`030?l0003oool0oooo06H0oooo00D0o`000?ooo`3oool0oooo0?l00004
0?ooo`80003o1P3oool20?l006`0oooo00<000000?ooo`3oool0;03oool0
0`000?l0o`000?ooo`0;0?ooo`030?l0003oool0003o06/0oooo00<0003o
0?l0003oool03P3oool00`3o0000oooo0?ooo`1@0?ooo`00FP3oool00`00
0000oooo0?ooo`0/0?ooo`030000o`3o0000003o00<0003o103oool00`3o
0000oooo0?ooo`1V0?ooo`050?l0003oool0oooo0?ooo`3o0000103oool0
0`000?l0oooo0000o`030000o`050?ooo`3o0000oooo0?ooo`3o0000J`3o
ool00`000000oooo0?ooo`0/0?ooo`030000o`3o0000oooo00/0oooo00<0
o`000?ooo`000?l0J`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo0500oooo001J0?ooo`030000003oool0oooo02/0oooo00<0003o
0?l0003oool0103oool30000o`030?ooo`3o0000oooo06L0oooo00D0o`00
0?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo00@0oooo0`00
0?l20?ooo`030?l0003oool0oooo06P0oooo00<000000?ooo`3oool0:`3o
ool00`000?l0o`000?ooo`0<0?ooo`030?l0003oool0003o06X0oooo00<0
003o0?l0003oool03`3oool00`000?l0o`000?ooo`1@0?ooo`00FP3oool0
0`000000oooo0?ooo`0[0?ooo`030000o`3o0000oooo00H0oooo00<0003o
0?ooo`3o0000J03oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0
oooo0000o`H0oooo00<0o`000?ooo`000?l00`3oool00`3o0000oooo0?oo
o`1W0?ooo`030000003oool0oooo02/0oooo00<0003o0?l0003oool03@3o
ool00`3o0000003o0?ooo`1Y0?ooo`030?l0003oool0oooo00l0oooo00<0
003o0?l0003oool0D03oool005X0oooo00<000000?ooo`3oool0:P3oool0
0`000?l0oooo0?l000080?ooo`030000o`3o0000oooo06L0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0000o`070?ooo`040?l0003oool0
oooo0000o`80oooo00<0o`000?ooo`3oool0I`3oool00`000000oooo0?oo
o`0[0?ooo`030000o`3o0000oooo00d0oooo00<0o`000?ooo`000?l0J@3o
ool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo04l0oooo001J
0?ooo`030000003oool0oooo02X0oooo00<0003o0?l0003oool0203oool0
0`000?l0o`000?ooo`1W0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`000?l01P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0
o`000?ooo`3oool0IP3oool00`000000oooo0?ooo`0[0?ooo`030?l0003o
ool0oooo00d0oooo00<0o`000?ooo`000?l0J@3oool00`3o0000oooo0?oo
o`0@0?ooo`030?l0003oool0oooo04l0oooo001J0?ooo`030000003oool0
oooo02T0oooo00<0003o0?ooo`3o00002P3oool00`000?l0oooo0?ooo`1V
0?ooo`030?l0003oool0oooo0080oooo00<0o`000000o`3oool01P3oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000I`3o
ool00`000000oooo0?ooo`0Z0?ooo`030000o`3o0000oooo00l0oooo00<0
o`000000o`3oool0I`3oool00`000?l0o`000?ooo`0A0?ooo`030?l0003o
ool0oooo04l0oooo001J0?ooo`030000003oool0oooo02T0oooo00<0003o
0?ooo`3o00002P3oool00`000?l0o`000?ooo`1V0?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0I03oool0
0`000000oooo0?ooo`0Z0?ooo`030000o`3o0000oooo00l0oooo00<0o`00
0?ooo`000?l0I`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o0000
oooo04l0oooo001J0?ooo`030000003oool0oooo02P0oooo00<0003o0?oo
o`3o00002`3oool00`000?l0o`000?ooo`1V0?ooo`030?l0003oool0oooo
0080oooo00<0003o0?l0003oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000o`3o0000oooo0100oooo00<0o`000000
o`3oool0IP3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo
04h0oooo001J0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3o
0000303oool00`000?l0oooo0?ooo`1U0?ooo`030?l0003oool0oooo0080
oooo00<0003o0?l0003oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0H`3oool00`000000
oooo0?ooo`0Z0?ooo`030?l0003oool0oooo0100oooo00<0o`000000o`3o
ool0IP3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo04h0
oooo001J0?ooo`030000003oool0oooo02L0oooo00@0003o0?ooo`3oool0
o`00303oool00`000?l0oooo0?ooo`1T0?ooo`030?l0003oool0oooo0080
oooo00@0003o0?ooo`3oool0o`00103oool00`3o0000oooo0?ooo`060?oo
o`050000o`3oool0oooo0?ooo`3o0000I@3oool00`000000oooo0?ooo`0Y
0?ooo`030000o`3o0000oooo0180oooo00<0o`000000o`3oool0I03oool0
0`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo04h0oooo001J0?oo
o`030000003oool0oooo02L0oooo00<0003o0?ooo`3o00003@3oool00`3o
0000003o0?ooo`1T0?ooo`030?l0003oool0oooo0080oooo00@0003o0?oo
o`3oool0o`00103oool00`3o0000oooo0?ooo`060?ooo`050000o`3oool0
oooo0?ooo`3o0000I@3oool00`000000oooo0?ooo`0Y0?ooo`030000o`3o
0000oooo0180oooo00<0o`000000o`3oool0I03oool00`3o0000oooo0?oo
o`0C0?ooo`030?l0003oool0oooo04h0oooo001J0?ooo`030000003oool0
oooo02H0oooo00@0003o0?ooo`3oool0o`003@3oool00`3o0000003o0?oo
o`0`0?ooo`030?l0003oool0oooo0340oooo00D0o`000?ooo`3oool0oooo
0000o`030?ooo`050?l0003oool0oooo0?ooo`3o00002P3oool01@000?l0
oooo0?ooo`3oool0o`0006@0oooo00<000000?ooo`3oool0:@3oool00`00
0?l0o`000?ooo`0C0?ooo`030?l0003oool0oooo06<0oooo00<0o`000?oo
o`3oool04`3oool00`3o0000003o0?ooo`1>0?ooo`00FP3oool00`000000
oooo0?ooo`0V0?ooo`040000o`3oool0oooo0?l000d0oooo00<0o`000?oo
o`000?l0<03oool00`3o0000oooo0?ooo`0a0?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool0103o0000oooo0?ooo`3o000:0?ooo`050000o`3o
ool0oooo0?ooo`3o0000I03oool00`000000oooo0?ooo`0Y0?ooo`030?l0
003oool0oooo01<0oooo00<0o`000?ooo`3oool0HP3oool00`3o0000003o
0?ooo`0E0?ooo`030?l0003oool0oooo04d0oooo001J0?ooo`030000003o
ool0oooo02D0oooo00@0003o0?ooo`3oool0o`003P3oool00`3o0000oooo
0000o`090?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3oool0
<@3oool0103o0000oooo0?ooo`000?l50?ooo`030?l0003oool0o`0000`0
oooo00@0003o0?ooo`3oool0o`00I03oool00`000000oooo0?ooo`0X0?oo
o`030000o`3o0000oooo01D0oooo00<0o`000?ooo`3oool0H@3oool00`3o
0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo04d0oooo001J0?ooo`03
0000003oool0oooo02D0oooo00@0003o0?ooo`3oool0o`003P3oool00`3o
0000oooo0000o`090?ooo`030?l0003oool0oooo02<0oooo0P3o000c0?oo
o`040?l0003oool0oooo0000o`D0oooo00<0o`000?ooo`3o0000303oool0
10000?l0oooo0?ooo`3o001T0?ooo`030000003oool0oooo02P0oooo00<0
003o0?l0003oool05@3oool00`3o0000oooo0?ooo`1Q0?ooo`030?l0003o
ool0oooo01D0oooo00<0o`000?ooo`3oool0C@3oool005X0oooo00<00000
0?ooo`3oool0903oool01@000?l0oooo0?ooo`3oool0o`0000l0oooo00<0
o`000?ooo`000?l01`3oool20?l002D0oooo0P3o000c0?ooo`030?l0003o
ool0003o00L0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?l0
001T0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool05@3o
ool00`000?l0o`000?ooo`1Q0?ooo`030?l0003oool0oooo01D0oooo00<0
o`000000o`3oool0C@3oool00580oooo1@0000030?ooo`030000003oool0
oooo02@0oooo00D0003o0?ooo`3oool0oooo0?l0000?0?ooo`030?l0003o
ool0003o00L0oooo0P3o000U0?ooo`030?l0003oool0o`000380oooo00<0
o`000?ooo`000?l01`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0o`0006@0oooo00<000000?ooo`3oool0:03oool00`3o0000oooo0?oo
o`0F0?ooo`030?l0003oool0oooo05l0oooo00<0o`000000o`3oool05P3o
ool00`3o0000003o0?ooo`1=0?ooo`00E03oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02@0oooo00@0003o0?ooo`3oool0o`00403o
ool0103o0000oooo0?ooo`000?l60?ooo`030?l0003oool0o`0002@0oooo
00<0o`000?ooo`3o0000<P3oool00`3o0000oooo0000o`0G0?ooo`030000
o`3o0000oooo05/0oooo100000040?ooo`030000003oool0oooo02L0oooo
00<0003o0?l0003oool05`3oool00`000?l0o`000?ooo`1O0?ooo`030?l0
003oool0oooo01L0oooo00<0o`000?ooo`3oool0C03oool005@0oooo00<0
00000?ooo`3oool00`3oool3000002<0oooo00D0003o0?ooo`3oool0oooo
0?l0000@0?ooo`040?l0003oool0oooo0000o`H0oooo00<0o`000?ooo`3o
0000903oool00`3o0000oooo0?l0000b0?ooo`030?l0003oool0003o01L0
oooo00<0003o0?l0003oool0F`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo02L0oooo00<0003o0?l0003oool05`3oool00`000?l0
o`000?ooo`1O0?ooo`030?l0003oool0oooo01L0oooo00<0o`000?ooo`3o
ool0C03oool004`0oooo100000040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool08`3oool01@000?l0oooo0?ooo`3oool0o`000100
oooo00@0o`000?ooo`3oool0003o1@3oool0103o0000oooo0?ooo`3o000T
0?ooo`030?l0003oool0o`000380oooo00<0o`000000o`3oool05`3oool0
0`000?l0oooo0?l0001L0?ooo`030000003oool0oooo00@0oooo0`00000W
0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?l0003oool0G@3oool0
0`3o0000003o0?ooo`0H0?ooo`030?l000000?l0oooo04`0oooo001D0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool08`3oool01000
0?l0oooo0?ooo`3o000A0?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool0103o0000oooo0?ooo`3o000S0?ooo`040?l0003oool0oooo0?l00340
oooo00<0o`000?ooo`000?l06@3oool00`000?l0o`000?ooo`1D0?ooo`@0
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0
oooo00<0o`000?ooo`3oool0603oool00`000?l0o`000?ooo`1M0?ooo`03
0?l000000?l0oooo01P0oooo00<0o`000000o`3oool0C03oool005<0oooo
0P0000050?ooo`030000003oool0oooo02<0oooo00@0003o0?ooo`3oool0
o`004@3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00@0o`000?oo
o`3oool0o`008`3oool0103o0000oooo0?ooo`3o000a0?ooo`030?l0003o
ool0003o01T0oooo00<0003o0?l0003oool0FP3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo02H0oooo00<0003o0?l0003oool0
6@3oool00`000?l0o`000?ooo`1M0?ooo`030?l0003oool0oooo01P0oooo
00<0o`000000o`3oool0C03oool005X0oooo00<000000?ooo`3oool08P3o
ool01@000?l0oooo0?ooo`3oool0o`000140oooo00<0o`000?ooo`3oool0
0P3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0o`000?ooo`3o
ool08@3oool0103o0000oooo0?ooo`3o000a0?ooo`030?l0003oool0003o
01T0oooo00<0003o0?l0003oool0F`3oool2000000D0oooo00<000000?oo
o`3oool09P3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0o`00
05`0oooo00<0o`000000o`3oool06P3oool00`3o0000oooo0?ooo`1;0?oo
o`00FP3oool00`000000oooo0?ooo`0L0?ooo`030?l0003oool0oooo00<0
oooo00@0003o0?ooo`3oool0o`004`3oool01@3o0000oooo0?ooo`3oool0
003o0080oooo00D0o`000?ooo`3oool0oooo0?l0000S0?ooo`040?l0003o
ool0oooo0?l00340oooo00<0o`000000o`3oool06P3oool00`000?l0oooo
0?ooo`1Q0?ooo`030000003oool0oooo02H0oooo00<0o`000?ooo`3oool0
6P3oool00`000?l0o`000?ooo`1K0?ooo`030?l000000?l0oooo01X0oooo
00<0o`000000o`3oool0B`3oool005X0oooo00<000000?ooo`3oool0703o
ool30?l000<0oooo00@0003o0?ooo`3oool0o`004`3oool01@3o0000oooo
0?ooo`3oool0003o0080oooo00D0o`000?ooo`3oool0oooo0?l0000S0?oo
o`050?l0003oool0oooo0?ooo`3o0000<03oool00`3o0000003o0?ooo`0J
0?ooo`030000o`3oool0oooo0640oooo00<000000?ooo`3oool09P3oool0
0`3o0000oooo0?ooo`0J0?ooo`030000o`3o0000oooo05/0oooo00<0o`00
0000o`3oool06P3oool00`3o0000003o0?ooo`1;0?ooo`00FP3oool00`00
0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo0080o`0000D0oooo0000
o`3oool0oooo0?l0000C0?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3o0000103oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool0;P3oool00`3o0000003o0?ooo`0J
0?ooo`030000o`3oool0oooo0640oooo00<000000?ooo`3oool09@3oool0
0`000?l0o`000?ooo`0K0?ooo`030000o`3o0000oooo05/0oooo00<0o`00
0?ooo`3oool06P3oool00`3o0000003o0?ooo`1;0?ooo`00FP3oool00`00
0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo0080oooo00@0003o0?l0
003oool0o`00503oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
o`0000@0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo02h0oooo00<0o`000000o`3oool06P3oool0
0`3o0000003o0?ooo`0:0?ooo`030?l0003oool0oooo05@0oooo00<00000
0?ooo`3oool09@3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3o0000
oooo05T0oooo00<0o`000000o`3oool06`3oool00`3o0000oooo0000o`1;
0?ooo`00FP3oool00`000000oooo0?ooo`0L0?ooo`030?l0003oool0oooo
0080oooo00@0003o0?ooo`3o0000o`00503oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3o0000oooo00@0oooo00<0o`000?ooo`3oool07`3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02h0oooo00<0003o
0?ooo`3oool06`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo02@0oooo00<0o`000?ooo`3oool0;@3oool00`000000oooo0?ooo`0U
0?ooo`030?l0003oool0oooo01`0oooo00<0003o0?l0003oool0F@3oool0
0`3o0000003o0?ooo`0K0?ooo`030?l0003oool0003o04/0oooo001J0?oo
o`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool0;P3oool00`000?l0oooo0?ooo`0K0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0903oool00`3o
0000oooo0?ooo`0]0?ooo`030000003oool0oooo02D0oooo00<0o`000?oo
o`3oool0703oool00`000?l0o`000?ooo`1I0?ooo`030?l000000?l0oooo
01`0oooo00<0o`000000o`3oool0BP3oool005X0oooo00<000000?ooo`3o
ool06`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo01H0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0^0?ooo`030000o`3oool0oooo01/0oooo00<0o`000000o`3o
ool0203oool20?l002D0oooo0P3o000_0?ooo`030000003oool0oooo02@0
oooo00<0003o0?l0003oool07@3oool00`000?l0o`000?ooo`1I0?ooo`03
0?l0003oool0oooo01`0oooo00<0o`000000o`3oool0BP3oool005X0oooo
00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo01H0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0000o`040?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`0^0?ooo`030000o`3oool0oooo01/0oooo
00<0o`000000o`3oool0203oool00`3o0000oooo0?l0000T0?ooo`80o`00
;`3oool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0oooo01h0oooo
00<0003o0?l0003oool0F03oool00`3o0000oooo0?ooo`0L0?ooo`030?l0
003oool0003o04X0oooo001J0?ooo`030000003oool0oooo01/0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0G0?ooo`070?l0003o
ool0oooo0?ooo`3o0000oooo0000o`040?ooo`030?l0003oool0oooo01h0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0]0?ooo`03
0000o`3o0000oooo01`0oooo00<0o`000000o`3oool0203oool00`3o0000
oooo0?l0000>0?ooo`030?l0003oool0oooo01<0oooo0P3o000_0?ooo`03
0000003oool0oooo02@0oooo00<0o`000?ooo`3oool07P3oool00`000?l0
o`000?ooo`0R0?ooo`030?l0003oool0oooo0380oooo00<0o`000000o`3o
ool07P3oool00`3o0000003o0?ooo`190?ooo`00FP3oool00`000000oooo
0?ooo`0K0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
5`3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`000?l0103oool00`3o
0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool0;03oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0003o
00P0oooo00<0o`000?ooo`3o00003P3oool20?l001<0oooo00@0o`000?oo
o`3oool0o`00;P3oool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0
oooo01h0oooo00<0003o0?l0003oool08P3oool20?l003<0oooo00<0o`00
0000o`3oool07P3oool00`3o0000003o0?ooo`190?ooo`00FP3oool00`00
0000oooo0?ooo`0K0?ooo`050?l0003oool0oooo0?ooo`000?l06P3oool0
1@3o0000oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003o
ool0003o00L0oooo00@0o`000?ooo`3oool0o`003P3oool00`3o0000oooo
0?l0000B0?ooo`040?l0003oool0oooo0?l002h0oooo00<000000?ooo`3o
ool0903oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo0200
oooo00<0o`000?ooo`3o0000<`3oool00`3o0000003o0?ooo`0O0?ooo`03
0?l000000?l0oooo04P0oooo001J0?ooo`030000003oool0oooo01/0oooo
00D0o`000?ooo`3oool0oooo0000o`0J0?ooo`040?l0003oool0oooo0?l0
00<0oooo00<0003o0?ooo`3oool00P3oool00`3o00000000000000020000
0080oooo0P00000G0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool0903oool4000000<0oooo00<000000000o`3oool07@3oool00`3o
0000oooo0000o`070?ooo`040?l0003oool0oooo0?l000d0oooo00@0o`00
0?ooo`3oool0oooo0P3o00060?ooo`800000103oool200000080oooo00@0
o`000?ooo`3oool0o`00;P3oool00`000000oooo0?ooo`0S0?ooo`030?l0
003oool0oooo0200oooo00<0o`000?ooo`3oool0803oool0103o0000oooo
0?ooo`3o000b0?ooo`030?l0003oool0oooo01l0oooo00<0o`000000o`3o
ool0:P3oool00`3o0000oooo0?ooo`0K0?ooo`00FP3oool00`000000oooo
0?ooo`0K0?ooo`050?l0003oool0oooo0?ooo`000?l06P3oool0103o0000
oooo0?ooo`3o00030?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`0000000`3oool010000000oooo0?ooo`00000F0?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool0903oool00`000000oooo0?ooo`03
0?ooo`04000000000?l0o`00000001h0oooo00<0o`000?ooo`000?l01P3o
ool0103o0000oooo0?ooo`3o000=0?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`05
0000003oool0oooo0000003o00000`3oool00`3o0000oooo0?ooo`0/0?oo
o`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool0803oool00`00
0?l0o`000?ooo`0P0?ooo`040?l0003oool0oooo0?l00380oooo00<0o`00
0?ooo`3oool0803oool00`3o0000oooo0?ooo`0X0?ooo`80o`007@3oool0
05X0oooo00<000000?ooo`3oool06`3oool0103o0000oooo0?ooo`000?lK
0?ooo`040?l0003oool0oooo0?l000@0oooo00L0003o0?ooo`3oool0oooo
0?l0003oool0000000<0oooo00@000000?ooo`3oool000005@3oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo02D0oooo00<000000?oo
o`3oool00P3oool010000000003o0?l00000000N0?ooo`030?l0003oool0
003o00H0oooo00D0o`000?ooo`3oool0oooo0?l0000<0?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?l0003oool00P3oool00`3o0000oooo
0?ooo`0/0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool0
803oool00`000000o`000000000200000080oooo0P00000I0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool0903oool4000000<0oooo
0P0000020?ooo`030?l0003oool0oooo0200oooo00<0o`000000o`3oool0
7@3oool2000000@0oooo0P0000020?ooo`040?l0003oool0oooo0?l001`0
oooo001J0?ooo`030000003oool0oooo01/0oooo00@0o`000?ooo`3oool0
003o6`3oool0103o0000oooo0?ooo`3o00040?ooo`070000o`3oool0oooo
0?ooo`3o0000oooo000000030?ooo`040000003oool0oooo00000180oooo
2@000?l20?ooo`030?l0003oool0oooo02H0oooo00P000000?ooo`3oool0
oooo000000000?l0o`00000001h0oooo00<0o`000?ooo`000?l01P3oool0
1@3o0000oooo0?ooo`3oool0o`0000`0oooo00<0o`000?ooo`3oool01@3o
ool90000o`050000003oool0oooo0000003o00000`3oool00`3o0000oooo
0?ooo`0/0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool0
8@3oool00`3o000000000?ooo`020?ooo`040000003oool0oooo000001P0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0T0?ooo`03
0000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`3o000S
0?ooo`030?l0003oool0oooo01/0oooo00@000000?ooo`3oool000000P3o
ool01@000000oooo0?ooo`000000o`0000<0oooo00<0o`000?ooo`3oool0
6P3oool005X0oooo00<000000?ooo`3oool06`3oool0103o0000oooo0?oo
o`000?lK0?ooo`030?l0003oool0o`0000H0oooo00H0003o0?ooo`3oool0
o`000?ooo`0000030?ooo`040000003oool0oooo00000140oooo00D0003o
0?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0o`0002H0oooo00@0
00000?ooo`3oool000000P3oool010000000003o0?l00000000N0?ooo`04
0?l0003oool0oooo0000o`@0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00D0003o0?oo
o`3o0000oooo000000020?ooo`040000003oool0oooo0000o`80oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0/0?ooo`030000003o
ool0oooo0280oooo00<0o`000000o`3oool08P3oool00`3o000000000?oo
o`020?ooo`040000003oool0oooo000001P0oooo00@0o`000?ooo`000?l0
003o0P3oool00`3o0000oooo0?ooo`0T0?ooo`030000003oool0oooo0080
oooo00H000000?ooo`3oool000000?l000000?lS0?ooo`030?l0003oool0
oooo01d0oooo00<000000?ooo`3oool00P000?l20?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool06P3oool005X0oooo00<000000?oo
o`3oool06`3oool0103o0000oooo0?ooo`000?lL0?ooo`80o`001P3oool0
10000?l0oooo0?ooo`3o0002000000@0oooo0P00000A0?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?l0
000W0?ooo`8000000`3oool00`000?l000000?l0000O0?ooo`040?l0003o
ool0oooo0000o`@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00<0oooo00@0003o0?ooo`3oool0
o`000P3oool2000000<0oooo00@0003o000000000000o`00103oool00`3o
0000oooo0?ooo`0/0?ooo`030000003oool0oooo0280oooo00<0o`000?oo
o`3oool08P3oool00`000?l0o`000?ooo`020?ooo`040000003oool0oooo
000001L0oooo00<0o`000?ooo`000?l00P3oool30000o`030?l0003oool0
oooo02@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
0000003o02<0oooo00<0003o0?l0003oool07P3oool010000000003o0?oo
o`0000020000o`030?l000000?l0oooo0080oooo00<0o`000?ooo`3oool0
6P3oool005X0oooo00<000000?ooo`3oool06P3oool0103o0000oooo0?oo
o`000?lM0?ooo`80o`001`3oool010000?l0oooo0?ooo`3o000B0?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0o`0002/0oooo00<0003o0?ooo`3o
00007`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0o`0000@0oooo00<0o`000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo02<0oooo00D0o`000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01D0oooo00<0o`00
0?ooo`000?l01@3oool0103o0000003o0000o`000?lQ0?ooo`040000003o
ool0oooo00000080oooo00D000000?ooo`3oool000000?l0000U0?ooo`03
0?l0003oool0oooo01X0oooo00/000000?ooo`3oool000000000o`3oool0
00000?ooo`3o000000000?ooo`030000o`030?ooo`3o0000oooo01X0oooo
001J0?ooo`030000003oool0oooo01X0oooo00@0o`000?ooo`3oool0003o
7@3oool20?l000L0oooo00@0003o0?ooo`3oool0o`00403oool20?l00005
0?ooo`3o0000oooo0?ooo`000?l01P3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0o`0002/0oooo00<0003o0?ooo`3o00007`3oool01@3o
0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o0000
oooo00D0oooo00<0o`000?ooo`3oool0:`3oool00`000000oooo0?ooo`0R
0?ooo`030?l0003oool0oooo0280oooo00<000000?l0003oool00`3oool2
000001P0oooo00<0o`000000o`3oool01P3oool00`3o0000oooo0000o`0R
0?ooo`800000103oool2000000030?ooo`3o0000oooo02@0oooo00<0003o
0?l0003oool06`3oool2000000060000o`3oool0oooo0?ooo`3o00000000
103oool00`000?l0oooo0?l0000K0?ooo`00FP3oool00`000000oooo0?oo
o`0J0?ooo`040?l0003oool0oooo0000oad0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?l0000?0?ooo`070?l0003oool0oooo0?ooo`3o
0000oooo0000o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?l0
003oool0:P3oool00`000?l0oooo0?l0000O0?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3o00001@3oool00`3o0000oooo0?ooo`090?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0Q0?ooo`030?l000000?l0oooo
02@0oooo00<0o`000?ooo`3oool06`3oool00`3o0000003o0?ooo`070?oo
o`040?l0003oool0oooo0000obX0oooo00<0o`000?ooo`3oool08`3oool0
0`000?l0o`000?ooo`0L0?ooo`050000o`3oool0oooo0?ooo`3o00001`3o
ool00`000?l0o`000?ooo`0J0?ooo`00FP3oool00`000000oooo0?ooo`0J
0?ooo`040?l0003oool0oooo0000oad0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?l0000>0?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
0000oooo02T0oooo00@0003o0?ooo`3oool0o`00803oool01`3o0000oooo
0?ooo`3oool0003o0?ooo`3o00001P3oool00`3o0000oooo0?ooo`080?oo
o`050?l0003oool0oooo0?ooo`000?l01`3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo02@0oooo00<0o`00
0000o`3oool06`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0
003o02X0oooo00<0o`000?ooo`3oool0903oool00`000?l0o`000?ooo`0J
0?ooo`030000o`3oool0oooo0080o`00203oool00`000?l0o`000?ooo`0J
0?ooo`00FP3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0003o
02T0oooo00<0003o0?l0003oool02`3oool20?l000D0oooo00<0003o0?l0
003oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
02P0oooo00<0003o0?ooo`3o00008@3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3o0000oooo00D0oooo00<0o`000?ooo`3oool0203oool0103o
0000oooo0?ooo`000?l90?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`000?l01@3oool00`3o0000oooo0?ooo`0;0?ooo`8000000P3oool2
000001X0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`0U
0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool0203oool0
103o0000oooo0?ooo`000?lY0?ooo`030?l0003oool0oooo02@0oooo00<0
003o0?l0003oool06P3oool00`000?l0o`000?l0000;0?ooo`030000o`3o
0000oooo01T0oooo001J0?oooad0000000<0o`00000000000?l0:@000000
0`000?l0o`000000000:000000030?l000000000000000@0000000@0003o
000000000000o`001P0000000`3o0000000000000007000000030?l00000
0?l0000002P0000000<0003o0000003o00008@0000000`3o000000000000
0002000000030000o`3o0000000000D0000000<0o`000000000000002000
00000`3o000000000000o`0;000000030?l00000000000000080000000@0
o`00000000000000003o100000000`3o0000000000000004000000P0oooo
00@000000?ooo`3oool000006`3oool00`000000oooo0?ooo`0Q0?ooo`03
0?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool06@3oool00`3o0000
oooo0?ooo`0:0?ooo`030?l0003oool0003o02P0oooo00<0o`000?ooo`3o
ool09@3oool00`000?l0oooo0?l0000H0?ooo`<0o`003@3oool00`000?l0
o`000?ooo`0;0?ooo`8000000P3oool2000000P0oooo001J0?ooo`030000
003oool0oooo01X0oooo00<0o`000?ooo`000?l0:P3oool01@000?l0oooo
0?ooo`3oool0000000L0oooo00<0o`000?ooo`3oool00`3oool01@000?l0
oooo0?ooo`3oool0o`0000H0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000003o0?ooo`0X0?ooo`030000o`3oool0o`000240oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`000?l0303oool01P3o0000oooo0?ooo`000000
oooo0?l00080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0<0?ooo`040000003oool0oooo000001/0oooo00<000000?ooo`3oool0
803oool00`3o0000003o0?ooo`0V0?ooo`030?l000000?l0oooo01P0oooo
00<0003o0?l0003oool0303oool00`3o0000003o0?ooo`0W0?ooo`030?l0
003oool0oooo02H0oooo00<0003o0?l0003oool05@3oool20?l000030000
o`3oool0oooo00h0oooo00<0o`000?ooo`3oool02`3oool010000000oooo
0?ooo`0000090?ooo`00FP3oool00`000000oooo0?ooo`0J0?ooo`030?l0
003oool0003o02X0oooo00D0o`000000o`3oool0oooo000000060?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`00
0?l09`3oool010000?l000000?ooo`3o000Q0?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`000?l01@3oool00`3o0000oooo0?ooo`070?oo
o`030?l000000?l0oooo00d0oooo00@0o`000?ooo`000000o`00103oool0
1@000?l0oooo0?ooo`3oool0o`0000d0oooo1000000L0?ooob<0000000<0
o`000000o`0000009P0000000`3o0000003o0000000G000000030000o`00
0000o`0000d0000000<0o`00000000000?l09`0000000`3o000000000000
000V000000030000o`000000o`0001D0000000<0o`000000o`0000004000
00000`3o0000000000000003000000P0oooo00@000000?ooo`3oool00000
2@3oool005X0oooo00<000000?ooo`3oool06P3oool00`3o0000003o0?oo
o`0[0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool0203oool00`3o0000oooo0000o`0W0?ooo`040000o`3o
ool0oooo0?l00240oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0000o`050?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
3@3oool0103o0000oooo0?ooo`3o00040?ooo`050000o`3oool0oooo0?oo
o`3o0000;@3oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo
02L0oooo00<0o`000000003oool05P3oool00`000?l0o`000?ooo`0>0?oo
o`030?l000000?l0oooo0280oooo00D000000?ooo`3oool0oooo0?l0000X
0?ooo`030000o`3oool0o`0001@0oooo00<0o`000?ooo`000?l01P3oool0
0`000000oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo1000000:
0?ooo`00FP3oool00`000000oooo0?ooo`0J0?ooo`030?l000000?l0oooo
02/0oooo00<0o`000000o`3oool01`3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo0?l0000;
0?ooo`030?l0003oool0003o02H0oooo00@0003o0?ooo`3oool0o`008@3o
ool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo0000o`D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0o`000?ooo`0?0?ooo`030?l0
003oool0o`0000D0oooo00@0003o0?ooo`3oool0o`00;@3oool00`000000
oooo0?ooo`0P0?ooo`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3o
ool05@3oool00`000?l0oooo0?l0000@0?ooo`030?l0003oool0oooo02D0
oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?l0000D0?ooo`03
0?l000000?l0oooo0180oooo00<0o`000?ooo`3oool05`3oool005X0oooo
00<000000?ooo`3oool06P3oool00`3o0000003o0?ooo`0[0?ooo`030?l0
00000?l0oooo00L0oooo00D0o`000?ooo`3oool0oooo0000o`080?ooo`05
0?l0003oool0oooo0?ooo`3o00002`3oool00`3o0000oooo0000o`0V0?oo
o`040000o`3oool0oooo0?l00240oooo00<0o`000?ooo`3oool00P3oool0
103o0000oooo0?ooo`000?l50?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?l0003oool03`3oool20?l000H0oooo00D0003o0?ooo`3oool0oooo
0?l0000/0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool0
9`3oool00`3o0000003o0?ooo`0D0?ooo`040000o`3oool0oooo0?l00100
oooo00<0o`000000o`3oool0903oool00`000?l0o`000?ooo`0X0?ooo`03
0000o`3oool0o`000180oooo00<0o`000000o`3oool04`3oool00`3o0000
oooo0?ooo`0G0?ooo`00FP3oool00`000000oooo0?ooo`0J0?ooo`030?l0
00000?l0oooo02/0oooo00<0o`000?ooo`000?l01P3oool01@3o0000oooo
0?ooo`3oool0003o00X0oooo00@0o`000?ooo`3oool0o`002`3oool0103o
0000oooo0?ooo`000?lT0?ooo`050000o`3oool0oooo0?ooo`3o00008P3o
ool0103o0000oooo0?ooo`3o00040?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?l0000A0?ooo`030?l0
003oool0oooo00D0oooo00@0003o0?ooo`3oool0o`00;03oool00`000000
oooo0?ooo`0O0?ooo`030?l000000?l0oooo02P0oooo00<0o`000000o`3o
ool0503oool00`000?l0oooo0?l0000B0?ooo`030?l0003oool0oooo02<0
oooo00<0o`000?ooo`3oool0:03oool00`000?l0oooo0?l0000B0?ooo`03
0?l000000?l0oooo01@0oooo00<0o`000?ooo`3oool05P3oool005X0oooo
00<000000?ooo`3oool06@3oool00`3o0000003o0?ooo`0/0?ooo`030?l0
003oool0003o00H0oooo00D0o`000?ooo`3oool0oooo0000o`0:0?ooo`04
0?l0003oool0oooo0?l000/0oooo00@0o`000?ooo`3oool0003o903oool0
1@000?l0oooo0?ooo`3oool0o`000280oooo00@0o`000?ooo`3oool0o`00
103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3o00006P3oool010000?l0oooo0?ooo`3o000/0?ooo`03
0000003oool0oooo01l0oooo00<0o`000000o`3oool0:@3oool00`3o0000
003o0?ooo`0B0?ooo`040000o`3oool0oooo0?l00180oooo00<0o`000000
o`3oool08`3oool00`3o0000oooo0?ooo`0Y0?ooo`030000o`3o0000oooo
0100oooo00<0o`000000o`3oool05@3oool00`3o0000oooo0?ooo`0F0?oo
o`00FP3oool00`000000oooo0?ooo`0I0?ooo`030?l000000?l0oooo02`0
oooo00<0o`000?ooo`3oool010000?l20?ooo`040?l0003oool0oooo0000
o``0oooo0P3o000<0?ooo`050?l0003oool0oooo0?ooo`000?l08`3oool0
1@000?l0oooo0?ooo`3oool0o`000280oooo00@0o`000?ooo`3oool0o`00
1@3oool40000o`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0
o`006`3oool00`000?l0oooo0?l0000/0?ooo`030000003oool0oooo01l0
oooo00<0o`000?ooo`3oool0:@3oool00`3o0000003o0?ooo`0B0?ooo`04
0000o`3oool0oooo0?l001<0oooo00<0o`000?ooo`3oool08P3oool00`3o
0000oooo0?ooo`0Y0?ooo`030000o`3oool0o`000100oooo00<0o`000000
o`3oool05@3oool00`3o0000003o0?ooo`0F0?ooo`00FP3oool00`000000
oooo0?ooo`0I0?ooo`030?l000000?l0oooo02`0oooo00<0o`000?ooo`3o
ool0103oool50000o`d0oooo0P3o000<0?ooo`050?l0003oool0oooo0?oo
o`000?l01@3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo
00<0oooo00D0003o0?ooo`3oool0oooo0?l0000R0?ooo`040?l0003oool0
oooo0?l000T0oooo1@000?l30?ooo`030?l0003oool0oooo01T0oooo00<0
003o0?ooo`3o0000;03oool00`000000oooo0?ooo`0O0?ooo`030?l0003o
ool0oooo02T0oooo00<0o`000?ooo`000?l04@3oool010000?l0oooo0?oo
o`3o000D0?ooo`030000o`3o0000oooo0280oooo00<0o`000?ooo`3oool0
:P3oool00`000?l0o`000?ooo`0>0?ooo`030?l000000?l0oooo01H0oooo
00<0o`000000o`3oool05P3oool005X0oooo00<000000?ooo`3oool06@3o
ool00`3o0000003o0?ooo`0]0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0:0?ooo`050?l0003o
ool0oooo0?ooo`000?l01@3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0
003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0000S0?ooo`04
0?l0003oool0oooo0?l000T0oooo00<0o`000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0J0?ooo`030000o`3o0000oooo02/0oooo00<000000?oo
o`3oool07P3oool00`3o0000003o0?ooo`0[0?ooo`030?l000000?l0oooo
0100oooo00@0003o0?ooo`3oool0o`005@3oool00`3o0000oooo0?ooo`0Q
0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?l0003oool03P3oool0
0`3o0000003o0?ooo`0G0?ooo`030?l000000?l0oooo01D0oooo001J0?oo
o`030000003oool0oooo01T0oooo00<0003o0?ooo`3oool0;@3oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo01`0oooo00<0o`000?oo
o`3oool00P3oool010000?l0oooo0?ooo`3oool20?l001L0oooo0P3o0003
0?ooo`050000o`3oool0oooo0?ooo`3o00008`3oool00`3o0000oooo0?l0
000;0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool06P3o
ool00`000?l0o`000?ooo`0[0?ooo`030000003oool0oooo01h0oooo00<0
o`000000o`3oool0:`3oool00`3o0000oooo0000o`0?0?ooo`040000o`3o
ool0o`000?l001H0oooo00<0003o0?l0003oool0803oool00`000?l0o`00
0?ooo`0/0?ooo`030000o`3o0000oooo00d0oooo00<0o`000?ooo`3oool0
5`3oool00`3o0000003o0?ooo`0E0?ooo`00FP3oool00`000000oooo0?oo
o`0I0?ooo`030000o`3oool0oooo02d0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0M0?ooo`050?l0003oool0oooo0?ooo`000?l0
0`3oool00`3o0000oooo0?l0000E0?ooo`030?l0003oool0o`0000<0oooo
00D0003o0?ooo`3oool0oooo0?l0000S0?ooo`030?l0003oool0o`0000/0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0J0?ooo`03
0000o`3o0000oooo02/0oooo00<000000?ooo`3oool07P3oool00`3o0000
003o0?ooo`0/0?ooo`030?l000000?l0oooo00d0oooo00<0003o0?l0003o
00006@3oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3o0000oooo02`0
oooo00<0003o0?l0003oool0303oool00`3o0000003o0?ooo`0H0?ooo`03
0?l0003oool0003o01D0oooo001J0?ooo`030000003oool0oooo01T0oooo
00<0003o0?ooo`3oool0;@3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo01h0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`03
0?l0003oool0o`0001D0oooo00@0o`000?ooo`3oool0o`000P3oool01@00
0?l0oooo0?ooo`3oool0o`0002<0oooo00<0o`000?ooo`3o00002`3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo01`0oooo00<0003o
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0
oooo02d0oooo00<0o`000000o`3oool02`3oool20?l001/0oooo00<0003o
0?l0003oool07`3oool00`3o0000oooo0?ooo`0]0?ooo`030?l0003oool0
oooo00/0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0000o`0E
0?ooo`00FP3oool00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo
02d0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0N0?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o00000P3oool00`3o
0000oooo0?ooo`0C0?ooo`060?l0003oool0oooo0?l0003oool0003o103o
ool00`3o0000oooo0?ooo`0R0?ooo`80o`002`3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo01`0oooo00<0003o0?l0003oool0:P3o
ool00`000000oooo0?ooo`0M0?ooo`030?l000000?l0oooo02h0oooo00<0
o`000000o`3oool02@3oool20?l000030000o`3oool0oooo01X0oooo00<0
003o0?l0003oool07`3oool00`3o0000oooo0?ooo`0]0?ooo`030?l0003o
ool0oooo00X0oooo00<0o`000000o`3oool06P3oool00`3o0000oooo0?oo
o`0D0?ooo`00FP3oool00`000000oooo0?ooo`0H0?ooo`030000o`3o0000
oooo02h0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0N
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o00000P3oool0
0`3o0000oooo0?ooo`0C0?ooo`060?l0003oool0oooo0?ooo`3o0000003o
103oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo00X0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0L0?ooo`030000
o`3o0000oooo02X0oooo00<000000?ooo`3oool07@3oool00`3o0000003o
0?ooo`0_0?ooo`030?l000000?l0oooo00L0oooo00@0o`000?ooo`3oool0
003o7@3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo02h0
oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0J0?ooo`03
0?l0003oool0oooo01@0oooo001J0?ooo`030000003oool0oooo01P0oooo
00<0003o0?l0003oool0;P3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo01h0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?l000020?ooo`030?l0003oool0oooo01<0oooo00H0o`000?ooo`3oool0
oooo0?l000000?l40?ooo`030?l0003oool0oooo0280oooo00<0o`000?oo
o`3oool02P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
01d0oooo00<0003o0?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0M0?oo
o`030?l000000?l0oooo0300oooo00<0o`000?ooo`3oool01@3oool0103o
0000oooo0?ooo`000?lN0?ooo`030000o`3o0000oooo01d0oooo00<0003o
0?l0003oool0;`3oool00`3o0000oooo0?ooo`080?ooo`030?l000000?l0
oooo01/0oooo00<0o`000?ooo`3oool0503oool005X0oooo00<000000?oo
o`3oool0603oool00`000?l0o`000?ooo`0^0?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3o0000oooo0080oooo00<0o`000?ooo`3oool04P3oool01P3o
0000oooo0?ooo`3oool0003o0?l000@0oooo00<0o`000?ooo`3oool08P3o
ool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0Y0?ooo`030?l0003o
ool0oooo01d0oooo00<0o`000?ooo`3oool0<03oool00`3o0000003o0?oo
o`040?ooo`050?l0003oool0oooo0?ooo`000?l07P3oool00`000?l0o`00
0?ooo`0M0?ooo`030000o`3o0000oooo02l0oooo00<0o`000000o`3oool0
203oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo01@0oooo
001J0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool0;`3o
ool01@3o0000oooo0?ooo`3oool0o`000240oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0140oooo
00<0o`000?ooo`3oool00P3oool00`000?l0o`000?ooo`030?ooo`030?l0
003oool0oooo0300oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0M0?ooo`030?l000000?l0oooo02T0oooo00<000000?l0003oool0
703oool00`3o0000003o0?ooo`0b0?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool00P000?lP0?ooo`030?l0003oool0oooo01`0oooo
00<0003o0?l0003oool0<03oool00`3o0000oooo0?ooo`060?ooo`030?l0
00000?l0oooo01d0oooo00<0o`000?ooo`3oool04`3oool005X0oooo00<0
00000?ooo`3oool0603oool00`000?l0oooo0?ooo`0_0?ooo`050?l0003o
ool0oooo0?ooo`3o00008@3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3o0000oooo00<0oooo00<0o`000?ooo`3oool0
<03oool01@3o0000oooo0?ooo`3oool0o`000200oooo00<0o`000000o`3o
ool0:@3oool00`000000o`000?ooo`0L0?ooo`030?l000000?l0oooo03<0
oooo00D0o`000?ooo`3oool0o`000?ooo`020000ob80oooo00<0o`000?oo
o`3oool0703oool00`000?l0o`000?ooo`0`0?ooo`030?l000000?l0oooo
00@0oooo00<0003o0?l0003oool07`3oool00`3o0000oooo0?ooo`0C0?oo
o`00FP3oool00`000000oooo0?ooo`0G0?ooo`030000o`3o0000oooo0300
oooo00@0o`000?ooo`3oool0o`008`3oool00`3o0000oooo0?ooo`020?oo
o`030?l000000?l0oooo0080oooo00<0o`000?ooo`3oool04@3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0o`0000<0oooo00<0o`000?oo
o`3oool0<03oool01@3o0000oooo0?ooo`3oool0o`000200oooo00<0o`00
0000o`3oool0:@3oool00`000000o`000000o`0L0?ooo`030?l000000?l0
oooo03<0oooo00<0o`000?ooo`3o00000P000?lT0?ooo`030000o`3o0000
oooo01`0oooo00<0o`000?ooo`3oool0<03oool0103o0000003o0?ooo`3o
ool30000o`030?l0003oool0oooo03D0oooo001J0?ooo`030000003oool0
oooo01L0oooo00<0003o0?l0003oool0<03oool0103o0000oooo0?ooo`3o
000S0?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0000o`030?ooo`03
0?l0003oool0oooo0140oooo00D0o`000?ooo`3oool0oooo0000o`020?oo
o`050?l0003oool0oooo0?ooo`3o0000<P3oool01@3o0000oooo0?ooo`3o
ool0o`000200oooo00<0o`000?ooo`000?l0:@3oool00`000000o`000000
o`0L0?ooo`030?l000000?l0oooo03@0oooo00<0o`000000o`3oool09P3o
ool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo0340oooo00<0
o`000000o`000?l00P3oool00`3o0000oooo0?ooo`0f0?ooo`00FP3oool0
0`000000oooo0?ooo`0G0?ooo`030000o`3o0000oooo0300oooo00@0o`00
0?ooo`3oool0o`008`3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`00
0?l0103oool00`3o0000oooo0?ooo`0@0?ooo`050?l0003oool0oooo0?oo
o`000?l00`3oool00`3o0000oooo0?l0000c0?ooo`050?l0003oool0oooo
0?ooo`3o0000803oool00`3o0000oooo0000o`0Y0?ooo`030000003oool0
o`0001`0oooo00<0o`000?ooo`3oool0G@3oool00`3o0000oooo0?ooo`0J
0?ooo`030000o`3o0000oooo0380oooo00D0o`000?ooo`3oool0oooo0?l0
000i0?ooo`00FP3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?l0003oool0<03oool0103o0000oooo0?ooo`3o
000S0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@000?l0oooo
0?ooo`3oool0o`000180oooo00D0o`000?ooo`3oool0oooo0000o`030?oo
o`030?l0003oool0o`0003<0oooo00D0o`000?ooo`3oool0oooo0?l0000Q
0?ooo`030?l000000?l0oooo02P0oooo00@000000?ooo`3o0000003o6P3o
ool00`3o0000003o0?ooo`1N0?ooo`030000o`3o0000oooo01X0oooo00<0
003o0?l0003oool0<P3oool0103o0000oooo0?ooo`3o000j0?ooo`00FP3o
ool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3o0000<@3oool00`3o0000oooo0?l0000T0?ooo`040?l0003o
ool0oooo0?l000<0oooo00D0003o0?ooo`3oool0oooo0?l0000A0?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool20?l003@0
oooo00@0o`000?ooo`3oool0o`008@3oool00`3o0000oooo0000o`0X0?oo
o`040000003oool0o`000000oaX0oooo00<0o`000000o`3oool0G`3oool0
0`3o0000oooo0?ooo`0I0?ooo`030000o`3o0000oooo03<0oooo0P3o000k
0?ooo`00DP3oool5000000<0oooo00<000000?ooo`3oool03@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0o`000340oooo00<0o`000?oo
o`3o0000903oool0103o0000oooo0?ooo`3o00030?ooo`050000o`3oool0
oooo0?ooo`3o00004@3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo
0P3o000d0?ooo`030?l0003oool0o`000280oooo00<0o`000?ooo`000?l0
:03oool010000000oooo0?ooo`3o000J0?ooo`030?l000000?l0oooo05l0
oooo00<0o`000?ooo`3oool06@3oool00`000?l0o`000?ooo`0c0?ooo`03
0?l0003oool0oooo03X0oooo001D0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0303oool00`3o0000oooo0?l000070?ooo`030000
o`3oool0o`000380oooo0P3o000T0?ooo`040?l0003oool0oooo0?l000@0
oooo00@0003o0?ooo`3oool0o`004@3oool01@3o0000oooo0?ooo`3oool0
003o00H0oooo00<0o`000?ooo`3oool0<P3oool00`3o0000oooo0?l0000R
0?ooo`040?l0003oool0oooo0000obL0oooo00D000000?ooo`3oool0o`00
0000o`0I0?ooo`030?l0003oool0oooo05l0oooo00<0003o0?l0003oool0
603oool00`000?l0oooo0?l0001a0?ooo`00E03oool00`000000oooo0?oo
o`030?ooo`030000o`000000000000`0oooo00<0o`000?ooo`3o00001`3o
ool00`000?l0oooo0?l0000b0?ooo`80o`00903oool0103o0000oooo0?oo
o`3o00040?ooo`050000o`3oool0oooo0?ooo`3o0000403oool01@3o0000
oooo0?ooo`3oool0003o00H0oooo00<0o`000?ooo`3oool0<P3oool00`3o
0000oooo0?l0000R0?ooo`040?l0003oool0oooo0000oal0oooo10000004
0?ooo`050000003oool0oooo0?l000000?l06@3oool00`3o0000oooo0?oo
o`1O0?ooo`030000o`3o0000oooo01P0oooo00<0003o0?l0003oool0L@3o
ool005@0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0o`0000H0oooo00@0003o0?ooo`3oool0o`00<P3o
ool00`3o0000oooo0?ooo`0T0?ooo`80o`001@3oool01@000?l0oooo0?oo
o`3oool0o`000100oooo00D0o`000?ooo`3oool0oooo0000o`0k0?ooo`03
0?l0003oool0o`000280oooo00<0o`000?ooo`3oool0803oool00`000000
oooo0?ooo`050?ooo`060000003oool0oooo0?l0003oool0003o5`3oool0
0`3o0000003o0?ooo`1Q0?ooo`030?l0003oool0oooo01L0oooo00<0003o
0?l0003oool0L@3oool005@0oooo00<000000?ooo`3oool00`3oool00`00
0000003o0?ooo`0<0?ooo`030?l0003oool0o`0000H0oooo00<0003o0?oo
o`3o0000<`3oool00`3o0000oooo0?ooo`0T0?ooo`80o`001P3oool01000
0?l0oooo0?ooo`3o000@0?ooo`040?l0003oool0oooo0000oc`0oooo00<0
o`000?ooo`3o00008P3oool00`3o0000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo00@0oooo0`0000000`3oool0o`000000o`0G0?ooo`030?l00000
0?l0oooo0640oooo00<0003o0?l0003oool05P3oool00`000?l0oooo0?l0
001b0?ooo`00D`3oool2000000D0oooo00<000000000o`3oool02`3oool0
1@3o0000oooo0?ooo`3oool0o`0000D0oooo00<0003o0?ooo`3o0000FP3o
ool20?l000H0oooo00@0003o0?ooo`3oool0o`003`3oool01@3o0000oooo
0?ooo`3oool0003o03d0oooo0P3o000R0?ooo`030?l0003oool0oooo0280
oooo00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`3oool0o`00
0000oaL0oooo00<0o`000?ooo`3oool0H@3oool00`000?l0o`000?ooo`0F
0?ooo`030000o`3oool0o`000780oooo001J0?ooo`030000003o0000003o
00/0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`040000o`3oool0
oooo0?l005X0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?l0
000?0?ooo`040?l0003oool0oooo0000och0oooo00<0o`000?ooo`3oool0
8@3oool00`3o0000oooo0?ooo`0P0?ooo`040000003oool0oooo000000@0
oooo00L000000?ooo`3oool0oooo0?l0003oool0003o01H0oooo00<0o`00
0?ooo`3oool0HP3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3o0000
oooo0780oooo001J0?ooo`030000003o0000003o00/0oooo00D0o`000?oo
o`3oool0oooo0?l000040?ooo`040000o`3oool0oooo0?l005X0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?l0000?0?ooo`040?l0003o
ool0oooo0000och0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo
0?ooo`0P0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030?l0
00000?l0oooo01D0oooo00<0o`000?ooo`3oool0HP3oool00`3o0000oooo
0?ooo`0E0?ooo`030000o`3o0000oooo0780oooo001J0?ooo`040000003o
ool0o`000000o`X0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`05
0000o`3oool0oooo0?ooo`3o0000I03oool00`000?l0oooo0?l0000>0?oo
o`030?l0003oool0003o03l0oooo00<0o`000?ooo`3oool08P3oool00`3o
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0080oooo00<0o`000000
o`3oool0503oool00`3o0000oooo0?ooo`1S0?ooo`030000o`3o0000oooo
01@0oooo00<0003o0?l0003oool0L`3oool005X0oooo00@000000?ooo`3o
0000003o2@3oool00`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo
0000o`<0oooo00<0o`000?ooo`3oool0HP3oool00`000?l0oooo0?l0000>
0?ooo`030?l0003oool0003o06@0oooo00<0o`000?ooo`3oool09`3oool0
0`000000oooo0?ooo`020?ooo`030?l0003oool0003o01@0oooo00<0o`00
0?ooo`3oool0I03oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3o0000
oooo07<0oooo001J0?ooo`050000003oool0o`000?ooo`000?l0203oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0003o00@0oooo00<0o`00
0?ooo`3oool0H`3oool00`000?l0o`000?ooo`0<0?ooo`030?l0003oool0
003o06D0oooo00<0o`000?ooo`3oool09`3oool00`000000oooo0?ooo`02
0?ooo`030?l0003oool0003o01@0oooo00<0o`000?ooo`3oool0I03oool0
0`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo07<0oooo001J0?oo
o`050000003oool0o`000?ooo`000?l0203oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0003o00@0oooo00<0o`000?ooo`3oool0H`3oool0
0`000?l0o`000?ooo`0<0?ooo`030?l0003oool0003o06D0oooo00<0o`00
0?ooo`3oool09`3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0
003o01<0oooo00<0o`000?ooo`3oool0I03oool00`000?l0o`000?ooo`0B
0?ooo`030000o`3o0000oooo07@0oooo001J0?ooo`060000003oool0oooo
0?l0003oool0003o1`3oool00`3o0000oooo0?ooo`030?ooo`030?l00000
0?l0oooo00@0oooo00<0o`000?ooo`3oool0I03oool00`000?l0oooo0?oo
o`0;0?ooo`030?l000000?l0oooo06D0oooo00<0o`000?ooo`3oool09`3o
ool00`000000oooo0?ooo`030?ooo`030?l0003oool0003o0180oooo00<0
o`000?ooo`3oool0IP3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo07@0oooo001J0?ooo`060000003oool0oooo0?l0003oool0003o
1`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0I03oool00`000?l0o`000?ooo`0;0?ooo`030?l0
00000?l0oooo06D0oooo00<0o`000?ooo`3oool09`3oool00`000000oooo
0?ooo`030?ooo`030?l0003oool0003o0180oooo00<0o`000?ooo`3oool0
IP3oool00`3o0000oooo0?ooo`0@0?ooo`030?l000000?l0oooo07D0oooo
001J0?ooo`040000003oool0oooo0?l00080oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o0000oooo00@0oooo
00<0o`000?ooo`3oool0I@3oool00`000?l0oooo0?ooo`0:0?ooo`030000
o`3oool0oooo06D0oooo00<0o`000?ooo`3oool09`3oool00`000000oooo
0?ooo`040?ooo`030?l0003oool0003o0140oooo00<0o`000?ooo`3oool0
IP3oool00`000?l0o`000?ooo`0@0?ooo`030?l0003oool0oooo07D0oooo
001J0?ooo`040000003oool0oooo0?l00080oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o0000oooo00@0oooo
00<0o`000?ooo`3oool0I@3oool00`000?l0oooo0?ooo`0:0?ooo`030000
o`3oool0oooo06D0oooo00<0o`000?ooo`3oool09`3oool00`000000oooo
0?ooo`040?ooo`030?l0003oool0003o0140oooo00<0o`000?ooo`3oool0
I`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l000000?l0oooo07H0oooo
001J0?ooo`050000003oool0oooo0?ooo`3o00000P3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o0000
103oool00`3o0000oooo0?ooo`1V0?ooo`030?l000000?l0oooo00T0oooo
00<0003o0?ooo`3oool0I`3oool00`3o0000oooo0?ooo`0V0?ooo`030000
003oool0oooo00@0oooo00@0o`000?ooo`3oool0003o3`3oool00`000?l0
o`000?ooo`1X0?ooo`030?l0003oool0oooo00h0oooo00<0o`000000o`3o
ool0MP3oool005X0oooo00D000000?ooo`3oool0oooo0?l000020?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?l000040?ooo`030?l0003oool0oooo06H0oooo00<0o`000000o`3o
ool02@3oool00`000?l0oooo0?ooo`1W0?ooo`030?l0003oool0oooo02H0
oooo00<000000?ooo`3oool0103oool0103o0000oooo0?ooo`000?l?0?oo
o`030?l0003oool0oooo06T0oooo00<0o`000?ooo`3oool0303oool00`3o
0000003o0?ooo`1g0?ooo`00FP3oool01@000000oooo0?ooo`3oool0o`00
00<0oooo00@0003o0?ooo`3oool0o`001@3oool01@000?l0oooo0?ooo`3o
ool0o`0000<0oooo00<0o`000?ooo`3oool0I`3oool00`3o0000003o0?oo
o`070?ooo`030000o`3o0000oooo06P0oooo00<0o`000?ooo`3oool09P3o
ool00`000000oooo0?ooo`050?ooo`040?l0003oool0oooo0000o`h0oooo
00<0o`000?ooo`3oool0J@3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0
00000?l0oooo07L0oooo001J0?ooo`050000003oool0oooo0?ooo`3o0000
0`3oool20000o`030?ooo`3o0000oooo00@0oooo00D0003o0?ooo`3oool0
oooo0?l000030?ooo`030?l0003oool0oooo06L0oooo00<0o`000000o`00
0?l01`3oool00`000?l0o`000?ooo`1X0?ooo`030?l0003oool0oooo02H0
oooo00<000000?ooo`3oool01@3oool20?l000030?ooo`000?l0oooo00`0
oooo00<0003o0?l0003oool0J`3oool00`3o0000oooo0?ooo`0:0?ooo`03
0?l0003oool0003o07P0oooo001J0?ooo`030000003oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool40000o`80oooo00<0003o0?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0o`0006T0oooo00<0o`000?ooo`3o
ool010000?l20?ooo`030000o`3oool0o`0006T0oooo00<0o`000?ooo`3o
ool09P3oool00`000000oooo0?ooo`070?ooo`80o`0000<0003o0?ooo`3o
ool02P3oool00`000?l0o`000?ooo`1[0?ooo`030?l0003oool0oooo00T0
oooo00@0o`000?ooo`3oool0003oN03oool005X0oooo00<000000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
003o103oool01@3o0000oooo0?ooo`3oool0o`0006T0oooo00<0o`000?oo
o`3oool0103oool30000o`030?ooo`3o0000oooo06P0oooo00<0o`000?oo
o`3oool09P3oool00`000000oooo0?ooo`090?ooo`<0o`002P3oool00`00
0?l0o`000?ooo`1[0?ooo`030?l000000?l0oooo00T0oooo00<0o`000?oo
o`000?l0N@3oool005X0oooo00<000000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00@0o`000?ooo`3o
ool0o`00J@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
06P0oooo00<0o`000?ooo`3oool09P3oool00`000000oooo0?ooo`0:0?oo
o`040000o`3oool0o`000?l000P0oooo00<0o`000?ooo`3oool0K03oool0
0`3o0000oooo0?ooo`070?ooo`040?l0003oool0oooo0000ogT0oooo001J
0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`090?ooo`040?l0003oool0oooo0?l006X0oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`1X0?ooo`030?l0003o
ool0oooo02H0oooo00<000000?ooo`3oool02P3oool01@000?l0oooo0?oo
o`3oool0o`0000H0oooo00<0003o0?l0003oool0K@3oool00`3o0000003o
0?ooo`070?ooo`040?l0003oool0oooo0000ogT0oooo001J0?ooo`030000
003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`04
0?l0003oool0oooo0?l006X0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`1X0?ooo`030?l0003oool0oooo02H0oooo00<000000?oo
o`3oool02`3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0003o
0?l0003oool0K@3oool00`3o0000003o0?ooo`060?ooo`040?l0003oool0
oooo0000ogX0oooo001J0?ooo`030000003oool0oooo00<0oooo00D0o`00
0?ooo`3oool0oooo0?l0000;0?ooo`040?l0003oool0oooo0?l006X0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`1Y0?ooo`030?l0
003oool0oooo02D0oooo00<000000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo0080003o00<0oooo0?l0003oool0
KP3oool00`3o0000003o0?ooo`050?ooo`040?l0003oool0oooo0000ogX0
oooo001J0?ooo`030000003oool0oooo00<0oooo00D0o`000?ooo`3oool0
oooo0?l0000<0?ooo`030?l0003oool0o`0006/0oooo0P3o00060?ooo`03
0?l0003oool0oooo06T0oooo00<0o`000?ooo`3oool09@3oool00`000000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo0080oooo0P3o00030?ooo`03
0?l0003oool0oooo06d0oooo00<0o`000000o`3oool0103oool0103o0000
oooo0000o`000?mk0?ooo`00DP3oool4000000@0oooo00<000000?ooo`3o
ool00`3oool0103o0000oooo0?ooo`3o000=0?ooo`80o`00KP3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo06T0oooo00<0o`000?oo
o`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
0080003o0P3oool00`3o0000oooo0?l0001`0?ooo`030?l0003oool0003o
00@0oooo00<0o`000000o`3oool0O03oool00580oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0o`0000d0
oooo0P3o001_0?ooo`80o`000P3oool00`3o0000oooo0?ooo`1Z0?ooo`03
0?l0003oool0oooo02D0oooo00<000000?ooo`3oool03@3oool20000o`D0
oooo0P3o001a0?ooo`060?l000000?l0oooo0?ooo`000?l0o`00O`3oool0
05<0oooo00<000000?ooo`3oool0103oool3000000@0oooo00<0o`000?oo
o`3o00003@3oool20?l00740oooo0`3o001/0?ooo`030?l0003oool0oooo
02D0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`1_0?oo
o`060?l0003oool0003o0000o`3oool0o`00O`3oool005@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0
o`0000h0oooo00<0o`000?ooo`3oool0L@3oool00`3o0000oooo0?ooo`2<
0?ooo`<000000`3oool00`000000oooo0?ooo`280?ooo`040?l0003oool0
oooo0?l00800oooo001B0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0103oool20?l000l0oooo00<0o`000?ooo`3oool0o`3o
ool20?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0R03o
ool0103o0000oooo0?ooo`3o00200?ooo`00D`3oool2000000D0oooo00<0
00000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo0?h0oooo1@0000030?ooo`<00000R03oool00`3o0000oooo0?l0
00210?ooo`00FP3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0
oooo0?l0oooo3`3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo08T0oooo0P3o00210?ooo`00FP3oool00`000000oooo0?ooo`3o
0?oooaP0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`29
0?ooo`030?l0003oool0oooo0800oooo001J0?ooo`030000003oool0oooo
0?l0oooo6@3oool2000000@0oooo00<000000?ooo`3oool0o`3oool=0?oo
o`00o`3ooooo0?oooh`0oooo003o0?ooool0ooooS03oool00?l0ooooo`3o
oon<0?ooo`00o`3ooooo0?oooh`0oooo003o0?ooool0ooooS03oool00?l0
ooooo`3ooon<0?ooo`00o`3ooooo0?oooh`0oooo003o0?ooool0ooooS03o
ool005L0oooo0P0000080?ooo`800000o`3oool>0?ooo`8000001P3oool2
000000P0oooo0P00003o0?ooo`L0oooo001G0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0o`3oool=0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oo
o`D0oooo001>0?ooo`80000000<0oooo000000000000103oool00`000000
oooo0?ooo`0200000080oooo0P0000020?ooo`030000003oool0oooo0?l0
oooo3P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
00000P3oool200000080oooo00<000000?ooo`3oool0o`3oool50?ooo`00
C`3oool00`000000oooo000000050?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool000000?l0oooo3`3oool00`00
0000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool000000?l0oooo1`3oool00500oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo0000003o0?ooo`h0oooo00@000000?ooo`3oool0
0000103oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo0000003o0?ooo`L0oooo001>0?ooo`80000000<0oooo0000
00000000103oool00`000000oooo0?ooo`04000000@0oooo00<000000?oo
o`3oool0o`3oool;0?ooo`<0000000<0oooo0000000000000`3oool00`00
0000oooo0?ooo`04000000@0oooo00<000000?ooo`3oool0o`3oool50?oo
o`00E`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0
oooo503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0
oooo1@3oool005L0oooo0P0000080?ooo`800000o`3ooolF0?ooo`800000
203oool200000?l0oooo1`3oool00?l0ooooo`3ooon<0?ooo`00o`3ooooo
0?oooh`0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{650, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Figure 9.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The input  ",
  Cell[BoxData[
      \(x[n] = 
        cos \((\[Pi]\/8\ n)\) + sin \((\[Pi]\/4\ n)\) + 
          sin \((2.60\ n)\)\)]],
  "  and output  ",
  Cell[BoxData[
      \(y[n]\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.22.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["9.22 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  \tIn Section 9.2, in Example 9.20 (b), we found that the difference \
equation  ",
  Cell[BoxData[
      \(y[n + 2] - 2\/3\ \@2\ y[n + 1] + 4\/9\ y[n] = 
        cos \((\(\[Pi]\/4\) n)\)\)]],
  "  has the general solution  \n\n\t\t",
  Cell[BoxData[
      \(y[
          n]\  = \ \(c\_1\) \(\((2\/3)\)\^n\) 
            cos \((\[Pi]\/4\ n\ )\) + \(c\_2\) \(\((2\/3)\)\^n\) 
            sin \((\[Pi]\/4\ n)\) + \ \(\(9\)\(\ \)\)\/\@13\ cos \
\((\(\[Pi]\/4\) n + arctan \((3\/2)\))\)\)]],
  ".\n\nSince  ",
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\((\(c\_1\) \(\((2\/3)\)\^n\) 
                cos \((\[Pi]\/4\ n\ )\) + \(c\_2\) \(\((2\/3)\)\^n\) 
                sin \((\[Pi]\/4\ n)\))\)\  = \ 0\)]],
  ",  the output signal ",
  Cell[BoxData[
      \(y[n]\)]],
  " tends to the steady state signal  ",
  Cell[BoxData[
      \(\(\(9\)\(\ \)\)\/\@13\ cos \((\(\[Pi]\/4\) n + 
            arctan \((3\/2)\))\)\)]],
  "  as  ",
  Cell[BoxData[
      \(n \[Rule] \[Infinity]\)]],
  ".   Hence the signal  ",
  Cell[BoxData[
      \(cos \((\(\[Pi]\/4\) n)\)\)]],
  "  is boosted up by an amplification factor of  ",
  Cell[BoxData[
      \(\(\(9\)\(\ \)\)\/\@13\  = \ 2.49615\)]],
  ".  A similar boost will be observed for the signal    ",
  Cell[BoxData[
      \(sin \((\(\[Pi]\/4\) n)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tFor this filter, the amplitude response is ",
  Cell[BoxData[
      \(A \((\[Theta])\) = \(\(|\)\(H \((\[ExponentialE]\^\[ImaginaryI]\
\[Theta])\)\)\(|\)\)\)]],
  "  where  ",
  Cell[BoxData[
      \(\(\(\ \)\(H \((z)\) = \ 
        1\/\(1 - 2\/3\ \(\@2\) z\^\(-1\) + \(4\/9\) z\^\(-2\)\)\)\)\)]],
  ".  We compute the boost for  ",
  Cell[BoxData[
      \(cos \((\(\[Pi]\/4\) n)\)\)]],
  " by evaluating  \n\n\t\t\t",
  Cell[BoxData[
      \(A \((\[Pi]\/4)\)\ \  = \ \ \(\(1\)\(/\)\) | 
          1 - 2\/3\ \(\@2\) \((\[ExponentialE]\^\(\[ImaginaryI]\ \
\[Pi]\/4\))\)\^\(-1\) + \(4\/9\) \((\[ExponentialE]\^\(\[ImaginaryI]\ \
\[Pi]\/4\))\)\^\(-2\) | \)]],
  "   \n\n\t\t\t",
  Cell[BoxData[{
      \(A \((\[Pi]\/4)\)\ \  = \ \ \(\(\(1\)\(/\)\) | 
            1 - 2\/3\ \(\@2\) \((\ \(1 - \[ImaginaryI]\)\/\@2)\) - \(4\ \
\[ImaginaryI]\)\/9\  | \ \ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \  = \ \ \(\(\
\(|\)\(9 \( 3 - 2\ \[ImaginaryI]\)\/13\)\(|\)\)\ \  = \ \ \(9\ \@13\)\/13\)\)\
\ \ \[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \ \)\(2.496150883013531`\)\
\)\)}]],
  ", \n\nwhich is the same value that was obtained in Example 9.20 (b) in \
Section 9.2.  The amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  " for an arbitrary frequency  ",
  Cell[BoxData[
      \(\[Theta]\)]],
  "  for is given in the Figure 9.7 below.  Observe that a maximum occurs \
near  ",
  Cell[BoxData[
      \(\[Theta] = \[Pi]\/4\)]],
  "and there is amplification for signals with  ",
  Cell[BoxData[
      \(0 < \[Theta] < 1.4944\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 9.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "The amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\) = \(\(|\)\(1\/\(1 - 
                2\/3\ \(\@2\) z\^\(-1\) + \(4\/9\) z\^\(-2\)\)\)\(|\)\)\)]],
  " for  ",
  Cell[BoxData[
      \(y[n] = x[n] + \(2\/3\) \(\@2\) y[n - 1] - \(4\/9\) y[n - 2]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["9.22 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Calculate the amplitude responses ",
  Cell[BoxData[
      RowBox[{"A", \((\[Pi]\/8)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "A", \((2.60)\)}]]],
  " and investigate the filtered signal for  ",
  Cell[BoxData[
      \(x[n] = \ 
        cos \((\[Pi]\/8\ n)\) + sin \((\[Pi]\/4\ n)\) + 
          sin \((2.60\ n)\)\)]],
  ".  \n\n\t\t\t",
  Cell[BoxData[
      \(A \((\[Pi]\/8)\)\ \  = \ \ \ \(\(1\)\(/\)\) | 
          1 - \(2\/3\) \(\@2\) \((\[ExponentialE]\^\(\[ImaginaryI]\ \
\[Pi]/8\))\)\^\(-1\) + \(4\/9\) \((\[ExponentialE]\^\(\[ImaginaryI]\ \
\[Pi]/8\))\)\^\(-2\) | \)]],
  "  \n\t\t\n\t\t\t",
  Cell[BoxData[
      \(A \((\[Pi]\/8)\)\ \  = \ \ \(\(\(|\)\(2.2315852602022903`\
\[InvisibleSpace] - 
              0.23426011564658894`\ \[ImaginaryI]\)\(|\)\)\ \
\[IndentingNewLine]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \  = \ \ \ \
2.243847270946682`\)\)]],
  "  \n\t\t\n\t\t\tand\n\n\t\t\t",
  Cell[BoxData[
      \(A \((2.60)\)\ \  = \ \ \(\(1\)\(/\)\) | 
          1 - \(2\/3\) \(\@2\) \((\[ExponentialE]\^\(2.60  \[ImaginaryI]\))\)\
\^\(-1\) + \(4\/9\) \((\[ExponentialE]\^\(2.60  \[ImaginaryI]\))\)\^\(-2\) | \
\)]],
  "  \n\t\t\n\t\t\t",
  Cell[BoxData[
      \(A \((2.60)\)\ \  = \ \ \
\(\(\(|\)\(0.4168309759180071`\[InvisibleSpace] - 
              0.18166408106617016`\ \[ImaginaryI]\)\(|\)\)\ \
\[IndentingNewLine]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  = \ \ \ \
0.45469759272990906`\)\)]],
  "  "
}], "Text"],

Cell[TextData[{
  "Using the above calculations we conclude that the components  ",
  Cell[BoxData[
      RowBox[{"cos", \((\[Pi]\/8\ n)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "sin", \((\[Pi]\/4\ n)\)}]]],
  "  will be boosted up by the factors ",
  Cell[BoxData[
      RowBox[{\(A \((\[Pi]\/8)\)\), "=", 
        RowBox[{
          RowBox[{"2.243847270946683`", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "A", \((\[Pi]\/4)\)}], "=", 
          "2.4961508830135313`"}]}]]],
  ", respectively; and the component ",
  Cell[BoxData[
      \(sin \((2.60\ n)\)\)]],
  "  will be attenuated by the factor ",
  Cell[BoxData[
      \(A \((2.60)\) = 0.45469759272990906`\)]],
  ".  The situation is shown in Figure 9.8. "
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 9.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The input  ",
  Cell[BoxData[
      \(x[n] = 
        cos \((\[Pi]\/8\ n)\) + sin \((\[Pi]\/4\ n)\) + 
          sin \((2.60\ n)\)\)]],
  "  and output  ",
  Cell[BoxData[
      \(y[n]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Background for the z-transform and its application for solving difference \
equations can be found in the book.\n\n",
  StyleBox[ButtonBox["Complex Analysis for Mathematics and Engineering",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.22.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["9.22.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given the recursion formula  ",
  Cell[BoxData[
      \(y[n]\ \  = \ \ x[n] + 2\/3\ \@2\ y[n - 1] - 4\/9\ y[n - 2]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["9.22 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that it is a boosting up filter for the signals ",
  Cell[BoxData[
      \(cos \((\(\[Pi]\/4\) n)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\(\[Pi]\/4\) n)\)\)]],
  " and calculate the amplitude response  ",
  Cell[BoxData[
      \(A \((\[Pi]\/4)\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(H[z_] = 
        1\/\(1 - 2\/3\ \(\@2\) z\^\(-1\) + \(4\/9\) z\^\(-2\)\);\)\ \), "\n", \

    \(\(A[\[Theta]_] = 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]];\)\), "\
\[IndentingNewLine]", 
    \(\(graph2 = 
        Plot[A[\[Theta]], {\[Theta], 0, \[Pi]}, 
          PlotRange \[Rule] {{0, \[Pi]}, {0, 2.6}}, 
          Ticks \[Rule] {Range[0, \[Pi], \[Pi]\/4], Range[0, 2.5, 0.5]}, 
          AxesLabel \[Rule] {"\<\[Theta]\>", "\<A(\[Theta])\>"}, 
          PlotStyle \[Rule] Red];\)\), "\n", 
    \(\(Print[\*"\"\< A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(\[Pi]\/4\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]  \[Pi]\/4\)\)]| = \>\"", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\/4\)]], "\< = \>", 
        N[Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\/4\)]]]\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<The amplitude response for the filter\>"];\)\), "\n", 
    \(\(Print[\*"\"\<y[n+2] = x[n] + \!\(2\/3\) \!\(\@2\) y[n+1] - \!\(4\/9\) \
y[n]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Where the transfer function is\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\< H[z] = \>", H[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<H[\!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)] = \>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Figure 9.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "The amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\) = \(\(|\)\(1\/\(1 - 
                2\/3\ \(\@2\) z\^\(-1\) + \(4\/9\) z\^\(-2\)\)\)\(|\)\)\)]],
  " for  ",
  Cell[BoxData[
      \(y[n] = x[n] + \(2\/3\) \(\@2\) y[n - 1] - \(4\/9\) y[n - 2]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["9.22 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Calculate the amplitude responses ",
  Cell[BoxData[
      RowBox[{"A", \((\[Pi]\/8)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "A", \((2.60)\)}]]],
  " and investigate the the filtered signal for  ",
  Cell[BoxData[
      \(x[n] = \ 
        cos \((\[Pi]\/8\ n)\) + sin \((\[Pi]\/4\ n)\) + 
          sin \((2.60\ n)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Show[graph2, 
        Ticks \[Rule] {{\[Pi]\/8, \[Pi]\/4, 2.60, \[Pi]}, 
            Range[0, 3.5, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  A[\!\(\[Pi]\/8\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]\[Pi]/8\)\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/8\)], "\<|\>"\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  A[\!\(\[Pi]\/8\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]\[Pi]/8\)\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/8. \)], "\<|\>"\ ];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  A[\!\(\[Pi]\/8\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]\[Pi]/8\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/8. \)]]\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<And\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  A[\!\(\[Pi]\/4\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]\[Pi]/4\)\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)], "\<|\>"\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  A[\!\(\[Pi]\/4\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]\[Pi]/4\)\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4. \)], "\<|\>"\ ];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  A[\!\(\[Pi]\/4\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]\[Pi]/4\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4. \)]]\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<And\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[2.60] = |H[\!\(\[ExponentialE]\^\(\[ImaginaryI]2  \
.60\)\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\(260\/100\) \[ImaginaryI]\)], "\<|\>"\ ];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[2.60] = |H[\!\(\[ExponentialE]\^\(\[ImaginaryI]2  \
.60\)\)]| = |\>\"", 
        H[\[ExponentialE]\^\(2.60  \[ImaginaryI]\)], "\<|\>"\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[2.60] = |H[\!\(\[ExponentialE]\^\(\[ImaginaryI]2  \
.60\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(2.60  \[ImaginaryI]\)]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = 
        Cos[\[Pi]\/8\ n] + Sin[\[Pi]\/4\ n] + 
          Sin[2.60\ n];\)\ \), "\[IndentingNewLine]", 
    \(\(m0 = 32;\)\), "\[IndentingNewLine]", 
    \(\(X1\  = \ 
        N[Table[Cos[\[Pi]\/8\ i] + Sin[\[Pi]\/4\ i], {i, 0, 
              m0}]];\)\), "\n", 
    \(\(X2\  = \ 
        N[Table[Cos[\[Pi]\/8\ i] + Sin[\[Pi]\/4\ i] + Sin[2.60\ i], {i, 0, 
              m0}]];\)\), "\[IndentingNewLine]", 
    \(\(X1 = Join[Table[0, {i, 1, 9}], X1];\)\), "\[IndentingNewLine]", 
    \(\(X2 = Join[Table[0, {i, 1, 9}], X2];\)\), "\n", 
    \(\(Y2 = \(Y1 = Table[0, {i, 0, m0 + 9}]\);\)\), "\n", 
    \(\(For[i = 10, 
        i \[LessEqual] 
          m0 + 10, \(i++\), \[IndentingNewLine]Y1\_\(\(\[LeftDoubleBracket]\)\
\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X1\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  + \(2\/3\) \@2\ Y1\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\) - \(4\/9\) 
                  Y1\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\)\ )\)\ ]; \ \[IndentingNewLine]Y2\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X2\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  + \(2\/3\) \(\@2\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\)\  - \(4\/9\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\)\ )\)\ ];\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(X1pts = 
        Transpose[{ticval, 
            Take[X1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(X2pts = 
        Transpose[{ticval, 
            Take[X2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1pts = 
        Transpose[{ticval, 
            Take[Y1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y2pts = 
        Transpose[{ticval, 
            Take[Y2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ListPlot[X1pts, PlotJoined \[Rule] True, PlotStyle \[Rule] {Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ListPlot[X2pts, PlotJoined \[Rule] True, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{0, m0}, {\(-2.4\), 2.2}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<n\>", "\<x[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Input signal x[n] = \>", 
        x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        ListPlot[Y1pts, PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] {Blue}, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr4 = 
        ListPlot[Y2pts, PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] Red, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr4, PlotRange \[Rule] {{0, m0}, {\(-4.8\), 4.2}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-4\), 4, 2]}, 
        AxesLabel \[Rule] {"\<n\>", "\<y[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Output signal y[n] = x[n] - \!\(\@2\)x[n-1] + \
x[n-2]\>\""\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  A[\!\(\[Pi]\/8\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]\[Pi]/8\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/8. \)]]\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  A[\!\(\[Pi]\/4\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]\[Pi]/4\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4. \)]]\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[2.60] = |H[\!\(\[ExponentialE]\^\(\[ImaginaryI]2  \
.60\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(2.60  \[ImaginaryI]\)]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Figure 9.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The input  ",
  Cell[BoxData[
      \(x[n] = 
        cos \((\[Pi]\/8\ n)\) + sin \((\[Pi]\/4\ n)\) + 
          sin \((2.60\ n)\)\)]],
  "  and output  ",
  Cell[BoxData[
      \(y[n]\)]],
  "."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["9.3.3  The General Filter Equation",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\tT",
    FontFamily->"Times New Roman"],
  "he general form of a ",
  Cell[BoxData[
      \(P\^th\)]],
  " ",
  StyleBox["order filter difference equation",
    FontFamily->"Times New Roman"],
  " is  ",
  StyleBox["\n\t\n",
    FontFamily->"Times New Roman"],
  StyleBox["(9-29)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\t\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[{
      \(\(y[n] + a\_1\ y[n - 1] + a\_2\ y[n - 2] +  ... \) + 
        a\_\(P - 1\)\ y[n - P + 1] + a\_P\ y[n - P]\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(=\)\(\ \ \ \)\(\(b\_0\ x[n] + b\_1\ x[n - 1] + 
              b\_2\ x[n - 2] +  ... \) + b\_\(Q - 1\)\ x[n - Q + 1] + 
          b\_Q\ x[n - Q]\)\)\)}]],
  " ",
  StyleBox["\n\nwhere ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({a\_p}\_\(p = 1\)\%P\)]],
  StyleBox[" and ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({b\_q}\_\(q = 0\)\%Q\)]],
  StyleBox[" are constants. ",
    FontFamily->"Times New Roman"],
  " Note carefully that the terms involved are of the form ",
  Cell[BoxData[
      \(y[n - p]\)]],
  " and ",
  Cell[BoxData[
      \(y[n - q]\)]],
  " where ",
  Cell[BoxData[
      \(p \[GreaterEqual] 0\)]],
  " and ",
  Cell[BoxData[
      \(q \[GreaterEqual] 0\)]],
  ", which makes these terms time delayed. ",
  StyleBox["The compact form of writing the difference equation is \n\n",
    FontFamily->"Times New Roman"],
  StyleBox["(9-30)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\t\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y[
            n]\  + \ \[Sum]\+\(p = 0\)\%P\( a\_p\) 
              y[n - p]\ \  = \ \ \[Sum]\+\(q = 0\)\%Q\( b\_q\) x[n - q]\)]],
  ",  \n\t\t\nwhere the input signal ",
  Cell[BoxData[
      \(x\_n = x[n]\)]],
  " is modified to obtain the output signal ",
  Cell[BoxData[
      \(y\_n = y[n]\)]],
  " using the recursion formula    \n\t\t\n",
  StyleBox["(9-31)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(y[
          n]\  = \ \ \[Sum]\+\(q = 0\)\%Q\( b\_q\) 
              x[n - q]\  - \ \[Sum]\+\(p = 1\)\%P\( a\_p\) y[n - p]\)]],
  ".  \n\nThe portion  ",
  Cell[BoxData[
      \(\[Sum]\+\(q = 0\)\%Q\( b\_q\) x[n - q]\)]],
  " will \"zero out\" signals and  ",
  Cell[BoxData[
      \(\[Sum]\+\(p = 1\)\%P\( a\_p\) y[n - p]\)]],
  " will \"boost up\" signals. "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 9.14.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Formula ",
  StyleBox["(9-31)",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" is called the recursion equation and the recursion coefficients \
are ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({a\_p}\_\(p = 1\)\%P\)],
    FontFamily->"Times New Roman"],
  StyleBox[" and ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({b\_q}\_\(q = 0\)\%Q\)],
    FontFamily->"Times New Roman"],
  StyleBox[".  It ",
    FontFamily->"Times New Roman"],
  "explicitly shows that the present output  ",
  Cell[BoxData[
      \(y[n]\)]],
  "  is a function of the past values  ",
  Cell[BoxData[
      \(y[n - p]\)]],
  ",  for ",
  Cell[BoxData[
      RowBox[{\(p = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "P"}]]],
  ", the present input  ",
  Cell[BoxData[
      \(x[n]\)]],
  ",  and the previous inputs  ",
  Cell[BoxData[
      \(x[n - q]\)]],
  "  for  ",
  Cell[BoxData[
      RowBox[{\(q = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "Q"}]]],
  ".  The sequences can be regarded as signals and they are zero for negative \
indices.  With this information we can now define the general formula for the \
transfer function  ",
  Cell[BoxData[
      \(H \((z)\)\)]],
  ".  Using the time delayed-shift property for causal sequences and taking \
the z-transform of each term in ",
  StyleBox["(9-31)",
    FontColor->RGBColor[0, 0, 1]],
  ", we obtain  \n\n",
  StyleBox["(9-32)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(Y[
          z]\ \  = \ \ \(-\ \(\[Sum]\+\(p = 1\)\%P\( a\_p\) Y[z] 
                z\^\(-p\)\)\)\ \  + \ \ \[Sum]\+\(q = 0\)\%Q\( b\_q\) X[z] 
              z\^\(-q\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "We can factor   ",
  Cell[BoxData[
      RowBox[{\(X[z]\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(Y[z]\)}]]],
  "  out of the summations and write this in an equivalent form \n\n",
  StyleBox["(9-33)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(Y[
            z] \((1\  + \ \[Sum]\+\(p = 1\)\%P\ \(a\_p\) 
                  z\^\(-p\))\)\ \  = \ \ X[
            z]\ \(\[Sum]\+\(q = 0\)\%Q\ \(b\_q\) z\^\(-q\)\)\)]],
  ". \n\nFrom equation ",
  StyleBox["(9-33)",
    FontColor->RGBColor[0, 0, 1]],
  " we obtain \n\n\t\t\t",
  Cell[BoxData[
      \(H \((z)\)\ \  = \ \ \(Y[z]\/X[z]\ \  = \ \ \(\[Sum]\+\(q = 0\)\%Q\ \
\(b\_q\) z\^\(-q\)\)\/\(1\  + \ \[Sum]\+\(p = 1\)\%P\ \(a\_p\) \
z\^\(-p\)\)\)\)]],
  "  \n\t\t\nwhich leads to the following important definition."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 9.4 (Transfer Function)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  The transfer function corresponding to the ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(P\^th\)]],
  StyleBox[" order difference equation (8) is given by  \n",
    FontFamily->"Times New Roman"],
  "\n",
  StyleBox["(9-34)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(H \((z)\)\ \  = \ \ \(Y[z]\/X[z]\ \  = \ \ \(\(b\_0 + \(b\_1\) \
z\^\(-1\) + \(b\_2\) z\^\(-2\) +  ... \) + \(b\_\(Q - 1\)\) z\^\(\(-Q\) + 1\) \
+ \(b\_Q\) z\^\(-Q\)\)\/\(\(1 + \(a\_1\) z\^\(-1\) + \(a\_2\) z\^\(-2\) +  \
... \) + \(a\_\(P - 1\)\) z\^\(\(-P\) + 1\) + \(a\_P\) z\^\(-P\)\)\)\)]],
  ". \n\nFormula ",
  StyleBox["(9-34)",
    FontColor->RGBColor[0, 0, 1]],
  " is the transfer function for an infinite impulse response filter (IIR \
filter).   In the special case when the denominator is unity it becomes the \
transfer function for a finite impulse response filter (FIR filter)."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 9.5 (Unit-Sample Response)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The sequence  ",
  Cell[BoxData[
      \(h[n]\  = \ \(\[GothicCapitalZ]\^\(-1\)\)[H \((z)\)]\)]],
  " corresponding to the transfer function  ",
  Cell[BoxData[
      \(H \((z)\) = \(Y \((z)\)\)\/\(X \((z)\)\)\)]],
  " is called the unit-sample response.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 9.6 (Output Response)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The output response  ",
  Cell[BoxData[
      \(y[n]\)]],
  "  of a the filter (10) given an input signal  ",
  Cell[BoxData[
      \(x[n]\)]],
  "  is given by the inverse z-transformation \n\n",
  StyleBox["(9-35)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(y[
          n]\ \  = \ \ \(\(\[GothicCapitalZ]\^\(-1\)\)[
            Y \((z)\)]\ \  = \ \ \(\[GothicCapitalZ]\^\(-1\)\)[
            H \((z)\) X \((z)\)]\)\)]],
  ",   \n\t\t\nand in convolution form it is given by  \n\n",
  StyleBox["(9-36)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(y[n]\ \  = \ \ \[Sum]\+\(i = 0\)\%n\ x[n - i] h[i]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tAnother important use of the transfer function is to study how a filter \
affects various frequencies.  In practice, a continuous time signal is \
sampled at a frequency  ",
  Cell[BoxData[
      \(f\_S\)]],
  "  that is at least twice the highest input signal frequency to avoid \
frequency fold-over, or aliasing. That is because the Fourier transform of a \
sampled signal is periodic with period  ",
  Cell[BoxData[
      \(\[Omega]\_S\  = \ \(2  \[Pi]\)\/f\_S\)]],
  ",  though we will not prove this here.  Aliasing prevents accurate \
recovery of the original signal from its samples. \n\n\tNow it can be shown \
that the argument of the Fourier transform maps onto the z-plane unit circle \
via the formula\n\n",
  StyleBox["(9-37)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t ",
  Cell[BoxData[
      \(\[Theta]\  = \ 2  \[Pi]\ f\/f\_S\)]],
  ",    where  ",
  Cell[BoxData[
      \(\[Theta]\)]],
  "  is called the normalized frequency.  \n\nTherefore the z-transform \
evaluated on the unit circle is also periodic, except with period ",
  Cell[BoxData[
      \(2  \[Pi]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 9.6 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Amplitude Response",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[")",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  \tThe amplitude response ",
  Cell[BoxData[
      \(\(\(A\) \((\[Theta])\)\(\ \)\)\)]],
  " is defined to be the magnitude of the transfer function evaluated at the \
complex unit signal ",
  Cell[BoxData[
      \(z = \[ExponentialE]\^\[ImaginaryI]\[Theta]\)]],
  ".  The formula is   \n\n",
  StyleBox["(9-38)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(A \((\[Theta])\)\ \  = \ \ \(\(|\)\(H \((\[ExponentialE]\^\(\
\[ImaginaryI]\ \[Theta]\))\)\)\(|\)\)\)]],
  " over the interval ",
  Cell[BoxData[
      \(\([0, \[Pi]]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tSinusoidal signals are linear combinations of  ",
  Cell[BoxData[
      RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        "  ", \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\)\)}]]],
  ".  To determine the amplitude response we input  ",
  Cell[BoxData[
      \(x[n]\  = \ \[ExponentialE]\^\(\[ImaginaryI]\ n\ \[Theta]\)\)]],
  "  which has z-transform   ",
  Cell[BoxData[
      \(X \((z)\)\  = \ \(\[GothicCapitalZ][x[n]]\  = \ 
          z\/\(z\  - \ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)\)\)]],
  "  \nThe z-transform of the output is  ",
  Cell[BoxData[
      \(Y \((z)\)\  = \ \(X \((z)\) 
            H \((z)\)\  = \ \(z\/\(z\  - \ \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\)\)\) H \((z)\)\)\)]],
  "  which can be written as \n\n",
  StyleBox["(9-39)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(Y \((z)\)\ \  = \ \ \(X \((z)\) 
            H \((z)\)\ \  = \ \ z \( 
                1\/\(z\  - \ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)\) \
\(\(b\_0 + \(b\_1\) z\^\(-1\) + \(b\_2\) z\^\(-2\) +  ... \) + \(b\_\(Q - 1\)\
\) z\^\(\(-Q\) + 1\) + \(b\_Q\) z\^\(-Q\)\)\/\(\(1 + \(a\_1\) z\^\(-1\) + \(a\
\_2\) z\^\(-2\) +  ... \) + \(a\_\(P - 1\)\) z\^\(\(-P\) + 1\) + \(a\_P\) z\^\
\(-P\)\)\)\)]],
  "\n\nIt is possible to use a technique like partial fraction expansions to \
write ",
  StyleBox["(9-39)",
    FontColor->RGBColor[0, 0, 1]],
  " in the form \n\n",
  StyleBox["(9-40)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(Y \((z)\)\ \  = \ \ \(z\ F\_0\/\(z\  - \ \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Theta]\)\)\  + \ 
            
            Q \((z)\)\  = \ \ F\_0\ z\/\(z\  - \ \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Theta]\)\)\  + \ Q \((z)\)\)\)]],
  ", \n\nwhere  ",
  Cell[BoxData[
      \(F\_0\  = \ H \((\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\))\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tFor stable solutions we have already mentioned (see Section 9.2.1) that \
the poles of the transfer function must all lie inside the unit circle.  \
Hence the terms in the solution  ",
  Cell[BoxData[
      \(y[n]\)]],
  "  corresponding to the poles of  ",
  Cell[BoxData[
      \(Q \((z)\)\)]],
  "  are all transient and decay to zero as ",
  Cell[BoxData[
      \(n \[Rule] \[Infinity]\)]],
  ".  The steady state portion of the solution   ",
  Cell[BoxData[
      \(y[n]\)]],
  "  is the inverse of the term ",
  Cell[BoxData[
      \(\(F\_0\) \[GothicCapitalZ][
          z\/\(z\  - \ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)]\)]],
  " and its magnitude is \n\n",
  StyleBox["(9-41)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(A \((\[Theta])\)\ \  = \ \ \(\(|\)\(H \((\[ExponentialE]\^\(\
\[ImaginaryI]\ \[Theta]\))\)\)\(|\)\)\)]],
  Cell[BoxData[
      \(\(\(|\)\(\[ExponentialE]\^\(\[ImaginaryI]n\ \[Theta]\)\)\(|\)\)\ \  = \
\ \ \(\(|\)\(H \((\[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\))\)\)\(|\)\)\)]],
  ". "
}], "Text"],

Cell["This proof is in the book.", "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["\tT",
    FontFamily->"Times New Roman"],
  "he fundamental theorem of algebra implies that the numerator has ",
  Cell[BoxData[
      \(Q\)]],
  " roots (called zeros) and the denominator has ",
  Cell[BoxData[
      \(P\)]],
  " roots (called poles).  The zeros ",
  Cell[BoxData[
      \({z\_q}\_\(q = 1\)\%Q\)]],
  " may be chosen in conjugate pairs on the unit circle and ",
  Cell[BoxData[
      \(\(\(|\)\(z\_q\)\(|\)\) = 1\)]],
  " for  ",
  Cell[BoxData[
      \(q = 1, 2,  ... , Q\)]],
  ".   For stability, all the poles ",
  Cell[BoxData[
      \({w\_p}\_\(p = 1\)\%P\)]],
  " must inside the unit circle and  ",
  Cell[BoxData[
      \(\(\(|\)\(w\_p\)\(|\)\(\(<\)\(1\)\)\)\)]],
  " for  ",
  Cell[BoxData[
      \(p = 1, 2,  ... , P\)]],
  ".   Furthermore, the poles are chosen to be real numbers and/or in \
conjugate pairs.  This will guarantee that the ",
  StyleBox["recursion coefficients",
    FontFamily->"Times New Roman"],
  " are all real numbers.  IIR filters may be all pole or zero-pole and \
stability is a concern; FIR filters and all zero-filters are always stable. "
}], "Text"],

Cell[TextData[{
  StyleBox["9.3.4  Design of Filters",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\tIn practice recursion formula (10) is used to calculate the \
output signal.  However, digital filter design is based on the above theory.  \
One starts by selecting the location of zeros and poles corresponding to \
filter design requirements and constructing the transfer function  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(H \((z)\) = \(Y \((z)\)\)\/\(X \((z)\)\)\)]],
  ".  Since t",
  StyleBox["he coefficients in ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(H \((z)\)\)]],
  StyleBox[" are real, all zeros and poles having an imaginary component must \
occur in conjugate pairs.  ",
    FontFamily->"Times New Roman"],
  "Then the ",
  StyleBox["recursion coefficients",
    FontFamily->"Times New Roman"],
  " are identified in (13) and used in (10) to write the recursive filter.  \
Both the numerator and denominator of   ",
  Cell[BoxData[
      \(H \((z)\)\)]],
  " can be factored into quadratic factors with real coefficients and \
possibly one or two linear factors with real coefficients.  The following \
principles are used to construct  ",
  Cell[BoxData[
      \(H \((z)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(i) Zeroing Out Factors",
    FontColor->RGBColor[0, 0, 1]],
  "  \n\n\tTo filter out the signals ",
  Cell[BoxData[
      \(cos \((\[Theta]\ n)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\[Theta]\ n)\)\)]],
  ", use factors of the form \n\n\t\t\t",
  Cell[BoxData[
      \(\((\ \(z - \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)\/z)\) \((\ \
\(z - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\)\)\/z)\)\ \  = \ \ 1\  \
- \ \((\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ \[Theta]\))\) z\^\(-1\)\  + \ z\^\(-2\)\)]],
  "   if   ",
  Cell[BoxData[
      \(0 < \[Theta] < \[Pi]\)]],
  ",    and  \n\n\t\t\t",
  Cell[BoxData[
      \(\((\ \(z - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\)\)\/z)\)\ \  = \ \
\ 1 + z\^\(-1\)\)]],
  "   if   ",
  Cell[BoxData[
      \(\[Theta] = \[Pi]\)]],
  ",  \n\nin the numerator of  ",
  Cell[BoxData[
      \(H \((z)\)\)]],
  ".  They will contribute to the term \n\n",
  StyleBox["(9-42)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\(b\_0 + \(b\_1\) z\^\(-1\) + \(b\_2\) 
                z\^\(-2\) +  ... \) + \(b\_\(Q - 1\)\) 
            z\^\(\(-Q\) + 1\) + \(b\_Q\) 
            z\^\(-Q\)\ \  = \ \ \(\(\(z\^Q\) b\_0 + \(b\_1\) z\^\(Q - 1\) + \
\(b\_2\) z\^\(Q - 2\) +  ... \) + \(b\_\(Q - 1\)\) z + b\_Q\)\/z\^Q\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["(ii) Boosting Up Factors",
    FontColor->RGBColor[0, 0, 1]],
  "  \n\n\tTo amplify the signals ",
  Cell[BoxData[
      \(cos \((\[Theta]\ n)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\[Theta]\ n)\)\)]],
  ", use factors of the form \n\n\t\t\t",
  Cell[BoxData[
      \(\((\ \(z - \[Rho]\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\)\)\/z)\) \
\((\ \(z - \[Rho]\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Phi]\)\)\/z)\)\ \ \
 = \ \ 1\  - \ \[Rho] \((\[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\) + \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Phi]\))\) 
            z\^\(-1\)\  + \ \[Rho]\^2\ z\^\(-2\)\)]],
  "     if  ",
  Cell[BoxData[
      \(0 < \[Rho] < 1\)]],
  "  and  ",
  Cell[BoxData[
      \(0 < \[Phi] < \[Pi]\)]],
  ",    and\n\n\t\t\t",
  Cell[BoxData[
      \(\((\ \(z - \[Rho]\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\)\)\/z)\)\ \
\  = \ \ 1\  + \ \[Rho]\ z\^\(-1\)\)]],
  "     if  ",
  Cell[BoxData[
      \(0 < \[Rho] < 1\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Phi] = \[Pi]\)]],
  ",    and  \n\n\t\t\t",
  Cell[BoxData[
      \(\((\ \(z - \[Rho]\)\/z)\)\ \  = \ \ 1\  - \ \[Rho]\ z\^\(-1\)\)]],
  "     if  ",
  Cell[BoxData[
      \(0 < \[Rho] < 1\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Phi] = 0\)]],
  ",  \n\nin the denominator of  ",
  Cell[BoxData[
      \(H \((z)\)\)]],
  ".  They will contribute to the term \n\n",
  StyleBox["(9-43)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\(1 + \(a\_1\) z\^\(-1\) + \(a\_2\) 
                z\^\(-2\) +  ... \) + \(a\_\(P - 1\)\) 
            z\^\(\(-P\) + 1\) + \(a\_P\) 
            z\^\(-P\)\ \  = \ \ \(\(z\^P + \(a\_1\) z\^\(P - 1\) + \(a\_2\) z\
\^\(P - 2\) +  ... \) + \(a\_\(P - 1\)\) z + a\_P\)\/z\^P\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["(iii) Attenuating Factors",
    FontColor->RGBColor[0, 0, 1]],
  "  \n\n\tTo attenuate the signals ",
  Cell[BoxData[
      \(cos \((\[Theta]\ n)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\[Theta]\ n)\)\)]],
  ",  use factors of the form \n\n\t\t\t",
  Cell[BoxData[
      \(\((\ \(z - \[Rho]\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)\/z)\
\) \((\ \(z - \[Rho]\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\)\)\/z)\
\)\ \  = \ \ 1\  - \ \[Rho] \((\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\) + \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\))\) 
            z\^\(-1\)\  + \ \[Rho]\^2\ z\^\(-2\)\)]],
  "     if  ",
  Cell[BoxData[
      \(0 < \[Rho] < 1\)]],
  "  and  ",
  Cell[BoxData[
      \(0 < \[Theta] < \[Pi]\)]],
  ",    and  \n\n\t\t\t",
  Cell[BoxData[
      \(\((\ \(z - \[Rho]\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\)\)\/z)\)\ \
\  = \ \ 1\  + \ \[Rho]\ z\^\(-1\)\)]],
  "     if  ",
  Cell[BoxData[
      \(0 < \[Rho] < 1\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Theta] = \[Pi]\)]],
  ".  \n\t\t\n\tThe factor\t\n\t\n\t\t\t",
  Cell[BoxData[
      \(\((\ \(z - \[Rho]\)\/z)\)\ \  = \ \ 1\  - \ \[Rho]\ z\^\(-1\)\)]],
  "     if  ",
  Cell[BoxData[
      \(0 < \[Rho] < 1\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Phi] = 0\)]],
  ",  \n\t\t\nis a special case that attenuates low frequency signals.  These \
factors will contribute to the term ",
  StyleBox["(9-42)",
    FontColor->RGBColor[0, 0, 1]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(iv) Combination of Factors",
    FontColor->RGBColor[0, 0, 1]],
  "  \n\n\tThe transfer function ",
  Cell[BoxData[
      \(H \((z)\)\)]],
  " could have a zero or pole at the origin, but this has no net effect on \
the output signal.  The other zeros and poles determine the nature of the \
filter.  A conjugate pair of zeros ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ \[Theta]\)\)]],
  " of  ",
  Cell[BoxData[
      \(H \((z)\)\)]],
  " on the unit circle will \"zero-out\" the signals ",
  Cell[BoxData[
      \(cos \((\[Theta]\ n)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\[Theta]\ n)\)\)]],
  ".  If ",
  Cell[BoxData[
      \(0 < \[Rho] \[TildeTilde] 1\)]],
  " the conjugate pair of zeros ",
  Cell[BoxData[
      \(\[Rho]\ \[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ \
\[Theta]\)\)]],
  " of  ",
  Cell[BoxData[
      \(H \((z)\)\)]],
  " will attenuate the signals ",
  Cell[BoxData[
      \(cos \((\[Theta]\ n)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\[Theta]\ n)\)\)]],
  ", and the conjugate pair of poles ",
  Cell[BoxData[
      \(\[Rho]\ \[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ \
\[Phi]\)\)]],
  " of  ",
  Cell[BoxData[
      \(H \((z)\)\)]],
  " will amplify the signals  ",
  Cell[BoxData[
      \(cos \((\[Theta]\ n)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\[Theta]\ n)\)\)]],
  ".  It is useful to plot the location of the zeros and poles and notice \
their magnitude and argument.  As a general rule, zeros are used to attenuate \
signals and poles are used to amplify signals.  The primary goal of filter \
design is to construct  ",
  Cell[BoxData[
      \(H \((z)\)\)]],
  " so that the amplitude response ",
  Cell[BoxData[
      \(\(\(A\) \((\[Theta])\)\(\ \)\)\)]],
  " has a desired shape.  The following examples have been chosen to \
illustrate these concepts.  Books on digital signal filter design will \
explain the process in detail. "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 9.23 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The filter  ",
  Cell[BoxData[
      \(y[n]\ \  = \ \ x[n] + \ x[n - 2]\)]],
  "  is designed to zero out  ",
  Cell[BoxData[
      RowBox[{"cos", \((\(\[Pi]\/2\) n)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "sin", \((\(\[Pi]\/2\) n)\)}]]],
  ".  \n\n",
  StyleBox["9.23 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The moving average filter   ",
  Cell[BoxData[
      \(y[n]\  = \ \(1\/4\) \((x[n] + x[n - 1] + x[n - 2] + x[n - 3])\)\)]],
  "   is designed to zero out  ",
  Cell[BoxData[
      RowBox[{\(cos \((n\ \[Pi])\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"cos", \((\(\[Pi]\/2\) n)\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", 
          "sin", \((\(\[Pi]\/2\) n)\)}]}]]],
  ". "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009E0000]b000`400?l0
0000o`00003oo`3ooooo0?oooeL0oooo003o0?ooool0ooooE`3oool00?l0
ooooo`3ooomG0?ooo`00o`3ooooo0?oooeL0oooo003o0?ooool0ooooE`3o
ool00?l0ooooo`3ooomG0?ooo`00o`3ooooo0?oooeL0oooo003o0?ooool0
ooooE`3oool00?l0oooo<P3oool300000?l0oooo8P3oool00<<0oooo0`00
000b0?ooo`@00000=P3oool00`000000oooo0?ooo`3o0?ooob40oooo0034
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0=03oool5
00000?l0oooo8P3oool00<40oooo1@00000c0?ooo`030000003oool0oooo
03<0oooo00@000000?ooo`3oool00000o`3ooolS0?ooo`00`@3oool01000
0000oooo0?ooo`00000e0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`000000o`3ooolS0?ooo`00`P3oool00`000000oooo0000000c0?oo
o`040000003oool0oooo000003D0oooo0P00003o0?ooob<0oooo00330?oo
o`800000=03oool200000?l0ooooF`3oool00?l0oooo:P3oool>00000003
0?ooo`00000000000?l0oooo703oool00?l0ooooh@3oool00`000000oooo
0?ooo`1b0?ooo`00_`3oool8000002l0oooo2000003R0?ooo`030000003o
ool0oooo0780oooo003o0?ooofH0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1a0?ooo`<0003oM03oool00?l0oooo;@3oool20000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?oo
o`040000003oool0oooo000007<0oooo1@000?mc0?ooo`00o`3oool/0?oo
o`040000003oool0oooo000000D0oooo00@000000?ooo`3oool00000;`3o
ool00`000000oooo0000001/0?ooo`L00?l01@000?l8003o06/0oooo0030
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0000000_0?ooo`030000003oool0
000006L0oooo1@00o`070?ooo`D0003o203oool5003o06H0oooo00310?oo
o`040000003oool0oooo000003<0oooo00@000000?ooo`3oool00000<P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0000002h0oooo1@00
001Q0?ooo`D00?l03@3oool30000o`h0oooo1@00o`1Q0?ooo`00`P3oool0
0`000000oooo0000000d0?ooo`030000003oool0000002l0oooo00@00000
0?ooo`3oool000001@3oool500000940oooo0P00o`0D0?ooo`030000003o
ool0oooo00P0oooo0`0000060?ooo`<00?l0GP3oool00<80oooo00<00000
0?ooo`000000=03oool00`000000oooo0000000`0?ooo`800000V@3oool3
003o01H0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`030000003o
ool0oooo00T0oooo0P00o`1L0?ooo`00`@3oool500000380oooo1@000038
0?ooo`800?l06@3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool02P3oool2003o05X0oooo003o
0?oool@0oooo0P00o`0K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`800?l0F03oool0
0?l0ooooLP3oool3000004d0oooo0P00o`0M0?ooo`030000003oool0oooo
00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000l0oooo0P00
o`1F0?ooo`00S03ooooM000000L0oooo00D000000?ooo`3oool0oooo0000
001:0?ooo`800?l07`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0403oool2003o05@0oooo
002<0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=03o
ool20?l003D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A@3o
ool2003o0240oooo00<000000?ooo`3oool00P3oool5000001L0oooo0P00
o`1B0?ooo`00S03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo03<0oooo0`3o000e0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool01@3oool6000004H0oooo00<00?l00?ooo`3oool08@3oool0
0`000000oooo0?ooo`0P0?ooo`03003o003oool0oooo04l0oooo002<0?oo
o`030000003oool0oooo06X0oooo00@0o`000?ooo`3oool0o`00M03oool0
1@000000oooo0?ooo`3oool0000004D0oooo00<00?l00?ooo`3oool08P3o
ool00`000000oooo0?ooo`0Q0?ooo`03003o003oool0oooo04h0oooo002<
0?ooo`030000003oool0oooo06T0oooo00D0o`000?ooo`3oool0oooo0?l0
001e0?ooo`<00000A@3oool00`00o`00oooo0?ooo`0S0?ooo`030000003o
ool0oooo0280oooo00<00?l00?ooo`3oool0C@3oool008`0oooo00<00000
0?ooo`3oool0J@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo0;P0oooo0P00o`0V0?ooo`030000003oool0oooo02<0oooo0P00o`1=
0?ooo`00S03oool00`000000oooo0?ooo`1X0?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool0]`3oool00`00o`00oooo0?ooo`0V0?oo
o`030000003oool0oooo02D0oooo00<00?l00?ooo`3oool0BP3oool008`0
oooo00<000000?ooo`3oool0J03oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0oooo0;D0oooo00<00?l00?ooo`3oool09`3oool00`000000
oooo0?ooo`0V0?ooo`800?l0BP3oool008`0oooo00<000000?ooo`3oool0
I`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0;@0oooo
00<00?l00?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`03003o
003oool0oooo04L0oooo002<0?ooo`030000003oool0oooo06L0oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`2a0?ooo`800?l0:`3o
ool00`000000oooo0?ooo`0Y0?ooo`03003o003oool0oooo04H0oooo002<
0?ooo`030000003oool0oooo06H0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`2`0?ooo`03003o003oool0oooo02/0oooo00<00000
0?ooo`3oool0:P3oool00`00o`00oooo0?ooo`150?ooo`00S03oool00`00
0000oooo0?ooo`1V0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?oo
o`3oool0[P3oool00`00o`00oooo0?ooo`0/0?ooo`030000003oool0oooo
02/0oooo00<00?l00?ooo`3oool0A03oool008`0oooo00<000000?ooo`3o
ool0I@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0:`0
oooo00<00?l00?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`03
003o003oool0oooo04<0oooo002<0?ooo`030000003oool0oooo06@0oooo
00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`2[0?ooo`03003o
003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`00o`00oooo
0?ooo`120?ooo`00S03oool00`000000oooo0?ooo`1T0?ooo`030?l0003o
ool0oooo00`0oooo00<0o`000?ooo`3oool0ZP3oool00`00o`00oooo0?oo
o`0^0?ooo`030000003oool0oooo02d0oooo00<00?l00?ooo`3oool0@P3o
ool008`0oooo00<000000?ooo`3oool0H`3oool00`3o0000oooo0?ooo`0=
0?ooo`030?l0003oool0oooo0:T0oooo00<00?l00?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0^0?ooo`03003o003oool0oooo0440oooo002<0?oo
o`030000003oool0oooo06<0oooo00<0o`000?ooo`3oool03P3oool00`3o
0000oooo0?ooo`2W0?ooo`03003o003oool0oooo0300oooo00<000000?oo
o`3oool0;`3oool00`00o`00oooo0?ooo`100?ooo`00S03oool00`000000
oooo0?ooo`1R0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3o
ool0YP3oool00`00o`00oooo0?ooo`0a0?ooo`030000003oool0oooo0300
oooo00<00?l00?ooo`3oool0?`3oool008`0oooo00<000000?ooo`3oool0
HP3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo0:@0oooo
00<00?l00?ooo`3oool0<P3oool00`000000oooo0?ooo`0a0?ooo`03003o
003oool0oooo03h0oooo002<0?ooo`030000003oool0oooo0640oooo00<0
o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`2S0?ooo`03003o003o
ool0oooo0380oooo00<000000?ooo`3oool0<@3oool00`00o`00oooo0?oo
o`0n0?ooo`00S03oool00`000000oooo0?ooo`1Q0?ooo`030?l0003oool0
oooo0180oooo00<0o`000?ooo`3oool0XP3oool00`00o`00oooo0?ooo`0c
0?ooo`030000003oool0oooo0380oooo00<00?l00?ooo`3oool0?@3oool0
08`0oooo00<000000?ooo`3oool0H03oool00`3o0000oooo0?ooo`0D0?oo
o`030?l0003oool0oooo0:00oooo00<00?l00?ooo`3oool0=03oool00`00
0000oooo0?ooo`0c0?ooo`03003o003oool0oooo03`0oooo002<0?ooo`03
0000003oool0oooo0600oooo00<0o`000?ooo`3oool0503oool00`3o0000
oooo0?ooo`2P0?ooo`03003o003oool0oooo03@0oooo00<000000?ooo`3o
ool0<`3oool00`00o`00oooo0?ooo`0l0?ooo`00S03oool00`000000oooo
0?ooo`1O0?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool0
WP3oool00`00o`00oooo0?ooo`0e0?ooo`030000003oool0oooo03@0oooo
00<00?l00?ooo`3oool0>`3oool008`0oooo00<000000?ooo`3oool0GP3o
ool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo09d0oooo00<0
0?l00?ooo`3oool0=P3oool00`000000oooo0?ooo`0e0?ooo`03003o003o
ool0oooo03X0oooo002<0?ooo`030000003oool0oooo05h0oooo00<0o`00
0?ooo`3oool0603oool00`3o0000oooo0?ooo`2L0?ooo`03003o003oool0
oooo03H0oooo00<000000?ooo`3oool0=P3oool00`00o`00oooo0?ooo`0i
0?ooo`00S03oool00`000000oooo0?ooo`1M0?ooo`030?l0003oool0oooo
01T0oooo00<0o`000?ooo`3oool0V`3oool00`00o`00oooo0?ooo`0g0?oo
o`030000003oool0oooo03H0oooo00<00?l00?ooo`3oool0>@3oool008`0
oooo00<000000?ooo`3oool0G@3oool00`3o0000oooo0?ooo`0J0?ooo`03
0?l0003oool0oooo09X0oooo00<00?l00?ooo`3oool0=`3oool00`000000
oooo0?ooo`0g0?ooo`03003o003oool0oooo03P0oooo002<0?ooo`030000
003oool0oooo05`0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo
0?ooo`2I0?ooo`03003o003oool0oooo03P0oooo00<000000?ooo`3oool0
=`3oool00`00o`00oooo0?ooo`0h0?ooo`00S03oool00`000000oooo0?oo
o`1L0?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool0V03o
ool00`00o`00oooo0?ooo`0h0?ooo`030000003oool0oooo03L0oooo00<0
0?l00?ooo`3oool0>03oool008`0oooo00<000000?ooo`3oool0F`3oool0
0`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo09L0oooo00<00?l0
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`03003o003oool0
oooo03L0oooo002<0?ooo`030000003oool0oooo05/0oooo00<0o`000?oo
o`3oool07P3oool00`3o0000oooo0?ooo`2F0?ooo`03003o003oool0oooo
03T0oooo00<000000?ooo`3oool0>03oool00`00o`00oooo0?ooo`0g0?oo
o`00S03oool00`000000oooo0?ooo`1J0?ooo`030?l0003oool0oooo01l0
oooo00<0o`000?ooo`3oool0UP3oool00`00o`00oooo0?ooo`0i0?ooo`03
0000003oool0oooo03T0oooo00<00?l00?ooo`3oool0=P3oool008`0oooo
00<000000?ooo`3oool0F@3oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0
003oool0oooo09@0oooo00<00?l00?ooo`3oool0>P3oool00`000000oooo
0?ooo`0i0?ooo`03003o003oool0oooo03H0oooo002<0?ooo`030000003o
ool0oooo05T0oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo0?oo
o`2D0?ooo`03003o003oool0oooo03X0oooo00<000000?ooo`3oool0>P3o
ool00`00o`00oooo0?ooo`0e0?ooo`00S03oool00`000000oooo0?ooo`1H
0?ooo`030?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool0TP3oool0
0`00o`00oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<00?l0
0?ooo`3oool0=@3oool008`0oooo00<000000?ooo`3oool0F03oool00`3o
0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo0940oooo00<00?l00?oo
o`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`03003o003oool0oooo
03D0oooo002<0?ooo`030000003oool0oooo05L0oooo00<0o`000?ooo`3o
ool09@3oool00`3o0000oooo0?ooo`2A0?ooo`03003o003oool0oooo03/0
oooo00<000000?ooo`3oool0>`3oool00`00o`00oooo0?ooo`0d0?ooo`00
S03oool00`000000oooo0?ooo`1G0?ooo`030?l0003oool0oooo02H0oooo
00<0o`000?ooo`3oool0S`3oool00`00o`00oooo0?ooo`0l0?ooo`030000
003oool0oooo03/0oooo00<00?l00?ooo`3oool0=03oool008`0oooo00<0
00000?ooo`3oool0EP3oool00`3o0000oooo0?ooo`0W0?ooo`030?l0003o
ool0oooo08l0oooo00<00?l00?ooo`3oool0?03oool00`000000oooo0?oo
o`0k0?ooo`03003o003oool0oooo03@0oooo002<0?ooo`030000003oool0
oooo05D0oooo00<0o`000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`2>
0?ooo`03003o003oool0oooo03`0oooo00<000000?ooo`3oool0>`3oool0
0`00o`00oooo0?ooo`0d0?ooo`00S03oool00`000000oooo0?ooo`1E0?oo
o`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool0S03oool00`00
o`00oooo0?ooo`0m0?ooo`030000003oool0oooo03/0oooo00<00?l00?oo
o`3oool0=03oool008`0oooo00<000000?ooo`3oool0E03oool00`3o0000
oooo0?ooo`0[0?ooo`030?l0003oool0oooo08`0oooo00<00?l00?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0l0?ooo`03003o003oool0oooo03<0
oooo002<0?ooo`030000003oool0oooo05@0oooo00<0o`000?ooo`3oool0
;03oool00`3o0000oooo0?ooo`2;0?ooo`03003o003oool0oooo03d0oooo
00<000000?ooo`3oool0?03oool00`00o`00oooo0?ooo`0c0?ooo`00S03o
ool00`000000oooo0?ooo`1C0?ooo`030?l0003oool0oooo02d0oooo00<0
o`000?ooo`3oool0R`3oool00`00o`00oooo0?ooo`0m0?ooo`030000003o
ool0oooo03`0oooo00<00?l00?ooo`3oool0<`3oool008`0oooo00<00000
0?ooo`3oool0D`3oool00`3o0000oooo0?ooo`0^0?ooo`030?l0003oool0
oooo08X0oooo00<00?l00?ooo`3oool0?@3oool00`000000oooo0?ooo`0l
0?ooo`03003o003oool0oooo03<0oooo002<0?ooo`030000003oool0oooo
0580oooo00<0o`000?ooo`3oool0<03oool00`3o0000oooo0?ooo`280?oo
o`03003o003oool0oooo03h0oooo00<000000?ooo`3oool0?03oool00`00
o`00oooo0?ooo`0c0?ooo`00S03oool00`000000oooo0?ooo`1B0?ooo`03
0?l0003oool0oooo0300oooo00<0o`000?ooo`3oool0R03oool00`00o`00
oooo0?ooo`0n0?ooo`030000003oool0oooo03d0oooo00<00?l00?ooo`3o
ool0<P3oool008`0oooo00<000000?ooo`3oool0D@3oool00`3o0000oooo
0?ooo`0b0?ooo`030?l0003oool0oooo08L0oooo00<00?l00?ooo`3oool0
?P3oool00`000000oooo0?ooo`0m0?ooo`03003o003oool0oooo0380oooo
002<0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0<`3o
ool00`3o0000oooo0?ooo`270?ooo`03003o003oool0oooo03h0oooo00<0
00000?ooo`3oool0?@3oool00`00o`00oooo0?ooo`0b0?ooo`00S03oool0
0`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo03@0oooo00<0o`00
0?ooo`3oool0QP3oool00`00o`00oooo0?ooo`0n0?ooo`030000003oool0
oooo03d0oooo00<00?l00?ooo`3oool0<P3oool008`0oooo00<000000?oo
o`3oool0C`3oool00`3o0000oooo0?ooo`0f0?ooo`030?l0003oool0oooo
08D0oooo00<00?l00?ooo`3oool0?P3oool00`000000oooo0?ooo`0m0?oo
o`03003o003oool0oooo0380oooo002<0?ooo`030000003oool0oooo04h0
oooo00<0o`000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`250?ooo`03
003o003oool0oooo03h0oooo00<000000?ooo`3oool0?@3oool00`00o`00
oooo0?ooo`0b0?ooo`00S03oool00`000000oooo0?ooo`1>0?ooo`030?l0
003oool0oooo03P0oooo00<0o`000?ooo`3oool0Q03oool00`00o`00oooo
0?ooo`0n0?ooo`030000003oool0oooo03d0oooo00<00?l00?ooo`3oool0
6@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo
002<0?ooo`030000003oool0oooo04d0oooo00<0o`000?ooo`3oool0>@3o
ool00`3o0000oooo0?ooo`240?ooo`03003o003oool0oooo03h0oooo00<0
00000?ooo`3oool0?@3oool00`00o`00oooo0?ooo`0H0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0303oool008`0oooo00<00000
0?ooo`3oool0C@3oool00`3o0000oooo0?ooo`0j0?ooo`030?l0003oool0
oooo08<0oooo00<00?l00?ooo`3oool0?03oool30?l003l0oooo00<00?l0
0?ooo`3oool02@3oool300000080oooo00<000000?ooo`3oool00`000003
0?ooo`030000003oool0oooo0080oooo100000040?ooo`030000003oool0
oooo00/0oooo002<0?ooo`030000003oool0oooo04`0oooo00<0o`000?oo
o`3oool0>`3oool00`3o0000oooo0?ooo`200?ooo`<0000000<00?l00000
00000000>`0000050?l003h0000000<00?l00000000000001@0000050?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool02`3oool008`0oooo00<000000?ooo`3oool0B`3oool00`3o
0000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0880oooo00<00?l00?oo
o`3oool0>`3oool50?l003h0oooo00<00?l00?ooo`3oool02P3oool30000
00<0oooo100000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`0;0?ooo`00S03oool00`000000
oooo0?ooo`1;0?ooo`030?l0003oool0oooo03d0oooo00<0o`000?ooo`3o
ool0PP3oool00`00o`00oooo0?ooo`0k0?ooo`D0o`00?P3oool00`00o`00
oooo0?ooo`0:0?ooo`040000003oool0oooo000000<0oooo0P0000040?oo
o`030000003oool0oooo0080oooo100000040?ooo`030000003oool0oooo
00/0oooo002<0?ooo`030000003oool0oooo04X0oooo00<0o`000?ooo`3o
ool0?`3oool00`3o0000oooo0?ooo`210?ooo`03003o003oool0oooo03`0
oooo0`3o00020?ooo`<00000>P3oool00`00o`00oooo0?ooo`0:0?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0<0?ooo`00S03oool00`000000oooo0?ooo`190?ooo`03
0?l0003oool0oooo0440oooo00<0o`000?ooo`3oool0P03oool00`00o`00
oooo0?ooo`0n0?ooo`050000003oool0oooo0?ooo`0000001@3oool50000
0340oooo00<00?l00?ooo`3oool02@3oool4000000`0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`00S03oool00`000000
oooo0?ooo`190?ooo`030?l0003oool0oooo0440oooo00<0o`000?ooo`3o
ool0P03oool00`00o`00oooo0?ooo`0n0?ooo`060000003oool0oooo0?oo
o`000000oooo0P0000040?ooo`030000003oool0oooo0340oooo00<00?l0
0?ooo`3oool0<P3oool008`0oooo00<000000?ooo`3oool0B03oool00`3o
0000oooo0?ooo`130?ooo`030?l0003oool0oooo07l0oooo00<00?l00?oo
o`3oool0?P3oool010000000oooo0?ooo`3oool200000080oooo00D00000
0?ooo`3oool0oooo0000000c0?ooo`03003o003oool0oooo0380oooo0024
0?ooo`D000000`3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0
oooo04<0oooo00<0o`000?ooo`3oool0O`3oool00`00o`00oooo0?ooo`0n
0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?oo
o`00000c0?ooo`03003o003oool0oooo0380oooo00260?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0A`3oool00`3o0000oooo0?oo
o`150?ooo`030?l0003oool0oooo07h0oooo00<00?l00?ooo`3oool0?P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0a0?ooo`03003o003oool0oooo0380oooo
00260?ooo`030000003oool0oooo00<0oooo0`0000160?ooo`030?l0003o
ool0oooo04H0oooo00<0o`000?ooo`3oool0OP3oool00`00o`00oooo0?oo
o`0n0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`040000003o
ool00000000003<0oooo00<00?l00?ooo`3oool0<P3oool008H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`160?ooo`030?l0003o
ool0oooo04L0oooo00<0o`000?ooo`3oool0O@3oool00`00o`00oooo0?oo
o`0n0?ooo`040000003oool0oooo0?ooo`80000000<0oooo000000000000
=`3oool00`00o`00oooo0?ooo`0b0?ooo`00QP3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo04D0oooo00<0o`000?ooo`3oool0B@3o
ool00`3o0000oooo0?ooo`1l0?ooo`03003o003oool0oooo03h0oooo00<0
00000?ooo`3oool0?03oool00`00o`00oooo0?ooo`0c0?ooo`00Q@3oool2
000000D0oooo00<000000?ooo`3oool0A03oool00`3o0000oooo0?ooo`1:
0?ooo`030?l0003oool0oooo07d0oooo00<00?l00?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0l0?ooo`03003o003oool0oooo03<0oooo002<0?oo
o`030000003oool0oooo04@0oooo00<0o`000?ooo`3oool0B`3oool00`3o
0000oooo0?ooo`1l0?ooo`03003o003oool0oooo03d0oooo00<000000?oo
o`3oool0?03oool00`00o`00oooo0?ooo`0c0?ooo`00S03oool00`000000
oooo0?ooo`130?ooo`030?l0003oool0oooo04d0oooo00<0o`000?ooo`3o
ool0N`3oool00`00o`00oooo0?ooo`0m0?ooo`030000003oool0oooo03`0
oooo00<00?l00?ooo`3oool0<`3oool008`0oooo00<000000?ooo`3oool0
@P3oool00`3o0000oooo0?ooo`1>0?ooo`030?l0003oool0oooo07/0oooo
00<00?l00?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`03003o
003oool0oooo03<0oooo002<0?ooo`030000003oool0oooo0480oooo00<0
o`000?ooo`3oool0C`3oool00`3o0000oooo0?ooo`1k0?ooo`03003o003o
ool0oooo03`0oooo00<000000?ooo`3oool0>`3oool00`00o`00oooo0?oo
o`0d0?ooo`00S03oool00`000000oooo0?ooo`110?ooo`030?l0003oool0
oooo0500oooo00<0o`000?ooo`3oool0N`3oool00`00o`00oooo0?ooo`0l
0?ooo`030000003oool0oooo03/0oooo00<00?l00?ooo`3oool0=03oool0
08`0oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`1A0?oo
o`030?l0003oool0oooo07X0oooo00<00?l00?ooo`3oool0?03oool00`00
0000oooo0?ooo`0k0?ooo`03003o003oool0oooo03@0oooo002<0?ooo`03
0000003oool0oooo0400oooo00<0o`000?ooo`3oool0D`3oool00`3o0000
oooo0?ooo`1j0?ooo`03003o003oool0oooo03/0oooo00<000000?ooo`3o
ool0>`3oool00`00o`00oooo0?ooo`0d0?ooo`00S03oool00`000000oooo
0?ooo`0o0?ooo`030?l0003oool0oooo05@0oooo00<0o`000?ooo`3oool0
NP3oool00`00o`00oooo0?ooo`0k0?ooo`030000003oool0oooo03/0oooo
00<00?l00?ooo`3oool0=03oool008`0oooo00<000000?ooo`3oool0?`3o
ool00`3o0000oooo0?ooo`1E0?ooo`030?l0003oool0oooo07T0oooo00<0
0?l00?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`03003o003o
ool0oooo03D0oooo002<0?ooo`030000003oool0oooo03h0oooo00<0o`00
0?ooo`3oool0E`3oool00`3o0000oooo0?ooo`1h0?ooo`03003o003oool0
oooo03/0oooo00<000000?ooo`3oool0>P3oool00`00o`00oooo0?ooo`0e
0?ooo`00S03oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo
05P0oooo00<0o`000?ooo`3oool0N@3oool00`00o`00oooo0?ooo`0j0?oo
o`030000003oool0oooo03X0oooo00<00?l00?ooo`3oool0=@3oool008`0
oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`1I0?ooo`03
0?l0003oool0oooo07P0oooo00<00?l00?ooo`3oool0>P3oool00`000000
oooo0?ooo`0i0?ooo`03003o003oool0oooo03H0oooo002<0?ooo`030000
003oool0oooo03`0oooo00<0o`000?ooo`3oool0F`3oool00`3o0000oooo
0?ooo`1h0?ooo`03003o003oool0oooo03T0oooo00<000000?ooo`3oool0
>@3oool00`00o`00oooo0?ooo`0f0?ooo`00S03oool00`000000oooo0?oo
o`0k0?ooo`030?l0003oool0oooo05d0oooo00<0o`000?ooo`3oool0M`3o
ool00`00o`00oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo00<0
0?l00?ooo`3oool0=`3oool008`0oooo00<000000?ooo`3oool0>`3oool0
0`3o0000oooo0?ooo`1M0?ooo`030?l0003oool0oooo07L0oooo00<00?l0
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`03003o003oool0
oooo03L0oooo002<0?ooo`030000003oool0oooo03X0oooo00<0o`000?oo
o`3oool0G`3oool00`3o0000oooo0?ooo`1g0?ooo`03003o003oool0oooo
03P0oooo00<000000?ooo`3oool0=`3oool00`00o`00oooo0?ooo`0h0?oo
o`00S03oool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0oooo0640
oooo00<0o`000?ooo`3oool0MP3oool00`00o`00oooo0?ooo`0h0?ooo`03
0000003oool0oooo03L0oooo00<00?l00?ooo`3oool0>03oool008`0oooo
00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`1S0?ooo`030?l0
003oool0oooo07H0oooo00<00?l00?ooo`3oool0=`3oool00`000000oooo
0?ooo`0f0?ooo`03003o003oool0oooo03T0oooo002<0?ooo`030000003o
ool0oooo03P0oooo00<0o`000?ooo`3oool0H`3oool00`3o0000oooo0?oo
o`1g0?ooo`03003o003oool0oooo03H0oooo00<000000?ooo`3oool0=P3o
ool00`00o`00oooo0?ooo`0i0?ooo`00S03oool00`000000oooo0?ooo`0g
0?ooo`030?l0003oool0oooo06D0oooo00<0o`000?ooo`3oool0MP3oool0
0`00o`00oooo0?ooo`0f0?ooo`030000003oool0oooo03D0oooo00<00?l0
0?ooo`3oool0>P3oool008`0oooo00<000000?ooo`3oool0=P3oool00`3o
0000oooo0?ooo`1W0?ooo`030?l0003oool0oooo07H0oooo00<00?l00?oo
o`3oool0=@3oool00`000000oooo0?ooo`0e0?ooo`03003o003oool0oooo
03X0oooo002<0?ooo`030000003oool0oooo03H0oooo00<0o`000?ooo`3o
ool0J03oool00`3o0000oooo0?ooo`1e0?ooo`03003o003oool0oooo03D0
oooo00<000000?ooo`3oool0=03oool00`00o`00oooo0?ooo`0k0?ooo`00
S03oool00`000000oooo0?ooo`0e0?ooo`030?l0003oool0oooo06T0oooo
00<0o`000?ooo`3oool0MP3oool00`00o`00oooo0?ooo`0d0?ooo`030000
003oool0oooo03<0oooo00<00?l00?ooo`3oool0?03oool008`0oooo00<0
00000?ooo`3oool0=03oool00`3o0000oooo0?ooo`1[0?ooo`030?l0003o
ool0oooo07D0oooo00<00?l00?ooo`3oool0=03oool00`000000oooo0?oo
o`0c0?ooo`03003o003oool0oooo03`0oooo002<0?ooo`030000003oool0
oooo03<0oooo00<0o`000?ooo`3oool0K@3oool00`3o0000oooo0?ooo`1e
0?ooo`03003o003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool0
0`00o`00oooo0?ooo`0m0?ooo`00S03oool00`000000oooo0?ooo`0b0?oo
o`030?l0003oool0oooo06l0oooo00<0o`000?ooo`3oool0M@3oool00`00
o`00oooo0?ooo`0b0?ooo`030000003oool0oooo0340oooo00<00?l00?oo
o`3oool0?P3oool008`0oooo00<000000?ooo`3oool0<P3oool00`3o0000
oooo0?ooo`1`0?ooo`030?l0003oool0oooo07@0oooo00<00?l00?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0a0?ooo`03003o003oool0oooo03h0
oooo002<0?ooo`030000003oool0oooo0340oooo00<0o`000?ooo`3oool0
L@3oool00`3o0000oooo0?ooo`1e0?ooo`03003o003oool0oooo0340oooo
00<000000?ooo`3oool0<03oool00`00o`00oooo0?ooo`0o0?ooo`00S03o
ool00`000000oooo0?ooo`0`0?ooo`030?l0003oool0oooo07<0oooo00<0
o`000?ooo`3oool0M@3oool00`00o`00oooo0?ooo`0`0?ooo`030000003o
ool0oooo02l0oooo00<00?l00?ooo`3oool0@03oool008`0oooo00<00000
0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`1e0?ooo`030?l0003oool0
oooo07D0oooo00<00?l00?ooo`3oool0;`3oool00`000000oooo0?ooo`0^
0?ooo`03003o003oool0oooo0440oooo002<0?ooo`030000003oool0oooo
02h0oooo00<0o`000?ooo`3oool0M`3oool00`3o0000oooo0?ooo`1e0?oo
o`03003o003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`00
o`00oooo0?ooo`120?ooo`00S03oool00`000000oooo0?ooo`0]0?ooo`03
0?l0003oool0oooo07T0oooo00<0o`000?ooo`3oool0M@3oool00`00o`00
oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<00?l00?ooo`3o
ool0@P3oool008`0oooo00<000000?ooo`3oool0;@3oool00`3o0000oooo
0?ooo`1j0?ooo`030?l0003oool0oooo07D0oooo00<00?l00?ooo`3oool0
;03oool00`000000oooo0?ooo`0/0?ooo`03003o003oool0oooo04<0oooo
002<0?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`3oool0N`3o
ool00`3o0000oooo0?ooo`1e0?ooo`03003o003oool0oooo02`0oooo00<0
00000?ooo`3oool0:`3oool00`00o`00oooo0?ooo`140?ooo`00S03oool0
0`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo07d0oooo00<0o`00
0?ooo`3oool0M@3oool00`00o`00oooo0?ooo`0[0?ooo`030000003oool0
oooo02X0oooo00<00?l00?ooo`3oool0A@3oool008`0oooo00<000000?oo
o`3oool0:P3oool00`3o0000oooo0?ooo`1o0?ooo`030?l0003oool0oooo
07D0oooo0P00o`0[0?ooo`030000003oool0oooo02T0oooo00<00?l00?oo
o`3oool0AP3oool008`0oooo00<000000?ooo`3oool0:@3oool00`3o0000
oooo0?ooo`210?ooo`030?l0003oool0oooo07H0oooo00<00?l00?ooo`3o
ool0:03oool00`000000oooo0?ooo`0X0?ooo`03003o003oool0oooo04L0
oooo002<0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool0
P`3oool00`3o0000oooo0?ooo`1f0?ooo`03003o003oool0oooo02L0oooo
00<000000?ooo`3oool09P3oool2003o04X0oooo002<0?ooo`030000003o
ool0oooo02L0oooo00<0o`000?ooo`3oool0Q@3oool00`3o0000oooo0?oo
o`1f0?ooo`03003o003oool0oooo02H0oooo00<000000?ooo`3oool09@3o
ool00`00o`00oooo0?ooo`1:0?ooo`00S03oool00`000000oooo0?ooo`0V
0?ooo`030?l0003oool0oooo08L0oooo00<0o`000?ooo`3oool0MP3oool2
003o02H0oooo00<000000?ooo`3oool08`3oool2003o04d0oooo002<0?oo
o`030000003oool0oooo02D0oooo00<0o`000?ooo`3oool0R@3oool00`3o
0000oooo0?ooo`1g0?ooo`03003o003oool0oooo02<0oooo00<000000?oo
o`3oool08P3oool00`00o`00oooo0?ooo`1=0?ooo`00S03oool00`000000
oooo0?ooo`0T0?ooo`030?l0003oool0oooo08/0oooo00<0o`000?ooo`3o
ool0M`3oool00`00o`00oooo0?ooo`0R0?ooo`030000003oool0oooo0240
oooo00<00?l00?ooo`3oool0CP3oool008`0oooo00<000000?ooo`3oool0
8`3oool00`3o0000oooo0?ooo`2=0?ooo`030?l0003oool0oooo07L0oooo
00<00?l00?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`D00000
503oool00`00o`00oooo0?ooo`1?0?ooo`00S03oool00`000000oooo0?oo
o`0R0?ooo`030?l0003oool0oooo08l0oooo00<0o`000?ooo`3oool0M`3o
ool2003o0240oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0B0?ooo`800?l0DP3oool008`0oooo00<000000?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`2A0?ooo`030?l0003oool0oooo07P0oooo0P00o`0O
0?ooo`040000003oool0oooo0?ooo`D000000`3oool00`000000oooo0?oo
o`0@0?ooo`800?l0E03oool008`0oooo00<000000?ooo`3oool0803oool0
0`3o0000oooo0?ooo`2C0?ooo`030?l0003oool0oooo07T0oooo0P00o`0M
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0>0?ooo`800?l0EP3oool008`0oooo00<00000
0?ooo`3oool07`3oool00`3o0000oooo0?ooo`2E0?ooo`030?l0003oool0
oooo07X0oooo0P00o`0K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`800?l0F03oool0
08`0oooo00<000000?ooo`3oool07@3oool20?l009T0oooo00<0o`000?oo
o`3oool0N`3oool2003o01T0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`3oool2000000`0oooo0P00o`1J0?ooo`00S03oool00`00
0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo09X0oooo0P3o001m0?oo
o`<00?l05P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000d0oooo0`00o`1L0?ooo`00S03oool00`000000oooo0?ooo`0K0?oo
o`030?l0003oool0oooo09d0oooo00<0o`000?ooo`3oool0O@3oool3003o
01<0oooo00<000000?ooo`3oool00P3oool5000000T0oooo0`00o`1O0?oo
o`00S03oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo09l0
oooo00<0o`000?ooo`3oool0O`3oool4003o00d0oooo0`000?l?0?ooo`<0
0?l0HP3oool008`0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo
0?ooo`2Q0?ooo`030?l0003oool0oooo0880oooo1000o`080?ooo`D0003o
2@3oool5003o06D0oooo002<0?ooo`030000003oool0oooo01L0oooo0P3o
002U0?ooo`030?l0003oool0oooo08D0oooo2000o`050000o`T00?l0JP3o
ool008`0oooo00<000000?ooo`3oool05@3oool20?l00:P0oooo0P3o002=
0?ooo`D0003oL`3oool008`0oooo00<000000?ooo`3oool0503oool00`3o
0000oooo0?ooo`2Z0?ooo`80o`00S03oool30000og@0oooo002<0?ooo`03
0000003oool0oooo0180oooo0P3o002_0?ooo`80o`00S03oool00`000000
oooo0?ooo`1b0?ooo`00S03oool00`000000oooo0?ooo`0@0?ooo`80o`00
/`3oool20?l008X0oooo00<000000?ooo`3oool0LP3oool008`0oooo00<0
00000?ooo`3oool03P3oool20?l00;L0oooo0P3o00280?ooo`030000003o
ool0oooo0780oooo002<0?ooo`030000003oool0oooo00`0oooo0P3o002k
0?ooo`80o`00QP3oool00`000000oooo0?ooo`1b0?ooo`00Q03oool40000
00@0oooo00<000000?ooo`3oool0203oool40?l00;l0oooo103o00220?oo
o`030000003oool0oooo0780oooo00240?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool40?l00<L0oooo1@3o003b0?ooo`00
Q@3oool00`000000oooo0?ooo`040?ooo`L0o`00d03oool60?l00>`0oooo
00260?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3o
ooo70?ooo`00Q03oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0?l0ooooa`3oool008D0oooo0P0000050?ooo`030000003oool0
oooo0?l0ooooa`3oool008`0oooo00<000000?ooo`3oool0o`3ooomC0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0J03oool008`0
oooo00<000000?ooo`3oool0o`3ooomB0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0I`3oool008`0oooo00<000000?ooo`3oool0
o`3ooom50?ooo`<0000000L0oooo000000000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool00P3oool4000000@0oooo00<000000?oo
o`3oool0IP3oool00?l0ooooe@3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`1V0?ooo`00o`3ooooE
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000050?ooo`03
0000003oool0oooo06H0oooo003o0?ooomD0oooo00<000000?ooo`3oool0
0`0000000`3oool000000?ooo`020?ooo`030000003oool0oooo0080oooo
100000040?ooo`030000003oool0oooo06H0oooo003o0?ooomD0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo06L0oooo003o0?ooom@0oooo0`00000;0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0J03oool00?l0ooooo`3ooomG0?oo
o`00o`3ooooo0?oooeL0oooo003o0?ooool0ooooE`3oool008X0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oool00oooo0029
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooono
0?ooo`00P@3oool2000000030?ooo`00000000000080oooo00<000000?oo
o`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0o`3ooonn0?oo
o`00P@3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0o`3ooonn0?ooo`00PP3oool3000000<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000o`3o
ooo00?ooo`00PP3oool00`000000oooo000000030?ooo`040000003oool0
oooo0?ooo`H000000`3oool00`000000oooo0?ooo`3o0?oookh0oooo0023
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`040000003oool0oooo00000?l0oooo`@3oool00880oooo0P00
00060?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000oooo
0?ooo`3o0?oool00oooo003o0?ooool0ooooE`3oool00?l0ooooo`3ooomG
0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{597, 183},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Figure 9.9.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "Amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  ", and zero-pole plot for  ",
  Cell[BoxData[
      \(y[n] = \(1\/4\) \(\[Sum]\+\(k = 0\)\%3 x[n - k]\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.23.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["9.23 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  For part (a) use the conjugate pair of zeros  ",
  Cell[BoxData[
      RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        "  ", \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/2\)\)}]]],
  "  and calculate \n\n\t\t\t",
  Cell[BoxData[{
      \(\((\ \(z - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\)\)\/z)\) \((\ \
\(z - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/2\)\)\/z)\)\ \  = \ \ \
\(\(1\/z\^2\) \((z - \[ImaginaryI])\)\ \((z + \[ImaginaryI])\)\  = \ \ \(1\/z\
\^2\) \((1 + z\^2)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1\ \  + \ \ 0 
             z\^\(-1\)\ \  + \ \ z\^\(-2\)\)\)\)}]],
  "  \n\nThe transfer function has the form  ",
  Cell[BoxData[
      \(H \((z)\)\  = \ \(b\_0 + \(b\_1\) z\^\(-1\) + \(b\_2\) z\^\(-2\)\)\/1\
\)]],
  " and we see that  ",
  Cell[BoxData[
      RowBox[{\(b\_0 = 1\), ",", 
        RowBox[{\(b\_1\), "=", 
          RowBox[{
            RowBox[{"0", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(b\_2\)}], "=", "1"}]}]}]]],
  ".  The desired filter for (a) is \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(y[n]\ \  = \ \ b\_0\ x[n] + b\_1\ x[n - 1] + 
          b\_2\ x[n - 2]\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(y[n]\ \  = \ \ x[n] + \ x[n - 2]\)}]],
  " "
}], "Text"],

Cell[TextData[{
  StyleBox["9.23 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  For part (b) we introduce the additional zero  ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\)\)]],
  "  and calculate \n\n\t\t\t",
  Cell[BoxData[{
      \(\((\ \(z - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\)\)\/z)\) \((\ \
\(z - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/2\)\)\/z)\) \((\ \(z - \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]\)\)\/z)\)\ \  = \ \ \(1\/z\^3\) \
\((z - \[ImaginaryI])\)\ \((z + \[ImaginaryI])\) \((z + 
              1)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(\(1\/z\^3\) \((z\^2 + 1)\) \((z + 1)\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(\(1\/z\^3\) \((z\^3 + z\^2 + z + 1)\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(1\  + \ z\^\(-1\)\  + \ z\^\(-2\)\  + \ z\^\(-3\)\)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "The transfer function has the form  ",
  Cell[BoxData[
      \(H \((z)\)\  = \ \(b\_0 + \(b\_1\) z\^\(-1\) + \(b\_2\) z\^\(-2\) + \
\(b\_3\) z\^\(-3\)\)\/1\)]],
  " and we see that  ",
  Cell[BoxData[
      \(b\_0 = \(b\_1 = \(b\_2 = \(b\_3 = 1\)\)\)\)]],
  ".  Hence, a filter for zeroing out ",
  Cell[BoxData[
      RowBox[{\(cos \((n\ \[Pi])\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"cos", \((\(\[Pi]\/2\) n)\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", 
          "sin", \((\(\[Pi]\/2\) n)\)}]}]]],
  " is \n\n\t\t\t",
  Cell[BoxData[{\(y[n]\ \  = \ \ b\_0\ x[n] + b\_1\ x[n - 1] + 
          b\_2\ x[n - 2] + b\_3\ x[n - 3]\), "\[IndentingNewLine]", 
      StyleBox["or",
        FontFamily->"Times New Roman"], 
    "\[IndentingNewLine]", \(y[n]\ \  = \ \ x[n] + \ x[n - 1] + \ 
          x[n - 2] + \ x[n - 3]\)}]],
  " "
}], "Text"],

Cell[TextData[{
  "If we multiply terms on the right hand side by ",
  Cell[BoxData[
      \(1\/4\)]],
  ", then we get the moving average filter  \n\n\t\t\t",
  Cell[BoxData[
      \(y[
          n]\ \  = \ \ \(1\/4\) \((x[n] + \ x[n - 1] + \ x[n - 2] + \ 
              x[n - 3])\)\)]],
  " \n\nand this filter will still zero out the same frequencies.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 9.9.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "Amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  ", and zero-pole plot for  ",
  Cell[BoxData[
      \(y[n] = \(1\/4\) \(\[Sum]\+\(k = 0\)\%3 x[n - k]\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Background for the z-transform and its application for solving difference \
equations can be found in the book.\n\n",
  StyleBox[ButtonBox["Complex Analysis for Mathematics and Engineering",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.23.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["9.23 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The filter  ",
  Cell[BoxData[
      \(y[n]\  = \ x[n] + \ x[n - 2]\)]],
  "  is designed to zero out  ",
  Cell[BoxData[
      RowBox[{"cos", \((\(\[Pi]\/2\) n)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "sin", \((\(\[Pi]\/2\) n)\)}]]],
  ".  Use the conjugate pair of zeros  ",
  Cell[BoxData[
      RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        "  ", \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/2\)\)}]]],
  "  and calculate "
}], "Text"],

Cell[BoxData[{
    \(\(H[
          z_] = \((\(z - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\)\)\/z)\) \
\((\(z - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/2\)\)\/z)\);\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<H[z] = (\!\(\(z - \
\[ExponentialE]\^\(\[ImaginaryI]\[Pi]/2\)\)\/z\))(\!\(\(z - \[ExponentialE]\^\
\(\(-\[ImaginaryI]\[Pi]\)/2\)\)\/z\))\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", H[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(H[z_] = ComplexExpand[H[z]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", H[z]\ ];\)\)}], "Input"],

Cell[TextData[{
  "There are no poles, so the transfer function has the form  ",
  Cell[BoxData[
      \(H \((z)\)\  = \ \(b\_0 + \(b\_1\) z\^\(-1\) + \(b\_2\) z\^\(-2\)\)\/1\
\)]],
  " and we see that  ",
  Cell[BoxData[
      RowBox[{\(b\_0 = 1\), ",", 
        RowBox[{\(b\_1\), "=", 
          RowBox[{
            RowBox[{"0", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(b\_2\)}], "=", "1"}]}]}]]],
  ".  The desired filter is  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[k, n, x, y];\)\), "\[IndentingNewLine]", 
    \(\(filter = 
        y[n] \[Equal] 
          ReplaceAll[
            H[z], {1 \[Rule] x[n], 
              Power[z, k_] \[Rule] x[n + k]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<For the transfer function\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", H[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The filter is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(H[z_] = 1 + z\^\(-2\);\)\ \ \), "\n", 
    \(\(A[\[Theta]_] = 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]];\)\), "\
\[IndentingNewLine]", 
    \(\(Plot[A[\[Theta]], {\[Theta], 0, \[Pi]}, 
        PlotRange \[Rule] {{0, \[Pi]}, {0, 2.1}}, 
        Ticks \[Rule] {Range[0, \[Pi], \[Pi]\/4], Range[0, 2, 1]}, 
        AxesLabel \[Rule] {"\<\[Theta]\>", "\<A(\[Theta])\>"}, 
        PlotStyle \[Rule] Red];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(\[Pi]\/2\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]  \[Pi]\/2\)\)]| = \>\"", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\/2\)]]\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<The amplitude response for the filter\>"];\)\), "\n", 
    \(\(Print["\<y[n] = x[n] + x[n-2]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Where the transfer function is\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", H[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<H[\!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)] = \>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]\ ];\)\ \)}], "Input"],

Cell[BoxData[
    \(\(ZeroPolePlot1;\)\)], "Input"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(filter\  = \ 
        y[n]\  \[Equal] \ x[n] + x[n - 2];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The FIR filter is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = Cos[\(n\ \[Pi]\)\/2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  x[n] = \>", x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-1] = \>", x[n - 1], "\< = \>", \ 
        TrigExpand[x[n - 1]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-2] = \>", x[n - 2], "\< = \>", \ 
        TrigExpand[x[n - 2]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute into the filter and get\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<y[n] \[Equal] x[n] + x[n-2]\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<  \>", \ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  y[n] == \>", x[n], "\< + (\>", 
        TrigExpand[x[n - 2]], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", \ Simplify[filter]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(filter\  = \ 
        y[n]\  \[Equal] \ x[n] + x[n - 2];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The FIR filter is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = Sin[\(n\ \[Pi]\)\/2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  x[n] = \>", x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-1] = \>", x[n - 1], "\< = \>", \ 
        TrigExpand[x[n - 1]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-2] = \>", x[n - 2], "\< = \>", \ 
        TrigExpand[x[n - 2]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute into the filter and get\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<y[n] \[Equal] x[n] + x[n-2]\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<  \>", \ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  y[n] == \>", x[n], "\< + (\>", 
        TrigExpand[x[n - 2]], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", \ Simplify[filter]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["9.23 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The moving average filter  ",
  Cell[BoxData[
      \(y[n]\  = \ \(1\/4\) \((x[n] + x[n - 1] + x[n - 2] + x[n - 3])\)\)]],
  "  is designed to zero out ",
  Cell[BoxData[
      RowBox[{\(cos \((n\ \[Pi])\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"cos", \((\(\[Pi]\/2\) n)\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", 
          "sin", \((\(\[Pi]\/2\) n)\)}]}]]],
  ". "
}], "Text"],

Cell[TextData[{
  "Use the conjugate pair of zeros  ",
  Cell[BoxData[
      RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        "  ", \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/2\)\)}]]],
  "  and the additional zero  ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\)\)]],
  "  and calculate "
}], "Text"],

Cell[BoxData[{
    \(\(H[
          z_] = \((\(z - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\)\)\/z)\) \
\((\(z - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/2\)\)\/z)\) \((\(z - \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]\)\)\/z)\);\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<H[z] = (\!\(\(z - \
\[ExponentialE]\^\(\[ImaginaryI]\[Pi]/2\)\)\/z\))(\!\(\(z - \[ExponentialE]\^\
\(\(-\[ImaginaryI]\[Pi]\)/2\)\)\/z\))(\!\(\(z - \[ExponentialE]\^\(-\
\[ImaginaryI]\[Pi]\)\)\/z\))\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", H[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(H[z_] = ComplexExpand[H[z]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", H[z]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The transfer function has the form  ",
  Cell[BoxData[
      \(H \((z)\)\  = \ \(b\_0 + \(b\_1\) z\^\(-1\) + \(b\_2\) z\^\(-2\) + \
\(b\_3\) z\^\(-3\)\)\/1\)]],
  " and we see that  ",
  Cell[BoxData[
      \(b\_0 = \(b\_1 = \(b\_2 = \(b\_3 = 1\)\)\)\)]],
  ".    The desired filter is  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[k, n, x, y];\)\), "\[IndentingNewLine]", 
    \(\(filter = 
        y[n] \[Equal] 
          ReplaceAll[
            H[z], {1 \[Rule] x[n], 
              Power[z, k_] \[Rule] x[n + k]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<For the transfer function\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", H[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The filter is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(filter\  = \ 
        y[n]\  \[Equal] \(1\/4\) \((x[n] + x[n - 1] + x[n - 2] + 
                x[n - 3])\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The FIR filter is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = Cos[n\ \[Pi]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  x[n] = \>", x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-1] = \>", x[n - 1], "\< = \>", \ 
        TrigExpand[x[n - 1]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-2] = \>", x[n - 2], "\< = \>", \ 
        TrigExpand[x[n - 2]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-3] = \>", x[n - 3], "\< = \>", \ 
        TrigExpand[x[n - 3]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute into the filter and get\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] \[Equal] \!\(1\/4\)(x[n] + x[n-1] + x[n-2] + \
x[n-3])\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] \[Equal] \!\(1\/4\)(\>\"", x[n], "\< + (\>", 
        TrigExpand[x[n - 1]], "\<) + (\>", TrigExpand[x[n - 2]], "\<) + (\>", 
        TrigExpand[x[n - 3]], "\<))\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ Simplify[filter]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(filter\  = \ 
        y[n]\  \[Equal] \(1\/4\) \((x[n] + x[n - 1] + x[n - 2] + 
                x[n - 3])\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The FIR filter is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = Cos[\(n\ \[Pi]\)\/2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  x[n] = \>", x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-1] = \>", x[n - 1], "\< = \>", \ 
        TrigExpand[x[n - 1]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-2] = \>", x[n - 2], "\< = \>", \ 
        TrigExpand[x[n - 2]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-3] = \>", x[n - 3], "\< = \>", \ 
        TrigExpand[x[n - 3]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute into the filter and get\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] \[Equal] \!\(1\/4\)(x[n] + x[n-1] + x[n-2] + \
x[n-3])\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] \[Equal] \!\(1\/4\)(\>\"", x[n], "\< + (\>", 
        TrigExpand[x[n - 1]], "\<) + (\>", TrigExpand[x[n - 2]], "\<) + (\>", 
        TrigExpand[x[n - 3]], "\<))\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ Simplify[filter]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(filter\  = \ 
        y[n]\  \[Equal] \ \(1\/4\) \((x[n] + x[n - 1] + x[n - 2] + 
                x[n - 3])\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The FIR filter is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = Sin[\(n\ \[Pi]\)\/2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  x[n] = \>", x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-1] = \>", x[n - 1], "\< = \>", \ 
        TrigExpand[x[n - 1]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-2] = \>", x[n - 2], "\< = \>", \ 
        TrigExpand[x[n - 2]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-3] = \>", x[n - 3], "\< = \>", \ 
        TrigExpand[x[n - 3]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute into the filter and get\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] \[Equal] \!\(1\/4\)(x[n] + x[n-1] + x[n-2] + \
x[n-3])\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] \[Equal] \!\(1\/4\)(\>\"", x[n], "\< + (\>", 
        TrigExpand[x[n - 1]], "\<) + (\>", TrigExpand[x[n - 2]], "\<) + (\>", 
        TrigExpand[x[n - 3]], "\<))\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ Simplify[filter]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Remark 9.15.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The function ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  " can be proven to be even, i.e.  ",
  Cell[BoxData[
      \(A \((\(-\[Theta]\))\) = A \((\[Theta])\)\)]],
  " which reinforces the fact that the zeros come in conjugate pairs.  Also, \
when expanded over a common denominator, the transfer function ",
  Cell[BoxData[
      \(H \((z)\) = \(1 + z + z\^2 + z\^3\)\/\(4\ z\^3\)\)]],
  " actually has a triple pole at the origin.  Finally it can be shown that \
the zeros are all equally spaced on the unit circle and that the arguments of \
the zeros correspond to frequencies that are zeroed out by the filter. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(H[
          z_] = \(1\/4\) \((1 + z\^\(-1\) + z\^\(-2\) + 
              z\^\(-3\))\);\)\ \ \), "\n", 
    \(\(A[\[Theta]_] = 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]];\)\), "\
\[IndentingNewLine]", 
    \(\(Plot[A[\[Theta]], {\[Theta], 0, \[Pi]}, 
        PlotRange \[Rule] {{0, \[Pi]}, {0, 1}}, 
        Ticks \[Rule] {Range[0, \[Pi], \[Pi]\/4], Range[0, 1, 0.25]}, 
        AxesLabel \[Rule] {"\<\[Theta]\>", "\<A(\[Theta])\>"}, 
        PlotStyle \[Rule] Red];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(\[Pi]\/2\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]  \[Pi]\/2\)\)]| = \>\"", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\/2\)]]\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< A[\[Pi]] = \
|H[\!\(\[ExponentialE]\^\[ImaginaryI]\[Pi]\)]| = \>\"", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\)]]\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<The amplitude response for the filter\>"];\)\), "\n", 
    \(\(Print[\*"\"\<y[n] = \!\(1\/4\)(x[n]+x[n-1]+x[n-2]+x[n-3])\>\""];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<Where the transfer function is\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", H[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<H[\!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)] = \>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]\ ];\)\ \)}], "Input"],

Cell[BoxData[
    \(\(ZeroPolePlot1;\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.24.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The moving average filter   ",
  Cell[BoxData[
      \(y[
          n]\ \  = \ \ \(1\/8\) \((x[n] + x[n - 1] + \ x[n - 2] + x[n - 3] + 
              x[n - 4] + x[n - 5] + x[n - 6] + x[n - 7])\)\)]],
  "  \nis designed to zero out  ",
  Cell[BoxData[
      RowBox[{\(cos \((n\ \[Pi])\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(cos \((\(\(3  \[Pi]\)\/4\) n)\)\), " ", 
        
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(sin \((\(\(3  \[Pi]\)\/4\) n)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(cos \((\(\[Pi]\/2\) n)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(sin \((\(\[Pi]\/2\) n)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"cos", \((\(\[Pi]\/4\) n)\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", 
          "sin", \((\(\[Pi]\/4\) n)\)}]}]]],
  ". "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009E0000]b000`400?l0
0000o`00003oo`3ooooo0?oooeL0oooo003o0?ooool0ooooE`3oool00?l0
ooooo`3ooomG0?ooo`00o`3ooooo0?oooeL0oooo003o0?ooool0ooooE`3o
ool00?l0ooooo`3ooomG0?ooo`00o`3ooooo0?oooeL0oooo003o0?ooool0
ooooE`3oool00?l0oooo=P3oool300000?l0oooo7P3oool00<L0oooo0`00
000b0?ooo`@00000=P3oool00`000000oooo0?ooo`3o0?oooad0oooo0038
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0=03oool5
00000?l0oooo7P3oool00<D0oooo1@00000c0?ooo`030000003oool0oooo
03<0oooo00@000000?ooo`3oool00000o`3ooolO0?ooo`00a@3oool01000
0000oooo0?ooo`00000e0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`000000o`3ooolO0?ooo`00aP3oool00`000000oooo0000000c0?oo
o`040000003oool0oooo000003D0oooo0P00003o0?oooal0oooo00370?oo
o`800000=03oool200000?l0ooooE`3oool00?l0oooo;@3oool<00000003
0?ooo`000000000000800000o`3ooolI0?ooo`00o`3ooooQ0?ooo`030000
003oool0oooo0780oooo00320?ooo`@0000000<0oooo0000000000000P00
000^0?ooo`@0000000<0oooo0000000000000P00003N0?ooo`030000003o
ool0oooo0780oooo003o0?ooofX0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1]0?ooo`<0003oM03oool00?l0oooo<03oool20000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0/0?oo
o`040000003oool0oooo000006l0oooo1@000?mc0?ooo`00o`3oool_0?oo
o`040000003oool0oooo000000D0oooo00@000000?ooo`3oool00000<03o
ool00`000000oooo0000001X0?ooo`L00?l01@000?l8003o06/0oooo0034
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0000000`0?ooo`030000003oool0
000006<0oooo1@00o`070?ooo`D0003o203oool5003o06H0oooo00350?oo
o`040000003oool0oooo000003<0oooo00@000000?ooo`3oool00000<@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0000002l0oooo1@00
001M0?ooo`D00?l03@3oool30000o`h0oooo1@00o`1Q0?ooo`00aP3oool0
0`000000oooo0000000d0?ooo`030000003oool0000002h0oooo00@00000
0?ooo`3oool000001@3oool5000008h0oooo0P00o`0D0?ooo`030000003o
ool0oooo00P0oooo0P0000070?ooo`<00?l0GP3oool00<H0oooo00<00000
0?ooo`000000=03oool00`000000oooo0000000_0?ooo`800000UP3oool3
003o01H0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`030000003o
ool0000000T0oooo0P00o`1L0?ooo`00a@3oool500000380oooo1@000034
0?ooo`800?l06@3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`0000002`3oool2003o05X0oooo003o
0?oool@0oooo0P00o`0K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool2000000h0oooo0P00o`1H0?ooo`00o`3ooome0?oo
o`<00000BP3oool2003o01d0oooo00<000000?ooo`3oool0103oool01@00
0000oooo0?ooo`3oool000000140oooo0P00o`1F0?ooo`00T03ooonU0000
00030?l000000000000003@0000000<0o`000?ooo`3oool0103oool01@00
0000oooo0?ooo`3oool0000004L0oooo0P00o`0O0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000`3oool200000140oooo0P00
o`1D0?ooo`00T03oool00`000000oooo0?ooo`0c0?ooo`80o`00=@3oool2
0?l003D0oooo0P3o000e0?ooo`030?l000000000oooo00D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`120?ooo`800?l08@3oool0
0`000000oooo0?ooo`020?ooo`D000005`3oool2003o0580oooo002@0?oo
o`030000003oool0oooo03<0oooo0P3o000e0?ooo`030?l000000000o`00
03<0oooo00@0o`000?ooo`000000o`00<`3oool00`3o0000oooo00000006
0?ooo`H00000@`3oool00`00o`00oooo0?ooo`0Q0?ooo`030000003oool0
oooo0200oooo00<00?l00?ooo`3oool0C`3oool00900oooo00<000000?oo
o`3oool0<`3oool20?l003@0oooo00@0o`000?ooo`3oool0o`00<P3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02l0oooo00<0o`00
0?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000480oooo00<0
0?l00?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`03003o003o
ool0oooo04h0oooo002@0?ooo`030000003oool0oooo0380oooo00@0o`00
0?ooo`3oool0o`00<P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo02h0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`0]0?ooo`030?l0003oool0oooo00X0oooo0`0000120?ooo`03003o003o
ool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`00o`00oooo0?oo
o`1=0?ooo`00T03oool00`000000oooo0?ooo`0b0?ooo`040?l0003oool0
oooo0?l00340oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`0]0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0:`3o
ool00`3o0000oooo0?ooo`1>0?ooo`800?l09P3oool00`000000oooo0?oo
o`0S0?ooo`800?l0C@3oool00900oooo00<000000?ooo`3oool0<@3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo02h0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`0/0?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`1>
0?ooo`03003o003oool0oooo02H0oooo00<000000?ooo`3oool09@3oool0
0`00o`00oooo0?ooo`1:0?ooo`00T03oool00`000000oooo0?ooo`0a0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0;@3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo02X0oooo00<0o`000?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0W0?ooo`030?l0003oool0oooo
04h0oooo00<00?l00?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?oo
o`800?l0BP3oool00900oooo00<000000?ooo`3oool0<@3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo02/0oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo00/0
oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`1>0?ooo`03
003o003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`00o`00
oooo0?ooo`170?ooo`00T03oool00`000000oooo0?ooo`0`0?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool0:`3oool00`3o0000oooo
0?ooo`090?ooo`030?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo04X0oooo
0`000?l2003o02/0oooo00<000000?ooo`3oool0:@3oool30000odH0oooo
002@0?ooo`030000003oool0oooo0300oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00/0oooo00<0
o`000?ooo`3oool0903oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo0200oooo0P3o001<0?ooo`D0003o;03oool00`000000oooo0?oo
o`0X0?ooo`D0003oA@3oool00900oooo00<000000?ooo`3oool0<03oool0
0`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo02P0oooo00<0o`00
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0
oooo0140oooo0P3o000N0?ooo`80o`00CP3oool50000ob`0oooo00<00000
0?ooo`3oool0:03oool50000odD0oooo002@0?ooo`030000003oool0oooo
02l0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0W0?oo
o`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool07`3oool20?l0
01H0oooo0P3o000K0?ooo`030?l0003oool0oooo04h0oooo1@000?l/0?oo
o`030000003oool0oooo02P0oooo1@000?m50?ooo`00T03oool00`000000
oooo0?ooo`0_0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool09P3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo01d0
oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0G0?ooo`03
0?l0003oool0oooo04l0oooo00@00?l00000o`000?l0003o;@3oool00`00
0000oooo0?ooo`0Y0?ooo`<0003o00<0oooo003o003oool0@`3oool00900
oooo00<000000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo02@0oooo00<0o`000?ooo`3oool04P3oool20?l001`0
oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`0D0?ooo`80
o`00DP3oool00`00o`00oooo0?ooo`090?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`030?ooo`03
003o003oool0oooo0480oooo002@0?ooo`030000003oool0oooo02h0oooo
00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0
003oool0oooo01D0oooo00<0o`000?ooo`3oool05`3oool20?l001h0oooo
00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`1A0?ooo`03003o
003oool0oooo0080oooo1@0000020?ooo`030000003oool0000002<0oooo
00<000000?ooo`3oool07`3oool5000000<0oooo00<000000?ooo`3oool0
103oool00`00o`00oooo0?ooo`110?ooo`00T03oool00`000000oooo0?oo
o`0^0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool08@3o
ool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo01D0oooo00<0
o`000?ooo`3oool07`3oool30?l000h0oooo0`3o001C0?ooo`03003o003o
ool0oooo00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`050?ooo`03003o003oool0oooo0400
oooo002@0?ooo`030000003oool0oooo02h0oooo00<0o`000?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo01P0oooo
00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0S0?ooo`@0o`00
1`3oool30?l005D0oooo00<00?l00?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`800000903oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00o`00oooo
0?ooo`0o0?ooo`00T03oool00`000000oooo0?ooo`0]0?ooo`030?l0003o
ool0oooo00`0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?oo
o`0J0?ooo`030?l0003oool0oooo0100oooo0P3o000Z0?ooo`L0o`00E`3o
ool00`00o`00oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000
9@3oool00`000000oooo0?ooo`0R0?ooo`070000003oool0oooo0?ooo`00
0000oooo000000080?ooo`03003o003oool0oooo03h0oooo002@0?ooo`03
0000003oool0oooo02d0oooo00<0o`000?ooo`3oool0303oool00`3o0000
oooo0?ooo`0N0?ooo`030?l0003oool0oooo01`0oooo0P3o000>0?ooo`80
o`00RP3oool00`00o`00oooo0?ooo`060?ooo`040000003oool0oooo0000
0080oooo0`00000S0?ooo`030000003oool0oooo0200oooo00@000000?oo
o`3oool000000P3oool3000000P0oooo00<00?l00?ooo`3oool0?P3oool0
0900oooo00<000000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0=0?oo
o`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool07`3oool40?l0
00L0oooo0`3o002;0?ooo`03003o003oool0oooo00L0oooo1@00000W0?oo
o`030000003oool0oooo0200oooo1@00000=0?ooo`03003o003oool0oooo
03d0oooo002@0?ooo`030000003oool0oooo02d0oooo00<0o`000?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo02@0
oooo1`3o002=0?ooo`03003o003oool0oooo03@0oooo00<000000?ooo`3o
ool0<`3oool00`00o`00oooo0?ooo`0l0?ooo`00T03oool00`000000oooo
0?ooo`0/0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0
6@3oool00`3o0000oooo0?ooo`2i0?ooo`03003o003oool0oooo03@0oooo
00<000000?ooo`3oool0<`3oool00`00o`00oooo0?ooo`0l0?ooo`00T03o
ool00`000000oooo0?ooo`0/0?ooo`030?l0003oool0oooo00l0oooo00<0
o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`2h0?ooo`03003o003o
ool0oooo03D0oooo00<000000?ooo`3oool0=03oool00`00o`00oooo0?oo
o`0k0?ooo`00T03oool00`000000oooo0?ooo`0/0?ooo`030?l0003oool0
oooo0100oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`2h
0?ooo`03003o003oool0oooo03H0oooo00<000000?ooo`3oool0=@3oool0
0`00o`00oooo0?ooo`0j0?ooo`00T03oool00`000000oooo0?ooo`0[0?oo
o`030?l0003oool0oooo0180oooo0P3o000F0?ooo`030?l0003oool0oooo
0;T0oooo00<00?l00?ooo`3oool0=P3oool00`000000oooo0?ooo`0f0?oo
o`03003o003oool0oooo03T0oooo001m0?ooo`800000103oool2000000<0
oooo100000040?ooo`030000003oool0oooo02/0oooo00<0o`000?ooo`3o
ool0503oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo0;T0
oooo00<00?l00?ooo`3oool0=`3oool00`000000oooo0?ooo`0f0?ooo`03
003o003oool0oooo03T0oooo001l0?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[0?ooo`03
0?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0403oool00`3o0000
oooo0?ooo`2j0?ooo`03003o003oool0oooo03L0oooo00<000000?ooo`3o
ool0=`3oool00`00o`00oooo0?ooo`0h0?ooo`00O03oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00@0oooo0P00000[0?ooo`03
0?l0003oool0oooo01L0oooo00<0o`000?ooo`3oool03P3oool00`3o0000
oooo0?ooo`2j0?ooo`03003o003oool0oooo03P0oooo00<000000?ooo`3o
ool0=`3oool00`00o`00oooo0?ooo`0h0?ooo`00O03oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0:P3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo00/0
oooo0P3o002m0?ooo`03003o003oool0oooo03P0oooo00<000000?ooo`3o
ool0=`3oool00`00o`00oooo0?ooo`0h0?ooo`00O03oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0:P3oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo
00P0oooo0P3o002n0?ooo`03003o003oool0oooo03T0oooo00<000000?oo
o`3oool0>03oool00`00o`00oooo0?ooo`0g0?ooo`00O@3oool2000000X0
oooo0P0000050?ooo`030000003oool0oooo02T0oooo00<0o`000?ooo`3o
ool06`3oool40?l00080oooo103o00300?ooo`03003o003oool0oooo03T0
oooo00<000000?ooo`3oool0>03oool00`00o`00oooo0?ooo`0g0?ooo`00
T03oool00`000000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo01h0oooo
103o00330?ooo`03003o003oool0oooo03T0oooo00<000000?ooo`3oool0
>@3oool00`00o`00oooo0?ooo`0f0?ooo`00T03oool00`000000oooo0?oo
o`0Y0?ooo`030?l0003oool0oooo0>@0oooo00<00?l00?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0i0?ooo`03003o003oool0oooo03H0oooo002@
0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool0i@3oool0
0`00o`00oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<00?l0
0?ooo`3oool0=@3oool00900oooo00<000000?ooo`3oool0:03oool00`3o
0000oooo0?ooo`3T0?ooo`03003o003oool0oooo03/0oooo00<000000?oo
o`3oool0>P3oool00`00o`00oooo0?ooo`0e0?ooo`00T03oool00`000000
oooo0?ooo`0X0?ooo`030?l0003oool0oooo0>@0oooo00<00?l00?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0j0?ooo`03003o003oool0oooo03D0
oooo002@0?ooo`030000003oool0oooo02L0oooo00<0o`000?ooo`3oool0
i@3oool00`00o`00oooo0?ooo`0k0?ooo`030000003oool0oooo03/0oooo
00<00?l00?ooo`3oool0=03oool00900oooo00<000000?ooo`3oool09`3o
ool00`3o0000oooo0?ooo`3T0?ooo`03003o003oool0oooo03`0oooo00<0
00000?ooo`3oool0>`3oool00`00o`00oooo0?ooo`0d0?ooo`00T03oool0
0`000000oooo0?ooo`0W0?ooo`030?l0003oool0oooo0>@0oooo00<00?l0
0?ooo`3oool0?03oool00`000000oooo0?ooo`0k0?ooo`03003o003oool0
oooo03@0oooo002@0?ooo`030000003oool0oooo02H0oooo00<0o`000?oo
o`3oool0i@3oool00`00o`00oooo0?ooo`0l0?ooo`030000003oool0oooo
03/0oooo00<00?l00?ooo`3oool0=03oool00900oooo00<000000?ooo`3o
ool09P3oool00`3o0000oooo0?ooo`3T0?ooo`03003o003oool0oooo03d0
oooo00<000000?ooo`3oool0>`3oool00`00o`00oooo0?ooo`0d0?ooo`00
T03oool00`000000oooo0?ooo`0V0?ooo`030?l0003oool0oooo0>@0oooo
00<00?l00?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`03003o
003oool0oooo03<0oooo002@0?ooo`030000003oool0oooo02H0oooo00<0
o`000?ooo`3oool0i03oool00`00o`00oooo0?ooo`0m0?ooo`030000003o
ool0oooo03`0oooo00<00?l00?ooo`3oool0<`3oool00900oooo00<00000
0?ooo`3oool09@3oool00`3o0000oooo0?ooo`3U0?ooo`03003o003oool0
oooo03d0oooo00<000000?ooo`3oool0?03oool00`00o`00oooo0?ooo`0c
0?ooo`00T03oool00`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo
0>D0oooo00<00?l00?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?oo
o`03003o003oool0oooo03<0oooo002@0?ooo`030000003oool0oooo02D0
oooo00<0o`000?ooo`3oool0i03oool00`00o`00oooo0?ooo`0n0?ooo`03
0000003oool0oooo03`0oooo00<00?l00?ooo`3oool0<`3oool00900oooo
00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`3U0?ooo`03003o
003oool0oooo03h0oooo00<000000?ooo`3oool0?@3oool00`00o`00oooo
0?ooo`0b0?ooo`00T03oool00`000000oooo0?ooo`0T0?ooo`030?l0003o
ool0oooo0>D0oooo00<00?l00?ooo`3oool0?P3oool00`000000oooo0?oo
o`0m0?ooo`03003o003oool0oooo0380oooo002@0?ooo`030000003oool0
oooo02@0oooo00<0o`000?ooo`3oool0i@3oool00`00o`00oooo0?ooo`0n
0?ooo`030000003oool0oooo03d0oooo00<00?l00?ooo`3oool0<P3oool0
0900oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`3V0?oo
o`03003o003oool0oooo03h0oooo00<000000?ooo`3oool0?@3oool00`00
o`00oooo0?ooo`0b0?ooo`00T03oool00`000000oooo0?ooo`0S0?ooo`03
0?l0003oool0oooo0>H0oooo00<00?l00?ooo`3oool0?P3oool00`000000
oooo0?ooo`0m0?ooo`03003o003oool0oooo0380oooo002@0?ooo`030000
003oool0oooo02<0oooo00<0o`000?ooo`3oool0iP3oool00`00o`00oooo
0?ooo`0n0?ooo`030000003oool0oooo03d0oooo00<00?l00?ooo`3oool0
<P3oool007d0oooo0P0000040?ooo`8000001@3oool3000000<0oooo00<0
00000?ooo`3oool08P3oool00`3o0000oooo0?ooo`3W0?ooo`03003o003o
ool0oooo03h0oooo00<000000?ooo`3oool0?@3oool00`00o`00oooo0?oo
o`0I0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3o
ool007`0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3oool0i`3o
ool00`00o`00oooo0?ooo`0n0?ooo`030000003oool0oooo03d0oooo00<0
0?l00?ooo`3oool0603oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00`0oooo001l0?ooo`040000003oool0oooo000000P0oooo1@00
00030?ooo`8000008`3oool00`3o0000oooo0?ooo`3U0?ooo`<0003o?P3o
ool30?l003l0oooo00<00?l00?ooo`3oool02@3oool300000080oooo00<0
00000?ooo`3oool00`0000030?ooo`030000003oool0oooo0080oooo1000
00040?ooo`030000003oool0oooo00/0oooo001l0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0Q0?ooo`030?l0003oool0oooo0>D0oooo1@000?ll000000D0o`00
?P0000000`00o`00000000000005000000D0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0;0?ooo`00
O03oool010000000oooo0?ooo`0000090?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`3U0?ooo`D0
003o?03oool50?l003h0oooo00<00?l00?ooo`3oool02P3oool3000000<0
oooo100000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00001@3oool00`000000oooo0?ooo`0;0?ooo`00O@3oool2000000/0oooo
0P0000040?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3oool0
i@3oool50000oc`0oooo1@3o000n0?ooo`03003o003oool0oooo00X0oooo
00@000000?ooo`3oool000000`3oool2000000@0oooo00<000000?ooo`3o
ool00P3oool4000000@0oooo00<000000?ooo`3oool02`3oool00900oooo
00<000000?ooo`3oool0803oool00`3o0000oooo0?ooo`3W0?ooo`<0003o
?P3oool30?l00080oooo0`00000j0?ooo`03003o003oool0oooo00X0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00`0oooo002@0?ooo`030000003oool0oooo0200oooo
00<0o`000?ooo`3oool0j@3oool00`00o`00oooo0?ooo`090?ooo`<00000
<P3oool01@000000oooo0?ooo`3oool0000000D0oooo1@00000a0?ooo`03
003o003oool0oooo00T0oooo1000000<0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool03@3oool00900oooo00<000000?ooo`3oool0
803oool00`3o0000oooo0?ooo`3Y0?ooo`04003o003oool0oooo0?ooo`D0
0000103oool00`000000oooo0?ooo`0a0?ooo`060000003oool0oooo0?oo
o`000000oooo0P0000040?ooo`030000003oool0oooo0340oooo00<00?l0
0?ooo`3oool0<P3oool00900oooo00<000000?ooo`3oool07`3oool00`3o
0000oooo0?ooo`3Z0?ooo`03003o003oool0oooo0080oooo00@000000?oo
o`3oool000000P3oool400000380oooo00@000000?ooo`3oool0oooo0P00
00020?ooo`050000003oool0oooo0?ooo`000000<`3oool00`00o`00oooo
0?ooo`0b0?ooo`00T03oool00`000000oooo0?ooo`0O0?ooo`030?l0003o
ool0oooo0>X0oooo00<00?l00?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000003<0oooo00D000000?ooo`3oool0oooo
000000040?ooo`040000003oool0oooo000003<0oooo00<00?l00?ooo`3o
ool0<P3oool00900oooo00<000000?ooo`3oool07`3oool00`3o0000oooo
0?ooo`3Z0?ooo`03003o003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool2000003<0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0<@3oool00`00o`00
oooo0?ooo`0b0?ooo`00T03oool00`000000oooo0?ooo`0O0?ooo`030?l0
003oool0oooo0>X0oooo00<00?l00?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool00P3oool200000080oooo00@000000?ooo`0000000000<`3oool00`00
o`00oooo0?ooo`0b0?ooo`00T03oool00`000000oooo0?ooo`0N0?ooo`03
0?l0003oool0oooo0>/0oooo00<00?l00?ooo`3oool00P3oool5000003L0
oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000000000g0?oo
o`03003o003oool0oooo0380oooo002@0?ooo`030000003oool0oooo01h0
oooo00<0o`000?ooo`3oool0j`3oool00`00o`00oooo0?ooo`0n0?ooo`03
0000003oool0oooo03`0oooo00<00?l00?ooo`3oool0<`3oool00900oooo
00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`3/0?ooo`03003o
003oool0oooo03d0oooo00<000000?ooo`3oool0?03oool00`00o`00oooo
0?ooo`0c0?ooo`00T03oool00`000000oooo0?ooo`0M0?ooo`030?l0003o
ool0oooo0>d0oooo00<00?l00?ooo`3oool0?@3oool00`000000oooo0?oo
o`0l0?ooo`03003o003oool0oooo03<0oooo002@0?ooo`030000003oool0
oooo01d0oooo00<0o`000?ooo`3oool0k@3oool00`00o`00oooo0?ooo`0m
0?ooo`030000003oool0oooo03`0oooo00<00?l00?ooo`3oool0<`3oool0
0900oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`3]0?oo
o`03003o003oool0oooo03d0oooo00<000000?ooo`3oool0?03oool00`00
o`00oooo0?ooo`0c0?ooo`00T03oool00`000000oooo0?ooo`0L0?ooo`03
0?l0003oool0oooo0>l0oooo00<00?l00?ooo`3oool0?03oool00`000000
oooo0?ooo`0k0?ooo`03003o003oool0oooo03@0oooo002@0?ooo`030000
003oool0oooo01`0oooo00<0o`000?ooo`3oool0k`3oool00`00o`00oooo
0?ooo`0l0?ooo`030000003oool0oooo03/0oooo00<00?l00?ooo`3oool0
=03oool00900oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?oo
o`3_0?ooo`03003o003oool0oooo03`0oooo00<000000?ooo`3oool0>`3o
ool00`00o`00oooo0?ooo`0d0?ooo`00T03oool00`000000oooo0?ooo`0L
0?ooo`030?l0003oool0oooo0?00oooo00<00?l00?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0k0?ooo`03003o003oool0oooo03@0oooo002@0?oo
o`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool0l@3oool00`00
o`00oooo0?ooo`0k0?ooo`030000003oool0oooo03/0oooo00<00?l00?oo
o`3oool0=03oool00900oooo00<000000?ooo`3oool06`3oool00`3o0000
oooo0?ooo`3a0?ooo`03003o003oool0oooo03/0oooo00<000000?ooo`3o
ool0>P3oool00`00o`00oooo0?ooo`0e0?ooo`00T03oool00`000000oooo
0?ooo`0K0?ooo`030?l0003oool0oooo0?40oooo00<00?l00?ooo`3oool0
>`3oool00`000000oooo0?ooo`0j0?ooo`03003o003oool0oooo03D0oooo
002@0?ooo`030000003oool0oooo01X0oooo00<0o`000?ooo`3oool0l`3o
ool00`00o`00oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<0
0?l00?ooo`3oool0=@3oool007d0oooo0P0000040?ooo`8000000`3oool3
000000D0oooo00<000000?ooo`3oool06P3oool00`3o0000oooo0?ooo`3c
0?ooo`03003o003oool0oooo03X0oooo00<000000?ooo`3oool0>@3oool0
0`00o`00oooo0?ooo`0f0?ooo`00O03oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06P3o
ool00`3o0000oooo0?ooo`3d0?ooo`03003o003oool0oooo03T0oooo00<0
00000?ooo`3oool0>@3oool00`00o`00oooo0?ooo`0f0?ooo`00O03oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo
0P00000J0?ooo`030?l0003oool0oooo0?D0oooo00<00?l00?ooo`3oool0
>@3oool00`000000oooo0?ooo`0h0?ooo`03003o003oool0oooo03L0oooo
001l0?ooo`040000003oool0oooo000000P0oooo0`0000050?ooo`030000
003oool0oooo01T0oooo00<0o`000?ooo`3oool0m@3oool00`00o`00oooo
0?ooo`0i0?ooo`030000003oool0oooo03P0oooo00<00?l00?ooo`3oool0
=`3oool007`0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0
mP3oool00`00o`00oooo0?ooo`0h0?ooo`030000003oool0oooo03L0oooo
00<00?l00?ooo`3oool0>03oool007d0oooo0P00000:0?ooo`<00000103o
ool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo0?H0oooo00<0
0?l00?ooo`3oool0>03oool00`000000oooo0?ooo`0g0?ooo`03003o003o
ool0oooo03P0oooo002@0?ooo`030000003oool0oooo01P0oooo00<0o`00
0?ooo`3oool0n03oool00`00o`00oooo0?ooo`0g0?ooo`030000003oool0
oooo03H0oooo00<00?l00?ooo`3oool0>@3oool00900oooo00<000000?oo
o`3oool0603oool00`3o0000oooo0?ooo`3i0?ooo`03003o003oool0oooo
03H0oooo00<000000?ooo`3oool0=P3oool00`00o`00oooo0?ooo`0i0?oo
o`00T03oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo0?T0
oooo00<00?l00?ooo`3oool0=P3oool00`000000oooo0?ooo`0e0?ooo`03
003o003oool0oooo03X0oooo002@0?ooo`030000003oool0oooo01L0oooo
00<0o`000?ooo`3oool0n`3oool00`00o`00oooo0?ooo`0e0?ooo`030000
003oool0oooo03D0oooo00<00?l00?ooo`3oool0>P3oool00900oooo00<0
00000?ooo`3oool05`3oool00`3o0000oooo0?ooo`3k0?ooo`03003o003o
ool0oooo03D0oooo00<000000?ooo`3oool0=03oool00`00o`00oooo0?oo
o`0k0?ooo`00T03oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0
oooo0?`0oooo00<00?l00?ooo`3oool0=03oool00`000000oooo0?ooo`0c
0?ooo`03003o003oool0oooo03`0oooo002@0?ooo`030000003oool0oooo
01H0oooo00<0o`000?ooo`3oool0o@3oool00`00o`00oooo0?ooo`0>0?oo
o`800000903oool00`000000oooo0?ooo`0U0?ooo`D000002@3oool00`00
o`00oooo0?ooo`0l0?ooo`00T03oool00`000000oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo0?h0oooo00<00?l00?ooo`3oool03`3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0203oool00`00o`00oooo0?ooo`0m0?ooo`00T03oool00`000000oooo
0?ooo`0E0?ooo`030?l0003oool0oooo0?l0oooo0@3oool00`00o`00oooo
0?ooo`050?ooo`D000000`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo01l0oooo1@0000030?ooo`030000003oool0oooo00L0oooo
00<00?l00?ooo`3oool0?P3oool00900oooo00<000000?ooo`3oool05@3o
ool00`3o0000oooo0?ooo`3o0?ooo`40oooo00<00?l00?ooo`3oool01P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0803oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00L0oooo00<00?l00?ooo`3oool0?P3oool00900oooo
00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`3o0?ooo`80oooo
00<00?l00?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000002<0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool0
?`3oool00900oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?oo
o`3o0?ooo`@0oooo00<00?l00?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08P3o
ool010000000oooo0?ooo`3oool2000000L0oooo00<00?l00?ooo`3oool0
@03oool00900oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?oo
o`3o0?ooo`D0oooo00<00?l00?ooo`3oool00`3oool010000000oooo0?oo
o`00000X0?ooo`030000003oool0oooo0200oooo00@000000?ooo`3oool0
00002P3oool00`00o`00oooo0?ooo`110?ooo`00T03oool00`000000oooo
0?ooo`0D0?ooo`030?l0003oool0oooo0?l0oooo1P3oool00`00o`00oooo
0?ooo`020?ooo`D000009`3oool00`000000oooo0?ooo`0P0?ooo`D00000
203oool00`00o`00oooo0?ooo`120?ooo`00T03oool00`000000oooo0?oo
o`0C0?ooo`030?l0003oool0oooo0?l0oooo203oool30000obd0oooo00<0
00000?ooo`3oool0:@3oool30000o`030?ooo`00o`00oooo04<0oooo002@
0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool0o`3oool7
0?ooo`D0003o;03oool00`000000oooo0?ooo`0X0?ooo`D0003oA@3oool0
0900oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?ooo`3o0?oo
o`L0oooo1@000?l/0?ooo`030000003oool0oooo02P0oooo1@000?m50?oo
o`00T03oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo0?l0
oooo203oool50000ob`0oooo00<000000?ooo`3oool0:03oool50000odD0
oooo002@0?ooo`030000003oool0oooo0180oooo00<0o`000?ooo`3oool0
o`3oool90?ooo`<0003o0P00o`0[0?ooo`030000003oool0oooo02T0oooo
0`000?m60?ooo`00T03oool00`000000oooo0?ooo`0B0?ooo`030?l0003o
ool0oooo0?l0oooo3P3oool00`00o`00oooo0?ooo`0X0?ooo`030000003o
ool0oooo02P0oooo00<00?l00?ooo`3oool0A`3oool00900oooo00<00000
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`3o0?oooa00oooo00<00?l0
0?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?ooo`800?l0BP3oool0
07d0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?oo
o`3oool04@3oool00`3o0000oooo0?ooo`3o0?oooa40oooo00<00?l00?oo
o`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`03003o003oool0oooo
04X0oooo001l0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0
oooo0?l0oooo4`3oool2003o02H0oooo00<000000?ooo`3oool08`3oool2
003o04d0oooo001l0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool00000103oool200000140oooo00<0o`000?ooo`3oool0o`3o
oolE0?ooo`03003o003oool0oooo02<0oooo00<000000?ooo`3oool08P3o
ool00`00o`00oooo0?ooo`1=0?ooo`00O03oool010000000oooo0?ooo`00
00090?ooo`8000001@3oool00`000000oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo0?l0oooo5P3oool00`00o`00oooo0?ooo`0R0?ooo`030000003o
ool0oooo0240oooo00<00?l00?ooo`3oool0CP3oool007`0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00l0oooo00<0o`000?ooo`3oool0o`3ooolH0?ooo`03003o
003oool0oooo0240oooo00<000000?ooo`3oool0203oool3000001D0oooo
00<00?l00?ooo`3oool0C`3oool007d0oooo0P00000:0?ooo`8000001@3o
ool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0?l0oooo6@3o
ool2003o0240oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0C0?ooo`800?l0DP3oool00900oooo00<000000?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`3o0?oooa/0oooo0P00o`0O0?ooo`040000003oool0
oooo0?ooo`D000000`3oool00`000000oooo0?ooo`0@0?ooo`800?l0E03o
ool00900oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`3o
0?oooah0oooo0P00o`0M0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0>0?ooo`800?l0EP3o
ool00900oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`3o
0?ooob00oooo0P00o`0K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0000000=0?ooo`800?l0F03oool0
0900oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`3o0?oo
ob<0oooo0P00o`0I0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`800?l0FP3oool00900
oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`3o0?ooobD0
oooo0`00o`0F0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000003@3oool3003o05`0oooo002@0?ooo`030000003oool0oooo00`0
oooo00<0o`000?ooo`3oool0o`3ooolY0?ooo`<00?l04`3oool00`000000
oooo0?ooo`020?ooo`D000002@3oool3003o05l0oooo002@0?ooo`030000
003oool0oooo00`0oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`@00?l0
3@3oool30000o`l0oooo0`00o`1R0?ooo`00T03oool00`000000oooo0?oo
o`0;0?ooo`030?l0003oool0oooo0?l0oooo<@3oool4003o00P0oooo1@00
0?l90?ooo`D00?l0I@3oool00900oooo00<000000?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`3o0?ooocD0oooo2000o`050000o`T00?l0JP3oool0
0900oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`3o0?oo
och0oooo1@000?mc0?ooo`00T03oool00`000000oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo0?l0oooo?`3oool30000og@0oooo002@0?ooo`030000
003oool0oooo00T0oooo00<0o`000?ooo`3oool0o`3ooom20?ooo`030000
003oool0oooo0780oooo002@0?ooo`030000003oool0oooo00T0oooo00<0
o`000?ooo`3oool0o`3ooom20?ooo`030000003oool0oooo0780oooo002@
0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0o`3ooom3
0?ooo`030000003oool0oooo0780oooo002@0?ooo`030000003oool0oooo
00P0oooo00<0o`000?ooo`3oool0o`3ooom30?ooo`030000003oool0oooo
0780oooo002@0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3o
ool0o`3ooom40?ooo`030000003oool0oooo0780oooo002@0?ooo`030000
003oool0oooo00L0oooo00<0o`000?ooo`3oool0o`3oooni0?ooo`00T03o
ool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo0?l0oooo^P3o
ool00900oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`3o
0?oookX0oooo002@0?ooo`030000003oool0oooo00@0oooo0P3o003o0?oo
okd0oooo002@0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0o`3ooonm0?ooo`00R03oool5000000<0oooo00<000000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`3o0?ooodX0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1X0?ooo`00RP3oool00`000000oooo0?oo
o`030?ooo`050000003oool0oooo0?ooo`3o0000o`3ooom<0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0I`3oool008X0oooo00<0
00000?ooo`3oool00`3oool40?l00?l0oooo@03oool3000000070?ooo`00
000000000?ooo`000000oooo000000020?ooo`030000003oool0oooo0080
oooo100000040?ooo`030000003oool0oooo06H0oooo002:0?ooo`030000
003oool0oooo0?l0ooooB03oool02@000000oooo0?ooo`3oool000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`1V0?ooo`00RP3oool00`00
0000oooo0?ooo`3o0?ooodP0oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000D0oooo00<000000?ooo`3oool0IP3oool008T0oooo0P00
003o0?ooodX0oooo00<000000?ooo`3oool00`0000000`3oool000000?oo
o`020?ooo`030000003oool0oooo0080oooo100000040?ooo`030000003o
ool0oooo06H0oooo003o0?ooomD0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo06L0oooo003o0?oo
om@0oooo0`00000;0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0J03oool00?l0ooooo`3ooomG0?ooo`00o`3ooooo0?oooeL0oooo
003o0?ooool0ooooE`3oool008h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`3o0?oook`0oooo002=0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0o`3ooonk0?ooo`00Q@3oool200000003
0?ooo`00000000000080oooo00<000000?ooo`3oool00P3oool3000000D0
oooo00<000000?ooo`3oool0o`3ooonj0?ooo`00Q@3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonj0?oo
o`00QP3oool3000000<0oooo00D000000?ooo`3oool0oooo000000040?oo
o`050000003oool0oooo0?ooo`000000o`3ooonl0?ooo`00QP3oool00`00
0000oooo000000030?ooo`040000003oool0oooo0?ooo`H000000`3oool0
0`000000oooo0?ooo`3o0?oookX0oooo00270?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0
oooo00000?l0oooo_@3oool008H0oooo0P0000060?ooo`040000003oool0
oooo0?ooo`<000000P3oool00`000000oooo0?ooo`3o0?oook`0oooo003o
0?ooool0ooooE`3oool00?l0ooooo`3ooomG0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{597, 183},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Figure 9.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "Amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  ", and zero-pole plot for  ",
  Cell[BoxData[
      \(y[n] = \(1\/8\) \(\[Sum]\+\(k = 0\)\%7 x[n - k]\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tWe use the property (i) zeroing out filter. Recall that the solutions to \
 ",
  Cell[BoxData[
      \(z\^8 = 1\)]],
  " are the eighth roots of unity  ",
  Cell[BoxData[
      \(z = \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/4\)\)]],
  " for  ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "3", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "4", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "5", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "6", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "7"}]]],
  " and lie on the unit circle.  Hence the roots of \n\n\t\t\t",
  Cell[BoxData[
      \(\(1\/8\) \(z\^8 - 1\)\/\(z - 1\)\ \  = \ \ \(\(1\/8\) \((z\^7 + 
                z\^6 + z\^5 + z\^4 + z\^3 + z\^2 + z + 
                1)\)\ \  = \ \ 0\)\)]],
  "\n\nare ",
  Cell[BoxData[
      \(z = \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\), \[ExponentialE]\^\(\
\[ImaginaryI]\ 3  \[Pi]/4\), \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 3  \
\[Pi]/4\), \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\), \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \ \[Pi]/2\), \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Pi]/4\), \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \ \[Pi]/4\)\)]],
  ".  There are no poles, so the transfer function has the form \n\n\t\t\t",
  Cell[BoxData[
      \(H \((z)\)\  = \ \(1\/8\) \((\(z - \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Pi]\)\)\/z)\) \((\(z - \[ExponentialE]\^\(\[ImaginaryI]\ 3  \[Pi]/4\)\)\/z)\
\) \((\(z - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 3  \[Pi]/4\)\)\/z)\) \
\((\(z - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\)\)\/z)\) \((\(z - \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \ \[Pi]/2\)\)\/z)\) \((\(z - \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\)\/z)\) \((\(z - \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \ \[Pi]/4\)\)\/z)\)\)]],
  " \n\t\t\n\t\t\t",
  Cell[BoxData[
      \(H \((z)\)\  = \ \(1\/8\) \(1\/z\^7\) \((z\^7 + z\^6 + z\^5 + z\^4 + 
              z\^3 + z\^2 + z + 1)\)\)]],
  "\n\n\t\t\t",
  Cell[BoxData[
      \(H \((z)\)\  = \ \(1\/8\) \((\ 
            1 + z\^\(-1\) + z\^\(-2\) + z\^\(-3\) + z\^\(-4\) + z\^\(-5\) + 
              z\^\(-6\) + z\^\(-7\))\)\)]],
  "\n\t\t\nUse  ",
  Cell[BoxData[
      \(b\_i = 1\/8\)]],
  " for ",
  Cell[BoxData[
      \(i = 0,  ... , 7\)]],
  " to get the desired recursive formula  \n\n\t\t\t",
  Cell[BoxData[
      \(y[
          n]\  = \ \(\(1\/8\) \((x[n] + x[n - 1] + \ x[n - 2] + x[n - 3] + 
              x[n - 4] + x[n - 5] + x[n - 6] + x[n - 7])\)\(\ \)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 9.16.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  This is an extension of the filter in Example 9.23, and zeros out twice \
as many frequencies.  The function ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  " has additional zeros located at  ",
  Cell[BoxData[
      RowBox[{\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \ \[Pi]/4\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          
          "StrikeThrough"->
            False}], \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \ \[Pi]/2\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          "  ", \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 3  \[Pi]/
                  4\)\)}]}]]],
  ".  The transfer function can be written  \n\n",
  "\t\t\t\t",
  Cell[BoxData[
      \(H \((z)\)\ \  = \ \ \(1 + z + z\^2 + z\^3 + z\^4 + z\^5 + z\^6 + z\^7\
\)\/\(8  z\^7\)\)]],
  ".  ",
  "\n\t\t\t\n\tThe representation has a pole of order seven at the origin.  \
Also, as in the previous example the zeros are equally spaced points on the \
unit circle, and their arguments correspond to the frequencies that are \
zeroed out  by the filter.  The situation is illustrated in Figure 9.10."
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 9.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "Amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  ", and zero-pole plot for  ",
  Cell[BoxData[
      \(y[n] = \(1\/8\) \(\[Sum]\+\(k = 0\)\%7 x[n - k]\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Background for the z-transform and its application for solving difference \
equations can be found in the book.\n\n",
  StyleBox[ButtonBox["Complex Analysis for Mathematics and Engineering",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Use the conjugate pairs of zeros  ",
  Cell[BoxData[
      RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        "  ", \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\)\)}]]],
  ";  ",
  Cell[BoxData[
      RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        "  ", \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/2\)\)}]]],
  ";   ",
  Cell[BoxData[
      RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ 3  \[Pi]/4\)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        "  ", \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 3  \[Pi]/4\)\)}]]],
  "  and the additional zero  ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\)\)]],
  "  and calculate "
}], "Text"],

Cell[BoxData[{
    \(\(H[
          z_] = \((\(z - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\)\/z)\) \
\((\(z - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\)\)\/z)\) \((\(z - \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\)\)\/z)\) \((\(z - \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/2\)\)\/z)\) \((\(z - \
\[ExponentialE]\^\(\[ImaginaryI]\ 3  \[Pi]/4\)\)\/z)\) \((\(z - \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 3  \[Pi]/4\)\)\/z)\) \((\(z - \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]\)\)\/z)\);\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<H[z] = (\!\(\(z - \
\[ExponentialE]\^\(\[ImaginaryI]\[Pi]/4\)\)\/z\))(\!\(\(z - \[ExponentialE]\^\
\(\(-\[ImaginaryI]\[Pi]\)/4\)\)\/z\))(\!\(\(z - \[ExponentialE]\^\(\
\[ImaginaryI]\[Pi]/2\)\)\/z\))(\!\(\(z - \[ExponentialE]\^\(\(-\[ImaginaryI]\
\[Pi]\)/2\)\)\/z\))(\!\(\(z - \[ExponentialE]\^\(\[ImaginaryI]3\[Pi]/4\)\)\/z\
\))(\!\(\(z - \[ExponentialE]\^\(\(-\[ImaginaryI]3\[Pi]\)/4\)\)\/z\))(\!\(\(z \
- \[ExponentialE]\^\(-\[ImaginaryI]\[Pi]\)\)\/z\))\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", H[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(H[z_] = ComplexExpand[H[z]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", H[z]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The transfer function has the form  ",
  Cell[BoxData[
      \(H \((z)\)\  = \ \(b\_0 + \(b\_1\) z\^\(-1\) + \(b\_2\) z\^\(-2\) + \
\(b\_3\) z\^\(-3\) + \(b\_4\) z\^\(-4\) + \(b\_5\) z\^\(-5\) + \(b\_6\) \
z\^\(-6\) + \(b\_7\) z\^\(-7\)\)\/1\)]],
  " and we see that  ",
  Cell[BoxData[
      \(b\_0 = \(b\_1 = \(b\_2 = \(b\_3 = \(b\_4 = \(b\_5 = \(b\_6 = \(b\_7 = 
                      1\)\)\)\)\)\)\)\)]],
  ".    The desired filter is  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[k, n, x, y];\)\), "\[IndentingNewLine]", 
    \(\(filter = 
        y[n] \[Equal] 
          ReplaceAll[
            H[z], {1 \[Rule] x[n], 
              Power[z, k_] \[Rule] x[n + k]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<For the transfer function\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", H[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The filter is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\)}], "Input"],

Cell[TextData[{
  "To obtain the moving average filter use  ",
  Cell[BoxData[
      \(b\_i = 1\/8\)]],
  " for ",
  Cell[BoxData[
      \(i = 0,  ... , 7\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[k, n, x, y];\)\), "\[IndentingNewLine]", 
    \(\(filter = 
        y[n] \[Equal] 
          ReplaceAll[
            H[z], {1 \[Rule] x[n], 
              Power[z, k_] \[Rule] x[n + k]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<For the transfer function\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", \(1\/8\) H[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(filter\  = \ 
        y[n]\  \[Equal] \(1\/8\) \(\[Sum]\+\(k = 0\)\%7 x[
                n - k]\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The filter is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\)}], "Input"],

Cell[TextData[{
  "As a typical example, we substitute  ",
  Cell[BoxData[
      \(x[n] = Cos[\(\(3  \[Pi]\)\/4\) n]\)]],
  " into the filter."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(filter\  = \ 
        y[n]\  \[Equal] \(1\/8\) \(\[Sum]\+\(k = 0\)\%7 x[
                n - k]\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The FIR filter is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(x[n_] = Cos[\(\(3  \[Pi]\)\/4\) n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use the sequence\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  x[n] = \>", x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-1] = \>", x[n - 1], "\< = \>", \ 
        TrigExpand[x[n - 1]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-2] = \>", x[n - 2], "\< = \>", \ 
        TrigExpand[x[n - 2]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-3] = \>", x[n - 3], "\< = \>", \ 
        TrigExpand[x[n - 3]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-4] = \>", x[n - 4], "\< = \>", \ 
        TrigExpand[x[n - 4]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-5] = \>", x[n - 5], "\< = \>", \ 
        TrigExpand[x[n - 5]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-6] = \>", x[n - 6], "\< = \>", \ 
        TrigExpand[x[n - 6]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[n-7] = \>", x[n - 7], "\< = \>", \ 
        TrigExpand[x[n - 7]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute into the filter and get\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] \[Equal] \!\(1\/8\)\!\(\[Sum]\+\(k = 0\)\%7\)x[n-k]\
\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] \[Equal] \!\(1\/8\)(\>\"", x[n], "\< + (\>", 
        TrigExpand[x[n - 1]], "\<) + (\>", TrigExpand[x[n - 2]], "\<) + (\>", 
        TrigExpand[x[n - 3]], "\<) + (\>", TrigExpand[x[n - 4]], "\<) + (\>", 
        TrigExpand[x[n - 5]], "\<) + (\>", TrigExpand[x[n - 6]], "\<) + (\>", 
        TrigExpand[x[n - 7]], "\<))\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ Simplify[filter]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Remark 9.16.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " This is an extension of the filter in Example 9.23 (b), and zeros out \
twice as many frequencies.  The function ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  " has additional zeros located at  ",
  Cell[BoxData[
      \(\(-\(\[Pi]\/4\)\), \(-\(\[Pi]\/2\)\), \(-\(\(3  \[Pi]\)\/4\)\)\)]],
  ".  The transfer function can be written  \n\t\t",
  Cell[BoxData[
      \(H[
          z] = \(1 + z + z\^2 + z\^3 + z\^4 + z\^5 + z\^6 + z\^7\)\/\(8\ z\^7\
\)\)]],
  ".  \nThe representation and has a pole of order seven at the origin.  \
Also, as in the previous example the zeros are equally spaced points on the \
unit circle, and their arguments correspond to frequencies that are zeroed \
out by the filter. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(H[
          z_] = \(1\/8\) \((1 + z\^\(-1\) + z\^\(-2\) + z\^\(-3\) + 
              z\^\(-4\) + z\^\(-5\) + z\^\(-6\) + 
              z\^\(-7\))\);\)\ \ \), "\n", 
    \(\(A[\[Theta]_] = 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]];\)\), "\
\[IndentingNewLine]", 
    \(\(Plot[A[\[Theta]], {\[Theta], 0, \[Pi]}, 
        PlotRange \[Rule] {{0, \[Pi]}, {0, 1}}, 
        Ticks \[Rule] {Range[0, \[Pi], \[Pi]\/4], Range[0, 1, 0.25]}, 
        AxesLabel \[Rule] {"\<\[Theta]\>", "\<A(\[Theta])\>"}, 
        PlotStyle \[Rule] Red];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  A[\!\(\[Pi]\/4\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]  \[Pi]\/4\)\)]| = \>\"", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\/4\)]]\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  A[\!\(\[Pi]\/2\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]  \[Pi]\/2\)\)]| = \>\"", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\/2\)]]\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(\(3  \[Pi]\)\/4\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI] \( 3  \[Pi]\)\/4\)\)]| = \>\"", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \(3  \[Pi]\)\/4\)]]\ ];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  A[\[Pi]] = \
|H[\!\(\[ExponentialE]\^\[ImaginaryI]\[Pi]\)]| = \>\"", 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\)]]\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<The amplitude response for the filter\>"];\)\), "\n", 
    \(\(Print[\*"\"\<y[n] = \!\(1\/8\)\!\(\[Sum]\+\(k = 0\)\%7\)x[n-k]\>\""];\
\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Where the transfer function is\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<  H[z] = \>", H[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<H[\!\(\[ExponentialE]\^\[ImaginaryI]\[Theta]\)] = \>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]\ ];\)\ \)}], "Input"],

Cell[BoxData[
    \(\(ZeroPolePlot1;\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.25 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Design a filter with poles  ",
  Cell[BoxData[
      \(2\/3\)]],
  Cell[BoxData[
      RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        "  ", \(2\/3\), \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/
                4\)\)}]]],
  "  for boosting up signals near ",
  Cell[BoxData[
      \(cos \((\(\[Pi]\/4\) n)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\(\[Pi]\/4\) n)\)\)]],
  ".\n\n",
  StyleBox["9.25 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Include the additional pole at  ",
  Cell[BoxData[
      \(\(1\/2\) \[ExponentialE]\^\(\[ImaginaryI]\ 0\) = 1\/2\)]],
  " to the filter design in (a) so that it also boosts up low frequency \
signals."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009E0000]b000`400?l0
0000o`00003oo`3ooooo0?oooeL0oooo003o0?ooool0ooooE`3oool00?l0
ooooo`3ooomG0?ooo`00o`3ooooo0?oooeL0oooo003o0?ooool0ooooE`3o
ool00?l0ooooo`3ooomG0?ooo`00o`3ooooo0?oooeL0oooo003o0?ooool0
ooooE`3oool00?l0oooo=P3oool300000?l0oooo7P3oool00<L0oooo0`00
000b0?ooo`@00000=P3oool00`000000oooo0?ooo`3o0?oooad0oooo0038
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0=03oool5
00000?l0oooo7P3oool00<D0oooo1@00000c0?ooo`030000003oool0oooo
03<0oooo00@000000?ooo`3oool00000o`3ooolO0?ooo`00a@3oool01000
0000oooo0?ooo`00000e0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`000000o`3ooolO0?ooo`00aP3oool00`000000oooo0000000c0?oo
o`040000003oool0oooo000003D0oooo0P00003o0?oooal0oooo00370?oo
o`800000=03oool200000?l0ooooE`3oool00?l0oooo;@3oool<00000003
0?ooo`000000000000800000o`3ooolI0?ooo`00o`3ooooQ0?ooo`030000
003oool0oooo0780oooo00320?ooo`@0000000<0oooo0000000000000P00
000^0?ooo`@0000000<0oooo0000000000000P00003N0?ooo`030000003o
ool0oooo0780oooo003o0?ooofX0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0780oooo003o0?oo
oc00oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0;03oool010000000oooo0?ooo`00001b0?ooo`030000003oool0
oooo0780oooo003o0?ooobl0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000`0?ooo`030000003oool0000006P0oooo5000
o`1[0?ooo`00a03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000<03oool0
0`000000oooo0000001S0?ooo`D00?l02P3oool00`000000oooo0?ooo`07
0?ooo`D00?l0IP3oool00<D0oooo00@000000?ooo`3oool00000<`3oool0
10000000oooo0?ooo`00000a0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`000000;`3oool5000005d0oooo1@00o`0?0?ooo`030000003o
ool0oooo00`0oooo1@00o`1Q0?ooo`00aP3oool00`000000oooo0000000d
0?ooo`030000003oool0000002h0oooo00@000000?ooo`3oool000001@3o
ool5000008h0oooo0P00o`0D0?ooo`030000003oool0oooo0140oooo0`00
o`1N0?ooo`00aP3oool00`000000oooo0000000d0?ooo`030000003oool0
000002l0oooo0P00002F0?ooo`<00?l05P3oool00`000000oooo0?ooo`0D
0?ooo`800?l0G03oool00<D0oooo1@00000b0?ooo`D00000a03oool2003o
01T0oooo00<000000?ooo`3oool05P3oool2003o05X0oooo003o0?oool@0
oooo0P00o`0K0?ooo`030000003oool0oooo01P0oooo0P00o`1H0?ooo`00
o`3ooome0?ooo`<00000BP3oool2003o01d0oooo00<000000?ooo`3oool0
6P3oool2003o05H0oooo002@0?ooomd000001P3oool01@000000oooo0?oo
o`3oool0000004L0oooo0P00o`0O0?ooo`030000003oool0oooo01`0oooo
0P00o`1D0?ooo`00T03oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`120?ooo`800?l08@3oool00`000000oooo0?oo
o`0N0?ooo`800?l0DP3oool00900oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`040?ooo`H00000@`3oool0
0`00o`00oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<00?l0
0?ooo`3oool0C`3oool00900oooo00<000000?ooo`3oool0h@3oool01@00
0000oooo0?ooo`3oool000000480oooo00<00?l00?ooo`3oool08P3oool0
0`000000oooo0?ooo`0Q0?ooo`03003o003oool0oooo04h0oooo002@0?oo
o`030000003oool0oooo0>80oooo0`0000120?ooo`03003o003oool0oooo
02<0oooo00<000000?ooo`3oool08P3oool00`00o`00oooo0?ooo`1=0?oo
o`00T03oool00`000000oooo0?ooo`3o0?ooobH0oooo0P00o`0V0?ooo`03
0000003oool0oooo02<0oooo0P00o`1=0?ooo`00T03oool00`000000oooo
0?ooo`3o0?ooobD0oooo00<00?l00?ooo`3oool09P3oool00`000000oooo
0?ooo`0U0?ooo`03003o003oool0oooo04X0oooo002@0?ooo`030000003o
ool0oooo0?l0oooo903oool00`00o`00oooo0?ooo`0W0?ooo`030000003o
ool0oooo02H0oooo0P00o`1:0?ooo`00T03oool00`000000oooo0?ooo`3o
0?ooob<0oooo00<00?l00?ooo`3oool0:03oool00`000000oooo0?ooo`0X
0?ooo`03003o003oool0oooo04L0oooo002@0?ooo`030000003oool0oooo
0?l0oooo8@3oool2003o02/0oooo00<000000?ooo`3oool0:@3oool00`00
o`00oooo0?ooo`160?ooo`00T03oool00`000000oooo0?ooo`3o0?ooob00
oooo00<00?l00?ooo`3oool0:`3oool00`000000oooo0?ooo`0Z0?ooo`03
003o003oool0oooo04D0oooo002@0?ooo`030000003oool0oooo0?l0oooo
7`3oool00`00o`00oooo0?ooo`0/0?ooo`030000003oool0oooo02/0oooo
00<00?l00?ooo`3oool0A03oool00900oooo00<000000?ooo`3oool0o`3o
oolN0?ooo`03003o003oool0oooo02d0oooo00<000000?ooo`3oool0;03o
ool00`00o`00oooo0?ooo`130?ooo`00T03oool00`000000oooo0?ooo`3o
0?oooad0oooo00<00?l00?ooo`3oool0;P3oool00`000000oooo0?ooo`0]
0?ooo`03003o003oool0oooo0480oooo002@0?ooo`030000003oool0oooo
0?l0oooo7@3oool00`00o`00oooo0?ooo`0^0?ooo`030000003oool0oooo
02d0oooo00<00?l00?ooo`3oool0@P3oool00900oooo00<000000?ooo`3o
ool0o`3ooolL0?ooo`03003o003oool0oooo02l0oooo00<000000?ooo`3o
ool0;P3oool00`00o`00oooo0?ooo`110?ooo`00T03oool00`000000oooo
0?ooo`3o0?oooa/0oooo00<00?l00?ooo`3oool0<03oool00`000000oooo
0?ooo`0_0?ooo`03003o003oool0oooo0400oooo002@0?ooo`030000003o
ool0oooo0?l0oooo6P3oool00`00o`00oooo0?ooo`0a0?ooo`030000003o
ool0oooo0300oooo00<00?l00?ooo`3oool0?`3oool00900oooo00<00000
0?ooo`3oool0o`3ooolI0?ooo`03003o003oool0oooo0380oooo00<00000
0?ooo`3oool0<@3oool00`00o`00oooo0?ooo`0n0?ooo`00T03oool00`00
0000oooo0?ooo`3o0?oooaT0oooo00<00?l00?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0a0?ooo`03003o003oool0oooo03h0oooo002@0?ooo`03
0000003oool0oooo0?l0oooo603oool00`00o`00oooo0?ooo`0c0?ooo`03
0000003oool0oooo0380oooo00<00?l00?ooo`3oool0?@3oool00900oooo
00<000000?ooo`3oool0o`3ooolG0?ooo`03003o003oool0oooo03@0oooo
00<000000?ooo`3oool0<`3oool00`00o`00oooo0?ooo`0l0?ooo`00T03o
ool00`000000oooo0?ooo`3=0?ooo`d0o`00?03oool00`00o`00oooo0?oo
o`0d0?ooo`030000003oool0oooo0280oooo0`0000040?ooo`D000001@3o
ool00`00o`00oooo0?ooo`0l0?ooo`00T03oool00`000000oooo0?ooo`2m
0?oooa00o`00B03oool00`00o`00oooo0?ooo`0e0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`03003o003oool0oooo03/0oooo002@0?ooo`030000003oool0oooo
0;40oooo303o001G0?ooo`03003o003oool0oooo03H0oooo00<000000?oo
o`3oool06P3oool30?l000H0oooo00@000000?ooo`0000000000103oool0
0`000000oooo0?ooo`070?ooo`03003o003oool0oooo03X0oooo001m0?oo
o`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo
0:P0oooo2@3o001S0?ooo`03003o003oool0oooo03H0oooo00<000000?oo
o`3oool06@3oool50?l000D0oooo0P0000020?ooo`050000003oool0oooo
0?ooo`0000002P3oool00`00o`00oooo0?ooo`0i0?ooo`00O03oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0X@3oool70?l006/0oooo00<00?l00?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0I0?ooo`D0o`001@3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000X0oooo00<00?l00?ooo`3oool0
>@3oool007`0oooo00@000000?ooo`3oool000002`3oool00`000000oooo
0?ooo`020?ooo`800000W@3oool50?l00780oooo00<00?l00?ooo`3oool0
=`3oool00`000000oooo0?ooo`0I0?ooo`D0o`001P3oool01P000000oooo
0?ooo`3oool000000?ooo`8000002`3oool00`00o`00oooo0?ooo`0h0?oo
o`00O03oool010000000oooo0?ooo`0000090?ooo`8000001@3oool00`00
0000oooo0?ooo`2G0?ooo`D0o`00MP3oool00`00o`00oooo0?ooo`0h0?oo
o`030000003oool0oooo01X0oooo0`3o00070?ooo`8000000P3oool00`00
0000oooo0?ooo`0<0?ooo`03003o003oool0oooo03P0oooo001l0?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2C0?ooo`@0o`00N`3oool00`00o`00oooo0?ooo`0h0?oo
o`030000003oool0oooo02<0oooo0P0000000`3oool000000000000?0?oo
o`03003o003oool0oooo03P0oooo001m0?ooo`8000002P3oool3000000@0
oooo00<000000?ooo`3oool0S`3oool40?l007h0oooo00<00?l00?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0h0?ooo`03003o003oool0oooo03L0
oooo002@0?ooo`030000003oool0oooo08`0oooo0`3o00220?ooo`03003o
003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`00o`00oooo
0?ooo`0g0?ooo`00T03oool00`000000oooo0?ooo`290?ooo`<0o`00Q@3o
ool00`00o`00oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<0
0?l00?ooo`3oool0=P3oool00900oooo00<000000?ooo`3oool0QP3oool3
0?l008L0oooo00<00?l00?ooo`3oool0>P3oool00`000000oooo0?ooo`0i
0?ooo`03003o003oool0oooo03H0oooo002@0?ooo`030000003oool0oooo
08@0oooo0P3o002:0?ooo`03003o003oool0oooo03X0oooo00<000000?oo
o`3oool0>P3oool00`00o`00oooo0?ooo`0e0?ooo`00T03oool00`000000
oooo0?ooo`210?ooo`<0o`00R`3oool00`00o`00oooo0?ooo`0k0?ooo`03
0000003oool0oooo03X0oooo00<00?l00?ooo`3oool0=@3oool00900oooo
00<000000?ooo`3oool0O`3oool20?l008h0oooo00<00?l00?ooo`3oool0
>`3oool00`000000oooo0?ooo`0j0?ooo`03003o003oool0oooo03D0oooo
002@0?ooo`030000003oool0oooo07d0oooo0P3o002@0?ooo`03003o003o
ool0oooo03/0oooo00<000000?ooo`3oool0>`3oool00`00o`00oooo0?oo
o`0d0?ooo`00T03oool00`000000oooo0?ooo`1k0?ooo`80o`00T@3oool0
0`00o`00oooo0?ooo`0l0?ooo`030000003oool0oooo03/0oooo00<00?l0
0?ooo`3oool0=03oool00900oooo00<000000?ooo`3oool0N@3oool20?l0
09<0oooo00<00?l00?ooo`3oool0?03oool00`000000oooo0?ooo`0k0?oo
o`03003o003oool0oooo03@0oooo002@0?ooo`030000003oool0oooo07L0
oooo0P3o002E0?ooo`03003o003oool0oooo03`0oooo00<000000?ooo`3o
ool0>`3oool00`00o`00oooo0?ooo`0d0?ooo`00T03oool00`000000oooo
0?ooo`1e0?ooo`80o`00UP3oool00`00o`00oooo0?ooo`0m0?ooo`030000
003oool0oooo03/0oooo00<00?l00?ooo`3oool0=03oool00900oooo00<0
00000?ooo`3oool0M03oool00`3o0000oooo0?ooo`2F0?ooo`03003o003o
ool0oooo03d0oooo00<000000?ooo`3oool0?03oool00`00o`00oooo0?oo
o`0c0?ooo`00T03oool00`000000oooo0?ooo`1b0?ooo`80o`00V@3oool0
0`00o`00oooo0?ooo`0m0?ooo`030000003oool0oooo03`0oooo00<00?l0
0?ooo`3oool0<`3oool00900oooo00<000000?ooo`3oool0L@3oool00`3o
0000oooo0?ooo`2I0?ooo`03003o003oool0oooo03d0oooo00<000000?oo
o`3oool0?03oool00`00o`00oooo0?ooo`0c0?ooo`00T03oool00`000000
oooo0?ooo`1_0?ooo`80o`00W03oool00`00o`00oooo0?ooo`0m0?ooo`03
0000003oool0oooo03`0oooo00<00?l00?ooo`3oool0<`3oool00900oooo
00<000000?ooo`3oool0KP3oool00`3o0000oooo0?ooo`2K0?ooo`03003o
003oool0oooo03h0oooo00<000000?ooo`3oool0?03oool00`00o`00oooo
0?ooo`0c0?ooo`00T03oool00`000000oooo0?ooo`1/0?ooo`80o`00WP3o
ool00`00o`00oooo0?ooo`0n0?ooo`030000003oool0oooo03d0oooo00<0
0?l00?ooo`3oool0<P3oool00900oooo00<000000?ooo`3oool0J`3oool0
0`3o0000oooo0?ooo`2N0?ooo`03003o003oool0oooo03h0oooo00<00000
0?ooo`3oool0?@3oool00`00o`00oooo0?ooo`0b0?ooo`00T03oool00`00
0000oooo0?ooo`1Z0?ooo`030?l0003oool0oooo09l0oooo00<00?l00?oo
o`3oool0?P3oool00`000000oooo0?ooo`0m0?ooo`03003o003oool0oooo
0380oooo002@0?ooo`030000003oool0oooo06T0oooo00<0o`000?ooo`3o
ool0X03oool00`00o`00oooo0?ooo`0n0?ooo`030000003oool0oooo03d0
oooo00<00?l00?ooo`3oool0<P3oool008P0oooo1@0000030?ooo`030000
003oool0oooo06P0oooo00<0o`000?ooo`3oool0X@3oool00`00o`00oooo
0?ooo`0n0?ooo`030000003oool0oooo03d0oooo00<00?l00?ooo`3oool0
<P3oool008X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1V0?ooo`80o`00Y03oool00`00o`00oooo0?ooo`0n0?ooo`030000003o
ool0oooo03d0oooo00<00?l00?ooo`3oool0<P3oool008X0oooo00<00000
0?ooo`3oool00`3oool2000006H0oooo00<0o`000?ooo`3oool0Y03oool0
0`00o`00oooo0?ooo`0n0?ooo`030000003oool0oooo03d0oooo00<00?l0
0?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00d0oooo002:0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0I03oool00`3o0000oooo0?ooo`2U0?ooo`03003o003oool0oooo
03h0oooo00<000000?ooo`3oool0?@3oool00`00o`00oooo0?ooo`0H0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool008X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1S0?ooo`03
0?l0003oool0oooo0:H0oooo00<00?l00?ooo`3oool0?03oool30000ocl0
oooo00<00?l00?ooo`3oool02@3oool300000080oooo00<000000?ooo`3o
ool00`0000030?ooo`030000003oool0oooo0080oooo100000040?ooo`03
0000003oool0oooo00/0oooo00290?ooo`8000001@3oool00`000000oooo
0?ooo`1R0?ooo`030?l0003oool0oooo0:@0oooo0`0000000`00o`000000
0000000k000000D0003o?P0000000`00o`00000000000005000000D0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000
oooo0?ooo`0;0?ooo`00T03oool00`000000oooo0?ooo`1Q0?ooo`030?l0
003oool0oooo0:P0oooo00<00?l00?ooo`3oool0>`3oool50000och0oooo
00<00?l00?ooo`3oool02P3oool3000000<0oooo100000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`0;0?ooo`00T03oool00`000000oooo0?ooo`1P0?ooo`030?l0003o
ool0oooo0:T0oooo00<00?l00?ooo`3oool0>`3oool50000och0oooo00<0
0?l00?ooo`3oool02P3oool010000000oooo0?ooo`0000030?ooo`800000
103oool00`000000oooo0?ooo`020?ooo`@00000103oool00`000000oooo
0?ooo`0;0?ooo`00T03oool00`000000oooo0?ooo`1O0?ooo`030?l0003o
ool0oooo0:X0oooo00<00?l00?ooo`3oool0?03oool30000ocl0oooo00<0
0?l00?ooo`3oool02P3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00900oooo00<0
00000?ooo`3oool0GP3oool00`3o0000oooo0?ooo`2[0?ooo`03003o003o
ool0oooo03h0oooo00<000000?ooo`3oool01`3oool500000340oooo00<0
0?l00?ooo`3oool02@3oool4000000`0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0=0?ooo`00T03oool00`000000oooo0?ooo`1M
0?ooo`030?l0003oool0oooo0:`0oooo00<00?l00?ooo`3oool0?P3oool0
10000000oooo0?ooo`3oool5000000<0oooo00<000000?ooo`3oool0<@3o
ool00`00o`00oooo0?ooo`0b0?ooo`00T03oool00`000000oooo0?ooo`1M
0?ooo`030?l0003oool0oooo0:`0oooo00<00?l00?ooo`3oool0?P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool0<@3oool00`00o`00oooo0?ooo`0b0?ooo`00T03oool0
0`000000oooo0?ooo`1L0?ooo`030?l0003oool0oooo0:d0oooo00<00?l0
0?ooo`3oool0?P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0<@3oool00`00o`00oooo0?ooo`0b
0?ooo`00T03oool00`000000oooo0?ooo`1K0?ooo`030?l0003oool0oooo
0:h0oooo00<00?l00?ooo`3oool0?P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0<@3oool00`00
o`00oooo0?ooo`0b0?ooo`00T03oool00`000000oooo0?ooo`1J0?ooo`03
0?l0003oool0oooo0:l0oooo00<00?l00?ooo`3oool0?P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo0P00000c0?oo
o`03003o003oool0oooo0380oooo002@0?ooo`030000003oool0oooo05T0
oooo00<0o`000?ooo`3oool0/03oool00`00o`00oooo0?ooo`0n0?ooo`03
0000003oool0oooo0080oooo1@00000f0?ooo`03003o003oool0oooo0380
oooo002@0?ooo`030000003oool0oooo05P0oooo00<0o`000?ooo`3oool0
/@3oool00`00o`00oooo0?ooo`0n0?ooo`030000003oool0oooo03`0oooo
00<00?l00?ooo`3oool0<`3oool00900oooo00<000000?ooo`3oool0F03o
ool00`3o0000oooo0?ooo`2b0?ooo`03003o003oool0oooo03d0oooo00<0
00000?ooo`3oool0?03oool00`00o`00oooo0?ooo`0c0?ooo`00T03oool0
0`000000oooo0?ooo`1G0?ooo`030?l0003oool0oooo0;<0oooo00<00?l0
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`03003o003oool0
oooo03<0oooo002@0?ooo`030000003oool0oooo05H0oooo00<0o`000?oo
o`3oool0]03oool00`00o`00oooo0?ooo`0m0?ooo`030000003oool0oooo
03`0oooo00<00?l00?ooo`3oool0<`3oool00900oooo00<000000?ooo`3o
ool0EP3oool00`3o0000oooo0?ooo`2d0?ooo`03003o003oool0oooo03d0
oooo00<000000?ooo`3oool0?03oool00`00o`00oooo0?ooo`0c0?ooo`00
T03oool00`000000oooo0?ooo`1E0?ooo`030?l0003oool0oooo0;H0oooo
00<00?l00?ooo`3oool0?03oool00`000000oooo0?ooo`0k0?ooo`03003o
003oool0oooo03@0oooo002@0?ooo`030000003oool0oooo05@0oooo00<0
o`000?ooo`3oool0]`3oool00`00o`00oooo0?ooo`0l0?ooo`030000003o
ool0oooo03/0oooo00<00?l00?ooo`3oool0=03oool00900oooo00<00000
0?ooo`3oool0E03oool00`3o0000oooo0?ooo`2g0?ooo`03003o003oool0
oooo03`0oooo00<000000?ooo`3oool0>`3oool00`00o`00oooo0?ooo`0d
0?ooo`00T03oool00`000000oooo0?ooo`1C0?ooo`030?l0003oool0oooo
0;T0oooo00<00?l00?ooo`3oool0>`3oool00`000000oooo0?ooo`0k0?oo
o`03003o003oool0oooo03@0oooo002@0?ooo`030000003oool0oooo0580
oooo00<0o`000?ooo`3oool0^P3oool00`00o`00oooo0?ooo`0k0?ooo`03
0000003oool0oooo03/0oooo00<00?l00?ooo`3oool0=03oool007`0oooo
1@0000020?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
DP3oool00`3o0000oooo0?ooo`2j0?ooo`03003o003oool0oooo03/0oooo
00<000000?ooo`3oool0>P3oool00`00o`00oooo0?ooo`0e0?ooo`00OP3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`2k0?ooo`03003o
003oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`00o`00oooo
0?ooo`0e0?ooo`00OP3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0080oooo0P00001A0?ooo`030?l0003oool0oooo0;d0oooo00<0
0?l00?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`03003o003o
ool0oooo03D0oooo001n0?ooo`030000003oool0oooo00P0oooo0P000005
0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0_@3oool0
0`00o`00oooo0?ooo`0j0?ooo`030000003oool0oooo03T0oooo00<00?l0
0?ooo`3oool0=P3oool007h0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo04l0oooo00<0o`000?oo
o`3oool0_`3oool00`00o`00oooo0?ooo`0i0?ooo`030000003oool0oooo
03T0oooo00<00?l00?ooo`3oool0=P3oool007d0oooo0P00000:0?ooo`<0
0000103oool00`000000oooo0?ooo`1>0?ooo`030?l0003oool0oooo0<00
oooo00<00?l00?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`03
003o003oool0oooo03L0oooo002@0?ooo`030000003oool0oooo04h0oooo
00<0o`000?ooo`3oool0`03oool00`00o`00oooo0?ooo`0i0?ooo`030000
003oool0oooo0280oooo0`00000C0?ooo`03003o003oool0oooo03L0oooo
002@0?ooo`030000003oool0oooo04d0oooo00<0o`000?ooo`3oool0`P3o
ool00`00o`00oooo0?ooo`0h0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0103oool3000000X0oooo00<00?l00?ooo`3oool0>03o
ool00900oooo00<000000?ooo`3oool0C@3oool00`3o0000oooo0?ooo`32
0?ooo`03003o003oool0oooo03P0oooo00<000000?ooo`3oool06P3oool3
0?l000H0oooo00@000000?ooo`00000000000`3oool00`000000oooo0?oo
o`0:0?ooo`03003o003oool0oooo03P0oooo002@0?ooo`030000003oool0
oooo04`0oooo00<0o`000?ooo`3oool0a03oool00`00o`00oooo0?ooo`0g
0?ooo`030000003oool0oooo01T0oooo1@3o00050?ooo`8000000P3oool0
1@000000oooo0?ooo`3oool0000000X0oooo00<00?l00?ooo`3oool0>@3o
ool00900oooo00<000000?ooo`3oool0C03oool00`3o0000oooo0?ooo`35
0?ooo`03003o003oool0oooo03H0oooo00<000000?ooo`3oool06@3oool5
0?l000D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000:0?ooo`03003o003oool0oooo03T0oooo002@0?ooo`030000003oool0
oooo04/0oooo00<0o`000?ooo`3oool0aP3oool00`00o`00oooo0?ooo`0f
0?ooo`030000003oool0oooo01T0oooo1@3o00060?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool0000000P0oooo00<00?l00?ooo`3o
ool0>P3oool00900oooo00<000000?ooo`3oool0B`3oool00`3o0000oooo
0?ooo`370?ooo`03003o003oool0oooo03D0oooo00<000000?ooo`3oool0
6P3oool30?l000L0oooo0P0000020?ooo`040000003oool0oooo000000T0
oooo00<00?l00?ooo`3oool0>P3oool00900oooo00<000000?ooo`3oool0
BP3oool00`3o0000oooo0?ooo`380?ooo`03003o003oool0oooo03D0oooo
00<000000?ooo`3oool08`3oool2000000030?ooo`000000000000`0oooo
00<00?l00?ooo`3oool0>`3oool00900oooo00<000000?ooo`3oool0BP3o
ool00`3o0000oooo0?ooo`390?ooo`03003o003oool0oooo03@0oooo00<0
00000?ooo`3oool0<`3oool00`00o`00oooo0?ooo`0l0?ooo`00T03oool0
0`000000oooo0?ooo`190?ooo`030?l0003oool0oooo0<X0oooo00<00?l0
0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`03003o003oool0
oooo03`0oooo002@0?ooo`030000003oool0oooo04T0oooo00<0o`000?oo
o`3oool0b`3oool00`00o`00oooo0?ooo`0c0?ooo`030000003oool0oooo
0380oooo00<00?l00?ooo`3oool0?@3oool00900oooo00<000000?ooo`3o
ool0B03oool00`3o0000oooo0?ooo`3=0?ooo`03003o003oool0oooo0380
oooo00<000000?ooo`3oool0<@3oool00`00o`00oooo0?ooo`0n0?ooo`00
T03oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo0<d0oooo
00<00?l00?ooo`3oool0<P3oool00`000000oooo0?ooo`0a0?ooo`03003o
003oool0oooo03h0oooo002@0?ooo`030000003oool0oooo04L0oooo00<0
o`000?ooo`3oool0c`3oool00`00o`00oooo0?ooo`0a0?ooo`030000003o
ool0oooo0300oooo00<00?l00?ooo`3oool0?`3oool00900oooo00<00000
0?ooo`3oool0A`3oool00`3o0000oooo0?ooo`3@0?ooo`03003o003oool0
oooo0300oooo00<000000?ooo`3oool0;`3oool00`00o`00oooo0?ooo`10
0?ooo`00T03oool00`000000oooo0?ooo`160?ooo`030?l0003oool0oooo
0=80oooo00<00?l00?ooo`3oool0;`3oool00`000000oooo0?ooo`0^0?oo
o`03003o003oool0oooo0440oooo002@0?ooo`030000003oool0oooo04H0
oooo00<0o`000?ooo`3oool0d`3oool00`00o`00oooo0?ooo`0^0?ooo`03
0000003oool0oooo02d0oooo00<00?l00?ooo`3oool0@P3oool00900oooo
00<000000?ooo`3oool0A@3oool00`3o0000oooo0?ooo`3E0?ooo`03003o
003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`00o`00oooo
0?ooo`120?ooo`00T03oool00`000000oooo0?ooo`150?ooo`030?l0003o
ool0oooo0=H0oooo00<00?l00?ooo`3oool0;03oool00`000000oooo0?oo
o`0/0?ooo`03003o003oool0oooo04<0oooo002@0?ooo`030000003oool0
oooo04@0oooo00<0o`000?ooo`3oool0e`3oool00`00o`00oooo0?ooo`0/
0?ooo`030000003oool0oooo02/0oooo00<00?l00?ooo`3oool0A03oool0
08P0oooo100000040?ooo`030000003oool0oooo04@0oooo00<0o`000?oo
o`3oool0f03oool00`00o`00oooo0?ooo`0[0?ooo`030000003oool0oooo
02X0oooo00<00?l00?ooo`3oool0A@3oool008P0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`130?ooo`030?l0003oool0oooo0=X0
oooo0P00o`0[0?ooo`030000003oool0oooo02T0oooo00<00?l00?ooo`3o
ool0AP3oool008T0oooo00<000000?ooo`3oool0103oool80?l003h0oooo
00<0o`000?ooo`3oool0g03oool00`00o`00oooo0?ooo`0X0?ooo`030000
003oool0oooo02P0oooo00<00?l00?ooo`3oool0A`3oool008X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`80o`00>`3o
ool00`3o0000oooo0?ooo`3N0?ooo`03003o003oool0oooo02L0oooo00<0
00000?ooo`3oool09P3oool2003o04X0oooo00280?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool01`3oool20?l003T0oooo00<0
o`000?ooo`3oool0g`3oool00`00o`00oooo0?ooo`0V0?ooo`030000003o
ool0oooo02D0oooo00<00?l00?ooo`3oool0BP3oool008T0oooo0P000005
0?ooo`030000003oool0oooo00T0oooo0P3o000f0?ooo`030?l0003oool0
oooo0>40oooo0P00o`0V0?ooo`030000003oool0oooo02<0oooo0P00o`1=
0?ooo`00T03oool00`000000oooo0?ooo`0;0?ooo`80o`00=03oool00`3o
0000oooo0?ooo`3S0?ooo`03003o003oool0oooo02<0oooo00<000000?oo
o`3oool08P3oool00`00o`00oooo0?ooo`1=0?ooo`00T03oool00`000000
oooo0?ooo`0=0?ooo`80o`00<@3oool00`3o0000oooo0?ooo`3U0?ooo`03
003o003oool0oooo0280oooo00<000000?ooo`3oool08@3oool00`00o`00
oooo0?ooo`1>0?ooo`00T03oool00`000000oooo0?ooo`0?0?ooo`030?l0
003oool0oooo02h0oooo00<0o`000?ooo`3oool0iP3oool00`00o`00oooo
0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<00?l00?ooo`3oool0
C`3oool00900oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?oo
o`0/0?ooo`030?l0003oool0oooo0>P0oooo0P00o`0Q0?ooo`030000003o
ool0oooo01h0oooo0P00o`1B0?ooo`00T03oool00`000000oooo0?ooo`0A
0?ooo`80o`00;03oool00`3o0000oooo0?ooo`3Z0?ooo`800?l07`3oool0
0`000000oooo0?ooo`0L0?ooo`800?l0E03oool00900oooo00<000000?oo
o`3oool04`3oool00`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo
0>d0oooo0P00o`0M0?ooo`030000003oool0oooo01X0oooo0P00o`1F0?oo
o`00T03oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo02L0
oooo00<0o`000?ooo`3oool0k`3oool2003o01/0oooo00<000000?ooo`3o
ool0603oool2003o05P0oooo002@0?ooo`030000003oool0oooo01D0oooo
0P3o000V0?ooo`030?l0003oool0oooo0?80oooo0P00o`0I0?ooo`030000
003oool0oooo01H0oooo0P00o`1J0?ooo`00T03oool00`000000oooo0?oo
o`0G0?ooo`030?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool0m03o
ool3003o01H0oooo00<000000?ooo`3oool04`3oool3003o05`0oooo002@
0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`3h0?ooo`<00?l04`3oool00`000000oooo0?ooo`0@
0?ooo`<00?l0G`3oool00900oooo00<000000?ooo`3oool06@3oool00`3o
0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo0?/0oooo1000o`0?0?oo
o`030000003oool0oooo00d0oooo0`00o`1R0?ooo`00T03oool00`000000
oooo0?ooo`0J0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3o
ool0o`3oool10?ooo`@00?l02`3oool00`000000oooo0?ooo`080?ooo`D0
0?l0I@3oool00900oooo00<000000?ooo`3oool06`3oool00`3o0000oooo
0?ooo`0M0?ooo`030?l0003oool0oooo0?l0oooo1@3ooolF003o06X0oooo
002@0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool06`3o
ool00`3o0000oooo0?ooo`3o0?oooa40oooo00<000000?ooo`3oool0LP3o
ool00900oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0J
0?ooo`030?l0003oool0oooo0?l0oooo4@3oool00`000000oooo0?ooo`1b
0?ooo`00T03oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo
01P0oooo00<0o`000?ooo`3oool0o`3ooolB0?ooo`030000003oool0oooo
0780oooo002@0?ooo`030000003oool0oooo01l0oooo00<0o`000?ooo`3o
ool05`3oool00`3o0000oooo0?ooo`3o0?oooa80oooo00<000000?ooo`3o
ool0LP3oool00900oooo00<000000?ooo`3oool0803oool00`3o0000oooo
0?ooo`0E0?ooo`030?l0003oool0oooo0?l0oooo4`3oool00`000000oooo
0?ooo`1b0?ooo`00T03oool00`000000oooo0?ooo`0Q0?ooo`030?l0003o
ool0oooo01<0oooo00<0o`000?ooo`3oool0o`3ooolD0?ooo`030000003o
ool0oooo0780oooo002@0?ooo`030000003oool0oooo0280oooo0P3o000C
0?ooo`030?l0003oool0oooo0?l0oooo503oool00`000000oooo0?ooo`1b
0?ooo`00O03oool4000000<0oooo0P0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?oo
o`3oool0o`3ooon:0?ooo`00O03oool00`000000oooo0?ooo`090?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool09@3oool00`3o
0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0?l0ooooR`3oool007d0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`80
00009`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0?l0
ooooS03oool007h0oooo00<000000?ooo`3oool0203oool2000000D0oooo
00<000000?ooo`3oool09`3oool20?l000T0oooo0P3o003o0?ooohl0oooo
001l0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0Y0?ooo`@0o`000P3oool30?l00?l0oooo
T@3oool007d0oooo0P00000:0?ooo`<00000103oool00`000000oooo0?oo
o`0]0?ooo`80o`00o`3ooolP0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0J03oool00900oooo00<000000?ooo`3oool0o`3ooom>
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0I`3oool0
0900oooo00<000000?ooo`3oool0o`3ooom10?ooo`<0000000L0oooo0000
00000000oooo0000003oool000000080oooo00<000000?ooo`3oool00P3o
ool4000000@0oooo00<000000?ooo`3oool0IP3oool00?l0ooooe@3oool0
2@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000
oooo0?ooo`1V0?ooo`00o`3ooooE0?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000050?ooo`030000003oool0oooo06H0oooo003o0?oo
omD0oooo00<000000?ooo`3oool00`0000000`3oool000000?ooo`020?oo
o`030000003oool0oooo0080oooo100000040?ooo`030000003oool0oooo
06H0oooo003o0?ooomD0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo06L0oooo003o0?ooom@0oooo
0`00000;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
J03oool00?l0ooooo`3ooomG0?ooo`00o`3ooooo0?oooeL0oooo003o0?oo
ool0ooooE`3oool008h0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`3o0?oook`0oooo002=0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0o`3ooonk0?ooo`00Q@3oool2000000030?ooo`00
000000000080oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<0
00000?ooo`3oool0o`3ooonj0?ooo`00Q@3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonj0?ooo`00QP3o
ool3000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000
003oool0oooo0?ooo`000000o`3ooonl0?ooo`00QP3oool00`000000oooo
000000030?ooo`040000003oool0oooo0?ooo`H000000`3oool00`000000
oooo0?ooo`3o0?oookX0oooo00270?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo0000
0?l0oooo_@3oool008H0oooo0P0000060?ooo`040000003oool0oooo0?oo
o`<000000P3oool00`000000oooo0?ooo`3o0?oook`0oooo003o0?ooool0
ooooE`3oool00?l0ooooo`3ooomG0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{597, 183},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Figure 9.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "Amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  ", and zero-pole plot for  ",
  Cell[BoxData[
      \(y[n]\  = \ x[n] + \(2\/3\) \@2\ y[n - 1] - \(4\/9\) y[n - 2]\)]],
  ". "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009E0000]b000`400?l0
0000o`00003oo`3ooooo0?oooeL0oooo003o0?ooool0ooooE`3oool00?l0
ooooo`3ooomG0?ooo`00o`3ooooo0?oooeL0oooo003o0?ooool0ooooE`3o
ool00?l0ooooo`3ooomG0?ooo`00o`3ooooo0?oooeL0oooo003o0?ooool0
ooooE`3oool00?l0oooo<P3oool300000?l0oooo8P3oool00<<0oooo0`00
000b0?ooo`@00000=P3oool00`000000oooo0?ooo`3o0?ooob40oooo0034
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0=03oool5
00000?l0oooo8P3oool00<40oooo1@00000c0?ooo`030000003oool0oooo
03<0oooo00@000000?ooo`3oool00000o`3ooolS0?ooo`00`@3oool01000
0000oooo0?ooo`00000e0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`000000o`3ooolS0?ooo`00`P3oool00`000000oooo0000000c0?oo
o`040000003oool0oooo000003D0oooo0P00003o0?ooob<0oooo00330?oo
o`800000=03oool200000?l0ooooF`3oool00?l0oooo:P3oool>00000003
0?ooo`00000000000?l0oooo703oool00?l0ooooh@3oool00`000000oooo
0?ooo`1b0?ooo`00_`3oool8000002l0oooo2000003R0?ooo`030000003o
ool0oooo0780oooo003o0?ooofH0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0780oooo003o0?oo
obd0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0:`3oool010000000oooo0?ooo`00001f0?ooo`030000003oool0
oooo0780oooo003o0?ooob`0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`00000_0?ooo`030000003oool0000006`0oooo5000
o`1[0?ooo`00`03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000;`3oool0
0`000000oooo0000001W0?ooo`D00?l02P3oool00`000000oooo0?ooo`07
0?ooo`D00?l0IP3oool00<40oooo00@000000?ooo`3oool00000<`3oool0
10000000oooo0?ooo`00000b0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`000000;P3oool500000640oooo1@00o`0?0?ooo`030000003o
ool0oooo00`0oooo1@00o`1Q0?ooo`00`P3oool00`000000oooo0000000d
0?ooo`030000003oool0000002l0oooo00@000000?ooo`3oool000001@3o
ool500000940oooo0P00o`0D0?ooo`030000003oool0oooo0140oooo0`00
o`1N0?ooo`00`P3oool00`000000oooo0000000d0?ooo`030000003oool0
00000300oooo0P00002I0?ooo`<00?l05P3oool00`000000oooo0?ooo`0D
0?ooo`800?l0G03oool00<40oooo1@00000b0?ooo`D00000b03oool2003o
01T0oooo00<000000?ooo`3oool05P3oool2003o05X0oooo003o0?oool@0
oooo0P00o`0K0?ooo`030000003oool0oooo01P0oooo0P00o`1H0?ooo`00
o`3ooomb0?ooo`<00000C@3oool2003o01d0oooo00<000000?ooo`3oool0
6P3oool2003o05H0oooo002<0?ooomd000001`3oool01@000000oooo0?oo
o`3oool0000004X0oooo0P00o`0O0?ooo`030000003oool0oooo01`0oooo
0P00o`1D0?ooo`00S03oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`150?ooo`800?l08@3oool00`000000oooo0?oo
o`0N0?ooo`800?l0DP3oool008`0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`050?ooo`H00000AP3oool0
0`00o`00oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<00?l0
0?ooo`3oool0C`3oool008`0oooo00<000000?ooo`3oool0hP3oool01@00
0000oooo0?ooo`3oool0000004D0oooo00<00?l00?ooo`3oool08P3oool0
0`000000oooo0?ooo`0Q0?ooo`03003o003oool0oooo04h0oooo002<0?oo
o`030000003oool0oooo0><0oooo0`0000150?ooo`03003o003oool0oooo
02<0oooo00<000000?ooo`3oool08P3oool00`00o`00oooo0?ooo`1=0?oo
o`00S03oool00`000000oooo0?ooo`3o0?ooobX0oooo0P00o`0V0?ooo`03
0000003oool0oooo02<0oooo0P00o`1=0?ooo`00S03oool00`000000oooo
0?ooo`3o0?ooobT0oooo00<00?l00?ooo`3oool09P3oool00`000000oooo
0?ooo`0U0?ooo`03003o003oool0oooo04X0oooo002<0?ooo`030000003o
ool0oooo0?l0oooo:03oool00`00o`00oooo0?ooo`0W0?ooo`030000003o
ool0oooo02H0oooo0P00o`1:0?ooo`00S03oool00`000000oooo0?ooo`3o
0?ooobL0oooo00<00?l00?ooo`3oool0:03oool00`000000oooo0?ooo`0X
0?ooo`03003o003oool0oooo04L0oooo002<0?ooo`030000003oool0oooo
0?l0oooo9@3oool2003o02/0oooo00<000000?ooo`3oool0:@3oool00`00
o`00oooo0?ooo`160?ooo`00S03oool00`000000oooo0?ooo`310?oooaT0
o`00B@3oool00`00o`00oooo0?ooo`0[0?ooo`030000003oool0oooo02X0
oooo00<00?l00?ooo`3oool0A@3oool008`0oooo00<000000?ooo`3oool0
/@3oool@0?l00640oooo00<00?l00?ooo`3oool0;03oool00`000000oooo
0?ooo`0[0?ooo`03003o003oool0oooo04@0oooo002<0?ooo`030000003o
ool0oooo0:P0oooo2@3o001`0?ooo`03003o003oool0oooo02d0oooo00<0
00000?ooo`3oool0;03oool00`00o`00oooo0?ooo`130?ooo`00S03oool0
0`000000oooo0?ooo`2O0?ooo`T0o`00N03oool00`00o`00oooo0?ooo`0^
0?ooo`030000003oool0oooo02d0oooo00<00?l00?ooo`3oool0@P3oool0
08`0oooo00<000000?ooo`3oool0UP3oool90?l00840oooo00<00?l00?oo
o`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`03003o003oool0oooo
0480oooo002<0?ooo`030000003oool0oooo08h0oooo203o00290?ooo`03
003o003oool0oooo02l0oooo00<000000?ooo`3oool0;P3oool00`00o`00
oooo0?ooo`110?ooo`00S03oool00`000000oooo0?ooo`2:0?ooo`@0o`00
T03oool00`00o`00oooo0?ooo`0`0?ooo`030000003oool0oooo02l0oooo
00<00?l00?ooo`3oool0@03oool008`0oooo00<000000?ooo`3oool0QP3o
ool40?l009<0oooo00<00?l00?ooo`3oool0<@3oool00`000000oooo0?oo
o`0`0?ooo`03003o003oool0oooo03l0oooo002<0?ooo`030000003oool0
oooo08<0oooo0`3o002F0?ooo`03003o003oool0oooo0380oooo00<00000
0?ooo`3oool0<@3oool00`00o`00oooo0?ooo`0n0?ooo`00S03oool00`00
0000oooo0?ooo`200?ooo`<0o`00V@3oool00`00o`00oooo0?ooo`0b0?oo
o`030000003oool0oooo0280oooo0`0000050?ooo`<00000103oool00`00
o`00oooo0?ooo`0n0?ooo`00S03oool00`000000oooo0?ooo`1m0?ooo`<0
o`00V`3oool00`00o`00oooo0?ooo`0c0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
003o003oool0oooo03d0oooo002<0?ooo`030000003oool0oooo07X0oooo
0`3o002M0?ooo`03003o003oool0oooo03@0oooo00<000000?ooo`3oool0
8`3oool010000000oooo0000000000040?ooo`030000003oool0oooo00D0
oooo00<00?l00?ooo`3oool0?03oool008`0oooo00<000000?ooo`3oool0
M`3oool30?l00:00oooo00<00?l00?ooo`3oool0=03oool00`000000oooo
0?ooo`0S0?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000000L0
oooo00<00?l00?ooo`3oool0?03oool008`0oooo00<000000?ooo`3oool0
M@3oool20?l00:80oooo00<00?l00?ooo`3oool0=@3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000
oooo000000070?ooo`03003o003oool0oooo03/0oooo002<0?ooo`030000
003oool0oooo07<0oooo0P3o002S0?ooo`03003o003oool0oooo03H0oooo
00<000000?ooo`3oool06P3oool30?l000L0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00L0oooo00<00?l00?ooo`3o
ool0>P3oool008`0oooo00<000000?ooo`3oool0L@3oool20?l00:D0oooo
00<00?l00?ooo`3oool0=P3oool00`000000oooo0?ooo`0I0?ooo`D0o`00
1P3oool200000080oooo00<000000?ooo`3oool02`3oool00`00o`00oooo
0?ooo`0i0?ooo`00S03oool00`000000oooo0?ooo`1_0?ooo`80o`00YP3o
ool00`00o`00oooo0?ooo`0g0?ooo`030000003oool0oooo01T0oooo1@3o
00050?ooo`80000000<0oooo0000000000003P3oool00`00o`00oooo0?oo
o`0i0?ooo`00S03oool00`000000oooo0?ooo`1]0?ooo`80o`00Z03oool0
0`00o`00oooo0?ooo`0g0?ooo`030000003oool0oooo01T0oooo1@3o000I
0?ooo`03003o003oool0oooo03P0oooo002<0?ooo`030000003oool0oooo
06`0oooo00<0o`000?ooo`3oool0Y`3oool00`00o`00oooo0?ooo`0h0?oo
o`030000003oool0oooo01X0oooo0`3o000J0?ooo`03003o003oool0oooo
03P0oooo002<0?ooo`030000003oool0oooo06X0oooo0P3o002Z0?ooo`03
003o003oool0oooo03P0oooo00<000000?ooo`3oool0=`3oool00`00o`00
oooo0?ooo`0h0?ooo`00S03oool00`000000oooo0?ooo`1Y0?ooo`030?l0
003oool0oooo0:T0oooo00<00?l00?ooo`3oool0>@3oool00`000000oooo
0?ooo`0h0?ooo`03003o003oool0oooo03L0oooo002<0?ooo`030000003o
ool0oooo06L0oooo0P3o002/0?ooo`03003o003oool0oooo03T0oooo00<0
00000?ooo`3oool0>03oool00`00o`00oooo0?ooo`0g0?ooo`00Q03oool5
000000<0oooo00<000000?ooo`3oool0IP3oool00`3o0000oooo0?ooo`2/
0?ooo`03003o003oool0oooo03T0oooo00<000000?ooo`3oool0>@3oool0
0`00o`00oooo0?ooo`0f0?ooo`00QP3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo06@0oooo0P3o002^0?ooo`03003o003oool0oooo
03X0oooo00<000000?ooo`3oool0>@3oool00`00o`00oooo0?ooo`0f0?oo
o`00QP3oool00`000000oooo0?ooo`030?ooo`<00000H`3oool00`3o0000
oooo0?ooo`2^0?ooo`03003o003oool0oooo03X0oooo00<000000?ooo`3o
ool0>P3oool00`00o`00oooo0?ooo`0e0?ooo`00QP3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0680oooo00<0o`000?ooo`3oool0
[P3oool00`00o`00oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo
00<00?l00?ooo`3oool0=@3oool008H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1Q0?ooo`030?l0003oool0oooo0:l0oooo00<0
0?l00?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`03003o003o
ool0oooo03D0oooo00250?ooo`8000001@3oool00`000000oooo0?ooo`1P
0?ooo`030?l0003oool0oooo0;00oooo00<00?l00?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0k0?ooo`03003o003oool0oooo03@0oooo002<0?oo
o`030000003oool0oooo05l0oooo00<0o`000?ooo`3oool0/03oool00`00
o`00oooo0?ooo`0l0?ooo`030000003oool0oooo03/0oooo00<00?l00?oo
o`3oool0=03oool008`0oooo00<000000?ooo`3oool0GP3oool00`3o0000
oooo0?ooo`2a0?ooo`03003o003oool0oooo03`0oooo00<000000?ooo`3o
ool0>`3oool00`00o`00oooo0?ooo`0d0?ooo`00S03oool00`000000oooo
0?ooo`1M0?ooo`030?l0003oool0oooo0;80oooo00<00?l00?ooo`3oool0
?03oool00`000000oooo0?ooo`0k0?ooo`03003o003oool0oooo03@0oooo
002<0?ooo`030000003oool0oooo05`0oooo00<0o`000?ooo`3oool0/P3o
ool00`00o`00oooo0?ooo`0m0?ooo`030000003oool0oooo03/0oooo00<0
0?l00?ooo`3oool0=03oool008`0oooo00<000000?ooo`3oool0F`3oool0
0`3o0000oooo0?ooo`2c0?ooo`03003o003oool0oooo03d0oooo00<00000
0?ooo`3oool0?03oool00`00o`00oooo0?ooo`0c0?ooo`00S03oool00`00
0000oooo0?ooo`1J0?ooo`030?l0003oool0oooo0;@0oooo00<00?l00?oo
o`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`03003o003oool0oooo
03<0oooo002<0?ooo`030000003oool0oooo05T0oooo00<0o`000?ooo`3o
ool0]@3oool00`00o`00oooo0?ooo`0m0?ooo`030000003oool0oooo03`0
oooo00<00?l00?ooo`3oool0<`3oool008`0oooo00<000000?ooo`3oool0
F@3oool00`3o0000oooo0?ooo`2e0?ooo`03003o003oool0oooo03d0oooo
00<000000?ooo`3oool0?03oool00`00o`00oooo0?ooo`0c0?ooo`00S03o
ool00`000000oooo0?ooo`1H0?ooo`030?l0003oool0oooo0;D0oooo00<0
0?l00?ooo`3oool0?P3oool00`000000oooo0?ooo`0l0?ooo`03003o003o
ool0oooo03<0oooo002<0?ooo`030000003oool0oooo05L0oooo00<0o`00
0?ooo`3oool0]P3oool00`00o`00oooo0?ooo`0n0?ooo`030000003oool0
oooo03d0oooo00<00?l00?ooo`3oool0<P3oool008`0oooo00<000000?oo
o`3oool0E`3oool00`3o0000oooo0?ooo`2f0?ooo`03003o003oool0oooo
03h0oooo00<000000?ooo`3oool0?@3oool00`00o`00oooo0?ooo`0b0?oo
o`00S03oool00`000000oooo0?ooo`1F0?ooo`030?l0003oool0oooo0;L0
oooo00<00?l00?ooo`3oool0?P3oool00`000000oooo0?ooo`0m0?ooo`03
003o003oool0oooo0380oooo002<0?ooo`030000003oool0oooo05D0oooo
00<0o`000?ooo`3oool0^03oool00`00o`00oooo0?ooo`0n0?ooo`030000
003oool0oooo03d0oooo00<00?l00?ooo`3oool0<P3oool008`0oooo00<0
00000?ooo`3oool0E03oool00`3o0000oooo0?ooo`2i0?ooo`03003o003o
ool0oooo03h0oooo00<000000?ooo`3oool0?@3oool00`00o`00oooo0?oo
o`0b0?ooo`00S03oool00`000000oooo0?ooo`1D0?ooo`030?l0003oool0
oooo0;T0oooo00<00?l00?ooo`3oool0?P3oool00`000000oooo0?ooo`0m
0?ooo`03003o003oool0oooo0380oooo002<0?ooo`030000003oool0oooo
05<0oooo00<0o`000?ooo`3oool0^P3oool00`00o`00oooo0?ooo`0n0?oo
o`030000003oool0oooo03d0oooo00<00?l00?ooo`3oool06@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo002<0?ooo`03
0000003oool0oooo0580oooo00<0o`000?ooo`3oool0^`3oool00`00o`00
oooo0?ooo`0n0?ooo`030000003oool0oooo03d0oooo00<00?l00?ooo`3o
ool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0
oooo002<0?ooo`030000003oool0oooo0580oooo00<0o`000?ooo`3oool0
^`3oool00`00o`00oooo0?ooo`0l0?ooo`<0003o7P3oool30?l001h0oooo
00<00?l00?ooo`3oool02@3oool300000080oooo00<000000?ooo`3oool0
0`0000030?ooo`030000003oool0oooo0080oooo100000040?ooo`030000
003oool0oooo00/0oooo002<0?ooo`030000003oool0oooo0540oooo00<0
o`000?ooo`3oool0^@3oool300000003003o00000000000003/000001@00
0?lL000000D0o`007@0000000`00o`00000000000005000000D0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo
0?ooo`0;0?ooo`00S03oool00`000000oooo0?ooo`1@0?ooo`030?l0003o
ool0oooo0;d0oooo00<00?l00?ooo`3oool0>`3oool50000oa`0oooo1@3o
000M0?ooo`03003o003oool0oooo00X0oooo0`0000030?ooo`@000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool02`3oool008`0oooo00<000000?ooo`3oool0D03oool0
0`3o0000oooo0?ooo`2m0?ooo`03003o003oool0oooo03/0oooo1@000?lL
0?ooo`D0o`007@3oool00`00o`00oooo0?ooo`0:0?ooo`040000003oool0
oooo000000<0oooo0P0000040?ooo`030000003oool0oooo0080oooo1000
00040?ooo`030000003oool0oooo00/0oooo002<0?ooo`030000003oool0
oooo04l0oooo00<0o`000?ooo`3oool0_P3oool00`00o`00oooo0?ooo`0l
0?ooo`<0003o7P3oool30?l000D0oooo0`00000F0?ooo`03003o003oool0
oooo00X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00`0oooo002<0?ooo`030000003oool0
oooo04l0oooo00<0o`000?ooo`3oool0_P3oool00`00o`00oooo0?ooo`0n
0?ooo`030000003oool0oooo00L0oooo1@00000I0?ooo`030000003oool0
oooo00<0oooo1@00000=0?ooo`03003o003oool0oooo00T0oooo1000000<
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool0
08`0oooo00<000000?ooo`3oool0CP3oool00`3o0000oooo0?ooo`2o0?oo
o`03003o003oool0oooo03h0oooo00@000000?ooo`3oool0oooo1@000003
0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`0000000000103o
ool00`000000oooo0?ooo`0=0?ooo`03003o003oool0oooo0380oooo002<
0?ooo`030000003oool0oooo04h0oooo00<0o`000?ooo`3oool0_`3oool0
0`00o`00oooo0?ooo`0n0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0I0?ooo`8000000P3o
ool01@000000oooo0?ooo`3oool0000000l0oooo00<00?l00?ooo`3oool0
<P3oool008`0oooo00<000000?ooo`3oool0C@3oool00`3o0000oooo0?oo
o`300?ooo`03003o003oool0oooo03h0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000?0?ooo`03003o
003oool0oooo0380oooo002<0?ooo`030000003oool0oooo04d0oooo00<0
o`000?ooo`3oool0`03oool00`00o`00oooo0?ooo`0n0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0J0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0=0?ooo`03003o003oool0oooo0380oooo002<0?ooo`030000003o
ool0oooo04`0oooo00<0o`000?ooo`3oool0`@3oool00`00o`00oooo0?oo
o`0n0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool2000001`0oooo0P0000020?ooo`040000003oool00000000000l0
oooo00<00?l00?ooo`3oool0<P3oool008@0oooo100000040?ooo`030000
003oool0oooo04/0oooo00<0o`000?ooo`3oool0`P3oool00`00o`00oooo
0?ooo`0n0?ooo`030000003oool0oooo0080oooo1@00000N0?ooo`800000
00<0oooo0000000000004`3oool00`00o`00oooo0?ooo`0b0?ooo`00Q03o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04/0oooo00<0
o`000?ooo`3oool0`P3oool00`00o`00oooo0?ooo`0n0?ooo`030000003o
ool0oooo03`0oooo00<00?l00?ooo`3oool0<`3oool008D0oooo00<00000
0?ooo`3oool0103oool3000004X0oooo00<0o`000?ooo`3oool0a03oool0
0`00o`00oooo0?ooo`0m0?ooo`030000003oool0oooo03`0oooo00<00?l0
0?ooo`3oool0<`3oool008H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`1:0?ooo`030?l0003oool0oooo0<@0oooo00<00?l00?oo
o`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`03003o003oool0oooo
03<0oooo00240?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0B@3oool00`3o0000oooo0?ooo`350?ooo`03003o003oool0oooo
03d0oooo00<000000?ooo`3oool0?03oool00`00o`00oooo0?ooo`0c0?oo
o`00Q@3oool2000000D0oooo00<000000?ooo`3oool0B@3oool00`3o0000
oooo0?ooo`350?ooo`03003o003oool0oooo03d0oooo00<000000?ooo`3o
ool0?03oool00`00o`00oooo0?ooo`0c0?ooo`00S03oool00`000000oooo
0?ooo`180?ooo`030?l0003oool0oooo0<L0oooo00<00?l00?ooo`3oool0
?03oool00`000000oooo0?ooo`0k0?ooo`03003o003oool0oooo03@0oooo
002<0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0a`3o
ool00`00o`00oooo0?ooo`0l0?ooo`030000003oool0oooo03/0oooo00<0
0?l00?ooo`3oool0=03oool008`0oooo00<000000?ooo`3oool0A`3oool0
0`3o0000oooo0?ooo`380?ooo`03003o003oool0oooo03`0oooo00<00000
0?ooo`3oool0>`3oool00`00o`00oooo0?ooo`0d0?ooo`00S03oool00`00
0000oooo0?ooo`170?ooo`030?l0003oool0oooo0<T0oooo00<00?l00?oo
o`3oool0>`3oool00`000000oooo0?ooo`0k0?ooo`03003o003oool0oooo
03@0oooo002<0?ooo`030000003oool0oooo04H0oooo00<0o`000?ooo`3o
ool0bP3oool00`00o`00oooo0?ooo`0k0?ooo`030000003oool0oooo03/0
oooo00<00?l00?ooo`3oool0=03oool008`0oooo00<000000?ooo`3oool0
AP3oool00`3o0000oooo0?ooo`3:0?ooo`03003o003oool0oooo03/0oooo
00<000000?ooo`3oool0>P3oool00`00o`00oooo0?ooo`0e0?ooo`00S03o
ool00`000000oooo0?ooo`150?ooo`030?l0003oool0oooo0</0oooo00<0
0?l00?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`03003o003o
ool0oooo03D0oooo002<0?ooo`030000003oool0oooo04D0oooo00<0o`00
0?ooo`3oool0c03oool00`00o`00oooo0?ooo`0j0?ooo`030000003oool0
oooo03X0oooo00<00?l00?ooo`3oool0=@3oool008`0oooo00<000000?oo
o`3oool0A03oool00`3o0000oooo0?ooo`3=0?ooo`03003o003oool0oooo
03X0oooo00<000000?ooo`3oool0>@3oool00`00o`00oooo0?ooo`0f0?oo
o`00S03oool00`000000oooo0?ooo`140?ooo`030?l0003oool0oooo0<h0
oooo00<00?l00?ooo`3oool0>@3oool00`000000oooo0?ooo`0i0?ooo`03
003o003oool0oooo03H0oooo002<0?ooo`030000003oool0oooo04<0oooo
00<0o`000?ooo`3oool0c`3oool00`00o`00oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo00<00?l00?ooo`3oool0=`3oool008`0oooo00<0
00000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`3?0?ooo`03003o003o
ool0oooo03T0oooo00<000000?ooo`3oool0>03oool00`00o`00oooo0?oo
o`0g0?ooo`00S03oool00`000000oooo0?ooo`120?ooo`030?l0003oool0
oooo0=40oooo00<00?l00?ooo`3oool0>03oool00`000000oooo0?ooo`0g
0?ooo`03003o003oool0oooo03P0oooo002<0?ooo`030000003oool0oooo
0480oooo00<0o`000?ooo`3oool0d@3oool00`00o`00oooo0?ooo`0h0?oo
o`030000003oool0oooo01X0oooo0`3o000J0?ooo`03003o003oool0oooo
03P0oooo002<0?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3o
ool0dP3oool00`00o`00oooo0?ooo`0g0?ooo`030000003oool0oooo01T0
oooo1@3o000H0?ooo`03003o003oool0oooo03T0oooo002<0?ooo`030000
003oool0oooo0440oooo00<0o`000?ooo`3oool0e03oool00`00o`00oooo
0?ooo`0f0?ooo`030000003oool0oooo01T0oooo1@3o00040?ooo`<00000
1@3oool2000000X0oooo00<00?l00?ooo`3oool0>@3oool008`0oooo00<0
00000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`3D0?ooo`03003o003o
ool0oooo03H0oooo00<000000?ooo`3oool06@3oool50?l000D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03003o003o
ool0oooo03X0oooo002<0?ooo`030000003oool0oooo0400oooo00<0o`00
0?ooo`3oool0eP3oool00`00o`00oooo0?ooo`0e0?ooo`030000003oool0
oooo01X0oooo0`3o00060?ooo`040000003oool00000000000@0oooo00<0
00000?ooo`3oool01`3oool00`00o`00oooo0?ooo`0j0?ooo`00S03oool0
0`000000oooo0?ooo`100?ooo`030?l0003oool0oooo0=H0oooo00<00?l0
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0S0?ooo`8000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<00?l0
0?ooo`3oool0>`3oool008`0oooo00<000000?ooo`3oool0?`3oool00`3o
0000oooo0?ooo`3H0?ooo`03003o003oool0oooo03@0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`020?ooo`050000003oool00000
0?ooo`0000001P3oool00`00o`00oooo0?ooo`0l0?ooo`00S03oool00`00
0000oooo0?ooo`0o0?ooo`030?l0003oool0oooo0=P0oooo00<00?l00?oo
o`3oool0=03oool00`000000oooo0?ooo`0T0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`03003o003oool0
oooo03`0oooo002<0?ooo`030000003oool0oooo03h0oooo00<0o`000?oo
o`3oool0fP3oool00`00o`00oooo0?ooo`0c0?ooo`030000003oool0oooo
02@0oooo0P0000020?ooo`030000003oool0oooo00L0oooo00<00?l00?oo
o`3oool0?@3oool008`0oooo00<000000?ooo`3oool0?P3oool00`3o0000
oooo0?ooo`3K0?ooo`03003o003oool0oooo0380oooo00<000000?ooo`3o
ool08`3oool2000000030?ooo`000000000000T0oooo00<00?l00?ooo`3o
ool0?P3oool008`0oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo
0?ooo`3K0?ooo`03003o003oool0oooo0380oooo00<000000?ooo`3oool0
<@3oool00`00o`00oooo0?ooo`0n0?ooo`00S03oool00`000000oooo0?oo
o`0m0?ooo`030?l0003oool0oooo0=d0oooo00<00?l00?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0`0?ooo`03003o003oool0oooo03l0oooo002<
0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0gP3oool0
0`00o`00oooo0?ooo`0`0?ooo`030000003oool0oooo02l0oooo00<00?l0
0?ooo`3oool0@03oool008`0oooo00<000000?ooo`3oool0?03oool00`3o
0000oooo0?ooo`3P0?ooo`03003o003oool0oooo02l0oooo00<000000?oo
o`3oool0;P3oool00`00o`00oooo0?ooo`110?ooo`00S03oool00`000000
oooo0?ooo`0l0?ooo`030?l0003oool0oooo0>40oooo00<00?l00?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0]0?ooo`03003o003oool0oooo0480
oooo00250?ooo`8000001@3oool00`000000oooo0?ooo`0k0?ooo`030?l0
003oool0oooo0><0oooo00<00?l00?ooo`3oool0;@3oool00`000000oooo
0?ooo`0]0?ooo`03003o003oool0oooo0480oooo00240?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0>`3oool00`3o0000oooo
0?ooo`3T0?ooo`03003o003oool0oooo02`0oooo00<000000?ooo`3oool0
;03oool00`00o`00oooo0?ooo`130?ooo`00QP3oool00`000000oooo0?oo
o`030?ooo`<00000>`3oool00`3o0000oooo0?ooo`3T0?ooo`03003o003o
ool0oooo02`0oooo00<000000?ooo`3oool0:`3oool00`00o`00oooo0?oo
o`140?ooo`00Q`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo03X0oooo00<0o`000?ooo`3oool0iP3oool00`00o`00oooo0?ooo`0[
0?ooo`030000003oool0oooo02X0oooo00<00?l00?ooo`3oool0A@3oool0
08@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0j
0?ooo`030?l0003oool0oooo0>L0oooo0P00o`0[0?ooo`030000003oool0
oooo02T0oooo00<00?l00?ooo`3oool0AP3oool008D0oooo0P0000050?oo
o`030000003oool0oooo03T0oooo00<0o`000?ooo`3oool0jP3oool00`00
o`00oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<00?l00?oo
o`3oool0A`3oool008`0oooo00<000000?ooo`3oool0>@3oool00`3o0000
oooo0?ooo`3[0?ooo`03003o003oool0oooo02L0oooo00<000000?ooo`3o
ool09P3oool2003o04X0oooo002<0?ooo`030000003oool0oooo03P0oooo
00<0o`000?ooo`3oool0k@3oool00`00o`00oooo0?ooo`0V0?ooo`030000
003oool0oooo02D0oooo00<00?l00?ooo`3oool0BP3oool008`0oooo00<0
00000?ooo`3oool0>03oool00`3o0000oooo0?ooo`3^0?ooo`800?l09P3o
ool00`000000oooo0?ooo`0S0?ooo`800?l0C@3oool008`0oooo00<00000
0?ooo`3oool0>03oool00`3o0000oooo0?ooo`3`0?ooo`03003o003oool0
oooo02<0oooo00<000000?ooo`3oool08P3oool00`00o`00oooo0?ooo`1=
0?ooo`00S03oool00`000000oooo0?ooo`0g0?ooo`030?l0003oool0oooo
0?80oooo00<00?l00?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?oo
o`03003o003oool0oooo04h0oooo002<0?ooo`030000003oool0oooo03L0
oooo00<0o`000?ooo`3oool0l`3oool00`00o`00oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0200oooo00<00?l00?ooo`3oool0C`3oool008`0oooo
00<000000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`3e0?ooo`800?l0
8@3oool00`000000oooo0?ooo`0N0?ooo`800?l0DP3oool008`0oooo00<0
00000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`3g0?ooo`800?l07`3o
ool00`000000oooo0?ooo`0L0?ooo`800?l0E03oool008`0oooo00<00000
0?ooo`3oool0=@3oool00`3o0000oooo0?ooo`3j0?ooo`800?l07@3oool0
0`000000oooo0?ooo`0J0?ooo`800?l0EP3oool008`0oooo00<000000?oo
o`3oool0=@3oool00`3o0000oooo0?ooo`3l0?ooo`800?l06`3oool00`00
0000oooo0?ooo`0H0?ooo`800?l0F03oool008`0oooo00<000000?ooo`3o
ool0=03oool00`3o0000oooo0?ooo`3o0?ooo`800?l06@3oool00`000000
oooo0?ooo`0F0?ooo`800?l0FP3oool008`0oooo00<000000?ooo`3oool0
=03oool00`3o0000oooo0?ooo`3o0?ooo`80oooo0`00o`0F0?ooo`030000
003oool0oooo01<0oooo0`00o`1L0?ooo`00S03oool00`000000oooo0?oo
o`0c0?ooo`030?l0003oool0oooo0?l0oooo1P3oool3003o01<0oooo00<0
00000?ooo`3oool0403oool3003o05l0oooo002<0?ooo`030000003oool0
oooo0380oooo00<0o`000?ooo`3oool0o`3oool:0?ooo`@00?l03`3oool0
0`000000oooo0?ooo`0=0?ooo`<00?l0HP3oool008`0oooo00<000000?oo
o`3oool0<P3oool00`3o0000oooo0?ooo`3o0?ooo`h0oooo1000o`0;0?oo
o`030000003oool0oooo00P0oooo1@00o`1U0?ooo`00S03oool00`000000
oooo0?ooo`0a0?ooo`030?l0003oool0oooo0?l0oooo4`3ooolF003o06X0
oooo002<0?ooo`030000003oool0oooo0340oooo00<0o`000?ooo`3oool0
o`3ooolN0?ooo`030000003oool0oooo0780oooo002<0?ooo`030000003o
ool0oooo0300oooo00<0o`000?ooo`3oool0o`3ooolO0?ooo`030000003o
ool0oooo0780oooo002<0?ooo`030000003oool0oooo02l0oooo00<0o`00
0?ooo`3oool0o`3ooolP0?ooo`030000003oool0oooo0780oooo002<0?oo
o`030000003oool0oooo02h0oooo00<0o`000?ooo`3oool0o`3ooolQ0?oo
o`030000003oool0oooo0780oooo002<0?ooo`030000003oool0oooo02d0
oooo00<0o`000?ooo`3oool0o`3ooolR0?ooo`030000003oool0oooo0780
oooo002<0?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`3oool0
o`3ooolS0?ooo`030000003oool0oooo0780oooo002<0?ooo`030000003o
ool0oooo02/0oooo00<0o`000?ooo`3oool0o`3ooolT0?ooo`030000003o
ool0oooo0780oooo002<0?ooo`030000003oool0oooo02X0oooo00<0o`00
0?ooo`3oool0o`3ooonJ0?ooo`00S03oool00`000000oooo0?ooo`0Y0?oo
o`030?l0003oool0oooo0?l0ooooV`3oool008`0oooo00<000000?ooo`3o
ool09`3oool20?l00?l0ooooWP3oool008`0oooo00<000000?ooo`3oool0
903oool30?l00?l0ooooX03oool008`0oooo00<000000?ooo`3oool07@3o
ool70?l00?l0ooooX`3oool008H0oooo0`0000030?ooo`030000003oool0
oooo01<0oooo2P3o003o0?ooocH0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`1X0?ooo`00Q`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00`0oooo1`3o003o0?ooocl0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`1W0?ooo`00Q03oool5000000<0
oooo3`3o003o0?ooocT0oooo0`0000001`3oool000000000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`@00000103oool0
0`000000oooo0?ooo`1V0?ooo`00Q03oool010000000oooo0?ooo`00003o
0?ooodd0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool0IP3oool008D0oooo00<000000?ooo`000000
o`3ooom=0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo00000005
0?ooo`030000003oool0oooo06H0oooo00260?ooo`800000o`3ooom=0?oo
o`030000003oool0oooo00<0000000<0oooo0000003oool00P3oool00`00
0000oooo0?ooo`020?ooo`@00000103oool00`000000oooo0?ooo`1V0?oo
o`00o`3ooooE0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1W0?ooo`00o`3ooooD0?ooo`<00000
2`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06P0oooo
003o0?ooool0ooooE`3oool00?l0ooooo`3ooomG0?ooo`00o`3ooooo0?oo
oeL0oooo002:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0o`3oooo00?ooo`00R@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0?l0oooo_`3oool00840oooo0P0000000`3oool000000000
00020?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003o
ool0oooo0?l0oooo_P3oool00840oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?l0oooo_P3oool00880oooo0`00
00030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool000000?l0oooo`03oool00880oooo00<000000?ooo`000000
0`3oool010000000oooo0?ooo`3oool6000000<0oooo00<000000?ooo`3o
ool0o`3ooonn0?ooo`00P`3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00003o0?oo
ol40oooo00220?ooo`8000001P3oool010000000oooo0?ooo`3oool30000
0080oooo00<000000?ooo`3oool0o`3oooo00?ooo`00o`3ooooo0?oooeL0
oooo003o0?ooool0ooooE`3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{597, 183},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Figure 9.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "Amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  ", and zero-pole plot for  ",
  Cell[BoxData[
      \(y[n]\  = \ 
        x[n] + \(1\/6\) \((3 + \ 4 \@ 2)\) 
            y[n - 1] - \(1\/9\) \((4 + 3 \@ 2)\) y[n - 2] + \(2\/9\) 
            y[n - 3]\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.25.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["9.25 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  We use the property ",
  StyleBox["(ii)",
    FontColor->RGBColor[0, 0, 1]],
  " boosting up filter.  The conjugate pair of poles  ",
  Cell[BoxData[
      \(2\/3\)]],
  Cell[BoxData[
      RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        "  ", \(2\/3\), \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/
                4\)\)}]]],
  "  lie on the circle  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = 2\/3\)]],
  ".  We then calculate \n\n\t\t\t",
  Cell[BoxData[{
      \(\((\ \(z - \(2\/3\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\)\/z)\
\) \((\ \(z - \(2\/3\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\)\)\/z)\
\)\ \ \  = \ \ \(1\/z\^2\) \((z - \(\@2\/3\) \((1 + \[ImaginaryI])\))\)\ \((z \
- \(\@2\/3\) \((1 - \[ImaginaryI])\))\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \)\(\(1\/z\^2\) \((\ 
            z\^2 - \(2\/3\) \(\@2\) z + 4\/9)\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1\ \  - \ \ \(2\/3\
\) \(\@2\) z\^\(-1\)\ \  + \ \ \(4\/9\) z\^\(-2\)\)\)\)}]]
}], "Text"],

Cell[TextData[{
  "There are no zeros, so the transfer function is  ",
  Cell[BoxData[
      \(H \((z)\)\  = \ 
        b\_0\/\(1 + \(a\_1\) z\^\(-1\) + \(a\_2\) z\^\(-2\)\)\)]],
  " and we see that  ",
  Cell[BoxData[
      RowBox[{\(b\_0 = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(a\_1\), "=", 
          RowBox[{
            RowBox[{\(-\(2\/3\)\), \(\@2\), "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(a\_2\)}], 
            "=", \(4\/9\)}]}]}]]],
  ".  The desired filter for (a) is \n\n\t\t\t",
  Cell[BoxData[{
      \(y[n]\ \  = \ \ b\_0\ x[n]\  - \ a\_1\ y[n - 1]\  - \ 
          a\_2\ y[n - 2]\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(y[
          n]\ \  = \ \ x[n]\  + \ \(2\/3\) \@2\ y[n - 1]\  - \ \(4\/9\) 
            y[n - 2]\)}]],
  " \n\nObserve that this is the same filter that was investigated in Example \
9.22. "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 9.17.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The transfer function can be written  ",
  Cell[BoxData[
      \(H[z] = z\^2\/\(z\^2 - \(2\/3\) \(\@2\) z + 4\/9\)\)]],
  " and has a zero of order two at the origin, and two poles inside the unit \
circle.  The arguments of the poles  ",
  Cell[BoxData[
      \(\(2\/3\) \[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ \
\[Pi]/4\)\)]],
  " correspond to frequencies that are boosted up by the filter. The \
situation is illustrated in Figure 9.11."
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 9.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "Amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  ", and zero-pole plot for  ",
  Cell[BoxData[
      \(y[n] = x[n] + \(2\/3\) \@2\ y[n - 1] - \(4\/9\) y[n - 2]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["9.25 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  For part (b) use the additional pole at  ",
  Cell[BoxData[
      \(\(1\/2\) \[ExponentialE]\^\(\[ImaginaryI]\ 0\) = 1\/2\)]],
  "  and calculate \n\n\t\t\t",
  Cell[BoxData[{
      \(\((\ \(z - \(2\/3\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\)\/z)\
\) \((\ \(z - \(2\/3\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\)\)\/z)\
\) \((\ \(z - 1\/2\)\/z)\)\ \ \[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\ \ \)\(\((\ 
            1 - \(2\/3\) \(\@2\) z\^\(-1\) + \(4\/9\) 
                z\^\(-2\))\)\ \((1 - \(1\/2\) 
                z\^\(-1\))\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\ \ \)\(1\  - \ \(1\/6\) \((3 + \ 4 \@ 2)\) 
            z\^\(-1\)\  + \ \(1\/9\) \((4 + 3 \@ 2)\) 
            z\^\(-2\)\  - \ \(2\/9\) z\^\(-3\)\)\)\)}]],
  "  \n\nThe transfer function is  ",
  Cell[BoxData[
      \(\(\(H \((z)\)\)\(\ \)\(=\)\(\ \)\(b\_0\/\(1 + \(a\_1\) 
                z\^\(-1\) + \(a\_2\) z\^\(-2\) + \(a\_3\) 
                z\^\(-3\)\)\)\(\ \)\)\)]],
  " where  ",
  Cell[BoxData[
      RowBox[{\(b\_0 = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          
          "StrikeThrough"->
            False}], \(a\_1 = \(-\(1\/6\)\) \((3 + \ 4 \@ 2)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(a\_2\), "=", 
          RowBox[{
            RowBox[{\(1\/9\), \((4 + 3 \@ 2)\), "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(a\_3\)}], 
            "=", \(-\(2\/9\)\)}]}]}]]],
  ".  The desired filter for (b) is \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(y[n]\ \  = \ \ b\_0\ x[n] - a\_1\ y[n - 1] - a\_2\ y[n - 2] - 
          a\_3\ y[n - 2]\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(y[
          n]\ \  = \ \ x[n] + \(1\/6\) \((3 + \ 4 \@ 2)\) 
            y[n - 1] - \(1\/9\) \((4 + 3 \@ 2)\) y[n - 2] + \(2\/9\) 
            y[n - 3]\)}]],
  " "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 9.18.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The transfer function can be written  ",
  Cell[BoxData[
      \(H[z] = 
        z\^3\/\(\(\ \)\(z\^3 - \(1\/6\) \((3 + \ 4 \@ 2)\) z\^2 + \(1\/9\) \
\((4 + 3 \@ 2)\) z - 2\/9\)\)\)]],
  " and has a zero of order three at the origin, and three poles inside the \
unit circle.  The arguments of the poles  ",
  Cell[BoxData[
      \(\(2\/3\) \[ExponentialE]\^\(\[ImaginaryI]*0\), \(2\/3\) \
\[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ \[Pi]/4\)\)]],
  " correspond to frequencies that are boosted up by the filter. The \
situation is illustrated in Figure 9.12. "
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 9.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "Amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  ", and zero-pole plot for  ",
  Cell[BoxData[
      \(y[n] = 
        x[n] + \(1\/6\) \((3 + \ 4 \@ 2)\) 
            y[n - 1] - \(1\/9\) \((4 + 3 \@ 2)\) y[n - 2] + \(2\/9\) 
            y[n - 3]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Background for the z-transform and its application for solving difference \
equations can be found in the book.\n\n",
  StyleBox[ButtonBox["Complex Analysis for Mathematics and Engineering",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.25.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["9.25 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Design a filter with poles  ",
  Cell[BoxData[
      \(2\/3\)]],
  Cell[BoxData[
      RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        "  ", \(2\/3\), \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/
                4\)\)}]]],
  "  for boosting up signals near ",
  Cell[BoxData[
      \(cos \((\(\[Pi]\/4\) n)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\(\[Pi]\/4\) n)\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(G[
          z_] = \((\(z - \(2\/3\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\
\)\/z)\) \((\(z - \(2\/3\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\)\)\
\/z)\)\ ;\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<H[z] = 1/(\!\(\(z - \(2\/3\) \[ExponentialE]\^\(\
\[ImaginaryI]\[Pi]/4\)\)\/z\))(\!\(\(z - \(2\/3\) \[ExponentialE]\^\(\(-\
\[ImaginaryI]\[Pi]\)/4\)\)\/z\))\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", 1/G[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(G[z_] = ComplexExpand[G[z]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", 1/G[z]\ ];\)\)}], "Input"],

Cell[TextData[{
  "There are no zeros, so the transfer function is  ",
  Cell[BoxData[
      \(H \((z)\)\  = \ 
        b\_0\/\(1 + \(a\_1\) z\^\(-1\) + \(a\_2\) z\^\(-2\)\)\)]],
  " and we see that  ",
  Cell[BoxData[
      RowBox[{\(b\_0 = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(a\_1\), "=", 
          RowBox[{
            RowBox[{\(-\(2\/3\)\), \(\@2\), "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(a\_2\)}], 
            "=", \(4\/9\)}]}]}]]],
  ".  \nThe desired filter is  ",
  Cell[BoxData[
      \(y[n]\  = \ 
        x[n]\  + \ \(2\/3\) \(\@2\) y[n - 1]\  - \(4\/\(\(\ \)\(9\)\)\) 
            y[n - 2]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 9.17.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The transfer function can be written  ",
  Cell[BoxData[
      \(H[z] = z\^2\/\(z\^2 - \(2\/3\) \(\@2\) z + 4\/9\)\)]],
  " and has a zero of order two at the origin, and two poles inside the unit \
circle.  The arguments of the poles  ",
  Cell[BoxData[
      \(\(2\/3\) \[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ \
\[Pi]/4\)\)]],
  " correspond to frequencies that are boosted up by the filter. The \
situation is illustrated in Figure 9.11."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(H[z_] = 
        1\/\(1 - \(2\/3\) \(\@2\) z\^\(-1\) + \(4\/9\) z\^\(-2\)\);\)\ \), "\n\
", 
    \(\(A[\[Theta]_] = 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]];\)\), "\
\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[A[\[Theta]], {\[Theta], 0, \[Pi]}, 
          PlotRange \[Rule] {{0, \[Pi]}, {0, 2.6}}, 
          Ticks \[Rule] {Range[0, \[Pi], \[Pi]\/4], Range[0, 2.5, 0.5]}, 
          AxesLabel \[Rule] {"\<\[Theta]\>", "\<A(\[Theta])\>"}, 
          PlotStyle \[Rule] Red];\)\), "\n", 
    \(\(Print["\<The amplitude response\>"];\)\), "\n", 
    \(\(Print[\*"\"\<A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the filter\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = y[n] = x[n] + \!\(2\/3\)\!\(\@2\)y[n-1] -\!\(4\/9\
\)y[n-2]\>\""];\)\ \)}], "Input"],

Cell[BoxData[
    \(\(ZeroPolePlot1;\)\)], "Input"],

Cell[TextData[{
  StyleBox["Figure 9.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "Amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  ", and zero-pole plot for  ",
  Cell[BoxData[
      \(y[n] = x[n] + \(2\/3\) \@2\ y[n - 1] - \(4\/9\) y[n - 2]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "We are done with part (a).\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can investigate how this filter work."
}], "Text"],

Cell[BoxData[{
    \(\(Show[gr1, 
        Ticks \[Rule] {{0, \[Pi]\/16, \[Pi]\/2, \(3\ \[Pi]\)\/4, \[Pi]}, 
            Range[0, 2.5, 0.5]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The amplitude response\>"];\)\), "\n", 
    \(\(Print[\*"\"\<A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(\[Pi]\/16\)]  = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]  \[Pi]\/16\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\[Pi]\/16. \) \[ImaginaryI]\)]]\ ];\)\ \), \
"\n", 
    \(\(Print[\*"\"\<A[\!\(\(3  \[Pi]\)\/4\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI] \( 3  \[Pi]\)\/4\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\(3  \[Pi]\)\/4. \) \[ImaginaryI]\)]]\ \
];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<For the filter\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = y[n] = x[n] + \!\(2\/3\)\!\(\@2\)y[n-1] -\!\(4\/9\
\)y[n-2]\>\""];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = 
        Cos[\[Pi]\/16\ n] + 
          Sin[\(3  \[Pi]\)\/4\ n];\)\ \), "\[IndentingNewLine]", 
    \(\(m0 = 65;\)\), "\[IndentingNewLine]", 
    \(\(X1\  = \ N[Table[Cos[\[Pi]\/16\ i], {i, 0, m0}]];\)\), "\n", 
    \(\(X2\  = \ 
        N[Table[Cos[\[Pi]\/16\ i] + Sin[\(3  \[Pi]\)\/4\ i], {i, 0, 
              m0}]];\)\), "\[IndentingNewLine]", 
    \(\(X1 = Join[Table[0, {i, 1, 9}], X1];\)\), "\[IndentingNewLine]", 
    \(\(X2 = Join[Table[0, {i, 1, 9}], X2];\)\), "\n", 
    \(\(Y2 = \(Y1 = Table[0, {i, 0, m0 + 9}]\);\)\), "\n", 
    \(\(For[i = 10, 
        i \[LessEqual] 
          m0 + 10, \(i++\), \[IndentingNewLine]Y1\_\(\(\[LeftDoubleBracket]\)\
\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X1\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  + \ \(2\/3\) 
                  Y1\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\)\  - \(4\/\(\(\ \)\(9\)\)\) 
                  Y1\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\)\ )\)\ ]; \ \[IndentingNewLine]Y2\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X2\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  + \ \(2\/3\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\)\  - \(4\/\(\(\ \)\(9\)\)\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\)\ )\)\ ];\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(X1pts = 
        Transpose[{ticval, 
            Take[X1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(X2pts = 
        Transpose[{ticval, 
            Take[X2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1pts = 
        Transpose[{ticval, 
            Take[Y1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y2pts = 
        Transpose[{ticval, 
            Take[Y2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ListPlot[X1pts, PlotJoined \[Rule] True, PlotStyle \[Rule] {Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ListPlot[X2pts, PlotJoined \[Rule] True, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{0, m0}, {\(-2\), 2}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<n\>", "\<x[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Input signal x[n] = \>", 
        x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        ListPlot[Take[Y1pts, \(-65\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] {Blue}, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr4 = 
        ListPlot[Take[Y2pts, \(-66\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] Red, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr4, PlotRange \[Rule] {{0, m0}, {\(-1.7\), 2.4}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<n\>", "\<y[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Output signal\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = y[n] = x[n] + \!\(2\/3\)\!\(\@2\)y[n-1] -\!\(4\/9\
\)y[n-2]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The  amplitude  responses\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Low  frequency:   A[\!\(\[Pi]\/16\)] = |H[\!\(\
\[ExponentialE]\^\(\(\[Pi]\/16\) \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\[Pi]\/16. \) \[ImaginaryI]\)]]\ ];\)\ \), \
"\n", 
    \(\(Print[\*"\"\<High frequency:  A[\!\(\(3  \[Pi]\)\/4\)] = |H[\!\(\
\[ExponentialE]\^\(\(\(3  \[Pi]\)\/4\) \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\(3  \[Pi]\)\/4. \) \[ImaginaryI]\)]]\ \
];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["9.25 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Include the additional pole at  ",
  Cell[BoxData[
      \(\(1\/2\) \[ExponentialE]\^\(\[ImaginaryI]\ 0\) = 1\/2\)]],
  " to the filter design in (a) so that it also boosts up low frequency \
signals."
}], "Text"],

Cell[BoxData[{
    \(\(G[
          z_] = \((\ \(z - \(2\/3\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\
\)\)\/z)\) \((\ \(z - \(2\/3\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\
\)\)\/z)\) \((\ \(z - \(1\/2\) \[ExponentialE]\^\(0\ \[ImaginaryI]\)\)\/z)\)\ \
;\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<H[z] = ( \!\(\(z - \(2\/3\) \[ExponentialE]\^\(\
\[ImaginaryI]\[Pi]/4\)\)\/z\))( \!\(\(z - \(2\/3\) \[ExponentialE]\^\(\(-\
\[ImaginaryI]\[Pi]\)/4\)\)\/z\))( \!\(\(z - \(1\/2\) \[ExponentialE]\^\(0  \
\[ImaginaryI]\)\)\/z\))\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", 1/G[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(G[z_] = ComplexExpand[G[z]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", 1/G[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(G[z_] = Collect[G[z], z];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", 1/G[z]\ ];\)\)}], "Input"],

Cell[TextData[{
  "There are no zeros, so the transfer function is  ",
  Cell[BoxData[
      \(\(\(H \((z)\)\)\(\ \)\(=\)\(\ \)\(b\_0\/\(1 + \(a\_1\) 
                z\^\(-1\) + \(a\_2\) z\^\(-2\) + \(a\_3\) 
                z\^\(-3\)\)\)\(\ \)\)\)]],
  " where  ",
  Cell[BoxData[
      RowBox[{\(b\_0 = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          
          "StrikeThrough"->
            False}], \(a\_1 = \(-\(1\/6\)\) \((3 + \ 4 \@ 2)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(a\_2\), "=", 
          RowBox[{
            RowBox[{\(1\/9\), \((4 + 3 \@ 2)\), "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(a\_3\)}], 
            "=", \(-\(2\/9\)\)}]}]}]]],
  ".  \nThe desired filter is ",
  Cell[BoxData[
      \(y[
          n]\ \  = \ \ x[n] + \(1\/6\) \((3 + \ 4 \@ 2)\) 
            y[n - 1] - \(1\/9\) \((4 + 3 \@ 2)\) y[n - 2] + \(2\/9\) 
            y[n - 3]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 9.18.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The transfer function can be written  ",
  Cell[BoxData[
      \(H[z] = 
        z\^3\/\(\(\ \)\(z\^3 - \(1\/6\) \((3 + \ 4 \@ 2)\) z\^2 + \(1\/9\) \
\((4 + 3 \@ 2)\) z - 2\/9\)\)\)]],
  " and has a zero of order three at the origin, and three poles inside the \
unit circle.  The arguments of the poles  ",
  Cell[BoxData[
      \(\(2\/3\) \[ExponentialE]\^\(\[ImaginaryI]*0\), \(2\/3\) \
\[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ \[Pi]/4\)\)]],
  " correspond to frequencies that are boosted up by the filter. The \
situation is illustrated in Figure 9.12. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(H[z_] = 
        1\/\(\(\ \)\(1 - \(1\/6\) \((3 + \ 4 \@ 2)\) z\^\(-1\) + \(1\/9\) \
\((4 + 3 \@ 2)\) z\^\(-2\) - \(2\/9\) z\^\(-3\)\)\);\)\ \), "\n", 
    \(\(A[\[Theta]_] = 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]];\)\), "\
\[IndentingNewLine]", 
    \(\(gr2 = 
        Plot[A[\[Theta]], {\[Theta], 0, \[Pi]}, 
          PlotRange \[Rule] {{0, \[Pi]}, {0, 4}}, 
          Ticks \[Rule] {Range[0, \[Pi], \[Pi]\/4], Range[0, 4, 1]}, 
          AxesLabel \[Rule] {"\<\[Theta]\>", "\<A(\[Theta])\>"}, 
          PlotStyle \[Rule] Red];\)\), "\n", 
    \(\(Print["\<The amplitude response\>"];\)\), "\n", 
    \(\(Print[\*"\"\<A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the filter\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = x[n] + \!\(1\/6\)(3+ 4\!\(\@2\))y[n-1] - \!\(1\/9\
\)(4+3\!\(\@2\))y[n-2] + \!\(2\/9\)y[n-3]\>\""];\)\ \)}], "Input"],

Cell[BoxData[
    \(\(ZeroPolePlot1;\)\)], "Input"],

Cell[TextData[{
  StyleBox["Figure 9.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "Amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  ", and zero-pole plot for  ",
  Cell[BoxData[
      \(y[n] = 
        x[n] + \(1\/6\) \((3 + \ 4 \@ 2)\) 
            y[n - 1] - \(1\/9\) \((4 + 3 \@ 2)\) y[n - 2] + \(2\/9\) 
            y[n - 3]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "We are done with part (b).\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can investigate how this filter work."
}], "Text"],

Cell[BoxData[{
    \(\(Show[gr2, 
        Ticks \[Rule] {{0, \[Pi]\/16, \[Pi]\/2, \(3\ \[Pi]\)\/4, \[Pi]}, 
            Range[0, 4, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The amplitude response\>"];\)\), "\n", 
    \(\(Print[\*"\"\<A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(\[Pi]\/16\)]  = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]  \[Pi]\/16\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\[Pi]\/16. \) \[ImaginaryI]\)]]\ ];\)\ \), \
"\n", 
    \(\(Print[\*"\"\<A[\!\(\(3  \[Pi]\)\/4\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI] \( 3  \[Pi]\)\/4\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\(3  \[Pi]\)\/4. \) \[ImaginaryI]\)]]\ \
];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<For the filter\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = x[n] + \!\(1\/6\)(3+ 4\!\(\@2\))y[n-1] - \!\(1\/9\
\)(4+3\!\(\@2\))y[n-2] + \!\(2\/9\)y[n-3]\>\""];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = 
        Cos[\[Pi]\/16\ n] + 
          Sin[\(3  \[Pi]\)\/4\ n];\)\ \), "\[IndentingNewLine]", 
    \(\(m0 = 65;\)\), "\[IndentingNewLine]", 
    \(\(X1\  = \ N[Table[Cos[\[Pi]\/16\ i], {i, 0, m0}]];\)\), "\n", 
    \(\(X2\  = \ 
        N[Table[Cos[\[Pi]\/16\ i] + Sin[\(3  \[Pi]\)\/4\ i], {i, 0, 
              m0}]];\)\), "\[IndentingNewLine]", 
    \(\(X1 = Join[Table[0, {i, 1, 9}], X1];\)\), "\[IndentingNewLine]", 
    \(\(X2 = Join[Table[0, {i, 1, 9}], X2];\)\), "\n", 
    \(\(Y2 = \(Y1 = Table[0, {i, 0, m0 + 9}]\);\)\), "\[IndentingNewLine]", 
    \(\(For[i = 10, 
        i \[LessEqual] 
          m0 + 10, \(i++\), \[IndentingNewLine]Y1\_\(\(\[LeftDoubleBracket]\)\
\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X1\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  + \ \(1\/6\) \((3 + \ 4 \@ 2)\) 
                  Y1\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\)\  - \ \(1\/9\) \((4 + 3 \@ 2)\) 
                  Y1\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\)\  + \ \(2\/9\) 
                  Y1\_\(\(\[LeftDoubleBracket]\)\(i - 3\)\(\
\[RightDoubleBracket]\)\))\)\ ]; \ \[IndentingNewLine]Y2\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X2\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  + \ \(1\/6\) \((3 + \ 4 \@ 2)\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\)\  - \ \(1\/9\) \((4 + 3 \@ 2)\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\)\  + \ \(2\/9\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 3\)\(\
\[RightDoubleBracket]\)\))\)\ ];\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(X1pts = 
        Transpose[{ticval, 
            Take[X1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(X2pts = 
        Transpose[{ticval, 
            Take[X2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1pts = 
        Transpose[{ticval, 
            Take[Y1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y2pts = 
        Transpose[{ticval, 
            Take[Y2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ListPlot[X1pts, PlotJoined \[Rule] True, PlotStyle \[Rule] {Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ListPlot[X2pts, PlotJoined \[Rule] True, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{0, m0}, {\(-2\), 2}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<n\>", "\<x[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Input signal x[n] = \>", 
        x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        ListPlot[Take[Y1pts, \(-65\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] {Blue}, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr4 = 
        ListPlot[Take[Y2pts, \(-66\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] Red, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr4, PlotRange \[Rule] {{0, m0}, {\(-4.2\), 4.5}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-4\), 4, 1]}, 
        AxesLabel \[Rule] {"\<n\>", "\<y[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Output signal\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = x[n] + \!\(1\/6\)(3+ 4\!\(\@2\))y[n-1] - \!\(1\/9\
\)(4+3\!\(\@2\))y[n-2] + \!\(2\/9\)y[n-3]\>\""];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The  amplitude  responses\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Low  frequency:   A[\!\(\[Pi]\/16\)] = |H[\!\(\
\[ExponentialE]\^\(\(\[Pi]\/16\) \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\[Pi]\/16. \) \[ImaginaryI]\)]]\ ];\)\ \), \
"\n", 
    \(\(Print[\*"\"\<High frequency:  A[\!\(\(3  \[Pi]\)\/4\)] = |H[\!\(\
\[ExponentialE]\^\(\(\(3  \[Pi]\)\/4\) \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\(3  \[Pi]\)\/4. \) \[ImaginaryI]\)]]\ \
];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.26.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Design a combination filter using the zeros ",
  Cell[BoxData[
      RowBox[{\(\[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ \[Pi]/2\)\),
         " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        " ", \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\)\)}]]],
  " for zeroing out ",
  Cell[BoxData[
      RowBox[{\(cos \((\[Pi]\ n)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"cos", \((\(\[Pi]\/2\) n)\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "sin", \((\(\[Pi]\/2\) n)\)}]}]]],
  " and poles ",
  Cell[BoxData[
      \(\(2\/3\) \[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ \
\[Pi]/4\)\)]],
  " boosting up some of the low frequencies."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009E0000]b000`400?l0
0000o`00003oo`3ooooo0?oooeL0oooo003o0?ooool0ooooE`3oool00?l0
ooooo`3ooomG0?ooo`00o`3ooooo0?oooeL0oooo003o0?ooool0ooooE`3o
ool00?l0ooooo`3ooomG0?ooo`00o`3ooooo0?oooeL0oooo003o0?ooool0
ooooE`3oool00?l0oooo<P3oool300000?l0oooo8P3oool00<<0oooo0`00
000b0?ooo`@00000=P3oool00`000000oooo0?ooo`3o0?ooob40oooo0034
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0=03oool5
00000?l0oooo8P3oool00<40oooo1@00000c0?ooo`030000003oool0oooo
03<0oooo00@000000?ooo`3oool00000o`3ooolS0?ooo`00`@3oool01000
0000oooo0?ooo`00000e0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`000000o`3ooolS0?ooo`00`P3oool00`000000oooo0000000c0?oo
o`040000003oool0oooo000003D0oooo0P00003o0?ooob<0oooo00330?oo
o`800000=03oool200000?l0ooooF`3oool00?l0oooo:P3oool>00000003
0?ooo`00000000000?l0oooo703oool00?l0ooooh@3oool00`000000oooo
0?ooo`1b0?ooo`00_`3oool8000002l0oooo2000003R0?ooo`030000003o
ool0oooo0780oooo003o0?ooofH0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1a0?ooo`<0003oM03oool00?l0oooo;@3oool20000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?oo
o`040000003oool0oooo000007<0oooo1@000?mc0?ooo`00o`3oool/0?oo
o`040000003oool0oooo000000D0oooo00@000000?ooo`3oool00000;`3o
ool00`000000oooo0000001/0?ooo`L00?l01@000?l8003o06/0oooo0030
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0000000_0?ooo`030000003oool0
000006L0oooo1@00o`070?ooo`D0003o203oool5003o06H0oooo00310?oo
o`040000003oool0oooo000003<0oooo00@000000?ooo`3oool00000<P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0000002h0oooo1@00
001Q0?ooo`D00?l03@3oool30000o`h0oooo1@00o`1Q0?ooo`00`P3oool0
0`000000oooo0000000d0?ooo`030000003oool0000002l0oooo00@00000
0?ooo`3oool000001@3oool500000940oooo0P00o`0D0?ooo`030000003o
ool0oooo00P0oooo0P0000070?ooo`<00?l0GP3oool00<80oooo00<00000
0?ooo`000000=03oool00`000000oooo0000000`0?ooo`800000V@3oool3
003o01H0oooo00@000000?ooo`3oool0oooo1@0000040?ooo`030000003o
ool0oooo00L0oooo0P00o`1L0?ooo`00`@3oool500000380oooo1@000038
0?ooo`800?l06@3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool02P3oool2003o05X0oooo003o
0?oool@0oooo0P00o`0K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`800?l0F03oool0
0?l0ooooLP3oool3000004d0oooo0P00o`0M0?ooo`030000003oool0oooo
00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000l0oooo0P00
o`1F0?ooo`00S03ooom^000000030?l000000000000006/0000000<0o`00
0?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000004X0oooo0P00
o`0O0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0@0?ooo`800?l0E03oool008`0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`@0o`00=03o
ool00`000000oooo0?ooo`0`0?ooo`D0o`001`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo04D0oooo0P00o`0Q0?ooo`030000003o
ool0oooo0080oooo1@00000G0?ooo`800?l0DP3oool008`0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0b0?ooo`030?l0003oool0
00000080oooo0P3o000b0?ooo`030000003oool0oooo02T0oooo1`3o0004
0?ooo`030000003oool0oooo00D0oooo1P0000160?ooo`03003o003oool0
oooo0240oooo00<000000?ooo`3oool0803oool00`00o`00oooo0?ooo`1?
0?ooo`00S03oool00`000000oooo0?ooo`1X0?ooo`030?l0003oool0oooo
00D0oooo0`3o001G0?ooo`@0o`00503oool01@000000oooo0?ooo`3oool0
000004D0oooo00<00?l00?ooo`3oool08P3oool00`000000oooo0?ooo`0Q
0?ooo`03003o003oool0oooo04h0oooo002<0?ooo`030000003oool0oooo
06H0oooo0P3o000;0?ooo`80o`00D03oool50?l001T0oooo0`0000150?oo
o`03003o003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`00
o`00oooo0?ooo`1=0?ooo`00S03oool00`000000oooo0?ooo`1U0?ooo`03
0?l0003oool0oooo00d0oooo0P3o00190?ooo`D0o`00I03oool2003o02H0
oooo00<000000?ooo`3oool08`3oool2003o04d0oooo002<0?ooo`030000
003oool0oooo06@0oooo00<0o`000?ooo`3oool0403oool20?l00400oooo
1`3o001X0?ooo`03003o003oool0oooo02H0oooo00<000000?ooo`3oool0
9@3oool00`00o`00oooo0?ooo`1:0?ooo`00S03oool00`000000oooo0?oo
o`1S0?ooo`030?l0003oool0oooo01<0oooo103o000c0?ooo`T0o`00KP3o
ool00`00o`00oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo0P00
o`1:0?ooo`00S03oool00`000000oooo0?ooo`1R0?ooo`030?l0003oool0
oooo01P0oooo1@3o000U0?ooo`T0o`00MP3oool00`00o`00oooo0?ooo`0X
0?ooo`030000003oool0oooo02P0oooo00<00?l00?ooo`3oool0A`3oool0
08`0oooo00<000000?ooo`3oool0H@3oool00`3o0000oooo0?ooo`0N0?oo
o`L0o`00603oool60?l007d0oooo0P00o`0[0?ooo`030000003oool0oooo
02T0oooo00<00?l00?ooo`3oool0AP3oool008`0oooo00<000000?ooo`3o
ool0H03oool00`3o0000oooo0?ooo`0V0?oooaP0o`00PP3oool00`00o`00
oooo0?ooo`0[0?ooo`030000003oool0oooo02X0oooo00<00?l00?ooo`3o
ool0A@3oool008`0oooo00<000000?ooo`3oool0G`3oool00`3o0000oooo
0?ooo`300?ooo`03003o003oool0oooo02`0oooo00<000000?ooo`3oool0
:`3oool00`00o`00oooo0?ooo`140?ooo`00S03oool00`000000oooo0?oo
o`1N0?ooo`030?l0003oool0oooo0<00oooo00<00?l00?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0/0?ooo`03003o003oool0oooo04<0oooo002<
0?ooo`030000003oool0oooo05d0oooo00<0o`000?ooo`3oool0`03oool0
0`00o`00oooo0?ooo`0^0?ooo`030000003oool0oooo02d0oooo00<00?l0
0?ooo`3oool0@P3oool008`0oooo00<000000?ooo`3oool0G03oool00`3o
0000oooo0?ooo`310?ooo`03003o003oool0oooo02h0oooo00<000000?oo
o`3oool0;@3oool00`00o`00oooo0?ooo`120?ooo`00Q03oool5000000<0
oooo00<000000?ooo`3oool0F`3oool00`3o0000oooo0?ooo`310?ooo`03
003o003oool0oooo02l0oooo00<000000?ooo`3oool0;P3oool00`00o`00
oooo0?ooo`110?ooo`00QP3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo05X0oooo00<0o`000?ooo`3oool0`@3oool00`00o`00oooo
0?ooo`0`0?ooo`030000003oool0oooo02l0oooo00<00?l00?ooo`3oool0
@03oool008H0oooo00<000000?ooo`3oool00`3oool3000005T0oooo00<0
o`000?ooo`3oool0`@3oool00`00o`00oooo0?ooo`0a0?ooo`030000003o
ool0oooo0300oooo00<00?l00?ooo`3oool0?`3oool008H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`1H0?ooo`030?l0003oool0
oooo0<40oooo00<00?l00?ooo`3oool0<P3oool00`000000oooo0?ooo`0a
0?ooo`03003o003oool0oooo03h0oooo00260?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0F03oool00`3o0000oooo0?ooo`310?oo
o`03003o003oool0oooo0380oooo00<000000?ooo`3oool0<@3oool00`00
o`00oooo0?ooo`0n0?ooo`00Q@3oool2000000D0oooo00<000000?ooo`3o
ool0E`3oool00`3o0000oooo0?ooo`310?ooo`03003o003oool0oooo03<0
oooo00<000000?ooo`3oool0<P3oool00`00o`00oooo0?ooo`0m0?ooo`00
S03oool00`000000oooo0?ooo`1F0?ooo`030?l0003oool0oooo0<40oooo
00<00?l00?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`03003o
003oool0oooo03`0oooo002<0?ooo`030000003oool0oooo05H0oooo00<0
o`000?ooo`3oool0`@3oool00`00o`00oooo0?ooo`0d0?ooo`030000003o
ool0oooo0280oooo0`0000050?ooo`<000001P3oool00`00o`00oooo0?oo
o`0l0?ooo`00S03oool00`000000oooo0?ooo`1E0?ooo`030?l0003oool0
oooo0<40oooo00<00?l00?ooo`3oool0=@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool0
0`00o`00oooo0?ooo`0k0?ooo`00S03oool00`000000oooo0?ooo`1D0?oo
o`030?l0003oool0oooo0<40oooo00<00?l00?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0J0?ooo`<0o`001P3oool010000000oooo000000000004
0?ooo`030000003oool0oooo00L0oooo00<00?l00?ooo`3oool0>P3oool0
08`0oooo00<000000?ooo`3oool0E03oool00`3o0000oooo0?ooo`310?oo
o`03003o003oool0oooo03H0oooo00<000000?ooo`3oool06@3oool50?l0
00D0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000002P3oool0
0`00o`00oooo0?ooo`0i0?ooo`00S03oool00`000000oooo0?ooo`1C0?oo
o`030?l0003oool0oooo0<40oooo00<00?l00?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0I0?ooo`D0o`001@3oool00`000000oooo0?ooo`020?oo
o`050000003oool000000?ooo`0000002@3oool00`00o`00oooo0?ooo`0i
0?ooo`00S03oool00`000000oooo0?ooo`1C0?ooo`030?l0003oool0oooo
0<40oooo00<00?l00?ooo`3oool0=`3oool00`000000oooo0?ooo`0I0?oo
o`D0o`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02@3oool00`00o`00oooo0?ooo`0h0?ooo`00S03oool00`00
0000oooo0?ooo`1B0?ooo`030?l0003oool0oooo0<40oooo00<00?l00?oo
o`3oool0>03oool00`000000oooo0?ooo`0J0?ooo`<0o`001`3oool20000
0080oooo00<000000?ooo`3oool0303oool00`00o`00oooo0?ooo`0h0?oo
o`00S03oool00`000000oooo0?ooo`1A0?ooo`030?l0003oool0oooo0<80
oooo00<00?l00?ooo`3oool0>03oool00`000000oooo0?ooo`0S0?ooo`80
000000<0oooo0000000000003`3oool00`00o`00oooo0?ooo`0h0?ooo`00
S03oool00`000000oooo0?ooo`1A0?ooo`030?l0003oool0oooo0<40oooo
00<00?l00?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`03003o
003oool0oooo03L0oooo00240?ooo`@00000103oool00`000000oooo0?oo
o`1@0?ooo`030?l0003oool0oooo0<80oooo00<00?l00?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0h0?ooo`03003o003oool0oooo03L0oooo0024
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0D03oool0
0`3o0000oooo0?ooo`320?ooo`03003o003oool0oooo03T0oooo00<00000
0?ooo`3oool0>@3oool00`00o`00oooo0?ooo`0f0?ooo`00Q@3oool00`00
0000oooo0?ooo`040?ooo`<00000C`3oool00`3o0000oooo0?ooo`320?oo
o`03003o003oool0oooo03X0oooo00<000000?ooo`3oool0>@3oool00`00
o`00oooo0?ooo`0f0?ooo`00QP3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo04l0oooo00<0o`000?ooo`3oool0`P3oool00`00o`00
oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<00?l00?ooo`3o
ool0=@3oool008@0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`1>0?ooo`030?l0003oool0oooo0<80oooo00<00?l00?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0j0?ooo`03003o003oool0oooo03D0
oooo00250?ooo`8000001@3oool00`000000oooo0?ooo`1>0?ooo`030?l0
003oool0oooo0<80oooo00<00?l00?ooo`3oool0>`3oool00`000000oooo
0?ooo`0j0?ooo`03003o003oool0oooo03D0oooo002<0?ooo`030000003o
ool0oooo04d0oooo00<0o`000?ooo`3oool0``3oool00`00o`00oooo0?oo
o`0k0?ooo`030000003oool0oooo03/0oooo00<00?l00?ooo`3oool0=03o
ool008`0oooo00<000000?ooo`3oool0C@3oool00`3o0000oooo0?ooo`32
0?ooo`03003o003oool0oooo03`0oooo00<000000?ooo`3oool0>`3oool0
0`00o`00oooo0?ooo`0d0?ooo`00S03oool00`000000oooo0?ooo`1=0?oo
o`030?l0003oool0oooo0<80oooo00<00?l00?ooo`3oool0?03oool00`00
0000oooo0?ooo`0k0?ooo`03003o003oool0oooo03@0oooo002<0?ooo`03
0000003oool0oooo04`0oooo00<0o`000?ooo`3oool0``3oool00`00o`00
oooo0?ooo`0l0?ooo`030000003oool0oooo03/0oooo00<00?l00?ooo`3o
ool0=03oool008`0oooo00<000000?ooo`3oool0C03oool00`3o0000oooo
0?ooo`320?ooo`03003o003oool0oooo03d0oooo00<000000?ooo`3oool0
>`3oool00`00o`00oooo0?ooo`0d0?ooo`00S03oool00`000000oooo0?oo
o`1;0?ooo`030?l0003oool0oooo0<<0oooo00<00?l00?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0l0?ooo`03003o003oool0oooo03<0oooo002<
0?ooo`030000003oool0oooo04/0oooo00<0o`000?ooo`3oool0``3oool0
0`00o`00oooo0?ooo`0m0?ooo`030000003oool0oooo03`0oooo00<00?l0
0?ooo`3oool0<`3oool008`0oooo00<000000?ooo`3oool0BP3oool00`3o
0000oooo0?ooo`340?ooo`03003o003oool0oooo03d0oooo00<000000?oo
o`3oool0?03oool00`00o`00oooo0?ooo`0c0?ooo`00S03oool00`000000
oooo0?ooo`1:0?ooo`030?l0003oool0oooo0<@0oooo00<00?l00?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0l0?ooo`03003o003oool0oooo03<0
oooo002<0?ooo`030000003oool0oooo04X0oooo00<0o`000?ooo`3oool0
``3oool00`00o`00oooo0?ooo`0n0?ooo`030000003oool0oooo03`0oooo
00<00?l00?ooo`3oool0<`3oool008`0oooo00<000000?ooo`3oool0B@3o
ool00`3o0000oooo0?ooo`340?ooo`03003o003oool0oooo03h0oooo00<0
00000?ooo`3oool0?@3oool00`00o`00oooo0?ooo`0b0?ooo`00Q@3oool2
000000D0oooo00<000000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`34
0?ooo`03003o003oool0oooo03h0oooo00<000000?ooo`3oool0?@3oool0
0`00o`00oooo0?ooo`0b0?ooo`00Q03oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0a@3oool0
0`00o`00oooo0?ooo`0n0?ooo`030000003oool0oooo03d0oooo00<00?l0
0?ooo`3oool0<P3oool008H0oooo00<000000?ooo`3oool00`3oool30000
04P0oooo00<0o`000?ooo`3oool0a@3oool00`00o`00oooo0?ooo`0n0?oo
o`030000003oool0oooo03d0oooo00<00?l00?ooo`3oool0<P3oool008L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`170?ooo`03
0?l0003oool0oooo0<H0oooo00<00?l00?ooo`3oool0?P3oool00`000000
oooo0?ooo`0m0?ooo`03003o003oool0oooo0380oooo00240?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0A`3oool00`3o0000
oooo0?ooo`360?ooo`03003o003oool0oooo03h0oooo00<000000?ooo`3o
ool0?@3oool00`00o`00oooo0?ooo`0b0?ooo`00Q@3oool2000000D0oooo
00<000000?ooo`3oool0A`3oool00`3o0000oooo0?ooo`360?ooo`03003o
003oool0oooo03h0oooo00<000000?ooo`3oool0?@3oool00`00o`00oooo
0?ooo`0I0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
3@3oool008`0oooo00<000000?ooo`3oool0AP3oool00`3o0000oooo0?oo
o`370?ooo`03003o003oool0oooo03h0oooo00<000000?ooo`3oool0?@3o
ool00`00o`00oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0303oool008`0oooo00<000000?ooo`3oool0AP3oool0
0`3o0000oooo0?ooo`350?ooo`<0003o?P3oool30?l003l0oooo00<00?l0
0?ooo`3oool02@3oool300000080oooo00<000000?ooo`3oool00`000003
0?ooo`030000003oool0oooo0080oooo100000040?ooo`030000003oool0
oooo00/0oooo002<0?ooo`030000003oool0oooo04H0oooo00<0o`000?oo
o`3oool0a03oool50000oc`000001@3o000n00000003003o000000000000
00D000001@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000004
0?ooo`030000003oool0oooo00/0oooo002<0?ooo`030000003oool0oooo
04D0oooo00<0o`000?ooo`3oool0a@3oool50000oc`0oooo1@3o000n0?oo
o`03003o003oool0oooo00X0oooo0`0000030?ooo`@000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool02`3oool008`0oooo00<000000?ooo`3oool0A@3oool00`3o0000
oooo0?ooo`350?ooo`D0003o?03oool50?l003h0oooo00<00?l00?ooo`3o
ool02P3oool010000000oooo0?ooo`0000030?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`@00000103oool00`000000oooo0?ooo`0;0?oo
o`00S03oool00`000000oooo0?ooo`150?ooo`030?l0003oool0oooo0<H0
oooo0`000?ln0?ooo`<0o`001@3oool3000003L0oooo00<00?l00?ooo`3o
ool02P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0303oool008`0oooo00<000000?ooo`3o
ool0A03oool00`3o0000oooo0?ooo`390?ooo`03003o003oool0oooo00P0
oooo0`00000c0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool5000002d0oooo00<00?l00?ooo`3oool02@3oool4000000`0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`00
S03oool00`000000oooo0?ooo`140?ooo`030?l0003oool0oooo0<T0oooo
00@00?l00?ooo`3oool0oooo1@0000020?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0103oool010000000oooo0000000000050?oo
o`030000003oool0oooo02d0oooo00<00?l00?ooo`3oool0<P3oool008`0
oooo00<000000?ooo`3oool0A03oool00`3o0000oooo0?ooo`390?ooo`03
003o003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo00@0oooo0P0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0;@3oool00`00
o`00oooo0?ooo`0b0?ooo`00S03oool00`000000oooo0?ooo`130?ooo`03
0?l0003oool0oooo0<X0oooo00<00?l00?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000;`3oool00`00o`00oooo0?ooo`0b0?ooo`00QP3oool3000000<0
oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`3:0?ooo`03
003o003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0
000003<0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0;@3oool00`00o`00oooo0?oo
o`0b0?ooo`00Q`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo04<0oooo00<0o`000?ooo`3oool0bP3oool00`00o`00oooo0?ooo`02
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?oo
o`02000002l0oooo00<00?l00?ooo`3oool0<P3oool008@0oooo1@000003
0?ooo`<00000@P3oool00`3o0000oooo0?ooo`3;0?ooo`03003o003oool0
oooo0080oooo1@00000g0?ooo`030000003oool0oooo00@0oooo0P000000
0`3oool000000000000d0?ooo`03003o003oool0oooo0380oooo00240?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0@P3oool0
0`3o0000oooo0?ooo`3;0?ooo`03003o003oool0oooo03h0oooo00<00000
0?ooo`3oool0?03oool00`00o`00oooo0?ooo`0c0?ooo`00Q@3oool00`00
0000oooo000000040?ooo`030000003oool0oooo0480oooo00<0o`000?oo
o`3oool0c03oool00`00o`00oooo0?ooo`0m0?ooo`030000003oool0oooo
03`0oooo00<00?l00?ooo`3oool0<`3oool008H0oooo0P0000040?ooo`03
0000003oool0oooo0480oooo00<0o`000?ooo`3oool0c03oool00`00o`00
oooo0?ooo`0m0?ooo`030000003oool0oooo03`0oooo00<00?l00?ooo`3o
ool0<`3oool008`0oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo
0?ooo`3=0?ooo`03003o003oool0oooo03d0oooo00<000000?ooo`3oool0
?03oool00`00o`00oooo0?ooo`0c0?ooo`00S03oool00`000000oooo0?oo
o`110?ooo`030?l0003oool0oooo0<d0oooo00<00?l00?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0l0?ooo`03003o003oool0oooo03<0oooo002<
0?ooo`030000003oool0oooo0440oooo00<0o`000?ooo`3oool0cP3oool0
0`00o`00oooo0?ooo`0l0?ooo`030000003oool0oooo03/0oooo00<00?l0
0?ooo`3oool0=03oool008`0oooo00<000000?ooo`3oool0@03oool00`3o
0000oooo0?ooo`3?0?ooo`03003o003oool0oooo03`0oooo00<000000?oo
o`3oool0>`3oool00`00o`00oooo0?ooo`0d0?ooo`00S03oool00`000000
oooo0?ooo`100?ooo`030?l0003oool0oooo0<l0oooo00<00?l00?ooo`3o
ool0?03oool00`000000oooo0?ooo`0k0?ooo`03003o003oool0oooo03@0
oooo002<0?ooo`030000003oool0oooo0400oooo00<0o`000?ooo`3oool0
d03oool00`00o`00oooo0?ooo`0k0?ooo`030000003oool0oooo03/0oooo
00<00?l00?ooo`3oool0=03oool008`0oooo00<000000?ooo`3oool0?`3o
ool00`3o0000oooo0?ooo`3A0?ooo`03003o003oool0oooo03/0oooo00<0
00000?ooo`3oool0>`3oool00`00o`00oooo0?ooo`0d0?ooo`00S03oool0
0`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo0=40oooo00<00?l0
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`03003o003oool0
oooo03D0oooo002<0?ooo`030000003oool0oooo03l0oooo00<0o`000?oo
o`3oool0d@3oool00`00o`00oooo0?ooo`0k0?ooo`030000003oool0oooo
03X0oooo00<00?l00?ooo`3oool0=@3oool008`0oooo00<000000?ooo`3o
ool0?P3oool00`3o0000oooo0?ooo`3C0?ooo`03003o003oool0oooo03X0
oooo00<000000?ooo`3oool0>P3oool00`00o`00oooo0?ooo`0e0?ooo`00
Q@3oool2000000D0oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo
0?ooo`3C0?ooo`03003o003oool0oooo03X0oooo00<000000?ooo`3oool0
>@3oool00`00o`00oooo0?ooo`0f0?ooo`00Q03oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool0
e03oool00`00o`00oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo
00<00?l00?ooo`3oool0=P3oool008L0oooo00<000000?ooo`3oool00P3o
ool3000003d0oooo00<0o`000?ooo`3oool0e@3oool00`00o`00oooo0?oo
o`0i0?ooo`030000003oool0oooo03P0oooo00<00?l00?ooo`3oool0=`3o
ool008D0oooo0P0000050?ooo`030000003oool0oooo03d0oooo00<0o`00
0?ooo`3oool0e@3oool00`00o`00oooo0?ooo`0i0?ooo`030000003oool0
oooo0280oooo0`00000C0?ooo`03003o003oool0oooo03L0oooo00250?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?@3oool00`3o
0000oooo0?ooo`3F0?ooo`03003o003oool0oooo03P0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`040?ooo`8000002`3oool00`00
o`00oooo0?ooo`0h0?ooo`00Q@3oool3000000@0oooo00<000000?ooo`3o
ool0?03oool00`3o0000oooo0?ooo`3G0?ooo`03003o003oool0oooo03P0
oooo00<000000?ooo`3oool06P3oool30?l000H0oooo00@000000?ooo`00
000000001@3oool00`000000oooo0?ooo`080?ooo`03003o003oool0oooo
03P0oooo002<0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3o
ool0f03oool00`00o`00oooo0?ooo`0g0?ooo`030000003oool0oooo01T0
oooo1@3o00050?ooo`8000000P3oool01@000000oooo0?ooo`3oool00000
00X0oooo00<00?l00?ooo`3oool0>@3oool008`0oooo00<000000?ooo`3o
ool0?03oool00`3o0000oooo0?ooo`3I0?ooo`03003o003oool0oooo03H0
oooo00<000000?ooo`3oool06@3oool50?l000D0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<00?l00?oo
o`3oool0>@3oool008`0oooo00<000000?ooo`3oool0>`3oool00`3o0000
oooo0?ooo`3J0?ooo`03003o003oool0oooo03H0oooo00<000000?ooo`3o
ool06@3oool50?l000H0oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000203oool00`00o`00oooo0?ooo`0j0?ooo`00S03oool0
0`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo0=/0oooo00<00?l0
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0J0?ooo`<0o`001`3oool2
00000080oooo00@000000?ooo`3oool000002@3oool00`00o`00oooo0?oo
o`0j0?ooo`00S03oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0
oooo0=/0oooo00<00?l00?ooo`3oool0=@3oool00`000000oooo0?ooo`0S
0?ooo`80000000<0oooo000000000000303oool00`00o`00oooo0?ooo`0k
0?ooo`00S03oool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo
0=d0oooo00<00?l00?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?oo
o`03003o003oool0oooo03`0oooo002<0?ooo`030000003oool0oooo03X0
oooo00<0o`000?ooo`3oool0g@3oool00`00o`00oooo0?ooo`0d0?ooo`03
0000003oool0oooo03<0oooo00<00?l00?ooo`3oool0?03oool008`0oooo
00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`3O0?ooo`03003o
003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool00`00o`00oooo
0?ooo`0m0?ooo`00S03oool00`000000oooo0?ooo`0i0?ooo`030?l0003o
ool0oooo0>00oooo00<00?l00?ooo`3oool0<P3oool00`000000oooo0?oo
o`0a0?ooo`03003o003oool0oooo03h0oooo002<0?ooo`030000003oool0
oooo03T0oooo00<0o`000?ooo`3oool0h03oool00`00o`00oooo0?ooo`0b
0?ooo`030000003oool0oooo0340oooo00<00?l00?ooo`3oool0?P3oool0
08`0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`3R0?oo
o`03003o003oool0oooo0340oooo00<000000?ooo`3oool0<03oool00`00
o`00oooo0?ooo`0o0?ooo`00Q03oool3000000D0oooo00<000000?ooo`3o
ool0>03oool00`3o0000oooo0?ooo`3S0?ooo`03003o003oool0oooo0300
oooo00<000000?ooo`3oool0;`3oool00`00o`00oooo0?ooo`100?ooo`00
Q03oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03P0
oooo00<0o`000?ooo`3oool0i03oool00`00o`00oooo0?ooo`0_0?ooo`03
0000003oool0oooo02h0oooo00<00?l00?ooo`3oool0@@3oool008@0oooo
00@000000?ooo`3oool00000103oool3000003L0oooo00<0o`000?ooo`3o
ool0iP3oool00`00o`00oooo0?ooo`0^0?ooo`030000003oool0oooo02d0
oooo00<00?l00?ooo`3oool0@P3oool008@0oooo0`0000050?ooo`030000
003oool0oooo03L0oooo00<0o`000?ooo`3oool0i`3oool00`00o`00oooo
0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<00?l00?ooo`3oool0
@P3oool008D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0g0?ooo`030?l0003oool0oooo0>P0oooo00<00?l00?ooo`3oool0;03o
ool00`000000oooo0?ooo`0/0?ooo`03003o003oool0oooo04<0oooo0025
0?ooo`<00000103oool00`000000oooo0?ooo`0f0?ooo`030?l0003oool0
oooo0>T0oooo00<00?l00?ooo`3oool0;03oool00`000000oooo0?ooo`0[
0?ooo`03003o003oool0oooo04@0oooo002<0?ooo`030000003oool0oooo
03H0oooo00<0o`000?ooo`3oool0jP3oool00`00o`00oooo0?ooo`0[0?oo
o`030000003oool0oooo02X0oooo00<00?l00?ooo`3oool0A@3oool008`0
oooo00<000000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`3[0?ooo`80
0?l0:`3oool00`000000oooo0?ooo`0Y0?ooo`03003o003oool0oooo04H0
oooo002<0?ooo`030000003oool0oooo03D0oooo00<0o`000?ooo`3oool0
kP3oool00`00o`00oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo
00<00?l00?ooo`3oool0A`3oool008`0oooo00<000000?ooo`3oool0=@3o
ool00`3o0000oooo0?ooo`3_0?ooo`03003o003oool0oooo02L0oooo00<0
00000?ooo`3oool09P3oool2003o04X0oooo002<0?ooo`030000003oool0
oooo03@0oooo00<0o`000?ooo`3oool0l@3oool00`00o`00oooo0?ooo`0V
0?ooo`030000003oool0oooo02D0oooo00<00?l00?ooo`3oool0BP3oool0
08`0oooo00<000000?ooo`3oool0=03oool00`3o0000oooo0?ooo`3b0?oo
o`800?l09P3oool00`000000oooo0?ooo`0S0?ooo`800?l0C@3oool008`0
oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`3e0?ooo`03
003o003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`00o`00
oooo0?ooo`1=0?ooo`00S03oool00`000000oooo0?ooo`0c0?ooo`030?l0
003oool0oooo0?H0oooo00<00?l00?ooo`3oool08P3oool00`000000oooo
0?ooo`0Q0?ooo`03003o003oool0oooo04h0oooo002<0?ooo`030000003o
ool0oooo0380oooo00<0o`000?ooo`3oool0n03oool00`00o`00oooo0?oo
o`0Q0?ooo`030000003oool0oooo00L0oooo1@00000D0?ooo`03003o003o
ool0oooo04l0oooo002<0?ooo`030000003oool0oooo0380oooo00<0o`00
0?ooo`3oool0n@3oool2003o0240oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0B0?ooo`800?l0DP3oool008H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0a0?ooo`030?l0003oool0oooo
0?`0oooo0P00o`0O0?ooo`040000003oool0oooo0?ooo`D000000`3oool0
0`000000oooo0?ooo`0@0?ooo`800?l0E03oool008H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0a0?ooo`030?l0003oool0oooo
0?h0oooo0P00o`0M0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0>0?ooo`800?l0EP3oool0
08H0oooo00<000000?ooo`3oool00`3oool300000300oooo00<0o`000?oo
o`3oool0o`3oool20?ooo`800?l06`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool2003o
05P0oooo00270?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0<03oool00`3o0000oooo0?ooo`3o0?ooo`@0oooo0P00o`0I0?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P00000<0?oo
o`800?l0FP3oool008@0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0_0?ooo`030?l0003oool0oooo0?l0oooo1`3oool3003o
01H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000=
0?ooo`<00?l0G03oool008@0oooo100000040?ooo`030000003oool0oooo
02l0oooo00<0o`000?ooo`3oool0o`3oool:0?ooo`<00?l04`3oool00`00
0000oooo0?ooo`020?ooo`D000002@3oool3003o05l0oooo002<0?ooo`03
0000003oool0oooo02h0oooo00<0o`000?ooo`3oool0o`3oool>0?ooo`@0
0?l03@3oool30000o`l0oooo0`00o`1R0?ooo`00S03oool00`000000oooo
0?ooo`0^0?ooo`030?l0003oool0oooo0?l0oooo4P3oool4003o00P0oooo
1@000?l90?ooo`D00?l0I@3oool008`0oooo00<000000?ooo`3oool0;@3o
ool00`3o0000oooo0?ooo`3o0?oooaL0oooo2000o`050000o`T00?l0JP3o
ool008`0oooo00<000000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`3o
0?oooal0oooo1@000?mc0?ooo`00S03oool00`000000oooo0?ooo`0/0?oo
o`030?l0003oool0oooo0?l0oooo8@3oool30000og@0oooo002<0?ooo`03
0000003oool0oooo02`0oooo00<0o`000?ooo`3oool0o`3ooolS0?ooo`03
0000003oool0oooo0780oooo002<0?ooo`030000003oool0oooo02/0oooo
00<0o`000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo0780oooo
002<0?ooo`030000003oool0oooo02/0oooo00<0o`000?ooo`3oool0o`3o
oolT0?ooo`030000003oool0oooo0780oooo002<0?ooo`030000003oool0
oooo02X0oooo00<0o`000?ooo`3oool0o`3ooolU0?ooo`030000003oool0
oooo0780oooo002<0?ooo`030000003oool0oooo02P0oooo0P3o003o0?oo
obP0oooo00<000000?ooo`3oool0LP3oool008`0oooo00<000000?ooo`3o
ool09`3oool00`3o0000oooo0?ooo`3o0?oooid0oooo00250?ooo`800000
1@3oool00`000000oooo0?ooo`0V0?ooo`030?l0003oool0oooo0?l0oooo
WP3oool008@0oooo00@000000?ooo`3oool00000103oool80?l001l0oooo
0P3o003o0?oooj40oooo00240?ooo`040000003oool0oooo000000@0oooo
0`0000050?ooo`T0o`00503oool20?l00?l0ooooX`3oool008D0oooo0P00
00050?ooo`030000003oool0oooo00h0oooo203o00090?ooo`<0o`00o`3o
oonU0?ooo`00Q03oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo01H0oooo2@3o003o0?oooc@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1X0?ooo`00Q@3oool2000000D0oooo00<00000
0?ooo`3oool0o`3ooomB0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0I`3oool008`0oooo00<000000?ooo`3oool0o`3ooom50?oo
o`<0000000L0oooo000000000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool00P3oool4000000@0oooo00<000000?ooo`3oool0IP3o
ool00?l0ooooe@3oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`1V0?ooo`00o`3ooooE0?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000050?ooo`030000003oool0
oooo06H0oooo003o0?ooomD0oooo00<000000?ooo`3oool00`0000000`3o
ool000000?ooo`020?ooo`030000003oool0oooo0080oooo100000040?oo
o`030000003oool0oooo06H0oooo003o0?ooomD0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06L0
oooo003o0?ooom@0oooo0`00000;0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0J03oool00?l0ooooo`3ooomG0?ooo`00o`3ooooo
0?oooeL0oooo003o0?ooool0ooooE`3oool008X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`3o0?oool00oooo00290?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooono0?ooo`00P@3o
ool2000000030?ooo`00000000000080oooo00<000000?ooo`3oool00P3o
ool3000000D0oooo00<000000?ooo`3oool0o`3ooonn0?ooo`00P@3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
o`3ooonn0?ooo`00PP3oool3000000<0oooo00D000000?ooo`3oool0oooo
000000040?ooo`050000003oool0oooo0?ooo`000000o`3oooo00?ooo`00
PP3oool00`000000oooo000000030?ooo`040000003oool0oooo0?ooo`H0
00000`3oool00`000000oooo0?ooo`3o0?oookh0oooo00230?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`04
0000003oool0oooo00000?l0oooo`@3oool00880oooo0P0000060?ooo`04
0000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`3o0?oo
ol00oooo003o0?ooool0ooooE`3oool00?l0ooooo`3ooomG0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{597, 183},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Figure 9.13.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "Amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  ", and zero-pole plot for  ",
  Cell[BoxData[
      \(y[n]\ \  = \ \ x[n] + x[n - 1] + x[n - 2] + x[n - 3] + 
          2\/3\ \@2\ y[n - 1]\  - \ 4\/9\ y[n - 2]\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.26.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "The zeroing out portion of this filter design is similar to the filter in \
Example 9.23 (b) where we showed that \n\n\t\t\t",
  Cell[BoxData[
      \(\((\ \(z - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\)\)\/z)\) \((\ \
\(z - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/2\)\)\/z)\) \((\ \(z - \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\)\)\/z)\)\ \  = \ \ 1 + z\^\(-1\) + 
          z\^\(-2\) + z\^\(-3\)\)]],
  ".  \n\nOf course, we could multiply by the constant ",
  Cell[BoxData[
      \(1\/4\)]],
  " to give this filter a moving average effect on the input signal ",
  Cell[BoxData[
      \(x[n]\)]],
  ".  However for simplicity, we use  ",
  Cell[BoxData[
      \(b\_0 = \(b\_1 = \(b\_2 = \(b\_3 = 1\)\)\)\)]],
  ". in the numerator of the transfer function. "
}], "Text"],

Cell[TextData[{
  "For the boosting out portion of this filter design we choose the one \
developed in Example 9.22 (a):  \n\n\t\t\t",
  Cell[BoxData[
      \(\((\ \(z - \(2\/3\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\)\/z)\
\) \((\ \(z - \(2\/3\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\)\)\/z)\
\)\ \ \  = \ \ 1\  - \ \(2\/3\) \(\@2\) z\^\(-1\)\  + \ \(4\/9\) 
            z\^\(-2\)\)]],
  " \n\nand we will use  ",
  Cell[BoxData[
      RowBox[{\(a\_1\), "=", 
        RowBox[{
          RowBox[{\(-\(2\/3\)\), \(\@2\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(a\_2\)}], 
          "=", \(4\/9\)}]}]]],
  "  in the denominator of the transfer function.  Putting the two parts \
together we obtain\n\n\t\t\t",
  Cell[BoxData[
      \(H \((z)\)\ \  = \ \ \(\(b\_0 + \(b\_1\) z\^\(-1\) + \(b\_2\) \
z\^\(-2\) + \(b\_3\) z\^\(-3\)\)\/\(1 + \(a\_1\) z\^\(-1\) + \(a\_2\) z\^\(-2\
\)\)\ \  = \ \ \(\(\ \)\(1 + z\^\(-1\) + z\^\(-2\) + z\^\(-3\)\)\)\/\(1 - \
2\/3\ \(\@2\) z\^\(-1\) + \(4\/9\) z\^\(-2\)\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "The corresponding filter for this transfer function is \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(y[n]\ \  = \ \ b\_0\ x[n] + b\_1\ x[n - 1] + b\_2\ x[n - 2] + 
          b\_3\ x[n - 3] - a\_1\ y[n - 1] - 
          a\_2\ y[n - 2]\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(y[n]\ \  = \ \ x[n] + x[n - 1] + x[n - 2] + x[n - 3] + 
          2\/3\ \@2\ y[n - 1]\  - \ 4\/9\ y[n - 2]\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 9.19.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The zeros  ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ \[Pi]/2\)\ \ and\
\ \ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\)\)]],
  "  of  ",
  Cell[BoxData[
      \(H \((z)\)\)]],
  " determine which signals are zeroed out and the arguments of the poles ",
  Cell[BoxData[
      \(\(2\/3\) \[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ \
\[Pi]/4\)\)]],
  " of  ",
  Cell[BoxData[
      \(H \((z)\)\)]],
  "point to frequencies that are boosted up by the filter. "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 9.20.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The flat portion of the graph in the interval ",
  Cell[BoxData[
      \(\([0, \[Pi]\/4]\)\)]],
  "  makes this filter more practical for boosting low frequencies than the \
filter in Example 9.22 (a).  "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 9.21.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The higher frequencies in the interval ",
  Cell[BoxData[
      \(\([\[Pi]\/2, \[Pi]]\)\)]],
  " are attenuated more than they are in Example 9.23 (b).  The situation is \
illustrated in Figure 9.13."
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 9.13.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "Amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  ", and zero-pole plot for  ",
  Cell[BoxData[
      \(y[n]\ \  = \ \ x[n] + x[n - 1] + x[n - 2] + x[n - 3] + 
          2\/3\ \@2\ y[n - 1]\  - \ 4\/9\ y[n - 2]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Background for the z-transform and its application for solving difference \
equations can be found in the book.\n\n",
  StyleBox[ButtonBox["Complex Analysis for Mathematics and Engineering",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.26.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Remark 9.19.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The zeros  ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ \[Pi]/2\)\ \ and\
\ \ \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\)\)]],
  "  of  ",
  Cell[BoxData[
      \(H \((z)\)\)]],
  " determine which signals are zeroed out and the arguments of the poles ",
  Cell[BoxData[
      \(\(2\/3\) \[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ \
\[Pi]/4\)\)]],
  " of  ",
  Cell[BoxData[
      \(H \((z)\)\)]],
  "point to frequencies that are boosted up by the filter. "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 9.20.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The flat portion of the graph in the interval ",
  Cell[BoxData[
      \(\([0, \[Pi]\/4]\)\)]],
  "  makes this filter more practical for boosting low frequencies than the \
filter in Example 9.22 (a).  "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark 9.21.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The higher frequencies in the interval ",
  Cell[BoxData[
      \(\([\[Pi]\/2, \[Pi]]\)\)]],
  " are attenuated more than they are in Example 9.23 (b).  The situation is \
illustrated in Figure 9.13."
}], "Text"],

Cell[BoxData[{
    \(\(H[
          z_] = \((\(z - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\)\)\/z)\) \
\((\(z - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/2\)\)\/z)\) \((\(z - \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]\)\)\/z)\);\)\), "\
\[IndentingNewLine]", 
    \(\(G[
          z_] = \((\(z - \(2\/3\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\
\)\/z)\) \((\(z - \(2\/3\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/4\)\)\
\/z)\)\ ;\)\), "\n", 
    \(\(Print[\*"\"\<H[z] = (\!\(\(z - \
\[ExponentialE]\^\(\[ImaginaryI]\[Pi]/2\)\)\/z\))(\!\(\(z - \[ExponentialE]\^\
\(\(-\[ImaginaryI]\[Pi]\)/2\)\)\/z\))(\!\(\(z - \[ExponentialE]\^\(-\
\[ImaginaryI]\[Pi]\)\)\/z\))/(\!\(\(z - \(2\/3\) \[ExponentialE]\^\(\
\[ImaginaryI]\[Pi]/4\)\)\/z\))(\!\(\(z - \(2\/3\) \[ExponentialE]\^\(\(-\
\[ImaginaryI]\[Pi]\)/4\)\)\/z\))\>\""];\)\), "\n", 
    \(\(Print["\<H[z] = \>", H[z]/G[z]\ ];\)\), "\n", 
    \(\(H[z_] = ComplexExpand[H[z]];\)\), "\[IndentingNewLine]", 
    \(\(G[z_] = ComplexExpand[G[z]];\)\), "\n", 
    \(\(Print["\<H[z] = \>", H[z]/G[z]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(H[
          z_] = \(1 + z\^\(-1\) + z\^\(-2\) + z\^\(-3\)\)\/\(1 - 2\/3\ \
\(\@2\) z\^\(-1\) + \(4\/9\) z\^\(-2\)\);\)\ \), "\n", 
    \(\(A[\[Theta]_] = 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]];\)\), "\
\[IndentingNewLine]", 
    \(\(gr3 = 
        Plot[A[\[Theta]], {\[Theta], 0, \[Pi]}, 
          PlotRange \[Rule] {{0, \[Pi]}, {0, 8.3}}, 
          Ticks \[Rule] {Range[0, \[Pi], \[Pi]\/4], Range[0, 8, 1]}, 
          AxesLabel \[Rule] {"\<\[Theta]\>", "\<A(\[Theta])\>"}, 
          PlotStyle \[Rule] Red];\)\), "\n", 
    \(\(Print["\<The amplitude response\>"];\)\), "\n", 
    \(\(Print[\*"\"\<A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the filter\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = x[n]+x[n-1]+x[n-2]+x[n-3] + \
\!\(2\/3\)\!\(\@2\)y[n-1] - \!\(4\/9\)y[n-2]\>\""];\)\ \)}], "Input"],

Cell[BoxData[
    \(\(ZeroPolePlot1;\)\)], "Input"],

Cell[TextData[{
  StyleBox["Figure 9.13.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  "Amplitude response ",
  Cell[BoxData[
      \(A \((\[Theta])\)\)]],
  ", and zero-pole plot for  ",
  Cell[BoxData[
      \(y[n]\ \  = \ \ x[n] + x[n - 1] + x[n - 2] + x[n - 3] + 
          2\/3\ \@2\ y[n - 1]\  - \ 4\/9\ y[n - 2]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can investigate how this filter work."
}], "Text"],

Cell[BoxData[{
    \(\(Show[gr3, 
        Ticks \[Rule] {{0, \[Pi]\/16, \[Pi]\/2, \(3\ \[Pi]\)\/4, \[Pi]}, 
            Range[0, 8, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The amplitude response\>"];\)\), "\n", 
    \(\(Print[\*"\"\<A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(\[Pi]\/16\)]  = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]  \[Pi]\/16\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\[Pi]\/16. \) \[ImaginaryI]\)]]\ ];\)\ \), \
"\n", 
    \(\(Print[\*"\"\<A[\!\(\(3  \[Pi]\)\/4\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI] \( 3  \[Pi]\)\/4\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\(3  \[Pi]\)\/4. \) \[ImaginaryI]\)]]\ \
];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<For the filter\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = x[n]+x[n-1]+x[n-2]+x[n-3] + \!\(2\/3\)\!\(\@2\) \
y[n-1] - \!\(4\/9\)y[n-2]\>\""];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = 
        Cos[\[Pi]\/16\ n] + 
          Sin[\(3  \[Pi]\)\/4\ n];\)\ \), "\[IndentingNewLine]", 
    \(\(m0 = 65;\)\), "\[IndentingNewLine]", 
    \(\(X1\  = \ N[Table[Cos[\[Pi]\/16\ i], {i, 0, m0}]];\)\), "\n", 
    \(\(X2\  = \ 
        N[Table[Cos[\[Pi]\/16\ i] + Sin[\(3  \[Pi]\)\/4\ i], {i, 0, 
              m0}]];\)\), "\[IndentingNewLine]", 
    \(\(X1 = Join[Table[0, {i, 1, 9}], X1];\)\), "\[IndentingNewLine]", 
    \(\(X2 = Join[Table[0, {i, 1, 9}], X2];\)\), "\n", 
    \(\(Y2 = \(Y1 = Table[0, {i, 0, m0 + 9}]\);\)\), "\[IndentingNewLine]", 
    \(\(For[i = 10, 
        i \[LessEqual] 
          m0 + 10, \(i++\), \[IndentingNewLine]Y1\_\(\(\[LeftDoubleBracket]\)\
\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X1\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  + X1\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\[RightDoubleBracket]\)\)\  \
+ X1\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\[RightDoubleBracket]\)\)\  + 
                X1\_\(\(\[LeftDoubleBracket]\)\(i - \
3\)\(\[RightDoubleBracket]\)\)\  + \ \(2\/3\) \(\@2\) 
                  Y1\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\)\  - \ \(4\/9\) 
                  Y1\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\)\ )\)\ ]; \ \[IndentingNewLine]Y2\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X2\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  + X2\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\[RightDoubleBracket]\)\)\  \
+ X2\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\[RightDoubleBracket]\)\)\  + 
                X2\_\(\(\[LeftDoubleBracket]\)\(i - \
3\)\(\[RightDoubleBracket]\)\)\  + \ \(2\/3\) \(\@2\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\)\  - \ \(4\/9\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\))\)\ ];\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(X1pts = 
        Transpose[{ticval, 
            Take[X1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(X2pts = 
        Transpose[{ticval, 
            Take[X2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1pts = 
        Transpose[{ticval, 
            Take[Y1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y2pts = 
        Transpose[{ticval, 
            Take[Y2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ListPlot[X1pts, PlotJoined \[Rule] True, PlotStyle \[Rule] {Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ListPlot[X2pts, PlotJoined \[Rule] True, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{0, m0}, {\(-2\), 2}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<n\>", "\<x[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Input signal x[n] = \>", 
        x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        ListPlot[Take[Y1pts, \(-65\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] {Blue}, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr4 = 
        ListPlot[Take[Y2pts, \(-66\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] Red, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr4, PlotRange \[Rule] {{0, m0}, {\(-8.2\), 8.8}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-8\), 8, 1]}, 
        AxesLabel \[Rule] {"\<n\>", "\<y[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Output signal\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = x[n]+x[n-1]+x[n-2]+x[n-3] + \!\(2\/3\)\!\(\@2\) \
y[n-1] - \!\(4\/9\)y[n-2]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The  amplitude  responses\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Low  frequency:   A[\!\(\[Pi]\/16\)] = |H[\!\(\
\[ExponentialE]\^\(\(\[Pi]\/16\) \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\[Pi]\/16. \) \[ImaginaryI]\)]]\ ];\)\ \), \
"\n", 
    \(\(Print[\*"\"\<High frequency:  A[\!\(\(3  \[Pi]\)\/4\)] = |H[\!\(\
\[ExponentialE]\^\(\(\(3  \[Pi]\)\/4\) \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\(3  \[Pi]\)\/4. \) \[ImaginaryI]\)]]\ \
];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Low Frequency Filter",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe previous examples emphasize high frequency filters.  To boost up \
high frequencies place the poles near the higher frequencies. The following \
example is similar to Example 9.25.  The poles have been changed from  ",
  Cell[BoxData[
      RowBox[{\(\(2\/3\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/4\)\), " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(2\/3\), \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/
                  4\)\), "  ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          "  ", \(1\/2\), \(\[ExponentialE]\^\(\[ImaginaryI]\ 0\)\)}]}]]],
  "  to ",
  Cell[BoxData[
      RowBox[{\(\(2\/3\) \[ExponentialE]\^\(\[ImaginaryI]\ 3  \[Pi]/4\)\), 
        " ", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(2\/3\), \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 3  \[Pi]/
                  4\)\), "  ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          "  ", \(1\/2\), \(\[ExponentialE]\^\(\[ImaginaryI]\ \
\[Pi]\)\)}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Extra Example 1 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Design a filter with poles  ",
  Cell[BoxData[
      RowBox[{\(2\/3\), \(\[ExponentialE]\^\(\[ImaginaryI]\ 3  \[Pi]/4\)\), "  ",
         
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        "  ", \(2\/3\), \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 3  \[Pi]/
                4\)\)}]]],
  "  for boosting up signals near ",
  Cell[BoxData[
      \(cos \((\(\(3  \[Pi]\)\/4\) n)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\(\(3  \[Pi]\)\/4\) n)\)\)]],
  ".\n\n",
  StyleBox["1 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Include the additional pole at  ",
  Cell[BoxData[
      \(\(1\/2\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\) = \
\(-\(1\/2\)\)\)]],
  " to the filter design in (a) so that it also boosts up high frequency \
signals."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["1 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Design a filter with poles  ",
  Cell[BoxData[
      RowBox[{\(2\/3\), \(\[ExponentialE]\^\(\[ImaginaryI]\ 3  \[Pi]/4\)\), "  ",
         
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        "  ", \(2\/3\), \(\[ExponentialE]\^\(\(-\[ImaginaryI]3\)\ \[Pi]/
                4\)\)}]]],
  "  for boosting up signals near ",
  Cell[BoxData[
      \(cos \((\(\(3  \[Pi]\)\/4\) n)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((\(\(3  \[Pi]\)\/4\) n)\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(G[
          z_] = \((\(z - \(2\/3\) \[ExponentialE]\^\(\[ImaginaryI]\ 3\ \
\[Pi]/4\)\)\/z)\) \((\(z - \(2\/3\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 3  \
\[Pi]/4\)\)\/z)\)\ ;\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<H[z] = 1/(\!\(\(z - \(2\/3\) \[ExponentialE]\^\(\
\[ImaginaryI]3\\\ \[Pi]/4\)\)\/z\))(\!\(\(z - \(2\/3\) \[ExponentialE]\^\(\(-\
\[ImaginaryI]3\)\\\ \[Pi]/4\)\)\/z\))\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", 1/G[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(G[z_] = ComplexExpand[G[z]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", 1/G[z]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(H[z_] = 
        1\/\(1 + \(2\/3\) \(\@2\) z\^\(-1\) + \(4\/9\) z\^\(-2\)\);\)\ \), "\n\
", 
    \(\(A[\[Theta]_] = 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]];\)\), "\
\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[A[\[Theta]], {\[Theta], 0, \[Pi]}, 
          PlotRange \[Rule] {{0, \[Pi]}, {0, 2.6}}, 
          Ticks \[Rule] {Range[0, \[Pi], \[Pi]\/4], Range[0, 2.5, 0.5]}, 
          AxesLabel \[Rule] {"\<\[Theta]\>", "\<A(\[Theta])\>"}, 
          PlotStyle \[Rule] Red];\)\), "\n", 
    \(\(Print["\<The amplitude response\>"];\)\), "\n", 
    \(\(Print[\*"\"\<A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the filter\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = y[n] = x[n] - \!\(2\/3\)\!\(\@2\)y[n-1] \
-\!\(4\/\(\(\\\ \)\(9\)\)\)y[n-2]\>\""];\)\ \)}], "Input"],

Cell[BoxData[
    \(\(ZeroPolePlot1;\)\)], "Input"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can investigate how this filter work."
}], "Text"],

Cell[BoxData[{
    \(\(Show[gr1, 
        Ticks \[Rule] {{0, \[Pi]\/16, \[Pi]\/2, \(3\ \[Pi]\)\/4, \[Pi]}, 
            Range[0, 2.5, 0.5]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The amplitude response\>"];\)\), "\n", 
    \(\(Print[\*"\"\<A[\[Theta]] = |H[\!\(\[ExponentialE]\^\(\[ImaginaryI]\\\ \
\[Theta]\)\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(\[Pi]\/16\)]  = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]  \[Pi]\/16\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\[Pi]\/16. \) \[ImaginaryI]\)]]\ ];\)\ \), \
"\n", 
    \(\(Print[\*"\"\<A[\!\(\(3  \[Pi]\)\/4\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI] \( 3  \[Pi]\)\/4\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\(3  \[Pi]\)\/4. \) \[ImaginaryI]\)]]\ \
];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<For the filter\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = y[n] = x[n] + \!\(2\/3\)\!\(\@2\)y[n-1] \
-\!\(4\/\(\(\\\ \)\(9\)\)\)y[n-2]\>\""];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = 
        Cos[\[Pi]\/16\ n] + 
          Sin[\(3  \[Pi]\)\/4\ n];\)\ \), "\[IndentingNewLine]", 
    \(\(m0 = 65;\)\), "\[IndentingNewLine]", 
    \(\(X1\  = \ N[Table[Cos[\[Pi]\/16\ i], {i, 0, m0}]];\)\), "\n", 
    \(\(X2\  = \ 
        N[Table[Cos[\[Pi]\/16\ i] + Sin[\(3  \[Pi]\)\/4\ i], {i, 0, 
              m0}]];\)\), "\[IndentingNewLine]", 
    \(\(X1 = Join[Table[0, {i, 1, 9}], X1];\)\), "\[IndentingNewLine]", 
    \(\(X2 = Join[Table[0, {i, 1, 9}], X2];\)\), "\n", 
    \(\(Y2 = \(Y1 = Table[0, {i, 0, m0 + 9}]\);\)\), "\n", 
    \(\(For[i = 10, 
        i \[LessEqual] 
          m0 + 10, \(i++\), \[IndentingNewLine]Y1\_\(\(\[LeftDoubleBracket]\)\
\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X1\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  - \ \(2\/3\) 
                  Y1\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\)\  - \(4\/\(\(\ \)\(9\)\)\) 
                  Y1\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\)\ )\)\ ]; \ \[IndentingNewLine]Y2\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X2\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  - \ \(2\/3\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\)\  - \(4\/\(\(\ \)\(9\)\)\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\)\ )\)\ ];\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(X1pts = 
        Transpose[{ticval, 
            Take[X1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(X2pts = 
        Transpose[{ticval, 
            Take[X2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1pts = 
        Transpose[{ticval, 
            Take[Y1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y2pts = 
        Transpose[{ticval, 
            Take[Y2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ListPlot[X1pts, PlotJoined \[Rule] True, PlotStyle \[Rule] {Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ListPlot[X2pts, PlotJoined \[Rule] True, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{0, m0}, {\(-2\), 2}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<n\>", "\<x[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Input signal x[n] = \>", 
        x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        ListPlot[Take[Y1pts, \(-65\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] {Blue}, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr4 = 
        ListPlot[Take[Y2pts, \(-66\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] Red, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr4, PlotRange \[Rule] {{0, m0}, {\(-2.5\), 2.5}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<n\>", "\<y[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Output signal\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = y[n] = x[n] + \!\(2\/3\)\!\(\@2\)y[n-1] \
-\!\(4\/\(\(\\\ \)\(9\)\)\)y[n-2]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The  amplitude  responses\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Low  frequency:   A[\!\(\[Pi]\/16\)] = |H[\!\(\
\[ExponentialE]\^\(\(\[Pi]\/16\) \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\[Pi]\/16. \) \[ImaginaryI]\)]]\ ];\)\ \), \
"\n", 
    \(\(Print[\*"\"\<High frequency:  A[\!\(\(3  \[Pi]\)\/4\)] = |H[\!\(\
\[ExponentialE]\^\(\(\(3  \[Pi]\)\/4\) \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\(3  \[Pi]\)\/4. \) \[ImaginaryI]\)]]\ \
];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["1 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Include the additional pole at  ",
  Cell[BoxData[
      \(\(1\/2\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]\) = \
\(-\(1\/2\)\)\)]],
  " to the filter design in (a) so that it also boosts up high frequency \
signals."
}], "Text"],

Cell[BoxData[{
    \(\(G[
          z_] = \((\ \(z - \(2\/3\) \[ExponentialE]\^\(\[ImaginaryI]\ 3  \
\[Pi]/4\)\)\/z)\) \((\ \(z - \(2\/3\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
3  \[Pi]/4\)\)\/z)\) \((\ \(z - \(1\/2\) \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Pi]\)\)\/z)\)\ ;\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<H[z] = ( \!\(\(z - \(2\/3\) \[ExponentialE]\^\(\
\[ImaginaryI]\\\ 3  \[Pi]/4\)\)\/z\))( \!\(\(z - \(2\/3\) \[ExponentialE]\^\(\
\(-\[ImaginaryI]\)\\\ 3  \[Pi]/4\)\)\/z\))( \!\(\(z - \(1\/2\) \
\[ExponentialE]\^\(\[ImaginaryI]\\\ \[Pi]\)\)\/z\))\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", 1/G[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(G[z_] = ComplexExpand[G[z]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", 1/G[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(G[z_] = Collect[G[z], z];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", 1/G[z]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(H[z_] = 
        1\/\(\(\ \)\(1 + \(1\/6\) \((3 + \ 4 \@ 2)\) z\^\(-1\) + \(1\/9\) \
\((4 + 3 \@ 2)\) z\^\(-2\) + \(2\/9\) z\^\(-3\)\)\);\)\ \), "\n", 
    \(\(A[\[Theta]_] = 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]];\)\), "\
\[IndentingNewLine]", 
    \(\(gr2 = 
        Plot[A[\[Theta]], {\[Theta], 0, \[Pi]}, 
          PlotRange \[Rule] {{0, \[Pi]}, {0, 4}}, 
          Ticks \[Rule] {Range[0, \[Pi], \[Pi]\/4], Range[0, 4, 1]}, 
          AxesLabel \[Rule] {"\<\[Theta]\>", "\<A(\[Theta])\>"}, 
          PlotStyle \[Rule] Red];\)\), "\n", 
    \(\(Print["\<The amplitude response\>"];\)\), "\n", 
    \(\(Print[\*"\"\<A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the filter\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = x[n] - \!\(1\/6\)(3+ 4\!\(\@2\))y[n-1] - \!\(1\/9\
\)(4+3\!\(\@2\))y[n-2] - \!\(2\/9\)y[n-3]\>\""];\)\ \)}], "Input"],

Cell[BoxData[
    \(\(ZeroPolePlot1;\)\)], "Input"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can investigate how this filter work."
}], "Text"],

Cell[BoxData[{
    \(\(Show[gr2, 
        Ticks \[Rule] {{0, \[Pi]\/16, \[Pi]\/2, \(3\ \[Pi]\)\/4, \[Pi]}, 
            Range[0, 4, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The amplitude response\>"];\)\), "\n", 
    \(\(Print[\*"\"\<A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(\[Pi]\/16\)]  = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]  \[Pi]\/16\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\[Pi]\/16. \) \[ImaginaryI]\)]]\ ];\)\ \), \
"\n", 
    \(\(Print[\*"\"\<A[\!\(\(3  \[Pi]\)\/4\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI] \( 3  \[Pi]\)\/4\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\(3  \[Pi]\)\/4. \) \[ImaginaryI]\)]]\ \
];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<For the filter\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = x[n] - \!\(1\/6\)(3+ 4\!\(\@2\))y[n-1] - \!\(1\/9\
\)(4+3\!\(\@2\))y[n-2] - \!\(2\/9\)y[n-3]\>\""];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = 
        Cos[\[Pi]\/16\ n] + 
          Sin[\(3  \[Pi]\)\/4\ n];\)\ \), "\[IndentingNewLine]", 
    \(\(m0 = 65;\)\), "\[IndentingNewLine]", 
    \(\(X1\  = \ N[Table[Cos[\[Pi]\/16\ i], {i, 0, m0}]];\)\), "\n", 
    \(\(X2\  = \ 
        N[Table[Cos[\[Pi]\/16\ i] + Sin[\(3  \[Pi]\)\/4\ i], {i, 0, 
              m0}]];\)\), "\[IndentingNewLine]", 
    \(\(X1 = Join[Table[0, {i, 1, 9}], X1];\)\), "\[IndentingNewLine]", 
    \(\(X2 = Join[Table[0, {i, 1, 9}], X2];\)\), "\n", 
    \(\(Y2 = \(Y1 = Table[0, {i, 0, m0 + 9}]\);\)\), "\[IndentingNewLine]", 
    \(\(For[i = 10, 
        i \[LessEqual] 
          m0 + 10, \(i++\), \[IndentingNewLine]Y1\_\(\(\[LeftDoubleBracket]\)\
\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X1\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  - \ \(1\/6\) \((3 + \ 4 \@ 2)\) 
                  Y1\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\)\  - \ \(1\/9\) \((4 + 3 \@ 2)\) 
                  Y1\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\)\  - \ \(2\/9\) 
                  Y1\_\(\(\[LeftDoubleBracket]\)\(i - 3\)\(\
\[RightDoubleBracket]\)\))\)\ ]; \ \[IndentingNewLine]Y2\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X2\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  - \ \(1\/6\) \((3 + \ 4 \@ 2)\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\)\  - \ \(1\/9\) \((4 + 3 \@ 2)\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\)\  - \ \(2\/9\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 3\)\(\
\[RightDoubleBracket]\)\))\)\ ];\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(X1pts = 
        Transpose[{ticval, 
            Take[X1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(X2pts = 
        Transpose[{ticval, 
            Take[X2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1pts = 
        Transpose[{ticval, 
            Take[Y1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y2pts = 
        Transpose[{ticval, 
            Take[Y2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ListPlot[X1pts, PlotJoined \[Rule] True, PlotStyle \[Rule] {Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ListPlot[X2pts, PlotJoined \[Rule] True, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{0, m0}, {\(-2\), 2}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<n\>", "\<x[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Input signal x[n] = \>", 
        x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        ListPlot[Take[Y1pts, \(-65\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] {Blue}, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr4 = 
        ListPlot[Take[Y2pts, \(-66\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] Red, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr4, PlotRange \[Rule] {{0, m0}, {\(-3.2\), 3.5}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-4\), 4, 1]}, 
        AxesLabel \[Rule] {"\<n\>", "\<y[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Output signal\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = x[n] - \!\(1\/6\)(3+ 4\!\(\@2\))y[n-1] - \!\(1\/9\
\)(4+3\!\(\@2\))y[n-2] - \!\(2\/9\)y[n-3]\>\""];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The  amplitude  responses\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Low  frequency:   A[\!\(\[Pi]\/16\)] = |H[\!\(\
\[ExponentialE]\^\(\(\[Pi]\/16\) \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\[Pi]\/16. \) \[ImaginaryI]\)]]\ ];\)\ \), \
"\n", 
    \(\(Print[\*"\"\<High frequency:  A[\!\(\(3  \[Pi]\)\/4\)] = |H[\!\(\
\[ExponentialE]\^\(\(\(3  \[Pi]\)\/4\) \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\(3  \[Pi]\)\/4. \) \[ImaginaryI]\)]]\ \
];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Band Pass Filter",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tPoles can be placed near frequencies to boost them up and zeros for \
attenuating the other frequencies."
}], "Text"],

Cell[TextData[{
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Design a combination filter boosting up some of the low frequencies \
where ",
  Cell[BoxData[
      \(\[Pi]\/3 < \[Theta] < \[Pi]\/2\)]],
  " and attenuating frequencies ",
  Cell[BoxData[
      \(\[Theta] < \(22\/100\) \[Pi]\)]],
  "  and  ",
  Cell[BoxData[
      \(\(63\/100\) \[Pi] < \[Theta]\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(F[
          z_] = \((\(z - \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/6\)\)\/z)\) \
\((\(z - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/6\)\)\/z)\) \((\(z - \
\[ExponentialE]\^\(\[ImaginaryI]\ 2  \[Pi]/3\)\)\/z)\) \((\(z - \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 2  \[Pi]/3\)\)\/z)\) \((\(z - \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 0\)\)\/z)\) \((\(z - \[ExponentialE]\^\
\(\(-\[ImaginaryI]\)\ \[Pi]\)\)\/z)\);\)\), "\[IndentingNewLine]", 
    \(\(G[
          z_] = \((\(z - \(5\/6\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/3\)\
\)\/z)\) \((\(z - \(5\/6\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/3\)\)\
\/z)\)\ \((\(z - \(5\/6\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\)\)\/z)\) \
\((\(z - \(5\/6\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/2\)\)\/z)\)\ ;\
\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<H[z] = (\!\(\(z - \[ExponentialE]\^\(\[ImaginaryI]\\\ \
\[Pi]/2\)\)\/z\))(\!\(\(z - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\\\ \
\[Pi]/2\)\)\/z\))(\!\(\(z - \[ExponentialE]\^\(\(-\[ImaginaryI]\)\\\ \
\[Pi]\)\)\/z\))/(\!\(\(z - \(2\/3\) \[ExponentialE]\^\(\[ImaginaryI]\\\ \
\[Pi]/4\)\)\/z\))(\!\(\(z - \(2\/3\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\\\ \
\[Pi]/4\)\)\/z\))\>\""];\)\), "\n", 
    \(\(H[z_] = F[z]/G[z];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", H[z]\ ];\)\), "\n", 
    \(\(F[z_] = Collect[ComplexExpand[F[z]], z];\)\), "\[IndentingNewLine]", 
    \(\(G[z_] = ComplexExpand[G[z]];\)\), "\n", 
    \(\(H[z_] = F[z]/G[z];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", H[z]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[k, n, x, y];\)\), "\[IndentingNewLine]", 
    \(\(filter = 
        y[n] \[Equal] 
          ReplaceAll[
              Expand[F[z]], {1 \[Rule] x[n], 
                Power[z, k_] \[Rule] x[n + k]}] - 
            ReplaceAll[
              G[z], {1 \[Rule] 0, 
                Power[z, k_] \[Rule] y[n + k]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<For the transfer function\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<H[z] = \>", H[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The filter is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(A[\[Theta]_] = 
        Abs[H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)]];\)\), "\
\[IndentingNewLine]", 
    \(\(gr3 = 
        Plot[A[\[Theta]], {\[Theta], 0, \[Pi]}, 
          PlotRange \[Rule] {{0, \[Pi]}, {0, 15}}, 
          Ticks \[Rule] {{0, \[Pi]\/6, \[Pi]\/3, \[Pi]\/2, \(2  \[Pi]\)\/3, \
\[Pi]}, Range[0, 16, 2]}, 
          AxesLabel \[Rule] {"\<\[Theta]\>", "\<A(\[Theta])\>"}, 
          PlotStyle \[Rule] Red];\)\), "\n", 
    \(\(Print["\<The amplitude response\>"];\)\), "\n", 
    \(\(Print[\*"\"\<A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(22\/100\)\[Pi]] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI] \( 22\/100\) \[Pi]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\ \)\(\[ImaginaryI] \( 22. \/100\) \[Pi]\)\
\)]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(63\/100\)\[Pi]] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI] \( 63\/100\) \[Pi]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\ \)\(\[ImaginaryI] \( 63. \/100\) \[Pi]\)\
\)]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<For the filter\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ filter\ ];\)\ \)}], "Input"],

Cell[BoxData[
    \(\(ZeroPolePlot1;\)\)], "Input"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can investigate how this filter work."
}], "Text"],

Cell[BoxData[{
    \(\(Show[gr3, 
        Ticks \[Rule] {{0, 13\/25, \[Pi]\/3, \[Pi]\/2, 21\/10, \[Pi]}, 
            Range[0, 15, 2]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The amplitude response\>"];\)\), "\n", 
    \(\(Print[\*"\"\<A[\[Theta]] = |H[\!\(\[ExponentialE]\^\[ImaginaryI]\
\[Theta]\)]| = |\>\"", 
        H[\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)], "\<|\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(13\/25\)] = \
|H[\!\(\[ExponentialE]\^\(\[ImaginaryI]  13\/25\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(13\/25. \) \[ImaginaryI]\)]]\ ];\)\ \), "\n\
", 
    \(\(Print[\*"\"\< A[\!\(\[Pi]\/2\)] = |H[\!\(\[ExponentialE]\^\(\
\[ImaginaryI]  \[Pi]\/2\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\[Pi]\/2. \) \[ImaginaryI]\)]]\ ];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A[\!\(21\/10\)] = \
|H[\!\(\[ExponentialE]\^\(\[ImaginaryI]  21\/10\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(21\/10. \) \[ImaginaryI]\)]]\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the filter\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = x[n]+x[n-1]+x[n-2]+x[n-3] + \!\(2\/3\)\!\(\@2\) \
y[n-1] - \!\(4\/9\)y[n-2]\>\""];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = 
        Cos[13\/25\ n] + Sin[21\/10\ n];\)\ \), "\[IndentingNewLine]", 
    \(\(m0 = 65;\)\), "\[IndentingNewLine]", 
    \(\(X1\  = \ N[Table[Cos[13\/25\ i], {i, 0, m0}]];\)\), "\n", 
    \(\(X2\  = \ 
        N[Table[Cos[13\/25\ i] + Sin[21\/10\ i], {i, 0, 
              m0}]];\)\), "\[IndentingNewLine]", 
    \(\(X1 = Join[Table[0, {i, 1, 9}], X1];\)\), "\[IndentingNewLine]", 
    \(\(X2 = Join[Table[0, {i, 1, 9}], X2];\)\), "\n", 
    \(\(Y2 = \(Y1 = Table[0, {i, 0, m0 + 9}]\);\)\), "\[IndentingNewLine]", 
    \(\(For[i = 10, 
        i \[LessEqual] 
          m0 + 10, \(i++\), \[IndentingNewLine]Y1\_\(\(\[LeftDoubleBracket]\)\
\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X1\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\) + \((1 - \@3)\) 
                  X1\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\) + \((1 - \@3)\)\ X1\_\(\(\[LeftDoubleBracket]\)\(i \
- 2\)\(\[RightDoubleBracket]\)\) + \((\@3 - 
                      1)\)\ X1\_\(\(\[LeftDoubleBracket]\)\(i - 4\)\(\
\[RightDoubleBracket]\)\) + \((\@3 - 
                      1)\)\ X1\_\(\(\[LeftDoubleBracket]\)\(i - 5\)\(\
\[RightDoubleBracket]\)\) - 
                X1\_\(\(\[LeftDoubleBracket]\)\(i - \
6\)\(\[RightDoubleBracket]\)\) + 
                5\/6\ Y1\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\) - 
                25\/18\ Y1\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\) + 
                125\/216\ Y1\_\(\(\[LeftDoubleBracket]\)\(i - 3\)\(\
\[RightDoubleBracket]\)\) - \(\(\(625\)\(\ \)\)\/1296\) 
                  Y1\_\(\(\[LeftDoubleBracket]\)\(i - 4\)\(\
\[RightDoubleBracket]\)\)\ )\)\ ]; \ \[IndentingNewLine]Y2\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X2\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\) + \((1 - \@3)\) 
                  X2\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\) + \((1 - \@3)\)\ X2\_\(\(\[LeftDoubleBracket]\)\(i \
- 2\)\(\[RightDoubleBracket]\)\) + \((\@3 - 
                      
                      1)\)\ X2\_\(\(\[LeftDoubleBracket]\)\(i - 4\)\(\
\[RightDoubleBracket]\)\) + \((\@3 - 
                      1)\)\ X2\_\(\(\[LeftDoubleBracket]\)\(i - 5\)\(\
\[RightDoubleBracket]\)\) - 
                X2\_\(\(\[LeftDoubleBracket]\)\(i - \
6\)\(\[RightDoubleBracket]\)\) + 
                5\/6\ Y2\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\) - 
                25\/18\ Y2\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\) + 
                125\/216\ Y2\_\(\(\[LeftDoubleBracket]\)\(i - 3\)\(\
\[RightDoubleBracket]\)\) - \(\(\(625\)\(\ \)\)\/1296\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 4\)\(\
\[RightDoubleBracket]\)\))\)\ ];\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(X1pts = 
        Transpose[{ticval, 
            Take[X1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(X2pts = 
        Transpose[{ticval, 
            Take[X2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1pts = 
        Transpose[{ticval, 
            Take[Y1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y2pts = 
        Transpose[{ticval, 
            Take[Y2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ListPlot[X1pts, PlotJoined \[Rule] True, PlotStyle \[Rule] {Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ListPlot[X2pts, PlotJoined \[Rule] True, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr2, gr1, PlotRange \[Rule] {{10, m0}, {\(-1.75\), 1.75}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 0.5]}, 
        AxesLabel \[Rule] {"\<n\>", "\<x[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Input signal x[n] = \>", 
        x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        ListPlot[Take[Y1pts, \(-65\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] {Blue}, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr4 = 
        ListPlot[Take[Y2pts, \(-66\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] Red, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr4, gr3, PlotRange \[Rule] {{10, m0}, {\(-0.35\), 0.35}}, 
        Ticks \[Rule] {Range[0, m0, 10], Chop[Range[\(-0.6\), 0.6, 0.1]]}, 
        AxesLabel \[Rule] {"\<n\>", "\<y[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Output signal\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = x[n]+(1-\!\(\@3\)) x[n-1]+(1-\!\(\@3\)) \
x[n-2]+(\!\(\@3\)-1) x[n-4]+(\!\(\@3\)-1) x[n-5]-x[n-6]+\!\(5\/6\) \
y[n-1]-\!\(25\/18\) y[n-2]+\!\(125\/216\) y[n-3]-\!\(\(\(625\)\(\\\ \
\)\)\/1296\)y[n-4]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The  amplitude  responses\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Low  frequency:  A[\!\(13\/25\)] = \
|H[\!\(\[ExponentialE]\^\(\(13\/25\) \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(13\/25. \) \[ImaginaryI]\)]]\ ];\)\ \), "\n\
", 
    \(\(Print[\*"\"\<High frequency:  A[\!\(21\/10\)] = \
|H[\!\(\[ExponentialE]\^\(\(21\/10\) \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(21\/10. \) \[ImaginaryI]\)]]\ ];\)\ \)}], \
"Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(x[n_] = 
        Cos[\[Pi]\/12\ n] + Sin[\[Pi]\/2\ n];\)\ \), "\[IndentingNewLine]", 
    \(\(m0 = 65;\)\), "\[IndentingNewLine]", 
    \(\(X1\  = \ N[Table[Cos[\[Pi]\/12\ i], {i, 0, m0}]];\)\), "\n", 
    \(\(X2\  = \ 
        N[Table[Cos[\[Pi]\/12\ i] + Sin[\[Pi]\/2\ i], {i, 0, 
              m0}]];\)\), "\[IndentingNewLine]", 
    \(\(X1 = Join[Table[0, {i, 1, 9}], X1];\)\), "\[IndentingNewLine]", 
    \(\(X2 = Join[Table[0, {i, 1, 9}], X2];\)\), "\n", 
    \(\(Y2 = \(Y1 = Table[0, {i, 0, m0 + 9}]\);\)\), "\[IndentingNewLine]", 
    \(\(For[i = 10, 
        i \[LessEqual] 
          m0 + 10, \(i++\), \[IndentingNewLine]Y1\_\(\(\[LeftDoubleBracket]\)\
\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X1\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\) + \((1 - \@3)\) 
                  X1\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\) + \((1 - \@3)\)\ X1\_\(\(\[LeftDoubleBracket]\)\(i \
- 2\)\(\[RightDoubleBracket]\)\) + \((\@3 - 
                      1)\)\ X1\_\(\(\[LeftDoubleBracket]\)\(i - 4\)\(\
\[RightDoubleBracket]\)\) + \((\@3 - 
                      1)\)\ X1\_\(\(\[LeftDoubleBracket]\)\(i - 5\)\(\
\[RightDoubleBracket]\)\) - 
                X1\_\(\(\[LeftDoubleBracket]\)\(i - \
6\)\(\[RightDoubleBracket]\)\) + 
                5\/6\ Y1\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\) - 
                25\/18\ Y1\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\) + 
                125\/216\ Y1\_\(\(\[LeftDoubleBracket]\)\(i - 3\)\(\
\[RightDoubleBracket]\)\) - \(\(\(625\)\(\ \)\)\/1296\) 
                  Y1\_\(\(\[LeftDoubleBracket]\)\(i - 4\)\(\
\[RightDoubleBracket]\)\)\ )\)\ ]; \ \[IndentingNewLine]Y2\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
          Chop[\ \((X2\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\) + \((1 - \@3)\) 
                  X2\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\) + \((1 - \@3)\)\ X2\_\(\(\[LeftDoubleBracket]\)\(i \
- 2\)\(\[RightDoubleBracket]\)\) + \((\@3 - 
                      1)\)\ X2\_\(\(\[LeftDoubleBracket]\)\(i - 4\)\(\
\[RightDoubleBracket]\)\) + \((\@3 - 
                      1)\)\ X2\_\(\(\[LeftDoubleBracket]\)\(i - 5\)\(\
\[RightDoubleBracket]\)\) - 
                X2\_\(\(\[LeftDoubleBracket]\)\(i - \
6\)\(\[RightDoubleBracket]\)\) + 
                5\/6\ Y2\_\(\(\[LeftDoubleBracket]\)\(i - 1\)\(\
\[RightDoubleBracket]\)\) - 
                25\/18\ Y2\_\(\(\[LeftDoubleBracket]\)\(i - 2\)\(\
\[RightDoubleBracket]\)\) + 
                125\/216\ Y2\_\(\(\[LeftDoubleBracket]\)\(i - 3\)\(\
\[RightDoubleBracket]\)\) - \(\(\(625\)\(\ \)\)\/1296\) 
                  Y2\_\(\(\[LeftDoubleBracket]\)\(i - 4\)\(\
\[RightDoubleBracket]\)\))\)\ ];\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(ticval = Table[i, {i, 0, m0}];\)\), "\n", 
    \(\(X1pts = 
        Transpose[{ticval, 
            Take[X1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(X2pts = 
        Transpose[{ticval, 
            Take[X2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1pts = 
        Transpose[{ticval, 
            Take[Y1, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Y2pts = 
        Transpose[{ticval, 
            Take[Y2, \(-m0\) - 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ListPlot[X1pts, PlotJoined \[Rule] True, PlotStyle \[Rule] {Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ListPlot[X2pts, PlotJoined \[Rule] True, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr2, gr1, PlotRange \[Rule] {{0, m0}, {\(-1.6\), 1.6}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
        AxesLabel \[Rule] {"\<n\>", "\<x[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Input signal x[n] = \>", 
        x[n]\ ];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        ListPlot[Take[Y1pts, \(-65\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] {Blue}, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr4 = 
        ListPlot[Take[Y2pts, \(-66\)], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, m0}, {\(-1\), 1}}, PlotStyle \[Rule] Red, 
          Ticks \[Rule] {Range[0, m0, 10], Range[\(-2\), 2, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr4, gr3, PlotRange \[Rule] {{0, m0}, {\(-13\), 13}}, 
        Ticks \[Rule] {Range[0, m0, 10], Range[\(-14\), 14, 2]}, 
        AxesLabel \[Rule] {"\<n\>", "\<y[n]\>"}, AspectRatio \[Rule] \ 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Output signal\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y[n] = x[n]+(1-\!\(\@3\)) x[n-1]+(1-\!\(\@3\)) \
x[n-2]+(\!\(\@3\)-1) x[n-4]+(\!\(\@3\)-1) x[n-5]-x[n-6]+\!\(5\/6\) \
y[n-1]-\!\(25\/18\) y[n-2]+\!\(125\/216\) y[n-3]-\!\(\(\(625\)\(\\\ \
\)\)\/1296\)y[n-4]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The  amplitude  responses\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Low  frequency:  A[\!\(\[Pi]\/12\)] = |H[\!\(\
\[ExponentialE]\^\(\(\[Pi]\/12\) \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\[Pi]\/12. \) \[ImaginaryI]\)]]\ ];\)\ \), \
"\n", 
    \(\(Print[\*"\"\<High frequency:   A[\!\(\[Pi]\/2\)] = |H[\!\(\
\[ExponentialE]\^\(\(\[Pi]\/2\) \[ImaginaryI]\)\)]| =  \>\"", 
        Abs[H[\[ExponentialE]\^\(\(\[Pi]\/2. \) \[ImaginaryI]\)]]\ ];\)\ \
\)}], "Input"]
}, Closed]],

Cell["\<\
\tA signal processing engineer uses complex analysis to construct filters \
with the desired amplitude and phase response characteristics.  Finite \
impulse response (FIR) filters have only zeros, whereas infinite impulse \
response (IIR) filters have poles and may have zeros as well.  The area of \
filter design involves many types, such as: low pass, high pass, all pass, \
band pass and band stop. Special forms of such filters include, but are not \
limited to Bessel, Butterworth, Chebyshev, Gaussian, moving average, single \
pole, Remez, etc.  More information about filter design can be found in books \
on digital signal processing.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Algorithm (Analysis of Filters)",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  The following subroutine will analyze the transfer function for  ",
  Cell[BoxData[
      \(\[Sum]\+\(p = 0\)\%P\( a\_p\) 
            y[n - p]\ \  = \ \ \[Sum]\+\(q = 0\)\%Q\( b\_q\) x[n - q]\)]],
  ".  The z-transform is\n\n\t\t\t",
  Cell[BoxData[
      \(Y[z] \(\[Sum]\+\(p = 0\)\%P\( a\_p\) z\^\(-p\)\)\ \ \  = \ \ \ X[
            z] \(\[Sum]\+\(q = 0\)\%Q\( b\_q\) z\^\(-q\)\)\)]],
  " \n\nThe functions  ",
  Cell[BoxData[
      \(A[z]\  = \ \[Sum]\+\(p = 0\)\%P\( a\_p\) z\^\(-p\)\)]],
  "  and  ",
  Cell[BoxData[
      \(B[z]\  = \ \[Sum]\+\(q = 0\)\%Q\( b\_q\) z\^\(-q\)\)]],
  "  must be defined. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica Subroutine (Analysis of Filters)",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(ZeroPolePlot1\  := \ 
      Module[{}, \[IndentingNewLine]Clear[x, y]; \ \[IndentingNewLine]H[z_] = 
          Together[H[z]]; \[IndentingNewLine]a = 
          CoefficientList[Expand[Numerator[H[z]]], 
            1\/z]; \ \[IndentingNewLine]b = 
          CoefficientList[Expand[Denominator[H[z]]], 
            1\/z]; \ \[IndentingNewLine]Zeros\  = \ 
          Solve[Numerator[Together[H[z]]] \[Equal] 0, 
            z]; \ \[IndentingNewLine]Poles\  = \ 
          Solve[Denominator[Together[H[p]]] \[Equal] 0, 
            p]; \ \[IndentingNewLine]Zeros\  = \ 
          MapAll[ComplexExpand, Zeros]; \ \[IndentingNewLine]Z = 
          Table[Zeros\_\(\(\[LeftDoubleBracket]\)\(i, 1, 2\)\(\
\[RightDoubleBracket]\)\), {i, 1, Length[Zeros]}]; \ \[IndentingNewLine]arg[
            z_] = If[0 \[LessEqual] Arg[z] \[LessEqual] \[Pi], Arg[z], 
            Arg[z] + 2  \[Pi]]; \[IndentingNewLine]If[
          Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\) \
\[NotEqual] 0, Z = Sort[Z, arg[#1] < arg[#2]\  &]]; \ \[IndentingNewLine]W = 
          Union[Table[
              Poles\_\(\(\[LeftDoubleBracket]\)\(i, 1, 2\)\(\
\[RightDoubleBracket]\)\), {i, 1, 
                Length[Poles]}]]; \ \[IndentingNewLine]Zdots = 
          Graphics[{Prepend[
                Prepend[
                  Table[Point[{Re[
                          Zeros\_\(\(\[LeftDoubleBracket]\)\(i, 1, 2\)\(\
\[RightDoubleBracket]\)\)], 
                        Im[Zeros\_\(\(\[LeftDoubleBracket]\)\(i, 1, 2\)\(\
\[RightDoubleBracket]\)\)]}], {i, 1, Length[Zeros]}], PointSize[0.04]], 
                Blue]}]; \ \[IndentingNewLine]Wdots = 
          Graphics[{Prepend[
                Prepend[
                  Table[Point[{Re[
                          Poles\_\(\(\[LeftDoubleBracket]\)\(i, 1, 2\)\(\
\[RightDoubleBracket]\)\)], 
                        Im[Poles\_\(\(\[LeftDoubleBracket]\)\(i, 1, 2\)\(\
\[RightDoubleBracket]\)\)]}], {i, 1, Length[Poles]}], PointSize[0.04]], 
                Red]}]; \ \[IndentingNewLine]circle\  = \ 
          Graphics[{{Green, 
                Circle[{0, 0}, 1]}}]; \[IndentingNewLine]poleplot = 
          Show[circle, Zdots, Wdots, 
            PlotRange \[Rule] {{\(-1.05\), 1.1}, {\(-1.05\), 1.1}}, 
            Axes \[Rule] True, \ Ticks \[Rule] None, 
            AxesLabel \[Rule] {"\<Re(z)\>", "\<Im(z)\>"}, 
            AspectRatio \[Rule] 
              1]; \[IndentingNewLine]Print["\<The transfer function is\>"]; \
\[IndentingNewLine]Print["\<H[z] = \>", 
          H[z]\ ]; \ \[IndentingNewLine]Print["\<The zeros of H[z] are\>"]; \
\[IndentingNewLine]For[i = 1, 
          i \[LessEqual] Length[Z], \(i++\), \[IndentingNewLine]If[
            Or[Re[Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\
\)] \[Equal] 0, 
              Im[Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
] \[Equal] 0], \(Print["\<z\>"\_i, "\<  =  \>", \ 
                Abs[Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)], "\< \>", 
                If[Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\
\) \[NotEqual] 
                    0, "\<\[ExponentialE]\>"\^Arg[Z\_\(\(\[LeftDoubleBracket]\
\)\(i\)\(\[RightDoubleBracket]\)\)], \*"\"\<\!\(\[ExponentialE]\^\(0  \
\[ImaginaryI]\)\)\>\""], "\<  =  \>", 
                Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]\
;\)]; \[IndentingNewLine]If[
            And[Re[Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\
\)] \[NotEqual] 0, 
              Im[Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
] > 0], \(Print["\<z\>"\_i, "\<  =  \>", \ 
                Abs[Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)], "\< \>", "\<\[ExponentialE]\>"\^\(\[ImaginaryI]\ Arg[Z\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]\), "\<  =  \>", 
                Re[Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\
\)], "\< + \[ImaginaryI]\>", 
                If[Abs[Im[
                        Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\)]] \[NotEqual] 1, 
                  Im[Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)], "\<\>"]\ \ ];\)]; \[IndentingNewLine]If[
            And[Re[Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\
\)] \[NotEqual] 0, 
              Im[Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
] < 0], \(Print["\<z\>"\_i, "\<  =  \>", \ 
                Abs[Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)], "\< \>", "\<\[ExponentialE]\>"\^\(\[ImaginaryI]\ Arg[Z\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]\), "\<  =  \>", 
                Re[Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\
\)], "\< - \[ImaginaryI]\>", 
                If[Abs[Im[
                        Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\)]] \[NotEqual] 
                    1, \(-Im[
                      Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\)]\), "\<\>"]\ \ ];\)];\[IndentingNewLine]]; \
\[IndentingNewLine]Print["\<The poles of H[z] are\>"]; \[IndentingNewLine]For[
          i = 1, i \[LessEqual] 
            Length[W], \(i++\), \[IndentingNewLine]\(Print["\<p\>"\_i, "\<  = \
 \>", Abs[
                W\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]\
, "\< \>", 
              If[W\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
 \[NotEqual] 
                  0, "\<\[ExponentialE]\>"\^Arg[W\_\(\(\[LeftDoubleBracket]\)\
\(i\)\(\[RightDoubleBracket]\)\)], \*"\"\<\!\(\[ExponentialE]\^\(0  \
\[ImaginaryI]\)\)\>\""], "\<  =  \>", 
              W\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\ \
];\)\ ];\ \ ]\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["The z-Transform",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/c2003/ZTransformBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True}],
  "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{996, 640},
WindowMargins->{{5, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageHeaderLines->{Inherited, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {36, 54}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[254777, 5120, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 539746, 11044}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 1504, 43, 242, "Text"],
Cell[3609, 107, 532, 20, 33, "Text"],
Cell[4144, 129, 5263, 143, 335, "Text"],
Cell[9410, 274, 1853, 54, 185, "Text"],
Cell[11266, 330, 1220, 32, 155, "Text"],
Cell[12489, 364, 920, 28, 128, "Text"],
Cell[13412, 394, 1873, 57, 153, "Text"],
Cell[15288, 453, 9051, 151, 149, 8937, 147, "GraphicsData", "Bitmap", "Text",
  Evaluatable->False],
Cell[24342, 606, 351, 13, 33, "Text"],
Cell[24696, 621, 41707, 687, 154, 41593, 683, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[66406, 1310, 265, 11, 33, "Text"],
Cell[66674, 1323, 59189, 973, 154, 59075, 969, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[125866, 2298, 280, 11, 36, "Text"],

Cell[CellGroupData[{
Cell[126171, 2313, 104, 2, 33, "Text"],
Cell[126278, 2317, 2470, 67, 245, "Text"],
Cell[128751, 2386, 1077, 26, 208, "Text"],
Cell[129831, 2414, 351, 13, 33, "Text"],
Cell[130185, 2429, 651, 20, 36, "Text"],
Cell[130839, 2451, 1656, 42, 295, "Text"],
Cell[132498, 2495, 913, 26, 74, "Text"],
Cell[133414, 2523, 265, 11, 33, "Text"],
Cell[133682, 2536, 664, 19, 36, "Text"],
Cell[134349, 2557, 853, 20, 225, "Text"],
Cell[135205, 2579, 709, 20, 55, "Text"],
Cell[135917, 2601, 280, 11, 36, "Text"],
Cell[136200, 2614, 407, 9, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[136644, 2628, 112, 2, 30, "Text"],
Cell[136759, 2632, 225, 8, 33, "Text"],
Cell[136987, 2642, 424, 15, 36, "Text"],
Cell[137414, 2659, 1443, 25, 333, "Input"],
Cell[138860, 2686, 1443, 25, 333, "Input"],
Cell[140306, 2713, 1335, 23, 244, "Input"],
Cell[141644, 2738, 351, 13, 33, "Text"],
Cell[141998, 2753, 637, 19, 33, "Text"],
Cell[142638, 2774, 1610, 32, 244, "Input"],
Cell[144251, 2808, 4110, 77, 644, "Input"],
Cell[148364, 2887, 351, 13, 33, "Text"],
Cell[148718, 2902, 671, 20, 36, "Text"],
Cell[149392, 2924, 1755, 34, 276, "Input"],
Cell[151150, 2960, 4460, 86, 717, "Input"],
Cell[155613, 3048, 280, 11, 36, "Text"]
}, Closed]],
Cell[155908, 3062, 1265, 41, 115, "Text"],
Cell[157176, 3105, 9547, 159, 149, 9433, 155, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[166726, 3266, 396, 13, 53, "Text"],
Cell[167125, 3281, 54712, 900, 163, 54598, 896, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[221840, 4183, 313, 13, 36, "Text"],

Cell[CellGroupData[{
Cell[222178, 4200, 104, 2, 33, "Text"],
Cell[222285, 4204, 1426, 41, 161, "Text"],
Cell[223714, 4247, 1630, 42, 283, "Text"],
Cell[225347, 4291, 396, 13, 53, "Text"],
Cell[225746, 4306, 1781, 47, 309, "Text"],
Cell[227530, 4355, 1239, 33, 55, "Text"],
Cell[228772, 4390, 313, 13, 36, "Text"],
Cell[229088, 4405, 407, 9, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[229532, 4419, 112, 2, 30, "Text"],
Cell[229647, 4423, 237, 8, 36, "Text"],
Cell[229887, 4433, 387, 14, 36, "Text"],
Cell[230277, 4449, 1573, 30, 325, "Input"],
Cell[231853, 4481, 396, 13, 53, "Text"],
Cell[232252, 4496, 688, 21, 36, "Text"],
Cell[232943, 4519, 2403, 46, 401, "Input"],
Cell[235349, 4567, 4341, 84, 721, "Input"],
Cell[239693, 4653, 313, 13, 36, "Text"]
}, Closed]],
Cell[240021, 4669, 2576, 82, 353, "Text"],
Cell[242600, 4753, 3323, 105, 130, "Text"],
Cell[245926, 4860, 1069, 30, 200, "Text"],
Cell[246998, 4892, 1094, 26, 137, "Text"],
Cell[248095, 4920, 401, 11, 38, "Text"],
Cell[248499, 4933, 805, 26, 147, "Text"],
Cell[249307, 4961, 1126, 28, 197, "Text"],
Cell[250436, 4991, 890, 29, 90, "Text"],

Cell[CellGroupData[{
Cell[251351, 5024, 96, 2, 33, "Text"],
Cell[251450, 5028, 2186, 55, 225, "Text"],
Cell[253639, 5085, 1090, 31, 94, "Text"],
Cell[254732, 5118, 42, 0, 33, "Text"],
Cell[254777, 5120, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[255137, 5132, 1137, 33, 91, "Text"],
Cell[256277, 5167, 1321, 33, 152, "Text"],
Cell[257601, 5202, 1384, 39, 239, "Text"],
Cell[258988, 5243, 1770, 55, 279, "Text"],
Cell[260761, 5300, 1488, 46, 274, "Text"],
Cell[262252, 5348, 1987, 61, 166, "Text"],
Cell[264242, 5411, 1581, 47, 77, "Text"],
Cell[265826, 5460, 27620, 456, 197, 27506, 452, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[293449, 5918, 309, 12, 36, "Text"],

Cell[CellGroupData[{
Cell[293783, 5934, 104, 2, 33, "Text"],
Cell[293890, 5938, 2051, 50, 231, "Text"],
Cell[295944, 5990, 1383, 26, 200, "Text"],
Cell[297330, 6018, 1362, 37, 112, "Text"],
Cell[298695, 6057, 369, 10, 115, "Text"],
Cell[299067, 6069, 309, 12, 36, "Text"],
Cell[299379, 6083, 407, 9, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[299823, 6097, 112, 2, 30, "Text"],
Cell[299938, 6101, 1084, 31, 36, "Text"],
Cell[301025, 6134, 583, 10, 152, "Input"],
Cell[301611, 6146, 733, 20, 38, "Text"],
Cell[302347, 6168, 499, 10, 130, "Input"],
Cell[302849, 6180, 1382, 25, 283, "Input"],
Cell[304234, 6207, 51, 1, 30, "Input"],
Cell[304288, 6210, 1155, 20, 302, "Input"],
Cell[305446, 6232, 1155, 20, 302, "Input"],
Cell[306604, 6254, 986, 29, 36, "Text"],
Cell[307593, 6285, 618, 17, 33, "Text"],
Cell[308214, 6304, 710, 12, 152, "Input"],
Cell[308927, 6318, 319, 9, 38, "Text"],
Cell[309249, 6329, 499, 10, 130, "Input"],
Cell[309751, 6341, 1424, 24, 352, "Input"],
Cell[311178, 6367, 1431, 24, 364, "Input"],
Cell[312612, 6393, 1433, 24, 364, "Input"],
Cell[314048, 6419, 742, 17, 75, "Text"],
Cell[314793, 6438, 1665, 32, 331, "Input"],
Cell[316461, 6472, 51, 1, 30, "Input"]
}, Closed]],
Cell[316527, 6476, 2286, 64, 55, "Text"],
Cell[318816, 6542, 30035, 495, 197, 29921, 491, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[348854, 7039, 310, 12, 36, "Text"],

Cell[CellGroupData[{
Cell[349189, 7055, 104, 2, 33, "Text"],
Cell[349296, 7059, 4167, 110, 339, "Text"],
Cell[353466, 7171, 2183, 58, 151, "Text"],
Cell[355652, 7231, 310, 12, 36, "Text"],
Cell[355965, 7245, 407, 9, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[356409, 7259, 112, 2, 30, "Text"],
Cell[356524, 7263, 1498, 41, 33, "Text"],
Cell[358025, 7306, 1238, 20, 152, "Input"],
Cell[359266, 7328, 472, 11, 38, "Text"],
Cell[359741, 7341, 499, 10, 130, "Input"],
Cell[360243, 7353, 179, 8, 36, "Text"],
Cell[360425, 7363, 648, 13, 189, "Input"],
Cell[361076, 7378, 155, 5, 36, "Text"],
Cell[361234, 7385, 2156, 36, 529, "Input"],
Cell[363393, 7423, 829, 20, 116, "Text"],
Cell[364225, 7445, 2173, 41, 412, "Input"],
Cell[366401, 7488, 51, 1, 30, "Input"]
}, Closed]],
Cell[366467, 7492, 1101, 34, 74, "Text"],
Cell[367571, 7528, 25757, 425, 197, 25643, 421, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[393331, 7955, 321, 12, 36, "Text"],
Cell[393655, 7969, 25326, 418, 197, 25212, 414, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[418984, 8389, 407, 15, 36, "Text"],

Cell[CellGroupData[{
Cell[419416, 8408, 104, 2, 33, "Text"],
Cell[419523, 8412, 1679, 39, 182, "Text"],
Cell[421205, 8453, 1396, 37, 157, "Text"],
Cell[422604, 8492, 569, 14, 66, "Text"],
Cell[423176, 8508, 317, 12, 36, "Text"],
Cell[423496, 8522, 2696, 68, 306, "Text"],
Cell[426195, 8592, 686, 16, 69, "Text"],
Cell[426884, 8610, 403, 15, 36, "Text"],
Cell[427290, 8627, 407, 9, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[427734, 8641, 112, 2, 30, "Text"],
Cell[427849, 8645, 797, 26, 36, "Text"],
Cell[428649, 8673, 627, 10, 166, "Input"],
Cell[429279, 8685, 1173, 34, 61, "Text"],
Cell[430455, 8721, 569, 14, 66, "Text"],
Cell[431027, 8737, 1020, 21, 248, "Input"],
Cell[432050, 8760, 51, 1, 30, "Input"],
Cell[432104, 8763, 317, 12, 36, "Text"],
Cell[432424, 8777, 190, 6, 71, "Text"],
Cell[432617, 8785, 1036, 19, 207, "Input"],
Cell[433656, 8806, 4377, 82, 761, "Input"],
Cell[438036, 8890, 318, 9, 36, "Text"],
Cell[438357, 8901, 899, 14, 206, "Input"],
Cell[439259, 8917, 1629, 46, 61, "Text"],
Cell[440891, 8965, 686, 16, 69, "Text"],
Cell[441580, 8983, 1106, 21, 248, "Input"],
Cell[442689, 9006, 51, 1, 30, "Input"],
Cell[442743, 9009, 403, 15, 36, "Text"],
Cell[443149, 9026, 190, 6, 71, "Text"],
Cell[443342, 9034, 1065, 19, 207, "Input"],
Cell[444410, 9055, 4679, 87, 761, "Input"]
}, Closed]],
Cell[449104, 9145, 1492, 42, 52, "Text"],
Cell[450599, 9189, 26814, 442, 197, 26700, 438, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[477416, 9633, 367, 13, 36, "Text"],

Cell[CellGroupData[{
Cell[477808, 9650, 104, 2, 33, "Text"],
Cell[477915, 9654, 800, 18, 136, "Text"],
Cell[478718, 9674, 1312, 30, 183, "Text"],
Cell[480033, 9706, 449, 10, 113, "Text"],
Cell[480485, 9718, 613, 19, 55, "Text"],
Cell[481101, 9739, 323, 9, 36, "Text"],
Cell[481427, 9750, 319, 9, 36, "Text"],
Cell[481749, 9761, 367, 13, 36, "Text"],
Cell[482119, 9776, 407, 9, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[482563, 9790, 112, 2, 30, "Text"],
Cell[482678, 9794, 613, 19, 55, "Text"],
Cell[483294, 9815, 323, 9, 36, "Text"],
Cell[483620, 9826, 319, 9, 36, "Text"],
Cell[483942, 9837, 1074, 19, 232, "Input"],
Cell[485019, 9858, 1070, 21, 251, "Input"],
Cell[486092, 9881, 51, 1, 30, "Input"],
Cell[486146, 9884, 367, 13, 36, "Text"],
Cell[486516, 9899, 176, 6, 71, "Text"],
Cell[486695, 9907, 1048, 19, 207, "Input"],
Cell[487746, 9928, 4868, 88, 761, "Input"]
}, Closed]],
Cell[492629, 10019, 2047, 53, 90, "Text"],
Cell[494679, 10074, 1122, 34, 77, "Text"],

Cell[CellGroupData[{
Cell[495826, 10112, 115, 2, 33, "Text"],
Cell[495944, 10116, 797, 25, 36, "Text"],
Cell[496744, 10143, 643, 10, 166, "Input"],
Cell[497390, 10155, 1036, 21, 248, "Input"],
Cell[498429, 10178, 51, 1, 30, "Input"],
Cell[498483, 10181, 176, 6, 71, "Text"],
Cell[498662, 10189, 1060, 19, 207, "Input"],
Cell[499725, 10210, 4393, 82, 761, "Input"],
Cell[504121, 10294, 331, 10, 36, "Text"],
Cell[504455, 10306, 931, 15, 206, "Input"],
Cell[505389, 10323, 1106, 21, 248, "Input"],
Cell[506498, 10346, 51, 1, 30, "Input"],
Cell[506552, 10349, 176, 6, 71, "Text"],
Cell[506731, 10357, 1065, 19, 207, "Input"],
Cell[507799, 10378, 4679, 87, 761, "Input"]
}, Closed]],
Cell[512493, 10468, 232, 6, 68, "Text"],
Cell[512728, 10476, 432, 15, 36, "Text"],

Cell[CellGroupData[{
Cell[513185, 10495, 115, 2, 33, "Text"],
Cell[513303, 10499, 1576, 25, 272, "Input"],
Cell[514882, 10526, 621, 13, 130, "Input"],
Cell[515506, 10541, 1365, 26, 259, "Input"],
Cell[516874, 10569, 51, 1, 30, "Input"],
Cell[516928, 10572, 176, 6, 71, "Text"],
Cell[517107, 10580, 1224, 23, 242, "Input"],
Cell[518334, 10605, 5872, 110, 906, "Input"],
Cell[524209, 10717, 5858, 109, 897, "Input"]
}, Closed]],
Cell[530082, 10829, 667, 10, 87, "Text"],
Cell[530752, 10841, 763, 19, 109, "Text"],

Cell[CellGroupData[{
Cell[531540, 10864, 166, 5, 33, "Text"],
Cell[531709, 10871, 5860, 107, 714, "Input",
  InitializationCell->True]
}, Closed]],
Cell[537584, 10981, 290, 7, 30, "Text"],
Cell[537877, 10990, 311, 10, 33, "Text"],
Cell[538191, 11002, 257, 5, 33, "Text"],
Cell[538451, 11009, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

