(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    192173,       3894]*)
(*NotebookOutlinePosition[    193181,       3930]*)
(*  CellTagsIndexPosition[    193104,       3924]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[{
  StyleBox["Chapter 10  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Conformal Mapping",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Overview",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe terminology \"",
  StyleBox[ButtonBox["conformal mapping",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ConformalMapping.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  "\" should have a familiar sound.  In 1569 the Flemish cartographer \
Gerardus Mercator (1512--1594) devised a cylindrical map projection that \
preserves angles.  The Mercator projection is still used today for world \
maps.  Another map projection known to the ancient Greeks is the \
stereographic projection. It is also conformal (i.e., angle preserving), and \
we introduced it in Chapter 2 when we defined the Riemann sphere. In complex \
analysis a function preserves angles if and only if it is analytic or \
anti-analytic (i.e., the conjugate of an analytic function).  A significant \
result, known as Riemann mapping theorem, states that any simply connected \
domain (other than the entire complex plane) can be mapped conformally onto \
the unit disk. "
}], "Text"],

Cell[TextData[StyleBox["10.1  Basic Properties of Conformal Mappings",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tLet ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " be an analytic function in the domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", and let  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  be a point in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  If  ",
  Cell[BoxData[
      \(f' \((z\_0)\) \[NotEqual] 0\)]],
  ",  then we can express ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " in the form  \n\n",
  StyleBox["(10-1)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(f \((z)\) = 
        f \((z\_0)\) + 
          f' \((z\_0)\) \((z - z\_0)\) + \[Eta] \((z)\) \((z - z\_0)\)\)]],
  ",  \n\nwhere  ",
  Cell[BoxData[
      \(\[Eta] \((z)\) \[Rule] \(0\ \ as\ \ z \[Rule] z\_0\)\)]],
  ".  If ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " is near ",
  Cell[BoxData[
      \(z\_0\)]],
  ", then the transformation  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  has the linear approximation  \n\n\t\t\t",
  Cell[BoxData[
      \(S \((z)\) = A + B \((z - z\_0)\)\)]],
  ",  \n\nwhere  ",
  Cell[BoxData[
      \(A = \(f \((z\_0)\)\ \ and\ \ B = f' \((z\_0)\)\)\)]],
  ".  Because  ",
  Cell[BoxData[
      \(\[Eta] \((z)\) \[Rule] 0\)]],
  "  when  ",
  Cell[BoxData[
      \(z \[Rule] z\_0\)]],
  ",  for points near ",
  Cell[BoxData[
      \(z\_0\)]],
  " the transformation  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  has an effect much like the linear mapping  ",
  Cell[BoxData[
      \(w = S \((z)\)\)]],
  ".  The effect of the linear mapping  S  is a rotation of the plane through \
the angle  ",
  Cell[BoxData[
      \(\[Alpha]\  = \ Arg \((f' \((z\_0)\))\)\)]],
  ",  followed by a magnification by the factor  ",
  Cell[BoxData[
      \(\(\(|\)\(f' \((z\_0)\)\)\(|\)\)\)]],
  ",  followed by a rigid translation by the vector  ",
  Cell[BoxData[
      \(A + Bz\_0\)]],
  ".  Consequently, the mapping  ",
  Cell[BoxData[
      \(w = S \((z)\)\)]],
  "  preserves angles at the point  ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  We now show that the mapping  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  also preserves angles at  ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\n\tFor a smooth curve that passes through the point  ",
  Cell[BoxData[
      \(z \((0)\) = z\_0\)]],
  ",  we use the notation  \n\n\t\t\t",
  Cell[BoxData[
      \(C : \ 
          z \((t)\)\ \  = \ \ x \((t)\)\  + \ \[ImaginaryI]\ y \((t)\)\)]],
  ",  \n\nfor  ",
  Cell[BoxData[
      \(\(-1\) \[LessEqual] t \[LessEqual] 1\)]],
  ".   \n\t\n\tA vector ",
  Cell[BoxData[
      \(T\&\[RightVector]\)]],
  " tangent to ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " at the point ",
  Cell[BoxData[
      \(z\_0\)]],
  " is given by  \n\n\t\t\t",
  Cell[BoxData[
      \(T\&\[RightVector]\  = \ z' \((0)\)\)]],
  ",  \n\t\t\t\nwhere the complex number  ",
  Cell[BoxData[
      \(z' \((0)\)\)]],
  "  is expressed as a vector."
}], "Text"],

Cell[TextData[{
  "\tThe angle of inclination of  ",
  Cell[BoxData[
      \(T\&\[RightVector]\)]],
  "  with respect to the positive ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " axis is  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Beta]\  = \ Arg\ z' \((0)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "The image of ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " under the mapping ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  " is the curve ",
  StyleBox["K",
    FontFamily->"Courier New"],
  " in the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane given by the formula \n\n\t\t\t",
  Cell[BoxData[
      \(K : \ 
          w \((t)\)\ \  = \ \ u \((x \((t)\), 
              y \((t)\))\)\  + \ \[ImaginaryI]\ v \((x \((t)\), 
              y \((t)\))\)\)]],
  ".  \n\nWe can use the chain rule to show that a vector  ",
  Cell[BoxData[
      \(\(T\^*\)\&\[RightVector]\)]],
  "  tangent to ",
  StyleBox["K",
    FontFamily->"Courier New"],
  " at the point  ",
  Cell[BoxData[
      \(w\_0 = f \((z\_0)\)\)]],
  "  is given by  \n\n\t\t\t",
  Cell[BoxData[
      \(\(T\^*\)\&\[RightVector]\ \  = \ \ \(w' \((0)\)\ \  = \ \ f' \((z\_0)\
\) z' \((0)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "The angle of inclination of ",
  Cell[BoxData[
      \(\(T\^*\)\&\[RightVector]\)]],
  " with respect to the positive u axis is \n\n\t\t\t",
  Cell[BoxData[
      \(\[Gamma]\ \  = \ \ \(Arg\ w' \((0)\)\ \  = \ \ \(Arg\ f' \((z\_0)\)\ \
\  + \ \ Arg\ z' \((0)\)\ \  = \ \ \[Alpha]\ \  + \ \ \[Beta]\)\)\)]],
  ",   \n\nwhere  ",
  Cell[BoxData[
      \(\[Alpha]\  = \ Arg\ f' \((z\_0)\)\)]],
  ".  \n\n\tTherefore the effect of the transformation ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  " is to rotate the angle of inclination of the tangent vector ",
  Cell[BoxData[
      \(T\&\[RightVector]\)]],
  " at ",
  Cell[BoxData[
      \(z\_0\)]],
  " through the angle ",
  Cell[BoxData[
      \(\[Alpha]\  = \ Arg\ f' \((z\_0)\)\)]],
  "  to obtain the angle of inclination of the tangent vector ",
  Cell[BoxData[
      \(\(T\^*\)\&\[RightVector]\)]],
  " at ",
  Cell[BoxData[
      \(w\_0 = f \((z\_0)\)\)]],
  ".  This situation is illustrated in Figure 10.1."
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 10.1",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/conformalmapping/\
ConformalMappingFigures/mat1001.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The tangents at the points ",
  Cell[BoxData[
      RowBox[{\(z\_0\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(w\_0\)}]]],
  ", where ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is an analytic function and ",
  Cell[BoxData[
      \(f' \((z\_0)\) \[NotEqual] 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tA mapping   ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  is said to be angle preserving, or ",
  StyleBox[ButtonBox["conformal",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ConformalTransformation.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " at ",
  Cell[BoxData[
      \(z\_0\)]],
  ", if it preserves angles between oriented curves in magnitude as well as \
in orientation.  Theorem 10.1 shows where a mapping by an analytic function \
is conformal. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Theorem 10.1 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Conformal Mapping",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ConformalMapping.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " be an analytic function in the domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", and let ",
  Cell[BoxData[
      \(z\_0\)]],
  " be a point in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  If  ",
  Cell[BoxData[
      \(f' \((z\_0)\) \[NotEqual] 0\)]],
  ",  then ",
  StyleBox["f(z)",
    FontFamily->"Courier New"],
  " is conformal at ",
  Cell[BoxData[
      \(z\_0\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 10.2",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/conformalmapping/\
ConformalMappingFigures/mat1002.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The analytic mapping ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  " is conformal at the point ",
  Cell[BoxData[
      \(z\_0\)]],
  ", where ",
  Cell[BoxData[
      \(f' \((z\_0)\) \[NotEqual] 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 10.1 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the mapping  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = cos \((z)\)\)\)]],
  "  is conformal at the points ",
  Cell[BoxData[
      \(z\_1 = \ \[ImaginaryI]\)]],
  ", ",
  Cell[BoxData[
      \(z\_2 = \ 1\)]],
  ", ",
  Cell[BoxData[
      \(z\_3 = \ \[Pi] + \[ImaginaryI]\)]],
  " and , ",
  Cell[BoxData[
      \(z\_4 = \ 1 - \[ImaginaryI]\)]],
  " and determine the angle of rotation given by ",
  Cell[BoxData[
      \(\[Alpha] = Arg \((f' \((z)\))\)\)]],
  " at the given points. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000800000_2000`400?l0
0000o`00003oo`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0
ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3o
ool00?l0ooooo`3oool20?ooo`00o`3ooooZ0?ooo`030000003oool0oooo
01@0oooo003o0?ooonX0oooo00<000000?ooo`3oool0503oool004l0oooo
1@00003o0?oooiH0oooo00<000000?ooo`3oool0503oool00540oooo00<0
00000?ooo`3oool0o`3ooonF0?ooo`030000003oool0oooo01@0oooo001A
0?ooo`030000003oool0oooo00<0oooo0`00003o0?oooi00oooo00<00000
0?ooo`3oool0503oool004T0oooo100000040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0o`3ooon@0?ooo`030000003oool0oooo
01@0oooo001A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0o`3ooon@0?ooo`030000003oool0oooo01@0oooo001@0?ooo`800000
1@3oool00`000000oooo0?ooo`3o0?oooi00oooo00<000000?ooo`3oool0
503oool005L0oooo00<000000?ooo`3oool0o`3ooon@0?ooo`030000003o
ool0oooo01@0oooo001G0?ooo`030000003oool0oooo0?l0ooooT03oool0
0`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?ooo`3o0?oo
oi00oooo00<000000?ooo`3oool0503oool005L0oooo00<000000?ooo`3o
ool0o`3ooon@0?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000
003oool0oooo0?l0ooooT03oool00`000000oooo0?ooo`0D0?ooo`00E`3o
ool00`000000oooo0?ooo`3o0?oooi00oooo00<000000?ooo`3oool0503o
ool005L0oooo00<000000?ooo`3oool0o`3ooon@0?ooo`030000003oool0
oooo01@0oooo001G0?ooo`030000003oool0oooo0?l0ooooT03oool00`00
0000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?ooo`3o0?oooi00
oooo00<000000?ooo`3oool0503oool005L0oooo00<000000?ooo`3oool0
o`3oool<0?ooo`030000o`3oool0oooo07X0oooo1@0000020?ooo`030000
003oool0oooo01@0oooo001G0?ooo`030000003oool0oooo0?l0oooo303o
ool30000og`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0D0?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00@0003o
0?ooo`3oool0oooo0P000?mj0?ooo`030000003oool0oooo0080oooo0P00
000E0?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1_0?ooo`@00000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo001G0?oo
o`030000003oool0oooo0?l0oooo2P3oool00`000?l0oooo0?ooo`050?oo
o`80003oM`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01@0oooo001G0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000?l0
oooo0?ooo`070?ooo`80003oM03oool2000000@0oooo00<000000?ooo`3o
ool0503oool005L0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000
o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0M`3oool00`000000oooo
0?ooo`0D0?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00<0
003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`1f0?ooo`030000003o
ool0oooo01@0oooo001G0?ooo`030000003oool0oooo0?l0oooo203oool0
0`000?l0oooo0?ooo`0=0?ooo`80003oMP3oool00`000000oooo0?ooo`0D
0?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`1c0?ooo`030000003oool0oooo
01@0oooo001G0?ooo`030000003oool0oooo0?l0oooo1`3oool00`000?l0
oooo0?ooo`0?0?ooo`040?l0003oool0003o0000og<0oooo00<000000?oo
o`3oool0503oool005L0oooo00<000000?ooo`3oool0o`3oool70?ooo`03
0000o`3oool0oooo00l0oooo00@0o`000?ooo`3oool0oooo0P000?ma0?oo
o`030000003oool0oooo01@0oooo001G0?ooo`030000003oool0oooo0?l0
oooo1P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00@0
oooo0P000?m_0?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000
003oool0oooo0?l0oooo1P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
003oool0oooo00H0oooo0P000?m]0?ooo`030000003oool0oooo01@0oooo
001G0?ooo`030000003oool0oooo0?l0oooo1@3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0JP3o
ool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?ooo`3o
0?ooo`D0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo06T0oooo00<000000?ooo`3oool0503oool0
05L0oooo00<000000?ooo`3oool0o`3oool40?ooo`030000o`3o0000oooo
00l0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`1X0?oo
o`030000003oool0oooo01@0oooo001G0?ooo`030000003oool0oooo0?l0
oooo103oool010000?l0oooo0?l0003o000>0?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool0I`3oool00`000000oooo0?ooo`0D0?oo
o`00E`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00<0003o0?ooo`3o
ool00P3oool30?l000X0oooo00<0o`000?ooo`3oool03@3oool010000?l0
oooo0000o`000?mW0?ooo`030000003oool0oooo01@0oooo001G0?ooo`03
0000003oool0oooo0?l0oooo0`3oool00`000?l0oooo0?ooo`050?ooo`80
o`001`3oool00`3o0000oooo0?ooo`0>0?ooo`040000o`3oool0oooo0?oo
o`80003oI@3oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000
oooo0?ooo`3o0?ooo`80oooo00<0003o0?ooo`3oool0203oool30?l000@0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`040?ooo`80
003oH`3oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo
0?ooo`3o0?ooo`80oooo00<0003o0?ooo`3oool02`3oool20?l000030?oo
o`3o0000oooo00h0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo
0?ooo`1P0?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000003o
ool0oooo0?l0oooo0P3oool00`000?l0oooo0?ooo`0=0?ooo`<0o`003P3o
ool00`000?l0oooo0?ooo`080?ooo`80003oH03oool00`000000oooo0?oo
o`0D0?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooo`40oooo00<0003o
0?ooo`3oool03`3oool0103o0000oooo0?l0003o000;0?ooo`030000o`3o
ool0oooo00/0oooo00<0003o0?l0003oool0G@3oool00`000000oooo0?oo
o`0D0?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooo`40oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`020?ooo`80o`002@3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0003o05d0oooo00<00000
0?ooo`3oool0503oool005L0oooo00<000000?ooo`3oool0o`3oool10?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0103oool20?l0
00H0oooo00<0003o0?ooo`3oool0303oool0103o0000oooo0?ooo`000?mL
0?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000003oool0oooo
0?l0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`070?oo
o`80o`00103oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool0F@3oool00`000000oooo0?ooo`0D0?oo
o`00E`3oool00`000000oooo0?ooo`3o0?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool02@3oool20?l000030?ooo`000?l0oooo00d0
oooo00<0o`000?ooo`3oool00`3oool20000oeT0oooo00<000000?ooo`3o
ool0503oool005L0oooo00<000000?ooo`3oool0o`3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00/0oooo00<0o`000000o`3oool0
303oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo05H0oooo
00<000000?ooo`3oool0503oool005L0oooo00<000000?ooo`3oool0o`3o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00/0oooo00@0
003o0?ooo`3o0000o`002`3oool00`3o0000oooo0?ooo`070?ooo`80003o
EP3oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?oo
o`3n0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0303o
ool010000?l0oooo0?ooo`3oool20?l000P0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo
001G0?ooo`030000003oool0oooo0?h0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00@0oooo0P3o
00050?ooo`030?l0003oool0oooo00X0oooo00@0003o0?ooo`000?l0003o
D`3oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?oo
o`3n0?ooo`<0003o3P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00H0oooo0P3o00030?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool00P3oool20000ocl0oooo0P0000040?ooo`800000103o
ool2000000@0oooo00<000000?ooo`3oool0503oool005L0oooo00<00000
0?ooo`3oool0oP3oool00`000?l0oooo0?ooo`040000o`T0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`080?ooo`<0o`002`3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo03/0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo01@0oooo001G0?ooo`030000003oool0oooo0?d0oooo00<0
003o0?ooo`3oool01@3oool20000o`L0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0:0?ooo`040?l0003oool0o`000?l000T0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0j0?ooo`040000
003oool0oooo000000/0oooo00@000000?ooo`3oool0oooo0P00000E0?oo
o`00E`3oool00`000000oooo0?ooo`3m0?ooo`030000o`3oool0oooo00L0
oooo10000?l20?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool02P3oool0103o0000oooo0?ooo`3oool20?l000H0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`0c0?ooo`@000000P3oool01000
0000oooo0?ooo`0000090?ooo`800000103oool00`000000oooo0?ooo`0D
0?ooo`00E`3oool00`000000oooo0?ooo`3m0?ooo`030000o`3oool0oooo
00/0oooo0P000?l00`3o0000003o0?ooo`0<0?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool0103oool20?l000<0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0000o`0j0?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D
0?ooo`00E`3oool00`000000oooo0?ooo`3l0?ooo`030000o`3oool0oooo
00h0oooo00@0o`000?ooo`000?l0003o2P3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00H0oooo0P3o00000`3oool0003o0?ooo`09
0?ooo`040?l0003oool0oooo0000ocX0oooo0P00000:0?ooo`<000000`3o
ool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?ooo`0h
0?ooo`D00000>@3oool400000440oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo00h0oooo00@0o`00
0?ooo`3oool0oooo0`000?l70?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool0203oool00`000?l0o`000?ooo`080?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool0B@3oool00`000000oooo0?oo
o`0D0?ooo`00E`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0@`3oool010000000oooo0?ooo`00
000l0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool01@3o
ool40000o`80oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`090?ooo`040000o`3oool0o`000?l000L0oooo00<0o`000?ooo`3oool0
0`3oool20000odT0oooo00<000000?ooo`3oool0503oool005L0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`000000?03oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo00T0oooo10000?l;0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool20?l000@0oooo00<0
o`000?ooo`3oool01P3oool20000odL0oooo00<000000?ooo`3oool0503o
ool005L0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`000000>`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`000?l00P000?l80?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0103oool0103o0000oooo0?ooo`3o00090?ooo`80003oA`3o
ool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo03T0oooo00@000000?ooo`3oool00000@P3o
ool5000003X0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00<0oooo0P000?l50?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool01@3oool20?l000T0oooo00@0
003o0?ooo`3oool0003oAP3oool00`000000oooo0?ooo`0D0?ooo`00E`3o
ool00`000000oooo0?ooo`0i0?ooo`800000?03oool200000880oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00D0oooo0`000?l20?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool01`3oool30?l000H0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo001G
0?ooo`030000003oool0oooo0?/0oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00P0oooo0P000?l0
0`3o0000003o0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00D0o`00
0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`00E`3oool0
0`000000oooo0?ooo`3k0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
003o0080003o1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo0080oooo0P3o00000`3oool0003o0?ooo`070?ooo`030000o`3o0000
oooo0440oooo00<000000?ooo`3oool0503oool005L0oooo00<000000?oo
o`3oool0nP3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?oo
o`@0003o00<0oooo0000o`3oool01`3oool00`3o0000oooo0?ooo`050?oo
o`030?l000000?l0oooo00L0oooo00<0o`000000o`3oool0@@3oool00`00
0000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?ooo`3T0?ooo`80
000000<0oooo0000000000004@3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`070?ooo`<0003o1`3oool00`3o0000oooo0?ooo`050?ooo`04
0000o`3oool0o`000?l000D0oooo00@0o`000?ooo`3oool0003o@@3oool0
0`000000oooo0?ooo`0D0?ooo`00E`3ooooQ000000L0oooo00<000000?oo
o`0000004P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`080?oo
o`040000o`3oool0003o0000o`D0oooo00<0o`000?ooo`3oool01@3oool0
1@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3oool00P3o
ool20000ocl0oooo00<000000?ooo`3oool0503oool005L0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A
0?ooo`030000o`3o0000o`0000D0o`00203oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`020?ooo`<0003o00<0oooo0?l0003oool01P3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0o`0000H0oooo00<0003o
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`0S0?ooo`80000000<0oooo0000
000000004@3oool00`000?l0oooo0?ooo`050?ooo`H0o`000P3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`050?ooo`030000o`3o0000oooo
00H0oooo00<0003o0?ooo`3oool0103oool20?l000L0oooo00<0003o0?oo
o`3oool0?03oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000
oooo0?ooo`3j0?ooo`030000o`3oool0oooo00/0oooo2@3o00070?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0003o0080003o0`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0o`0000D0oooo00<0003o0?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo
0?ooo`3j0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
103oool50?l00080oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
0P3oool40000o`L0oooo00<0o`000?ooo`3oool00P3o00000`3oool0003o
0000o`100?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000003o
ool0oooo0?X0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`090?ooo`80o`0000<0003o0?l0003o00000`3o00050?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`<0003o103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo0400oooo00<000000?ooo`3oool0503oool005L0oooo00<00000
0?ooo`3oool0nP3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool0103oool70?l000T0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0
oooo0?ooo`80003o00<0oooo0?l0003oool0103oool00`000?l0oooo0?oo
o`110?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000003oool0
oooo0?X0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`05
0?ooo`@000000P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
o`0000<0o`00103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0o`000?ooo`04
0?ooo`030000o`3oool0oooo0080oooo1@00000j0?ooo`030000003oool0
oooo01@0oooo001G0?ooo`030000003oool0oooo0?T0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?oo
o`@0o`0000<0003o0?l0003oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`000?l00P000?l00`3o
ool0003o0?ooo`060?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0503oool005L0oooo00<000000?ooo`3oool0n@3oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3o00001@3o00000`3oool0o`000?ooo`060?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`060?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0503oool005L0oooo00<000000?ooo`3oool0n@3oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0000000<00000103oool01@000000oooo
0?ooo`3oool0003o00/0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`050?ooo`L0o`0000<0oooo0000o`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`000000000000800000103oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000
003oool0oooo0?T0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`050?ooo`040000003oool0oooo00000080oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool00`3oool0103o0000003o0?l0003o00030?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo01@0oooo001G0?ooo`03
0000003oool0oooo0?T0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`060?ooo`8000000`3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00H0o`000P3oool00`000?l0
oooo0?ooo`060?ooo`800000?03oool00`000000oooo0?ooo`0D0?ooo`00
E`3oool00`000000oooo0?ooo`3i0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3o00000`000?l0oooo0?ooo`140?ooo`030000003oool0oooo01@0oooo
001G0?ooo`030000003oool0oooo0?T0oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo0?oo
o`3oool0003o04L0oooo00<000000?ooo`3oool0503oool005L0oooo00<0
00000?ooo`3oool0n@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0D0?ooo`00E`3oool0
0`000000oooo0?ooo`3i0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00H0oooo0`3o00060?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo04D0oooo00<000000?ooo`3oool01@3oool4000000/0oooo001G0?oo
o`030000003oool0oooo0?H0oooo0`00000@0000o`030?l000000?l0003o
01H0003o0P3o00070000o`D0o`001@000?l00`3o0000003o0000o`0:0000
o`80o`0010000?m8000000H0oooo00@000000?ooo`3oool00000303oool0
05L0oooo00<000000?ooo`3oool0n@3oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`080?ooo`80o`001`3oool50?l000D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000303oool0
05L0oooo00<000000?ooo`3oool0n@3oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`050?ooo`D0o`001@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`150?ooo`030000003oool0oooo00<0oooo0P0000000`3o
ool000000000000<0?ooo`00E`3oool00`000000oooo0?ooo`3i0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo0`3o00060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool20?l000<0
oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0D0?ooo`00
E`3oool00`000000oooo0?ooo`3i0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0
oooo0000o`170?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000
003oool0oooo0?T0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?l000020?l000030000
o`3oool0oooo04@0oooo00<000000?ooo`3oool0503oool005L0oooo00<0
00000?ooo`3oool0n@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103o
ool010000?l0oooo0?ooo`3oool40?l000<0oooo00<0003o0?ooo`3oool0
A03oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?oo
o`3i0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01P3oool0103o0000oooo0?ooo`3oool30?l000040000
o`3o0000o`000?l00080oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000
003oool0oooo0?T0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`050?ooo`D0o`000`3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
@`3oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?oo
o`3i0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3o00001@3o00000`3oool0o`000?ooo`060?ooo`030000o`3o
ool0oooo00<0oooo00@0o`000?ooo`3oool0oooo0P000?m50?ooo`030000
003oool0oooo01@0oooo001G0?ooo`030000003oool0oooo0?T0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool40?l000030000o`3o
0000oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`030?ooo`040?l0003oool0003o0000o`80oooo00<0003o0?ooo`3oool0
@P3oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?oo
o`3j0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`080?ooo`L0o`00103oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0440oooo00<0
00000?ooo`3oool0503oool005L0oooo00<000000?ooo`3oool0nP3oool0
0`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00X0oooo00@0003o
0?ooo`3oool0oooo1`3o00000`3oool0o`000?ooo`090?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`020?ooo`80003o00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`110?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000003oool0
oooo0?X0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`09
0?ooo`80o`0000<0003o0?l0003o0000203oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool4
0000o`<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`10
0?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000003oool0oooo
09l0oooo?P000?lM0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool02@3o00020?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
0080oooo10000?l70?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0000
o`110?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000003oool0
oooo09l0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo01/0oooo00<0003o0?ooo`3oool02`3oool50?l000/0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool00P000?l40?ooo`030000o`3oool0
oooo00@0oooo00@0o`000?ooo`3o0000o`000`3oool20000ocl0oooo00<0
00000?ooo`3oool0503oool005L0oooo00<000000?ooo`3oool0W`3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool06`3oool0
0`000?l0oooo0?ooo`060?ooo`D0o`000P3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3o0000003o00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo03`0oooo00<000000?ooo`3oool0503oool005L0oooo00<000000?oo
o`3oool0W`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool06`3oool00`000?l0o`000?l000060?l000L0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool00`3oool20000o`030?ooo`3o0000oooo
00H0oooo00<0003o0?ooo`3oool00`3oool30?l000H0oooo00<0003o0?oo
o`3oool0?@3oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000
oooo0?ooo`2O0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`0K0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`000?l00P000?l40?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool00P3o00030?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo0?ooo`0D0?ooo`00
E`3oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00L0oooo0`000?l70?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3o00001P3oool00`3o0000oooo0?ooo`020000od00oooo
00<000000?ooo`3oool0503oool005L0oooo00<000000?ooo`3oool0W`3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool06`3o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?ooo`<0003o00<0
oooo0000o`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000000o`3oool0@@3oool00`000000oooo0?oo
o`0D0?ooo`00E`3oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0L0?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0003o00<0003o1@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00<0oooo0P3o00000`3oool0003o0?ooo`07
0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool0503oool0
05L0oooo00<000000?ooo`3oool0W`3oooln0?l001h0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00T0oooo00<0003o0?l000000?l02@3oool00`000?l0oooo0?ooo`060?oo
o`040?l0003oool0oooo0?ooo`80o`00103oool00`000?l0oooo0?ooo`03
0?ooo`80003o@`3oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`00
0000oooo0?ooo`2O0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0L0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`050?ooo`@0003o00<0oooo0?l0
003oool02@3oool00`000?l0oooo0?ooo`070?ooo`<0o`001P3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04<0oooo00<000000?oo
o`3oool0503oool005L0oooo00<000000?ooo`3oool0W`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0703oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool00P3oool30000o`D0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00@0003o0?ooo`3o
ool0003oAP3oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000
oooo0?ooo`2O0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`0L0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool02`3oool010000?l0oooo0000o`000?l90?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool00`3oool30?l000030?ooo`3o0000oooo
00P0oooo0P000?m70?ooo`030000003oool0oooo01@0oooo001G0?ooo`03
0000003oool0oooo09l0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0:0?ooo`<0003o2`3oool00`3o0000oooo0?ooo`080?ooo`04
0000o`3oool0oooo0?ooo`80o`001@3oool00`3o0000oooo0?ooo`050?oo
o`80003oB03oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000
oooo0?ooo`2O0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`0M0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool01P3oool40000o`030?ooo`000?l0oooo00`0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0o`000?l000080?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0B03oool00`000000oooo0?ooo`0D0?ooo`00
E`3oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo00h0oooo
00@0o`000?ooo`3oool0oooo10000?l60?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000003o0?ooo`0:0?ooo`05
0?l0003oool0oooo0?ooo`000?l0B`3oool00`000000oooo0?ooo`0D0?oo
o`00E`3oool00`000000oooo0?ooo`2O0?oooch0003o7`3oool00`000?l0
oooo0?ooo`0>0?ooo`040?l0003oool0003o0000o`X0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`040?ooo`80o`000P3oool00`00
0?l0oooo0?ooo`080?ooo`040?l0003oool0oooo0000od`0oooo00<00000
0?ooo`3oool0503oool005L0oooo00<000000?ooo`3oool0W`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool07@3oool00`00
0?l0oooo0?ooo`0<0?ooo`80003o00<0o`000000o`3oool0303oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo0P3o00040?oo
o`030000o`3oool0oooo00T0oooo00<0o`000000o`3oool0>P3oool20000
00@0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0D0?oo
o`00E`3oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo00H0
oooo1@000?l20?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool02P3oool01@3o0000oooo0?ooo`3oool0o`0000L0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`0i0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0D0?ooo`00E`3oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0
oooo0080oooo10000?l80?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool02`3oool30?l000T0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`0j0?ooo`040000003oool0oooo000000/0oooo00@0
00000?ooo`3oool0oooo0P00000E0?ooo`00E`3oool00`000000oooo0?oo
o`2O0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`0O0?ooo`040000o`3oool0003o0000o``0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`090?ooo`80o`002`3oool00`000?l0oooo
0?ooo`040?ooo`80003o?@3oool010000000oooo0?ooo`0000090?ooo`80
0000103oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo
0?ooo`2O0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`0O0?ooo`80003o3`3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00H0oooo0`3o00020?ooo`030?l0003oool0oooo00T0oooo
00@0003o0?ooo`3oool0oooo0P000?lo0?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?oo
o`00E`3oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`040?ooo`80
o`001@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0003o0480
oooo0P00000:0?ooo`<000000`3oool00`000000oooo0?ooo`0D0?ooo`00
E`3oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`0P0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`1C0?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000003o
ool0oooo09l0oooo?P3o000R0?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`020?l000X0oooo00<0
o`000?ooo`3oool01`3oool20000oeH0oooo00<000000?ooo`3oool0503o
ool005L0oooo00<000000?ooo`3oool0W`3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?l0003oool02`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo05H0oooo00<00000
0?ooo`3oool0503oool005L0oooo00<000000?ooo`3oool0W`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool08@3oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00X0oooo0P3o00000`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00<0oooo0P000?mI0?oo
o`030000003oool0oooo01@0oooo001G0?ooo`030000003oool0oooo09l0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0240
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`080?ooo`80
o`000`3oool00`000?l0oooo0?ooo`0<0?ooo`050?l0003oool0oooo0?oo
o`000?l0F`3oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000
oooo0?ooo`2O0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool01@3oool20?l000D0oooo00<0003o0?ooo`3oool0303oool0103o0000
oooo0000o`000?mL0?ooo`030000003oool0oooo01@0oooo001G0?ooo`03
0000003oool0oooo09l0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool20?l000H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool08@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0080
oooo0`3o00080?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0G03oool00`000000oooo0?ooo`0D0?ooo`00C`3oool5000000<0oooo
00<000000?ooo`3oool0W`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`030?ooo`@0o`001@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`0R0?ooo`030000o`3oool0oooo00h0oooo00@0o`000?ooo`3o0000
o`002`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo05d0
oooo00<000000?ooo`3oool0503oool00540oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo0080oooo1P3o00040?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo0280oooo00<0003o0?ooo`3oool03@3oool30?l000h0oooo
00<0003o0?ooo`3oool0203oool20000of00oooo00<000000?ooo`3oool0
503oool00540oooo00<000000?ooo`3oool00`3oool3000009l0oooo7000
0?l60?l001`0003o903oool00`000?l0oooo0?ooo`0;0?ooo`80o`0000<0
oooo0?l0003oool03P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3o
ool0oooo0600oooo00<000000?ooo`3oool0503oool00540oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00<0oooo103o00050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool01`3oool3
0?l000@0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`04
0?ooo`80003oH`3oool00`000000oooo0?ooo`0D0?ooo`00D@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo09l0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool20?l000H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool08`3oool00`000?l0oooo0?ooo`050?oo
o`80o`001`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?ooo`0D0?oo
o`00D03oool2000000D0oooo00<000000?ooo`3oool0W`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0903oool00`000?l0
oooo0?ooo`020?ooo`80o`002P3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo0080003oIP3oool00`000000oooo0?ooo`0D0?ooo`00
E`3oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`0T0?ooo`030000o`3oool0oooo0080o`00
3@3oool00`3o0000oooo0?ooo`0=0?ooo`80003oJ03oool00`000000oooo
0?ooo`0D0?ooo`00E`3oool00`000000oooo0?ooo`2O0?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3o
0000oooo00h0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`1X0?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000003oool0
oooo09l0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo02D0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo06T0oooo00<000000?ooo`3oool0503oool0
05L0oooo00<000000?ooo`3oool0W`3oooln0?l002P0oooo00<0003o0?oo
o`3oool03P3oool00`3o0000oooo0?ooo`080?ooo`80003oK03oool00`00
0000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?ooo`2O0?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0V0?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool01@3oool20000ofh0
oooo00<000000?ooo`3oool0503oool005L0oooo00<000000?ooo`3oool0
W`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
9`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00<0oooo
0P000?m`0?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000003o
ool0oooo09l0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo02L0oooo00<0003o0?ooo`3oool03`3oool01@3o0000oooo0?oo
o`3oool0003o0780oooo00<000000?ooo`3oool0503oool005L0oooo00<0
00000?ooo`3oool0W`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0>0?ooo`040?l0003o
ool0003o0000og<0oooo00<000000?ooo`3oool0503oool005L0oooo00<0
00000?ooo`3oool0W`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo07<0oooo00<000000?ooo`3oool0503oool005L0oooo00<00000
0?ooo`3oool0W`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0
oooo07@0oooo00<000000?ooo`3oool0503oool005L0oooo00<000000?oo
o`3oool0W`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0:@3oool00`000?l0oooo0?ooo`0;0?ooo`80003oM`3oool00`00
0000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?ooo`2O0?oooch0
003o;03oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo07L0
oooo00<000000?ooo`3oool0503oool005L0oooo00<000000?ooo`3oool0
W`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
:P3oool00`000?l0oooo0?ooo`070?ooo`80003oNP3oool00`000000oooo
0?ooo`0D0?ooo`00E`3oool00`000000oooo0?ooo`2O0?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3o
ool0oooo00@0oooo0P000?me0?ooo`D000000P3oool00`000000oooo0?oo
o`0D0?ooo`00E`3oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3oool0
oooo0080oooo0P000?mi0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0503oool005L0oooo00<000000?ooo`3oool0W`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0;03oool01000
0?l0oooo0000o`000?mk0?ooo`030000003oool0oooo0080oooo0P00000E
0?ooo`00E`3oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`0/0?ooo`80003oO@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo001G0?ooo`03
0000003oool0oooo09l0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo0:/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?ooo`2O0?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`2Z0?ooo`800000
103oool00`000000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?oo
o`2O0?oooch0o`00/P3oool00`000000oooo0?ooo`0D0?ooo`00E`3oool0
0`000000oooo0?ooo`2O0?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`2`0?ooo`030000003oool0oooo01@0oooo001G0?oo
o`030000003oool0oooo09l0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo0;00oooo00<000000?ooo`3oool0503oool005L0
oooo00<000000?ooo`3oool0W`3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0/03oool00`000000oooo0?ooo`0D0?ooo`00
E`3oool00`000000oooo0?ooo`2O0?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`2`0?ooo`030000003oool0oooo01@0oooo
001G0?ooo`030000003oool0oooo09l0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo0;00oooo00<000000?ooo`3oool0503o
ool005L0oooo00<000000?ooo`3oool0W`3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0/03oool00`000000oooo0?ooo`0D
0?ooo`00E`3oool00`000000oooo0?ooo`2O0?oooch0003o/P3oool00`00
0000oooo0?ooo`0D0?ooo`00E`3oool00`000000oooo0?ooo`3o0?oooi00
oooo00<000000?ooo`3oool0503oool005L0oooo00<000000?ooo`3oool0
o`3ooon@0?ooo`030000003oool0oooo01@0oooo001G0?ooo`030000003o
ool0oooo0?l0ooooT03oool00`000000oooo0?ooo`0D0?ooo`00E`3oool0
0`000000oooo0?ooo`3o0?oooi00oooo00<000000?ooo`3oool0503oool0
05L0oooo00<000000?ooo`3oool0o`3ooon@0?ooo`030000003oool0oooo
01@0oooo001G0?ooo`030000003oool0oooo0?l0ooooT03oool00`000000
oooo0?ooo`0D0?ooo`00o`3ooooZ0?ooo`030000003oool0oooo01@0oooo
003o0?ooonX0oooo00<000000?ooo`3oool0503oool00?l0ooooo`3oool2
0?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0oooo
o`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool0
05D0oooo0P00003o0?ooojX0oooo001F0?ooo`030000003oool0oooo0?l0
ooooZ03oool005L0oooo00<000000?ooo`3oool0o`3ooon?0?ooo`800000
5P3oool005H0oooo00<000000?ooo`000000o`3ooon@0?ooo`8000005P3o
ool005D0oooo00@000000?ooo`3oool00000o`3ooon?0?ooo`040000003o
ool0oooo000001D0oooo001D0?ooo`<0000000<0oooo000000000000o`3o
oon=0?ooo`8000000P3oool2000001@0oooo003o0?ooool0oooo0P3oool0
0?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo
0P3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{512, 188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  Because ",
  Cell[BoxData[
      \(f' \((z)\)\  = \ \(-\ sin\) \((z)\)\)]],
  ", we conclude that the mapping  ",
  Cell[BoxData[
      \(w = cos \((z)\)\)]],
  "  is conformal at all points except ",
  Cell[BoxData[
      \(z = n\ \[Pi]\)]],
  ", where n is an integer.  Calculation reveals that  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(f' \((z\_1)\)\ \  = \ \ \ \ \ \(f' \((\[ImaginaryI])\)\ \ \ \
\ \  = \ \ \(-\ \[ImaginaryI]\)\ sinh\ 1\)\), 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "\[IndentingNewLine]", 
          "\n", \(f' \((z\_2)\)\ \  = \ \ \ \ \ \(f' \((1)\)\ \ \ \ \  = \ \ \
\(-\ sin\)\ 1\)\), 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "\n", 
          "\[IndentingNewLine]", \(f' \((z\_3)\)\ \  = \ \ \(f' \((\[Pi] + \
\[ImaginaryI])\)\  = \ \ \[ImaginaryI]\ sinh\ 1\)\), 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{\(f' \((z\_4)\)\), "  ", "=", "  ", 
        RowBox[{\(f' \((1 - \[ImaginaryI])\)\), " ", "=", "  ", 
          RowBox[{\(\(-\ cosh\)\ 1\ sin\ 1\), "  ", "+", "  ", 
            RowBox[{"\[ImaginaryI]", " ", "cos", " ", "1", " ", "sinh", " ", 
              RowBox[{"1", 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[".",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}]}]}]}]}]],
  "   \n\nTherefore the angle of rotation is given by  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(\[Alpha]\_1\ \  = \ \ \(Arg \((f' \((z\_1)\))\)\ \  = \ \ \ \
\ \ \(f' \((\[ImaginaryI])\)\ \ \ \ \  = \ \ \(-\ \[ImaginaryI]\)\ sinh\ \
1\)\)\), 
          StyleBox[
            RowBox[{" ", 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "\n", 
          "\[IndentingNewLine]", \(\[Alpha]\_2\ \  = \ \ \(Arg \((f' \((z\_2)\
\))\)\ \  = \ \ \ \ \ \(f' \((1)\)\ \ \ \ \  = \ \ \(-\ sin\)\ 1\)\)\), 
          StyleBox[
            RowBox[{" ", 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "\n", 
          "\[IndentingNewLine]", \(\[Alpha]\_3\ \  = \ \ \(Arg \((f' \((z\_3)\
\))\)\ \  = \ \ \(f' \((\[Pi] + \[ImaginaryI])\)\  = \ \ \[ImaginaryI]\ sinh\ \
1\)\)\), 
          StyleBox[
            RowBox[{"  ", 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["  ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], 
        StyleBox["  ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{\(\[Alpha]\_4\ \  = \ \ \(Arg \((f' \((z\_4)\))\)\ \  = \ \ \
\(f' \((1 - \[ImaginaryI])\)\  = \ \ \(-\ 
                    cosh\)\ 1\ sin\ 1\ \  + \ \ \[ImaginaryI]\ cos\ 1\ sinh\ \
1\)\)\), " "}], "\[IndentingNewLine]", 
      RowBox[{"                                          ", 
        RowBox[{"=", "  ", 
          RowBox[{"\[Pi]", "-", 
            RowBox[{"arctan", 
              RowBox[{\((cot\ 1\ tanh\ 1)\), 
                StyleBox[
                  RowBox[{" ", 
                    StyleBox[" ",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}]}]], 
                StyleBox[".",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}]}]}]}]}]],
  "    "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["Enter the function f(z) = cos(z).", "Text"],

Cell[BoxData[{
    \(\(Remove[z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f];\)\ \), "\n", 
    \(\(f[z_]\  = \ Cos[z];\)\ \), "\n", 
    \(\(Print["\<f(z) = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Consider the mapping  w = cos(z)  near ",
  Cell[BoxData[
      \(z\_1 = \ \[ImaginaryI]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Z\  = \ \[ImaginaryI];\)\ \), "\n", 
    \(\(Print["\<     f(z) = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<    f'(z) = \>", \(f'\)[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<   At \!\(z\_1\) = \>\"", 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    f(\>", Z, "\<) = \>", 
        f[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    f(\>", Z, "\<) = \>", 
        N[f[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<   f'(\>", Z, "\<) = \>", \(f'\)[Z], "\< = \>", 
        N[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_1\) = Arg(f'(\!\(z\_1\))) = \>\"", 
        Arg[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_1\) = Arg(f'(\!\(z\_1\))) = \>\"", 
        N[Arg[\(f'\)[Z]]]];\)\ \), "\n", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_1\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", Abs[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_1\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", N[Abs[\(f'\)[Z]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The image of a small rectangle about  ",
  Cell[BoxData[
      \(z\_1 = \ \[ImaginaryI]\)]],
  "  is a curvilinear region about ",
  Cell[BoxData[
      \(w\_1 = \ cosh \((1)\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, Iden, wplane, z, zplane];\)\ \), "\n", 
    \(\(Iden[z_] = z;\)\ \), "\n", 
    \(\(f[z_] = Cos[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(zdot = 
        Graphics[{Red, PointSize[0.03], 
            Point[{Re[Z], Im[Z]}]}];\)\ \), "\[IndentingNewLine]", 
    \(\(wdot = 
        Graphics[{Red, PointSize[0.03], 
            Point[{Re[f[Z]], Im[f[Z]]}]}];\)\ \), "\n", 
    \(\(zplane = 
        CartesianMap[
          Iden, {\(-0.5\), 0.5, 0.125}, {0.5, 1.5, 
            0.125}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.8\), 
                0.8}, {0, 1.6}}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-0.75\), 0.75, 
                0.25], Range[\(-1\), 1.5, 0.5]}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(wplane = 
        CartesianMap[
          f, {\(-0.5\), 0.5, 0.125}, {0.5, 1.5, 
            0.125}, \[IndentingNewLine]PlotRange \[Rule] {{0, 
                2.5}, {\(-1.25\), 1.25}}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2.5, 0.5], 
              Range[\(-1\), 1, 0.5]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[zplane, 
        zdot, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.8\), 0.8}, {0, 
              1.6}}, AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-0.75\), 0.75, 0.25], 
            Range[\(-1\), 1.5, 0.5]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A small square about \!\(z\_1\) = \>\"", 
        Z];\)\ \), "\n", 
    \(\(Show[wplane, 
        wdot, \[IndentingNewLine]PlotRange \[Rule] {{0, 2.4}, {\(-1.05\), 
              1.05}}, AspectRatio \[Rule] 
          2.1\/2.4, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2.5, 0.5], 
            Range[\(-1\), 1, 0.5]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The curvilinear image about \!\(w\_1\) = \>\"", \ 
        f[Z], "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z], "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<where \!\(w\_1\) = f(\>\"", Z, "\<) = \>", 
        f[Z], "\< = \>", N[f[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_1\) = Arg(f'(\!\(z\_1\))) = \>\"", 
        Arg[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_1\) = Arg(f'(\!\(z\_1\))) = \>\"", 
        N[Arg[\(f'\)[Z]]]];\)\ \), "\n", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_1\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", Abs[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_1\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", N[Abs[\(f'\)[Z]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Consider the mapping  w = cos(z)  near ",
  Cell[BoxData[
      \(z\_2 = \ 1\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Z = 1;\)\ \), "\n", 
    \(\(Print["\<     f(z) = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<    f'(z) = \>", \(f'\)[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<   At \!\(z\_2\) = \>\"", 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    f(\>", Z, "\<) = \>", 
        f[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    f(\>", Z, "\<) = \>", 
        ComplexExpand[f[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    f(\>", Z, "\<) = \>", N[f[Z]]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<   f'(\>", Z, "\<) = \>", \(f'\)[Z], "\< = \>", 
        N[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_2\) = Arg(f'(\!\(z\_2\))) = \>\"", 
        Arg[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_2\) = Arg(f'(\!\(z\_2\))) = \>\"", 
        N[Arg[\(f'\)[Z]]]];\)\ \), "\n", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_2\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", Abs[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_2\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", N[Abs[\(f'\)[Z]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The image of a small rectangle about  ",
  Cell[BoxData[
      \(z\_2 = \ 1\)]],
  " is a curvilinear region about ",
  Cell[BoxData[
      \(w\_2 = cos \((1)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, Iden, wplane, z, zplane];\)\ \), "\n", 
    \(\(Iden[z_] = z;\)\ \), "\n", 
    \(\(f[z_] = Cos[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(zdot = 
        Graphics[{Red, PointSize[0.03], Point[{Re[Z], Im[Z]}]}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(wdot = 
        Graphics[{Red, PointSize[0.03], Point[{Re[f[Z]], Im[f[Z]]}]}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(zplane = 
        CartesianMap[
          Iden, {0.6, 1.4, 0.1}, {\(-0.4\), 0.4, 
            0.1}, \[IndentingNewLine]PlotRange \[Rule] {{0, 1.5}, {\(-0.75\), 
                0.75}}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2.0, 0.25], 
              Range[\(-1.0\), 1.0, 0.25]}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(wplane = 
        CartesianMap[
          f, {0.6, 1.4, 0.1}, {\(-0.4\), 0.4, 
            0.1}, \[IndentingNewLine]PlotRange \[Rule] {{0, 1.88}, {0.0, 
                1.88}}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2, 0.5], 
              Range[0, 2, 
                0.5]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<u\>", \
"\<v\>"}, PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[zplane, zdot, PlotRange \[Rule] {{0, 1.5}, {\(-0.75\), 0.75}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2.0, 0.5], 
            Range[\(-1.0\), 1.0, 0.25]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A small square about \!\(z\_2\) = \>\"", 
        Z];\)\ \), "\n", 
    \(\(Show[wplane, wdot, PlotRange \[Rule] {{0, 1.0}, {\(-0.5\), 0.5}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 1, 0.5], 
            Range[\(-0.5\), 0.5, 0.25]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<The curvilinear image about \!\(w\_2\) = \>\"", \ 
        f[Z], "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z], "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<where \!\(w\_2\) = f(\>\"", Z, "\<) = \>", 
        f[Z], "\< = \>", N[f[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_2\) = Arg(f'(\!\(z\_2\))) = \>\"", 
        Arg[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_2\) = Arg(f'(\!\(z\_2\))) = \>\"", 
        N[Arg[\(f'\)[Z]]]];\)\ \), "\n", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_2\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", Abs[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_2\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", N[Abs[\(f'\)[Z]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Consider the mapping  w = cos(z)  near ",
  Cell[BoxData[
      \(z\_3 = \ \[Pi] + \[ImaginaryI]\)],
    AspectRatioFixed->True],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Z\  = \ \[Pi] + \[ImaginaryI];\)\ \ \ \ \), "\n", 
    \(\(Print["\<     f(z) = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<    f'(z) = \>", \(f'\)[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<    At  \!\(z\_3\)  = \>\"", 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    f(\>", Z, "\<) = \>", 
        f[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    f(\>", Z, "\<) = \>", N[f[Z]]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<   f'(\>", Z, "\<) = \>", \(f'\)[Z], "\< = \>", 
        N[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_3\) = Arg(f'(\!\(z\_3\))) = \>\"", 
        Arg[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_3\) = Arg(f'(\!\(z\_3\))) = \>\"", 
        N[Arg[\(f'\)[Z]]]];\)\ \), "\n", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_3\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", Abs[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_3\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", N[Abs[\(f'\)[Z]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The image of a small rectangle about  ",
  Cell[BoxData[
      \(z\_3 = \ \[Pi] + \[ImaginaryI]\)],
    AspectRatioFixed->True],
  "  is a curvilinear region about  ",
  Cell[BoxData[
      \(w\_3 = \ \(-cosh\) \((1)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, Iden, wplane, z, zplane];\)\ \), "\n", 
    \(\(Iden[z_] = z;\)\ \), "\n", 
    \(\(f[z_] = Cos[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(zdot = 
        Graphics[{Red, PointSize[0.03], Point[{Re[Z], Im[Z]}]}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(wdot = 
        Graphics[{Red, PointSize[0.03], Point[{Re[f[Z]], Im[f[Z]]}]}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(zplane = 
        CartesianMap[
          Iden, {\[Pi] - 0.5, \[Pi] + 0.5, 0.125}, {0.5, 1.5, 
            0.125}, \[IndentingNewLine]PlotRange \[Rule] {{0, 4}, {0, 2}}, 
          AspectRatio \[Rule] 
            1\/2, \[IndentingNewLine]Ticks \[Rule] {Range[0, 4, 1], 
              Range[0, 2, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(wplane = 
        CartesianMap[
          f, {\[Pi] - 0.5, \[Pi] + 0.5, 0.125}, {0.5, 1.5, 
            0.125}, \[IndentingNewLine]PlotRange \[Rule] {{\(-3.2\), 
                0}, {\(-1.1\), 1.1}}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-3\), 0, 1], 
              Range[\(-1\), 1, 0.5]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[zplane, zdot, PlotRange \[Rule] {{0, 3.65}, {0, 1.55}}, 
        AspectRatio \[Rule] 
          1.55\/3.65, \[IndentingNewLine]Ticks \[Rule] {Range[0, 4, 1], 
            Range[0, 2, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A small square about \!\(z\_3\) = \>\"", 
        Z];\)\ \), "\n", 
    \(\(Show[wplane, wdot, 
        PlotRange \[Rule] {{\(-2.4\), 0}, {\(-1.05\), 1.05}}, 
        AspectRatio \[Rule] 
          2.1\/2.4, \[IndentingNewLine]Ticks \[Rule] {Range[\(-3\), 0, 1], 
            Range[\(-1\), 1, 0.5]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<The curvilinear image about \!\(w\_3\) = \>\"", \ 
        f[Z], "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z], "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<where \!\(w\_3\) = f(\>\"", Z, "\<) = \>", 
        f[Z], "\< = \>", N[f[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_3\) = Arg(f'(\!\(z\_3\))) = \>\"", 
        Arg[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_3\) = Arg(f'(\!\(z\_3\))) = \>\"", 
        N[Arg[\(f'\)[Z]]]];\)\ \), "\n", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_3\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", Abs[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_3\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", N[Abs[\(f'\)[Z]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Consider the mapping  w = cos(z)  near ",
  Cell[BoxData[
      \(z\_4 = \ 1 - \[ImaginaryI]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Z = 1 - \[ImaginaryI];\)\ \), "\n", 
    \(\(Print["\<     f(z) = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<    f'(z) = \>", \(f'\)[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<    At  \!\(z\_4\)  = \>\"", 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    f(\>", Z, "\<) = \>", 
        f[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    f(\>", Z, "\<) = \>", 
        ComplexExpand[f[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    f(\>", Z, "\<) = \>", N[f[Z]]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<   f'(\>", Z, "\<) = \>", \(f'\)[Z], "\< = \>", 
        N[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_4\) = Arg(f'(\!\(z\_4\))) = \>\"", 
        Arg[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_4\) = Arg(f'(\!\(z\_4\))) = \>\"", 
        N[Arg[\(f'\)[Z]]]];\)\ \), "\n", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_4\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", Abs[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_4\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", N[Abs[\(f'\)[Z]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The image of a small rectangle about  z = 1- i  is a curvilinear region \
about ",
  Cell[BoxData[
      \(w = 
        cos \((1)\)\ cosh \((1)\) + \[ImaginaryI]\ sin \((1)\)\ sinh \
\((1)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, Iden, wplane, z, zplane];\)\ \), "\n", 
    \(\(Iden[z_] = z;\)\ \), "\n", 
    \(\(f[z_] = Cos[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(zdot = 
        Graphics[{Red, PointSize[0.03], Point[{Re[Z], Im[Z]}]}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(wdot = 
        Graphics[{Red, PointSize[0.03], Point[{Re[f[Z]], Im[f[Z]]}]}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(zplane = 
        CartesianMap[
          Iden, {0.6, 1.4, 0.1}, {\(-1.4\), \(-0.6\), 
            0.1}, \[IndentingNewLine]PlotRange \[Rule] {{0, 1.5}, {\(-1.5\), 
                0.0}}, AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2.0, 0.5], 
              Range[\(-2.0\), 0.0, 0.5]}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(wplane = 
        CartesianMap[
          f, {0.6, 1.4, 0.1}, {\(-1.4\), \(-0.6\), 
            0.1}, \[IndentingNewLine]PlotRange \[Rule] {{0, 1.88}, {0.0, 
                1.88}}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2, 0.5], 
              Range[0, 2, 
                0.5]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<u\>", \
"\<v\>"}, PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[zplane, zdot, PlotRange \[Rule] {{0, 1.5}, {\(-1.5\), 0.0}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2.0, 0.5], 
            Range[\(-2.0\), 0.0, 0.5]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<A small square about \!\(z\_4\) = \>\"", 
        Z];\)\ \), "\n", 
    \(\(Show[wplane, wdot, PlotRange \[Rule] {{0, 1.88}, {0.0, 1.88}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2, 0.5], 
            Range[0, 2, 0.5]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<The curvilinear image about \!\(w\_4\) = \>\"", \ 
        f[Z], "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z], "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<where \!\(w\_4\) = f(\>\"", Z, "\<) = \>", 
        f[Z], "\< = \>", N[f[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_4\) = Arg(f'(\!\(z\_4\))) = \>\"", 
        Arg[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Rotate \!\(\[Alpha]\_4\) = Arg(f'(\!\(z\_4\))) = \>\"", 
        N[Arg[\(f'\)[Z]]]];\)\ \), "\n", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_4\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", Abs[\(f'\)[Z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< Magnify  =   |f'(\!\(z\_4\))|  = |\>\"", \(f'\)[
          Z], "\<| = \>", N[Abs[\(f'\)[Z]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tLet ",
  StyleBox["f(z)",
    FontFamily->"Courier"],
  " be a nonconstant analytic function.  If ",
  Cell[BoxData[
      \(f' \((z\_0)\) = 0\)]],
  ", then ",
  Cell[BoxData[
      \(z\_0\)]],
  " is called a critical point of ",
  StyleBox["f(z)",
    FontFamily->"Courier"],
  ", and the mapping ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  " is ",
  ButtonBox["not conformal",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/NonconformalMap.html"], None},
    ButtonStyle->"Hyperlink"],
  " at ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  The next result shows what happens at a critical point."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 10.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["f(z)",
    FontFamily->"Courier"],
  " be analytic at the point ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  If ",
  Cell[BoxData[
      RowBox[{\(f' \((z\_0)\) = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(f'' \((z\_0)\) = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\(f\^\((k - 1)\)\) \((z\_0)\) = 
          0\)}]]],
  " ",
  Cell[BoxData[
      SuperscriptBox["", 
        TagBox["",
          Derivative],
        MultilineFunction->None]]],
  "and  ",
  Cell[BoxData[
      \(\(f\^\((k)\)\) \((z\_0)\) \[NotEqual] 0\)]],
  ",  then the mapping ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  " magnifies angles at the vertex ",
  Cell[BoxData[
      \(z\_0\)]],
  " by the factor ",
  StyleBox["k",
    FontFamily->"Courier"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 10.3",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/conformalmapping/\
ConformalMappingFigures/mat1003.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The analytic mapping ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  " at point ",
  Cell[BoxData[
      \(z\_0\)]],
  ", where ",
  Cell[BoxData[
      RowBox[{\(f' \((z\_0)\) = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\(f\^\((k - 1)\)\) \((z\_0)\) = 
          0\)}]]],
  " ",
  Cell[BoxData[
      SuperscriptBox["", 
        TagBox["",
          Derivative],
        MultilineFunction->None]]],
  "and  ",
  Cell[BoxData[
      \(\(f\^\((k)\)\) \((z\_0)\) \[NotEqual] 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 10.2 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the mapping ",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^2\)\)],
    AspectRatioFixed->True],
  " maps the unit square ",
  Cell[BoxData[
      \(S = {x + \[ImaginaryI]\ \(y : \ 0 < x < 1\), 0 < y < 1}\)]],
  " onto the region in the upper half-plane ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  ", which lies under the parabolas  \n\n\t\t\t",
  Cell[BoxData[
      \(u\  = \ 1 - \(1\/4\) v\^2\)]],
  "   and   ",
  Cell[BoxData[
      \(u\  = \ \(-\ 1\) + \(1\/4\) v\^2\)]],
  "\n\nas shown in Figure 10.4. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007e0000_R000`400?l0
0000o`00003oo`3oooof0?ooo`00o`3oooof0?ooo`00o`3oooof0?ooo`00
o`3oooof0?ooo`00o`3oooof0?ooo`00o`3oooof0?ooo`00o`3ooom00?oo
o`D00000U@3oool5000001L0oooo003o0?oood80oooo00<000000?ooo`3o
ool0U`3oool00`000000oooo0?ooo`0G0?ooo`00o`3ooom20?ooo`030000
003oool0oooo09L0oooo00<000000?ooo`3oool05`3oool00?l0oooo>P3o
ool4000000@0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?oo
o`0G0?ooo`00`P3oool2000000@0oooo0P0000040?ooo`800000@03oool5
000002`0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0G
0?ooo`00`@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo00000440oooo00<000000?ooo`3oool0:`3oool2000009P0oooo0P00
000I0?ooo`00`@3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0h03oool00<40oooo00@00000
0?ooo`3oool000002@3oool200000480oooo00<000000?ooo`3oool0h03o
ool00<40oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo0>00oooo00320?ooo`8000002P3oool3
00000400oooo0P00003@0?ooo`@000003P3oool007l0oooo00<000000?oo
o`3oool0_03oool?0000o`030?l000000?l0003o01H0003o00<0o`000000
o`000?l040000?l00`3o0000003o0000o`090000o`80o`001@000?l00`3o
0000003o0000o`1=0000o`H0oooo00@000000?ooo`3oool000003`3oool0
07l0oooo00<000000?ooo`3oool0_03oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`020?ooo`80o`000P3oool00`00
0?l0oooo0?ooo`020?l00080oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00@0oooo00@000000?ooo`3oool000003`3oool007l0oooo00<00000
0?ooo`3oool0VP3oool2000000030?ooo`000000000001d0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
1P3o0000oooo0?ooo`3oool0003o0?ooo`80o`0000<0oooo0000o`000?l0
0P3oool20?l000@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool00`3oool2000000030?ooo`000000000000l0oooo
001o0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`0000007P3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`0:0?l0003oool0oooo0?ooo`000?l0o`000?ooo`000000o`00
0000o`<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0G0?ooo`00O03oool30000
09@0003o100000070?ooo`030000003oool0oooo01d0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0:0?ooo`80003o2P3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`040?l0003oool0o`00
0?l00080003o00<0oooo000000000?l00`3o00000`3oool0o`000?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo01L0oooo001o0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool01`3oool2000000030?ooo`000000000001d0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool20?l0
00<0oooo00<0003o0?ooo`000?l0103oool20?l000D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool05`3oool007l0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0Y0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o0000o`000080
o`0000<0oooo0?l0003oool00`3oool20000o`@0oooo00<0o`000?ooo`3o
0000103o00000`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0G0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo02T0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo
0P3o00000`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
0P000?l30?ooo`030?l0003oool0oooo00@0oooo00<0003o0?l0003o0000
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool05`3oool007l0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0Y0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0103o
ool70?l00080oooo00<0003o0?ooo`3oool0103oool01`3o0000oooo0?oo
o`000?l0oooo000000000?l00P3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00L0o`001P3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo01L0oooo001o0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0:@3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo0?ooo`<0
o`000P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`000?l00P3oool010000000oooo0000o`3o00070?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3o00030?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool05`3oool007l0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00<0
oooo103o000010000?l0o`000?l0003o00050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0
00000080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00<0oooo203o00050?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo01L0oooo001o0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?l000030?l000@0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`040000o`3oool0oooo0?ooo`<0003o00P0oooo
0?l0003oool0oooo0000003oool0o`000?ooo`<0003o0`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool00`3oool60?l000/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo01L0oooo001o0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0:P3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo00@0003o0?ooo`3oool0
oooo2P3o00090?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool010000?l0oooo0000o`000?l50?ooo`050?l0003oool00000
0?ooo`3o0000103oool20000o`030?ooo`000?l0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`T0o`000`3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0603oool007l0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool02@3oool00`3o0000003o0?l000020?l000P0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool0103o0000oooo0000003o0007
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo1@3o000;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0603oool0
07l0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0Z0?oo
o`030000o`3oool0oooo00`0oooo303o00000`3oool0003o0?ooo`0:0?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`030?ooo`<0003o203oool20?l000P0oooo0`000?l50?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0o`0000/0o`003P3oool00`00
0?l0oooo0?ooo`0H0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo02X0oooo00<0003o0?ooo`3oool01`3oool60?l000`0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00`000?l30?ooo`03
0000o`3oool0oooo00D0oooo0P3o00070?ooo`040000o`3oool0oooo0?oo
o`<0003o0P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0;0?oo
o`H0o`002@3oool00`000?l0oooo0?ooo`0H0?ooo`00O`3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo02X0oooo00<0003o0?l0003o
00001`3o00050?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?l000000?l01`3oool00`000?l0oooo0?ooo`030?ooo`04
0?l0003oool000000?l000D0oooo00<0003o0?ooo`3oool01@3oool30000
o`L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool00`3oool:0?l0
01X0oooo001o0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0:P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo0080oooo0`000?l00`3oool0o`000?ooo`080?ooo`03
0000o`3oool0oooo0080o`000P3oool010000000oooo0?l0003o00020?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`000?l00P000?l40?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0603oool007l0ooooU03o000/0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool00P000?l50?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3o0000103oool01`000000
oooo0?ooo`3oool0o`000?ooo`000?l0203oool00`3o0000oooo0?ooo`03
0?ooo`80003o00<0oooo0000o`3oool02P3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0H0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo02/0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02@3oool20000o`L0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`80003o2`3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0H0?ooo`00O`3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo02/0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool01@3oool50000o`T0oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0000o`040?ooo`070000003oool0oooo0?oo
o`000?l0oooo0?l000070?ooo`030?l0003oool0oooo00L0oooo1P000?l6
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01P0oooo001o0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0:`3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`040000o`@0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`030?ooo`80o`000P3oool00`00
0?l0oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000?l00P3oool2
0?l000@0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`03
0?ooo`<0003o0P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0H
0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
02/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000000o`000?l0203oool00`00
0?l0oooo0?ooo`080?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool0
1@000?l0oooo0?ooo`3oool000000080oooo00<0003o0?ooo`3oool00`3o
ool01@3o0000oooo0?ooo`3oool0o`0000T0oooo00<0003o0?ooo`3oool0
1`3oool20000o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01P0oooo
001o0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0:`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool01P3oool40000o`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool01`3oool0103o0000oooo0?l0003o00070?ooo`060000
o`3oool0oooo0000003oool0003o1`3oool30?l000X0oooo00<0003o0?oo
o`3oool0203oool00`3o0000003o0000o`020000o`P0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
01P0oooo001o0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0;03oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0
oooo00@0003o0?ooo`3oool0oooo1@000?l40?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?oo
o`040000o`3oool000000000o`X0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0080oooo1@000?l3
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0I0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo02`0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0;0?ooo`@0003o2@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00H0oooo0P3o00000`3oool0o`000?ooo`090?oo
o`80003o2P3oool0103o0000oooo0?l0003o00070?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool01`3oool40000o`d0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0I0?ooo`00O`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo02`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`080?ooo`80003o00<0oooo0000
o`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00<0oooo0P3o00030?ooo`030?l0003oool0oooo00P0oooo0P000?l:0?oo
o`040?l0003oool0oooo0?ooo`80o`001@3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00X0oooo00@0003o0?ooo`000?l0003o2P3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01T0oooo001o
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0;03oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00@0oooo10000?l3
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203oool0
10000?l0oooo0?ooo`3oool20?l000H0oooo00<0o`000?ooo`3oool01P3o
ool010000?l0oooo000000000?l80?ooo`030?l0003oool0oooo00@0oooo
0P3o00020?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2P3oool010000?l0oooo0?ooo`3oool40000o`H0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0I0?ooo`00O`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo02`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0000o`040000o`L0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0o`0000T0oooo
00<0o`000?ooo`3oool00`3oool20000o`80oooo00@000000?ooo`000?l0
003o1@3oool00`3o0000oooo0?ooo`070?ooo`80o`0000<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00D0
oooo1P000?l00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01T0
oooo001o0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
;03oool00`000?l0oooo0?ooo`090?ooo`@0003o00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?l0003oool02@3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo00D000000?ooo`3oool0oooo0000o`040?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?l0003o00002P3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000000o`00
0?l00`000?l:0?ooo`030000o`3oool0oooo01X0oooo001o0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0;03oool00`000?l0oooo
0?ooo`050?ooo`@0003o103oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool01@3oool30?l000030?oo
o`000?l0oooo00X0oooo00@0o`000?ooo`3oool0003o1@3oool00`000000
oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000/0oooo00<0003o0?oo
o`3oool00P3o00070?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`030?ooo`<0003o1`3oool00`00
0?l0oooo0?ooo`0J0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo02d0oooo00<0003o0?ooo`3oool010000?l80?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`030?ooo`80o`00103oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l000000?l0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000?l0
o`000?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo0P3o00050?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`060?ooo`@0003o0`3oool00`000?l0oooo0?ooo`0J0?ooo`00
O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo02`0oooo
10000?l<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`020?l000L0oooo00<0003o0?ooo`3oool0
2@3oool00`000?l0o`000?ooo`050?ooo`030000003oool0oooo00<0oooo
00<0o`000000o`3oool02P3oool00`000?l0oooo0?ooo`050?ooo`80o`00
0P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool02P3oool40000oa`0oooo001o0?oooi@0003o;`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool02`3oool30?l000X0oooo00<0003o0?ooo`3oool01`3o
ool010000?l0oooo0?ooo`3o00050?ooo`030000003oool0oooo0080oooo
00@0o`000?ooo`3oool0003o2@3oool00`000?l0oooo0?ooo`080?ooo`<0
o`003@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool06`3oool007l0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0]0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`080?ooo`<0o`00
303oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0o`0000@0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?ooo`@0
o`002P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool06`3oool007l0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0]0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`80o`00
0`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`040000
003oool0oooo0?l000H0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`0:0?ooo`040?l0003oool0oooo0?ooo`80o`00203oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool06`3oool007l0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0]0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`030?ooo`<0o`001@3oool00`3o0000
oooo0?ooo`0;0?ooo`040000o`3oool0oooo0?ooo`80003o1`3oool01@3o
0000oooo0?ooo`3oool000000080oooo00<0o`000?ooo`3oool01@3oool2
0000o`<0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`04
0?ooo`<0o`001@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool06`3oool007l0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0^0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`020?l0
00T0oooo00<0o`000?ooo`3oool02P3oool010000?l0oooo0000o`000?l:
0?ooo`060?l0003oool0oooo0000003oool0o`002P3oool30000o`d0oooo
00<0o`000?ooo`3oool01`3oool20?l00080oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01`0oooo
001o0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0;P3o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?l0003o00002`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00/0oooo00@0o`000?ooo`000000o`003@3oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00T0oooo0`3o000=0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool0703oool007l0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0^0?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool02@3oool20?l000030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0203oool30000o`h0oooo0P3o
000=0?ooo`040000o`3oool0003o0000o`X0oooo00<0o`000?ooo`3oool0
303oool00`000?l0o`000?l0000;0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool0703oool007l0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0^0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool01P3oool30?l000<0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`000?l0
3@3oool20?l000d0oooo00D0003o0?ooo`3oool0oooo0000o`090?ooo`03
0?l0003oool0oooo00/0oooo00@0003o0?ooo`3oool0oooo0`3o00080?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0703oool007l0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0^0?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool00P3oool30?l000H0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`040?ooo`80
003o1@3oool00`000?l0oooo0?ooo`090?ooo`040?l0003oool000000?l0
00/0oooo00<0003o0?ooo`3oool00`3oool20000o`H0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`040?ooo`<0o`00103oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01`0oooo001o0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0o`000080o`002P3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080oooo0P000?l70?ooo`03
0000o`3oool0oooo00P0oooo00H0o`000?ooo`3oool000000?ooo`3o0009
0?ooo`030000o`3oool0oooo00H0oooo0P000?l40?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool0203oool30?l000030?ooo`3o0000
oooo00h0oooo00<0003o0?ooo`3oool07@3oool007l0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0_0?ooo`030000o`3oool0oooo
00`0oooo0`3o000=0?ooo`030000o`3oool0oooo00`0oooo00@0o`000?oo
o`000?l0003o2P3oool00`000?l0oooo0?ooo`060?ooo`050?l0003oool0
oooo0?ooo`0000000P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00P0oooo0P000?l00`3oool0o`000?ooo`0=0?ooo`030000o`3o
ool0oooo00/0oooo0`3o000>0?ooo`030000o`3oool0oooo01d0oooo001o
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0;`3oool0
0`000?l0oooo0?ooo`090?ooo`<0o`000P3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000000o`3oool0303oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo0?l000060?ooo`030000o`3oool0oooo00/0oooo0P00
0?l=0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool00`3o
000;0?ooo`030000o`3oool0oooo01d0oooo001o0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`06
0?ooo`<0o`001@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00X0oooo00<0003o0?ooo`3o00003P3oool010000?l0oooo0?ooo`3o
ool20?l000D0oooo00<000000?ooo`3oool00P3oool20?l000<0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0000o`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool00`3oool30?l000P0oooo00<0
003o0?ooo`3oool07@3oool007l0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0`0?ooo`040000o`3oool0oooo0?ooo`@0o`00203o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00P0oooo00@0
003o0?ooo`3oool0o`003P3oool010000?l0oooo0?ooo`3o00070?ooo`03
0000003oool0oooo00@0oooo00<0o`000?ooo`000?l03`3oool0103o0000
oooo0?ooo`000?l:0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool01P3oool40?l000<0oooo00<0003o0?ooo`3oool07P3oool007l0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0`0?ooo`04
0000o`3o0000o`000?l000d0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`060?ooo`80003o103oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3o0000oooo00L0oooo00<000000?ooo`3oool01@3oool00`3o
0000003o0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo0P000?l80?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool40?l0
0200oooo001o0?oooi@0o`00<P3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool00`3oool20000o`L0
oooo00<0o`000?ooo`3oool02`3oool00`3o0000003o0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00<0003o0?l0003oool0303oool00`3o0000
oooo0?ooo`050?ooo`80003o1@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool07P3oool007l0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0a0?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool010000?l0oooo
0?ooo`3oool20000o`T0oooo00<0o`000?ooo`3oool02P3oool0103o0000
oooo0?ooo`000?l70?ooo`030000003oool0oooo00@0oooo00@0003o0?oo
o`3oool0o`002`3oool00`3o0000oooo0?ooo`080?ooo`80003o0`3oool0
0`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool07`3oool007l0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0a0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool03@3oool30000o``0oooo00<0o`000?ooo`3oool0203oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`3oool02P3oool30000o`l0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`0O0?ooo`00O`3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo0340oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0<0?ooo`80003o3`3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0=0?ooo`80
003o3P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01l0
oooo001o0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
<P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00X0oooo
0P000?l20?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
0`3oool20?l000P0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000o`3oool0oooo00D0oooo0P3o00050?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool00P000?l<0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool0803oool007l0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0b0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool01P3oool30000o`@0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00T0oooo00D0003o0?ooo`3oool0oooo000000030?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo0080oooo0`000?l80?ooo`030?l0
003oool0oooo00h0oooo00<0003o0?ooo`3oool0803oool007l0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0b0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool0103oool20000o`P0oooo00<0
003o0?ooo`3oool03@3oool0103o0000oooo0?l0003o000<0?ooo`050000
o`3oool0oooo0?ooo`0000000P3oool00`000?l0oooo0?ooo`0:0?ooo`80
o`0000<0oooo0?l0003oool03P3oool00`000?l0oooo0?ooo`060?ooo`80
003o1P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0200
oooo001o0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
<`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo
0P000?l:0?ooo`030000o`3oool0oooo00d0oooo0P3o000?0?ooo`060000
o`3oool0oooo0000003oool0003o3`3oool20?l000l0oooo00<0003o0?oo
o`3oool0203oool20000o`<0oooo00<0o`000?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`0Q0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo03<0oooo00<0003o0?ooo`3oool03P3oool0103o0000
oooo0000o`000?l=0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3o0000403oool010000?l0oooo000000000?l@0?ooo`030?l0003oool0
o`0000d0oooo00<0003o0?ooo`3oool02`3oool20000o`030?ooo`3o0000
oooo00l0oooo00<0003o0?ooo`3oool08@3oool007l0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0d0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000000o`3oool03P3oool00`000?l0oooo0?ooo`0:0?oo
o`050?l0003oool0oooo0?ooo`3o0000403oool20000oa00oooo00D0o`00
0?ooo`3oool0oooo0?l0000<0?ooo`030000o`3oool0oooo00d0oooo0P00
0?l@0?ooo`030000o`3oool0oooo0240oooo001o0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0=03oool00`000?l0oooo0?ooo`0;
0?ooo`80003o00<0oooo0?l0003oool03`3oool00`000?l0oooo0?ooo`07
0?ooo`80o`00103oool00`3o0000oooo0?ooo`0>0?ooo`80003o3`3oool0
0`3o0000oooo0?ooo`030?ooo`80o`002@3oool00`000?l0oooo0?ooo`0>
0?ooo`040?l0003oool0003o0000o`h0oooo00<0003o0?ooo`3oool08@3o
ool007l0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0e
0?ooo`030000o`3oool0oooo00P0oooo0P000?l30?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030?l0003oool0oooo00`0oooo00@0003o0?ooo`000000003o3P3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`020?ooo`80003o2`3o
ool00`000?l0oooo0?ooo`0R0?ooo`00O`3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo03D0oooo00<0003o0?ooo`3oool01P3oool2
0000o`H0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool02P3oool0
1P000?l0oooo0?ooo`000000oooo0000o``0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool0103oool20000o`T0oooo00<0003o0?ooo`3oool0
8P3oool007l0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0e0?ooo`030000o`3oool0oooo00<0oooo0`000?l90?ooo`030?l0003o
ool0oooo00h0oooo00@0003o0?ooo`3oool0oooo0P3o000;0?ooo`030?l0
003oool0oooo00P0oooo00D0003o0?ooo`3oool0oooo000000020?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool20?l000<0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`070?ooo`<0
003o1@3oool00`000?l0oooo0?ooo`0S0?ooo`00O`3ooonD0000ocP0oooo
00<0003o0?ooo`000?l00P000?l<0?ooo`030?l0003oool0oooo00h0oooo
00@0003o0?ooo`3oool0o`003P3oool00`3o0000oooo0?ooo`050?ooo`80
003o103oool010000000oooo0?ooo`3oool20000o`L0oooo00<0o`000?oo
o`3oool0303oool0103o0000oooo0?ooo`000?l@0?ooo`030?l0003oool0
oooo00X0oooo0`000?l20?ooo`030000o`3oool0oooo02<0oooo001o0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0=P3oool20000
oa00oooo00<0o`000?ooo`3oool03P3oool00`000?l0o`000?ooo`0>0?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool03@3oool00`3o0000003o0?ooo`0?0?ooo`030?l0003oool0oooo
00h0oooo0P000?lV0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo03H0oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0=0?ooo`80o`0000<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?l0003o00003`3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo02@0oooo001o0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
003oool0oooo00X0oooo0P3o00020?ooo`030000o`3oool0oooo00l0oooo
00@0o`000?ooo`000?l0003o203oool00`000000oooo0?ooo`050?ooo`80
003o00<0oooo0?l0003oool0403oool00`000?l0oooo0?ooo`020?l000`0
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0U0?ooo`00
O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo03L0oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`080?ooo`80o`00
1@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00<0oooo0P3o00090?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool09@3oool007l0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0g0?ooo`030000o`3oool0oooo0100oooo00<0
o`000?ooo`3oool01@3oool20?l000P0oooo00<0003o0?ooo`3oool03@3o
ool00`000?l0oooo0?l000090?ooo`030000003oool0oooo00H0oooo00<0
o`000?ooo`000?l03`3oool00`000?l0oooo0?ooo`060?ooo`80o`001`3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo02D0oooo001o
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0>03oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00<0oooo0P3o000:
0?ooo`030000o`3oool0oooo00`0oooo00D0003o0?ooo`3oool0oooo0?l0
00080?ooo`030000003oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo
0000o`0>0?ooo`030000o`3oool0oooo00P0oooo0P3o00040?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool09P3oool007l0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0h0?ooo`030000o`3o
ool0oooo0100oooo00D0o`000?ooo`3oool0oooo0?l0000=0?ooo`030000
o`3oool0oooo00T0oooo0P000?l50?ooo`030?l0003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`80003o
2`3oool00`000?l0oooo0?ooo`0;0?ooo`050?l0003oool0oooo0?ooo`3o
00004P3oool00`000?l0oooo0?ooo`0V0?ooo`00O`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo03T0oooo00<0003o0?ooo`3oool0
3`3oool0103o0000oooo0?l0003o000?0?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo00d0oooo0`3o000B0?ooo`03
0000o`3oool0oooo02L0oooo001o0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0>@3oool00`000?l0oooo0?ooo`0?0?ooo`80o`00
4@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`0?0?ooo`80o`004@3oool00`000?l0oooo0?ooo`0W0?ooo`00O`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo03X0oooo00<0
003o0?ooo`3oool0303oool20?l000030?ooo`3o0000oooo0140oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`020?l000h0oooo00<0003o0?ooo`3oool0:03o
ool007l0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0j
0?ooo`030000o`3oool0oooo00X0oooo0P3o00040?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool00P3oool20000o`d0oooo00<0o`00
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0o`0000d0oooo0P00
0?l40?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool00P3o
ool20?l000`0oooo00<0003o0?ooo`3oool0:03oool007l0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0j0?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0@
0?ooo`040000o`3oool0oooo0000oa00oooo00D0o`000?ooo`3oool0oooo
000000020?ooo`030?l0003oool0oooo00h0oooo00@0003o0?ooo`3oool0
003o4@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool0:@3oool006h0oooo0P0000040?ooo`800000
103oool2000000<0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0k0?ooo`030000o`3oool0oooo00H0oooo0P3o00080?ooo`030?l0
003oool0oooo0100oooo0P000?lB0?ooo`060?l0003oool0oooo0000003o
ool0o`004P3oool20000oa80oooo00<0o`000?ooo`3oool01P3oool20?l0
00P0oooo00<0003o0?ooo`3oool0:@3oool006d0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000020?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0403oool2
0000oa<0oooo00@0o`000?ooo`000000o`004`3oool20000oa40oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo02X0oooo001]0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool0U03o000n0?ooo`030000o`3oool0oooo0080oooo0P3o
000<0?ooo`030?l0003oool0oooo00d0oooo0P000?l00`3oool0003o0?oo
o`0=0?ooo`D0000000<0oooo0?l0003o0000503oool010000?l0oooo0000
o`000?l?0?ooo`030?l0003oool0oooo00X0oooo0P3o00040?ooo`030000
o`3oool0oooo02X0oooo001]0?ooo`040000003oool0oooo000000T0oooo
0P0000030?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
?03oool00`000?l0oooo0?ooo`020?l000l0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00d0oooo
00@000000?ooo`3oool0oooo0P3o000C0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0=0?ooo`80
o`0000<0oooo0000o`3oool0;03oool006d0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0?@3oool00`000?l0o`000?ooo`0@0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`0<0?ooo`070000003oool0oooo0?l0003oool000000?l0000A
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0?0?ooo`80o`00;@3oool006h0oooo0P00000:0?oo
o`<000000P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
03d0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool02`3oool00`00
0000oooo0?l000020?ooo`030000003oool0o`0000l0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool0:`3oool007l0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0n0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool01@3oool20000o`X0oooo00<0003o0?ooo`3o
ool02P3oool20?l000<0oooo00<000000?ooo`3oool00P3o000<0?ooo`03
0000o`3oool0oooo00P0oooo0P000?l70?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool0;03oool007l0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0n0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000000003oool00`3oool00`000000oooo
0?ooo`020?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool0;03oool007l0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0o0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0303o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool0;@3oool007l0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0o0?ooo`030000o`3oool0oooo0180oooo00@0o`00
0?ooo`000?l0003o4@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00h0oooo0P000?l00`3oool0o`000?oo
o`0C0?ooo`030000o`3oool0oooo02d0oooo001o0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0@03oool00`000?l0oooo0?ooo`0A
0?ooo`030?l000000?l0oooo01<0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0A0?ooo`80003o4`3oool0
0`000?l0oooo0?ooo`0^0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo0400oooo00<0003o0?ooo`3oool0403oool20000
o`030?l0003oool0oooo0180oooo00D0003o0?ooo`3oool0oooo0?l00009
0?ooo`030000003oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo0000
o`0D0?ooo`040?l0003oool0003o0000oa40oooo00<0003o0?ooo`3oool0
;P3oool007l0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`110?ooo`030000o`3oool0oooo00h0oooo00D0003o0?ooo`3oool0oooo
0?l0000D0?ooo`030000o`3oool0o`0000X0oooo00<000000?ooo`3oool0
1`3oool00`3o0000oooo0000o`0D0?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0_0?ooo`00O`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo0440oooo00<0
003o0?ooo`3oool0303oool20000o`@0oooo00<0o`000?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<0
o`000000o`3oool04`3oool00`3o0000oooo0?ooo`030?ooo`80003o3@3o
ool00`000?l0oooo0?ooo`0_0?ooo`00O`3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo0480oooo00<0003o0?ooo`3oool02@3oool2
0000o`L0oooo00<0o`000?ooo`3oool04@3oool00`3o0000003o0?ooo`0:
0?ooo`030000003oool0oooo00P0oooo00<0003o0?l0003oool04P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo00<0003o
0?ooo`3oool0<03oool007l0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`130?ooo`030000o`3oool0oooo00H0oooo0P000?l:0?oo
o`030?l0003oool0oooo00h0oooo0P3o00020?ooo`030000o`3oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?l0
0100oooo00<0o`000?ooo`3oool0203oool20000o`P0oooo00<0003o0?oo
o`3oool0<@3oool007l0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`130?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool0<@3oool007l0ooooU0000?m60?ooo`030000o`3oool0oooo0080oooo
0P000?l>0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00`0oooo0P000?l40?ooo`030000o`3oool0oooo0380oooo
001o0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0A@3o
ool010000?l0oooo0000o`000?lA0?ooo`030?l0003oool0oooo00T0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`090?ooo`030?l0003oool0oooo00l0oooo0P000?l00`3oool0003o
0?ooo`0d0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo04D0oooo0P000?lC0?ooo`030?l0003oool0oooo00L0oooo0P3o
000;0?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`090?ooo`80o`002@3oool00`3o0000oooo0?oo
o`0A0?ooo`80003o=@3oool007l0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`160?ooo`030000o`3oool0oooo0180oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`0d0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo04H0oooo00<0003o0?ooo`3oool04`3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0003o0100oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0
oooo03@0oooo001o0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0A`3oool00`000?l0oooo0?ooo`0C0?ooo`050?l0003oool0oooo
0?ooo`3o00004P3oool01@000?l0oooo0?ooo`3oool000000080oooo00<0
003o0?ooo`3oool0403oool01@3o0000oooo0?ooo`3oool0o`0001D0oooo
00<0003o0?ooo`3oool0=@3oool007l0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`170?ooo`030000o`3oool0oooo01<0oooo00@0
o`000?ooo`3oool0o`00503oool01P000?l0oooo0?ooo`000000oooo0000
oa@0oooo00<0o`000?ooo`3o00005P3oool00`000?l0oooo0?ooo`0e0?oo
o`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo04P0
oooo00<0003o0?ooo`3oool04`3oool20?l001H0oooo00@0003o0?ooo`00
0000003o5P3oool20?l001D0oooo00<0003o0?ooo`3oool0=P3oool007l0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`190?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3o00005`3oool20000oaL0
oooo00<0o`000?ooo`3o00004`3oool00`000?l0oooo0?ooo`0g0?ooo`00
O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo04T0oooo
00<0003o0?ooo`3oool0403oool01@3o0000oooo0?ooo`3oool0o`0001H0
oooo0P000?lF0?ooo`050?l0003oool0oooo0?ooo`3o00004P3oool00`00
0?l0oooo0?ooo`0g0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo04X0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo0180oooo00@0003o0?ooo`00
0000003o503oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool0>03oool007l0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`1;0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0@0?ooo`06
0000o`3oool0oooo0000003oool0003o4P3oool00`3o0000oooo0?ooo`05
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0>@3oool0
07l0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`1;0?oo
o`030000o`3oool0oooo00X0oooo0P3o00080?ooo`030?l0003oool0oooo
00l0oooo00D0003o0?ooo`3oool0oooo000000020?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool01`3oool20?l000`0oooo00<0003o
0?ooo`3oool0>@3oool007l0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`1<0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
0080oooo00D000000?ooo`3oool0oooo0000o`0?0?ooo`030?l0003oool0
oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0j
0?ooo`00O`3ooonD0?l004l0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo03/0oooo001o0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0C@3oool00`000?l0oooo0?ooo`040?ooo`80
o`003`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00d0oooo0P3o00060?ooo`030000o`3oool0oooo03/0
oooo001o0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
CP3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0100oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo0P000?l80?ooo`030?l0003oool0oooo0100oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0l0?ooo`00O`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo04l0oooo00@0
003o0?ooo`3o0000o`00503oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo0180oooo0P3o00000`3oool0003o
0?ooo`0n0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo0500oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo01@0oooo00<0
o`000?ooo`3oool0?P3oool007l0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`1@0?ooo`030000o`3oool0oooo01D0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00D0003o0?ooo`3oool0oooo0?l0000G0?ooo`030000o`3o
ool0oooo03h0oooo001o0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0D@3oool00`000?l0oooo0?ooo`0E0?ooo`040?l0003oool0
oooo0000o`/0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo0?l0
000G0?ooo`030000o`3oool0oooo03l0oooo001o0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0DP3oool00`000?l0oooo0?ooo`0E
0?ooo`030?l000000?l0oooo00/0oooo00<000000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo0400oooo001o0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0D`3oool00`00
0?l0oooo0?ooo`0C0?ooo`030000o`3oool0o`0000`0oooo00<000000?oo
o`3oool02@3oool00`3o0000oooo0000o`0E0?ooo`030000o`3oool0oooo
0440oooo001o0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0D`3oool00`000?l0oooo0?ooo`0B0?ooo`050000o`3oool0oooo0?oo
o`3o00002`3oool00`000000oooo0?ooo`080?ooo`050?l0003oool0oooo
0?ooo`000?l04`3oool00`000?l0oooo0?ooo`120?ooo`00O`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo05@0oooo00<0003o0?oo
o`3oool0403oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0@P3oool007l0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`1E0?ooo`03
0000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo04<0
oooo001o0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
EP3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo
0?ooo`140?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo05L0oooo00<0003o0?ooo`3oool02@3oool20000o`/0oooo00<0
o`000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030?l0003o
ool0oooo00T0oooo0P000?l;0?ooo`030000o`3oool0oooo04D0oooo001o
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0E`3oool0
0`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`15
0?ooo`00O`3ooonD0000oeX0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool0AP3oool007l0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`1I0?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<0o`000?ooo`3oool03`3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo04H0oooo001o0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0FP3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0o`0001<0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`170?ooo`00O`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo05X0oooo00<0003o0?ooo`3oool0
0P000?lE0?ooo`050?l0003oool0oooo0?ooo`0000000P3oool00`3o0000
oooo0?ooo`0C0?ooo`80003o0`3oool00`000?l0oooo0?ooo`170?ooo`00
O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo05/0oooo
0P000?lH0?ooo`060?l0003oool0oooo0000003oool0o`00603oool00`00
0?l0oooo0000o`1:0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo05/0oooo0P000?lI0?ooo`040?l0003oool000000?l0
01X0oooo00<0003o0?ooo`3oool0B@3oool007l0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`1M0?ooo`030000o`3oool0oooo01L0
oooo0P3o000J0?ooo`030000o`3oool0oooo04X0oooo001o0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0G@3oool00`000?l0oooo
0?ooo`0G0?ooo`80o`006@3oool00`000?l0oooo0?ooo`1;0?ooo`00O`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo05h0oooo00<0
003o0?ooo`3oool05@3oool0103o0000oooo0000003o000G0?ooo`030000
o`3oool0oooo04`0oooo001o0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0G`3oool00`000?l0oooo0?ooo`0C0?ooo`060?l0003o
ool0oooo0000003oool0o`005@3oool00`000?l0oooo0?ooo`1=0?ooo`00
O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo0600oooo
00<0003o0?ooo`3oool04@3oool01@3o0000oooo0?ooo`3oool000000080
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`1>0?ooo`00
O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo0640oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`3o00004@3oool00`000?l0oooo0?ooo`1?0?ooo`00
O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo0640oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo
0?ooo`1?0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo0680oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`1@0?ooo`00O`3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo06<0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`1A0?ooo`00O`3ooonD0?l0
06H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`1B0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo06@0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`1B0?ooo`00O`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo06D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1C0?ooo`00O`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo06H0oooo00<0
003o0?ooo`3oool00P3oool20?l000/0oooo00<000000?ooo`3oool0203o
ool20?l000@0oooo00<0003o0?ooo`3oool0E03oool007l0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`1W0?ooo`040000o`3oool0
oooo0?l000d0oooo00<000000?ooo`3oool02P3oool0103o0000oooo0?oo
o`000?mG0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo06P0oooo00<0003o0?l0003oool03@3oool00`000000oooo0?oo
o`0;0?ooo`030?l000000?l0oooo05L0oooo001o0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0J@3oool00`000?l0oooo0?ooo`0<
0?ooo`030000003oool0oooo00/0oooo00<0003o0?ooo`3oool0E`3oool0
07l0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`1Z0?oo
o`030000o`3oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`1H0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo06/0oooo00<0003o0?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000o`3oool0oooo05T0oooo001o0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0K03oool00`000?l0oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool0
FP3oool007l0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`1]0?ooo`030000o`3oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`1K0?ooo`00O`3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo06h0oooo00<0003o0?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000o`3oool0oooo05`0oooo001i0?oo
o`D0000000<0oooo0000o`3oool03@3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`1_0?oo
o`030000o`3oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`1L0?ooo`00N`3oool01@000000oooo0?ooo`3oool0003o
00h0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0L03oool00`000?l0oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool0G@3oool007/0
oooo00@000000?ooo`3oool0ooooU0000?mc0?ooo`030000o`3oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`1N0?oo
o`00N`3oool01@000000oooo0?ooo`3oool000000?l0oooo203oool00`00
0?l0oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0003o0?oo
o`3oool0G`3oool007/0oooo00D000000?ooo`3oool0oooo0000003o0?oo
o`T0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000o`3oool0oooo0600oooo001j0?ooo`8000000`3oool00`000000
oooo0?ooo`3o0?ooo`P0oooo00D0003o0?ooo`3oool0oooo000000030?oo
o`030000o`3oool0oooo0640oooo001o0?ooo`030000003oool0oooo0?l0
oooo2@3oool010000?l0oooo0?ooo`0000020?ooo`030000o`3oool0oooo
0680oooo003o0?ooohL0oooo100000001P3oool0003o0?ooo`000000oooo
0000ofD0oooo003o0?ooohL0oooo00<000000?ooo`3oool00`3oool00`00
0?l000000000o`1V0?ooo`00o`3ooon80?ooo`030000003oool0oooo00<0
oooo00<0003o0000003oool0I@3oool00?l0ooooR@3oool00`000000oooo
0?ooo`1Z0?ooo`00o`3ooon70?ooo`040000003oool0oooo000006/0oooo
001m0?ooo`800000o`3oool90?ooo`800000K03oool007h0oooo00<00000
0?ooo`3oool0o`3ooome0?ooo`00O`3oool00`000000oooo0?ooo`3o0?oo
og@0oooo001n0?ooo`030000003oool000000?l0ooooM@3oool007d0oooo
00@000000?ooo`3oool00000o`3ooome0?ooo`00O03oool3000000030?oo
o`00000000000?l0ooooM03oool00?l0ooooS@3oool2000006L0oooo003o
0?ooohd0oooo0P00001W0?ooo`00o`3ooon<0?ooo`040000003oool0oooo
000006H0oooo003o0?oooh/0oooo0P0000020?ooo`800000I@3oool00?l0
oooomP3oool00?l0oooomP3oool00?l0oooomP3oool00?l0oooomP3oool0
0001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{501, 190},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 10.4",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/conformalmapping/\
ConformalMappingFigures/mat1004.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The mapping  ",
  Cell[BoxData[
      \(w\  = \ z\^2\)],
    AspectRatioFixed->True],
  "."
}], "Text"],

Cell[TextData[{
  "Solution.  The derivative is  ",
  Cell[BoxData[
      \(f' \((z)\) = 2  z\)],
    AspectRatioFixed->True],
  ",  and we conclude that the mapping  ",
  Cell[BoxData[
      \(w = z\^2\)],
    AspectRatioFixed->True],
  "  is conformal for all  ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)],
    AspectRatioFixed->True],
  ".   Note that the right angles at the vertices  ",
  Cell[BoxData[
      \(z\_1 = 1\)]],
  ", ",
  Cell[BoxData[
      \(z\_2 = 1 + \[ImaginaryI]\)]],
  ", and ",
  Cell[BoxData[
      \(z\_3 = \[ImaginaryI]\)]],
  "  are mapped onto right angles at the vertices  ",
  Cell[BoxData[
      \(w\_1 = 1\)]],
  ", ",
  Cell[BoxData[
      \(w\_2 = 2  \[ImaginaryI]\)]],
  ", and ",
  Cell[BoxData[
      \(w\_3 = \(-1\)\)]],
  ",  respectively.  At the point  ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  ",  we have  ",
  Cell[BoxData[
      \(f' \((z\_0)\) = \ \(f' \((0)\) = 0\)\)]],
  "  and  ",
  Cell[BoxData[
      \(f'' \((z\_0)\) = \ \(f'' \((0)\) = 2 \[NotEqual] 0\)\)]],
  ".  Hence angles at the vertex  ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  "  are magnified by the factor ",
  Cell[BoxData[
      \(k = 2\)]],
  ".  In particular, the right angle at ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  " is mapped onto the straight angle at ",
  Cell[BoxData[
      \(w\_0 = 0\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f \((z)\) = z\^2\)],
    AspectRatioFixed->True],
  "  and graph the mapping."
}], "Text"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\(Clear[f, Iden, z];\)\ \n
    \(Iden[z_]\  = \ z;\)\ \n
    \(f[z_]\  = \ z\^2;\)\ \n
    \(CartesianMap[
        Iden, {0, 1, 0.1}, {0, 1, 
          0.1}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 1, 0.5], 
            Range[0, 1, 
              0.5]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Blue, Red}];\)\ \ \[IndentingNewLine]
    \(Print["\<Vertical lines x = a, and horizontal lines y = b,\>"];\)\ \
\[IndentingNewLine]
    \(Print["\<forming a unit square in the z-plane.\>"];\)\ \n
    \(CartesianMap[\ 
        f\ \ , {0, 1, 0.1}, {0, 1, 
          0.1}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 1, 1], 
            Range[0, 2, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        PlotRange \[Rule] {{\(-1\), 1}, {0, 2}}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Red}];\)\ \ \[IndentingNewLine]
    \(Print["\<The image parabolas \>", \ 
        u \[Equal] a\^2 - v\^2\/\(4  a\^2\), "\< and \>", 
        u \[Equal] \(-b\^2\) + v\^2\/\(4\ b\^2\)];\)\ \n
    \(Print["\<under the mapping  w = \>", f[z]];\)\ \[IndentingNewLine]
    \)\)\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tAnother property of a conformal mapping   ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  is obtained by considering the modulus of  ",
  Cell[BoxData[
      \(f' \((z\_0)\)\)]],
  ".  If  ",
  Cell[BoxData[
      \(z\_1\)]],
  "  is near  ",
  Cell[BoxData[
      \(z\_0\)]],
  ",  we can use the equation  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z\_1)\)\ \  = \ \ f \((z\_0)\)\  + \ 
          f' \((z\_0)\) \((z\_1 - z\_0)\)\  + \ \[Eta] \((z\_1)\) \((z\_1 - 
                z\_0)\)\)]],
  " \n\nand neglect the term  ",
  Cell[BoxData[
      \(\[Eta] \((z\_1)\) \((z\_1 - z\_0)\)\)]],
  ".  We then have the approximation\n\n",
  StyleBox["(10-9)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      RowBox[{\(w\_1 - w\_0\), "  ", "=", "  ", 
        RowBox[{\(f \((z\_1)\) - f \((z\_0)\)\), "  ", 
          StyleBox["\[TildeTilde]",
            FontSize->14], "  ", \(f' \((z\_0)\) \((z\_1 - z\_0)\)\)}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tFrom Equation ",
  StyleBox["(10-9)",
    FontColor->RGBColor[0, 0, 1]],
  ", the distance  ",
  Cell[BoxData[
      \(\(\(|\)\(w\_1 - w\_0\)\(|\)\)\)]],
  "  between the images of the points  ",
  Cell[BoxData[
      \(z\_1\)]],
  "  and  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  given approximately by  ",
  Cell[BoxData[
      \(\(\(|\)\(f' \((z\_0)\) || z\_1 - z\_0\)\(|\)\)\)]],
  ".  Therefore we say that the transformation   ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  changes small distances near ",
  Cell[BoxData[
      \(z\_0\)]],
  " by the scale factor ",
  Cell[BoxData[
      \(\(\(|\)\(f' \((z\_0)\)\)\(|\)\)\)]],
  ".   For example, the scale factor of the transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = z\^2\)\)],
    AspectRatioFixed->True],
  "  near the point  ",
  Cell[BoxData[
      \(z\_0 = 1 + \[ImaginaryI]\)]],
  "  is  ",
  Cell[BoxData[
      \(\(\(|\)\(f' \((z\_0)\)\)\(|\)\)\  = \ \(\(\(|\)\(2 
               z\_0\)\(|\)\)\  = \(\(\(|\)\(2 \((1 + \
\[ImaginaryI])\)\)\(|\)\)\  = \ 2\ \@\(\(2\)\(\ \)\)\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe also need to say a few things about the inverse transformation   ",
  Cell[BoxData[
      \(z = g \((w)\)\)]],
  "  of a conformal mapping   ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  near a point ",
  Cell[BoxData[
      \(z\_0\)]],
  ", where ",
  Cell[BoxData[
      \(f' \((z\_0)\) \[NotEqual] 0\)]],
  ".  \nA complete justification of the following assertions relies on \
theorems studied in advanced calculus. (See, for instance, R. Creighton Buck, \
Advanced Calculus, 3rd ed. (New York, McGraw-Hill), pp. 358-361, 1978.)  "
}], "Text"],

Cell[TextData[{
  "\tWe express the mapping   ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  in the coordinate form  \n\n",
  StyleBox["(10-10)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{"u", "=", 
        RowBox[{
          RowBox[{"u", \((x, y)\), "   ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "   ", "v"}], 
          "=", \(v \((x, y)\)\)}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe mapping in Equations ",
  StyleBox["(10-10)",
    FontColor->RGBColor[0, 0, 1]],
  " represents a transformation from the xy plane into the uv plane, and the \
Jacobian determinant, ",
  Cell[BoxData[
      \(J \((x, y)\)\)]],
  ", is defined by  \n\n",
  StyleBox["(10-11)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{\(J \((x, y)\)\), "  ", "=", "  ", 
        RowBox[{"|", GridBox[{
              {\(\(u\_x\) \((x, y)\)\), \(\(u\_y\) \((x, y)\)\)},
              {\(\(v\_x\) \((x, y)\)\), \(\(v\_y\) \((x, y)\)\)}
              }], "|"}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe transformation in Equations ",
  StyleBox["(10-10)",
    FontColor->RGBColor[0, 0, 1]],
  " has a local inverse, provided  ",
  Cell[BoxData[
      \(J \((x, y)\) \[NotEqual] 0\)]],
  ".  Expanding Equation ",
  StyleBox["(10-11)",
    FontColor->RGBColor[0, 0, 1]],
  " and using the Cauchy--Riemann equations, we obtain  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(J \((x\_0, y\_0)\)\), "   ", "=", "   ", 
          RowBox[{
            RowBox[{"|", GridBox[{
                  {\(\(u\_x\) \((x\_0, y\_0)\)\), \(\(u\_y\) \((x\_0, 
                        y\_0)\)\)},
                  {\(\(v\_x\) \((x\_0, y\_0)\)\), \(\(v\_y\) \((x\_0, 
                        y\_0)\)\)}
                  }], "|"}], "    ", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", "                  ", "=", 
            "   ", \(\(u\_x\) \((x\_0, y\_0)\) \(v\_y\) \((x\_0, 
                  y\_0)\)\ \  - \ \ \(v\_x\) \((x\_0, 
                  y\_0)\) \(u\_y\) \((x\_0, y\_0)\)\)}]}], " ", 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "                       ", \(\(=\)\(\ \ \ \)\(\(u\_x\) \((x\_0, 
                y\_0)\) \(u\_x\) \((x\_0, y\_0)\)\ \  - \ \ \(v\_x\) \((x\_0, 
                y\_0)\) \((\(-v\_x\) \((x\_0, y\_0)\))\)\)\), " ", 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "                       ", \(\(=\)\(\ \ \ \)\(\(u\_x\%2\) \((x\_0, 
                y\_0)\)\ \  + \ \ \(v\_x\%2\) \((x\_0, y\_0)\)\)\), "  ", 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "                       ", \(\(=\)\(\ \)\(\(|\)\(\ \)\(f' \
\((z\_0)\)\)\(|\)\(\ \ \)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(\(\[NotEqual]\)\(\ \)\(0\)\)\)\)}]}]],
  "  "
}], "Text"],

Cell[TextData[{
  "\tConsequently, Equations ",
  StyleBox["(10-11)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(10-11)",
    FontColor->RGBColor[0, 0, 1]],
  " imply that a local inverse ",
  Cell[BoxData[
      \(z = g \((w)\)\)]],
  " exists in a neighborhood of the point  ",
  Cell[BoxData[
      \(w\_0 = f \((z\_0)\)\)]],
  ".  The derivative of ",
  StyleBox["g(w)",
    FontFamily->"Courier New"],
  " at ",
  Cell[BoxData[
      \(w\_0\)]],
  " is given by the familiar expression  \n\n\t\t\t",
  Cell[BoxData[{
      \(g' \((w\_0)\)\ \  = \ \ \(\(\(lim\)\(\ \)\)\+\(w \[Rule] w\_0\)\ \(g \
\((w)\) - g \((w\_0)\)\)\/\(w - w\_0\)\ \  = \ \ \ \(\(\(lim\)\(\ \)\)\+\(w \
\[Rule] w\_0\)\ \(z - z\_0\)\/\(w - w\_0\)\ \  = \ \ \ \(\(lim\)\(\ \)\)\+\(z \
\[Rule] z\_0\)\ \(z - z\_0\)\/\(w - w\_0\)\)\)\ \ \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(\(lim\)\(\ \
\)\)\+\(z \[Rule] z\_0\)\ \(z - z\_0\)\/\(f \((z)\) - f \((z\_0)\)\)\ \  = \ \
\ \ \(\(lim\)\(\ \)\)\+\(z \[Rule] z\_0\)\ 1/\((\(f \((z)\) - f \
\((z\_0)\)\)\/\(z - z\_0\))\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1/\((\(\(lim\)\(\ \
\)\)\+\(z \[Rule] z\_0\)\ \(f \((z)\) - f \((z\_0)\)\)\/\(z - z\_0\))\)\)\)\
\[IndentingNewLine]\ \), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1\/\(f' \((z\_0)\)\
\)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1\/\(f' \((g \
\((w\_0)\))\)\)\)\)\)}]],
  "   "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Conformal Mapping",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ConformalMappingBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Mobius - Bilinear Transformation",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/MobiusTranformationBib.\
html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{968, 641},
WindowMargins->{{7, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[12194, 423, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[94167, 2084, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 192788, 3910}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 203, 7, 33, "Text"],
Cell[2308, 71, 1114, 21, 147, "Text"],
Cell[3425, 94, 134, 2, 33, "Text"],
Cell[3562, 98, 2260, 85, 242, "Text",
  Evaluatable->False],
Cell[5825, 185, 769, 27, 242, "Text"],
Cell[6597, 214, 289, 11, 71, "Text"],
Cell[6889, 227, 919, 33, 147, "Text"],
Cell[7811, 262, 999, 30, 166, "Text"],
Cell[8813, 294, 913, 30, 33, "Text"],
Cell[9729, 326, 609, 19, 52, "Text",
  Evaluatable->False],
Cell[10341, 347, 901, 36, 33, "Text",
  Evaluatable->False],
Cell[11245, 385, 598, 22, 33, "Text"],

Cell[CellGroupData[{
Cell[11868, 411, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[12016, 417, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[12194, 423, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[12554, 435, 666, 25, 49, "Text",
  Evaluatable->False],
Cell[13223, 462, 46900, 772, 202, 46786, 768, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[60126, 1236, 8963, 231, 390, "Text"],

Cell[CellGroupData[{
Cell[69114, 1471, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[69278, 1477, 49, 0, 33, "Text"],
Cell[69330, 1479, 255, 6, 110, "Input"],
Cell[69588, 1487, 208, 8, 33, "Text"],
Cell[69799, 1497, 1290, 24, 310, "Input"],
Cell[71092, 1523, 218, 8, 33, "Text"],
Cell[71313, 1533, 3365, 64, 646, "Input"],
Cell[74681, 1599, 196, 8, 33, "Text"],
Cell[74880, 1609, 1370, 25, 330, "Input"],
Cell[76253, 1636, 204, 8, 33, "Text"],
Cell[76460, 1646, 3363, 64, 590, "Input"],
Cell[79826, 1712, 244, 9, 33, "Text"],
Cell[80073, 1723, 1281, 23, 310, "Input"],
Cell[81357, 1748, 262, 9, 33, "Text"],
Cell[81622, 1759, 3320, 60, 616, "Input"],
Cell[84945, 1821, 212, 8, 33, "Text"],
Cell[85160, 1831, 1389, 25, 330, "Input"],
Cell[86552, 1858, 234, 8, 33, "Text"],
Cell[86789, 1868, 3324, 61, 590, "Input"]
}, Closed]],
Cell[90128, 1932, 645, 25, 49, "Text"],
Cell[90776, 1959, 1662, 59, 52, "Text",
  Evaluatable->False],
Cell[92441, 2020, 1375, 48, 33, "Text"],

Cell[CellGroupData[{
Cell[93841, 2072, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[93989, 2078, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[94167, 2084, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[94527, 2096, 694, 23, 128, "Text",
  Evaluatable->False],
Cell[95224, 2121, 84590, 1390, 204, 84476, 1386, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[179817, 3513, 479, 17, 33, "Text"],
Cell[180299, 3532, 1345, 53, 71, "Text"],

Cell[CellGroupData[{
Cell[181669, 3589, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[181833, 3595, 156, 6, 33, "Text"],
Cell[181992, 3603, 1229, 25, 328, "Input"]
}, Closed]],
Cell[183236, 3631, 1027, 33, 144, "Text",
  Evaluatable->False],
Cell[184266, 3666, 1106, 38, 71, "Text"],
Cell[185375, 3706, 576, 16, 71, "Text"],
Cell[185954, 3724, 669, 22, 71, "Text"],
Cell[186626, 3748, 622, 19, 83, "Text"],
Cell[187251, 3769, 1857, 40, 275, "Text"],
Cell[189111, 3811, 1637, 39, 296, "Text"],
Cell[190751, 3852, 290, 7, 33, "Text"],
Cell[191044, 3861, 291, 7, 33, "Text"],
Cell[191338, 3870, 306, 7, 33, "Text"],
Cell[191647, 3879, 257, 5, 33, "Text"],
Cell[191907, 3886, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

